(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   4027242,     155005]*)
(*NotebookOutlinePosition[   4027984,     155030]*)
(*  CellTagsIndexPosition[   4027940,     155026]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["FOCUSING IN FRONT OF NONHOMOGENEITY", "Text",
  FontSize->14,
  Background->None]], "Title",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  StyleBox["The wavefront  and the tail  are incident from the left.\n\nThe \
nonhomogeneity  ",
    FontSize->12],
  StyleBox["is located on the positive ",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"],
  StyleBox["x",
    FontSize->12,
    FontSlant->"Italic",
    CharacterEncoding->"WindowsANSI"],
  StyleBox["-axis.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"],
  StyleBox["  \n\nThe focusing location,  ",
    FontSize->12],
  StyleBox["x0",
    FontSize->12,
    FontVariations->{"CompatibilityType"->0},
    CharacterEncoding->"WindowsANSI"],
  StyleBox[" <0, is in front of the nonhomogeneity and needs to be specified. \
\n\nThe potential   v[x], which is ",
    FontSize->12],
  StyleBox["the nonhomogeneity, is strictly positive.  \n\nThe transmission \
coefficient, left reflection coefficient, and right reflection coefficient, \
respectively, are denoted by  T[k],  L[k],  R[k].\n\nThe tail of the wave is \
denoted by  g[x,t].\n\nThe focusing moment is chosen as  t=0.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"]
}], "Text",
  FontSize->18,
  Background->RGBColor[1, 1, 0]],

Cell["\<\
The potential and the scattering coefficients are given next:\
\>", \
"Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(Clear[v, T, L, R, x0, g, e]; 
    v[x_] = \ UnitStep[
          x]\ 80\ \((Sqrt[5] + 1)\) \((Sqrt[5] + 
            2)\)\ E^\((2\ Sqrt[
                  5]\ x)\)/\((\((1 + Sqrt[5])\) \((2 + 
                      Sqrt[5])\)\ E^\((2\ Sqrt[5]\ x)\) - 2)\)^2;\), "\n", 
    \(\(T[k_] = 
        k \((k + I\ Sqrt[5])\)/\((\((k + I)\) \((k + 2\ I)\))\);\)\), "\n", 
    \(\(L[k_] = 2/\((\((k + I)\) \((k + 2\ I)\))\);\)\), "\n", 
    \(\(R[
          k_] = \(-2\)\ \((k + 
                I\ Sqrt[5])\)/\((\((k + I)\) \((k + 2\ I)\) \((k - 
                    I\ Sqrt[5])\))\);\)\)}], "Input",
  CellOpen->False],

Cell["\<\
Specify the focusing location  x0, a nonpositive number, \
next:\
\>", "Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(\(x0 = \(-1\);\)\(\ \)\)\)], "Input"],

Cell["The tail  g[x,t]  of the focusing  wave is evaluated  next:", "Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(\(e[x_] = 
        4\ Sqrt[5]/\((\((1 + Sqrt[5])\) \((2 + 
                      Sqrt[5])\)\ E^\((2\ Sqrt[5]\ x)\) - 
                2)\);\)\n\t\t\), "\n", 
    \(\(q25[x_, t_] = \ 
        2 \((Sqrt[5] - 2 + 
                e[x])\)\ E^\((2 \((\ x - x0 - t)\))\)\  - \((Sqrt[5] - 1 + 
                e[x])\)\ E^\((x - x0 - t)\);\)\n\t\), "\n", 
    \(\t\(q26[x_, t_] = 
        2 \((E^\((\(-2\) \((\ x + x0 + t)\))\)\  - 
              E^\((\(-\((\ x + x0 + t)\)\))\))\)\ ;\)\n\n\), "\n", 
    \(\(g[x_, t_] = \ 
        UnitStep[x]\ \ \ UnitStep[\(-x\) + x0 + t]\ q25[x, t] + 
          UnitStep[\(-x\)]\ \ \ UnitStep[x + x0 + t]\ q26[x, 
              t];\)\)}], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`Animation`\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`FilledPlot`\)], "Input",
  CellOpen->False],

Cell[TextData[{
  "The focusing wave is animated  next. The wavefront (",
  StyleBox["magenta",
    FontColor->RGBColor[1, 0, 1]],
  ") and the tail (",
  StyleBox["blue",
    FontColor->RGBColor[0, 0, 1]],
  ") are incident from the left onto the nonhomogeneity (",
  StyleBox["green",
    FontColor->RGBColor[0, 1, 0]],
  "):"
}], "Text",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Animate[{FilledPlot\[IndentingNewLine][{v[x]}, \ {x, \ \(-2\), \ 
              2}, \ PlotRange -> {\(-1\), 4}, \ 
            Fills \[Rule] {Hue[ .3]}], \[IndentingNewLine]\ \ \ \ \ \ \ \
Plot[{10\ UnitStep[x - x0 - t]}, \ {x, \ \(-2\), \ 2}, \ 
            PlotStyle \[Rule] \ Hue[ .9], 
            PlotRange -> {\(-1\), 
                1}], \[IndentingNewLine]\ \ \ \ \ \ \ Plot[{g[x, 
                t]}, {x, \ \(-2\), \ 2}, \ PlotStyle \[Rule] \ Hue[ .6], \ 
            PlotRange -> {\(-1\), 
                1}]}, \[IndentingNewLine]\ {t, \ \(-0.2\), \ 2.9,  .02}, 
        PlotLabel \[Rule] {"\<t\>", t}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20178 .12361 L
.20742 .12361 L
.21019 .12361 L
.2114 .12361 L
.21274 .12361 L
.21394 .12361 L
s
.21394 .12361 m
.21439 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00ol0V@000?ooo`0:oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0;Oooo`03o`2Ioooooooo
00[oool00`000?ooooooo`0ioooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00A_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000c<ol01P0005Goool004Koool00ol0VOoo
ooooo`16oooo00<0000co`0co`00<C?o0080001Koooo0016oooo00?o09Woooooool0A_ooo`030000
<ol0<ol002lco`020000GOooo`00A_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000/<ol00`00
05ooool004Koool00ol0VOooooooo`16oooo0P0002Xco`030000H_ooo`00A_ooo`03o`2Ioooooooo
04Koool00`0003?o03?o000W<ol00P0006Goool004Koool00ol0VOooooooo`16oooo00<0000co`0c
o`009S?o00030000oooooooo06Goool004Koool00ol0VOooooooo`16oooo00<0000co`0co`009C?o
00030000oooooooo06Koool004Koool00ol0VOooooooo`16oooo00<0000co`0co`0093?o00030000
oooooooo06Ooool004Koool00ol0VOooooooo`16oooo00<0000co`0co`008S?o0080001Zoooo0016
oooo00?o09Woooooool0A_ooo`80000R<ol000<0003oooooool0J_ooo`00A_ooo`03o`2Ioooooooo
04Koool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00A_ooo`03o`2Ioooooooo04Koool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00A_ooo`03o`2Ioooooooo04Koool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00A_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00A_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00A_ooo`03o`2Ioooooooo04Koool200007C?o00030000oooooooo06ooool0
04Koool00ol0VOooooooo`16oooo00<0000co`0co`006c?o00030000oooooooo073oool004Koool0
0ol0VOooooooo`16oooo00<0000co`0co`006c?o00030000oooooooo073oool004Koool00ol0VOoo
ooooo`16oooo00<0000co`0co`006S?o00030000oooooooo077oool004Koool00ol0VOooooooo`16
oooo00<0000co`0co`006S?o00030000oooooooo077oool004Koool00ol0VOooooooo`16oooo00<0
000co`0co`006C?o00030000oooooooo07;oool004Koool00ol0VOooooooo`16oooo0P0001Xco`00
0`000?ooooooo`1boooo0016oooo00?o09Woooooool0A_ooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo0016oooo00?o09Woooooool0A_ooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo0016oooo00?o09Woooooool0A_ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo0016
oooo00?o09Woooooool0A_ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo0016oooo00?o
09Woooooool0?_ooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool004Koool0
0ol0VOooooooo`10oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo0016oooo00?o09Woooooool0@?ooo`030000oooooooo00?oool300005C?o00030000oooooooo
07Koool004Koool00ol0VOooooooo`10oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1foooo0016oooo00?o09Woooooool0@?ooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00A_ooo`03o`2Ioooooooo03ooool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo0016oooo00?o09Woooooool0A_ooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo0016oooo00?o09Woooooool0A_ooo`030000<ol0<ol001<co`00
0`000?ooooooo`1hoooo0016oooo00?o09Woooooool0A_ooo`80000D<ol000<0003oooooool0N?oo
o`00A_ooo`03o`2Ioooooooo04Koool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00A_oo
o`03o`2Ioooooooo04Koool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00A_ooo`03o`2I
oooooooo04Koool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00A_ooo`03o`2Ioooooooo
04Koool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00A_ooo`03o`2Ioooooooo04Koool0
0`0003?o03?o000A<ol000<0003oooooool0N_ooo`00A_ooo`03o`2Ioooooooo04Koool200004S?o
00030000oooooooo07[oool004Koool00ol0VOooooooo`16oooo00<0000co`0co`004C?o00030000
oooooooo07[oool004Koool00ol0VOooooooo`16oooo00<0000co`0co`004C?o00030000oooooooo
07[oool004Koool00ol0VOooooooo`16oooo00<0000co`0co`0043?o00030000oooooooo07_oool0
04Koool00ol0VOooooooo`16oooo00<0000co`0co`0043?o00030000oooooooo07_oool004Koool0
0ol0VOooooooo`16oooo00<0000co`0co`0043?o00030000oooooooo07_oool004Koool00ol0VOoo
ooooo`16oooo00<0000co`0co`0043?o00030000oooooooo07_oool004Koool00ol0VOooooooo`16
oooo0P00010co`000`000?ooooooo`1loooo0016oooo00?o09Woooooool0A_ooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo0016oooo00?o09Woooooool0A_ooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo0016oooo00?o09Woooooool0A_ooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo0016oooo00?o09Woooooool0A_ooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo0016oooo00?o09Woooooool0A_ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo0016
oooo00?o09Woooooool0A_ooo`80000?<ol000<0003oooooool0OOooo`00A_ooo`03o`2Ioooooooo
04Koool00`0003?o03?o000><ol000<0003oooooool0OOooo`00A_ooo`03o`2Ioooooooo04Koool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00A_ooo`03o`2Ioooooooo04Koool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00A_ooo`03o`2Ioooooooo03koool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo0016oooo00?o09Woooooool0?_ooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00A_ooo`03o`2Ioooooooo03ooool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo0017oooo00?o09Woooooool0?ooo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Aoooo`03o`2I
oooooooo03goool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00Aoooo`03o`2Ioooooooo03koool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo0017oooo00?o09Woooooool0AOooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0017
oooo00?o09Woooooool0AOooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0017oooo00?o
09Woooooool0AOooo`80000=<ol000<0003oooooool0Ooooo`00Aoooo`03o`2Ioooooooo04Goool0
0`0003?o03?o000<<ol000<0003oooooool0Ooooo`00Aoooo`03o`2Ioooooooo04Goool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00Aoooo`03o`2Ioooooooo04Goool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00Aoooo`03o`2Ioooooooo04Goool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00Aoooo`03o`2Ioooooooo04Goool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Aoooo`03o`2Ioooooooo04Goool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00Aoooo`03o`2Ioooooooo04Goool2000033?o00030000oooooooo083oool004Ooool00ol0VOoo
ooooo`15oooo00<0000co`0co`002c?o00030000oooooooo083oool004Ooool00ol0VOooooooo`15
oooo00<0000co`0co`002S?o00030000oooooooo087oool004Ooool00ol0VOooooooo`15oooo00<0
000co`0co`002S?o00030000oooooooo087oool004Ooool00ol0VOooooooo`15oooo00<0000co`0c
o`002S?o00030000oooooooo087oool004Ooool00ol0VOooooooo`15oooo00<0000co`0co`002S?o
00030000oooooooo087oool004Ooool00ol0VOooooooo`15oooo0P0000/co`000`000?ooooooo`21
oooo0017oooo00?o09Woooooool0AOooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0017
oooo00?o09Woooooool0AOooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0017oooo00?o
09Woooooool0AOooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo0017oooo00?o09Wooooo
ool0AOooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo0017oooo00?o09Woooooool0AOoo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo0017oooo00?o09Woooooool0AOooo`80000:
<ol000<0003oooooool0P_ooo`00Aoooo`03o`2Ioooooooo04Goool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00Aoooo`03o`2Ioooooooo04Goool00`0003?o03?o0009<ol000<0003ooooo
ool0P_ooo`00Aoooo`03o`2Ioooooooo04Goool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00Aoooo`03o`2Ioooooooo03koool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo0017oooo00?o09Woooooool0?Oooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo0017oooo00?o09Woooooool0?oooo`030000oooooooo00?oool3000023?o
00030000oooooooo08?oool004Ooool00ol0VOooooooo`10oooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo0017oooo00?o09Woooooool0?Oooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo0017oooo00?o09Woooooool0?_oo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool004Ooool00ol0VOooooooo`15
oooo00<0000co`0co`001c?o00030000oooooooo08Coool004Ooool00ol0VOooooooo`15oooo00<0
000co`0co`001c?o00030000oooooooo08Coool004Ooool00ol0VOooooooo`15oooo00<0000co`0c
o`001c?o00030000oooooooo08Coool004Ooool00ol0VOooooooo`15oooo0P0000Pco`000`000?oo
ooooo`24oooo0017oooo00?o09Woooooool0AOooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo0017oooo00?o09Woooooool0AOooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0017
oooo00?o09Woooooool0AOooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0017oooo00?o
09Woooooool0AOooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo0017oooo00?o09Wooooo
ool0AOooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo0017oooo00?o09Woooooool0AOoo
o`800007<ol000<0003oooooool0QOooo`00Aoooo`03o`2Ioooooooo04Goool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00Aoooo`03o`2Ioooooooo04Goool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00Aoooo`03o`2Ioooooooo04Goool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00Aoooo`03o`2Ioooooooo04Goool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00Aoooo`03o`2Ioooooooo04Goool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00Aooo
o`03o`2Ioooooooo04Goool200001S?o00030000oooooooo08Koool004Ooool00ol0VOooooooo`15
oooo00<0000co`0co`001C?o00030000oooooooo08Koool004Ooool00ol0VOooooooo`15oooo00<0
000co`0co`001C?o00030000oooooooo08Koool004Ooool00ol0VOooooooo`15oooo00<0000co`0c
o`001C?o00030000oooooooo08Koool004Ooool00ol0VOooooooo`15oooo00<0000co`0co`001C?o
00030000oooooooo08Koool004Ooool00ol0VOooooooo`15oooo00<0000co`0co`001C?o00030000
oooooooo08Koool004Ooool00ol0VOooooooo`15oooo0P0000Hco`000`000?ooooooo`26oooo0017
oooo00?o09Woooooool0AOooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0017oooo00?o
09Woooooool0AOooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0017oooo00?o09Wooooo
ool0AOooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo0017oooo00?o09Woooooool0AOoo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo0017oooo00?o09Woooooool0?oooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool004Ooool00ol0VOooooooo`10oooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo0017oooo00?o09Wooooo
ool0?Oooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Woool4<ol00P000004<ol0oooooooooooo0P0000?oool400000oooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool4
00000c?o00040000<ol0<ol000002?ooo`030000oooooooo00Coool00`000?ooooooo`1hoooo001g
oooo00<0003oooooool00_ooo`030000oooooooo013oool3<ol000@0000co`0co`000009oooo00<0
003oooooool01?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003oooo`<co`00
100003?o03?o000000[oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000001;oool3<ol000@0000co`0co`000008oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo01?oool4<ol00P000003<ol0oooooooo00Ooool2
00000oooo`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{79.5625, 308.938}, {290.125, 148.813}} -> {-0.349561, \
1.05307, 0.00349883, 0.00566123}, {{79.875, 308.563}, {290.125, 148.813}} -> \
{-4.02891, 4.80237, 0.0165954, 0.0319664}, {{79.875, 308.563}, {290.125, \
148.813}} -> {-4.02891, 4.80237, 0.0165954, 0.0319664}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20178 .12361 L
.20742 .12361 L
.21274 .12361 L
.21506 .12361 L
.21753 .12361 L
.21881 .12361 L
s
.21881 .12361 m
.2191 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?l0VOooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0;oooo`03o`2Ioooooooo
00Soool00`000?ooooooo`0ioooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00B?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000c<ol01P0005Goool004Soool00ol0VOoo
ooooo`14oooo00<0000co`0co`00<C?o0080001Koooo0018oooo00?o09Woooooool0A?ooo`030000
<ol0<ol002lco`020000GOooo`00B?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000/<ol00`00
05ooool004Soool00ol0VOooooooo`14oooo0P0002Xco`030000H_ooo`00B?ooo`03o`2Ioooooooo
04Coool00`0003?o03?o000W<ol00P0006Goool004Soool00ol0VOooooooo`14oooo00<0000co`0c
o`009S?o00030000oooooooo06Goool004Soool00ol0VOooooooo`14oooo00<0000co`0co`009C?o
00030000oooooooo06Koool004Soool00ol0VOooooooo`14oooo00<0000co`0co`0093?o00030000
oooooooo06Ooool004Soool00ol0VOooooooo`14oooo00<0000co`0co`008S?o0080001Zoooo0018
oooo00?o09Woooooool0A?ooo`80000R<ol000<0003oooooool0J_ooo`00B?ooo`03o`2Ioooooooo
04Coool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00B?ooo`03o`2Ioooooooo04Coool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00B?ooo`03o`2Ioooooooo04Coool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00B?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00B?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00B?ooo`03o`2Ioooooooo04Coool200007C?o00030000oooooooo06ooool0
04Soool00ol0VOooooooo`14oooo00<0000co`0co`006c?o00030000oooooooo073oool004Soool0
0ol0VOooooooo`14oooo00<0000co`0co`006c?o00030000oooooooo073oool004Soool00ol0VOoo
ooooo`14oooo00<0000co`0co`006S?o00030000oooooooo077oool004Soool00ol0VOooooooo`14
oooo00<0000co`0co`006S?o00030000oooooooo077oool004Soool00ol0VOooooooo`14oooo00<0
000co`0co`006C?o00030000oooooooo07;oool004Soool00ol0VOooooooo`14oooo0P0001Xco`00
0`000?ooooooo`1boooo0018oooo00?o09Woooooool0A?ooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo0018oooo00?o09Woooooool0A?ooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo0018oooo00?o09Woooooool0A?ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo0018
oooo00?o09Woooooool0A?ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo0018oooo00?o
09Woooooool0??ooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool004Soool0
0ol0VOooooooo`0noooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo0018oooo00?o09Woooooool0?_ooo`030000oooooooo00?oool300005C?o00030000oooooooo
07Koool004Soool00ol0VOooooooo`0noooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1foooo0018oooo00?o09Woooooool0?_ooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00B?ooo`03o`2Ioooooooo03goool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo0018oooo00?o09Woooooool0A?ooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo0018oooo00?o09Woooooool0A?ooo`030000<ol0<ol001<co`00
0`000?ooooooo`1hoooo0018oooo00?o09Woooooool0A?ooo`80000D<ol000<0003oooooool0N?oo
o`00B?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00B?oo
o`03o`2Ioooooooo04Coool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00B?ooo`03o`2I
oooooooo04Coool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00B?ooo`03o`2Ioooooooo
04Coool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00B?ooo`03o`2Ioooooooo04Coool0
0`0003?o03?o000A<ol000<0003oooooool0N_ooo`00B?ooo`03o`2Ioooooooo04Coool200004S?o
00030000oooooooo07[oool004Soool00ol0VOooooooo`14oooo00<0000co`0co`004C?o00030000
oooooooo07[oool004Soool00ol0VOooooooo`14oooo00<0000co`0co`004C?o00030000oooooooo
07[oool004Soool00ol0VOooooooo`14oooo00<0000co`0co`0043?o00030000oooooooo07_oool0
04Soool00ol0VOooooooo`14oooo00<0000co`0co`0043?o00030000oooooooo07_oool004Soool0
0ol0VOooooooo`14oooo00<0000co`0co`0043?o00030000oooooooo07_oool004Soool00ol0VOoo
ooooo`14oooo00<0000co`0co`0043?o00030000oooooooo07_oool004Soool00ol0VOooooooo`14
oooo0P00010co`000`000?ooooooo`1loooo0018oooo00?o09Woooooool0A?ooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo0018oooo00?o09Woooooool0A?ooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo0018oooo00?o09Woooooool0A?ooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo0018oooo00?o09Woooooool0A?ooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo0018oooo00?o09Woooooool0A?ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo0018
oooo00?o09Woooooool0A?ooo`80000?<ol000<0003oooooool0OOooo`00B?ooo`03o`2Ioooooooo
04Coool00`0003?o03?o000><ol000<0003oooooool0OOooo`00B?ooo`03o`2Ioooooooo04Coool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00B?ooo`03o`2Ioooooooo04Coool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00B?ooo`03o`2Ioooooooo03coool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo0018oooo00?o09Woooooool0??ooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00B?ooo`03o`2Ioooooooo03goool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo0018oooo00?o09Woooooool0?_oo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00B?ooo`03o`2I
oooooooo03coool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00B?ooo`03o`2Ioooooooo03goool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo0018oooo00?o09Woooooool0A?ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0018
oooo00?o09Woooooool0A?ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0018oooo00?o
09Woooooool0A?ooo`80000=<ol000<0003oooooool0Ooooo`00B?ooo`03o`2Ioooooooo04Coool0
0`0003?o03?o000<<ol000<0003oooooool0Ooooo`00B?ooo`03o`2Ioooooooo04Coool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00B?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00B?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00B?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00B?ooo`03o`2Ioooooooo04Coool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00B?ooo`03o`2Ioooooooo04Coool2000033?o00030000oooooooo083oool004Soool00ol0VOoo
ooooo`14oooo00<0000co`0co`002c?o00030000oooooooo083oool004Soool00ol0VOooooooo`14
oooo00<0000co`0co`002S?o00030000oooooooo087oool004Soool00ol0VOooooooo`14oooo00<0
000co`0co`002S?o00030000oooooooo087oool004Soool00ol0VOooooooo`14oooo00<0000co`0c
o`002S?o00030000oooooooo087oool004Soool00ol0VOooooooo`14oooo00<0000co`0co`002S?o
00030000oooooooo087oool004Soool00ol0VOooooooo`14oooo0P0000/co`000`000?ooooooo`21
oooo0018oooo00?o09Woooooool0A?ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0018
oooo00?o09Woooooool0A?ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0018oooo00?o
09Woooooool0A?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo0018oooo00?o09Wooooo
ool0A?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo0018oooo00?o09Woooooool0A?oo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo0018oooo00?o09Woooooool0A?ooo`80000:
<ol000<0003oooooool0P_ooo`00B?ooo`03o`2Ioooooooo04Coool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00B?ooo`03o`2Ioooooooo04Coool00`0003?o03?o0009<ol000<0003ooooo
ool0P_ooo`00B?ooo`03o`2Ioooooooo04Coool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00B?ooo`03o`2Ioooooooo03goool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo0018oooo00?o09Woooooool0??ooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo0018oooo00?o09Woooooool0?_ooo`030000oooooooo00?oool3000023?o
00030000oooooooo08?oool004Soool00ol0VOooooooo`0ooooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo0018oooo00?o09Woooooool0??ooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo0018oooo00?o09Woooooool0?Ooo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool004Soool00ol0VOooooooo`14
oooo00<0000co`0co`001c?o00030000oooooooo08Coool004Soool00ol0VOooooooo`14oooo00<0
000co`0co`001c?o00030000oooooooo08Coool004Soool00ol0VOooooooo`14oooo00<0000co`0c
o`001c?o00030000oooooooo08Coool004Soool00ol0VOooooooo`14oooo0P0000Pco`000`000?oo
ooooo`24oooo0018oooo00?o09Woooooool0A?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo0018oooo00?o09Woooooool0A?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0018
oooo00?o09Woooooool0A?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0018oooo00?o
09Woooooool0A?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo0018oooo00?o09Wooooo
ool0A?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo0018oooo00?o09Woooooool0A?oo
o`800007<ol000<0003oooooool0QOooo`00B?ooo`03o`2Ioooooooo04Coool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00B?ooo`03o`2Ioooooooo04Coool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00B?ooo`03o`2Ioooooooo04Coool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00B?ooo`03o`2Ioooooooo04Coool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00B?ooo`03o`2Ioooooooo04Coool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00B?oo
o`03o`2Ioooooooo04Coool200001S?o00030000oooooooo08Koool004Soool00ol0VOooooooo`14
oooo00<0000co`0co`001C?o00030000oooooooo08Koool004Soool00ol0VOooooooo`14oooo00<0
000co`0co`001C?o00030000oooooooo08Koool004Soool00ol0VOooooooo`14oooo00<0000co`0c
o`001C?o00030000oooooooo08Koool004Soool00ol0VOooooooo`14oooo00<0000co`0co`001C?o
00030000oooooooo08Koool004Soool00ol0VOooooooo`14oooo00<0000co`0co`001C?o00030000
oooooooo08Koool004Soool00ol0VOooooooo`14oooo0P0000Hco`000`000?ooooooo`26oooo0018
oooo00?o09Woooooool0A?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0018oooo00?o
09Woooooool0A?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0018oooo00?o09Wooooo
ool0A?ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo0018oooo00?o09Woooooool0A?oo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo0018oooo00?o09Woooooool0?_ooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool004Soool00ol0VOooooooo`0ooooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo0018oooo00?o09Wooooo
ool0??ooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00M_ooo`030000oooooooo01Koool7<ol04Ooo
o`030000oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool03?ooo`Lco`0B
oooo00<0003oooooool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00coool00c?o000000000004<ol00P0000?oool500000_ooo`800004oooo00<0003oooooool0MOoo
o`00MOooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00003oooo00@0000co`0co`000003<ol01oooo`050000oooooooooooo000000;oool01@000?oo
ooooooooo`00001goooo001doooo00<0003oooooool00_ooo`030000oooooooo01?oool0100003?o
03?o000000<co`07oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`1doooo001eoooo00<0003oooooool01@0001;oool0100003?o03?o000000<co`07oooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo0000
01Goool0100003?o03?o000000<co`07oooo00D0003oooooooooool000000_ooo`050000oooooooo
oooo000007Ooool007Koool00`000?ooooooo`0Foooo00<co`000000000013?o00Koool200001?oo
o`800003oooo00<0003oooooool0M_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.21345 .12361 L
.21786 .12361 L
.22037 .12361 L
.22159 .12361 L
.22272 .12361 L
s
.22272 .12361 m
.22318 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooool0V@09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0<?ooo`03o`2Ioooooooo
00Ooool00`000?ooooooo`0ioooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00BOooo`03o`2Ioooooooo04?oool00`0003?o03?o000c<ol01P0005Goool004Woool00ol0VOoo
ooooo`13oooo00<0000co`0co`00<C?o0080001Koooo0019oooo00?o09Woooooool0@oooo`030000
<ol0<ol002lco`020000GOooo`00BOooo`03o`2Ioooooooo04?oool00`0003?o03?o000/<ol00`00
05ooool004Woool00ol0VOooooooo`13oooo0P0002Xco`030000H_ooo`00BOooo`03o`2Ioooooooo
04?oool00`0003?o03?o000W<ol00P0006Goool004Woool00ol0VOooooooo`13oooo00<0000co`0c
o`009S?o00030000oooooooo06Goool004Woool00ol0VOooooooo`13oooo00<0000co`0co`009C?o
00030000oooooooo06Koool004Woool00ol0VOooooooo`13oooo00<0000co`0co`0093?o00030000
oooooooo06Ooool004Woool00ol0VOooooooo`13oooo00<0000co`0co`008S?o0080001Zoooo0019
oooo00?o09Woooooool0@oooo`80000R<ol000<0003oooooool0J_ooo`00BOooo`03o`2Ioooooooo
04?oool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00BOooo`03o`2Ioooooooo04?oool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00BOooo`03o`2Ioooooooo04?oool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00BOooo`03o`2Ioooooooo04?oool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00BOooo`03o`2Ioooooooo04?oool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00BOooo`03o`2Ioooooooo04?oool200007C?o00030000oooooooo06ooool0
04Woool00ol0VOooooooo`13oooo00<0000co`0co`006c?o00030000oooooooo073oool004Woool0
0ol0VOooooooo`13oooo00<0000co`0co`006c?o00030000oooooooo073oool004Woool00ol0VOoo
ooooo`13oooo00<0000co`0co`006S?o00030000oooooooo077oool004Woool00ol0VOooooooo`13
oooo00<0000co`0co`006S?o00030000oooooooo077oool004Woool00ol0VOooooooo`13oooo00<0
000co`0co`006C?o00030000oooooooo07;oool004Woool00ol0VOooooooo`13oooo0P0001Xco`00
0`000?ooooooo`1boooo0019oooo00?o09Woooooool0@oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo0019oooo00?o09Woooooool0@oooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo0019oooo00?o09Woooooool0@oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo0019
oooo00?o09Woooooool0@oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo0019oooo00?o
09Woooooool0>oooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool004Woool0
0ol0VOooooooo`0moooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo0019oooo00?o09Woooooool0?Oooo`030000oooooooo00?oool300005C?o00030000oooooooo
07Koool004Woool00ol0VOooooooo`0moooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1foooo0019oooo00?o09Woooooool0?Oooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00BOooo`03o`2Ioooooooo03coool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo0019oooo00?o09Woooooool0@oooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo0019oooo00?o09Woooooool0@oooo`030000<ol0<ol001<co`00
0`000?ooooooo`1hoooo0019oooo00?o09Woooooool0@oooo`80000D<ol000<0003oooooool0N?oo
o`00BOooo`03o`2Ioooooooo04?oool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00BOoo
o`03o`2Ioooooooo04?oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00BOooo`03o`2I
oooooooo04?oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00BOooo`03o`2Ioooooooo
04?oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00BOooo`03o`2Ioooooooo04?oool0
0`0003?o03?o000A<ol000<0003oooooool0N_ooo`00BOooo`03o`2Ioooooooo04?oool200004S?o
00030000oooooooo07[oool004Woool00ol0VOooooooo`13oooo00<0000co`0co`004C?o00030000
oooooooo07[oool004Woool00ol0VOooooooo`13oooo00<0000co`0co`004C?o00030000oooooooo
07[oool004Woool00ol0VOooooooo`13oooo00<0000co`0co`0043?o00030000oooooooo07_oool0
04Woool00ol0VOooooooo`13oooo00<0000co`0co`0043?o00030000oooooooo07_oool004Woool0
0ol0VOooooooo`13oooo00<0000co`0co`0043?o00030000oooooooo07_oool004Woool00ol0VOoo
ooooo`13oooo00<0000co`0co`0043?o00030000oooooooo07_oool004Woool00ol0VOooooooo`13
oooo0P00010co`000`000?ooooooo`1loooo0019oooo00?o09Woooooool0@oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo0019oooo00?o09Woooooool0@oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo0019oooo00?o09Woooooool0@oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo0019oooo00?o09Woooooool0@oooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo0019oooo00?o09Woooooool0@oooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo0019
oooo00?o09Woooooool0@oooo`80000?<ol000<0003oooooool0OOooo`00BOooo`03o`2Ioooooooo
04?oool00`0003?o03?o000><ol000<0003oooooool0OOooo`00BOooo`03o`2Ioooooooo04?oool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00BOooo`03o`2Ioooooooo04?oool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00BOooo`03o`2Ioooooooo03_oool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo0019oooo00?o09Woooooool0>oooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00BOooo`03o`2Ioooooooo03coool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo0019oooo00?o09Woooooool0?Ooo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00BOooo`03o`2I
oooooooo03_oool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00BOooo`03o`2Ioooooooo03coool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo0019oooo00?o09Woooooool0@oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0019
oooo00?o09Woooooool0@oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0019oooo00?o
09Woooooool0@oooo`80000=<ol000<0003oooooool0Ooooo`00BOooo`03o`2Ioooooooo04?oool0
0`0003?o03?o000<<ol000<0003oooooool0Ooooo`00BOooo`03o`2Ioooooooo04?oool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00BOooo`03o`2Ioooooooo04?oool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00BOooo`03o`2Ioooooooo04?oool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00BOooo`03o`2Ioooooooo04?oool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00BOooo`03o`2Ioooooooo04?oool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00BOooo`03o`2Ioooooooo04?oool2000033?o00030000oooooooo083oool004Woool00ol0VOoo
ooooo`13oooo00<0000co`0co`002c?o00030000oooooooo083oool004Woool00ol0VOooooooo`13
oooo00<0000co`0co`002S?o00030000oooooooo087oool004Woool00ol0VOooooooo`13oooo00<0
000co`0co`002S?o00030000oooooooo087oool004Woool00ol0VOooooooo`13oooo00<0000co`0c
o`002S?o00030000oooooooo087oool004Woool00ol0VOooooooo`13oooo00<0000co`0co`002S?o
00030000oooooooo087oool004Woool00ol0VOooooooo`13oooo0P0000/co`000`000?ooooooo`21
oooo0019oooo00?o09Woooooool0@oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0019
oooo00?o09Woooooool0@oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0019oooo00?o
09Woooooool0@oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo0019oooo00?o09Wooooo
ool0@oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo0019oooo00?o09Woooooool0@ooo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo0019oooo00?o09Woooooool0@oooo`80000:
<ol000<0003oooooool0P_ooo`00BOooo`03o`2Ioooooooo04?oool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00BOooo`03o`2Ioooooooo04?oool00`0003?o03?o0009<ol000<0003ooooo
ool0P_ooo`00BOooo`03o`2Ioooooooo04?oool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00BOooo`03o`2Ioooooooo03coool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo0019oooo00?o09Woooooool0>oooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo0019oooo00?o09Woooooool0?Oooo`030000oooooooo00?oool3000023?o
00030000oooooooo08?oool004Woool00ol0VOooooooo`0noooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo0019oooo00?o09Woooooool0>oooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo0019oooo00?o09Woooooool0??oo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool004Woool00ol0VOooooooo`13
oooo00<0000co`0co`001c?o00030000oooooooo08Coool004Woool00ol0VOooooooo`13oooo00<0
000co`0co`001c?o00030000oooooooo08Coool004Woool00ol0VOooooooo`13oooo00<0000co`0c
o`001c?o00030000oooooooo08Coool004Woool00ol0VOooooooo`13oooo0P0000Pco`000`000?oo
ooooo`24oooo0019oooo00?o09Woooooool0@oooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo0019oooo00?o09Woooooool0@oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0019
oooo00?o09Woooooool0@oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0019oooo00?o
09Woooooool0@oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo0019oooo00?o09Wooooo
ool0@oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo0019oooo00?o09Woooooool0@ooo
o`800007<ol000<0003oooooool0QOooo`00BOooo`03o`2Ioooooooo04?oool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00BOooo`03o`2Ioooooooo04?oool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00BOooo`03o`2Ioooooooo04?oool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00BOooo`03o`2Ioooooooo04?oool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00BOooo`03o`2Ioooooooo04?oool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00BOoo
o`03o`2Ioooooooo04?oool200001S?o00030000oooooooo08Koool004Woool00ol0VOooooooo`13
oooo00<0000co`0co`001C?o00030000oooooooo08Koool004Woool00ol0VOooooooo`13oooo00<0
000co`0co`001C?o00030000oooooooo08Koool004Woool00ol0VOooooooo`13oooo00<0000co`0c
o`001C?o00030000oooooooo08Koool004Woool00ol0VOooooooo`13oooo00<0000co`0co`001C?o
00030000oooooooo08Koool004Woool00ol0VOooooooo`13oooo00<0000co`0co`001C?o00030000
oooooooo08Koool004Woool00ol0VOooooooo`13oooo0P0000Hco`000`000?ooooooo`26oooo0019
oooo00?o09Woooooool0@oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0019oooo00?o
09Woooooool0@oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0019oooo00?o09Wooooo
ool0@oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo0019oooo00?o09Woooooool0@ooo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo0019oooo00?o09Woooooool0?Oooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool004Woool00ol0VOooooooo`0noooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo0019oooo00?o09Wooooo
ool0>oooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00M_ooo`030000oooooooo01Koool7<ol04Ooo
o`030000oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool03?ooo`Lco`0B
oooo00<0003oooooool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00coool00c?o000000000004<ol00P0000?oool5000000Coool0000000000004oooo00<0003ooooo
ool0MOooo`00MOooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01?ooo`@00003oooo00@0000co`0co`000003<ol01oooo`050000oooooooooooo000000;oool0
1@000?ooooooooooo`00001goooo001doooo00<0003oooooool00_ooo`030000oooooooo01?oool0
100003?o03?o000000<co`07oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001;oool0100003?o03?o000000<co`07
oooo00@0003oooooooooool300001?ooo`030000oooooooo07Goool007Goool01@000?oooooooooo
o`00000Eoooo00@0000co`0co`000003<ol01oooo`030000oooooooo00;oool00`000?ooooooo`03
oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Koool00c?o000000000004<ol01_oo
o`800004oooo0`0000;oool00`000?ooooooo`1foooo002?oooo1c?o08[oool008ooool7<ol0R_oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.21345 .12361 L
.22272 .12361 L
.22513 .12361 L
.22738 .12361 L
.22852 .12361 L
s
.22852 .12361 m
.229 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool010000?ooooooool0V@Soool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0
003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0aoooo00?o09Wooooo
ool01_ooo`030000oooooooo03Woool00`0003?o03?o000i<ol02@0003Coool00`000?ooooooo`0E
oooo001:oooo00?o09Woooooool0@_ooo`030000<ol0<ol003<co`060000EOooo`00B_ooo`03o`2I
oooooooo04;oool00`0003?o03?o000a<ol00P0005_oool004[oool00ol0VOooooooo`12oooo00<0
000co`0co`00;c?o0080001Moooo001:oooo00?o09Woooooool0@_ooo`030000<ol0<ol002`co`03
0000Goooo`00B_ooo`03o`2Ioooooooo04;oool20000:S?o00<0001Roooo001:oooo00?o09Wooooo
ool0@_ooo`030000<ol0<ol002Lco`020000IOooo`00B_ooo`03o`2Ioooooooo04;oool00`0003?o
03?o000V<ol000<0003oooooool0IOooo`00B_ooo`03o`2Ioooooooo04;oool00`0003?o03?o000U
<ol000<0003oooooool0I_ooo`00B_ooo`03o`2Ioooooooo04;oool00`0003?o03?o000T<ol000<0
003oooooool0Ioooo`00B_ooo`03o`2Ioooooooo04;oool00`0003?o03?o000R<ol00P0006[oool0
04[oool00ol0VOooooooo`12oooo0P00028co`000`000?ooooooo`1Zoooo001:oooo00?o09Wooooo
ool0@_ooo`030000<ol0<ol0020co`000`000?ooooooo`1[oooo001:oooo00?o09Woooooool0@_oo
o`030000<ol0<ol001lco`000`000?ooooooo`1/oooo001:oooo00?o09Woooooool0@_ooo`030000
<ol0<ol001lco`000`000?ooooooo`1/oooo001:oooo00?o09Woooooool0@_ooo`030000<ol0<ol0
01hco`000`000?ooooooo`1]oooo001:oooo00?o09Woooooool0@_ooo`030000<ol0<ol001dco`00
0`000?ooooooo`1^oooo001:oooo00?o09Woooooool0@_ooo`80000M<ol000<0003oooooool0Kooo
o`00B_ooo`03o`2Ioooooooo04;oool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00B_oo
o`03o`2Ioooooooo04;oool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00B_ooo`03o`2I
oooooooo04;oool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00B_ooo`03o`2Ioooooooo
04;oool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00B_ooo`03o`2Ioooooooo04;oool0
0`0003?o03?o000I<ol000<0003oooooool0L_ooo`00B_ooo`03o`2Ioooooooo04;oool200006S?o
00030000oooooooo07;oool004[oool00ol0VOooooooo`12oooo00<0000co`0co`0063?o00030000
oooooooo07?oool004[oool00ol0VOooooooo`12oooo00<0000co`0co`0063?o00030000oooooooo
07?oool004[oool00ol0VOooooooo`12oooo00<0000co`0co`005c?o00030000oooooooo07Coool0
04[oool00ol0VOooooooo`12oooo00<0000co`0co`005c?o00030000oooooooo07Coool004[oool0
0ol0VOooooooo`0joooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00B_oo
o`03o`2Ioooooooo03coool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo
07Goool004[oool00ol0VOooooooo`0loooo00<0003oooooool00oooo`<0000E<ol000<0003ooooo
ool0M_ooo`00B_ooo`03o`2Ioooooooo03coool00`000?ooooooo`03oooo00<0000co`0co`005C?o
00030000oooooooo07Koool004[oool00ol0VOooooooo`0loooo00<0003oooooool00oooo`030000
<ol0<ol001Dco`000`000?ooooooo`1foooo001:oooo00?o09Woooooool0>oooo`800005oooo00<0
000co`0co`0053?o00030000oooooooo07Ooool004[oool00ol0VOooooooo`12oooo00<0000co`0c
o`0053?o00030000oooooooo07Ooool004[oool00ol0VOooooooo`12oooo00<0000co`0co`004c?o
00030000oooooooo07Soool004[oool00ol0VOooooooo`12oooo0P0001@co`000`000?ooooooo`1h
oooo001:oooo00?o09Woooooool0@_ooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo001:
oooo00?o09Woooooool0@_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001:oooo00?o
09Woooooool0@_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001:oooo00?o09Wooooo
ool0@_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001:oooo00?o09Woooooool0@_oo
o`030000<ol0<ol0014co`000`000?ooooooo`1joooo001:oooo00?o09Woooooool0@_ooo`80000B
<ol000<0003oooooool0N_ooo`00B_ooo`03o`2Ioooooooo04;oool00`0003?o03?o000A<ol000<0
003oooooool0N_ooo`00B_ooo`03o`2Ioooooooo04;oool00`0003?o03?o000A<ol000<0003ooooo
ool0N_ooo`00B_ooo`03o`2Ioooooooo04;oool00`0003?o03?o000@<ol000<0003oooooool0Nooo
o`00B_ooo`03o`2Ioooooooo04;oool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00B_oo
o`03o`2Ioooooooo04;oool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00B_ooo`03o`2I
oooooooo04;oool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00B_ooo`03o`2Ioooooooo
04;oool2000043?o00030000oooooooo07coool004[oool00ol0VOooooooo`12oooo00<0000co`0c
o`003c?o00030000oooooooo07coool004[oool00ol0VOooooooo`12oooo00<0000co`0co`003c?o
00030000oooooooo07coool004[oool00ol0VOooooooo`12oooo00<0000co`0co`003c?o00030000
oooooooo07coool004[oool00ol0VOooooooo`12oooo00<0000co`0co`003c?o00030000oooooooo
07coool004[oool00ol0VOooooooo`12oooo00<0000co`0co`003S?o00030000oooooooo07goool0
04[oool00ol0VOooooooo`12oooo0P0000lco`000`000?ooooooo`1moooo001:oooo00?o09Wooooo
ool0@_ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001:oooo00?o09Woooooool0@_oo
o`030000<ol0<ol000hco`000`000?ooooooo`1moooo001:oooo00?o09Woooooool0@_ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001:oooo00?o09Woooooool0>_ooo`@00004oooo00<0
000co`0co`003C?o00030000oooooooo07koool004[oool00ol0VOooooooo`0joooo00<0003ooooo
ool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo001:oooo00?o09Woooooool0>ooo
o`030000oooooooo00Coool300003C?o00030000oooooooo07koool004[oool00ol0VOooooooo`0l
oooo00<0003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo001:oooo00?o
09Woooooool0>_ooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001:oooo00?o09Woooooool0>oooo`800005oooo00<0000co`0co`0033?o00030000oooooooo
07ooool004[oool00ol0VOooooooo`12oooo00<0000co`0co`0033?o00030000oooooooo07ooool0
04[oool00ol0VOooooooo`12oooo00<0000co`0co`0033?o00030000oooooooo07ooool004[oool0
0ol0VOooooooo`12oooo0P0000dco`000`000?ooooooo`1ooooo001:oooo00?o09Woooooool0@_oo
o`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001:oooo00?o09Woooooool0@_ooo`030000
<ol0<ol000/co`000`000?ooooooo`20oooo001:oooo00?o09Woooooool0@_ooo`030000<ol0<ol0
00/co`000`000?ooooooo`20oooo001:oooo00?o09Woooooool0@_ooo`030000<ol0<ol000/co`00
0`000?ooooooo`20oooo001:oooo00?o09Woooooool0@_ooo`030000<ol0<ol000/co`000`000?oo
ooooo`20oooo001:oooo00?o09Woooooool0@_ooo`030000<ol0<ol000/co`000`000?ooooooo`20
oooo001:oooo00?o09Woooooool0@_ooo`80000<<ol000<0003oooooool0P?ooo`00B_ooo`03o`2I
oooooooo04;oool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00B_ooo`03o`2Ioooooooo
04;oool00`0003?o03?o000:<ol000<0003oooooool0POooo`00B_ooo`03o`2Ioooooooo04;oool0
0`0003?o03?o000:<ol000<0003oooooool0POooo`00B_ooo`03o`2Ioooooooo04;oool00`0003?o
03?o000:<ol000<0003oooooool0POooo`00B_ooo`03o`2Ioooooooo04;oool00`0003?o03?o000:
<ol000<0003oooooool0POooo`00B_ooo`03o`2Ioooooooo04;oool200002c?o00030000oooooooo
087oool004[oool00ol0VOooooooo`12oooo00<0000co`0co`002S?o00030000oooooooo087oool0
04[oool00ol0VOooooooo`12oooo00<0000co`0co`002S?o00030000oooooooo087oool004[oool0
0ol0VOooooooo`12oooo00<0000co`0co`002C?o00030000oooooooo08;oool004[oool00ol0VOoo
ooooo`12oooo00<0000co`0co`002C?o00030000oooooooo08;oool004[oool00ol0VOooooooo`12
oooo00<0000co`0co`002C?o00030000oooooooo08;oool004[oool00ol0VOooooooo`12oooo0P00
00Xco`000`000?ooooooo`22oooo001:oooo00?o09Woooooool0@_ooo`030000<ol0<ol000Tco`00
0`000?ooooooo`22oooo001:oooo00?o09Woooooool0@_ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`22oooo001:oooo00?o09Woooooool0@_ooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001:oooo00?o09Woooooool0>oooo`800005oooo00<0000co`0co`0023?o00030000oooooooo
08?oool004[oool00ol0VOooooooo`0joooo00@0003oooooool00004oooo00<0000co`0co`0023?o
00030000oooooooo08?oool004[oool00ol0VOooooooo`0loooo00<0003oooooool00oooo`<00008
<ol000<0003oooooool0Poooo`00B_ooo`03o`2Ioooooooo03goool00`000?ooooooo`02oooo00<0
000co`0co`0023?o00030000oooooooo08?oool004[oool00ol0VOooooooo`0joooo00@0003ooooo
ool00004oooo00<0000co`0co`0023?o00030000oooooooo08?oool004[oool00ol0VOooooooo`0k
oooo0P0000Goool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00B_ooo`03o`2Ioooooooo
04;oool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00B_ooo`03o`2Ioooooooo04;oool0
0`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00B_ooo`03o`2Ioooooooo04;oool00`0003?o
03?o0007<ol000<0003oooooool0Q?ooo`00B_ooo`03o`2Ioooooooo04;oool2000023?o00030000
oooooooo08Coool004[oool00ol0VOooooooo`12oooo00<0000co`0co`001c?o00030000oooooooo
08Coool004[oool00ol0VOooooooo`12oooo00<0000co`0co`001c?o00030000oooooooo08Coool0
04[oool00ol0VOooooooo`12oooo00<0000co`0co`001c?o00030000oooooooo08Coool004[oool0
0ol0VOooooooo`12oooo00<0000co`0co`001S?o00030000oooooooo08Goool004[oool00ol0VOoo
ooooo`12oooo00<0000co`0co`001S?o00030000oooooooo08Goool004[oool00ol0VOooooooo`12
oooo0P0000Lco`000`000?ooooooo`25oooo001:oooo00?o09Woooooool0@_ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`25oooo001:oooo00?o09Woooooool0@_ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`25oooo001:oooo00?o09Woooooool0@_ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`25oooo001:oooo00?o09Woooooool0@_ooo`030000<ol0<ol000Hco`000`000?ooooooo`25
oooo001:oooo00?o09Woooooool0@_ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001:
oooo00?o09Woooooool0@_ooo`800006<ol000<0003oooooool0Q_ooo`00B_ooo`03o`2Ioooooooo
04;oool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00B_ooo`03o`2Ioooooooo04;oool0
0`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00B_ooo`03o`2Ioooooooo04;oool00`0003?o
03?o0005<ol000<0003oooooool0Q_ooo`00B_ooo`03o`2Ioooooooo04;oool00`0003?o03?o0005
<ol000<0003oooooool0Q_ooo`00B_ooo`03o`2Ioooooooo04;oool00`0003?o03?o0005<ol000<0
003oooooool0Q_ooo`00B_ooo`03o`2Ioooooooo04;oool200001S?o00030000oooooooo08Koool0
04[oool00ol0VOooooooo`12oooo00<0000co`0co`001C?o00030000oooooooo08Koool004[oool0
0ol0VOooooooo`12oooo00<0000co`0co`001C?o00030000oooooooo08Koool004[oool00ol0VOoo
ooooo`12oooo00<0000co`0co`0013?o00030000oooooooo08Ooool004[oool00ol0VOooooooo`12
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool004[oool00ol0VOooooooo`0loooo0`00
00?oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00B_ooo`03o`2Ioooooooo03goool0
0`000?ooooooo`02oooo00<0000co`0co`0013?o00030000oooooooo08Ooool004[oool00ol0VOoo
ooooo`0joooo1@0000?oool3000013?o00030000oooooooo08Ooool008Ooool010000?ooooooo`00
00Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o
08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001foooo00<0003oooooool05_ooo`Lco`0A
oooo00<0003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0<oooo1c?o
01;oool00`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool03?ooo`03<ol00000000000@co`0200000oooo`D00003oooo0`0000;oool00`000?ooooooo`1e
oooo001eoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04
oooo100000?oool0100003?o03?o000000<co`07oooo00<0003oooooool01?ooo`050000oooooooo
oooo000007Ooool007Coool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000<ol0<ol0
00000c?o00Ooool010000?ooooooooooo`D00003oooo00<0003oooooool0M?ooo`00MOooo`030000
oooooooo00D0000Boooo00@0000co`0co`000003<ol01oooo`050000oooooooooooo000000;oool0
1@000?ooooooooooo`00001goooo001eoooo00D0003oooooooooool000005Oooo`040000<ol0<ol0
00000c?o00Ooool00`000?ooooooo`02oooo00<0003oool000000oooo`030000oooooooo07Goool0
07Koool00`000?ooooooo`0Foooo00<co`000000000013?o00Koool200001Oooo`800002oooo00<0
003oooooool0M_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.22738 .12361 L
.22994 .12361 L
.23119 .12361 L
.23233 .12361 L
s
.23233 .12361 m
.23283 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool01@000?ooooooooooool0V@07oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_oo
o`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0<_ooo`03o`2I
oooooooo00Goool00`000?ooooooo`0ioooo00<0000co`0co`00>C?o00T0000doooo00<0003ooooo
ool05Oooo`00Boooo`03o`2Ioooooooo047oool00`0003?o03?o000c<ol01P0005Goool004_oool0
0ol0VOooooooo`11oooo00<0000co`0co`00<C?o0080001Koooo001;oooo00?o09Woooooool0@Ooo
o`030000<ol0<ol002lco`020000GOooo`00Boooo`03o`2Ioooooooo047oool00`0003?o03?o000/
<ol00`0005ooool004_oool00ol0VOooooooo`11oooo0P0002Xco`030000H_ooo`00Boooo`03o`2I
oooooooo047oool00`0003?o03?o000W<ol00P0006Goool004_oool00ol0VOooooooo`11oooo00<0
000co`0co`009S?o00030000oooooooo06Goool004_oool00ol0VOooooooo`11oooo00<0000co`0c
o`009C?o00030000oooooooo06Koool004_oool00ol0VOooooooo`11oooo00<0000co`0co`0093?o
00030000oooooooo06Ooool004_oool00ol0VOooooooo`11oooo00<0000co`0co`008S?o0080001Z
oooo001;oooo00?o09Woooooool0@Oooo`80000R<ol000<0003oooooool0J_ooo`00Boooo`03o`2I
oooooooo047oool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00Boooo`03o`2Ioooooooo
047oool00`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Boooo`03o`2Ioooooooo047oool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Boooo`03o`2Ioooooooo047oool00`0003?o
03?o000N<ol000<0003oooooool0KOooo`00Boooo`03o`2Ioooooooo047oool00`0003?o03?o000M
<ol000<0003oooooool0K_ooo`00Boooo`03o`2Ioooooooo047oool200007C?o00030000oooooooo
06ooool004_oool00ol0VOooooooo`11oooo00<0000co`0co`006c?o00030000oooooooo073oool0
04_oool00ol0VOooooooo`11oooo00<0000co`0co`006c?o00030000oooooooo073oool004_oool0
0ol0VOooooooo`11oooo00<0000co`0co`006S?o00030000oooooooo077oool004_oool00ol0VOoo
ooooo`11oooo00<0000co`0co`006S?o00030000oooooooo077oool004_oool00ol0VOooooooo`11
oooo00<0000co`0co`006C?o00030000oooooooo07;oool004_oool00ol0VOooooooo`11oooo0P00
01Xco`000`000?ooooooo`1boooo001;oooo00?o09Woooooool0@Oooo`030000<ol0<ol001Pco`00
0`000?ooooooo`1coooo001;oooo00?o09Woooooool0@Oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001;oooo00?o09Woooooool0@Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1d
oooo001;oooo00?o09Woooooool0@Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001;
oooo00?o09Woooooool0>Oooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool0
04_oool00ol0VOooooooo`0koooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001;oooo00?o09Woooooool0>oooo`030000oooooooo00?oool300005C?o00030000
oooooooo07Koool004_oool00ol0VOooooooo`0koooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`1foooo001;oooo00?o09Woooooool0>oooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00Boooo`03o`2Ioooooooo03[oool200001Ooo
o`030000<ol0<ol001@co`000`000?ooooooo`1goooo001;oooo00?o09Woooooool0@Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001;oooo00?o09Woooooool0@Oooo`030000<ol0<ol0
01<co`000`000?ooooooo`1hoooo001;oooo00?o09Woooooool0@Oooo`80000D<ol000<0003ooooo
ool0N?ooo`00Boooo`03o`2Ioooooooo047oool00`0003?o03?o000C<ol000<0003oooooool0N?oo
o`00Boooo`03o`2Ioooooooo047oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Booo
o`03o`2Ioooooooo047oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Boooo`03o`2I
oooooooo047oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Boooo`03o`2Ioooooooo
047oool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00Boooo`03o`2Ioooooooo047oool2
00004S?o00030000oooooooo07[oool004_oool00ol0VOooooooo`11oooo00<0000co`0co`004C?o
00030000oooooooo07[oool004_oool00ol0VOooooooo`11oooo00<0000co`0co`004C?o00030000
oooooooo07[oool004_oool00ol0VOooooooo`11oooo00<0000co`0co`0043?o00030000oooooooo
07_oool004_oool00ol0VOooooooo`11oooo00<0000co`0co`0043?o00030000oooooooo07_oool0
04_oool00ol0VOooooooo`11oooo00<0000co`0co`0043?o00030000oooooooo07_oool004_oool0
0ol0VOooooooo`11oooo00<0000co`0co`0043?o00030000oooooooo07_oool004_oool00ol0VOoo
ooooo`11oooo0P00010co`000`000?ooooooo`1loooo001;oooo00?o09Woooooool0@Oooo`030000
<ol0<ol000lco`000`000?ooooooo`1loooo001;oooo00?o09Woooooool0@Oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001;oooo00?o09Woooooool0@Oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001;oooo00?o09Woooooool0@Oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001;oooo00?o09Woooooool0@Oooo`030000<ol0<ol000hco`000`000?ooooooo`1m
oooo001;oooo00?o09Woooooool0@Oooo`80000?<ol000<0003oooooool0OOooo`00Boooo`03o`2I
oooooooo047oool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Boooo`03o`2Ioooooooo
047oool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Boooo`03o`2Ioooooooo047oool0
0`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Boooo`03o`2Ioooooooo03Woool400001?oo
o`030000<ol0<ol000dco`000`000?ooooooo`1noooo001;oooo00?o09Woooooool0>Oooo`030000
oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Boooo`03o`2Ioooooooo
03[oool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001;oooo00?o09Wooooo
ool0>oooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Booo
o`03o`2Ioooooooo03Woool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00Boooo`03o`2Ioooooooo03[oool200001Oooo`030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001;oooo00?o09Woooooool0@Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001;oooo00?o09Woooooool0@Oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001;
oooo00?o09Woooooool0@Oooo`80000=<ol000<0003oooooool0Ooooo`00Boooo`03o`2Ioooooooo
047oool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00Boooo`03o`2Ioooooooo047oool0
0`0003?o03?o000;<ol000<0003oooooool0P?ooo`00Boooo`03o`2Ioooooooo047oool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00Boooo`03o`2Ioooooooo047oool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00Boooo`03o`2Ioooooooo047oool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00Boooo`03o`2Ioooooooo047oool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Boooo`03o`2Ioooooooo047oool2000033?o00030000oooooooo083oool004_oool0
0ol0VOooooooo`11oooo00<0000co`0co`002c?o00030000oooooooo083oool004_oool00ol0VOoo
ooooo`11oooo00<0000co`0co`002S?o00030000oooooooo087oool004_oool00ol0VOooooooo`11
oooo00<0000co`0co`002S?o00030000oooooooo087oool004_oool00ol0VOooooooo`11oooo00<0
000co`0co`002S?o00030000oooooooo087oool004_oool00ol0VOooooooo`11oooo00<0000co`0c
o`002S?o00030000oooooooo087oool004_oool00ol0VOooooooo`11oooo0P0000/co`000`000?oo
ooooo`21oooo001;oooo00?o09Woooooool0@Oooo`030000<ol0<ol000Xco`000`000?ooooooo`21
oooo001;oooo00?o09Woooooool0@Oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001;
oooo00?o09Woooooool0@Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001;oooo00?o
09Woooooool0@Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001;oooo00?o09Wooooo
ool0@Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001;oooo00?o09Woooooool0@Ooo
o`80000:<ol000<0003oooooool0P_ooo`00Boooo`03o`2Ioooooooo047oool00`0003?o03?o0009
<ol000<0003oooooool0P_ooo`00Boooo`03o`2Ioooooooo047oool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00Boooo`03o`2Ioooooooo047oool00`0003?o03?o0008<ol000<0003ooooo
ool0Poooo`00Boooo`03o`2Ioooooooo03[oool200001Oooo`030000<ol0<ol000Pco`000`000?oo
ooooo`23oooo001;oooo00?o09Woooooool0>Oooo`040000oooooooo00001?ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`23oooo001;oooo00?o09Woooooool0>oooo`030000oooooooo00?oool3
000023?o00030000oooooooo08?oool004_oool00ol0VOooooooo`0loooo00<0003oooooool00_oo
o`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001;oooo00?o09Woooooool0>Oooo`040000
oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001;oooo00?o09Wooooo
ool0>_ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool004_oool00ol0VOoo
ooooo`11oooo00<0000co`0co`001c?o00030000oooooooo08Coool004_oool00ol0VOooooooo`11
oooo00<0000co`0co`001c?o00030000oooooooo08Coool004_oool00ol0VOooooooo`11oooo00<0
000co`0co`001c?o00030000oooooooo08Coool004_oool00ol0VOooooooo`11oooo0P0000Pco`00
0`000?ooooooo`24oooo001;oooo00?o09Woooooool0@Oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`24oooo001;oooo00?o09Woooooool0@Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001;oooo00?o09Woooooool0@Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001;
oooo00?o09Woooooool0@Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001;oooo00?o
09Woooooool0@Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001;oooo00?o09Wooooo
ool0@Oooo`800007<ol000<0003oooooool0QOooo`00Boooo`03o`2Ioooooooo047oool00`0003?o
03?o0006<ol000<0003oooooool0QOooo`00Boooo`03o`2Ioooooooo047oool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00Boooo`03o`2Ioooooooo047oool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00Boooo`03o`2Ioooooooo047oool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00Boooo`03o`2Ioooooooo047oool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00Boooo`03o`2Ioooooooo047oool200001S?o00030000oooooooo08Koool004_oool00ol0VOoo
ooooo`11oooo00<0000co`0co`001C?o00030000oooooooo08Koool004_oool00ol0VOooooooo`11
oooo00<0000co`0co`001C?o00030000oooooooo08Koool004_oool00ol0VOooooooo`11oooo00<0
000co`0co`001C?o00030000oooooooo08Koool004_oool00ol0VOooooooo`11oooo00<0000co`0c
o`001C?o00030000oooooooo08Koool004_oool00ol0VOooooooo`11oooo00<0000co`0co`001C?o
00030000oooooooo08Koool004_oool00ol0VOooooooo`11oooo0P0000Hco`000`000?ooooooo`26
oooo001;oooo00?o09Woooooool0@Oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001;
oooo00?o09Woooooool0@Oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001;oooo00?o
09Woooooool0@Oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001;oooo00?o09Wooooo
ool0@Oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001;oooo00?o09Woooooool0>ooo
o`<00003oooo00<0000co`0co`0013?o00030000oooooooo08Ooool004_oool00ol0VOooooooo`0l
oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001;oooo00?o
09Woooooool0>Oooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003ooooo
ool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?oo
o`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00M_ooo`030000oooooooo01Koool7
<ol04Oooo`030000oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool03?oo
o`Lco`0Boooo00<0003oooooool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00coool00c?o000000000004<ol00P0000?oool5000000?oool0000000000P0000?oool0
0`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`04oooo100000?oool0100003?o03?o000000<co`07oooo00D0003oooooooooool0
00001_ooo`030000oooooooo07Goool007Coool00`000?ooooooo`02oooo00<0003oooooool04ooo
o`040000<ol0<ol000000c?o00Ooool00`000?ooooooo`02oooo00<0003oooooool01?ooo`030000
oooooooo07Coool007Goool00`000?ooooooo`0500004_ooo`040000<ol0<ol000000c?o00Ooool0
0`000?ooooooo`03oooo00<0003oooooool00_ooo`030000oooooooo07Goool007Goool01@000?oo
ooooooooo`00000Eoooo00@0000co`0co`000003<ol01oooo`050000oooooooooooo000000;oool0
1@000?ooooooooooo`00001goooo001foooo00<0003oooooool05_ooo`03<ol00000000000@co`06
oooo0P0000Coool200000oooo`030000oooooooo07Koool008ooool7<ol0R_ooo`00Soooo`Lco`2:
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.23496 .12361 L
.2364 .12361 L
.23711 .12361 L
.23775 .12361 L
s
.23775 .12361 m
.23821 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`02oooo00?o09Wooooo
ool01?ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03?oool00ol0VOooooooo`04oooo00<0003oooooool0>Oooo`030000<ol0<ol003Tco`090000=?oo
o`030000oooooooo01Goool004coool00ol0VOooooooo`10oooo00<0000co`0co`00<c?o00H0001E
oooo001<oooo00?o09Woooooool0@?ooo`030000<ol0<ol0034co`020000Foooo`00C?ooo`03o`2I
oooooooo043oool00`0003?o03?o000_<ol00P0005goool004coool00ol0VOooooooo`10oooo00<0
000co`0co`00;3?o00<0001Ooooo001<oooo00?o09Woooooool0@?ooo`80000Z<ol00`0006;oool0
04coool00ol0VOooooooo`10oooo00<0000co`0co`009c?o0080001Uoooo001<oooo00?o09Wooooo
ool0@?ooo`030000<ol0<ol002Hco`000`000?ooooooo`1Uoooo001<oooo00?o09Woooooool0@?oo
o`030000<ol0<ol002Dco`000`000?ooooooo`1Voooo001<oooo00?o09Woooooool0@?ooo`030000
<ol0<ol002@co`000`000?ooooooo`1Woooo001<oooo00?o09Woooooool0@?ooo`030000<ol0<ol0
028co`020000J_ooo`00C?ooo`03o`2Ioooooooo043oool200008S?o00030000oooooooo06[oool0
04coool00ol0VOooooooo`10oooo00<0000co`0co`0083?o00030000oooooooo06_oool004coool0
0ol0VOooooooo`10oooo00<0000co`0co`007c?o00030000oooooooo06coool004coool00ol0VOoo
ooooo`10oooo00<0000co`0co`007c?o00030000oooooooo06coool004coool00ol0VOooooooo`10
oooo00<0000co`0co`007S?o00030000oooooooo06goool004coool00ol0VOooooooo`10oooo00<0
000co`0co`007C?o00030000oooooooo06koool004coool00ol0VOooooooo`10oooo0P0001dco`00
0`000?ooooooo`1_oooo001<oooo00?o09Woooooool0@?ooo`030000<ol0<ol001/co`000`000?oo
ooooo`1`oooo001<oooo00?o09Woooooool0@?ooo`030000<ol0<ol001/co`000`000?ooooooo`1`
oooo001<oooo00?o09Woooooool0@?ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001<
oooo00?o09Woooooool0@?ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001<oooo00?o
09Woooooool0@?ooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo001<oooo00?o09Wooooo
ool0@?ooo`80000J<ol000<0003oooooool0L_ooo`00C?ooo`03o`2Ioooooooo043oool00`0003?o
03?o000H<ol000<0003oooooool0Loooo`00C?ooo`03o`2Ioooooooo043oool00`0003?o03?o000H
<ol000<0003oooooool0Loooo`00C?ooo`03o`2Ioooooooo043oool00`0003?o03?o000G<ol000<0
003oooooool0M?ooo`00C?ooo`03o`2Ioooooooo043oool00`0003?o03?o000G<ol000<0003ooooo
ool0M?ooo`00C?ooo`03o`2Ioooooooo03Soool500000oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001<oooo00?o09Woooooool0>_ooo`030000oooooooo00?oool00`0003?o03?o000F
<ol000<0003oooooool0MOooo`00C?ooo`03o`2Ioooooooo03[oool00`000?ooooooo`03oooo0`00
01Dco`000`000?ooooooo`1foooo001<oooo00?o09Woooooool0>_ooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00C?ooo`03o`2Ioooooooo03[oool00`000?oo
ooooo`03oooo00<0000co`0co`005C?o00030000oooooooo07Koool004coool00ol0VOooooooo`0i
oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00C?ooo`03o`2Ioooooooo
043oool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00C?ooo`03o`2Ioooooooo043oool0
0`0003?o03?o000C<ol000<0003oooooool0N?ooo`00C?ooo`03o`2Ioooooooo043oool2000053?o
00030000oooooooo07Soool004coool00ol0VOooooooo`10oooo00<0000co`0co`004c?o00030000
oooooooo07Soool004coool00ol0VOooooooo`10oooo00<0000co`0co`004S?o00030000oooooooo
07Woool004coool00ol0VOooooooo`10oooo00<0000co`0co`004S?o00030000oooooooo07Woool0
04coool00ol0VOooooooo`10oooo00<0000co`0co`004S?o00030000oooooooo07Woool004coool0
0ol0VOooooooo`10oooo00<0000co`0co`004C?o00030000oooooooo07[oool004coool00ol0VOoo
ooooo`10oooo0P00018co`000`000?ooooooo`1joooo001<oooo00?o09Woooooool0@?ooo`030000
<ol0<ol0014co`000`000?ooooooo`1joooo001<oooo00?o09Woooooool0@?ooo`030000<ol0<ol0
014co`000`000?ooooooo`1joooo001<oooo00?o09Woooooool0@?ooo`030000<ol0<ol0010co`00
0`000?ooooooo`1koooo001<oooo00?o09Woooooool0@?ooo`030000<ol0<ol0010co`000`000?oo
ooooo`1koooo001<oooo00?o09Woooooool0@?ooo`030000<ol0<ol0010co`000`000?ooooooo`1k
oooo001<oooo00?o09Woooooool0@?ooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo001<
oooo00?o09Woooooool0@?ooo`80000@<ol000<0003oooooool0O?ooo`00C?ooo`03o`2Ioooooooo
043oool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00C?ooo`03o`2Ioooooooo043oool0
0`0003?o03?o000?<ol000<0003oooooool0O?ooo`00C?ooo`03o`2Ioooooooo043oool00`0003?o
03?o000?<ol000<0003oooooool0O?ooo`00C?ooo`03o`2Ioooooooo043oool00`0003?o03?o000?
<ol000<0003oooooool0O?ooo`00C?ooo`03o`2Ioooooooo043oool00`0003?o03?o000><ol000<0
003oooooool0OOooo`00C?ooo`03o`2Ioooooooo043oool200003c?o00030000oooooooo07goool0
04coool00ol0VOooooooo`10oooo00<0000co`0co`003S?o00030000oooooooo07goool004coool0
0ol0VOooooooo`10oooo00<0000co`0co`003S?o00030000oooooooo07goool004coool00ol0VOoo
ooooo`10oooo00<0000co`0co`003C?o00030000oooooooo07koool004coool00ol0VOooooooo`0h
oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00C?ooo`03o`2Ioooooooo
03Soool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo07koool004coool0
0ol0VOooooooo`0ioooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0O_ooo`00COoo
o`03o`2Ioooooooo03Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo
07koool004goool00ol0VOooooooo`0goooo00@0003oooooool00004oooo00<0000co`0co`0033?o
00030000oooooooo07ooool004goool00ol0VOooooooo`0hoooo0P0000Goool00`0003?o03?o000<
<ol000<0003oooooool0Ooooo`00COooo`03o`2Ioooooooo03ooool00`0003?o03?o000<<ol000<0
003oooooool0Ooooo`00COooo`03o`2Ioooooooo03ooool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00COooo`03o`2Ioooooooo03ooool200003C?o00030000oooooooo07ooool004goool0
0ol0VOooooooo`0ooooo00<0000co`0co`0033?o00030000oooooooo07ooool004goool00ol0VOoo
ooooo`0ooooo00<0000co`0co`002c?o00030000oooooooo083oool004goool00ol0VOooooooo`0o
oooo00<0000co`0co`002c?o00030000oooooooo083oool004goool00ol0VOooooooo`0ooooo00<0
000co`0co`002c?o00030000oooooooo083oool004goool00ol0VOooooooo`0ooooo00<0000co`0c
o`002c?o00030000oooooooo083oool004goool00ol0VOooooooo`0ooooo00<0000co`0co`002c?o
00030000oooooooo083oool004goool00ol0VOooooooo`0ooooo0P0000`co`000`000?ooooooo`20
oooo001=oooo00?o09Woooooool0?oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001=
oooo00?o09Woooooool0?oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001=oooo00?o
09Woooooool0?oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001=oooo00?o09Wooooo
ool0?oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001=oooo00?o09Woooooool0?ooo
o`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001=oooo00?o09Woooooool0?oooo`80000;
<ol000<0003oooooool0POooo`00COooo`03o`2Ioooooooo03ooool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00COooo`03o`2Ioooooooo03ooool00`0003?o03?o000:<ol000<0003ooooo
ool0POooo`00COooo`03o`2Ioooooooo03ooool00`0003?o03?o0009<ol000<0003oooooool0P_oo
o`00COooo`03o`2Ioooooooo03ooool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00COoo
o`03o`2Ioooooooo03ooool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00COooo`03o`2I
oooooooo03ooool200002S?o00030000oooooooo08;oool004goool00ol0VOooooooo`0ooooo00<0
000co`0co`002C?o00030000oooooooo08;oool004goool00ol0VOooooooo`0ooooo00<0000co`0c
o`002C?o00030000oooooooo08;oool004goool00ol0VOooooooo`0ooooo00<0000co`0co`0023?o
00030000oooooooo08?oool004goool00ol0VOooooooo`0hoooo0P0000Goool00`0003?o03?o0008
<ol000<0003oooooool0Poooo`00COooo`03o`2Ioooooooo03Ooool010000?ooooooo`0000Coool0
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00COooo`03o`2Ioooooooo03Woool00`000?oo
ooooo`03oooo0`0000Pco`000`000?ooooooo`23oooo001=oooo00?o09Woooooool0>_ooo`030000
oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00COooo`03o`2Ioooooooo
03Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00COoo
o`03o`2Ioooooooo03Soool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001=
oooo00?o09Woooooool0?oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001=oooo00?o
09Woooooool0?oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001=oooo00?o09Wooooo
ool0?oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001=oooo00?o09Woooooool0?ooo
o`800008<ol000<0003oooooool0Q?ooo`00COooo`03o`2Ioooooooo03ooool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00COooo`03o`2Ioooooooo03ooool00`0003?o03?o0007<ol000<0
003oooooool0Q?ooo`00COooo`03o`2Ioooooooo03ooool00`0003?o03?o0007<ol000<0003ooooo
ool0Q?ooo`00COooo`03o`2Ioooooooo03ooool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00COooo`03o`2Ioooooooo03ooool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00COoo
o`03o`2Ioooooooo03ooool200001c?o00030000oooooooo08Goool004goool00ol0VOooooooo`0o
oooo00<0000co`0co`001S?o00030000oooooooo08Goool004goool00ol0VOooooooo`0ooooo00<0
000co`0co`001S?o00030000oooooooo08Goool004goool00ol0VOooooooo`0ooooo00<0000co`0c
o`001S?o00030000oooooooo08Goool004goool00ol0VOooooooo`0ooooo00<0000co`0co`001S?o
00030000oooooooo08Goool004goool00ol0VOooooooo`0ooooo00<0000co`0co`001S?o00030000
oooooooo08Goool004goool00ol0VOooooooo`0ooooo0P0000Hco`000`000?ooooooo`26oooo001=
oooo00?o09Woooooool0?oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001=oooo00?o
09Woooooool0?oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001=oooo00?o09Wooooo
ool0?oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001=oooo00?o09Woooooool0?ooo
o`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001=oooo00?o09Woooooool0?oooo`030000
<ol0<ol000Dco`000`000?ooooooo`26oooo001=oooo00?o09Woooooool0?oooo`800006<ol000<0
003oooooool0Q_ooo`00COooo`03o`2Ioooooooo03ooool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00COooo`03o`2Ioooooooo03ooool00`0003?o03?o0005<ol000<0003oooooool0Q_oo
o`00COooo`03o`2Ioooooooo03ooool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00COoo
o`03o`2Ioooooooo03ooool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00COooo`03o`2I
oooooooo03Woool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001=oooo00?o
09Woooooool0>_ooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0Qooo
o`00COooo`03o`2Ioooooooo03Ooool500000oooo`<00004<ol000<0003oooooool0Qoooo`00Qooo
o`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029
oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?oo
ooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`09oooo13?o0080000013?o0?ooooooooooo`800003oooo1@0000;oool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`04oooo100000<co`00100003?o03?o000000[oool00`000?ooooooo`02oooo00<0
003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0@oooo0c?o00040000
<ol0<ol000002_ooo`030000oooooooo00?oool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0000ooool3<ol000@0000co`0co`00000:oooo00<0003oooooool00_ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`00000Boooo0c?o00040000<ol0<ol000002_ooo`030000
oooooooo00;oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04oooo`@co`02000000<c
o`3oooooool01oooo`800003oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o
08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.23739 .12361 L
.24016 .12361 L
.24152 .12361 L
.24276 .12361 L
s
.24276 .12361 m
.24322 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`04oooo00?o09Wooooo
ool00_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03Goool00ol0VOooooooo`02oooo00<0003oooooool0>Oooo`030000<ol0<ol003Tco`090000=?oo
o`030000oooooooo01Goool004koool00ol0VOooooooo`0noooo00<0000co`0co`00<c?o00H0001E
oooo001>oooo00?o09Woooooool0?_ooo`030000<ol0<ol0034co`020000Foooo`00C_ooo`03o`2I
oooooooo03koool00`0003?o03?o000_<ol00P0005goool004koool00ol0VOooooooo`0noooo00<0
000co`0co`00;3?o00<0001Ooooo001>oooo00?o09Woooooool0?_ooo`80000Z<ol00`0006;oool0
04koool00ol0VOooooooo`0noooo00<0000co`0co`009c?o0080001Uoooo001>oooo00?o09Wooooo
ool0?_ooo`030000<ol0<ol002Hco`000`000?ooooooo`1Uoooo001>oooo00?o09Woooooool0?_oo
o`030000<ol0<ol002Dco`000`000?ooooooo`1Voooo001>oooo00?o09Woooooool0?_ooo`030000
<ol0<ol002@co`000`000?ooooooo`1Woooo001>oooo00?o09Woooooool0?_ooo`030000<ol0<ol0
028co`020000J_ooo`00C_ooo`03o`2Ioooooooo03koool200008S?o00030000oooooooo06[oool0
04koool00ol0VOooooooo`0noooo00<0000co`0co`0083?o00030000oooooooo06_oool004koool0
0ol0VOooooooo`0noooo00<0000co`0co`007c?o00030000oooooooo06coool004koool00ol0VOoo
ooooo`0noooo00<0000co`0co`007c?o00030000oooooooo06coool004koool00ol0VOooooooo`0n
oooo00<0000co`0co`007S?o00030000oooooooo06goool004koool00ol0VOooooooo`0noooo00<0
000co`0co`007C?o00030000oooooooo06koool004koool00ol0VOooooooo`0noooo0P0001dco`00
0`000?ooooooo`1_oooo001>oooo00?o09Woooooool0?_ooo`030000<ol0<ol001/co`000`000?oo
ooooo`1`oooo001>oooo00?o09Woooooool0?_ooo`030000<ol0<ol001/co`000`000?ooooooo`1`
oooo001>oooo00?o09Woooooool0?_ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001>
oooo00?o09Woooooool0?_ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001>oooo00?o
09Woooooool0?_ooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo001>oooo00?o09Wooooo
ool0?_ooo`80000J<ol000<0003oooooool0L_ooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o
03?o000H<ol000<0003oooooool0Loooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o000H
<ol000<0003oooooool0Loooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o000G<ol000<0
003oooooool0M?ooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o000G<ol000<0003ooooo
ool0M?ooo`00C_ooo`03o`2Ioooooooo03Koool500000oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001>oooo00?o09Woooooool0>?ooo`030000oooooooo00?oool00`0003?o03?o000F
<ol000<0003oooooool0MOooo`00C_ooo`03o`2Ioooooooo03Soool00`000?ooooooo`03oooo0`00
01Dco`000`000?ooooooo`1foooo001>oooo00?o09Woooooool0>?ooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00C_ooo`03o`2Ioooooooo03Soool00`000?oo
ooooo`03oooo00<0000co`0co`005C?o00030000oooooooo07Koool004koool00ol0VOooooooo`0g
oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00C_ooo`03o`2Ioooooooo
03koool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00C_ooo`03o`2Ioooooooo03koool0
0`0003?o03?o000C<ol000<0003oooooool0N?ooo`00C_ooo`03o`2Ioooooooo03koool2000053?o
00030000oooooooo07Soool004koool00ol0VOooooooo`0noooo00<0000co`0co`004c?o00030000
oooooooo07Soool004koool00ol0VOooooooo`0noooo00<0000co`0co`004S?o00030000oooooooo
07Woool004koool00ol0VOooooooo`0noooo00<0000co`0co`004S?o00030000oooooooo07Woool0
04koool00ol0VOooooooo`0noooo00<0000co`0co`004S?o00030000oooooooo07Woool004koool0
0ol0VOooooooo`0noooo00<0000co`0co`004C?o00030000oooooooo07[oool004koool00ol0VOoo
ooooo`0noooo0P00018co`000`000?ooooooo`1joooo001>oooo00?o09Woooooool0?_ooo`030000
<ol0<ol0014co`000`000?ooooooo`1joooo001>oooo00?o09Woooooool0?_ooo`030000<ol0<ol0
014co`000`000?ooooooo`1joooo001>oooo00?o09Woooooool0?_ooo`030000<ol0<ol0010co`00
0`000?ooooooo`1koooo001>oooo00?o09Woooooool0?_ooo`030000<ol0<ol0010co`000`000?oo
ooooo`1koooo001>oooo00?o09Woooooool0?_ooo`030000<ol0<ol0010co`000`000?ooooooo`1k
oooo001>oooo00?o09Woooooool0?_ooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo001>
oooo00?o09Woooooool0?_ooo`80000@<ol000<0003oooooool0O?ooo`00C_ooo`03o`2Ioooooooo
03koool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00C_ooo`03o`2Ioooooooo03koool0
0`0003?o03?o000?<ol000<0003oooooool0O?ooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o
03?o000?<ol000<0003oooooool0O?ooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o000?
<ol000<0003oooooool0O?ooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o000><ol000<0
003oooooool0OOooo`00C_ooo`03o`2Ioooooooo03koool200003c?o00030000oooooooo07goool0
04koool00ol0VOooooooo`0noooo00<0000co`0co`003S?o00030000oooooooo07goool004koool0
0ol0VOooooooo`0noooo00<0000co`0co`003S?o00030000oooooooo07goool004koool00ol0VOoo
ooooo`0noooo00<0000co`0co`003C?o00030000oooooooo07koool004koool00ol0VOooooooo`0f
oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00C_ooo`03o`2Ioooooooo
03Koool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo07koool004koool0
0ol0VOooooooo`0goooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0O_ooo`00C_oo
o`03o`2Ioooooooo03Soool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo
07koool004koool00ol0VOooooooo`0foooo00@0003oooooool00004oooo00<0000co`0co`0033?o
00030000oooooooo07ooool004koool00ol0VOooooooo`0goooo0P0000Goool00`0003?o03?o000<
<ol000<0003oooooool0Ooooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o000<<ol000<0
003oooooool0Ooooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00C_ooo`03o`2Ioooooooo03koool200003C?o00030000oooooooo07ooool004koool0
0ol0VOooooooo`0noooo00<0000co`0co`0033?o00030000oooooooo07ooool004koool00ol0VOoo
ooooo`0noooo00<0000co`0co`002c?o00030000oooooooo083oool004koool00ol0VOooooooo`0n
oooo00<0000co`0co`002c?o00030000oooooooo083oool004koool00ol0VOooooooo`0noooo00<0
000co`0co`002c?o00030000oooooooo083oool004koool00ol0VOooooooo`0noooo00<0000co`0c
o`002c?o00030000oooooooo083oool004koool00ol0VOooooooo`0noooo00<0000co`0co`002c?o
00030000oooooooo083oool004koool00ol0VOooooooo`0noooo0P0000`co`000`000?ooooooo`20
oooo001>oooo00?o09Woooooool0?_ooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001>
oooo00?o09Woooooool0?_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001>oooo00?o
09Woooooool0?_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001>oooo00?o09Wooooo
ool0?_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001>oooo00?o09Woooooool0?_oo
o`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001>oooo00?o09Woooooool0?_ooo`80000;
<ol000<0003oooooool0POooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o000:<ol000<0003ooooo
ool0POooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o0009<ol000<0003oooooool0P_oo
o`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00C_oo
o`03o`2Ioooooooo03koool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00C_ooo`03o`2I
oooooooo03koool200002S?o00030000oooooooo08;oool004koool00ol0VOooooooo`0noooo00<0
000co`0co`002C?o00030000oooooooo08;oool004koool00ol0VOooooooo`0noooo00<0000co`0c
o`002C?o00030000oooooooo08;oool004koool00ol0VOooooooo`0noooo00<0000co`0co`0023?o
00030000oooooooo08?oool004koool00ol0VOooooooo`0goooo0P0000Goool00`0003?o03?o0008
<ol000<0003oooooool0Poooo`00C_ooo`03o`2Ioooooooo03Koool010000?ooooooo`0000Coool0
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00C_ooo`03o`2Ioooooooo03Soool00`000?oo
ooooo`03oooo0`0000Pco`000`000?ooooooo`23oooo001>oooo00?o09Woooooool0>Oooo`030000
oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00C_ooo`03o`2Ioooooooo
03Koool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00C_oo
o`03o`2Ioooooooo03Ooool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001>
oooo00?o09Woooooool0?_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001>oooo00?o
09Woooooool0?_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001>oooo00?o09Wooooo
ool0?_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001>oooo00?o09Woooooool0?_oo
o`800008<ol000<0003oooooool0Q?ooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o0007<ol000<0
003oooooool0Q?ooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o0007<ol000<0003ooooo
ool0Q?ooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00C_oo
o`03o`2Ioooooooo03koool200001c?o00030000oooooooo08Goool004koool00ol0VOooooooo`0n
oooo00<0000co`0co`001S?o00030000oooooooo08Goool004koool00ol0VOooooooo`0noooo00<0
000co`0co`001S?o00030000oooooooo08Goool004koool00ol0VOooooooo`0noooo00<0000co`0c
o`001S?o00030000oooooooo08Goool004koool00ol0VOooooooo`0noooo00<0000co`0co`001S?o
00030000oooooooo08Goool004koool00ol0VOooooooo`0noooo00<0000co`0co`001S?o00030000
oooooooo08Goool004koool00ol0VOooooooo`0noooo0P0000Hco`000`000?ooooooo`26oooo001>
oooo00?o09Woooooool0?_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001>oooo00?o
09Woooooool0?_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001>oooo00?o09Wooooo
ool0?_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001>oooo00?o09Woooooool0?_oo
o`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001>oooo00?o09Woooooool0?_ooo`030000
<ol0<ol000Dco`000`000?ooooooo`26oooo001>oooo00?o09Woooooool0?_ooo`800006<ol000<0
003oooooool0Q_ooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o0005<ol000<0003oooooool0Q_oo
o`00C_ooo`03o`2Ioooooooo03koool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00C_oo
o`03o`2Ioooooooo03koool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00C_ooo`03o`2I
oooooooo03Soool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001>oooo00?o
09Woooooool0>Oooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0Qooo
o`00C_ooo`03o`2Ioooooooo03Koool500000oooo`<00004<ol000<0003oooooool0Qoooo`00Qooo
o`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029
oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Koool00`000?oo
ooooo`0Foooo1c?o017oool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?ooo`030000
oooooooo00coool7<ol04_ooo`030000oooooooo07Goool007Goool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`0<oooo00<co`000000000013?o00800004oooo0P0000Coool200001?oo
o`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`040000<ol0<ol000000c?o00Goool010000?ooooooo`00
00;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001doooo00<0003oooooool00_oo
o`030000oooooooo01?oool0100003?o03?o000000<co`05oooo00@0003oooooool00002oooo00@0
003oooooool00004oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Boooo00@0
000co`0co`000003<ol01Oooo`040000oooooooo00000oooo`800004oooo00<0003oooooool0MOoo
o`00MOooo`050000oooooooooooo000001Goool0100003?o03?o000000<co`05oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo
01Koool00c?o000000000004<ol01_ooo`800004oooo0P0000?oool00`000?ooooooo`1foooo002?
oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.23739 .12361 L
.24276 .12361 L
.24502 .12361 L
.24627 .12361 L
.24745 .12361 L
s
.24745 .12361 m
.24772 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`05oooo00Go09Wooooo
ooooool000002oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_oo
o`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0=_ooo`05o`2I
oooooooooooo000003_oool00`0003?o03?o000i<ol02@0003Coool00`000?ooooooo`0Eoooo001?
oooo00?o09Woooooool0?Oooo`030000<ol0<ol003<co`060000EOooo`00Coooo`03o`2Ioooooooo
03goool00`0003?o03?o000a<ol00P0005_oool004ooool00ol0VOooooooo`0moooo00<0000co`0c
o`00;c?o0080001Moooo001?oooo00?o09Woooooool0?Oooo`030000<ol0<ol002`co`030000Gooo
o`00Coooo`03o`2Ioooooooo03goool20000:S?o00<0001Roooo001?oooo00?o09Woooooool0?Ooo
o`030000<ol0<ol002Lco`020000IOooo`00Coooo`03o`2Ioooooooo03goool00`0003?o03?o000V
<ol000<0003oooooool0IOooo`00Coooo`03o`2Ioooooooo03goool00`0003?o03?o000U<ol000<0
003oooooool0I_ooo`00Coooo`03o`2Ioooooooo03goool00`0003?o03?o000T<ol000<0003ooooo
ool0Ioooo`00Coooo`03o`2Ioooooooo03goool00`0003?o03?o000R<ol00P0006[oool004ooool0
0ol0VOooooooo`0moooo0P00028co`000`000?ooooooo`1Zoooo001?oooo00?o09Woooooool0?Ooo
o`030000<ol0<ol0020co`000`000?ooooooo`1[oooo001?oooo00?o09Woooooool0?Oooo`030000
<ol0<ol001lco`000`000?ooooooo`1/oooo001?oooo00?o09Woooooool0?Oooo`030000<ol0<ol0
01lco`000`000?ooooooo`1/oooo001?oooo00?o09Woooooool0?Oooo`030000<ol0<ol001hco`00
0`000?ooooooo`1]oooo001?oooo00?o09Woooooool0?Oooo`030000<ol0<ol001dco`000`000?oo
ooooo`1^oooo001?oooo00?o09Woooooool0?Oooo`80000M<ol000<0003oooooool0Koooo`00Cooo
o`03o`2Ioooooooo03goool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00Coooo`03o`2I
oooooooo03goool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00Coooo`03o`2Ioooooooo
03goool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00Coooo`03o`2Ioooooooo03goool0
0`0003?o03?o000J<ol000<0003oooooool0LOooo`00Coooo`03o`2Ioooooooo03goool00`0003?o
03?o000I<ol000<0003oooooool0L_ooo`00Coooo`03o`2Ioooooooo03goool200006S?o00030000
oooooooo07;oool004ooool00ol0VOooooooo`0moooo00<0000co`0co`0063?o00030000oooooooo
07?oool004ooool00ol0VOooooooo`0moooo00<0000co`0co`0063?o00030000oooooooo07?oool0
04ooool00ol0VOooooooo`0moooo00<0000co`0co`005c?o00030000oooooooo07Coool004ooool0
0ol0VOooooooo`0moooo00<0000co`0co`005c?o00030000oooooooo07Coool004ooool00ol0VOoo
ooooo`0eoooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00Coooo`03o`2I
oooooooo03Ooool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo07Goool0
04ooool00ol0VOooooooo`0goooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0M_oo
o`00Coooo`03o`2Ioooooooo03Ooool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000
oooooooo07Koool004ooool00ol0VOooooooo`0goooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`1foooo001?oooo00?o09Woooooool0=_ooo`800005oooo00<0000co`0c
o`0053?o00030000oooooooo07Ooool004ooool00ol0VOooooooo`0moooo00<0000co`0co`0053?o
00030000oooooooo07Ooool004ooool00ol0VOooooooo`0moooo00<0000co`0co`004c?o00030000
oooooooo07Soool004ooool00ol0VOooooooo`0moooo0P0001@co`000`000?ooooooo`1hoooo001?
oooo00?o09Woooooool0?Oooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo001?oooo00?o
09Woooooool0?Oooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001?oooo00?o09Wooooo
ool0?Oooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001?oooo00?o09Woooooool0?Ooo
o`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001?oooo00?o09Woooooool0?Oooo`030000
<ol0<ol0014co`000`000?ooooooo`1joooo001?oooo00?o09Woooooool0?Oooo`80000B<ol000<0
003oooooool0N_ooo`00Coooo`03o`2Ioooooooo03goool00`0003?o03?o000A<ol000<0003ooooo
ool0N_ooo`00Coooo`03o`2Ioooooooo03goool00`0003?o03?o000A<ol000<0003oooooool0N_oo
o`00Coooo`03o`2Ioooooooo03goool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Cooo
o`03o`2Ioooooooo03goool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Coooo`03o`2I
oooooooo03goool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Coooo`03o`2Ioooooooo
03goool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Coooo`03o`2Ioooooooo03goool2
000043?o00030000oooooooo07coool004ooool00ol0VOooooooo`0moooo00<0000co`0co`003c?o
00030000oooooooo07coool004ooool00ol0VOooooooo`0moooo00<0000co`0co`003c?o00030000
oooooooo07coool004ooool00ol0VOooooooo`0moooo00<0000co`0co`003c?o00030000oooooooo
07coool004ooool00ol0VOooooooo`0moooo00<0000co`0co`003c?o00030000oooooooo07coool0
04ooool00ol0VOooooooo`0moooo00<0000co`0co`003S?o00030000oooooooo07goool004ooool0
0ol0VOooooooo`0moooo0P0000lco`000`000?ooooooo`1moooo001?oooo00?o09Woooooool0?Ooo
o`030000<ol0<ol000hco`000`000?ooooooo`1moooo001?oooo00?o09Woooooool0?Oooo`030000
<ol0<ol000hco`000`000?ooooooo`1moooo001?oooo00?o09Woooooool0?Oooo`030000<ol0<ol0
00dco`000`000?ooooooo`1noooo001?oooo00?o09Woooooool0=Oooo`@00004oooo00<0000co`0c
o`003C?o00030000oooooooo07koool004ooool00ol0VOooooooo`0eoooo00<0003oooooool01Ooo
o`030000<ol0<ol000dco`000`000?ooooooo`1noooo001?oooo00?o09Woooooool0=_ooo`030000
oooooooo00Coool300003C?o00030000oooooooo07koool004ooool00ol0VOooooooo`0goooo00<0
003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo001?oooo00?o09Wooooo
ool0=Oooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001?
oooo00?o09Woooooool0=_ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo07ooool0
04ooool00ol0VOooooooo`0moooo00<0000co`0co`0033?o00030000oooooooo07ooool004ooool0
0ol0VOooooooo`0moooo00<0000co`0co`0033?o00030000oooooooo07ooool004ooool00ol0VOoo
ooooo`0moooo0P0000dco`000`000?ooooooo`1ooooo001?oooo00?o09Woooooool0?Oooo`030000
<ol0<ol000`co`000`000?ooooooo`1ooooo001?oooo00?o09Woooooool0?Oooo`030000<ol0<ol0
00/co`000`000?ooooooo`20oooo001?oooo00?o09Woooooool0?Oooo`030000<ol0<ol000/co`00
0`000?ooooooo`20oooo001?oooo00?o09Woooooool0?Oooo`030000<ol0<ol000/co`000`000?oo
ooooo`20oooo001?oooo00?o09Woooooool0?Oooo`030000<ol0<ol000/co`000`000?ooooooo`20
oooo001?oooo00?o09Woooooool0?Oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001?
oooo00?o09Woooooool0?Oooo`80000<<ol000<0003oooooool0P?ooo`00Coooo`03o`2Ioooooooo
03goool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00Coooo`03o`2Ioooooooo03goool0
0`0003?o03?o000:<ol000<0003oooooool0POooo`00Coooo`03o`2Ioooooooo03goool00`0003?o
03?o000:<ol000<0003oooooool0POooo`00Coooo`03o`2Ioooooooo03goool00`0003?o03?o000:
<ol000<0003oooooool0POooo`00Coooo`03o`2Ioooooooo03goool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00Coooo`03o`2Ioooooooo03goool200002c?o00030000oooooooo087oool0
04ooool00ol0VOooooooo`0moooo00<0000co`0co`002S?o00030000oooooooo087oool004ooool0
0ol0VOooooooo`0moooo00<0000co`0co`002S?o00030000oooooooo087oool004ooool00ol0VOoo
ooooo`0moooo00<0000co`0co`002C?o00030000oooooooo08;oool004ooool00ol0VOooooooo`0m
oooo00<0000co`0co`002C?o00030000oooooooo08;oool004ooool00ol0VOooooooo`0moooo00<0
000co`0co`002C?o00030000oooooooo08;oool004ooool00ol0VOooooooo`0moooo0P0000Xco`00
0`000?ooooooo`22oooo001?oooo00?o09Woooooool0?Oooo`030000<ol0<ol000Tco`000`000?oo
ooooo`22oooo001?oooo00?o09Woooooool0?Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22
oooo001?oooo00?o09Woooooool0?Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001?
oooo00?o09Woooooool0=_ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo08?oool0
04ooool00ol0VOooooooo`0eoooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000
oooooooo08?oool004ooool00ol0VOooooooo`0goooo00<0003oooooool00oooo`<00008<ol000<0
003oooooool0Poooo`00Coooo`03o`2Ioooooooo03Soool00`000?ooooooo`02oooo00<0000co`0c
o`0023?o00030000oooooooo08?oool004ooool00ol0VOooooooo`0eoooo00@0003oooooool00004
oooo00<0000co`0co`0023?o00030000oooooooo08?oool004ooool00ol0VOooooooo`0foooo0P00
00Goool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00Coooo`03o`2Ioooooooo03goool0
0`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00Coooo`03o`2Ioooooooo03goool00`0003?o
03?o0007<ol000<0003oooooool0Q?ooo`00Coooo`03o`2Ioooooooo03goool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00Coooo`03o`2Ioooooooo03goool2000023?o00030000oooooooo
08Coool004ooool00ol0VOooooooo`0moooo00<0000co`0co`001c?o00030000oooooooo08Coool0
04ooool00ol0VOooooooo`0moooo00<0000co`0co`001c?o00030000oooooooo08Coool004ooool0
0ol0VOooooooo`0moooo00<0000co`0co`001c?o00030000oooooooo08Coool004ooool00ol0VOoo
ooooo`0moooo00<0000co`0co`001S?o00030000oooooooo08Goool004ooool00ol0VOooooooo`0m
oooo00<0000co`0co`001S?o00030000oooooooo08Goool004ooool00ol0VOooooooo`0moooo0P00
00Lco`000`000?ooooooo`25oooo001?oooo00?o09Woooooool0?Oooo`030000<ol0<ol000Hco`00
0`000?ooooooo`25oooo001?oooo00?o09Woooooool0?Oooo`030000<ol0<ol000Hco`000`000?oo
ooooo`25oooo001?oooo00?o09Woooooool0?Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25
oooo001?oooo00?o09Woooooool0?Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001?
oooo00?o09Woooooool0?Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001?oooo00?o
09Woooooool0?Oooo`800006<ol000<0003oooooool0Q_ooo`00Coooo`03o`2Ioooooooo03goool0
0`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00Coooo`03o`2Ioooooooo03goool00`0003?o
03?o0005<ol000<0003oooooool0Q_ooo`00Coooo`03o`2Ioooooooo03goool00`0003?o03?o0005
<ol000<0003oooooool0Q_ooo`00Coooo`03o`2Ioooooooo03goool00`0003?o03?o0005<ol000<0
003oooooool0Q_ooo`00Coooo`03o`2Ioooooooo03goool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00Coooo`03o`2Ioooooooo03goool200001S?o00030000oooooooo08Koool004ooool0
0ol0VOooooooo`0moooo00<0000co`0co`001C?o00030000oooooooo08Koool004ooool00ol0VOoo
ooooo`0moooo00<0000co`0co`001C?o00030000oooooooo08Koool004ooool00ol0VOooooooo`0m
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool004ooool00ol0VOooooooo`0moooo00<0
000co`0co`0013?o00030000oooooooo08Ooool004ooool00ol0VOooooooo`0goooo0`0000?oool0
0`0003?o03?o0004<ol000<0003oooooool0Qoooo`00Coooo`03o`2Ioooooooo03Soool00`000?oo
ooooo`02oooo00<0000co`0co`0013?o00030000oooooooo08Ooool004ooool00ol0VOooooooo`0e
oooo1@0000?oool3000013?o00030000oooooooo08Ooool008Ooool010000?ooooooo`0000Coool7
<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool0
08ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001foooo00<0003oooooool05_ooo`Lco`0Aoooo00<0
003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0<oooo1c?o01;oool0
0`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03?oo
o`03<ol00000000000@co`0200001?ooo`800003oooo0`0000Coool00`000?ooooooo`1eoooo001e
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo1000
00?oool0100003?o03?o000000<co`05oooo00@0003oooooool00002oooo00@0003oooooool00003
oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0
000co`0co`000003<ol01Oooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo07Coool007Goool00`000?ooooooo`0500004_ooo`040000<ol0<ol000000c?o00Goool0
10000?ooooooo`0000;oool300001?ooo`030000oooooooo07Goool007Goool01@000?oooooooooo
o`00000Eoooo00@0000co`0co`000003<ol01Oooo`040000oooooooo00000oooo`030000oooooooo
00?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05_ooo`03<ol00000000000@co`06
oooo0P0000Coool300000_ooo`030000oooooooo07Koool008ooool7<ol0R_ooo`00Soooo`Lco`2:
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.23739 .12361 L
.24276 .12361 L
.24745 .12361 L
.24873 .12361 L
.25012 .12361 L
.25142 .12361 L
s
.25142 .12361 m
.2519 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`06oooo00Co09Wooooo
ool0000;oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0
003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0goooo00Co09Wooooo
ool0000koooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Oooo`00D?ooo`03o`2I
oooooooo03coool00`0003?o03?o000c<ol01P0005Goool0053oool00ol0VOooooooo`0loooo00<0
000co`0co`00<C?o0080001Koooo001@oooo00?o09Woooooool0??ooo`030000<ol0<ol002lco`02
0000GOooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o000/<ol00`0005ooool0053oool0
0ol0VOooooooo`0loooo0P0002Xco`030000H_ooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o
03?o000W<ol00P0006Goool0053oool00ol0VOooooooo`0loooo00<0000co`0co`009S?o00030000
oooooooo06Goool0053oool00ol0VOooooooo`0loooo00<0000co`0co`009C?o00030000oooooooo
06Koool0053oool00ol0VOooooooo`0loooo00<0000co`0co`0093?o00030000oooooooo06Ooool0
053oool00ol0VOooooooo`0loooo00<0000co`0co`008S?o0080001Zoooo001@oooo00?o09Wooooo
ool0??ooo`80000R<ol000<0003oooooool0J_ooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o
03?o000P<ol000<0003oooooool0Joooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o000O
<ol000<0003oooooool0K?ooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o000O<ol000<0
003oooooool0K?ooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o000N<ol000<0003ooooo
ool0KOooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o000M<ol000<0003oooooool0K_oo
o`00D?ooo`03o`2Ioooooooo03coool200007C?o00030000oooooooo06ooool0053oool00ol0VOoo
ooooo`0loooo00<0000co`0co`006c?o00030000oooooooo073oool0053oool00ol0VOooooooo`0l
oooo00<0000co`0co`006c?o00030000oooooooo073oool0053oool00ol0VOooooooo`0loooo00<0
000co`0co`006S?o00030000oooooooo077oool0053oool00ol0VOooooooo`0loooo00<0000co`0c
o`006S?o00030000oooooooo077oool0053oool00ol0VOooooooo`0loooo00<0000co`0co`006C?o
00030000oooooooo07;oool0053oool00ol0VOooooooo`0loooo0P0001Xco`000`000?ooooooo`1b
oooo001@oooo00?o09Woooooool0??ooo`030000<ol0<ol001Pco`000`000?ooooooo`1coooo001@
oooo00?o09Woooooool0??ooo`030000<ol0<ol001Pco`000`000?ooooooo`1coooo001@oooo00?o
09Woooooool0??ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001@oooo00?o09Wooooo
ool0??ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001@oooo00?o09Woooooool0=?oo
o`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool0053oool00ol0VOooooooo`0f
oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1eoooo001@oooo00?o
09Woooooool0=_ooo`030000oooooooo00?oool300005C?o00030000oooooooo07Koool0053oool0
0ol0VOooooooo`0foooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`1f
oooo001@oooo00?o09Woooooool0=_ooo`030000oooooooo00?oool00`0003?o03?o000E<ol000<0
003oooooool0M_ooo`00D?ooo`03o`2Ioooooooo03Goool200001Oooo`030000<ol0<ol001@co`00
0`000?ooooooo`1goooo001@oooo00?o09Woooooool0??ooo`030000<ol0<ol001@co`000`000?oo
ooooo`1goooo001@oooo00?o09Woooooool0??ooo`030000<ol0<ol001<co`000`000?ooooooo`1h
oooo001@oooo00?o09Woooooool0??ooo`80000D<ol000<0003oooooool0N?ooo`00D?ooo`03o`2I
oooooooo03coool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00D?ooo`03o`2Ioooooooo
03coool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00D?ooo`03o`2Ioooooooo03coool0
0`0003?o03?o000B<ol000<0003oooooool0NOooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o
03?o000B<ol000<0003oooooool0NOooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00D?ooo`03o`2Ioooooooo03coool200004S?o00030000oooooooo
07[oool0053oool00ol0VOooooooo`0loooo00<0000co`0co`004C?o00030000oooooooo07[oool0
053oool00ol0VOooooooo`0loooo00<0000co`0co`004C?o00030000oooooooo07[oool0053oool0
0ol0VOooooooo`0loooo00<0000co`0co`0043?o00030000oooooooo07_oool0053oool00ol0VOoo
ooooo`0loooo00<0000co`0co`0043?o00030000oooooooo07_oool0053oool00ol0VOooooooo`0l
oooo00<0000co`0co`0043?o00030000oooooooo07_oool0053oool00ol0VOooooooo`0loooo00<0
000co`0co`0043?o00030000oooooooo07_oool0053oool00ol0VOooooooo`0loooo0P00010co`00
0`000?ooooooo`1loooo001@oooo00?o09Woooooool0??ooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001@oooo00?o09Woooooool0??ooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo001@oooo00?o09Woooooool0??ooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo001@
oooo00?o09Woooooool0??ooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo001@oooo00?o
09Woooooool0??ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001@oooo00?o09Wooooo
ool0??ooo`80000?<ol000<0003oooooool0OOooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o
03?o000><ol000<0003oooooool0OOooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o000>
<ol000<0003oooooool0OOooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o000=<ol000<0
003oooooool0O_ooo`00D?ooo`03o`2Ioooooooo03Coool400001?ooo`030000<ol0<ol000dco`00
0`000?ooooooo`1noooo001@oooo00?o09Woooooool0=?ooo`030000oooooooo00Goool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00D?ooo`03o`2Ioooooooo03Goool00`000?ooooooo`04
oooo0`0000dco`000`000?ooooooo`1noooo001@oooo00?o09Woooooool0=_ooo`030000oooooooo
00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00D?ooo`03o`2Ioooooooo03Coool0
10000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00D?ooo`03o`2I
oooooooo03Goool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001@oooo00?o
09Woooooool0??ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001@oooo00?o09Wooooo
ool0??ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001@oooo00?o09Woooooool0??oo
o`80000=<ol000<0003oooooool0Ooooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o000<
<ol000<0003oooooool0Ooooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00D?oo
o`03o`2Ioooooooo03coool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00D?ooo`03o`2I
oooooooo03coool2000033?o00030000oooooooo083oool0053oool00ol0VOooooooo`0loooo00<0
000co`0co`002c?o00030000oooooooo083oool0053oool00ol0VOooooooo`0loooo00<0000co`0c
o`002S?o00030000oooooooo087oool0053oool00ol0VOooooooo`0loooo00<0000co`0co`002S?o
00030000oooooooo087oool0053oool00ol0VOooooooo`0loooo00<0000co`0co`002S?o00030000
oooooooo087oool0053oool00ol0VOooooooo`0loooo00<0000co`0co`002S?o00030000oooooooo
087oool0053oool00ol0VOooooooo`0loooo0P0000/co`000`000?ooooooo`21oooo001@oooo00?o
09Woooooool0??ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001@oooo00?o09Wooooo
ool0??ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001@oooo00?o09Woooooool0??oo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001@oooo00?o09Woooooool0??ooo`030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001@oooo00?o09Woooooool0??ooo`030000<ol0<ol0
00Tco`000`000?ooooooo`22oooo001@oooo00?o09Woooooool0??ooo`80000:<ol000<0003ooooo
ool0P_ooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o0009<ol000<0003oooooool0P_oo
o`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00D?oo
o`03o`2Ioooooooo03coool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00D?ooo`03o`2I
oooooooo03Goool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001@oooo00?o
09Woooooool0=?ooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001@oooo00?o09Woooooool0=_ooo`030000oooooooo00?oool3000023?o00030000oooooooo
08?oool0053oool00ol0VOooooooo`0goooo00<0003oooooool00_ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo001@oooo00?o09Woooooool0=?ooo`040000oooooooo00001?ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo001@oooo00?o09Woooooool0=Oooo`800005oooo00<0
000co`0co`001c?o00030000oooooooo08Coool0053oool00ol0VOooooooo`0loooo00<0000co`0c
o`001c?o00030000oooooooo08Coool0053oool00ol0VOooooooo`0loooo00<0000co`0co`001c?o
00030000oooooooo08Coool0053oool00ol0VOooooooo`0loooo00<0000co`0co`001c?o00030000
oooooooo08Coool0053oool00ol0VOooooooo`0loooo0P0000Pco`000`000?ooooooo`24oooo001@
oooo00?o09Woooooool0??ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001@oooo00?o
09Woooooool0??ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001@oooo00?o09Wooooo
ool0??ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001@oooo00?o09Woooooool0??oo
o`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001@oooo00?o09Woooooool0??ooo`030000
<ol0<ol000Hco`000`000?ooooooo`25oooo001@oooo00?o09Woooooool0??ooo`800007<ol000<0
003oooooool0QOooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00D?ooo`03o`2Ioooooooo03coool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00D?oo
o`03o`2Ioooooooo03coool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00D?ooo`03o`2I
oooooooo03coool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00D?ooo`03o`2Ioooooooo
03coool200001S?o00030000oooooooo08Koool0053oool00ol0VOooooooo`0loooo00<0000co`0c
o`001C?o00030000oooooooo08Koool0053oool00ol0VOooooooo`0loooo00<0000co`0co`001C?o
00030000oooooooo08Koool0053oool00ol0VOooooooo`0loooo00<0000co`0co`001C?o00030000
oooooooo08Koool0053oool00ol0VOooooooo`0loooo00<0000co`0co`001C?o00030000oooooooo
08Koool0053oool00ol0VOooooooo`0loooo00<0000co`0co`001C?o00030000oooooooo08Koool0
053oool00ol0VOooooooo`0loooo0P0000Hco`000`000?ooooooo`26oooo001@oooo00?o09Wooooo
ool0??ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001@oooo00?o09Woooooool0??oo
o`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001@oooo00?o09Woooooool0??ooo`030000
<ol0<ol000@co`000`000?ooooooo`27oooo001@oooo00?o09Woooooool0??ooo`030000<ol0<ol0
00@co`000`000?ooooooo`27oooo001@oooo00?o09Woooooool0=_ooo`<00003oooo00<0000co`0c
o`0013?o00030000oooooooo08Ooool0053oool00ol0VOooooooo`0goooo00<0003oooooool00_oo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo001@oooo00?o09Woooooool0=?ooo`D00003
oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004oooo1c?o08[oool0
08Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o
08[oool008ooool7<ol0R_ooo`00M_ooo`030000oooooooo01Koool7<ol04Oooo`030000oooooooo
07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool03?ooo`Lco`0Boooo00<0003ooooo
ool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo00coool00c?o0000
00000004<ol00P0000Coool200001Oooo`<00002oooo00<0003oooooool0MOooo`00MOooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0
000co`0co`000003<ol01Oooo`040000oooooooo00001Oooo`050000oooooooooooo000007Ooool0
07Coool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000<ol0<ol000000c?o00Goool0
10000?ooooooo`0000;oool500000oooo`030000oooooooo07Coool007Goool00`000?ooooooo`05
00004_ooo`040000<ol0<ol000000c?o00Goool010000?ooooooo`0000;oool010000?ooooooo`00
00?oool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005Oooo`040000<ol0<ol0
00000c?o00Goool010000?ooooooo`0000?oool00`000?ooo`000003oooo00<0003oooooool0MOoo
o`00M_ooo`030000oooooooo01Koool00c?o000000000004<ol01_ooo`800005oooo0P0000;oool0
0`000?ooooooo`1foooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.24276 .12361 L
.24754 .12361 L
.25261 .12361 L
.2547 .12361 L
.25585 .12361 L
.25694 .12361 L
s
.25694 .12361 m
.25746 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`07oooo00?o09Woool0
00002oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>?ooo`03o`2Ioooo0000
03_oool00`0003?o03?o000i<ol02@0003Coool00`000?ooooooo`0Eoooo001Aoooo00?o09Wooooo
ool0>oooo`030000<ol0<ol003<co`060000EOooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o
03?o000a<ol00P0005_oool0057oool00ol0VOooooooo`0koooo00<0000co`0co`00;c?o0080001M
oooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol002`co`030000Goooo`00DOooo`03o`2I
oooooooo03_oool20000:S?o00<0001Roooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol0
02Lco`020000IOooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o000V<ol000<0003ooooo
ool0IOooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o000U<ol000<0003oooooool0I_oo
o`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o000T<ol000<0003oooooool0Ioooo`00DOoo
o`03o`2Ioooooooo03_oool00`0003?o03?o000R<ol00P0006[oool0057oool00ol0VOooooooo`0k
oooo0P00028co`000`000?ooooooo`1Zoooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol0
020co`000`000?ooooooo`1[oooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol001lco`00
0`000?ooooooo`1/oooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol001lco`000`000?oo
ooooo`1/oooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol001hco`000`000?ooooooo`1]
oooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol001dco`000`000?ooooooo`1^oooo001A
oooo00?o09Woooooool0>oooo`80000M<ol000<0003oooooool0Koooo`00DOooo`03o`2Ioooooooo
03_oool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00DOooo`03o`2Ioooooooo03_oool0
0`0003?o03?o000K<ol000<0003oooooool0L?ooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o
03?o000J<ol000<0003oooooool0LOooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o000J
<ol000<0003oooooool0LOooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o000I<ol000<0
003oooooool0L_ooo`00DOooo`03o`2Ioooooooo03_oool200006S?o00030000oooooooo07;oool0
057oool00ol0VOooooooo`0koooo00<0000co`0co`0063?o00030000oooooooo07?oool0057oool0
0ol0VOooooooo`0koooo00<0000co`0co`0063?o00030000oooooooo07?oool0057oool00ol0VOoo
ooooo`0koooo00<0000co`0co`005c?o00030000oooooooo07Coool0057oool00ol0VOooooooo`0k
oooo00<0000co`0co`005c?o00030000oooooooo07Coool0057oool00ol0VOooooooo`0coooo1@00
00?oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00DOooo`03o`2Ioooooooo03Goool0
0`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo07Goool0057oool00ol0VOoo
ooooo`0eoooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0M_ooo`00DOooo`03o`2I
oooooooo03Goool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo07Koool0
057oool00ol0VOooooooo`0eoooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?oo
ooooo`1foooo001Aoooo00?o09Woooooool0=?ooo`800005oooo00<0000co`0co`0053?o00030000
oooooooo07Ooool0057oool00ol0VOooooooo`0koooo00<0000co`0co`0053?o00030000oooooooo
07Ooool0057oool00ol0VOooooooo`0koooo00<0000co`0co`004c?o00030000oooooooo07Soool0
057oool00ol0VOooooooo`0koooo0P0001@co`000`000?ooooooo`1hoooo001Aoooo00?o09Wooooo
ool0>oooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo001Aoooo00?o09Woooooool0>ooo
o`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001Aoooo00?o09Woooooool0>oooo`030000
<ol0<ol0018co`000`000?ooooooo`1ioooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol0
018co`000`000?ooooooo`1ioooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol0014co`00
0`000?ooooooo`1joooo001Aoooo00?o09Woooooool0>oooo`80000B<ol000<0003oooooool0N_oo
o`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00DOoo
o`03o`2Ioooooooo03_oool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00DOooo`03o`2I
oooooooo03_oool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00DOooo`03o`2Ioooooooo
03_oool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00DOooo`03o`2Ioooooooo03_oool0
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o
03?o000@<ol000<0003oooooool0Noooo`00DOooo`03o`2Ioooooooo03_oool2000043?o00030000
oooooooo07coool0057oool00ol0VOooooooo`0koooo00<0000co`0co`003c?o00030000oooooooo
07coool0057oool00ol0VOooooooo`0koooo00<0000co`0co`003c?o00030000oooooooo07coool0
057oool00ol0VOooooooo`0koooo00<0000co`0co`003c?o00030000oooooooo07coool0057oool0
0ol0VOooooooo`0koooo00<0000co`0co`003c?o00030000oooooooo07coool0057oool00ol0VOoo
ooooo`0koooo00<0000co`0co`003S?o00030000oooooooo07goool0057oool00ol0VOooooooo`0k
oooo0P0000lco`000`000?ooooooo`1moooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol0
00hco`000`000?ooooooo`1moooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol000hco`00
0`000?ooooooo`1moooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol000dco`000`000?oo
ooooo`1noooo001Aoooo00?o09Woooooool0<oooo`@00004oooo00<0000co`0co`003C?o00030000
oooooooo07koool0057oool00ol0VOooooooo`0coooo00<0003oooooool01Oooo`030000<ol0<ol0
00dco`000`000?ooooooo`1noooo001Aoooo00?o09Woooooool0=?ooo`030000oooooooo00Coool3
00003C?o00030000oooooooo07koool0057oool00ol0VOooooooo`0eoooo00<0003oooooool00ooo
o`030000<ol0<ol000dco`000`000?ooooooo`1noooo001Aoooo00?o09Woooooool0<oooo`040000
oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001Aoooo00?o09Wooooo
ool0=?ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo07ooool0057oool00ol0VOoo
ooooo`0koooo00<0000co`0co`0033?o00030000oooooooo07ooool0057oool00ol0VOooooooo`0k
oooo00<0000co`0co`0033?o00030000oooooooo07ooool0057oool00ol0VOooooooo`0koooo0P00
00dco`000`000?ooooooo`1ooooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol000`co`00
0`000?ooooooo`1ooooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol000/co`000`000?oo
ooooo`20oooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol000/co`000`000?ooooooo`20
oooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001A
oooo00?o09Woooooool0>oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001Aoooo00?o
09Woooooool0>oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001Aoooo00?o09Wooooo
ool0>oooo`80000<<ol000<0003oooooool0P?ooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o000:
<ol000<0003oooooool0POooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o000:<ol000<0003ooooo
ool0POooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o000:<ol000<0003oooooool0POoo
o`00DOooo`03o`2Ioooooooo03_oool200002c?o00030000oooooooo087oool0057oool00ol0VOoo
ooooo`0koooo00<0000co`0co`002S?o00030000oooooooo087oool0057oool00ol0VOooooooo`0k
oooo00<0000co`0co`002S?o00030000oooooooo087oool0057oool00ol0VOooooooo`0koooo00<0
000co`0co`002C?o00030000oooooooo08;oool0057oool00ol0VOooooooo`0koooo00<0000co`0c
o`002C?o00030000oooooooo08;oool0057oool00ol0VOooooooo`0koooo00<0000co`0co`002C?o
00030000oooooooo08;oool0057oool00ol0VOooooooo`0koooo0P0000Xco`000`000?ooooooo`22
oooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001A
oooo00?o09Woooooool0>oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Aoooo00?o
09Woooooool0>oooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001Aoooo00?o09Wooooo
ool0=?ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo08?oool0057oool00ol0VOoo
ooooo`0coooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo08?oool0
057oool00ol0VOooooooo`0eoooo00<0003oooooool00oooo`<00008<ol000<0003oooooool0Pooo
o`00DOooo`03o`2Ioooooooo03Koool00`000?ooooooo`02oooo00<0000co`0co`0023?o00030000
oooooooo08?oool0057oool00ol0VOooooooo`0coooo00@0003oooooool00004oooo00<0000co`0c
o`0023?o00030000oooooooo08?oool0057oool00ol0VOooooooo`0doooo0P0000Goool00`0003?o
03?o0007<ol000<0003oooooool0Q?ooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o0007<ol000<0
003oooooool0Q?ooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o0007<ol000<0003ooooo
ool0Q?ooo`00DOooo`03o`2Ioooooooo03_oool2000023?o00030000oooooooo08Coool0057oool0
0ol0VOooooooo`0koooo00<0000co`0co`001c?o00030000oooooooo08Coool0057oool00ol0VOoo
ooooo`0koooo00<0000co`0co`001c?o00030000oooooooo08Coool0057oool00ol0VOooooooo`0k
oooo00<0000co`0co`001c?o00030000oooooooo08Coool0057oool00ol0VOooooooo`0koooo00<0
000co`0co`001S?o00030000oooooooo08Goool0057oool00ol0VOooooooo`0koooo00<0000co`0c
o`001S?o00030000oooooooo08Goool0057oool00ol0VOooooooo`0koooo0P0000Lco`000`000?oo
ooooo`25oooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol000Hco`000`000?ooooooo`25
oooo001Aoooo00?o09Woooooool0>oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001A
oooo00?o09Woooooool0>oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Aoooo00?o
09Woooooool0>oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Aoooo00?o09Wooooo
ool0>oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Aoooo00?o09Woooooool0>ooo
o`800006<ol000<0003oooooool0Q_ooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o0005
<ol000<0003oooooool0Q_ooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o0005<ol000<0
003oooooool0Q_ooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o0005<ol000<0003oooooool0Q_oo
o`00DOooo`03o`2Ioooooooo03_oool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00DOoo
o`03o`2Ioooooooo03_oool200001S?o00030000oooooooo08Koool0057oool00ol0VOooooooo`0k
oooo00<0000co`0co`001C?o00030000oooooooo08Koool0057oool00ol0VOooooooo`0koooo00<0
000co`0co`001C?o00030000oooooooo08Koool0057oool00ol0VOooooooo`0koooo00<0000co`0c
o`0013?o00030000oooooooo08Ooool0057oool00ol0VOooooooo`0koooo00<0000co`0co`0013?o
00030000oooooooo08Ooool0057oool00ol0VOooooooo`0eoooo0`0000?oool00`0003?o03?o0004
<ol000<0003oooooool0Qoooo`00DOooo`03o`2Ioooooooo03Koool00`000?ooooooo`02oooo00<0
000co`0co`0013?o00030000oooooooo08Ooool0057oool00ol0VOooooooo`0coooo1@0000?oool3
000013?o00030000oooooooo08Ooool008Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?oo
o`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_oo
o`00Soooo`Lco`2:oooo001foooo00<0003oooooool05_ooo`Lco`0Aoooo00<0003oooooool0M_oo
o`00MOooo`030000oooooooo00Soool00`000?ooooooo`0<oooo1c?o01;oool00`000?ooooooo`1e
oooo001eoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`03<ol000000000
00@co`0200001?ooo`800003oooo100000?oool00`000?ooooooo`1eoooo001eoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool0100003?o
03?o000000<co`05oooo00@0003oooooool00002oooo00<0003oooooool01?ooo`030000oooooooo
07Goool007Coool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000<ol0<ol000000c?o
00Goool010000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0M?ooo`00MOoo
o`030000oooooooo00D0000Boooo00@0000co`0co`000003<ol01Oooo`040000oooooooo00001?oo
o`030000oooooooo00;oool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005Ooo
o`040000<ol0<ol000000c?o00Goool010000?ooooooo`0000;oool010000?ooooooo`0000?oool0
0`000?ooooooo`1eoooo001foooo00<0003oooooool05_ooo`03<ol00000000000@co`06oooo0P00
00Coool200000oooo`030000oooooooo07Koool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.25127 .12361 L
.25666 .12361 L
.2593 .12361 L
.26045 .12361 L
.26171 .12361 L
s
.26171 .12361 m
.26223 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
03Woool00`0003?o03?o000i<ol02@0003Coool00`000?ooooooo`0Eoooo001Coooo00?o09Wooooo
ool0>Oooo`030000<ol0<ol003<co`060000EOooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o
03?o000a<ol00P0005_oool005?oool00ol0VOooooooo`0ioooo00<0000co`0co`00;c?o0080001M
oooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol002`co`030000Goooo`00Doooo`03o`2I
oooooooo03Woool20000:S?o00<0001Roooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol0
02Lco`020000IOooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o000V<ol000<0003ooooo
ool0IOooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o000U<ol000<0003oooooool0I_oo
o`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o000T<ol000<0003oooooool0Ioooo`00Dooo
o`03o`2Ioooooooo03Woool00`0003?o03?o000R<ol00P0006[oool005?oool00ol0VOooooooo`0i
oooo0P00028co`000`000?ooooooo`1Zoooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol0
020co`000`000?ooooooo`1[oooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol001lco`00
0`000?ooooooo`1/oooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol001lco`000`000?oo
ooooo`1/oooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol001hco`000`000?ooooooo`1]
oooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol001dco`000`000?ooooooo`1^oooo001C
oooo00?o09Woooooool0>Oooo`80000M<ol000<0003oooooool0Koooo`00Doooo`03o`2Ioooooooo
03Woool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00Doooo`03o`2Ioooooooo03Woool0
0`0003?o03?o000K<ol000<0003oooooool0L?ooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o
03?o000J<ol000<0003oooooool0LOooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o000J
<ol000<0003oooooool0LOooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o000I<ol000<0
003oooooool0L_ooo`00Doooo`03o`2Ioooooooo03Woool200006S?o00030000oooooooo07;oool0
05?oool00ol0VOooooooo`0ioooo00<0000co`0co`0063?o00030000oooooooo07?oool005?oool0
0ol0VOooooooo`0ioooo00<0000co`0co`0063?o00030000oooooooo07?oool005?oool00ol0VOoo
ooooo`0ioooo00<0000co`0co`005c?o00030000oooooooo07Coool005?oool00ol0VOooooooo`0i
oooo00<0000co`0co`005c?o00030000oooooooo07Coool005?oool00ol0VOooooooo`0aoooo1@00
00?oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00Doooo`03o`2Ioooooooo03?oool0
0`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo07Goool005?oool00ol0VOoo
ooooo`0coooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0M_ooo`00Doooo`03o`2I
oooooooo03?oool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo07Koool0
05?oool00ol0VOooooooo`0coooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?oo
ooooo`1foooo001Coooo00?o09Woooooool0<_ooo`800005oooo00<0000co`0co`0053?o00030000
oooooooo07Ooool005?oool00ol0VOooooooo`0ioooo00<0000co`0co`0053?o00030000oooooooo
07Ooool005?oool00ol0VOooooooo`0ioooo00<0000co`0co`004c?o00030000oooooooo07Soool0
05?oool00ol0VOooooooo`0ioooo0P0001@co`000`000?ooooooo`1hoooo001Coooo00?o09Wooooo
ool0>Oooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo001Coooo00?o09Woooooool0>Ooo
o`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001Coooo00?o09Woooooool0>Oooo`030000
<ol0<ol0018co`000`000?ooooooo`1ioooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol0
018co`000`000?ooooooo`1ioooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol0014co`00
0`000?ooooooo`1joooo001Coooo00?o09Woooooool0>Oooo`80000B<ol000<0003oooooool0N_oo
o`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00Dooo
o`03o`2Ioooooooo03Woool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00Doooo`03o`2I
oooooooo03Woool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Doooo`03o`2Ioooooooo
03Woool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Doooo`03o`2Ioooooooo03Woool0
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o
03?o000@<ol000<0003oooooool0Noooo`00Doooo`03o`2Ioooooooo03Woool2000043?o00030000
oooooooo07coool005?oool00ol0VOooooooo`0ioooo00<0000co`0co`003c?o00030000oooooooo
07coool005?oool00ol0VOooooooo`0ioooo00<0000co`0co`003c?o00030000oooooooo07coool0
05?oool00ol0VOooooooo`0ioooo00<0000co`0co`003c?o00030000oooooooo07coool005?oool0
0ol0VOooooooo`0ioooo00<0000co`0co`003c?o00030000oooooooo07coool005?oool00ol0VOoo
ooooo`0ioooo00<0000co`0co`003S?o00030000oooooooo07goool005?oool00ol0VOooooooo`0i
oooo0P0000lco`000`000?ooooooo`1moooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol0
00hco`000`000?ooooooo`1moooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol000hco`00
0`000?ooooooo`1moooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol000dco`000`000?oo
ooooo`1noooo001Coooo00?o09Woooooool0<Oooo`@00004oooo00<0000co`0co`003C?o00030000
oooooooo07koool005?oool00ol0VOooooooo`0aoooo00<0003oooooool01Oooo`030000<ol0<ol0
00dco`000`000?ooooooo`1noooo001Coooo00?o09Woooooool0<_ooo`030000oooooooo00Coool3
00003C?o00030000oooooooo07koool005?oool00ol0VOooooooo`0coooo00<0003oooooool00ooo
o`030000<ol0<ol000dco`000`000?ooooooo`1noooo001Coooo00?o09Woooooool0<Oooo`040000
oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001Coooo00?o09Wooooo
ool0<_ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo07ooool005?oool00ol0VOoo
ooooo`0ioooo00<0000co`0co`0033?o00030000oooooooo07ooool005?oool00ol0VOooooooo`0i
oooo00<0000co`0co`0033?o00030000oooooooo07ooool005?oool00ol0VOooooooo`0ioooo0P00
00dco`000`000?ooooooo`1ooooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol000`co`00
0`000?ooooooo`1ooooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol000/co`000`000?oo
ooooo`20oooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol000/co`000`000?ooooooo`20
oooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001C
oooo00?o09Woooooool0>Oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001Coooo00?o
09Woooooool0>Oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001Coooo00?o09Wooooo
ool0>Oooo`80000<<ol000<0003oooooool0P?ooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o000:
<ol000<0003oooooool0POooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o000:<ol000<0003ooooo
ool0POooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o000:<ol000<0003oooooool0POoo
o`00Doooo`03o`2Ioooooooo03Woool200002c?o00030000oooooooo087oool005?oool00ol0VOoo
ooooo`0ioooo00<0000co`0co`002S?o00030000oooooooo087oool005?oool00ol0VOooooooo`0i
oooo00<0000co`0co`002S?o00030000oooooooo087oool005?oool00ol0VOooooooo`0ioooo00<0
000co`0co`002C?o00030000oooooooo08;oool005?oool00ol0VOooooooo`0ioooo00<0000co`0c
o`002C?o00030000oooooooo08;oool005?oool00ol0VOooooooo`0ioooo00<0000co`0co`002C?o
00030000oooooooo08;oool005?oool00ol0VOooooooo`0ioooo0P0000Xco`000`000?ooooooo`22
oooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001C
oooo00?o09Woooooool0>Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Coooo00?o
09Woooooool0>Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001Coooo00?o09Wooooo
ool0<_ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo08?oool005?oool00ol0VOoo
ooooo`0aoooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo08?oool0
05?oool00ol0VOooooooo`0coooo00<0003oooooool00oooo`<00008<ol000<0003oooooool0Pooo
o`00Doooo`03o`2Ioooooooo03Coool00`000?ooooooo`02oooo00<0000co`0co`0023?o00030000
oooooooo08?oool005?oool00ol0VOooooooo`0aoooo00@0003oooooool00004oooo00<0000co`0c
o`0023?o00030000oooooooo08?oool005?oool00ol0VOooooooo`0boooo0P0000Goool00`0003?o
03?o0007<ol000<0003oooooool0Q?ooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o0007<ol000<0
003oooooool0Q?ooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o0007<ol000<0003ooooo
ool0Q?ooo`00Doooo`03o`2Ioooooooo03Woool2000023?o00030000oooooooo08Coool005?oool0
0ol0VOooooooo`0ioooo00<0000co`0co`001c?o00030000oooooooo08Coool005?oool00ol0VOoo
ooooo`0ioooo00<0000co`0co`001c?o00030000oooooooo08Coool005?oool00ol0VOooooooo`0i
oooo00<0000co`0co`001c?o00030000oooooooo08Coool005?oool00ol0VOooooooo`0ioooo00<0
000co`0co`001S?o00030000oooooooo08Goool005?oool00ol0VOooooooo`0ioooo00<0000co`0c
o`001S?o00030000oooooooo08Goool005?oool00ol0VOooooooo`0ioooo0P0000Lco`000`000?oo
ooooo`25oooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25
oooo001Coooo00?o09Woooooool0>Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001C
oooo00?o09Woooooool0>Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Coooo00?o
09Woooooool0>Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Coooo00?o09Wooooo
ool0>Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Coooo00?o09Woooooool0>Ooo
o`800006<ol000<0003oooooool0Q_ooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o0005
<ol000<0003oooooool0Q_ooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o0005<ol000<0
003oooooool0Q_ooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o0005<ol000<0003oooooool0Q_oo
o`00Doooo`03o`2Ioooooooo03Woool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00Dooo
o`03o`2Ioooooooo03Woool200001S?o00030000oooooooo08Koool005?oool00ol0VOooooooo`0i
oooo00<0000co`0co`001C?o00030000oooooooo08Koool005?oool00ol0VOooooooo`0ioooo00<0
000co`0co`001C?o00030000oooooooo08Koool005?oool00ol0VOooooooo`0ioooo00<0000co`0c
o`0013?o00030000oooooooo08Ooool005?oool00ol0VOooooooo`0ioooo00<0000co`0co`0013?o
00030000oooooooo08Ooool005?oool00ol0VOooooooo`0coooo0`0000?oool00`0003?o03?o0004
<ol000<0003oooooool0Qoooo`00Doooo`03o`2Ioooooooo03Coool00`000?ooooooo`02oooo00<0
000co`0co`0013?o00030000oooooooo08Ooool005?oool00ol0VOooooooo`0aoooo1@0000?oool3
000013?o00030000oooooooo08Ooool008Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?oo
o`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_oo
o`00Soooo`Lco`2:oooo001ooooo00<0003oooooool03Oooo`Lco`08oooo00<0003oooooool0Oooo
o`00O_ooo`030000oooooooo00Soool00`000?ooooooo`03oooo1c?o00Woool00`000?ooooooo`1n
oooo001noooo00<0003oooooool00_ooo`800004oooo00<0003oooooool00oooo`@co`02000000@c
o`3oooooooooool200001?ooo`030000oooooooo07koool007koool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00;oool3<ol000@0000co`0co`000009oooo00<0
003oooooool0O_ooo`00OOooo`030000oooooooo00;oool00`000?ooooooo`0:oooo0c?o00040000
<ol0<ol000002_ooo`030000oooooooo07goool007koool00`000?ooooooo`0500002Oooo`<co`00
100003?o03?o000000Woool00`000?ooooooo`1noooo001noooo00D0003oooooooooool000003?oo
o`<co`00100003?o03?o000000Woool00`000?ooooooo`1noooo001ooooo00<0003oooooool03Ooo
o`@co`02000000<co`3oooooool01_ooo`030000oooooooo07ooool008ooool7<ol0R_ooo`00Sooo
o`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.25127 .12361 L
.25666 .12361 L
.26171 .12361 L
.26425 .12361 L
.26498 .12361 L
.26568 .12361 L
s
.26568 .12361 m
.2662 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003o09Wo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000o`2Ioooo
03Woool00`0003?o03?o000i<ol02@0003Coool00`000?ooooooo`0Eoooo001Doooo00?o09Wooooo
ool0>?ooo`030000<ol0<ol003<co`060000EOooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o
03?o000a<ol00P0005_oool005Coool00ol0VOooooooo`0hoooo00<0000co`0co`00;c?o0080001M
oooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol002`co`030000Goooo`00E?ooo`03o`2I
oooooooo03Soool20000:S?o00<0001Roooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol0
02Lco`020000IOooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o000V<ol000<0003ooooo
ool0IOooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o000U<ol000<0003oooooool0I_oo
o`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o000T<ol000<0003oooooool0Ioooo`00E?oo
o`03o`2Ioooooooo03Soool00`0003?o03?o000R<ol00P0006[oool005Coool00ol0VOooooooo`0h
oooo0P00028co`000`000?ooooooo`1Zoooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol0
020co`000`000?ooooooo`1[oooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol001lco`00
0`000?ooooooo`1/oooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol001lco`000`000?oo
ooooo`1/oooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol001hco`000`000?ooooooo`1]
oooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol001dco`000`000?ooooooo`1^oooo001D
oooo00?o09Woooooool0>?ooo`80000M<ol000<0003oooooool0Koooo`00E?ooo`03o`2Ioooooooo
03Soool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00E?ooo`03o`2Ioooooooo03Soool0
0`0003?o03?o000K<ol000<0003oooooool0L?ooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o
03?o000J<ol000<0003oooooool0LOooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o000J
<ol000<0003oooooool0LOooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o000I<ol000<0
003oooooool0L_ooo`00E?ooo`03o`2Ioooooooo03Soool200006S?o00030000oooooooo07;oool0
05Coool00ol0VOooooooo`0hoooo00<0000co`0co`0063?o00030000oooooooo07?oool005Coool0
0ol0VOooooooo`0hoooo00<0000co`0co`0063?o00030000oooooooo07?oool005Coool00ol0VOoo
ooooo`0hoooo00<0000co`0co`005c?o00030000oooooooo07Coool005Coool00ol0VOooooooo`0h
oooo00<0000co`0co`005c?o00030000oooooooo07Coool005Coool00ol0VOooooooo`0`oooo1@00
00?oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00E?ooo`03o`2Ioooooooo03;oool0
0`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo07Goool005Coool00ol0VOoo
ooooo`0boooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0M_ooo`00E?ooo`03o`2I
oooooooo03;oool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo07Koool0
05Coool00ol0VOooooooo`0boooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?oo
ooooo`1foooo001Doooo00?o09Woooooool0<Oooo`800005oooo00<0000co`0co`0053?o00030000
oooooooo07Ooool005Coool00ol0VOooooooo`0hoooo00<0000co`0co`0053?o00030000oooooooo
07Ooool005Coool00ol0VOooooooo`0hoooo00<0000co`0co`004c?o00030000oooooooo07Soool0
05Coool00ol0VOooooooo`0hoooo0P0001@co`000`000?ooooooo`1hoooo001Doooo00?o09Wooooo
ool0>?ooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo001Doooo00?o09Woooooool0>?oo
o`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001Doooo00?o09Woooooool0>?ooo`030000
<ol0<ol0018co`000`000?ooooooo`1ioooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol0
018co`000`000?ooooooo`1ioooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol0014co`00
0`000?ooooooo`1joooo001Doooo00?o09Woooooool0>?ooo`80000B<ol000<0003oooooool0N_oo
o`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00E?oo
o`03o`2Ioooooooo03Soool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00E?ooo`03o`2I
oooooooo03Soool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00E?ooo`03o`2Ioooooooo
03Soool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00E?ooo`03o`2Ioooooooo03Soool0
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o
03?o000@<ol000<0003oooooool0Noooo`00E?ooo`03o`2Ioooooooo03Soool2000043?o00030000
oooooooo07coool005Coool00ol0VOooooooo`0hoooo00<0000co`0co`003c?o00030000oooooooo
07coool005Coool00ol0VOooooooo`0hoooo00<0000co`0co`003c?o00030000oooooooo07coool0
05Coool00ol0VOooooooo`0hoooo00<0000co`0co`003c?o00030000oooooooo07coool005Coool0
0ol0VOooooooo`0hoooo00<0000co`0co`003c?o00030000oooooooo07coool005Coool00ol0VOoo
ooooo`0hoooo00<0000co`0co`003S?o00030000oooooooo07goool005Coool00ol0VOooooooo`0h
oooo0P0000lco`000`000?ooooooo`1moooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol0
00hco`000`000?ooooooo`1moooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol000hco`00
0`000?ooooooo`1moooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol000dco`000`000?oo
ooooo`1noooo001Doooo00?o09Woooooool0<?ooo`@00004oooo00<0000co`0co`003C?o00030000
oooooooo07koool005Coool00ol0VOooooooo`0`oooo00<0003oooooool01Oooo`030000<ol0<ol0
00dco`000`000?ooooooo`1noooo001Doooo00?o09Woooooool0<Oooo`030000oooooooo00Coool3
00003C?o00030000oooooooo07koool005Coool00ol0VOooooooo`0boooo00<0003oooooool00ooo
o`030000<ol0<ol000dco`000`000?ooooooo`1noooo001Doooo00?o09Woooooool0<?ooo`040000
oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001Doooo00?o09Wooooo
ool0<Oooo`800005oooo00<0000co`0co`0033?o00030000oooooooo07ooool005Coool00ol0VOoo
ooooo`0hoooo00<0000co`0co`0033?o00030000oooooooo07ooool005Coool00ol0VOooooooo`0h
oooo00<0000co`0co`0033?o00030000oooooooo07ooool005Coool00ol0VOooooooo`0hoooo0P00
00dco`000`000?ooooooo`1ooooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol000`co`00
0`000?ooooooo`1ooooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol000/co`000`000?oo
ooooo`20oooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol000/co`000`000?ooooooo`20
oooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001D
oooo00?o09Woooooool0>?ooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001Doooo00?o
09Woooooool0>?ooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001Doooo00?o09Wooooo
ool0>?ooo`80000<<ol000<0003oooooool0P?ooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o000:
<ol000<0003oooooool0POooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o000:<ol000<0003ooooo
ool0POooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o000:<ol000<0003oooooool0POoo
o`00E?ooo`03o`2Ioooooooo03Soool200002c?o00030000oooooooo087oool005Coool00ol0VOoo
ooooo`0hoooo00<0000co`0co`002S?o00030000oooooooo087oool005Coool00ol0VOooooooo`0h
oooo00<0000co`0co`002S?o00030000oooooooo087oool005Coool00ol0VOooooooo`0hoooo00<0
000co`0co`002C?o00030000oooooooo08;oool005Coool00ol0VOooooooo`0hoooo00<0000co`0c
o`002C?o00030000oooooooo08;oool005Coool00ol0VOooooooo`0hoooo00<0000co`0co`002C?o
00030000oooooooo08;oool005Coool00ol0VOooooooo`0hoooo0P0000Xco`000`000?ooooooo`22
oooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001D
oooo00?o09Woooooool0>?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Doooo00?o
09Woooooool0>?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001Doooo00?o09Wooooo
ool0<Oooo`800005oooo00<0000co`0co`0023?o00030000oooooooo08?oool005Coool00ol0VOoo
ooooo`0`oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo08?oool0
05Coool00ol0VOooooooo`0boooo00<0003oooooool00oooo`<00008<ol000<0003oooooool0Pooo
o`00E?ooo`03o`2Ioooooooo03?oool00`000?ooooooo`02oooo00<0000co`0co`0023?o00030000
oooooooo08?oool005Coool00ol0VOooooooo`0`oooo00@0003oooooool00004oooo00<0000co`0c
o`0023?o00030000oooooooo08?oool005Coool00ol0VOooooooo`0aoooo0P0000Goool00`0003?o
03?o0007<ol000<0003oooooool0Q?ooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o0007<ol000<0
003oooooool0Q?ooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o0007<ol000<0003ooooo
ool0Q?ooo`00E?ooo`03o`2Ioooooooo03Soool2000023?o00030000oooooooo08Coool005Coool0
0ol0VOooooooo`0hoooo00<0000co`0co`001c?o00030000oooooooo08Coool005Coool00ol0VOoo
ooooo`0hoooo00<0000co`0co`001c?o00030000oooooooo08Coool005Coool00ol0VOooooooo`0h
oooo00<0000co`0co`001c?o00030000oooooooo08Coool005Coool00ol0VOooooooo`0hoooo00<0
000co`0co`001S?o00030000oooooooo08Goool005Coool00ol0VOooooooo`0hoooo00<0000co`0c
o`001S?o00030000oooooooo08Goool005Coool00ol0VOooooooo`0hoooo0P0000Lco`000`000?oo
ooooo`25oooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25
oooo001Doooo00?o09Woooooool0>?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001D
oooo00?o09Woooooool0>?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Doooo00?o
09Woooooool0>?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Doooo00?o09Wooooo
ool0>?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Doooo00?o09Woooooool0>?oo
o`800006<ol000<0003oooooool0Q_ooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o0005
<ol000<0003oooooool0Q_ooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o0005<ol000<0
003oooooool0Q_ooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o0005<ol000<0003oooooool0Q_oo
o`00E?ooo`03o`2Ioooooooo03Soool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00E?oo
o`03o`2Ioooooooo03Soool200001S?o00030000oooooooo08Koool005Coool00ol0VOooooooo`0h
oooo00<0000co`0co`001C?o00030000oooooooo08Koool005Coool00ol0VOooooooo`0hoooo00<0
000co`0co`001C?o00030000oooooooo08Koool005Coool00ol0VOooooooo`0hoooo00<0000co`0c
o`0013?o00030000oooooooo08Ooool005Coool00ol0VOooooooo`0hoooo00<0000co`0co`0013?o
00030000oooooooo08Ooool005Coool00ol0VOooooooo`0boooo0`0000?oool00`0003?o03?o0004
<ol000<0003oooooool0Qoooo`00E?ooo`03o`2Ioooooooo03?oool00`000?ooooooo`02oooo00<0
000co`0co`0013?o00030000oooooooo08Ooool005Coool00ol0VOooooooo`0`oooo1@0000?oool3
000013?o00030000oooooooo08Ooool008Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?oo
o`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_oo
o`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>oooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o00ooool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004<ol00P00
0004<ol0oooooooooooo0P0000?oool400000oooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`00
00Hco`02oooo00@0003oooooool00002oooo00<0003oooooool01?ooo`030000oooooooo07Soool0
07Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00001S?o00;oool0
10000?ooooooo`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000<oooo00@0003oooooool00006<ol00_ooo`040000oooooooo00001?ooo`030000
oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000
oooooooo00001S?o00;oool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007<ol00oooo`800004oooo0P0000?oool0
0`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.25127 .12361 L
.26171 .12361 L
.26698 .12361 L
.26843 .12361 L
.26922 .12361 L
.26998 .12361 L
.27068 .12361 L
s
.27068 .12361 m
.27099 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
09T02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000ooooo`2I
03Woool00`0003?o03?o000i<ol02@0003Coool00`000?ooooooo`0Eoooo001Eoooo00?o09Wooooo
ool0=oooo`030000<ol0<ol003<co`060000EOooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o
03?o000a<ol00P0005_oool005Goool00ol0VOooooooo`0goooo00<0000co`0co`00;c?o0080001M
oooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol002`co`030000Goooo`00EOooo`03o`2I
oooooooo03Ooool20000:S?o00<0001Roooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol0
02Lco`020000IOooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o000V<ol000<0003ooooo
ool0IOooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o000U<ol000<0003oooooool0I_oo
o`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o000T<ol000<0003oooooool0Ioooo`00EOoo
o`03o`2Ioooooooo03Ooool00`0003?o03?o000R<ol00P0006[oool005Goool00ol0VOooooooo`0g
oooo0P00028co`000`000?ooooooo`1Zoooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol0
020co`000`000?ooooooo`1[oooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol001lco`00
0`000?ooooooo`1/oooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol001lco`000`000?oo
ooooo`1/oooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol001hco`000`000?ooooooo`1]
oooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol001dco`000`000?ooooooo`1^oooo001E
oooo00?o09Woooooool0=oooo`80000M<ol000<0003oooooool0Koooo`00EOooo`03o`2Ioooooooo
03Ooool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00EOooo`03o`2Ioooooooo03Ooool0
0`0003?o03?o000K<ol000<0003oooooool0L?ooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o
03?o000J<ol000<0003oooooool0LOooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o000J
<ol000<0003oooooool0LOooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o000I<ol000<0
003oooooool0L_ooo`00EOooo`03o`2Ioooooooo03Ooool200006S?o00030000oooooooo07;oool0
05Goool00ol0VOooooooo`0goooo00<0000co`0co`0063?o00030000oooooooo07?oool005Goool0
0ol0VOooooooo`0goooo00<0000co`0co`0063?o00030000oooooooo07?oool005Goool00ol0VOoo
ooooo`0goooo00<0000co`0co`005c?o00030000oooooooo07Coool005Goool00ol0VOooooooo`0g
oooo00<0000co`0co`005c?o00030000oooooooo07Coool005Goool00ol0VOooooooo`0_oooo1@00
00?oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00EOooo`03o`2Ioooooooo037oool0
0`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo07Goool005Goool00ol0VOoo
ooooo`0aoooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0M_ooo`00EOooo`03o`2I
oooooooo037oool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo07Koool0
05Goool00ol0VOooooooo`0aoooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?oo
ooooo`1foooo001Eoooo00?o09Woooooool0<?ooo`800005oooo00<0000co`0co`0053?o00030000
oooooooo07Ooool005Goool00ol0VOooooooo`0goooo00<0000co`0co`0053?o00030000oooooooo
07Ooool005Goool00ol0VOooooooo`0goooo00<0000co`0co`004c?o00030000oooooooo07Soool0
05Goool00ol0VOooooooo`0goooo0P0001@co`000`000?ooooooo`1hoooo001Eoooo00?o09Wooooo
ool0=oooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo001Eoooo00?o09Woooooool0=ooo
o`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001Eoooo00?o09Woooooool0=oooo`030000
<ol0<ol0018co`000`000?ooooooo`1ioooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol0
018co`000`000?ooooooo`1ioooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol0014co`00
0`000?ooooooo`1joooo001Eoooo00?o09Woooooool0=oooo`80000B<ol000<0003oooooool0N_oo
o`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00EOoo
o`03o`2Ioooooooo03Ooool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00EOooo`03o`2I
oooooooo03Ooool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00EOooo`03o`2Ioooooooo
03Ooool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00EOooo`03o`2Ioooooooo03Ooool0
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o
03?o000@<ol000<0003oooooool0Noooo`00EOooo`03o`2Ioooooooo03Ooool2000043?o00030000
oooooooo07coool005Goool00ol0VOooooooo`0goooo00<0000co`0co`003c?o00030000oooooooo
07coool005Goool00ol0VOooooooo`0goooo00<0000co`0co`003c?o00030000oooooooo07coool0
05Goool00ol0VOooooooo`0goooo00<0000co`0co`003c?o00030000oooooooo07coool005Goool0
0ol0VOooooooo`0goooo00<0000co`0co`003c?o00030000oooooooo07coool005Goool00ol0VOoo
ooooo`0goooo00<0000co`0co`003S?o00030000oooooooo07goool005Goool00ol0VOooooooo`0g
oooo0P0000lco`000`000?ooooooo`1moooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol0
00hco`000`000?ooooooo`1moooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol000hco`00
0`000?ooooooo`1moooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol000dco`000`000?oo
ooooo`1noooo001Eoooo00?o09Woooooool0;oooo`@00004oooo00<0000co`0co`003C?o00030000
oooooooo07koool005Goool00ol0VOooooooo`0_oooo00<0003oooooool01Oooo`030000<ol0<ol0
00dco`000`000?ooooooo`1noooo001Eoooo00?o09Woooooool0<?ooo`030000oooooooo00Coool3
00003C?o00030000oooooooo07koool005Goool00ol0VOooooooo`0aoooo00<0003oooooool00ooo
o`030000<ol0<ol000dco`000`000?ooooooo`1noooo001Eoooo00?o09Woooooool0;oooo`040000
oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001Eoooo00?o09Wooooo
ool0<?ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo07ooool005Goool00ol0VOoo
ooooo`0goooo00<0000co`0co`0033?o00030000oooooooo07ooool005Goool00ol0VOooooooo`0g
oooo00<0000co`0co`0033?o00030000oooooooo07ooool005Goool00ol0VOooooooo`0goooo0P00
00dco`000`000?ooooooo`1ooooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol000`co`00
0`000?ooooooo`1ooooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol000/co`000`000?oo
ooooo`20oooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol000/co`000`000?ooooooo`20
oooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001E
oooo00?o09Woooooool0=oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001Eoooo00?o
09Woooooool0=oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001Eoooo00?o09Wooooo
ool0=oooo`80000<<ol000<0003oooooool0P?ooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o000:
<ol000<0003oooooool0POooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o000:<ol000<0003ooooo
ool0POooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o000:<ol000<0003oooooool0POoo
o`00EOooo`03o`2Ioooooooo03Ooool200002c?o00030000oooooooo087oool005Goool00ol0VOoo
ooooo`0goooo00<0000co`0co`002S?o00030000oooooooo087oool005Goool00ol0VOooooooo`0g
oooo00<0000co`0co`002S?o00030000oooooooo087oool005Goool00ol0VOooooooo`0goooo00<0
000co`0co`002C?o00030000oooooooo08;oool005Goool00ol0VOooooooo`0goooo00<0000co`0c
o`002C?o00030000oooooooo08;oool005Goool00ol0VOooooooo`0goooo00<0000co`0co`002C?o
00030000oooooooo08;oool005Goool00ol0VOooooooo`0goooo0P0000Xco`000`000?ooooooo`22
oooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001E
oooo00?o09Woooooool0=oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Eoooo00?o
09Woooooool0=oooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001Eoooo00?o09Wooooo
ool0<?ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo08?oool005Goool00ol0VOoo
ooooo`0_oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo08?oool0
05Goool00ol0VOooooooo`0aoooo00<0003oooooool00oooo`<00008<ol000<0003oooooool0Pooo
o`00EOooo`03o`2Ioooooooo03;oool00`000?ooooooo`02oooo00<0000co`0co`0023?o00030000
oooooooo08?oool005Goool00ol0VOooooooo`0_oooo00@0003oooooool00004oooo00<0000co`0c
o`0023?o00030000oooooooo08?oool005Goool00ol0VOooooooo`0`oooo0P0000Goool00`0003?o
03?o0007<ol000<0003oooooool0Q?ooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o0007<ol000<0
003oooooool0Q?ooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0Q?ooo`00EOooo`03o`2Ioooooooo03Ooool2000023?o00030000oooooooo08Coool005Goool0
0ol0VOooooooo`0goooo00<0000co`0co`001c?o00030000oooooooo08Coool005Goool00ol0VOoo
ooooo`0goooo00<0000co`0co`001c?o00030000oooooooo08Coool005Goool00ol0VOooooooo`0g
oooo00<0000co`0co`001c?o00030000oooooooo08Coool005Goool00ol0VOooooooo`0goooo00<0
000co`0co`001S?o00030000oooooooo08Goool005Goool00ol0VOooooooo`0goooo00<0000co`0c
o`001S?o00030000oooooooo08Goool005Goool00ol0VOooooooo`0goooo0P0000Lco`000`000?oo
ooooo`25oooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol000Hco`000`000?ooooooo`25
oooo001Eoooo00?o09Woooooool0=oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001E
oooo00?o09Woooooool0=oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Eoooo00?o
09Woooooool0=oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Eoooo00?o09Wooooo
ool0=oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Eoooo00?o09Woooooool0=ooo
o`800006<ol000<0003oooooool0Q_ooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o0005
<ol000<0003oooooool0Q_ooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o0005<ol000<0
003oooooool0Q_ooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o0005<ol000<0003oooooool0Q_oo
o`00EOooo`03o`2Ioooooooo03Ooool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00EOoo
o`03o`2Ioooooooo03Ooool200001S?o00030000oooooooo08Koool005Goool00ol0VOooooooo`0g
oooo00<0000co`0co`001C?o00030000oooooooo08Koool005Goool00ol0VOooooooo`0goooo00<0
000co`0co`001C?o00030000oooooooo08Koool005Goool00ol0VOooooooo`0goooo00<0000co`0c
o`0013?o00030000oooooooo08Ooool005Goool00ol0VOooooooo`0goooo00<0000co`0co`0013?o
00030000oooooooo08Ooool005Goool00ol0VOooooooo`0aoooo0`0000?oool00`0003?o03?o0004
<ol000<0003oooooool0Qoooo`00EOooo`03o`2Ioooooooo03;oool00`000?ooooooo`02oooo00<0
000co`0co`0013?o00030000oooooooo08Ooool005Goool00ol0VOooooooo`0_oooo1@0000?oool3
000013?o00030000oooooooo08Ooool008Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?oo
o`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_oo
o`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>oooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o00ooool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004<ol00P00
0004<ol0oooooooooooo0P0000Goool300000_ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`00
00Hco`02oooo00@0003oooooool00005oooo00D0003oooooooooool00000N_ooo`00Moooo`030000
oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00006<ol00_ooo`040000oooooooo
00000_ooo`D00003oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0
003oooooool00006<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00006<ol00_oo
o`040000oooooooo00000oooo`030000oooo000000?oool00`000?ooooooo`1hoooo001ioooo00<0
003oooooool04Oooo`800007<ol00oooo`800005oooo0P0000;oool00`000?ooooooo`1ioooo002?
oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.26171 .12361 L
.26709 .12361 L
.27003 .12361 L
.27279 .12361 L
.27399 .12361 L
.27513 .12361 L
s
.27513 .12361 m
.27566 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00@0003ooooo
oooo09T8oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0
003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00@0003ooooo
oooo09Thoooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Oooo`00E_ooo`03o`2I
oooooooo03Koool00`0003?o03?o000c<ol01P0005Goool005Koool00ol0VOooooooo`0foooo00<0
000co`0co`00<C?o0080001Koooo001Foooo00?o09Woooooool0=_ooo`030000<ol0<ol002lco`02
0000GOooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000/<ol00`0005ooool005Koool0
0ol0VOooooooo`0foooo0P0002Xco`030000H_ooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o
03?o000W<ol00P0006Goool005Koool00ol0VOooooooo`0foooo00<0000co`0co`009S?o00030000
oooooooo06Goool005Koool00ol0VOooooooo`0foooo00<0000co`0co`009C?o00030000oooooooo
06Koool005Koool00ol0VOooooooo`0foooo00<0000co`0co`0093?o00030000oooooooo06Ooool0
05Koool00ol0VOooooooo`0foooo00<0000co`0co`008S?o0080001Zoooo001Foooo00?o09Wooooo
ool0=_ooo`80000R<ol000<0003oooooool0J_ooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o
03?o000P<ol000<0003oooooool0Joooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000O
<ol000<0003oooooool0K?ooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000O<ol000<0
003oooooool0K?ooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000N<ol000<0003ooooo
ool0KOooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000M<ol000<0003oooooool0K_oo
o`00E_ooo`03o`2Ioooooooo03Koool200007C?o00030000oooooooo06ooool005Koool00ol0VOoo
ooooo`0foooo00<0000co`0co`006c?o00030000oooooooo073oool005Koool00ol0VOooooooo`0f
oooo00<0000co`0co`006c?o00030000oooooooo073oool005Koool00ol0VOooooooo`0foooo00<0
000co`0co`006S?o00030000oooooooo077oool005Koool00ol0VOooooooo`0foooo00<0000co`0c
o`006S?o00030000oooooooo077oool005Koool00ol0VOooooooo`0foooo00<0000co`0co`006C?o
00030000oooooooo07;oool005Koool00ol0VOooooooo`0foooo0P0001Xco`000`000?ooooooo`1b
oooo001Foooo00?o09Woooooool0=_ooo`030000<ol0<ol001Pco`000`000?ooooooo`1coooo001F
oooo00?o09Woooooool0=_ooo`030000<ol0<ol001Pco`000`000?ooooooo`1coooo001Foooo00?o
09Woooooool0=_ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001Foooo00?o09Wooooo
ool0=_ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001Foooo00?o09Woooooool0;_oo
o`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool005Koool00ol0VOooooooo`0`
oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1eoooo001Foooo00?o
09Woooooool0<?ooo`030000oooooooo00?oool300005C?o00030000oooooooo07Koool005Koool0
0ol0VOooooooo`0`oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`1f
oooo001Foooo00?o09Woooooool0<?ooo`030000oooooooo00?oool00`0003?o03?o000E<ol000<0
003oooooool0M_ooo`00E_ooo`03o`2Ioooooooo02ooool200001Oooo`030000<ol0<ol001@co`00
0`000?ooooooo`1goooo001Foooo00?o09Woooooool0=_ooo`030000<ol0<ol001@co`000`000?oo
ooooo`1goooo001Foooo00?o09Woooooool0=_ooo`030000<ol0<ol001<co`000`000?ooooooo`1h
oooo001Foooo00?o09Woooooool0=_ooo`80000D<ol000<0003oooooool0N?ooo`00E_ooo`03o`2I
oooooooo03Koool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00E_ooo`03o`2Ioooooooo
03Koool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00E_ooo`03o`2Ioooooooo03Koool0
0`0003?o03?o000B<ol000<0003oooooool0NOooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o
03?o000B<ol000<0003oooooool0NOooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00E_ooo`03o`2Ioooooooo03Koool200004S?o00030000oooooooo
07[oool005Koool00ol0VOooooooo`0foooo00<0000co`0co`004C?o00030000oooooooo07[oool0
05Koool00ol0VOooooooo`0foooo00<0000co`0co`004C?o00030000oooooooo07[oool005Koool0
0ol0VOooooooo`0foooo00<0000co`0co`0043?o00030000oooooooo07_oool005Koool00ol0VOoo
ooooo`0foooo00<0000co`0co`0043?o00030000oooooooo07_oool005Koool00ol0VOooooooo`0f
oooo00<0000co`0co`0043?o00030000oooooooo07_oool005Koool00ol0VOooooooo`0foooo00<0
000co`0co`0043?o00030000oooooooo07_oool005Koool00ol0VOooooooo`0foooo0P00010co`00
0`000?ooooooo`1loooo001Foooo00?o09Woooooool0=_ooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001Foooo00?o09Woooooool0=_ooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo001Foooo00?o09Woooooool0=_ooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo001F
oooo00?o09Woooooool0=_ooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo001Foooo00?o
09Woooooool0=_ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001Foooo00?o09Wooooo
ool0=_ooo`80000?<ol000<0003oooooool0OOooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o
03?o000><ol000<0003oooooool0OOooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000>
<ol000<0003oooooool0OOooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000=<ol000<0
003oooooool0O_ooo`00E_ooo`03o`2Ioooooooo02koool400001?ooo`030000<ol0<ol000dco`00
0`000?ooooooo`1noooo001Foooo00?o09Woooooool0;_ooo`030000oooooooo00Goool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00E_ooo`03o`2Ioooooooo02ooool00`000?ooooooo`04
oooo0`0000dco`000`000?ooooooo`1noooo001Foooo00?o09Woooooool0<?ooo`030000oooooooo
00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00E_ooo`03o`2Ioooooooo02koool0
10000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00E_ooo`03o`2I
oooooooo02ooool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001Foooo00?o
09Woooooool0=_ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001Foooo00?o09Wooooo
ool0=_ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001Foooo00?o09Woooooool0=_oo
o`80000=<ol000<0003oooooool0Ooooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000<
<ol000<0003oooooool0Ooooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00E_oo
o`03o`2Ioooooooo03Koool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00E_ooo`03o`2I
oooooooo03Koool2000033?o00030000oooooooo083oool005Koool00ol0VOooooooo`0foooo00<0
000co`0co`002c?o00030000oooooooo083oool005Koool00ol0VOooooooo`0foooo00<0000co`0c
o`002S?o00030000oooooooo087oool005Koool00ol0VOooooooo`0foooo00<0000co`0co`002S?o
00030000oooooooo087oool005Koool00ol0VOooooooo`0foooo00<0000co`0co`002S?o00030000
oooooooo087oool005Koool00ol0VOooooooo`0foooo00<0000co`0co`002S?o00030000oooooooo
087oool005Koool00ol0VOooooooo`0foooo0P0000/co`000`000?ooooooo`21oooo001Foooo00?o
09Woooooool0=_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Foooo00?o09Wooooo
ool0=_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Foooo00?o09Woooooool0=_oo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Foooo00?o09Woooooool0=_ooo`030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001Foooo00?o09Woooooool0=_ooo`030000<ol0<ol0
00Tco`000`000?ooooooo`22oooo001Foooo00?o09Woooooool0=_ooo`80000:<ol000<0003ooooo
ool0P_ooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o0009<ol000<0003oooooool0P_oo
o`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00E_oo
o`03o`2Ioooooooo03Koool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00E_ooo`03o`2I
oooooooo02ooool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001Foooo00?o
09Woooooool0;_ooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001Foooo00?o09Woooooool0<?ooo`030000oooooooo00?oool3000023?o00030000oooooooo
08?oool005Koool00ol0VOooooooo`0aoooo00<0003oooooool00_ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo001Foooo00?o09Woooooool0;_ooo`040000oooooooo00001?ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo001Foooo00?o09Woooooool0;oooo`800005oooo00<0
000co`0co`001c?o00030000oooooooo08Coool005Koool00ol0VOooooooo`0foooo00<0000co`0c
o`001c?o00030000oooooooo08Coool005Koool00ol0VOooooooo`0foooo00<0000co`0co`001c?o
00030000oooooooo08Coool005Koool00ol0VOooooooo`0foooo00<0000co`0co`001c?o00030000
oooooooo08Coool005Koool00ol0VOooooooo`0foooo0P0000Pco`000`000?ooooooo`24oooo001F
oooo00?o09Woooooool0=_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Foooo00?o
09Woooooool0=_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Foooo00?o09Wooooo
ool0=_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Foooo00?o09Woooooool0=_oo
o`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Foooo00?o09Woooooool0=_ooo`030000
<ol0<ol000Hco`000`000?ooooooo`25oooo001Foooo00?o09Woooooool0=_ooo`800007<ol000<0
003oooooool0QOooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00E_ooo`03o`2Ioooooooo03Koool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00E_oo
o`03o`2Ioooooooo03Koool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00E_ooo`03o`2I
oooooooo03Koool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00E_ooo`03o`2Ioooooooo
03Koool200001S?o00030000oooooooo08Koool005Koool00ol0VOooooooo`0foooo00<0000co`0c
o`001C?o00030000oooooooo08Koool005Koool00ol0VOooooooo`0foooo00<0000co`0co`001C?o
00030000oooooooo08Koool005Koool00ol0VOooooooo`0foooo00<0000co`0co`001C?o00030000
oooooooo08Koool005Koool00ol0VOooooooo`0foooo00<0000co`0co`001C?o00030000oooooooo
08Koool005Koool00ol0VOooooooo`0foooo00<0000co`0co`001C?o00030000oooooooo08Koool0
05Koool00ol0VOooooooo`0foooo0P0000Hco`000`000?ooooooo`26oooo001Foooo00?o09Wooooo
ool0=_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Foooo00?o09Woooooool0=_oo
o`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Foooo00?o09Woooooool0=_ooo`030000
<ol0<ol000@co`000`000?ooooooo`27oooo001Foooo00?o09Woooooool0=_ooo`030000<ol0<ol0
00@co`000`000?ooooooo`27oooo001Foooo00?o09Woooooool0<?ooo`<00003oooo00<0000co`0c
o`0013?o00030000oooooooo08Ooool005Koool00ol0VOooooooo`0aoooo00<0003oooooool00_oo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Foooo00?o09Woooooool0;_ooo`D00003
oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004oooo1c?o08[oool0
08Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o
08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?oooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool2000013?o
0080000013?o0?ooooooooooo`800003oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003ooooo
ool00006<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00001S?o
00;oool010000?ooooooo`0000;oool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001h
oooo00<0003oooooool01@0000coool010000?ooooooo`0000Hco`02oooo00@0003oooooool00002
oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000
oooooooo00001S?o00;oool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo017oool200001c?o00?oool200001?ooo`<00002oooo00<0
003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.26171 .12361 L
.26709 .12361 L
.27279 .12361 L
.27765 .12361 L
.27899 .12361 L
.27972 .12361 L
.28042 .12361 L
s
.28042 .12361 m
.28068 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00D0003ooooo
oooooooo09T01oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_oo
o`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`050000
ooooooooooooo`2I03Ooool00`0003?o03?o000i<ol02@0003Coool00`000?ooooooo`0Eoooo001G
oooo00?o09Woooooool0=Oooo`030000<ol0<ol003<co`060000EOooo`00Eoooo`03o`2Ioooooooo
03Goool00`0003?o03?o000a<ol00P0005_oool005Ooool00ol0VOooooooo`0eoooo00<0000co`0c
o`00;c?o0080001Moooo001Goooo00?o09Woooooool0=Oooo`030000<ol0<ol002`co`030000Gooo
o`00Eoooo`03o`2Ioooooooo03Goool20000:S?o00<0001Roooo001Goooo00?o09Woooooool0=Ooo
o`030000<ol0<ol002Lco`020000IOooo`00Eoooo`03o`2Ioooooooo03Goool00`0003?o03?o000V
<ol000<0003oooooool0IOooo`00Eoooo`03o`2Ioooooooo03Goool00`0003?o03?o000U<ol000<0
003oooooool0I_ooo`00Eoooo`03o`2Ioooooooo03Goool00`0003?o03?o000T<ol000<0003ooooo
ool0Ioooo`00Eoooo`03o`2Ioooooooo03Goool00`0003?o03?o000R<ol00P0006[oool005Ooool0
0ol0VOooooooo`0eoooo0P00028co`000`000?ooooooo`1Zoooo001Goooo00?o09Woooooool0=Ooo
o`030000<ol0<ol0020co`000`000?ooooooo`1[oooo001Goooo00?o09Woooooool0=Oooo`030000
<ol0<ol001lco`000`000?ooooooo`1/oooo001Goooo00?o09Woooooool0=Oooo`030000<ol0<ol0
01lco`000`000?ooooooo`1/oooo001Goooo00?o09Woooooool0=Oooo`030000<ol0<ol001hco`00
0`000?ooooooo`1]oooo001Goooo00?o09Woooooool0=Oooo`030000<ol0<ol001dco`000`000?oo
ooooo`1^oooo001Goooo00?o09Woooooool0=Oooo`80000M<ol000<0003oooooool0Koooo`00Eooo
o`03o`2Ioooooooo03Goool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00Eoooo`03o`2I
oooooooo03Goool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00Eoooo`03o`2Ioooooooo
03Goool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00Eoooo`03o`2Ioooooooo03Goool0
0`0003?o03?o000J<ol000<0003oooooool0LOooo`00Eoooo`03o`2Ioooooooo03Goool00`0003?o
03?o000I<ol000<0003oooooool0L_ooo`00Eoooo`03o`2Ioooooooo03Goool200006S?o00030000
oooooooo07;oool005Ooool00ol0VOooooooo`0eoooo00<0000co`0co`0063?o00030000oooooooo
07?oool005Ooool00ol0VOooooooo`0eoooo00<0000co`0co`0063?o00030000oooooooo07?oool0
05Ooool00ol0VOooooooo`0eoooo00<0000co`0co`005c?o00030000oooooooo07Coool005Ooool0
0ol0VOooooooo`0eoooo00<0000co`0co`005c?o00030000oooooooo07Coool005Ooool00ol0VOoo
ooooo`0]oooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00Eoooo`03o`2I
oooooooo02ooool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo07Goool0
05Ooool00ol0VOooooooo`0_oooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0M_oo
o`00Eoooo`03o`2Ioooooooo02ooool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000
oooooooo07Koool005Ooool00ol0VOooooooo`0_oooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`1foooo001Goooo00?o09Woooooool0;_ooo`800005oooo00<0000co`0c
o`0053?o00030000oooooooo07Ooool005Ooool00ol0VOooooooo`0eoooo00<0000co`0co`0053?o
00030000oooooooo07Ooool005Ooool00ol0VOooooooo`0eoooo00<0000co`0co`004c?o00030000
oooooooo07Soool005Ooool00ol0VOooooooo`0eoooo0P0001@co`000`000?ooooooo`1hoooo001G
oooo00?o09Woooooool0=Oooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo001Goooo00?o
09Woooooool0=Oooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001Goooo00?o09Wooooo
ool0=Oooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001Goooo00?o09Woooooool0=Ooo
o`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001Goooo00?o09Woooooool0=Oooo`030000
<ol0<ol0014co`000`000?ooooooo`1joooo001Goooo00?o09Woooooool0=Oooo`80000B<ol000<0
003oooooool0N_ooo`00Eoooo`03o`2Ioooooooo03Goool00`0003?o03?o000A<ol000<0003ooooo
ool0N_ooo`00Eoooo`03o`2Ioooooooo03Goool00`0003?o03?o000A<ol000<0003oooooool0N_oo
o`00Eoooo`03o`2Ioooooooo03Goool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Eooo
o`03o`2Ioooooooo03Goool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Eoooo`03o`2I
oooooooo03Goool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Eoooo`03o`2Ioooooooo
03Goool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Eoooo`03o`2Ioooooooo03Goool2
000043?o00030000oooooooo07coool005Ooool00ol0VOooooooo`0eoooo00<0000co`0co`003c?o
00030000oooooooo07coool005Ooool00ol0VOooooooo`0eoooo00<0000co`0co`003c?o00030000
oooooooo07coool005Ooool00ol0VOooooooo`0eoooo00<0000co`0co`003c?o00030000oooooooo
07coool005Ooool00ol0VOooooooo`0eoooo00<0000co`0co`003c?o00030000oooooooo07coool0
05Ooool00ol0VOooooooo`0eoooo00<0000co`0co`003S?o00030000oooooooo07goool005Ooool0
0ol0VOooooooo`0eoooo0P0000lco`000`000?ooooooo`1moooo001Goooo00?o09Woooooool0=Ooo
o`030000<ol0<ol000hco`000`000?ooooooo`1moooo001Goooo00?o09Woooooool0=Oooo`030000
<ol0<ol000hco`000`000?ooooooo`1moooo001Goooo00?o09Woooooool0=Oooo`030000<ol0<ol0
00dco`000`000?ooooooo`1noooo001Goooo00?o09Woooooool0;Oooo`@00004oooo00<0000co`0c
o`003C?o00030000oooooooo07koool005Ooool00ol0VOooooooo`0]oooo00<0003oooooool01Ooo
o`030000<ol0<ol000dco`000`000?ooooooo`1noooo001Goooo00?o09Woooooool0;_ooo`030000
oooooooo00Coool300003C?o00030000oooooooo07koool005Ooool00ol0VOooooooo`0_oooo00<0
003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo001Goooo00?o09Wooooo
ool0;Oooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001G
oooo00?o09Woooooool0;_ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo07ooool0
05Ooool00ol0VOooooooo`0eoooo00<0000co`0co`0033?o00030000oooooooo07ooool005Ooool0
0ol0VOooooooo`0eoooo00<0000co`0co`0033?o00030000oooooooo07ooool005Ooool00ol0VOoo
ooooo`0eoooo0P0000dco`000`000?ooooooo`1ooooo001Goooo00?o09Woooooool0=Oooo`030000
<ol0<ol000`co`000`000?ooooooo`1ooooo001Goooo00?o09Woooooool0=Oooo`030000<ol0<ol0
00/co`000`000?ooooooo`20oooo001Goooo00?o09Woooooool0=Oooo`030000<ol0<ol000/co`00
0`000?ooooooo`20oooo001Goooo00?o09Woooooool0=Oooo`030000<ol0<ol000/co`000`000?oo
ooooo`20oooo001Goooo00?o09Woooooool0=Oooo`030000<ol0<ol000/co`000`000?ooooooo`20
oooo001Goooo00?o09Woooooool0=Oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001G
oooo00?o09Woooooool0=Oooo`80000<<ol000<0003oooooool0P?ooo`00Eoooo`03o`2Ioooooooo
03Goool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00Eoooo`03o`2Ioooooooo03Goool0
0`0003?o03?o000:<ol000<0003oooooool0POooo`00Eoooo`03o`2Ioooooooo03Goool00`0003?o
03?o000:<ol000<0003oooooool0POooo`00Eoooo`03o`2Ioooooooo03Goool00`0003?o03?o000:
<ol000<0003oooooool0POooo`00Eoooo`03o`2Ioooooooo03Goool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00Eoooo`03o`2Ioooooooo03Goool200002c?o00030000oooooooo087oool0
05Ooool00ol0VOooooooo`0eoooo00<0000co`0co`002S?o00030000oooooooo087oool005Ooool0
0ol0VOooooooo`0eoooo00<0000co`0co`002S?o00030000oooooooo087oool005Ooool00ol0VOoo
ooooo`0eoooo00<0000co`0co`002C?o00030000oooooooo08;oool005Ooool00ol0VOooooooo`0e
oooo00<0000co`0co`002C?o00030000oooooooo08;oool005Ooool00ol0VOooooooo`0eoooo00<0
000co`0co`002C?o00030000oooooooo08;oool005Ooool00ol0VOooooooo`0eoooo0P0000Xco`00
0`000?ooooooo`22oooo001Goooo00?o09Woooooool0=Oooo`030000<ol0<ol000Tco`000`000?oo
ooooo`22oooo001Goooo00?o09Woooooool0=Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22
oooo001Goooo00?o09Woooooool0=Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001G
oooo00?o09Woooooool0;_ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo08?oool0
05Ooool00ol0VOooooooo`0]oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000
oooooooo08?oool005Ooool00ol0VOooooooo`0_oooo00<0003oooooool00oooo`<00008<ol000<0
003oooooool0Poooo`00Eoooo`03o`2Ioooooooo033oool00`000?ooooooo`02oooo00<0000co`0c
o`0023?o00030000oooooooo08?oool005Ooool00ol0VOooooooo`0]oooo00@0003oooooool00004
oooo00<0000co`0co`0023?o00030000oooooooo08?oool005Ooool00ol0VOooooooo`0^oooo0P00
00Goool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00Eoooo`03o`2Ioooooooo03Goool0
0`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00Eoooo`03o`2Ioooooooo03Goool00`0003?o
03?o0007<ol000<0003oooooool0Q?ooo`00Eoooo`03o`2Ioooooooo03Goool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00Eoooo`03o`2Ioooooooo03Goool2000023?o00030000oooooooo
08Coool005Ooool00ol0VOooooooo`0eoooo00<0000co`0co`001c?o00030000oooooooo08Coool0
05Ooool00ol0VOooooooo`0eoooo00<0000co`0co`001c?o00030000oooooooo08Coool005Ooool0
0ol0VOooooooo`0eoooo00<0000co`0co`001c?o00030000oooooooo08Coool005Ooool00ol0VOoo
ooooo`0eoooo00<0000co`0co`001S?o00030000oooooooo08Goool005Ooool00ol0VOooooooo`0e
oooo00<0000co`0co`001S?o00030000oooooooo08Goool005Ooool00ol0VOooooooo`0eoooo0P00
00Lco`000`000?ooooooo`25oooo001Goooo00?o09Woooooool0=Oooo`030000<ol0<ol000Hco`00
0`000?ooooooo`25oooo001Goooo00?o09Woooooool0=Oooo`030000<ol0<ol000Hco`000`000?oo
ooooo`25oooo001Goooo00?o09Woooooool0=Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25
oooo001Goooo00?o09Woooooool0=Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001G
oooo00?o09Woooooool0=Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Goooo00?o
09Woooooool0=Oooo`800006<ol000<0003oooooool0Q_ooo`00Eoooo`03o`2Ioooooooo03Goool0
0`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00Eoooo`03o`2Ioooooooo03Goool00`0003?o
03?o0005<ol000<0003oooooool0Q_ooo`00Eoooo`03o`2Ioooooooo03Goool00`0003?o03?o0005
<ol000<0003oooooool0Q_ooo`00Eoooo`03o`2Ioooooooo03Goool00`0003?o03?o0005<ol000<0
003oooooool0Q_ooo`00Eoooo`03o`2Ioooooooo03Goool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00Eoooo`03o`2Ioooooooo03Goool200001S?o00030000oooooooo08Koool005Ooool0
0ol0VOooooooo`0eoooo00<0000co`0co`001C?o00030000oooooooo08Koool005Ooool00ol0VOoo
ooooo`0eoooo00<0000co`0co`001C?o00030000oooooooo08Koool005Ooool00ol0VOooooooo`0e
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool005Ooool00ol0VOooooooo`0eoooo00<0
000co`0co`0013?o00030000oooooooo08Ooool005Ooool00ol0VOooooooo`0_oooo0`0000?oool0
0`0003?o03?o0004<ol000<0003oooooool0Qoooo`00Eoooo`03o`2Ioooooooo033oool00`000?oo
ooooo`02oooo00<0000co`0co`0013?o00030000oooooooo08Ooool005Ooool00ol0VOooooooo`0]
oooo1@0000?oool3000013?o00030000oooooooo08Ooool008Ooool010000?ooooooo`0000Coool7
<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool0
08ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>oooo00<0
003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o00ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004<ol00P000004<ol0oooooooooooo0P0000Coool200001?ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
10000?ooooooo`0000Hco`02oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003ooooo
ool00006<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00001S?o00;oool010000?oo
ooooo`0000?oool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?
oooo00@0003oooooool00006<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`03oooo0P0000Coool2
00000oooo`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.27731 .12361 L
.28025 .12361 L
.28302 .12361 L
.28425 .12361 L
.28542 .12361 L
s
.28542 .12361 m
.28567 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool00oooo`03o`2Ioooooooo00?oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`03oooo00?o09Woooooool0<oooo`030000<ol0<ol003Tco`090000=?oo
o`030000oooooooo01Goool005Woool00ol0VOooooooo`0coooo00<0000co`0co`00<c?o00H0001E
oooo001Ioooo00?o09Woooooool0<oooo`030000<ol0<ol0034co`020000Foooo`00FOooo`03o`2I
oooooooo03?oool00`0003?o03?o000_<ol00P0005goool005Woool00ol0VOooooooo`0coooo00<0
000co`0co`00;3?o00<0001Ooooo001Ioooo00?o09Woooooool0<oooo`80000Z<ol00`0006;oool0
05Woool00ol0VOooooooo`0coooo00<0000co`0co`009c?o0080001Uoooo001Ioooo00?o09Wooooo
ool0<oooo`030000<ol0<ol002Hco`000`000?ooooooo`1Uoooo001Ioooo00?o09Woooooool0<ooo
o`030000<ol0<ol002Dco`000`000?ooooooo`1Voooo001Ioooo00?o09Woooooool0<oooo`030000
<ol0<ol002@co`000`000?ooooooo`1Woooo001Ioooo00?o09Woooooool0<oooo`030000<ol0<ol0
028co`020000J_ooo`00FOooo`03o`2Ioooooooo03?oool200008S?o00030000oooooooo06[oool0
05Woool00ol0VOooooooo`0coooo00<0000co`0co`0083?o00030000oooooooo06_oool005Woool0
0ol0VOooooooo`0coooo00<0000co`0co`007c?o00030000oooooooo06coool005Woool00ol0VOoo
ooooo`0coooo00<0000co`0co`007c?o00030000oooooooo06coool005Woool00ol0VOooooooo`0c
oooo00<0000co`0co`007S?o00030000oooooooo06goool005Woool00ol0VOooooooo`0coooo00<0
000co`0co`007C?o00030000oooooooo06koool005Woool00ol0VOooooooo`0coooo0P0001dco`00
0`000?ooooooo`1_oooo001Ioooo00?o09Woooooool0<oooo`030000<ol0<ol001/co`000`000?oo
ooooo`1`oooo001Ioooo00?o09Woooooool0<oooo`030000<ol0<ol001/co`000`000?ooooooo`1`
oooo001Ioooo00?o09Woooooool0<oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001I
oooo00?o09Woooooool0<oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001Ioooo00?o
09Woooooool0<oooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo001Ioooo00?o09Wooooo
ool0<oooo`80000J<ol000<0003oooooool0L_ooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o
03?o000H<ol000<0003oooooool0Loooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o000H
<ol000<0003oooooool0Loooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o000G<ol000<0
003oooooool0M?ooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o000G<ol000<0003ooooo
ool0M?ooo`00FOooo`03o`2Ioooooooo02_oool500000oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001Ioooo00?o09Woooooool0;Oooo`030000oooooooo00?oool00`0003?o03?o000F
<ol000<0003oooooool0MOooo`00FOooo`03o`2Ioooooooo02goool00`000?ooooooo`03oooo0`00
01Dco`000`000?ooooooo`1foooo001Ioooo00?o09Woooooool0;Oooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00FOooo`03o`2Ioooooooo02goool00`000?oo
ooooo`03oooo00<0000co`0co`005C?o00030000oooooooo07Koool005Woool00ol0VOooooooo`0/
oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00FOooo`03o`2Ioooooooo
03?oool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00FOooo`03o`2Ioooooooo03?oool0
0`0003?o03?o000C<ol000<0003oooooool0N?ooo`00FOooo`03o`2Ioooooooo03?oool2000053?o
00030000oooooooo07Soool005Woool00ol0VOooooooo`0coooo00<0000co`0co`004c?o00030000
oooooooo07Soool005Woool00ol0VOooooooo`0coooo00<0000co`0co`004S?o00030000oooooooo
07Woool005Woool00ol0VOooooooo`0coooo00<0000co`0co`004S?o00030000oooooooo07Woool0
05Woool00ol0VOooooooo`0coooo00<0000co`0co`004S?o00030000oooooooo07Woool005Woool0
0ol0VOooooooo`0coooo00<0000co`0co`004C?o00030000oooooooo07[oool005Woool00ol0VOoo
ooooo`0coooo0P00018co`000`000?ooooooo`1joooo001Ioooo00?o09Woooooool0<oooo`030000
<ol0<ol0014co`000`000?ooooooo`1joooo001Ioooo00?o09Woooooool0<oooo`030000<ol0<ol0
014co`000`000?ooooooo`1joooo001Ioooo00?o09Woooooool0<oooo`030000<ol0<ol0010co`00
0`000?ooooooo`1koooo001Ioooo00?o09Woooooool0<oooo`030000<ol0<ol0010co`000`000?oo
ooooo`1koooo001Ioooo00?o09Woooooool0<oooo`030000<ol0<ol0010co`000`000?ooooooo`1k
oooo001Ioooo00?o09Woooooool0<oooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo001I
oooo00?o09Woooooool0<oooo`80000@<ol000<0003oooooool0O?ooo`00FOooo`03o`2Ioooooooo
03?oool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00FOooo`03o`2Ioooooooo03?oool0
0`0003?o03?o000?<ol000<0003oooooool0O?ooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o
03?o000?<ol000<0003oooooool0O?ooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o000?
<ol000<0003oooooool0O?ooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o000><ol000<0
003oooooool0OOooo`00FOooo`03o`2Ioooooooo03?oool200003c?o00030000oooooooo07goool0
05Woool00ol0VOooooooo`0coooo00<0000co`0co`003S?o00030000oooooooo07goool005Woool0
0ol0VOooooooo`0coooo00<0000co`0co`003S?o00030000oooooooo07goool005Woool00ol0VOoo
ooooo`0coooo00<0000co`0co`003C?o00030000oooooooo07koool005Woool00ol0VOooooooo`0[
oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00FOooo`03o`2Ioooooooo
02_oool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo07koool005Woool0
0ol0VOooooooo`0/oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0O_ooo`00FOoo
o`03o`2Ioooooooo02goool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo
07koool005Woool00ol0VOooooooo`0[oooo00@0003oooooool00004oooo00<0000co`0co`0033?o
00030000oooooooo07ooool005Woool00ol0VOooooooo`0/oooo0P0000Goool00`0003?o03?o000<
<ol000<0003oooooool0Ooooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o000<<ol000<0
003oooooool0Ooooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00FOooo`03o`2Ioooooooo03?oool200003C?o00030000oooooooo07ooool005Woool0
0ol0VOooooooo`0coooo00<0000co`0co`0033?o00030000oooooooo07ooool005Woool00ol0VOoo
ooooo`0coooo00<0000co`0co`002c?o00030000oooooooo083oool005Woool00ol0VOooooooo`0c
oooo00<0000co`0co`002c?o00030000oooooooo083oool005Woool00ol0VOooooooo`0coooo00<0
000co`0co`002c?o00030000oooooooo083oool005Woool00ol0VOooooooo`0coooo00<0000co`0c
o`002c?o00030000oooooooo083oool005Woool00ol0VOooooooo`0coooo00<0000co`0co`002c?o
00030000oooooooo083oool005Woool00ol0VOooooooo`0coooo0P0000`co`000`000?ooooooo`20
oooo001Ioooo00?o09Woooooool0<oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001I
oooo00?o09Woooooool0<oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Ioooo00?o
09Woooooool0<oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Ioooo00?o09Wooooo
ool0<oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Ioooo00?o09Woooooool0<ooo
o`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Ioooo00?o09Woooooool0<oooo`80000;
<ol000<0003oooooool0POooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o000:<ol000<0003ooooo
ool0POooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o0009<ol000<0003oooooool0P_oo
o`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00FOoo
o`03o`2Ioooooooo03?oool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00FOooo`03o`2I
oooooooo03?oool200002S?o00030000oooooooo08;oool005Woool00ol0VOooooooo`0coooo00<0
000co`0co`002C?o00030000oooooooo08;oool005Woool00ol0VOooooooo`0coooo00<0000co`0c
o`002C?o00030000oooooooo08;oool005Woool00ol0VOooooooo`0coooo00<0000co`0co`0023?o
00030000oooooooo08?oool005Woool00ol0VOooooooo`0/oooo0P0000Goool00`0003?o03?o0008
<ol000<0003oooooool0Poooo`00FOooo`03o`2Ioooooooo02_oool010000?ooooooo`0000Coool0
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00FOooo`03o`2Ioooooooo02goool00`000?oo
ooooo`03oooo0`0000Pco`000`000?ooooooo`23oooo001Ioooo00?o09Woooooool0;_ooo`030000
oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00FOooo`03o`2Ioooooooo
02_oool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00FOoo
o`03o`2Ioooooooo02coool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001I
oooo00?o09Woooooool0<oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Ioooo00?o
09Woooooool0<oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Ioooo00?o09Wooooo
ool0<oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Ioooo00?o09Woooooool0<ooo
o`800008<ol000<0003oooooool0Q?ooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o0007<ol000<0
003oooooool0Q?ooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o0007<ol000<0003ooooo
ool0Q?ooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00FOoo
o`03o`2Ioooooooo03?oool200001c?o00030000oooooooo08Goool005Woool00ol0VOooooooo`0c
oooo00<0000co`0co`001S?o00030000oooooooo08Goool005Woool00ol0VOooooooo`0coooo00<0
000co`0co`001S?o00030000oooooooo08Goool005Woool00ol0VOooooooo`0coooo00<0000co`0c
o`001S?o00030000oooooooo08Goool005Woool00ol0VOooooooo`0coooo00<0000co`0co`001S?o
00030000oooooooo08Goool005Woool00ol0VOooooooo`0coooo00<0000co`0co`001S?o00030000
oooooooo08Goool005Woool00ol0VOooooooo`0coooo0P0000Hco`000`000?ooooooo`26oooo001I
oooo00?o09Woooooool0<oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Ioooo00?o
09Woooooool0<oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Ioooo00?o09Wooooo
ool0<oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Ioooo00?o09Woooooool0<ooo
o`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Ioooo00?o09Woooooool0<oooo`030000
<ol0<ol000Dco`000`000?ooooooo`26oooo001Ioooo00?o09Woooooool0<oooo`800006<ol000<0
003oooooool0Q_ooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o0005<ol000<0003oooooool0Q_oo
o`00FOooo`03o`2Ioooooooo03?oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00FOoo
o`03o`2Ioooooooo03?oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00FOooo`03o`2I
oooooooo02goool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Ioooo00?o
09Woooooool0;_ooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0Qooo
o`00FOooo`03o`2Ioooooooo02_oool500000oooo`<00004<ol000<0003oooooool0Qoooo`00Qooo
o`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029
oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007coool00`000?oo
ooooo`0@oooo1c?o00_oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000
oooooooo00Koool7<ol03?ooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo00<co`000000000013?o00800003oooo1@0000;oool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0000co`0co`000003<ol01oooo`030000oooooooo00;oool00`000?ooooooo`1k
oooo001joooo00<0003oooooool00_ooo`030000oooooooo00goool0100003?o03?o000000<co`07
oooo00<0003oooooool00oooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003?oo
o`040000<ol0<ol000000c?o00Ooool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Nooo
o`050000oooooooooooo000000ooool0100003?o03?o000000<co`07oooo00<0003oooooool00_oo
o`030000oooooooo07_oool007coool00`000?ooooooo`0@oooo00<co`000000000013?o00Koool2
00000oooo`030000oooooooo07coool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.27731 .12361 L
.28302 .12361 L
.28542 .12361 L
.288 .12361 L
.28876 .12361 L
.28948 .12361 L
.29013 .12361 L
s
.29013 .12361 m
.29041 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool01?ooo`03o`2Ioooooooo00;oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`04oooo00?o09Woooooool0<_ooo`030000<ol0<ol003Tco`090000=?oo
o`030000oooooooo01Goool005[oool00ol0VOooooooo`0boooo00<0000co`0co`00<c?o00H0001E
oooo001Joooo00?o09Woooooool0<_ooo`030000<ol0<ol0034co`020000Foooo`00F_ooo`03o`2I
oooooooo03;oool00`0003?o03?o000_<ol00P0005goool005[oool00ol0VOooooooo`0boooo00<0
000co`0co`00;3?o00<0001Ooooo001Joooo00?o09Woooooool0<_ooo`80000Z<ol00`0006;oool0
05[oool00ol0VOooooooo`0boooo00<0000co`0co`009c?o0080001Uoooo001Joooo00?o09Wooooo
ool0<_ooo`030000<ol0<ol002Hco`000`000?ooooooo`1Uoooo001Joooo00?o09Woooooool0<_oo
o`030000<ol0<ol002Dco`000`000?ooooooo`1Voooo001Joooo00?o09Woooooool0<_ooo`030000
<ol0<ol002@co`000`000?ooooooo`1Woooo001Joooo00?o09Woooooool0<_ooo`030000<ol0<ol0
028co`020000J_ooo`00F_ooo`03o`2Ioooooooo03;oool200008S?o00030000oooooooo06[oool0
05[oool00ol0VOooooooo`0boooo00<0000co`0co`0083?o00030000oooooooo06_oool005[oool0
0ol0VOooooooo`0boooo00<0000co`0co`007c?o00030000oooooooo06coool005[oool00ol0VOoo
ooooo`0boooo00<0000co`0co`007c?o00030000oooooooo06coool005[oool00ol0VOooooooo`0b
oooo00<0000co`0co`007S?o00030000oooooooo06goool005[oool00ol0VOooooooo`0boooo00<0
000co`0co`007C?o00030000oooooooo06koool005[oool00ol0VOooooooo`0boooo0P0001dco`00
0`000?ooooooo`1_oooo001Joooo00?o09Woooooool0<_ooo`030000<ol0<ol001/co`000`000?oo
ooooo`1`oooo001Joooo00?o09Woooooool0<_ooo`030000<ol0<ol001/co`000`000?ooooooo`1`
oooo001Joooo00?o09Woooooool0<_ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001J
oooo00?o09Woooooool0<_ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001Joooo00?o
09Woooooool0<_ooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo001Joooo00?o09Wooooo
ool0<_ooo`80000J<ol000<0003oooooool0L_ooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o
03?o000H<ol000<0003oooooool0Loooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o000H
<ol000<0003oooooool0Loooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o000G<ol000<0
003oooooool0M?ooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o000G<ol000<0003ooooo
ool0M?ooo`00F_ooo`03o`2Ioooooooo02[oool500000oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001Joooo00?o09Woooooool0;?ooo`030000oooooooo00?oool00`0003?o03?o000F
<ol000<0003oooooool0MOooo`00F_ooo`03o`2Ioooooooo02coool00`000?ooooooo`03oooo0`00
01Dco`000`000?ooooooo`1foooo001Joooo00?o09Woooooool0;?ooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00F_ooo`03o`2Ioooooooo02coool00`000?oo
ooooo`03oooo00<0000co`0co`005C?o00030000oooooooo07Koool005[oool00ol0VOooooooo`0[
oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00F_ooo`03o`2Ioooooooo
03;oool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00F_ooo`03o`2Ioooooooo03;oool0
0`0003?o03?o000C<ol000<0003oooooool0N?ooo`00F_ooo`03o`2Ioooooooo03;oool2000053?o
00030000oooooooo07Soool005[oool00ol0VOooooooo`0boooo00<0000co`0co`004c?o00030000
oooooooo07Soool005[oool00ol0VOooooooo`0boooo00<0000co`0co`004S?o00030000oooooooo
07Woool005[oool00ol0VOooooooo`0boooo00<0000co`0co`004S?o00030000oooooooo07Woool0
05[oool00ol0VOooooooo`0boooo00<0000co`0co`004S?o00030000oooooooo07Woool005[oool0
0ol0VOooooooo`0boooo00<0000co`0co`004C?o00030000oooooooo07[oool005[oool00ol0VOoo
ooooo`0boooo0P00018co`000`000?ooooooo`1joooo001Joooo00?o09Woooooool0<_ooo`030000
<ol0<ol0014co`000`000?ooooooo`1joooo001Joooo00?o09Woooooool0<_ooo`030000<ol0<ol0
014co`000`000?ooooooo`1joooo001Joooo00?o09Woooooool0<_ooo`030000<ol0<ol0010co`00
0`000?ooooooo`1koooo001Joooo00?o09Woooooool0<_ooo`030000<ol0<ol0010co`000`000?oo
ooooo`1koooo001Joooo00?o09Woooooool0<_ooo`030000<ol0<ol0010co`000`000?ooooooo`1k
oooo001Joooo00?o09Woooooool0<_ooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo001J
oooo00?o09Woooooool0<_ooo`80000@<ol000<0003oooooool0O?ooo`00F_ooo`03o`2Ioooooooo
03;oool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00F_ooo`03o`2Ioooooooo03;oool0
0`0003?o03?o000?<ol000<0003oooooool0O?ooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o
03?o000?<ol000<0003oooooool0O?ooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o000?
<ol000<0003oooooool0O?ooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o000><ol000<0
003oooooool0OOooo`00F_ooo`03o`2Ioooooooo03;oool200003c?o00030000oooooooo07goool0
05[oool00ol0VOooooooo`0boooo00<0000co`0co`003S?o00030000oooooooo07goool005[oool0
0ol0VOooooooo`0boooo00<0000co`0co`003S?o00030000oooooooo07goool005[oool00ol0VOoo
ooooo`0boooo00<0000co`0co`003C?o00030000oooooooo07koool005[oool00ol0VOooooooo`0Z
oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00F_ooo`03o`2Ioooooooo
02[oool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo07koool005[oool0
0ol0VOooooooo`0[oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0O_ooo`00F_oo
o`03o`2Ioooooooo02coool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo
07koool005[oool00ol0VOooooooo`0Zoooo00@0003oooooool00004oooo00<0000co`0co`0033?o
00030000oooooooo07ooool005[oool00ol0VOooooooo`0[oooo0P0000Goool00`0003?o03?o000<
<ol000<0003oooooool0Ooooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o000<<ol000<0
003oooooool0Ooooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00F_ooo`03o`2Ioooooooo03;oool200003C?o00030000oooooooo07ooool005[oool0
0ol0VOooooooo`0boooo00<0000co`0co`0033?o00030000oooooooo07ooool005[oool00ol0VOoo
ooooo`0boooo00<0000co`0co`002c?o00030000oooooooo083oool005[oool00ol0VOooooooo`0b
oooo00<0000co`0co`002c?o00030000oooooooo083oool005[oool00ol0VOooooooo`0boooo00<0
000co`0co`002c?o00030000oooooooo083oool005[oool00ol0VOooooooo`0boooo00<0000co`0c
o`002c?o00030000oooooooo083oool005[oool00ol0VOooooooo`0boooo00<0000co`0co`002c?o
00030000oooooooo083oool005[oool00ol0VOooooooo`0boooo0P0000`co`000`000?ooooooo`20
oooo001Joooo00?o09Woooooool0<_ooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001J
oooo00?o09Woooooool0<_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Joooo00?o
09Woooooool0<_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Joooo00?o09Wooooo
ool0<_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Joooo00?o09Woooooool0<_oo
o`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Joooo00?o09Woooooool0<_ooo`80000;
<ol000<0003oooooool0POooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o000:<ol000<0003ooooo
ool0POooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o0009<ol000<0003oooooool0P_oo
o`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00F_oo
o`03o`2Ioooooooo03;oool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00F_ooo`03o`2I
oooooooo03;oool200002S?o00030000oooooooo08;oool005[oool00ol0VOooooooo`0boooo00<0
000co`0co`002C?o00030000oooooooo08;oool005[oool00ol0VOooooooo`0boooo00<0000co`0c
o`002C?o00030000oooooooo08;oool005[oool00ol0VOooooooo`0boooo00<0000co`0co`0023?o
00030000oooooooo08?oool005[oool00ol0VOooooooo`0[oooo0P0000Goool00`0003?o03?o0008
<ol000<0003oooooool0Poooo`00F_ooo`03o`2Ioooooooo02[oool010000?ooooooo`0000Coool0
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00F_ooo`03o`2Ioooooooo02coool00`000?oo
ooooo`03oooo0`0000Pco`000`000?ooooooo`23oooo001Joooo00?o09Woooooool0;Oooo`030000
oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00F_ooo`03o`2Ioooooooo
02[oool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00F_oo
o`03o`2Ioooooooo02_oool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001J
oooo00?o09Woooooool0<_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Joooo00?o
09Woooooool0<_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Joooo00?o09Wooooo
ool0<_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Joooo00?o09Woooooool0<_oo
o`800008<ol000<0003oooooool0Q?ooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o0007<ol000<0
003oooooool0Q?ooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o0007<ol000<0003ooooo
ool0Q?ooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00F_oo
o`03o`2Ioooooooo03;oool200001c?o00030000oooooooo08Goool005[oool00ol0VOooooooo`0b
oooo00<0000co`0co`001S?o00030000oooooooo08Goool005[oool00ol0VOooooooo`0boooo00<0
000co`0co`001S?o00030000oooooooo08Goool005[oool00ol0VOooooooo`0boooo00<0000co`0c
o`001S?o00030000oooooooo08Goool005[oool00ol0VOooooooo`0boooo00<0000co`0co`001S?o
00030000oooooooo08Goool005[oool00ol0VOooooooo`0boooo00<0000co`0co`001S?o00030000
oooooooo08Goool005[oool00ol0VOooooooo`0boooo0P0000Hco`000`000?ooooooo`26oooo001J
oooo00?o09Woooooool0<_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Joooo00?o
09Woooooool0<_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Joooo00?o09Wooooo
ool0<_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Joooo00?o09Woooooool0<_oo
o`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Joooo00?o09Woooooool0<_ooo`030000
<ol0<ol000Dco`000`000?ooooooo`26oooo001Joooo00?o09Woooooool0<_ooo`800006<ol000<0
003oooooool0Q_ooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o0005<ol000<0003oooooool0Q_oo
o`00F_ooo`03o`2Ioooooooo03;oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00F_oo
o`03o`2Ioooooooo03;oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00F_ooo`03o`2I
oooooooo02coool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Joooo00?o
09Woooooool0;Oooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0Qooo
o`00F_ooo`03o`2Ioooooooo02[oool500000oooo`<00004<ol000<0003oooooool0Qoooo`00Qooo
o`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029
oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?oo
ooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000@co`02000000<co`3oooooool01@000003oooo00000000
00800003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00001S?o00Coool01@000?oooooooooo
o`000006oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=
oooo00@0003oooooool00006<ol01?ooo`030000oooooooo00;oool00`000?ooooooo`04oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00006<ol01?oo
o`030000oooooooo00?oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000ooool010000?ooooooo`0000Hco`04oooo00D0003oooooooooool000000_oo
o`050000oooooooooooo000007[oool007Woool00`000?ooooooo`0Aoooo0P0000Lco`03oooo0P00
00Coool200000oooo`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.28302 .12361 L
.2881 .12361 L
.29088 .12361 L
.29224 .12361 L
.29349 .12361 L
.29462 .12361 L
s
.29462 .12361 m
.29506 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool01Oooo`05o`2Ioooooooooooo000000_oool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_oo
o`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000
oooooooo00Goool00ol0VOooooooo`0aoooo00<0000co`0co`00>C?o00T0000doooo00<0003ooooo
ool05Oooo`00Foooo`03o`2Ioooooooo037oool00`0003?o03?o000c<ol01P0005Goool005_oool0
0ol0VOooooooo`0aoooo00<0000co`0co`00<C?o0080001Koooo001Koooo00?o09Woooooool0<Ooo
o`030000<ol0<ol002lco`020000GOooo`00Foooo`03o`2Ioooooooo037oool00`0003?o03?o000/
<ol00`0005ooool005_oool00ol0VOooooooo`0aoooo0P0002Xco`030000H_ooo`00Foooo`03o`2I
oooooooo037oool00`0003?o03?o000W<ol00P0006Goool005_oool00ol0VOooooooo`0aoooo00<0
000co`0co`009S?o00030000oooooooo06Goool005_oool00ol0VOooooooo`0aoooo00<0000co`0c
o`009C?o00030000oooooooo06Koool005_oool00ol0VOooooooo`0aoooo00<0000co`0co`0093?o
00030000oooooooo06Ooool005_oool00ol0VOooooooo`0aoooo00<0000co`0co`008S?o0080001Z
oooo001Koooo00?o09Woooooool0<Oooo`80000R<ol000<0003oooooool0J_ooo`00Foooo`03o`2I
oooooooo037oool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00Foooo`03o`2Ioooooooo
037oool00`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Foooo`03o`2Ioooooooo037oool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Foooo`03o`2Ioooooooo037oool00`0003?o
03?o000N<ol000<0003oooooool0KOooo`00Foooo`03o`2Ioooooooo037oool00`0003?o03?o000M
<ol000<0003oooooool0K_ooo`00Foooo`03o`2Ioooooooo037oool200007C?o00030000oooooooo
06ooool005_oool00ol0VOooooooo`0aoooo00<0000co`0co`006c?o00030000oooooooo073oool0
05_oool00ol0VOooooooo`0aoooo00<0000co`0co`006c?o00030000oooooooo073oool005_oool0
0ol0VOooooooo`0aoooo00<0000co`0co`006S?o00030000oooooooo077oool005_oool00ol0VOoo
ooooo`0aoooo00<0000co`0co`006S?o00030000oooooooo077oool005_oool00ol0VOooooooo`0a
oooo00<0000co`0co`006C?o00030000oooooooo07;oool005_oool00ol0VOooooooo`0aoooo0P00
01Xco`000`000?ooooooo`1boooo001Koooo00?o09Woooooool0<Oooo`030000<ol0<ol001Pco`00
0`000?ooooooo`1coooo001Koooo00?o09Woooooool0<Oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001Koooo00?o09Woooooool0<Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1d
oooo001Koooo00?o09Woooooool0<Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001K
oooo00?o09Woooooool0:Oooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool0
05_oool00ol0VOooooooo`0[oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001Koooo00?o09Woooooool0:oooo`030000oooooooo00?oool300005C?o00030000
oooooooo07Koool005_oool00ol0VOooooooo`0[oooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`1foooo001Koooo00?o09Woooooool0:oooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00Foooo`03o`2Ioooooooo02[oool200001Ooo
o`030000<ol0<ol001@co`000`000?ooooooo`1goooo001Koooo00?o09Woooooool0<Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001Koooo00?o09Woooooool0<Oooo`030000<ol0<ol0
01<co`000`000?ooooooo`1hoooo001Koooo00?o09Woooooool0<Oooo`80000D<ol000<0003ooooo
ool0N?ooo`00Foooo`03o`2Ioooooooo037oool00`0003?o03?o000C<ol000<0003oooooool0N?oo
o`00Foooo`03o`2Ioooooooo037oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Fooo
o`03o`2Ioooooooo037oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Foooo`03o`2I
oooooooo037oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Foooo`03o`2Ioooooooo
037oool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00Foooo`03o`2Ioooooooo037oool2
00004S?o00030000oooooooo07[oool005_oool00ol0VOooooooo`0aoooo00<0000co`0co`004C?o
00030000oooooooo07[oool005_oool00ol0VOooooooo`0aoooo00<0000co`0co`004C?o00030000
oooooooo07[oool005_oool00ol0VOooooooo`0aoooo00<0000co`0co`0043?o00030000oooooooo
07_oool005_oool00ol0VOooooooo`0aoooo00<0000co`0co`0043?o00030000oooooooo07_oool0
05_oool00ol0VOooooooo`0aoooo00<0000co`0co`0043?o00030000oooooooo07_oool005_oool0
0ol0VOooooooo`0aoooo00<0000co`0co`0043?o00030000oooooooo07_oool005_oool00ol0VOoo
ooooo`0aoooo0P00010co`000`000?ooooooo`1loooo001Koooo00?o09Woooooool0<Oooo`030000
<ol0<ol000lco`000`000?ooooooo`1loooo001Koooo00?o09Woooooool0<Oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001Koooo00?o09Woooooool0<Oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001Koooo00?o09Woooooool0<Oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001Koooo00?o09Woooooool0<Oooo`030000<ol0<ol000hco`000`000?ooooooo`1m
oooo001Koooo00?o09Woooooool0<Oooo`80000?<ol000<0003oooooool0OOooo`00Foooo`03o`2I
oooooooo037oool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Foooo`03o`2Ioooooooo
037oool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Foooo`03o`2Ioooooooo037oool0
0`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Foooo`03o`2Ioooooooo02Woool400001?oo
o`030000<ol0<ol000dco`000`000?ooooooo`1noooo001Koooo00?o09Woooooool0:Oooo`030000
oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Foooo`03o`2Ioooooooo
02[oool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001Koooo00?o09Wooooo
ool0:oooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Fooo
o`03o`2Ioooooooo02Woool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00Foooo`03o`2Ioooooooo02[oool200001Oooo`030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001Koooo00?o09Woooooool0<Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001Koooo00?o09Woooooool0<Oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001K
oooo00?o09Woooooool0<Oooo`80000=<ol000<0003oooooool0Ooooo`00Foooo`03o`2Ioooooooo
037oool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00Foooo`03o`2Ioooooooo037oool0
0`0003?o03?o000;<ol000<0003oooooool0P?ooo`00Foooo`03o`2Ioooooooo037oool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00Foooo`03o`2Ioooooooo037oool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00Foooo`03o`2Ioooooooo037oool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00Foooo`03o`2Ioooooooo037oool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Foooo`03o`2Ioooooooo037oool2000033?o00030000oooooooo083oool005_oool0
0ol0VOooooooo`0aoooo00<0000co`0co`002c?o00030000oooooooo083oool005_oool00ol0VOoo
ooooo`0aoooo00<0000co`0co`002S?o00030000oooooooo087oool005_oool00ol0VOooooooo`0a
oooo00<0000co`0co`002S?o00030000oooooooo087oool005_oool00ol0VOooooooo`0aoooo00<0
000co`0co`002S?o00030000oooooooo087oool005_oool00ol0VOooooooo`0aoooo00<0000co`0c
o`002S?o00030000oooooooo087oool005_oool00ol0VOooooooo`0aoooo0P0000/co`000`000?oo
ooooo`21oooo001Koooo00?o09Woooooool0<Oooo`030000<ol0<ol000Xco`000`000?ooooooo`21
oooo001Koooo00?o09Woooooool0<Oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001K
oooo00?o09Woooooool0<Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Koooo00?o
09Woooooool0<Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Koooo00?o09Wooooo
ool0<Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Koooo00?o09Woooooool0<Ooo
o`80000:<ol000<0003oooooool0P_ooo`00Foooo`03o`2Ioooooooo037oool00`0003?o03?o0009
<ol000<0003oooooool0P_ooo`00Foooo`03o`2Ioooooooo037oool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00Foooo`03o`2Ioooooooo037oool00`0003?o03?o0008<ol000<0003ooooo
ool0Poooo`00Foooo`03o`2Ioooooooo02[oool200001Oooo`030000<ol0<ol000Pco`000`000?oo
ooooo`23oooo001Koooo00?o09Woooooool0:Oooo`040000oooooooo00001?ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`23oooo001Koooo00?o09Woooooool0:oooo`030000oooooooo00?oool3
000023?o00030000oooooooo08?oool005_oool00ol0VOooooooo`0/oooo00<0003oooooool00_oo
o`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001Koooo00?o09Woooooool0:Oooo`040000
oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001Koooo00?o09Wooooo
ool0:_ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool005_oool00ol0VOoo
ooooo`0aoooo00<0000co`0co`001c?o00030000oooooooo08Coool005_oool00ol0VOooooooo`0a
oooo00<0000co`0co`001c?o00030000oooooooo08Coool005_oool00ol0VOooooooo`0aoooo00<0
000co`0co`001c?o00030000oooooooo08Coool005_oool00ol0VOooooooo`0aoooo0P0000Pco`00
0`000?ooooooo`24oooo001Koooo00?o09Woooooool0<Oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`24oooo001Koooo00?o09Woooooool0<Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001Koooo00?o09Woooooool0<Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001K
oooo00?o09Woooooool0<Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Koooo00?o
09Woooooool0<Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Koooo00?o09Wooooo
ool0<Oooo`800007<ol000<0003oooooool0QOooo`00Foooo`03o`2Ioooooooo037oool00`0003?o
03?o0006<ol000<0003oooooool0QOooo`00Foooo`03o`2Ioooooooo037oool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00Foooo`03o`2Ioooooooo037oool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00Foooo`03o`2Ioooooooo037oool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00Foooo`03o`2Ioooooooo037oool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00Foooo`03o`2Ioooooooo037oool200001S?o00030000oooooooo08Koool005_oool00ol0VOoo
ooooo`0aoooo00<0000co`0co`001C?o00030000oooooooo08Koool005_oool00ol0VOooooooo`0a
oooo00<0000co`0co`001C?o00030000oooooooo08Koool005_oool00ol0VOooooooo`0aoooo00<0
000co`0co`001C?o00030000oooooooo08Koool005_oool00ol0VOooooooo`0aoooo00<0000co`0c
o`001C?o00030000oooooooo08Koool005_oool00ol0VOooooooo`0aoooo00<0000co`0co`001C?o
00030000oooooooo08Koool005_oool00ol0VOooooooo`0aoooo0P0000Hco`000`000?ooooooo`26
oooo001Koooo00?o09Woooooool0<Oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001K
oooo00?o09Woooooool0<Oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Koooo00?o
09Woooooool0<Oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Koooo00?o09Wooooo
ool0<Oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Koooo00?o09Woooooool0:ooo
o`<00003oooo00<0000co`0co`0013?o00030000oooooooo08Ooool005_oool00ol0VOooooooo`0/
oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Koooo00?o
09Woooooool0:Oooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003ooooo
ool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?oo
o`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7
<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Ooo
o`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Ooool2000013?o008000000c?o0?ooooooo`0500000oooo`<00002oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01Oooo`040000oooooooo00001S?o00Coool00`000?ooooooo`04oooo00D0003oooooooooool0
0000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00006
<ol01?ooo`040000oooooooooooo1@0000?oool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0000coool010000?ooooooo`0000Hco`04oooo00D0003oooooooooool000000_ooo`050000
oooooooooooo000007[oool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00006
<ol01?ooo`030000oooooooo00;oool00`000?ooo`000003oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo017oool200001c?o00?oool200001Oooo`800002oooo00<0003oooooool0NOoo
o`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.28302 .12361 L
.2881 .12361 L
.29349 .12361 L
.2957 .12361 L
.29809 .12361 L
.29879 .12361 L
.29945 .12361 L
s
.29945 .12361 m
.29995 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool01_ooo`04o`2Ioooooooo00002oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0
003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003ooooo
ool01_ooo`03o`2Ioooooooo033oool00`0003?o03?o000i<ol02@0003Coool00`000?ooooooo`0E
oooo001Loooo00?o09Woooooool0<?ooo`030000<ol0<ol003<co`060000EOooo`00G?ooo`03o`2I
oooooooo033oool00`0003?o03?o000a<ol00P0005_oool005coool00ol0VOooooooo`0`oooo00<0
000co`0co`00;c?o0080001Moooo001Loooo00?o09Woooooool0<?ooo`030000<ol0<ol002`co`03
0000Goooo`00G?ooo`03o`2Ioooooooo033oool20000:S?o00<0001Roooo001Loooo00?o09Wooooo
ool0<?ooo`030000<ol0<ol002Lco`020000IOooo`00G?ooo`03o`2Ioooooooo033oool00`0003?o
03?o000V<ol000<0003oooooool0IOooo`00G?ooo`03o`2Ioooooooo033oool00`0003?o03?o000U
<ol000<0003oooooool0I_ooo`00G?ooo`03o`2Ioooooooo033oool00`0003?o03?o000T<ol000<0
003oooooool0Ioooo`00G?ooo`03o`2Ioooooooo033oool00`0003?o03?o000R<ol00P0006[oool0
05coool00ol0VOooooooo`0`oooo0P00028co`000`000?ooooooo`1Zoooo001Loooo00?o09Wooooo
ool0<?ooo`030000<ol0<ol0020co`000`000?ooooooo`1[oooo001Loooo00?o09Woooooool0<?oo
o`030000<ol0<ol001lco`000`000?ooooooo`1/oooo001Loooo00?o09Woooooool0<?ooo`030000
<ol0<ol001lco`000`000?ooooooo`1/oooo001Loooo00?o09Woooooool0<?ooo`030000<ol0<ol0
01hco`000`000?ooooooo`1]oooo001Loooo00?o09Woooooool0<?ooo`030000<ol0<ol001dco`00
0`000?ooooooo`1^oooo001Loooo00?o09Woooooool0<?ooo`80000M<ol000<0003oooooool0Kooo
o`00G?ooo`03o`2Ioooooooo033oool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00G?oo
o`03o`2Ioooooooo033oool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00G?ooo`03o`2I
oooooooo033oool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00G?ooo`03o`2Ioooooooo
033oool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00G?ooo`03o`2Ioooooooo033oool0
0`0003?o03?o000I<ol000<0003oooooool0L_ooo`00G?ooo`03o`2Ioooooooo033oool200006S?o
00030000oooooooo07;oool005coool00ol0VOooooooo`0`oooo00<0000co`0co`0063?o00030000
oooooooo07?oool005coool00ol0VOooooooo`0`oooo00<0000co`0co`0063?o00030000oooooooo
07?oool005coool00ol0VOooooooo`0`oooo00<0000co`0co`005c?o00030000oooooooo07Coool0
05coool00ol0VOooooooo`0`oooo00<0000co`0co`005c?o00030000oooooooo07Coool005coool0
0ol0VOooooooo`0Xoooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00G?oo
o`03o`2Ioooooooo02[oool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo
07Goool005coool00ol0VOooooooo`0Zoooo00<0003oooooool00oooo`<0000E<ol000<0003ooooo
ool0M_ooo`00G?ooo`03o`2Ioooooooo02[oool00`000?ooooooo`03oooo00<0000co`0co`005C?o
00030000oooooooo07Koool005coool00ol0VOooooooo`0Zoooo00<0003oooooool00oooo`030000
<ol0<ol001Dco`000`000?ooooooo`1foooo001Loooo00?o09Woooooool0:Oooo`800005oooo00<0
000co`0co`0053?o00030000oooooooo07Ooool005coool00ol0VOooooooo`0`oooo00<0000co`0c
o`0053?o00030000oooooooo07Ooool005coool00ol0VOooooooo`0`oooo00<0000co`0co`004c?o
00030000oooooooo07Soool005coool00ol0VOooooooo`0`oooo0P0001@co`000`000?ooooooo`1h
oooo001Loooo00?o09Woooooool0<?ooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo001L
oooo00?o09Woooooool0<?ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001Loooo00?o
09Woooooool0<?ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001Loooo00?o09Wooooo
ool0<?ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001Loooo00?o09Woooooool0<?oo
o`030000<ol0<ol0014co`000`000?ooooooo`1joooo001Loooo00?o09Woooooool0<?ooo`80000B
<ol000<0003oooooool0N_ooo`00G?ooo`03o`2Ioooooooo033oool00`0003?o03?o000A<ol000<0
003oooooool0N_ooo`00G?ooo`03o`2Ioooooooo033oool00`0003?o03?o000A<ol000<0003ooooo
ool0N_ooo`00G?ooo`03o`2Ioooooooo033oool00`0003?o03?o000@<ol000<0003oooooool0Nooo
o`00G?ooo`03o`2Ioooooooo033oool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00G?oo
o`03o`2Ioooooooo033oool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00G?ooo`03o`2I
oooooooo033oool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00G?ooo`03o`2Ioooooooo
033oool2000043?o00030000oooooooo07coool005coool00ol0VOooooooo`0`oooo00<0000co`0c
o`003c?o00030000oooooooo07coool005coool00ol0VOooooooo`0`oooo00<0000co`0co`003c?o
00030000oooooooo07coool005coool00ol0VOooooooo`0`oooo00<0000co`0co`003c?o00030000
oooooooo07coool005coool00ol0VOooooooo`0`oooo00<0000co`0co`003c?o00030000oooooooo
07coool005coool00ol0VOooooooo`0`oooo00<0000co`0co`003S?o00030000oooooooo07goool0
05coool00ol0VOooooooo`0`oooo0P0000lco`000`000?ooooooo`1moooo001Loooo00?o09Wooooo
ool0<?ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001Loooo00?o09Woooooool0<?oo
o`030000<ol0<ol000hco`000`000?ooooooo`1moooo001Loooo00?o09Woooooool0<?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001Loooo00?o09Woooooool0:?ooo`@00004oooo00<0
000co`0co`003C?o00030000oooooooo07koool005coool00ol0VOooooooo`0Xoooo00<0003ooooo
ool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo001Loooo00?o09Woooooool0:Ooo
o`030000oooooooo00Coool300003C?o00030000oooooooo07koool005coool00ol0VOooooooo`0Z
oooo00<0003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo001Loooo00?o
09Woooooool0:?ooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001Loooo00?o09Woooooool0:Oooo`800005oooo00<0000co`0co`0033?o00030000oooooooo
07ooool005coool00ol0VOooooooo`0`oooo00<0000co`0co`0033?o00030000oooooooo07ooool0
05coool00ol0VOooooooo`0`oooo00<0000co`0co`0033?o00030000oooooooo07ooool005coool0
0ol0VOooooooo`0`oooo0P0000dco`000`000?ooooooo`1ooooo001Loooo00?o09Woooooool0<?oo
o`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001Loooo00?o09Woooooool0<?ooo`030000
<ol0<ol000/co`000`000?ooooooo`20oooo001Loooo00?o09Woooooool0<?ooo`030000<ol0<ol0
00/co`000`000?ooooooo`20oooo001Loooo00?o09Woooooool0<?ooo`030000<ol0<ol000/co`00
0`000?ooooooo`20oooo001Loooo00?o09Woooooool0<?ooo`030000<ol0<ol000/co`000`000?oo
ooooo`20oooo001Loooo00?o09Woooooool0<?ooo`030000<ol0<ol000/co`000`000?ooooooo`20
oooo001Loooo00?o09Woooooool0<?ooo`80000<<ol000<0003oooooool0P?ooo`00G?ooo`03o`2I
oooooooo033oool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00G?ooo`03o`2Ioooooooo
033oool00`0003?o03?o000:<ol000<0003oooooool0POooo`00G?ooo`03o`2Ioooooooo033oool0
0`0003?o03?o000:<ol000<0003oooooool0POooo`00G?ooo`03o`2Ioooooooo033oool00`0003?o
03?o000:<ol000<0003oooooool0POooo`00G?ooo`03o`2Ioooooooo033oool00`0003?o03?o000:
<ol000<0003oooooool0POooo`00G?ooo`03o`2Ioooooooo033oool200002c?o00030000oooooooo
087oool005coool00ol0VOooooooo`0`oooo00<0000co`0co`002S?o00030000oooooooo087oool0
05coool00ol0VOooooooo`0`oooo00<0000co`0co`002S?o00030000oooooooo087oool005coool0
0ol0VOooooooo`0`oooo00<0000co`0co`002C?o00030000oooooooo08;oool005coool00ol0VOoo
ooooo`0`oooo00<0000co`0co`002C?o00030000oooooooo08;oool005coool00ol0VOooooooo`0`
oooo00<0000co`0co`002C?o00030000oooooooo08;oool005coool00ol0VOooooooo`0`oooo0P00
00Xco`000`000?ooooooo`22oooo001Loooo00?o09Woooooool0<?ooo`030000<ol0<ol000Tco`00
0`000?ooooooo`22oooo001Loooo00?o09Woooooool0<?ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`22oooo001Loooo00?o09Woooooool0<?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001Loooo00?o09Woooooool0:Oooo`800005oooo00<0000co`0co`0023?o00030000oooooooo
08?oool005coool00ol0VOooooooo`0Xoooo00@0003oooooool00004oooo00<0000co`0co`0023?o
00030000oooooooo08?oool005coool00ol0VOooooooo`0Zoooo00<0003oooooool00oooo`<00008
<ol000<0003oooooool0Poooo`00G?ooo`03o`2Ioooooooo02_oool00`000?ooooooo`02oooo00<0
000co`0co`0023?o00030000oooooooo08?oool005coool00ol0VOooooooo`0Xoooo00@0003ooooo
ool00004oooo00<0000co`0co`0023?o00030000oooooooo08?oool005coool00ol0VOooooooo`0Y
oooo0P0000Goool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00G?ooo`03o`2Ioooooooo
033oool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00G?ooo`03o`2Ioooooooo033oool0
0`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00G?ooo`03o`2Ioooooooo033oool00`0003?o
03?o0007<ol000<0003oooooool0Q?ooo`00G?ooo`03o`2Ioooooooo033oool2000023?o00030000
oooooooo08Coool005coool00ol0VOooooooo`0`oooo00<0000co`0co`001c?o00030000oooooooo
08Coool005coool00ol0VOooooooo`0`oooo00<0000co`0co`001c?o00030000oooooooo08Coool0
05coool00ol0VOooooooo`0`oooo00<0000co`0co`001c?o00030000oooooooo08Coool005coool0
0ol0VOooooooo`0`oooo00<0000co`0co`001S?o00030000oooooooo08Goool005coool00ol0VOoo
ooooo`0`oooo00<0000co`0co`001S?o00030000oooooooo08Goool005coool00ol0VOooooooo`0`
oooo0P0000Lco`000`000?ooooooo`25oooo001Loooo00?o09Woooooool0<?ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`25oooo001Loooo00?o09Woooooool0<?ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`25oooo001Loooo00?o09Woooooool0<?ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`25oooo001Loooo00?o09Woooooool0<?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25
oooo001Loooo00?o09Woooooool0<?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001L
oooo00?o09Woooooool0<?ooo`800006<ol000<0003oooooool0Q_ooo`00G?ooo`03o`2Ioooooooo
033oool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00G?ooo`03o`2Ioooooooo033oool0
0`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00G?ooo`03o`2Ioooooooo033oool00`0003?o
03?o0005<ol000<0003oooooool0Q_ooo`00G?ooo`03o`2Ioooooooo033oool00`0003?o03?o0005
<ol000<0003oooooool0Q_ooo`00G?ooo`03o`2Ioooooooo033oool00`0003?o03?o0005<ol000<0
003oooooool0Q_ooo`00G?ooo`03o`2Ioooooooo033oool200001S?o00030000oooooooo08Koool0
05coool00ol0VOooooooo`0`oooo00<0000co`0co`001C?o00030000oooooooo08Koool005coool0
0ol0VOooooooo`0`oooo00<0000co`0co`001C?o00030000oooooooo08Koool005coool00ol0VOoo
ooooo`0`oooo00<0000co`0co`0013?o00030000oooooooo08Ooool005coool00ol0VOooooooo`0`
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool005coool00ol0VOooooooo`0Zoooo0`00
00?oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00G?ooo`03o`2Ioooooooo02_oool0
0`000?ooooooo`02oooo00<0000co`0co`0013?o00030000oooooooo08Ooool005coool00ol0VOoo
ooooo`0Xoooo1@0000?oool3000013?o00030000oooooooo08Ooool008Ooool010000?ooooooo`00
00Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o
08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o
00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01oooo`800004<ol00P000003<ol0oooooooo00D000001?ooo`000000000000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0003oooooool00006<ol01?ooo`050000oooooooooooo000000;oool01@000?oo
ooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?oo
ooooo`0000Hco`04oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`0000Hco`04oooo00@0
003oooooooooool300001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?
oooo00@0003oooooool00006<ol01?ooo`030000oooooooo00;oool00`000?ooooooo`03oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo017oool200001c?o00?oool200001?ooo`<00002
oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.29779 .12361 L
.30059 .12361 L
.30182 .12361 L
.30316 .12361 L
.30442 .12361 L
s
.30442 .12361 m
.30489 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool01oooo`03o`2Ioooo000000_oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
00Ooool00ol0VOooooooo`0_oooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00GOooo`03o`2Ioooooooo02ooool00`0003?o03?o000c<ol01P0005Goool005goool00ol0VOoo
ooooo`0_oooo00<0000co`0co`00<C?o0080001Koooo001Moooo00?o09Woooooool0;oooo`030000
<ol0<ol002lco`020000GOooo`00GOooo`03o`2Ioooooooo02ooool00`0003?o03?o000/<ol00`00
05ooool005goool00ol0VOooooooo`0_oooo0P0002Xco`030000H_ooo`00GOooo`03o`2Ioooooooo
02ooool00`0003?o03?o000W<ol00P0006Goool005goool00ol0VOooooooo`0_oooo00<0000co`0c
o`009S?o00030000oooooooo06Goool005goool00ol0VOooooooo`0_oooo00<0000co`0co`009C?o
00030000oooooooo06Koool005goool00ol0VOooooooo`0_oooo00<0000co`0co`0093?o00030000
oooooooo06Ooool005goool00ol0VOooooooo`0_oooo00<0000co`0co`008S?o0080001Zoooo001M
oooo00?o09Woooooool0;oooo`80000R<ol000<0003oooooool0J_ooo`00GOooo`03o`2Ioooooooo
02ooool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00GOooo`03o`2Ioooooooo02ooool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00GOooo`03o`2Ioooooooo02ooool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00GOooo`03o`2Ioooooooo02ooool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00GOooo`03o`2Ioooooooo02ooool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00GOooo`03o`2Ioooooooo02ooool200007C?o00030000oooooooo06ooool0
05goool00ol0VOooooooo`0_oooo00<0000co`0co`006c?o00030000oooooooo073oool005goool0
0ol0VOooooooo`0_oooo00<0000co`0co`006c?o00030000oooooooo073oool005goool00ol0VOoo
ooooo`0_oooo00<0000co`0co`006S?o00030000oooooooo077oool005goool00ol0VOooooooo`0_
oooo00<0000co`0co`006S?o00030000oooooooo077oool005goool00ol0VOooooooo`0_oooo00<0
000co`0co`006C?o00030000oooooooo07;oool005goool00ol0VOooooooo`0_oooo0P0001Xco`00
0`000?ooooooo`1boooo001Moooo00?o09Woooooool0;oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001Moooo00?o09Woooooool0;oooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo001Moooo00?o09Woooooool0;oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001M
oooo00?o09Woooooool0;oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001Moooo00?o
09Woooooool09oooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool005goool0
0ol0VOooooooo`0Yoooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo001Moooo00?o09Woooooool0:Oooo`030000oooooooo00?oool300005C?o00030000oooooooo
07Koool005goool00ol0VOooooooo`0Yoooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1foooo001Moooo00?o09Woooooool0:Oooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00GOooo`03o`2Ioooooooo02Soool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001Moooo00?o09Woooooool0;oooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo001Moooo00?o09Woooooool0;oooo`030000<ol0<ol001<co`00
0`000?ooooooo`1hoooo001Moooo00?o09Woooooool0;oooo`80000D<ol000<0003oooooool0N?oo
o`00GOooo`03o`2Ioooooooo02ooool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00GOoo
o`03o`2Ioooooooo02ooool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00GOooo`03o`2I
oooooooo02ooool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00GOooo`03o`2Ioooooooo
02ooool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00GOooo`03o`2Ioooooooo02ooool0
0`0003?o03?o000A<ol000<0003oooooool0N_ooo`00GOooo`03o`2Ioooooooo02ooool200004S?o
00030000oooooooo07[oool005goool00ol0VOooooooo`0_oooo00<0000co`0co`004C?o00030000
oooooooo07[oool005goool00ol0VOooooooo`0_oooo00<0000co`0co`004C?o00030000oooooooo
07[oool005goool00ol0VOooooooo`0_oooo00<0000co`0co`0043?o00030000oooooooo07_oool0
05goool00ol0VOooooooo`0_oooo00<0000co`0co`0043?o00030000oooooooo07_oool005goool0
0ol0VOooooooo`0_oooo00<0000co`0co`0043?o00030000oooooooo07_oool005goool00ol0VOoo
ooooo`0_oooo00<0000co`0co`0043?o00030000oooooooo07_oool005goool00ol0VOooooooo`0_
oooo0P00010co`000`000?ooooooo`1loooo001Moooo00?o09Woooooool0;oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001Moooo00?o09Woooooool0;oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001Moooo00?o09Woooooool0;oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001Moooo00?o09Woooooool0;oooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo001Moooo00?o09Woooooool0;oooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001M
oooo00?o09Woooooool0;oooo`80000?<ol000<0003oooooool0OOooo`00GOooo`03o`2Ioooooooo
02ooool00`0003?o03?o000><ol000<0003oooooool0OOooo`00GOooo`03o`2Ioooooooo02ooool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00GOooo`03o`2Ioooooooo02ooool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00GOooo`03o`2Ioooooooo02Ooool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001Moooo00?o09Woooooool09oooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00GOooo`03o`2Ioooooooo02Soool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001Moooo00?o09Woooooool0:Ooo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00GOooo`03o`2I
oooooooo02Ooool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00GOooo`03o`2Ioooooooo02Soool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001Moooo00?o09Woooooool0;oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001M
oooo00?o09Woooooool0;oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001Moooo00?o
09Woooooool0;oooo`80000=<ol000<0003oooooool0Ooooo`00GOooo`03o`2Ioooooooo02ooool0
0`0003?o03?o000<<ol000<0003oooooool0Ooooo`00GOooo`03o`2Ioooooooo02ooool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00GOooo`03o`2Ioooooooo02ooool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00GOooo`03o`2Ioooooooo02ooool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00GOooo`03o`2Ioooooooo02ooool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00GOooo`03o`2Ioooooooo02ooool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00GOooo`03o`2Ioooooooo02ooool2000033?o00030000oooooooo083oool005goool00ol0VOoo
ooooo`0_oooo00<0000co`0co`002c?o00030000oooooooo083oool005goool00ol0VOooooooo`0_
oooo00<0000co`0co`002S?o00030000oooooooo087oool005goool00ol0VOooooooo`0_oooo00<0
000co`0co`002S?o00030000oooooooo087oool005goool00ol0VOooooooo`0_oooo00<0000co`0c
o`002S?o00030000oooooooo087oool005goool00ol0VOooooooo`0_oooo00<0000co`0co`002S?o
00030000oooooooo087oool005goool00ol0VOooooooo`0_oooo0P0000/co`000`000?ooooooo`21
oooo001Moooo00?o09Woooooool0;oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001M
oooo00?o09Woooooool0;oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Moooo00?o
09Woooooool0;oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Moooo00?o09Wooooo
ool0;oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Moooo00?o09Woooooool0;ooo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Moooo00?o09Woooooool0;oooo`80000:
<ol000<0003oooooool0P_ooo`00GOooo`03o`2Ioooooooo02ooool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00GOooo`03o`2Ioooooooo02ooool00`0003?o03?o0009<ol000<0003ooooo
ool0P_ooo`00GOooo`03o`2Ioooooooo02ooool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00GOooo`03o`2Ioooooooo02Soool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001Moooo00?o09Woooooool09oooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo001Moooo00?o09Woooooool0:Oooo`030000oooooooo00?oool3000023?o
00030000oooooooo08?oool005goool00ol0VOooooooo`0Zoooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo001Moooo00?o09Woooooool09oooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001Moooo00?o09Woooooool0:?oo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool005goool00ol0VOooooooo`0_
oooo00<0000co`0co`001c?o00030000oooooooo08Coool005goool00ol0VOooooooo`0_oooo00<0
000co`0co`001c?o00030000oooooooo08Coool005goool00ol0VOooooooo`0_oooo00<0000co`0c
o`001c?o00030000oooooooo08Coool005goool00ol0VOooooooo`0_oooo0P0000Pco`000`000?oo
ooooo`24oooo001Moooo00?o09Woooooool0;oooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001Moooo00?o09Woooooool0;oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001M
oooo00?o09Woooooool0;oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Moooo00?o
09Woooooool0;oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Moooo00?o09Wooooo
ool0;oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Moooo00?o09Woooooool0;ooo
o`800007<ol000<0003oooooool0QOooo`00GOooo`03o`2Ioooooooo02ooool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00GOooo`03o`2Ioooooooo02ooool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00GOooo`03o`2Ioooooooo02ooool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00GOooo`03o`2Ioooooooo02ooool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00GOooo`03o`2Ioooooooo02ooool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00GOoo
o`03o`2Ioooooooo02ooool200001S?o00030000oooooooo08Koool005goool00ol0VOooooooo`0_
oooo00<0000co`0co`001C?o00030000oooooooo08Koool005goool00ol0VOooooooo`0_oooo00<0
000co`0co`001C?o00030000oooooooo08Koool005goool00ol0VOooooooo`0_oooo00<0000co`0c
o`001C?o00030000oooooooo08Koool005goool00ol0VOooooooo`0_oooo00<0000co`0co`001C?o
00030000oooooooo08Koool005goool00ol0VOooooooo`0_oooo00<0000co`0co`001C?o00030000
oooooooo08Koool005goool00ol0VOooooooo`0_oooo0P0000Hco`000`000?ooooooo`26oooo001M
oooo00?o09Woooooool0;oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Moooo00?o
09Woooooool0;oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Moooo00?o09Wooooo
ool0;oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Moooo00?o09Woooooool0;ooo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Moooo00?o09Woooooool0:Oooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool005goool00ol0VOooooooo`0Zoooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Moooo00?o09Wooooo
ool09oooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool2000013?o008000000c?o0?ooooooo`0500000_ooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo00001S?o00Coool01@000?ooooooooooo`000002oooo00D0003oooooooooool0
0000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00006
<ol01?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00006<ol01?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0
003oooooool00006<ol01?ooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00001j
oooo001ioooo00<0003oooooool04Oooo`800007<ol00oooo`800004oooo0P0000?oool00`000?oo
ooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.29779 .12361 L
.30316 .12361 L
.3056 .12361 L
.30791 .12361 L
.30919 .12361 L
s
.30919 .12361 m
.30948 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
00Woool00ol0VOooooooo`0]oooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00Goooo`03o`2Ioooooooo02goool00`0003?o03?o000c<ol01P0005Goool005ooool00ol0VOoo
ooooo`0]oooo00<0000co`0co`00<C?o0080001Koooo001Ooooo00?o09Woooooool0;Oooo`030000
<ol0<ol002lco`020000GOooo`00Goooo`03o`2Ioooooooo02goool00`0003?o03?o000/<ol00`00
05ooool005ooool00ol0VOooooooo`0]oooo0P0002Xco`030000H_ooo`00Goooo`03o`2Ioooooooo
02goool00`0003?o03?o000W<ol00P0006Goool005ooool00ol0VOooooooo`0]oooo00<0000co`0c
o`009S?o00030000oooooooo06Goool005ooool00ol0VOooooooo`0]oooo00<0000co`0co`009C?o
00030000oooooooo06Koool005ooool00ol0VOooooooo`0]oooo00<0000co`0co`0093?o00030000
oooooooo06Ooool005ooool00ol0VOooooooo`0]oooo00<0000co`0co`008S?o0080001Zoooo001O
oooo00?o09Woooooool0;Oooo`80000R<ol000<0003oooooool0J_ooo`00Goooo`03o`2Ioooooooo
02goool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00Goooo`03o`2Ioooooooo02goool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Goooo`03o`2Ioooooooo02goool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00Goooo`03o`2Ioooooooo02goool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00Goooo`03o`2Ioooooooo02goool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00Goooo`03o`2Ioooooooo02goool200007C?o00030000oooooooo06ooool0
05ooool00ol0VOooooooo`0]oooo00<0000co`0co`006c?o00030000oooooooo073oool005ooool0
0ol0VOooooooo`0]oooo00<0000co`0co`006c?o00030000oooooooo073oool005ooool00ol0VOoo
ooooo`0]oooo00<0000co`0co`006S?o00030000oooooooo077oool005ooool00ol0VOooooooo`0]
oooo00<0000co`0co`006S?o00030000oooooooo077oool005ooool00ol0VOooooooo`0]oooo00<0
000co`0co`006C?o00030000oooooooo07;oool005ooool00ol0VOooooooo`0]oooo0P0001Xco`00
0`000?ooooooo`1boooo001Ooooo00?o09Woooooool0;Oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001Ooooo00?o09Woooooool0;Oooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo001Ooooo00?o09Woooooool0;Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001O
oooo00?o09Woooooool0;Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001Ooooo00?o
09Woooooool09Oooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool005ooool0
0ol0VOooooooo`0Woooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo001Ooooo00?o09Woooooool09oooo`030000oooooooo00?oool300005C?o00030000oooooooo
07Koool005ooool00ol0VOooooooo`0Woooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1foooo001Ooooo00?o09Woooooool09oooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00Goooo`03o`2Ioooooooo02Koool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001Ooooo00?o09Woooooool0;Oooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo001Ooooo00?o09Woooooool0;Oooo`030000<ol0<ol001<co`00
0`000?ooooooo`1hoooo001Ooooo00?o09Woooooool0;Oooo`80000D<ol000<0003oooooool0N?oo
o`00Goooo`03o`2Ioooooooo02goool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00Gooo
o`03o`2Ioooooooo02goool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Goooo`03o`2I
oooooooo02goool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Goooo`03o`2Ioooooooo
02goool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Goooo`03o`2Ioooooooo02goool0
0`0003?o03?o000A<ol000<0003oooooool0N_ooo`00Goooo`03o`2Ioooooooo02goool200004S?o
00030000oooooooo07[oool005ooool00ol0VOooooooo`0]oooo00<0000co`0co`004C?o00030000
oooooooo07[oool005ooool00ol0VOooooooo`0]oooo00<0000co`0co`004C?o00030000oooooooo
07[oool005ooool00ol0VOooooooo`0]oooo00<0000co`0co`0043?o00030000oooooooo07_oool0
05ooool00ol0VOooooooo`0]oooo00<0000co`0co`0043?o00030000oooooooo07_oool005ooool0
0ol0VOooooooo`0]oooo00<0000co`0co`0043?o00030000oooooooo07_oool005ooool00ol0VOoo
ooooo`0]oooo00<0000co`0co`0043?o00030000oooooooo07_oool005ooool00ol0VOooooooo`0]
oooo0P00010co`000`000?ooooooo`1loooo001Ooooo00?o09Woooooool0;Oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001Ooooo00?o09Woooooool0;Oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001Ooooo00?o09Woooooool0;Oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001Ooooo00?o09Woooooool0;Oooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo001Ooooo00?o09Woooooool0;Oooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001O
oooo00?o09Woooooool0;Oooo`80000?<ol000<0003oooooool0OOooo`00Goooo`03o`2Ioooooooo
02goool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Goooo`03o`2Ioooooooo02goool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00Goooo`03o`2Ioooooooo02goool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00Goooo`03o`2Ioooooooo02Goool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001Ooooo00?o09Woooooool09Oooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Goooo`03o`2Ioooooooo02Koool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001Ooooo00?o09Woooooool09ooo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Goooo`03o`2I
oooooooo02Goool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00Goooo`03o`2Ioooooooo02Koool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001Ooooo00?o09Woooooool0;Oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001O
oooo00?o09Woooooool0;Oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001Ooooo00?o
09Woooooool0;Oooo`80000=<ol000<0003oooooool0Ooooo`00Goooo`03o`2Ioooooooo02goool0
0`0003?o03?o000<<ol000<0003oooooool0Ooooo`00Goooo`03o`2Ioooooooo02goool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00Goooo`03o`2Ioooooooo02goool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00Goooo`03o`2Ioooooooo02goool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00Goooo`03o`2Ioooooooo02goool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Goooo`03o`2Ioooooooo02goool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00Goooo`03o`2Ioooooooo02goool2000033?o00030000oooooooo083oool005ooool00ol0VOoo
ooooo`0]oooo00<0000co`0co`002c?o00030000oooooooo083oool005ooool00ol0VOooooooo`0]
oooo00<0000co`0co`002S?o00030000oooooooo087oool005ooool00ol0VOooooooo`0]oooo00<0
000co`0co`002S?o00030000oooooooo087oool005ooool00ol0VOooooooo`0]oooo00<0000co`0c
o`002S?o00030000oooooooo087oool005ooool00ol0VOooooooo`0]oooo00<0000co`0co`002S?o
00030000oooooooo087oool005ooool00ol0VOooooooo`0]oooo0P0000/co`000`000?ooooooo`21
oooo001Ooooo00?o09Woooooool0;Oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001O
oooo00?o09Woooooool0;Oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Ooooo00?o
09Woooooool0;Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Ooooo00?o09Wooooo
ool0;Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Ooooo00?o09Woooooool0;Ooo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Ooooo00?o09Woooooool0;Oooo`80000:
<ol000<0003oooooool0P_ooo`00Goooo`03o`2Ioooooooo02goool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00Goooo`03o`2Ioooooooo02goool00`0003?o03?o0009<ol000<0003ooooo
ool0P_ooo`00Goooo`03o`2Ioooooooo02goool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00Goooo`03o`2Ioooooooo02Koool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001Ooooo00?o09Woooooool09Oooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo001Ooooo00?o09Woooooool09oooo`030000oooooooo00?oool3000023?o
00030000oooooooo08?oool005ooool00ol0VOooooooo`0Xoooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo001Ooooo00?o09Woooooool09Oooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001Ooooo00?o09Woooooool09_oo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool005ooool00ol0VOooooooo`0]
oooo00<0000co`0co`001c?o00030000oooooooo08Coool005ooool00ol0VOooooooo`0]oooo00<0
000co`0co`001c?o00030000oooooooo08Coool005ooool00ol0VOooooooo`0]oooo00<0000co`0c
o`001c?o00030000oooooooo08Coool005ooool00ol0VOooooooo`0]oooo0P0000Pco`000`000?oo
ooooo`24oooo001Ooooo00?o09Woooooool0;Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001Ooooo00?o09Woooooool0;Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001O
oooo00?o09Woooooool0;Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Ooooo00?o
09Woooooool0;Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Ooooo00?o09Wooooo
ool0;Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Ooooo00?o09Woooooool0;Ooo
o`800007<ol000<0003oooooool0QOooo`00Goooo`03o`2Ioooooooo02goool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00Goooo`03o`2Ioooooooo02goool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00Goooo`03o`2Ioooooooo02goool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00Goooo`03o`2Ioooooooo02goool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00Goooo`03o`2Ioooooooo02goool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00Gooo
o`03o`2Ioooooooo02goool200001S?o00030000oooooooo08Koool005ooool00ol0VOooooooo`0]
oooo00<0000co`0co`001C?o00030000oooooooo08Koool005ooool00ol0VOooooooo`0]oooo00<0
000co`0co`001C?o00030000oooooooo08Koool005ooool00ol0VOooooooo`0]oooo00<0000co`0c
o`001C?o00030000oooooooo08Koool005ooool00ol0VOooooooo`0]oooo00<0000co`0co`001C?o
00030000oooooooo08Koool005ooool00ol0VOooooooo`0]oooo00<0000co`0co`001C?o00030000
oooooooo08Koool005ooool00ol0VOooooooo`0]oooo0P0000Hco`000`000?ooooooo`26oooo001O
oooo00?o09Woooooool0;Oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Ooooo00?o
09Woooooool0;Oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Ooooo00?o09Wooooo
ool0;Oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Ooooo00?o09Woooooool0;Ooo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Ooooo00?o09Woooooool09oooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool005ooool00ol0VOooooooo`0Xoooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Ooooo00?o09Wooooo
ool09Oooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00O?ooo`030000oooooooo013oool7<ol02ooo
o`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool01_ooo`Lco`0<
oooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Koool00c?o000000000004<ol00P0000?oool400000oooo`030000oooooooo07_oool007_oool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0100003?o
03?o000000<co`05oooo00<0003oooooool01?ooo`030000oooooooo07_oool007[oool00`000?oo
ooooo`02oooo00<0003oooooool03Oooo`040000<ol0<ol000000c?o00Koool00`000?ooooooo`04
oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<oooo00@0000co`0co`000003
<ol01oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool0
00003oooo`040000<ol0<ol000000c?o00Goool010000?ooooooo`0000?oool00`000?ooooooo`1k
oooo001loooo00<0003oooooool04?ooo`03<ol00000000000@co`06oooo0P0000?oool00`000?oo
ooooo`1loooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.30316 .12361 L
.30791 .12361 L
.31054 .12361 L
.31183 .12361 L
.31304 .12361 L
.31371 .12361 L
s
.31371 .12361 m
.314 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000o`2Ioooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
00[oool00ol0VOooooooo`0/oooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00H?ooo`03o`2Ioooooooo02coool00`0003?o03?o000c<ol01P0005Goool0063oool00ol0VOoo
ooooo`0/oooo00<0000co`0co`00<C?o0080001Koooo001Poooo00?o09Woooooool0;?ooo`030000
<ol0<ol002lco`020000GOooo`00H?ooo`03o`2Ioooooooo02coool00`0003?o03?o000/<ol00`00
05ooool0063oool00ol0VOooooooo`0/oooo0P0002Xco`030000H_ooo`00H?ooo`03o`2Ioooooooo
02coool00`0003?o03?o000W<ol00P0006Goool0063oool00ol0VOooooooo`0/oooo00<0000co`0c
o`009S?o00030000oooooooo06Goool0063oool00ol0VOooooooo`0/oooo00<0000co`0co`009C?o
00030000oooooooo06Koool0063oool00ol0VOooooooo`0/oooo00<0000co`0co`0093?o00030000
oooooooo06Ooool0063oool00ol0VOooooooo`0/oooo00<0000co`0co`008S?o0080001Zoooo001P
oooo00?o09Woooooool0;?ooo`80000R<ol000<0003oooooool0J_ooo`00H?ooo`03o`2Ioooooooo
02coool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00H?ooo`03o`2Ioooooooo02coool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00H?ooo`03o`2Ioooooooo02coool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00H?ooo`03o`2Ioooooooo02coool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00H?ooo`03o`2Ioooooooo02coool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00H?ooo`03o`2Ioooooooo02coool200007C?o00030000oooooooo06ooool0
063oool00ol0VOooooooo`0/oooo00<0000co`0co`006c?o00030000oooooooo073oool0063oool0
0ol0VOooooooo`0/oooo00<0000co`0co`006c?o00030000oooooooo073oool0063oool00ol0VOoo
ooooo`0/oooo00<0000co`0co`006S?o00030000oooooooo077oool0063oool00ol0VOooooooo`0/
oooo00<0000co`0co`006S?o00030000oooooooo077oool0063oool00ol0VOooooooo`0/oooo00<0
000co`0co`006C?o00030000oooooooo07;oool0063oool00ol0VOooooooo`0/oooo0P0001Xco`00
0`000?ooooooo`1boooo001Poooo00?o09Woooooool0;?ooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001Poooo00?o09Woooooool0;?ooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo001Poooo00?o09Woooooool0;?ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001P
oooo00?o09Woooooool0;?ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001Poooo00?o
09Woooooool09?ooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool0063oool0
0ol0VOooooooo`0Voooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo001Poooo00?o09Woooooool09_ooo`030000oooooooo00?oool300005C?o00030000oooooooo
07Koool0063oool00ol0VOooooooo`0Voooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1foooo001Poooo00?o09Woooooool09_ooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00H?ooo`03o`2Ioooooooo02Goool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001Poooo00?o09Woooooool0;?ooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo001Poooo00?o09Woooooool0;?ooo`030000<ol0<ol001<co`00
0`000?ooooooo`1hoooo001Poooo00?o09Woooooool0;?ooo`80000D<ol000<0003oooooool0N?oo
o`00H?ooo`03o`2Ioooooooo02coool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00H?oo
o`03o`2Ioooooooo02coool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00H?ooo`03o`2I
oooooooo02coool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00H?ooo`03o`2Ioooooooo
02coool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00H?ooo`03o`2Ioooooooo02coool0
0`0003?o03?o000A<ol000<0003oooooool0N_ooo`00H?ooo`03o`2Ioooooooo02coool200004S?o
00030000oooooooo07[oool0063oool00ol0VOooooooo`0/oooo00<0000co`0co`004C?o00030000
oooooooo07[oool0063oool00ol0VOooooooo`0/oooo00<0000co`0co`004C?o00030000oooooooo
07[oool0063oool00ol0VOooooooo`0/oooo00<0000co`0co`0043?o00030000oooooooo07_oool0
063oool00ol0VOooooooo`0/oooo00<0000co`0co`0043?o00030000oooooooo07_oool0063oool0
0ol0VOooooooo`0/oooo00<0000co`0co`0043?o00030000oooooooo07_oool0063oool00ol0VOoo
ooooo`0/oooo00<0000co`0co`0043?o00030000oooooooo07_oool0063oool00ol0VOooooooo`0/
oooo0P00010co`000`000?ooooooo`1loooo001Poooo00?o09Woooooool0;?ooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001Poooo00?o09Woooooool0;?ooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001Poooo00?o09Woooooool0;?ooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001Poooo00?o09Woooooool0;?ooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo001Poooo00?o09Woooooool0;?ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001P
oooo00?o09Woooooool0;?ooo`80000?<ol000<0003oooooool0OOooo`00H?ooo`03o`2Ioooooooo
02coool00`0003?o03?o000><ol000<0003oooooool0OOooo`00H?ooo`03o`2Ioooooooo02coool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00H?ooo`03o`2Ioooooooo02coool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00H?ooo`03o`2Ioooooooo02Coool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001Poooo00?o09Woooooool09?ooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00H?ooo`03o`2Ioooooooo02Goool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001Poooo00?o09Woooooool09_oo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00H?ooo`03o`2I
oooooooo02Coool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00H?ooo`03o`2Ioooooooo02Goool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001Poooo00?o09Woooooool0;?ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001P
oooo00?o09Woooooool0;?ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001Poooo00?o
09Woooooool0;?ooo`80000=<ol000<0003oooooool0Ooooo`00H?ooo`03o`2Ioooooooo02coool0
0`0003?o03?o000<<ol000<0003oooooool0Ooooo`00H?ooo`03o`2Ioooooooo02coool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00H?ooo`03o`2Ioooooooo02coool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00H?ooo`03o`2Ioooooooo02coool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00H?ooo`03o`2Ioooooooo02coool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00H?ooo`03o`2Ioooooooo02coool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00H?ooo`03o`2Ioooooooo02coool2000033?o00030000oooooooo083oool0063oool00ol0VOoo
ooooo`0/oooo00<0000co`0co`002c?o00030000oooooooo083oool0063oool00ol0VOooooooo`0/
oooo00<0000co`0co`002S?o00030000oooooooo087oool0063oool00ol0VOooooooo`0/oooo00<0
000co`0co`002S?o00030000oooooooo087oool0063oool00ol0VOooooooo`0/oooo00<0000co`0c
o`002S?o00030000oooooooo087oool0063oool00ol0VOooooooo`0/oooo00<0000co`0co`002S?o
00030000oooooooo087oool0063oool00ol0VOooooooo`0/oooo0P0000/co`000`000?ooooooo`21
oooo001Poooo00?o09Woooooool0;?ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001P
oooo00?o09Woooooool0;?ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Poooo00?o
09Woooooool0;?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Poooo00?o09Wooooo
ool0;?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Poooo00?o09Woooooool0;?oo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Poooo00?o09Woooooool0;?ooo`80000:
<ol000<0003oooooool0P_ooo`00H?ooo`03o`2Ioooooooo02coool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00H?ooo`03o`2Ioooooooo02coool00`0003?o03?o0009<ol000<0003ooooo
ool0P_ooo`00H?ooo`03o`2Ioooooooo02coool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00H?ooo`03o`2Ioooooooo02Goool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001Poooo00?o09Woooooool09?ooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo001Poooo00?o09Woooooool09_ooo`030000oooooooo00?oool3000023?o
00030000oooooooo08?oool0063oool00ol0VOooooooo`0Woooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo001Poooo00?o09Woooooool09?ooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001Poooo00?o09Woooooool09Ooo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool0063oool00ol0VOooooooo`0/
oooo00<0000co`0co`001c?o00030000oooooooo08Coool0063oool00ol0VOooooooo`0/oooo00<0
000co`0co`001c?o00030000oooooooo08Coool0063oool00ol0VOooooooo`0/oooo00<0000co`0c
o`001c?o00030000oooooooo08Coool0063oool00ol0VOooooooo`0/oooo0P0000Pco`000`000?oo
ooooo`24oooo001Poooo00?o09Woooooool0;?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001Poooo00?o09Woooooool0;?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001P
oooo00?o09Woooooool0;?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Poooo00?o
09Woooooool0;?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Poooo00?o09Wooooo
ool0;?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Poooo00?o09Woooooool0;?oo
o`800007<ol000<0003oooooool0QOooo`00H?ooo`03o`2Ioooooooo02coool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00H?ooo`03o`2Ioooooooo02coool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00H?ooo`03o`2Ioooooooo02coool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00H?ooo`03o`2Ioooooooo02coool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00H?ooo`03o`2Ioooooooo02coool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00H?oo
o`03o`2Ioooooooo02coool200001S?o00030000oooooooo08Koool0063oool00ol0VOooooooo`0/
oooo00<0000co`0co`001C?o00030000oooooooo08Koool0063oool00ol0VOooooooo`0/oooo00<0
000co`0co`001C?o00030000oooooooo08Koool0063oool00ol0VOooooooo`0/oooo00<0000co`0c
o`001C?o00030000oooooooo08Koool0063oool00ol0VOooooooo`0/oooo00<0000co`0co`001C?o
00030000oooooooo08Koool0063oool00ol0VOooooooo`0/oooo00<0000co`0co`001C?o00030000
oooooooo08Koool0063oool00ol0VOooooooo`0/oooo0P0000Hco`000`000?ooooooo`26oooo001P
oooo00?o09Woooooool0;?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Poooo00?o
09Woooooool0;?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Poooo00?o09Wooooo
ool0;?ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Poooo00?o09Woooooool0;?oo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Poooo00?o09Woooooool09_ooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool0063oool00ol0VOooooooo`0Woooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Poooo00?o09Wooooo
ool09?ooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool2000013?o008000000c?o0?ooooooo`0400000_ooo`@00003oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo00001S?o00;oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000
oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo
00001S?o00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500003?ooo`040000oooooooo00001S?o00Coool00`000?ooooooo`03
oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?
oooo00@0003oooooool00006<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`03oooo0P0000Coool2
00000oooo`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.30316 .12361 L
.31304 .12361 L
.31574 .12361 L
.31723 .12361 L
.31797 .12361 L
.31865 .12361 L
s
.31865 .12361 m
.31918 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000ooooo`2I00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
00_oool00ol0VOooooooo`0[oooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00HOooo`03o`2Ioooooooo02_oool00`0003?o03?o000c<ol01P0005Goool0067oool00ol0VOoo
ooooo`0[oooo00<0000co`0co`00<C?o0080001Koooo001Qoooo00?o09Woooooool0:oooo`030000
<ol0<ol002lco`020000GOooo`00HOooo`03o`2Ioooooooo02_oool00`0003?o03?o000/<ol00`00
05ooool0067oool00ol0VOooooooo`0[oooo0P0002Xco`030000H_ooo`00HOooo`03o`2Ioooooooo
02_oool00`0003?o03?o000W<ol00P0006Goool0067oool00ol0VOooooooo`0[oooo00<0000co`0c
o`009S?o00030000oooooooo06Goool0067oool00ol0VOooooooo`0[oooo00<0000co`0co`009C?o
00030000oooooooo06Koool0067oool00ol0VOooooooo`0[oooo00<0000co`0co`0093?o00030000
oooooooo06Ooool0067oool00ol0VOooooooo`0[oooo00<0000co`0co`008S?o0080001Zoooo001Q
oooo00?o09Woooooool0:oooo`80000R<ol000<0003oooooool0J_ooo`00HOooo`03o`2Ioooooooo
02_oool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00HOooo`03o`2Ioooooooo02_oool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00HOooo`03o`2Ioooooooo02_oool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00HOooo`03o`2Ioooooooo02_oool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00HOooo`03o`2Ioooooooo02_oool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00HOooo`03o`2Ioooooooo02_oool200007C?o00030000oooooooo06ooool0
067oool00ol0VOooooooo`0[oooo00<0000co`0co`006c?o00030000oooooooo073oool0067oool0
0ol0VOooooooo`0[oooo00<0000co`0co`006c?o00030000oooooooo073oool0067oool00ol0VOoo
ooooo`0[oooo00<0000co`0co`006S?o00030000oooooooo077oool0067oool00ol0VOooooooo`0[
oooo00<0000co`0co`006S?o00030000oooooooo077oool0067oool00ol0VOooooooo`0[oooo00<0
000co`0co`006C?o00030000oooooooo07;oool0067oool00ol0VOooooooo`0[oooo0P0001Xco`00
0`000?ooooooo`1boooo001Qoooo00?o09Woooooool0:oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001Qoooo00?o09Woooooool0:oooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo001Qoooo00?o09Woooooool0:oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001Q
oooo00?o09Woooooool0:oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001Qoooo00?o
09Woooooool08oooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool0067oool0
0ol0VOooooooo`0Uoooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo001Qoooo00?o09Woooooool09Oooo`030000oooooooo00?oool300005C?o00030000oooooooo
07Koool0067oool00ol0VOooooooo`0Uoooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1foooo001Qoooo00?o09Woooooool09Oooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00HOooo`03o`2Ioooooooo02Coool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001Qoooo00?o09Woooooool0:oooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo001Qoooo00?o09Woooooool0:oooo`030000<ol0<ol001<co`00
0`000?ooooooo`1hoooo001Qoooo00?o09Woooooool0:oooo`80000D<ol000<0003oooooool0N?oo
o`00HOooo`03o`2Ioooooooo02_oool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00HOoo
o`03o`2Ioooooooo02_oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00HOooo`03o`2I
oooooooo02_oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00HOooo`03o`2Ioooooooo
02_oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00HOooo`03o`2Ioooooooo02_oool0
0`0003?o03?o000A<ol000<0003oooooool0N_ooo`00HOooo`03o`2Ioooooooo02_oool200004S?o
00030000oooooooo07[oool0067oool00ol0VOooooooo`0[oooo00<0000co`0co`004C?o00030000
oooooooo07[oool0067oool00ol0VOooooooo`0[oooo00<0000co`0co`004C?o00030000oooooooo
07[oool0067oool00ol0VOooooooo`0[oooo00<0000co`0co`0043?o00030000oooooooo07_oool0
067oool00ol0VOooooooo`0[oooo00<0000co`0co`0043?o00030000oooooooo07_oool0067oool0
0ol0VOooooooo`0[oooo00<0000co`0co`0043?o00030000oooooooo07_oool0067oool00ol0VOoo
ooooo`0[oooo00<0000co`0co`0043?o00030000oooooooo07_oool0067oool00ol0VOooooooo`0[
oooo0P00010co`000`000?ooooooo`1loooo001Qoooo00?o09Woooooool0:oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001Qoooo00?o09Woooooool0:oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001Qoooo00?o09Woooooool0:oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001Qoooo00?o09Woooooool0:oooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo001Qoooo00?o09Woooooool0:oooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001Q
oooo00?o09Woooooool0:oooo`80000?<ol000<0003oooooool0OOooo`00HOooo`03o`2Ioooooooo
02_oool00`0003?o03?o000><ol000<0003oooooool0OOooo`00HOooo`03o`2Ioooooooo02_oool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00HOooo`03o`2Ioooooooo02_oool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00HOooo`03o`2Ioooooooo02?oool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001Qoooo00?o09Woooooool08oooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00HOooo`03o`2Ioooooooo02Coool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001Qoooo00?o09Woooooool09Ooo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00HOooo`03o`2I
oooooooo02?oool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00HOooo`03o`2Ioooooooo02Coool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001Qoooo00?o09Woooooool0:oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001Q
oooo00?o09Woooooool0:oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001Qoooo00?o
09Woooooool0:oooo`80000=<ol000<0003oooooool0Ooooo`00HOooo`03o`2Ioooooooo02_oool0
0`0003?o03?o000<<ol000<0003oooooool0Ooooo`00HOooo`03o`2Ioooooooo02_oool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00HOooo`03o`2Ioooooooo02_oool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00HOooo`03o`2Ioooooooo02_oool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00HOooo`03o`2Ioooooooo02_oool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00HOooo`03o`2Ioooooooo02_oool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00HOooo`03o`2Ioooooooo02_oool2000033?o00030000oooooooo083oool0067oool00ol0VOoo
ooooo`0[oooo00<0000co`0co`002c?o00030000oooooooo083oool0067oool00ol0VOooooooo`0[
oooo00<0000co`0co`002S?o00030000oooooooo087oool0067oool00ol0VOooooooo`0[oooo00<0
000co`0co`002S?o00030000oooooooo087oool0067oool00ol0VOooooooo`0[oooo00<0000co`0c
o`002S?o00030000oooooooo087oool0067oool00ol0VOooooooo`0[oooo00<0000co`0co`002S?o
00030000oooooooo087oool0067oool00ol0VOooooooo`0[oooo0P0000/co`000`000?ooooooo`21
oooo001Qoooo00?o09Woooooool0:oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Q
oooo00?o09Woooooool0:oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Qoooo00?o
09Woooooool0:oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Qoooo00?o09Wooooo
ool0:oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Qoooo00?o09Woooooool0:ooo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Qoooo00?o09Woooooool0:oooo`80000:
<ol000<0003oooooool0P_ooo`00HOooo`03o`2Ioooooooo02_oool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00HOooo`03o`2Ioooooooo02_oool00`0003?o03?o0009<ol000<0003ooooo
ool0P_ooo`00HOooo`03o`2Ioooooooo02_oool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00HOooo`03o`2Ioooooooo02Coool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001Qoooo00?o09Woooooool08oooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo001Qoooo00?o09Woooooool09Oooo`030000oooooooo00?oool3000023?o
00030000oooooooo08?oool0067oool00ol0VOooooooo`0Voooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo001Qoooo00?o09Woooooool08oooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001Qoooo00?o09Woooooool09?oo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool0067oool00ol0VOooooooo`0[
oooo00<0000co`0co`001c?o00030000oooooooo08Coool0067oool00ol0VOooooooo`0[oooo00<0
000co`0co`001c?o00030000oooooooo08Coool0067oool00ol0VOooooooo`0[oooo00<0000co`0c
o`001c?o00030000oooooooo08Coool0067oool00ol0VOooooooo`0[oooo0P0000Pco`000`000?oo
ooooo`24oooo001Qoooo00?o09Woooooool0:oooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001Qoooo00?o09Woooooool0:oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Q
oooo00?o09Woooooool0:oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Qoooo00?o
09Woooooool0:oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Qoooo00?o09Wooooo
ool0:oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Qoooo00?o09Woooooool0:ooo
o`800007<ol000<0003oooooool0QOooo`00HOooo`03o`2Ioooooooo02_oool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00HOooo`03o`2Ioooooooo02_oool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00HOooo`03o`2Ioooooooo02_oool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00HOooo`03o`2Ioooooooo02_oool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00HOooo`03o`2Ioooooooo02_oool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00HOoo
o`03o`2Ioooooooo02_oool200001S?o00030000oooooooo08Koool0067oool00ol0VOooooooo`0[
oooo00<0000co`0co`001C?o00030000oooooooo08Koool0067oool00ol0VOooooooo`0[oooo00<0
000co`0co`001C?o00030000oooooooo08Koool0067oool00ol0VOooooooo`0[oooo00<0000co`0c
o`001C?o00030000oooooooo08Koool0067oool00ol0VOooooooo`0[oooo00<0000co`0co`001C?o
00030000oooooooo08Koool0067oool00ol0VOooooooo`0[oooo00<0000co`0co`001C?o00030000
oooooooo08Koool0067oool00ol0VOooooooo`0[oooo0P0000Hco`000`000?ooooooo`26oooo001Q
oooo00?o09Woooooool0:oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Qoooo00?o
09Woooooool0:oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Qoooo00?o09Wooooo
ool0:oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Qoooo00?o09Woooooool0:ooo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Qoooo00?o09Woooooool09Oooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool0067oool00ol0VOooooooo`0Voooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Qoooo00?o09Wooooo
ool08oooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool2000013?o008000000c?o0?ooooooo`0400001?ooo`<00002oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo00001S?o00;oool00`000?ooooooo`06oooo00D0003oooooooooool00000N_oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00006<ol00ooo
o`030000oooooooo00;oool500000oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00003?ooo`040000oooooooo00001S?o00Coool01@000?ooooooooooo`000002oooo00D0003ooooo
ooooool00000N_ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Hco`02
oooo00@0003oooooool00003oooo00<0003oool000000oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Aoooo0P0000Lco`03oooo0P0000Goool200000_ooo`030000oooooooo07Woool0
08ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.30316 .12361 L
.31304 .12361 L
.31574 .12361 L
.31865 .12361 L
.32006 .12361 L
.3214 .12361 L
.3226 .12361 L
s
.3226 .12361 m
.32313 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`040000ooooooooo`2I2?ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0
003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003ooooo
ool03?ooo`03o`2Ioooooooo02[oool00`0003?o03?o000i<ol02@0003Coool00`000?ooooooo`0E
oooo001Roooo00?o09Woooooool0:_ooo`030000<ol0<ol003<co`060000EOooo`00H_ooo`03o`2I
oooooooo02[oool00`0003?o03?o000a<ol00P0005_oool006;oool00ol0VOooooooo`0Zoooo00<0
000co`0co`00;c?o0080001Moooo001Roooo00?o09Woooooool0:_ooo`030000<ol0<ol002`co`03
0000Goooo`00H_ooo`03o`2Ioooooooo02[oool20000:S?o00<0001Roooo001Roooo00?o09Wooooo
ool0:_ooo`030000<ol0<ol002Lco`020000IOooo`00H_ooo`03o`2Ioooooooo02[oool00`0003?o
03?o000V<ol000<0003oooooool0IOooo`00H_ooo`03o`2Ioooooooo02[oool00`0003?o03?o000U
<ol000<0003oooooool0I_ooo`00H_ooo`03o`2Ioooooooo02[oool00`0003?o03?o000T<ol000<0
003oooooool0Ioooo`00H_ooo`03o`2Ioooooooo02[oool00`0003?o03?o000R<ol00P0006[oool0
06;oool00ol0VOooooooo`0Zoooo0P00028co`000`000?ooooooo`1Zoooo001Roooo00?o09Wooooo
ool0:_ooo`030000<ol0<ol0020co`000`000?ooooooo`1[oooo001Roooo00?o09Woooooool0:_oo
o`030000<ol0<ol001lco`000`000?ooooooo`1/oooo001Roooo00?o09Woooooool0:_ooo`030000
<ol0<ol001lco`000`000?ooooooo`1/oooo001Roooo00?o09Woooooool0:_ooo`030000<ol0<ol0
01hco`000`000?ooooooo`1]oooo001Roooo00?o09Woooooool0:_ooo`030000<ol0<ol001dco`00
0`000?ooooooo`1^oooo001Roooo00?o09Woooooool0:_ooo`80000M<ol000<0003oooooool0Kooo
o`00H_ooo`03o`2Ioooooooo02[oool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00H_oo
o`03o`2Ioooooooo02[oool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00H_ooo`03o`2I
oooooooo02[oool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00H_ooo`03o`2Ioooooooo
02[oool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00H_ooo`03o`2Ioooooooo02[oool0
0`0003?o03?o000I<ol000<0003oooooool0L_ooo`00H_ooo`03o`2Ioooooooo02[oool200006S?o
00030000oooooooo07;oool006;oool00ol0VOooooooo`0Zoooo00<0000co`0co`0063?o00030000
oooooooo07?oool006;oool00ol0VOooooooo`0Zoooo00<0000co`0co`0063?o00030000oooooooo
07?oool006;oool00ol0VOooooooo`0Zoooo00<0000co`0co`005c?o00030000oooooooo07Coool0
06;oool00ol0VOooooooo`0Zoooo00<0000co`0co`005c?o00030000oooooooo07Coool006;oool0
0ol0VOooooooo`0Roooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00H_oo
o`03o`2Ioooooooo02Coool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo
07Goool006;oool00ol0VOooooooo`0Toooo00<0003oooooool00oooo`<0000E<ol000<0003ooooo
ool0M_ooo`00H_ooo`03o`2Ioooooooo02Coool00`000?ooooooo`03oooo00<0000co`0co`005C?o
00030000oooooooo07Koool006;oool00ol0VOooooooo`0Toooo00<0003oooooool00oooo`030000
<ol0<ol001Dco`000`000?ooooooo`1foooo001Roooo00?o09Woooooool08oooo`800005oooo00<0
000co`0co`0053?o00030000oooooooo07Ooool006;oool00ol0VOooooooo`0Zoooo00<0000co`0c
o`0053?o00030000oooooooo07Ooool006;oool00ol0VOooooooo`0Zoooo00<0000co`0co`004c?o
00030000oooooooo07Soool006;oool00ol0VOooooooo`0Zoooo0P0001@co`000`000?ooooooo`1h
oooo001Roooo00?o09Woooooool0:_ooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo001R
oooo00?o09Woooooool0:_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001Roooo00?o
09Woooooool0:_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001Roooo00?o09Wooooo
ool0:_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001Roooo00?o09Woooooool0:_oo
o`030000<ol0<ol0014co`000`000?ooooooo`1joooo001Roooo00?o09Woooooool0:_ooo`80000B
<ol000<0003oooooool0N_ooo`00H_ooo`03o`2Ioooooooo02[oool00`0003?o03?o000A<ol000<0
003oooooool0N_ooo`00H_ooo`03o`2Ioooooooo02[oool00`0003?o03?o000A<ol000<0003ooooo
ool0N_ooo`00H_ooo`03o`2Ioooooooo02[oool00`0003?o03?o000@<ol000<0003oooooool0Nooo
o`00H_ooo`03o`2Ioooooooo02[oool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00H_oo
o`03o`2Ioooooooo02[oool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00H_ooo`03o`2I
oooooooo02[oool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00H_ooo`03o`2Ioooooooo
02[oool2000043?o00030000oooooooo07coool006;oool00ol0VOooooooo`0Zoooo00<0000co`0c
o`003c?o00030000oooooooo07coool006;oool00ol0VOooooooo`0Zoooo00<0000co`0co`003c?o
00030000oooooooo07coool006;oool00ol0VOooooooo`0Zoooo00<0000co`0co`003c?o00030000
oooooooo07coool006;oool00ol0VOooooooo`0Zoooo00<0000co`0co`003c?o00030000oooooooo
07coool006;oool00ol0VOooooooo`0Zoooo00<0000co`0co`003S?o00030000oooooooo07goool0
06;oool00ol0VOooooooo`0Zoooo0P0000lco`000`000?ooooooo`1moooo001Roooo00?o09Wooooo
ool0:_ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001Roooo00?o09Woooooool0:_oo
o`030000<ol0<ol000hco`000`000?ooooooo`1moooo001Roooo00?o09Woooooool0:_ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001Roooo00?o09Woooooool08_ooo`@00004oooo00<0
000co`0co`003C?o00030000oooooooo07koool006;oool00ol0VOooooooo`0Roooo00<0003ooooo
ool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo001Roooo00?o09Woooooool08ooo
o`030000oooooooo00Coool300003C?o00030000oooooooo07koool006;oool00ol0VOooooooo`0T
oooo00<0003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo001Roooo00?o
09Woooooool08_ooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001Roooo00?o09Woooooool08oooo`800005oooo00<0000co`0co`0033?o00030000oooooooo
07ooool006;oool00ol0VOooooooo`0Zoooo00<0000co`0co`0033?o00030000oooooooo07ooool0
06;oool00ol0VOooooooo`0Zoooo00<0000co`0co`0033?o00030000oooooooo07ooool006;oool0
0ol0VOooooooo`0Zoooo0P0000dco`000`000?ooooooo`1ooooo001Roooo00?o09Woooooool0:_oo
o`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001Roooo00?o09Woooooool0:_ooo`030000
<ol0<ol000/co`000`000?ooooooo`20oooo001Roooo00?o09Woooooool0:_ooo`030000<ol0<ol0
00/co`000`000?ooooooo`20oooo001Roooo00?o09Woooooool0:_ooo`030000<ol0<ol000/co`00
0`000?ooooooo`20oooo001Roooo00?o09Woooooool0:_ooo`030000<ol0<ol000/co`000`000?oo
ooooo`20oooo001Roooo00?o09Woooooool0:_ooo`030000<ol0<ol000/co`000`000?ooooooo`20
oooo001Roooo00?o09Woooooool0:_ooo`80000<<ol000<0003oooooool0P?ooo`00H_ooo`03o`2I
oooooooo02[oool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00H_ooo`03o`2Ioooooooo
02[oool00`0003?o03?o000:<ol000<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo02[oool0
0`0003?o03?o000:<ol000<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo02[oool00`0003?o
03?o000:<ol000<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo02[oool00`0003?o03?o000:
<ol000<0003oooooool0POooo`00H_ooo`03o`2Ioooooooo02[oool200002c?o00030000oooooooo
087oool006;oool00ol0VOooooooo`0Zoooo00<0000co`0co`002S?o00030000oooooooo087oool0
06;oool00ol0VOooooooo`0Zoooo00<0000co`0co`002S?o00030000oooooooo087oool006;oool0
0ol0VOooooooo`0Zoooo00<0000co`0co`002C?o00030000oooooooo08;oool006;oool00ol0VOoo
ooooo`0Zoooo00<0000co`0co`002C?o00030000oooooooo08;oool006;oool00ol0VOooooooo`0Z
oooo00<0000co`0co`002C?o00030000oooooooo08;oool006;oool00ol0VOooooooo`0Zoooo0P00
00Xco`000`000?ooooooo`22oooo001Roooo00?o09Woooooool0:_ooo`030000<ol0<ol000Tco`00
0`000?ooooooo`22oooo001Roooo00?o09Woooooool0:_ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`22oooo001Roooo00?o09Woooooool0:_ooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001Roooo00?o09Woooooool08oooo`800005oooo00<0000co`0co`0023?o00030000oooooooo
08?oool006;oool00ol0VOooooooo`0Roooo00@0003oooooool00004oooo00<0000co`0co`0023?o
00030000oooooooo08?oool006;oool00ol0VOooooooo`0Toooo00<0003oooooool00oooo`<00008
<ol000<0003oooooool0Poooo`00H_ooo`03o`2Ioooooooo02Goool00`000?ooooooo`02oooo00<0
000co`0co`0023?o00030000oooooooo08?oool006;oool00ol0VOooooooo`0Roooo00@0003ooooo
ool00004oooo00<0000co`0co`0023?o00030000oooooooo08?oool006;oool00ol0VOooooooo`0S
oooo0P0000Goool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00H_ooo`03o`2Ioooooooo
02[oool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00H_ooo`03o`2Ioooooooo02[oool0
0`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00H_ooo`03o`2Ioooooooo02[oool00`0003?o
03?o0007<ol000<0003oooooool0Q?ooo`00H_ooo`03o`2Ioooooooo02[oool2000023?o00030000
oooooooo08Coool006;oool00ol0VOooooooo`0Zoooo00<0000co`0co`001c?o00030000oooooooo
08Coool006;oool00ol0VOooooooo`0Zoooo00<0000co`0co`001c?o00030000oooooooo08Coool0
06;oool00ol0VOooooooo`0Zoooo00<0000co`0co`001c?o00030000oooooooo08Coool006;oool0
0ol0VOooooooo`0Zoooo00<0000co`0co`001S?o00030000oooooooo08Goool006;oool00ol0VOoo
ooooo`0Zoooo00<0000co`0co`001S?o00030000oooooooo08Goool006;oool00ol0VOooooooo`0Z
oooo0P0000Lco`000`000?ooooooo`25oooo001Roooo00?o09Woooooool0:_ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`25oooo001Roooo00?o09Woooooool0:_ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`25oooo001Roooo00?o09Woooooool0:_ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`25oooo001Roooo00?o09Woooooool0:_ooo`030000<ol0<ol000Hco`000`000?ooooooo`25
oooo001Roooo00?o09Woooooool0:_ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001R
oooo00?o09Woooooool0:_ooo`800006<ol000<0003oooooool0Q_ooo`00H_ooo`03o`2Ioooooooo
02[oool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00H_ooo`03o`2Ioooooooo02[oool0
0`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00H_ooo`03o`2Ioooooooo02[oool00`0003?o
03?o0005<ol000<0003oooooool0Q_ooo`00H_ooo`03o`2Ioooooooo02[oool00`0003?o03?o0005
<ol000<0003oooooool0Q_ooo`00H_ooo`03o`2Ioooooooo02[oool00`0003?o03?o0005<ol000<0
003oooooool0Q_ooo`00H_ooo`03o`2Ioooooooo02[oool200001S?o00030000oooooooo08Koool0
06;oool00ol0VOooooooo`0Zoooo00<0000co`0co`001C?o00030000oooooooo08Koool006;oool0
0ol0VOooooooo`0Zoooo00<0000co`0co`001C?o00030000oooooooo08Koool006;oool00ol0VOoo
ooooo`0Zoooo00<0000co`0co`0013?o00030000oooooooo08Ooool006;oool00ol0VOooooooo`0Z
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool006;oool00ol0VOooooooo`0Toooo0`00
00?oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00H_ooo`03o`2Ioooooooo02Goool0
0`000?ooooooo`02oooo00<0000co`0co`0013?o00030000oooooooo08Ooool006;oool00ol0VOoo
ooooo`0Roooo1@0000?oool3000013?o00030000oooooooo08Ooool008Ooool010000?ooooooo`00
00Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o
08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o
00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01oooo`800004<ol00P000003<ol0oooooooo00@00002oooo0`0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05
oooo00@0003oooooool00006<ol00_ooo`030000oooooooo00?oool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?oo
ooooo`0000Hco`03oooo00<0003oooooool00_ooo`040000oooooooo00001?ooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00001S?o00Coool010000?oo
ooooooooo`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool0
10000?ooooooo`0000Hco`02oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`03oooo0P0000Coool300000_oo
o`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.31875 .12361 L
.32392 .12361 L
.32617 .12361 L
.32728 .12361 L
.32831 .12361 L
s
.32831 .12361 m
.32878 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`050000ooooooooooooo`2I00Ooool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_oo
o`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000
oooooooo00goool00ol0VOooooooo`0Yoooo00<0000co`0co`00>C?o00T0000doooo00<0003ooooo
ool05Oooo`00Hoooo`03o`2Ioooooooo02Woool00`0003?o03?o000c<ol01P0005Goool006?oool0
0ol0VOooooooo`0Yoooo00<0000co`0co`00<C?o0080001Koooo001Soooo00?o09Woooooool0:Ooo
o`030000<ol0<ol002lco`020000GOooo`00Hoooo`03o`2Ioooooooo02Woool00`0003?o03?o000/
<ol00`0005ooool006?oool00ol0VOooooooo`0Yoooo0P0002Xco`030000H_ooo`00Hoooo`03o`2I
oooooooo02Woool00`0003?o03?o000W<ol00P0006Goool006?oool00ol0VOooooooo`0Yoooo00<0
000co`0co`009S?o00030000oooooooo06Goool006?oool00ol0VOooooooo`0Yoooo00<0000co`0c
o`009C?o00030000oooooooo06Koool006?oool00ol0VOooooooo`0Yoooo00<0000co`0co`0093?o
00030000oooooooo06Ooool006?oool00ol0VOooooooo`0Yoooo00<0000co`0co`008S?o0080001Z
oooo001Soooo00?o09Woooooool0:Oooo`80000R<ol000<0003oooooool0J_ooo`00Hoooo`03o`2I
oooooooo02Woool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00Hoooo`03o`2Ioooooooo
02Woool00`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Hoooo`03o`2Ioooooooo02Woool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Hoooo`03o`2Ioooooooo02Woool00`0003?o
03?o000N<ol000<0003oooooool0KOooo`00Hoooo`03o`2Ioooooooo02Woool00`0003?o03?o000M
<ol000<0003oooooool0K_ooo`00Hoooo`03o`2Ioooooooo02Woool200007C?o00030000oooooooo
06ooool006?oool00ol0VOooooooo`0Yoooo00<0000co`0co`006c?o00030000oooooooo073oool0
06?oool00ol0VOooooooo`0Yoooo00<0000co`0co`006c?o00030000oooooooo073oool006?oool0
0ol0VOooooooo`0Yoooo00<0000co`0co`006S?o00030000oooooooo077oool006?oool00ol0VOoo
ooooo`0Yoooo00<0000co`0co`006S?o00030000oooooooo077oool006?oool00ol0VOooooooo`0Y
oooo00<0000co`0co`006C?o00030000oooooooo07;oool006?oool00ol0VOooooooo`0Yoooo0P00
01Xco`000`000?ooooooo`1boooo001Soooo00?o09Woooooool0:Oooo`030000<ol0<ol001Pco`00
0`000?ooooooo`1coooo001Soooo00?o09Woooooool0:Oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001Soooo00?o09Woooooool0:Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1d
oooo001Soooo00?o09Woooooool0:Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001S
oooo00?o09Woooooool08Oooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool0
06?oool00ol0VOooooooo`0Soooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001Soooo00?o09Woooooool08oooo`030000oooooooo00?oool300005C?o00030000
oooooooo07Koool006?oool00ol0VOooooooo`0Soooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`1foooo001Soooo00?o09Woooooool08oooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00Hoooo`03o`2Ioooooooo02;oool200001Ooo
o`030000<ol0<ol001@co`000`000?ooooooo`1goooo001Soooo00?o09Woooooool0:Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001Soooo00?o09Woooooool0:Oooo`030000<ol0<ol0
01<co`000`000?ooooooo`1hoooo001Soooo00?o09Woooooool0:Oooo`80000D<ol000<0003ooooo
ool0N?ooo`00Hoooo`03o`2Ioooooooo02Woool00`0003?o03?o000C<ol000<0003oooooool0N?oo
o`00Hoooo`03o`2Ioooooooo02Woool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Hooo
o`03o`2Ioooooooo02Woool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Hoooo`03o`2I
oooooooo02Woool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Hoooo`03o`2Ioooooooo
02Woool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00Hoooo`03o`2Ioooooooo02Woool2
00004S?o00030000oooooooo07[oool006?oool00ol0VOooooooo`0Yoooo00<0000co`0co`004C?o
00030000oooooooo07[oool006?oool00ol0VOooooooo`0Yoooo00<0000co`0co`004C?o00030000
oooooooo07[oool006?oool00ol0VOooooooo`0Yoooo00<0000co`0co`0043?o00030000oooooooo
07_oool006?oool00ol0VOooooooo`0Yoooo00<0000co`0co`0043?o00030000oooooooo07_oool0
06?oool00ol0VOooooooo`0Yoooo00<0000co`0co`0043?o00030000oooooooo07_oool006?oool0
0ol0VOooooooo`0Yoooo00<0000co`0co`0043?o00030000oooooooo07_oool006?oool00ol0VOoo
ooooo`0Yoooo0P00010co`000`000?ooooooo`1loooo001Soooo00?o09Woooooool0:Oooo`030000
<ol0<ol000lco`000`000?ooooooo`1loooo001Soooo00?o09Woooooool0:Oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001Soooo00?o09Woooooool0:Oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001Soooo00?o09Woooooool0:Oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001Soooo00?o09Woooooool0:Oooo`030000<ol0<ol000hco`000`000?ooooooo`1m
oooo001Soooo00?o09Woooooool0:Oooo`80000?<ol000<0003oooooool0OOooo`00Hoooo`03o`2I
oooooooo02Woool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Hoooo`03o`2Ioooooooo
02Woool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Hoooo`03o`2Ioooooooo02Woool0
0`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Hoooo`03o`2Ioooooooo027oool400001?oo
o`030000<ol0<ol000dco`000`000?ooooooo`1noooo001Soooo00?o09Woooooool08Oooo`030000
oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Hoooo`03o`2Ioooooooo
02;oool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001Toooo00?o09Wooooo
ool08_ooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00I?oo
o`03o`2Ioooooooo023oool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00I?ooo`03o`2Ioooooooo027oool200001Oooo`030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001Toooo00?o09Woooooool0:?ooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001Toooo00?o09Woooooool0:?ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001T
oooo00?o09Woooooool0:?ooo`80000=<ol000<0003oooooool0Ooooo`00I?ooo`03o`2Ioooooooo
02Soool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00I?ooo`03o`2Ioooooooo02Soool0
0`0003?o03?o000;<ol000<0003oooooool0P?ooo`00I?ooo`03o`2Ioooooooo02Soool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00I?ooo`03o`2Ioooooooo02Soool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00I?ooo`03o`2Ioooooooo02Soool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00I?ooo`03o`2Ioooooooo02Soool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00I?ooo`03o`2Ioooooooo02Soool2000033?o00030000oooooooo083oool006Coool0
0ol0VOooooooo`0Xoooo00<0000co`0co`002c?o00030000oooooooo083oool006Coool00ol0VOoo
ooooo`0Xoooo00<0000co`0co`002S?o00030000oooooooo087oool006Coool00ol0VOooooooo`0X
oooo00<0000co`0co`002S?o00030000oooooooo087oool006Coool00ol0VOooooooo`0Xoooo00<0
000co`0co`002S?o00030000oooooooo087oool006Coool00ol0VOooooooo`0Xoooo00<0000co`0c
o`002S?o00030000oooooooo087oool006Coool00ol0VOooooooo`0Xoooo0P0000/co`000`000?oo
ooooo`21oooo001Toooo00?o09Woooooool0:?ooo`030000<ol0<ol000Xco`000`000?ooooooo`21
oooo001Toooo00?o09Woooooool0:?ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001T
oooo00?o09Woooooool0:?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Toooo00?o
09Woooooool0:?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Toooo00?o09Wooooo
ool0:?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Toooo00?o09Woooooool0:?oo
o`80000:<ol000<0003oooooool0P_ooo`00I?ooo`03o`2Ioooooooo02Soool00`0003?o03?o0009
<ol000<0003oooooool0P_ooo`00I?ooo`03o`2Ioooooooo02Soool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00I?ooo`03o`2Ioooooooo02Soool00`0003?o03?o0008<ol000<0003ooooo
ool0Poooo`00I?ooo`03o`2Ioooooooo027oool200001Oooo`030000<ol0<ol000Pco`000`000?oo
ooooo`23oooo001Toooo00?o09Woooooool08?ooo`040000oooooooo00001?ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`23oooo001Toooo00?o09Woooooool08_ooo`030000oooooooo00?oool3
000023?o00030000oooooooo08?oool006Coool00ol0VOooooooo`0Soooo00<0003oooooool00_oo
o`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001Toooo00?o09Woooooool08?ooo`040000
oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001Toooo00?o09Wooooo
ool08Oooo`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool006Coool00ol0VOoo
ooooo`0Xoooo00<0000co`0co`001c?o00030000oooooooo08Coool006Coool00ol0VOooooooo`0X
oooo00<0000co`0co`001c?o00030000oooooooo08Coool006Coool00ol0VOooooooo`0Xoooo00<0
000co`0co`001c?o00030000oooooooo08Coool006Coool00ol0VOooooooo`0Xoooo0P0000Pco`00
0`000?ooooooo`24oooo001Toooo00?o09Woooooool0:?ooo`030000<ol0<ol000Lco`000`000?oo
ooooo`24oooo001Toooo00?o09Woooooool0:?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001Toooo00?o09Woooooool0:?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001T
oooo00?o09Woooooool0:?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Toooo00?o
09Woooooool0:?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Toooo00?o09Wooooo
ool0:?ooo`800007<ol000<0003oooooool0QOooo`00I?ooo`03o`2Ioooooooo02Soool00`0003?o
03?o0006<ol000<0003oooooool0QOooo`00I?ooo`03o`2Ioooooooo02Soool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00I?ooo`03o`2Ioooooooo02Soool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00I?ooo`03o`2Ioooooooo02Soool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00I?ooo`03o`2Ioooooooo02Soool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00I?ooo`03o`2Ioooooooo02Soool200001S?o00030000oooooooo08Koool006Coool00ol0VOoo
ooooo`0Xoooo00<0000co`0co`001C?o00030000oooooooo08Koool006Coool00ol0VOooooooo`0X
oooo00<0000co`0co`001C?o00030000oooooooo08Koool006Coool00ol0VOooooooo`0Xoooo00<0
000co`0co`001C?o00030000oooooooo08Koool006Coool00ol0VOooooooo`0Xoooo00<0000co`0c
o`001C?o00030000oooooooo08Koool006Coool00ol0VOooooooo`0Xoooo00<0000co`0co`001C?o
00030000oooooooo08Koool006Coool00ol0VOooooooo`0Xoooo0P0000Hco`000`000?ooooooo`26
oooo001Toooo00?o09Woooooool0:?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001T
oooo00?o09Woooooool0:?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Toooo00?o
09Woooooool0:?ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Toooo00?o09Wooooo
ool0:?ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Toooo00?o09Woooooool08_oo
o`<00003oooo00<0000co`0co`0013?o00030000oooooooo08Ooool006Coool00ol0VOooooooo`0S
oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Toooo00?o
09Woooooool08?ooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003ooooo
ool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?oo
o`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7
<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Ooo
o`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Ooool2000013?o008000000c?o0?ooooooo`0400000oooo`800004oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01Oooo`040000oooooooo00001S?o00;oool00`000?ooooooo`03oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0
003oooooool00006<ol00oooo`030000oooooooo00;oool010000?ooooooo`0000Coool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`0000Hco`04oooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00ooool010000?ooooooo`0000Hco`02oooo00@0003oooooool00002oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200001c?o00?oool200001?oo
o`800003oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.32831 .12361 L
.33073 .12361 L
.33193 .12361 L
.33304 .12361 L
s
.33304 .12361 m
.33356 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00?oool00ol0VOooooooo`03oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0?oooo00?o09Woooooool09oooo`030000<ol0<ol003Tco`090000=?oo
o`030000oooooooo01Goool006Goool00ol0VOooooooo`0Woooo00<0000co`0co`00<c?o00H0001E
oooo001Uoooo00?o09Woooooool09oooo`030000<ol0<ol0034co`020000Foooo`00IOooo`03o`2I
oooooooo02Ooool00`0003?o03?o000_<ol00P0005goool006Goool00ol0VOooooooo`0Woooo00<0
000co`0co`00;3?o00<0001Ooooo001Uoooo00?o09Woooooool09oooo`80000Z<ol00`0006;oool0
06Goool00ol0VOooooooo`0Woooo00<0000co`0co`009c?o0080001Uoooo001Uoooo00?o09Wooooo
ool09oooo`030000<ol0<ol002Hco`000`000?ooooooo`1Uoooo001Uoooo00?o09Woooooool09ooo
o`030000<ol0<ol002Dco`000`000?ooooooo`1Voooo001Uoooo00?o09Woooooool09oooo`030000
<ol0<ol002@co`000`000?ooooooo`1Woooo001Uoooo00?o09Woooooool09oooo`030000<ol0<ol0
028co`020000J_ooo`00IOooo`03o`2Ioooooooo02Ooool200008S?o00030000oooooooo06[oool0
06Goool00ol0VOooooooo`0Woooo00<0000co`0co`0083?o00030000oooooooo06_oool006Goool0
0ol0VOooooooo`0Woooo00<0000co`0co`007c?o00030000oooooooo06coool006Goool00ol0VOoo
ooooo`0Woooo00<0000co`0co`007c?o00030000oooooooo06coool006Goool00ol0VOooooooo`0W
oooo00<0000co`0co`007S?o00030000oooooooo06goool006Goool00ol0VOooooooo`0Woooo00<0
000co`0co`007C?o00030000oooooooo06koool006Goool00ol0VOooooooo`0Woooo0P0001dco`00
0`000?ooooooo`1_oooo001Uoooo00?o09Woooooool09oooo`030000<ol0<ol001/co`000`000?oo
ooooo`1`oooo001Uoooo00?o09Woooooool09oooo`030000<ol0<ol001/co`000`000?ooooooo`1`
oooo001Uoooo00?o09Woooooool09oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001U
oooo00?o09Woooooool09oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001Uoooo00?o
09Woooooool09oooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo001Uoooo00?o09Wooooo
ool09oooo`80000J<ol000<0003oooooool0L_ooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o
03?o000H<ol000<0003oooooool0Loooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o000H
<ol000<0003oooooool0Loooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o000G<ol000<0
003oooooool0M?ooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o000G<ol000<0003ooooo
ool0M?ooo`00IOooo`03o`2Ioooooooo01ooool500000oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001Uoooo00?o09Woooooool08Oooo`030000oooooooo00?oool00`0003?o03?o000F
<ol000<0003oooooool0MOooo`00IOooo`03o`2Ioooooooo027oool00`000?ooooooo`03oooo0`00
01Dco`000`000?ooooooo`1foooo001Uoooo00?o09Woooooool08Oooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00IOooo`03o`2Ioooooooo027oool00`000?oo
ooooo`03oooo00<0000co`0co`005C?o00030000oooooooo07Koool006Goool00ol0VOooooooo`0P
oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00IOooo`03o`2Ioooooooo
02Ooool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00IOooo`03o`2Ioooooooo02Ooool0
0`0003?o03?o000C<ol000<0003oooooool0N?ooo`00IOooo`03o`2Ioooooooo02Ooool2000053?o
00030000oooooooo07Soool006Goool00ol0VOooooooo`0Woooo00<0000co`0co`004c?o00030000
oooooooo07Soool006Goool00ol0VOooooooo`0Woooo00<0000co`0co`004S?o00030000oooooooo
07Woool006Goool00ol0VOooooooo`0Woooo00<0000co`0co`004S?o00030000oooooooo07Woool0
06Goool00ol0VOooooooo`0Woooo00<0000co`0co`004S?o00030000oooooooo07Woool006Goool0
0ol0VOooooooo`0Woooo00<0000co`0co`004C?o00030000oooooooo07[oool006Goool00ol0VOoo
ooooo`0Woooo0P00018co`000`000?ooooooo`1joooo001Uoooo00?o09Woooooool09oooo`030000
<ol0<ol0014co`000`000?ooooooo`1joooo001Uoooo00?o09Woooooool09oooo`030000<ol0<ol0
014co`000`000?ooooooo`1joooo001Uoooo00?o09Woooooool09oooo`030000<ol0<ol0010co`00
0`000?ooooooo`1koooo001Uoooo00?o09Woooooool09oooo`030000<ol0<ol0010co`000`000?oo
ooooo`1koooo001Uoooo00?o09Woooooool09oooo`030000<ol0<ol0010co`000`000?ooooooo`1k
oooo001Uoooo00?o09Woooooool09oooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo001U
oooo00?o09Woooooool09oooo`80000@<ol000<0003oooooool0O?ooo`00IOooo`03o`2Ioooooooo
02Ooool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00IOooo`03o`2Ioooooooo02Ooool0
0`0003?o03?o000?<ol000<0003oooooool0O?ooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o
03?o000?<ol000<0003oooooool0O?ooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o000?
<ol000<0003oooooool0O?ooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o000><ol000<0
003oooooool0OOooo`00IOooo`03o`2Ioooooooo02Ooool200003c?o00030000oooooooo07goool0
06Goool00ol0VOooooooo`0Woooo00<0000co`0co`003S?o00030000oooooooo07goool006Goool0
0ol0VOooooooo`0Woooo00<0000co`0co`003S?o00030000oooooooo07goool006Goool00ol0VOoo
ooooo`0Woooo00<0000co`0co`003C?o00030000oooooooo07koool006Goool00ol0VOooooooo`0O
oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00IOooo`03o`2Ioooooooo
01ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo07koool006Goool0
0ol0VOooooooo`0Poooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0O_ooo`00IOoo
o`03o`2Ioooooooo027oool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo
07koool006Goool00ol0VOooooooo`0Ooooo00@0003oooooool00004oooo00<0000co`0co`0033?o
00030000oooooooo07ooool006Goool00ol0VOooooooo`0Poooo0P0000Goool00`0003?o03?o000<
<ol000<0003oooooool0Ooooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o000<<ol000<0
003oooooool0Ooooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00IOooo`03o`2Ioooooooo02Ooool200003C?o00030000oooooooo07ooool006Goool0
0ol0VOooooooo`0Woooo00<0000co`0co`0033?o00030000oooooooo07ooool006Goool00ol0VOoo
ooooo`0Woooo00<0000co`0co`002c?o00030000oooooooo083oool006Goool00ol0VOooooooo`0W
oooo00<0000co`0co`002c?o00030000oooooooo083oool006Goool00ol0VOooooooo`0Woooo00<0
000co`0co`002c?o00030000oooooooo083oool006Goool00ol0VOooooooo`0Woooo00<0000co`0c
o`002c?o00030000oooooooo083oool006Goool00ol0VOooooooo`0Woooo00<0000co`0co`002c?o
00030000oooooooo083oool006Goool00ol0VOooooooo`0Woooo0P0000`co`000`000?ooooooo`20
oooo001Uoooo00?o09Woooooool09oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001U
oooo00?o09Woooooool09oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Uoooo00?o
09Woooooool09oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Uoooo00?o09Wooooo
ool09oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Uoooo00?o09Woooooool09ooo
o`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Uoooo00?o09Woooooool09oooo`80000;
<ol000<0003oooooool0POooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o000:<ol000<0003ooooo
ool0POooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o0009<ol000<0003oooooool0P_oo
o`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00IOoo
o`03o`2Ioooooooo02Ooool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00IOooo`03o`2I
oooooooo02Ooool200002S?o00030000oooooooo08;oool006Goool00ol0VOooooooo`0Woooo00<0
000co`0co`002C?o00030000oooooooo08;oool006Goool00ol0VOooooooo`0Woooo00<0000co`0c
o`002C?o00030000oooooooo08;oool006Goool00ol0VOooooooo`0Woooo00<0000co`0co`0023?o
00030000oooooooo08?oool006Goool00ol0VOooooooo`0Poooo0P0000Goool00`0003?o03?o0008
<ol000<0003oooooool0Poooo`00IOooo`03o`2Ioooooooo01ooool010000?ooooooo`0000Coool0
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00IOooo`03o`2Ioooooooo027oool00`000?oo
ooooo`03oooo0`0000Pco`000`000?ooooooo`23oooo001Uoooo00?o09Woooooool08_ooo`030000
oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00IOooo`03o`2Ioooooooo
01ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00IOoo
o`03o`2Ioooooooo023oool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001U
oooo00?o09Woooooool09oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Uoooo00?o
09Woooooool09oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Uoooo00?o09Wooooo
ool09oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Uoooo00?o09Woooooool09ooo
o`800008<ol000<0003oooooool0Q?ooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o0007<ol000<0
003oooooool0Q?ooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o0007<ol000<0003ooooo
ool0Q?ooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00IOoo
o`03o`2Ioooooooo02Ooool200001c?o00030000oooooooo08Goool006Goool00ol0VOooooooo`0W
oooo00<0000co`0co`001S?o00030000oooooooo08Goool006Goool00ol0VOooooooo`0Woooo00<0
000co`0co`001S?o00030000oooooooo08Goool006Goool00ol0VOooooooo`0Woooo00<0000co`0c
o`001S?o00030000oooooooo08Goool006Goool00ol0VOooooooo`0Woooo00<0000co`0co`001S?o
00030000oooooooo08Goool006Goool00ol0VOooooooo`0Woooo00<0000co`0co`001S?o00030000
oooooooo08Goool006Goool00ol0VOooooooo`0Woooo0P0000Hco`000`000?ooooooo`26oooo001U
oooo00?o09Woooooool09oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Uoooo00?o
09Woooooool09oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Uoooo00?o09Wooooo
ool09oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Uoooo00?o09Woooooool09ooo
o`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Uoooo00?o09Woooooool09oooo`030000
<ol0<ol000Dco`000`000?ooooooo`26oooo001Uoooo00?o09Woooooool09oooo`800006<ol000<0
003oooooool0Q_ooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o0005<ol000<0003oooooool0Q_oo
o`00IOooo`03o`2Ioooooooo02Ooool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00IOoo
o`03o`2Ioooooooo02Ooool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00IOooo`03o`2I
oooooooo027oool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Uoooo00?o
09Woooooool08_ooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0Qooo
o`00IOooo`03o`2Ioooooooo01ooool500000oooo`<00004<ol000<0003oooooool0Qoooo`00Qooo
o`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029
oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007coool00`000?oo
ooooo`0@oooo1c?o00_oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000
oooooooo00Koool7<ol03?ooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo00<co`000000000013?o00800004oooo0P0000Coool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0000co`0co`000003<ol01Oooo`040000oooooooo00000oooo`030000oooooooo
07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000<ol0<ol000000c?o
00Ooool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<
oooo00@0000co`0co`000003<ol02?ooo`050000oooooooooooo000007goool007_oool01@000?oo
ooooooooo`00000?oooo00@0000co`0co`000003<ol01Oooo`040000oooooooo00000oooo`030000
oooooooo07_oool007coool00`000?ooooooo`0@oooo00<co`000000000013?o00Koool200000ooo
o`030000oooooooo07coool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.32831 .12361 L
.33304 .12361 L
.33443 .12361 L
.33575 .12361 L
.33693 .12361 L
s
.33693 .12361 m
.33745 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Coool00ol0VOooooooo`02oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0@oooo00?o09Woooooool09_ooo`030000<ol0<ol003Tco`090000=?oo
o`030000oooooooo01Goool006Koool00ol0VOooooooo`0Voooo00<0000co`0co`00<c?o00H0001E
oooo001Voooo00?o09Woooooool09_ooo`030000<ol0<ol0034co`020000Foooo`00I_ooo`03o`2I
oooooooo02Koool00`0003?o03?o000_<ol00P0005goool006Koool00ol0VOooooooo`0Voooo00<0
000co`0co`00;3?o00<0001Ooooo001Voooo00?o09Woooooool09_ooo`80000Z<ol00`0006;oool0
06Koool00ol0VOooooooo`0Voooo00<0000co`0co`009c?o0080001Uoooo001Voooo00?o09Wooooo
ool09_ooo`030000<ol0<ol002Hco`000`000?ooooooo`1Uoooo001Voooo00?o09Woooooool09_oo
o`030000<ol0<ol002Dco`000`000?ooooooo`1Voooo001Voooo00?o09Woooooool09_ooo`030000
<ol0<ol002@co`000`000?ooooooo`1Woooo001Voooo00?o09Woooooool09_ooo`030000<ol0<ol0
028co`020000J_ooo`00I_ooo`03o`2Ioooooooo02Koool200008S?o00030000oooooooo06[oool0
06Koool00ol0VOooooooo`0Voooo00<0000co`0co`0083?o00030000oooooooo06_oool006Koool0
0ol0VOooooooo`0Voooo00<0000co`0co`007c?o00030000oooooooo06coool006Koool00ol0VOoo
ooooo`0Voooo00<0000co`0co`007c?o00030000oooooooo06coool006Koool00ol0VOooooooo`0V
oooo00<0000co`0co`007S?o00030000oooooooo06goool006Koool00ol0VOooooooo`0Voooo00<0
000co`0co`007C?o00030000oooooooo06koool006Koool00ol0VOooooooo`0Voooo0P0001dco`00
0`000?ooooooo`1_oooo001Voooo00?o09Woooooool09_ooo`030000<ol0<ol001/co`000`000?oo
ooooo`1`oooo001Voooo00?o09Woooooool09_ooo`030000<ol0<ol001/co`000`000?ooooooo`1`
oooo001Voooo00?o09Woooooool09_ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001V
oooo00?o09Woooooool09_ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001Voooo00?o
09Woooooool09_ooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo001Voooo00?o09Wooooo
ool09_ooo`80000J<ol000<0003oooooool0L_ooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o
03?o000H<ol000<0003oooooool0Loooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o000H
<ol000<0003oooooool0Loooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o000G<ol000<0
003oooooool0M?ooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o000G<ol000<0003ooooo
ool0M?ooo`00I_ooo`03o`2Ioooooooo01koool500000oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001Voooo00?o09Woooooool08?ooo`030000oooooooo00?oool00`0003?o03?o000F
<ol000<0003oooooool0MOooo`00I_ooo`03o`2Ioooooooo023oool00`000?ooooooo`03oooo0`00
01Dco`000`000?ooooooo`1foooo001Voooo00?o09Woooooool08?ooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00I_ooo`03o`2Ioooooooo023oool00`000?oo
ooooo`03oooo00<0000co`0co`005C?o00030000oooooooo07Koool006Koool00ol0VOooooooo`0O
oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00I_ooo`03o`2Ioooooooo
02Koool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00I_ooo`03o`2Ioooooooo02Koool0
0`0003?o03?o000C<ol000<0003oooooool0N?ooo`00I_ooo`03o`2Ioooooooo02Koool2000053?o
00030000oooooooo07Soool006Koool00ol0VOooooooo`0Voooo00<0000co`0co`004c?o00030000
oooooooo07Soool006Koool00ol0VOooooooo`0Voooo00<0000co`0co`004S?o00030000oooooooo
07Woool006Koool00ol0VOooooooo`0Voooo00<0000co`0co`004S?o00030000oooooooo07Woool0
06Koool00ol0VOooooooo`0Voooo00<0000co`0co`004S?o00030000oooooooo07Woool006Koool0
0ol0VOooooooo`0Voooo00<0000co`0co`004C?o00030000oooooooo07[oool006Koool00ol0VOoo
ooooo`0Voooo0P00018co`000`000?ooooooo`1joooo001Voooo00?o09Woooooool09_ooo`030000
<ol0<ol0014co`000`000?ooooooo`1joooo001Voooo00?o09Woooooool09_ooo`030000<ol0<ol0
014co`000`000?ooooooo`1joooo001Voooo00?o09Woooooool09_ooo`030000<ol0<ol0010co`00
0`000?ooooooo`1koooo001Voooo00?o09Woooooool09_ooo`030000<ol0<ol0010co`000`000?oo
ooooo`1koooo001Voooo00?o09Woooooool09_ooo`030000<ol0<ol0010co`000`000?ooooooo`1k
oooo001Voooo00?o09Woooooool09_ooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo001V
oooo00?o09Woooooool09_ooo`80000@<ol000<0003oooooool0O?ooo`00I_ooo`03o`2Ioooooooo
02Koool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00I_ooo`03o`2Ioooooooo02Koool0
0`0003?o03?o000?<ol000<0003oooooool0O?ooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o
03?o000?<ol000<0003oooooool0O?ooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o000?
<ol000<0003oooooool0O?ooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o000><ol000<0
003oooooool0OOooo`00I_ooo`03o`2Ioooooooo02Koool200003c?o00030000oooooooo07goool0
06Koool00ol0VOooooooo`0Voooo00<0000co`0co`003S?o00030000oooooooo07goool006Koool0
0ol0VOooooooo`0Voooo00<0000co`0co`003S?o00030000oooooooo07goool006Koool00ol0VOoo
ooooo`0Voooo00<0000co`0co`003C?o00030000oooooooo07koool006Koool00ol0VOooooooo`0N
oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00I_ooo`03o`2Ioooooooo
01koool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo07koool006Koool0
0ol0VOooooooo`0Ooooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0O_ooo`00I_oo
o`03o`2Ioooooooo023oool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo
07koool006Koool00ol0VOooooooo`0Noooo00@0003oooooool00004oooo00<0000co`0co`0033?o
00030000oooooooo07ooool006Koool00ol0VOooooooo`0Ooooo0P0000Goool00`0003?o03?o000<
<ol000<0003oooooool0Ooooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o000<<ol000<0
003oooooool0Ooooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00I_ooo`03o`2Ioooooooo02Koool200003C?o00030000oooooooo07ooool006Koool0
0ol0VOooooooo`0Voooo00<0000co`0co`0033?o00030000oooooooo07ooool006Koool00ol0VOoo
ooooo`0Voooo00<0000co`0co`002c?o00030000oooooooo083oool006Koool00ol0VOooooooo`0V
oooo00<0000co`0co`002c?o00030000oooooooo083oool006Koool00ol0VOooooooo`0Voooo00<0
000co`0co`002c?o00030000oooooooo083oool006Koool00ol0VOooooooo`0Voooo00<0000co`0c
o`002c?o00030000oooooooo083oool006Koool00ol0VOooooooo`0Voooo00<0000co`0co`002c?o
00030000oooooooo083oool006Koool00ol0VOooooooo`0Voooo0P0000`co`000`000?ooooooo`20
oooo001Voooo00?o09Woooooool09_ooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001V
oooo00?o09Woooooool09_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Voooo00?o
09Woooooool09_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Voooo00?o09Wooooo
ool09_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Voooo00?o09Woooooool09_oo
o`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Voooo00?o09Woooooool09_ooo`80000;
<ol000<0003oooooool0POooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o000:<ol000<0003ooooo
ool0POooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o0009<ol000<0003oooooool0P_oo
o`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00I_oo
o`03o`2Ioooooooo02Koool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00I_ooo`03o`2I
oooooooo02Koool200002S?o00030000oooooooo08;oool006Koool00ol0VOooooooo`0Voooo00<0
000co`0co`002C?o00030000oooooooo08;oool006Koool00ol0VOooooooo`0Voooo00<0000co`0c
o`002C?o00030000oooooooo08;oool006Koool00ol0VOooooooo`0Voooo00<0000co`0co`0023?o
00030000oooooooo08?oool006Koool00ol0VOooooooo`0Ooooo0P0000Goool00`0003?o03?o0008
<ol000<0003oooooool0Poooo`00I_ooo`03o`2Ioooooooo01koool010000?ooooooo`0000Coool0
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00I_ooo`03o`2Ioooooooo023oool00`000?oo
ooooo`03oooo0`0000Pco`000`000?ooooooo`23oooo001Voooo00?o09Woooooool08Oooo`030000
oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00I_ooo`03o`2Ioooooooo
01koool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00I_oo
o`03o`2Ioooooooo01ooool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001V
oooo00?o09Woooooool09_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Voooo00?o
09Woooooool09_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Voooo00?o09Wooooo
ool09_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Voooo00?o09Woooooool09_oo
o`800008<ol000<0003oooooool0Q?ooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o0007<ol000<0
003oooooool0Q?ooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o0007<ol000<0003ooooo
ool0Q?ooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00I_oo
o`03o`2Ioooooooo02Koool200001c?o00030000oooooooo08Goool006Koool00ol0VOooooooo`0V
oooo00<0000co`0co`001S?o00030000oooooooo08Goool006Koool00ol0VOooooooo`0Voooo00<0
000co`0co`001S?o00030000oooooooo08Goool006Koool00ol0VOooooooo`0Voooo00<0000co`0c
o`001S?o00030000oooooooo08Goool006Koool00ol0VOooooooo`0Voooo00<0000co`0co`001S?o
00030000oooooooo08Goool006Koool00ol0VOooooooo`0Voooo00<0000co`0co`001S?o00030000
oooooooo08Goool006Koool00ol0VOooooooo`0Voooo0P0000Hco`000`000?ooooooo`26oooo001V
oooo00?o09Woooooool09_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Voooo00?o
09Woooooool09_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Voooo00?o09Wooooo
ool09_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Voooo00?o09Woooooool09_oo
o`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Voooo00?o09Woooooool09_ooo`030000
<ol0<ol000Dco`000`000?ooooooo`26oooo001Voooo00?o09Woooooool09_ooo`800006<ol000<0
003oooooool0Q_ooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o0005<ol000<0003oooooool0Q_oo
o`00I_ooo`03o`2Ioooooooo02Koool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00I_oo
o`03o`2Ioooooooo02Koool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00I_ooo`03o`2I
oooooooo023oool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Voooo00?o
09Woooooool08Oooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0Qooo
o`00I_ooo`03o`2Ioooooooo01koool500000oooo`<00004<ol000<0003oooooool0Qoooo`00Qooo
o`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029
oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?oo
ooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000@co`02000000@co`3oooooooooool200000oooo`@00003
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`040000oooooooo00001S?o00;oool010000?ooooooo`0000;oool0
0`000?ooooooo`04oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0=oooo00@0003oooooool00006<ol01?ooo`030000oooooooo00;oool00`000?ooooooo`04
oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00006
<ol01Oooo`030000oooooooo00;oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000000ooool010000?ooooooo`0000Hco`02oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool2
00001c?o00?oool200001?ooo`800003oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?
oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 .12361 L
s
.34187 .12361 m
.34236 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Goool01Ol0VOooooooooooo`00000;oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_oo
o`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000
oooooooo017oool00ol0VOooooooo`0Uoooo00<0000co`0co`00>C?o00T0000doooo00<0003ooooo
ool05Oooo`00Ioooo`03o`2Ioooooooo02Goool00`0003?o03?o000c<ol01P0005Goool006Ooool0
0ol0VOooooooo`0Uoooo00<0000co`0co`00<C?o0080001Koooo001Woooo00?o09Woooooool09Ooo
o`030000<ol0<ol002lco`020000GOooo`00Ioooo`03o`2Ioooooooo02Goool00`0003?o03?o000/
<ol00`0005ooool006Ooool00ol0VOooooooo`0Uoooo0P0002Xco`030000H_ooo`00Ioooo`03o`2I
oooooooo02Goool00`0003?o03?o000W<ol00P0006Goool006Ooool00ol0VOooooooo`0Uoooo00<0
000co`0co`009S?o00030000oooooooo06Goool006Ooool00ol0VOooooooo`0Uoooo00<0000co`0c
o`009C?o00030000oooooooo06Koool006Ooool00ol0VOooooooo`0Uoooo00<0000co`0co`0093?o
00030000oooooooo06Ooool006Ooool00ol0VOooooooo`0Uoooo00<0000co`0co`008S?o0080001Z
oooo001Woooo00?o09Woooooool09Oooo`80000R<ol000<0003oooooool0J_ooo`00Ioooo`03o`2I
oooooooo02Goool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00Ioooo`03o`2Ioooooooo
02Goool00`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Ioooo`03o`2Ioooooooo02Goool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Ioooo`03o`2Ioooooooo02Goool00`0003?o
03?o000N<ol000<0003oooooool0KOooo`00Ioooo`03o`2Ioooooooo02Goool00`0003?o03?o000M
<ol000<0003oooooool0K_ooo`00Ioooo`03o`2Ioooooooo02Goool200007C?o00030000oooooooo
06ooool006Ooool00ol0VOooooooo`0Uoooo00<0000co`0co`006c?o00030000oooooooo073oool0
06Ooool00ol0VOooooooo`0Uoooo00<0000co`0co`006c?o00030000oooooooo073oool006Ooool0
0ol0VOooooooo`0Uoooo00<0000co`0co`006S?o00030000oooooooo077oool006Ooool00ol0VOoo
ooooo`0Uoooo00<0000co`0co`006S?o00030000oooooooo077oool006Ooool00ol0VOooooooo`0U
oooo00<0000co`0co`006C?o00030000oooooooo07;oool006Ooool00ol0VOooooooo`0Uoooo0P00
01Xco`000`000?ooooooo`1boooo001Woooo00?o09Woooooool09Oooo`030000<ol0<ol001Pco`00
0`000?ooooooo`1coooo001Woooo00?o09Woooooool09Oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001Woooo00?o09Woooooool09Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1d
oooo001Woooo00?o09Woooooool09Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001W
oooo00?o09Woooooool07Oooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool0
06Ooool00ol0VOooooooo`0Ooooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001Woooo00?o09Woooooool07oooo`030000oooooooo00?oool300005C?o00030000
oooooooo07Koool006Ooool00ol0VOooooooo`0Ooooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`1foooo001Woooo00?o09Woooooool07oooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00Ioooo`03o`2Ioooooooo01koool200001Ooo
o`030000<ol0<ol001@co`000`000?ooooooo`1goooo001Woooo00?o09Woooooool09Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001Woooo00?o09Woooooool09Oooo`030000<ol0<ol0
01<co`000`000?ooooooo`1hoooo001Woooo00?o09Woooooool09Oooo`80000D<ol000<0003ooooo
ool0N?ooo`00Ioooo`03o`2Ioooooooo02Goool00`0003?o03?o000C<ol000<0003oooooool0N?oo
o`00Ioooo`03o`2Ioooooooo02Goool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Iooo
o`03o`2Ioooooooo02Goool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Ioooo`03o`2I
oooooooo02Goool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Ioooo`03o`2Ioooooooo
02Goool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00Ioooo`03o`2Ioooooooo02Goool2
00004S?o00030000oooooooo07[oool006Ooool00ol0VOooooooo`0Uoooo00<0000co`0co`004C?o
00030000oooooooo07[oool006Ooool00ol0VOooooooo`0Uoooo00<0000co`0co`004C?o00030000
oooooooo07[oool006Ooool00ol0VOooooooo`0Uoooo00<0000co`0co`0043?o00030000oooooooo
07_oool006Ooool00ol0VOooooooo`0Uoooo00<0000co`0co`0043?o00030000oooooooo07_oool0
06Ooool00ol0VOooooooo`0Uoooo00<0000co`0co`0043?o00030000oooooooo07_oool006Ooool0
0ol0VOooooooo`0Uoooo00<0000co`0co`0043?o00030000oooooooo07_oool006Ooool00ol0VOoo
ooooo`0Uoooo0P00010co`000`000?ooooooo`1loooo001Woooo00?o09Woooooool09Oooo`030000
<ol0<ol000lco`000`000?ooooooo`1loooo001Woooo00?o09Woooooool09Oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001Woooo00?o09Woooooool09Oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001Woooo00?o09Woooooool09Oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001Woooo00?o09Woooooool09Oooo`030000<ol0<ol000hco`000`000?ooooooo`1m
oooo001Woooo00?o09Woooooool09Oooo`80000?<ol000<0003oooooool0OOooo`00Ioooo`03o`2I
oooooooo02Goool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Ioooo`03o`2Ioooooooo
02Goool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Ioooo`03o`2Ioooooooo02Goool0
0`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Ioooo`03o`2Ioooooooo01goool400001?oo
o`030000<ol0<ol000dco`000`000?ooooooo`1noooo001Woooo00?o09Woooooool07Oooo`030000
oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Ioooo`03o`2Ioooooooo
01koool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001Woooo00?o09Wooooo
ool07oooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Iooo
o`03o`2Ioooooooo01goool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00Ioooo`03o`2Ioooooooo01koool200001Oooo`030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001Woooo00?o09Woooooool09Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001Woooo00?o09Woooooool09Oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001W
oooo00?o09Woooooool09Oooo`80000=<ol000<0003oooooool0Ooooo`00Ioooo`03o`2Ioooooooo
02Goool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00Ioooo`03o`2Ioooooooo02Goool0
0`0003?o03?o000;<ol000<0003oooooool0P?ooo`00Ioooo`03o`2Ioooooooo02Goool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00Ioooo`03o`2Ioooooooo02Goool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00Ioooo`03o`2Ioooooooo02Goool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00Ioooo`03o`2Ioooooooo02Goool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Ioooo`03o`2Ioooooooo02Goool2000033?o00030000oooooooo083oool006Ooool0
0ol0VOooooooo`0Uoooo00<0000co`0co`002c?o00030000oooooooo083oool006Ooool00ol0VOoo
ooooo`0Uoooo00<0000co`0co`002S?o00030000oooooooo087oool006Ooool00ol0VOooooooo`0U
oooo00<0000co`0co`002S?o00030000oooooooo087oool006Ooool00ol0VOooooooo`0Uoooo00<0
000co`0co`002S?o00030000oooooooo087oool006Ooool00ol0VOooooooo`0Uoooo00<0000co`0c
o`002S?o00030000oooooooo087oool006Ooool00ol0VOooooooo`0Uoooo0P0000/co`000`000?oo
ooooo`21oooo001Woooo00?o09Woooooool09Oooo`030000<ol0<ol000Xco`000`000?ooooooo`21
oooo001Woooo00?o09Woooooool09Oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001W
oooo00?o09Woooooool09Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Woooo00?o
09Woooooool09Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Woooo00?o09Wooooo
ool09Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Woooo00?o09Woooooool09Ooo
o`80000:<ol000<0003oooooool0P_ooo`00Ioooo`03o`2Ioooooooo02Goool00`0003?o03?o0009
<ol000<0003oooooool0P_ooo`00Ioooo`03o`2Ioooooooo02Goool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00Ioooo`03o`2Ioooooooo02Goool00`0003?o03?o0008<ol000<0003ooooo
ool0Poooo`00Ioooo`03o`2Ioooooooo01koool200001Oooo`030000<ol0<ol000Pco`000`000?oo
ooooo`23oooo001Woooo00?o09Woooooool07Oooo`040000oooooooo00001?ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`23oooo001Woooo00?o09Woooooool07oooo`030000oooooooo00?oool3
000023?o00030000oooooooo08?oool006Ooool00ol0VOooooooo`0Poooo00<0003oooooool00_oo
o`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001Woooo00?o09Woooooool07Oooo`040000
oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001Woooo00?o09Wooooo
ool07_ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool006Ooool00ol0VOoo
ooooo`0Uoooo00<0000co`0co`001c?o00030000oooooooo08Coool006Ooool00ol0VOooooooo`0U
oooo00<0000co`0co`001c?o00030000oooooooo08Coool006Ooool00ol0VOooooooo`0Uoooo00<0
000co`0co`001c?o00030000oooooooo08Coool006Ooool00ol0VOooooooo`0Uoooo0P0000Pco`00
0`000?ooooooo`24oooo001Woooo00?o09Woooooool09Oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`24oooo001Woooo00?o09Woooooool09Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001Woooo00?o09Woooooool09Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001W
oooo00?o09Woooooool09Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Woooo00?o
09Woooooool09Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Woooo00?o09Wooooo
ool09Oooo`800007<ol000<0003oooooool0QOooo`00Ioooo`03o`2Ioooooooo02Goool00`0003?o
03?o0006<ol000<0003oooooool0QOooo`00Ioooo`03o`2Ioooooooo02Goool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00Ioooo`03o`2Ioooooooo02Goool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00Ioooo`03o`2Ioooooooo02Goool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00Ioooo`03o`2Ioooooooo02Goool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00Ioooo`03o`2Ioooooooo02Goool200001S?o00030000oooooooo08Koool006Ooool00ol0VOoo
ooooo`0Uoooo00<0000co`0co`001C?o00030000oooooooo08Koool006Ooool00ol0VOooooooo`0U
oooo00<0000co`0co`001C?o00030000oooooooo08Koool006Ooool00ol0VOooooooo`0Uoooo00<0
000co`0co`001C?o00030000oooooooo08Koool006Ooool00ol0VOooooooo`0Uoooo00<0000co`0c
o`001C?o00030000oooooooo08Koool006Ooool00ol0VOooooooo`0Uoooo00<0000co`0co`001C?o
00030000oooooooo08Koool006Ooool00ol0VOooooooo`0Uoooo0P0000Hco`000`000?ooooooo`26
oooo001Woooo00?o09Woooooool09Oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001W
oooo00?o09Woooooool09Oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Woooo00?o
09Woooooool09Oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Woooo00?o09Wooooo
ool09Oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Woooo00?o09Woooooool07ooo
o`<00003oooo00<0000co`0co`0013?o00030000oooooooo08Ooool006Ooool00ol0VOooooooo`0P
oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Woooo00?o
09Woooooool07Oooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003ooooo
ool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?oo
o`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7
<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Ooo
o`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Ooool2000013?o0080000013?o0?ooooooooooo`800005oooo0`0000;oool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0003oooooool00006<ol00_ooo`040000oooooooo00001Oooo`050000oooooooo
oooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo
00001S?o00Coool010000?ooooooooooo`D00003oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000<oooo00@0003oooooool00006<ol01Oooo`040000oooooooo00000_ooo`050000
oooooooooooo000007[oool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00006
<ol00_ooo`040000oooooooo00000oooo`030000oooo000000?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool04Oooo`800007<ol00oooo`800005oooo0P0000;oool00`000?ooooooo`1i
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.33304 .12361 L
.33788 .12361 L
.34055 .12361 L
.34309 .12361 L
.34549 .12361 L
.34615 .12361 L
.34685 .12361 L
s
.34685 .12361 m
.34735 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Koool01?l0VOooooooo`0000_oool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0
003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003ooooo
ool04_ooo`03o`2Ioooooooo02Coool00`0003?o03?o000i<ol02@0003Coool00`000?ooooooo`0E
oooo001Xoooo00?o09Woooooool09?ooo`030000<ol0<ol003<co`060000EOooo`00J?ooo`03o`2I
oooooooo02Coool00`0003?o03?o000a<ol00P0005_oool006Soool00ol0VOooooooo`0Toooo00<0
000co`0co`00;c?o0080001Moooo001Xoooo00?o09Woooooool09?ooo`030000<ol0<ol002`co`03
0000Goooo`00J?ooo`03o`2Ioooooooo02Coool20000:S?o00<0001Roooo001Xoooo00?o09Wooooo
ool09?ooo`030000<ol0<ol002Lco`020000IOooo`00J?ooo`03o`2Ioooooooo02Coool00`0003?o
03?o000V<ol000<0003oooooool0IOooo`00J?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000U
<ol000<0003oooooool0I_ooo`00J?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000T<ol000<0
003oooooool0Ioooo`00J?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000R<ol00P0006[oool0
06Soool00ol0VOooooooo`0Toooo0P00028co`000`000?ooooooo`1Zoooo001Xoooo00?o09Wooooo
ool09?ooo`030000<ol0<ol0020co`000`000?ooooooo`1[oooo001Xoooo00?o09Woooooool09?oo
o`030000<ol0<ol001lco`000`000?ooooooo`1/oooo001Xoooo00?o09Woooooool09?ooo`030000
<ol0<ol001lco`000`000?ooooooo`1/oooo001Xoooo00?o09Woooooool09?ooo`030000<ol0<ol0
01hco`000`000?ooooooo`1]oooo001Xoooo00?o09Woooooool09?ooo`030000<ol0<ol001dco`00
0`000?ooooooo`1^oooo001Xoooo00?o09Woooooool09?ooo`80000M<ol000<0003oooooool0Kooo
o`00J?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00J?oo
o`03o`2Ioooooooo02Coool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00J?ooo`03o`2I
oooooooo02Coool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00J?ooo`03o`2Ioooooooo
02Coool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00J?ooo`03o`2Ioooooooo02Coool0
0`0003?o03?o000I<ol000<0003oooooool0L_ooo`00J?ooo`03o`2Ioooooooo02Coool200006S?o
00030000oooooooo07;oool006Soool00ol0VOooooooo`0Toooo00<0000co`0co`0063?o00030000
oooooooo07?oool006Soool00ol0VOooooooo`0Toooo00<0000co`0co`0063?o00030000oooooooo
07?oool006Soool00ol0VOooooooo`0Toooo00<0000co`0co`005c?o00030000oooooooo07Coool0
06Soool00ol0VOooooooo`0Toooo00<0000co`0co`005c?o00030000oooooooo07Coool006Soool0
0ol0VOooooooo`0Loooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00J?oo
o`03o`2Ioooooooo01koool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo
07Goool006Soool00ol0VOooooooo`0Noooo00<0003oooooool00oooo`<0000E<ol000<0003ooooo
ool0M_ooo`00J?ooo`03o`2Ioooooooo01koool00`000?ooooooo`03oooo00<0000co`0co`005C?o
00030000oooooooo07Koool006Soool00ol0VOooooooo`0Noooo00<0003oooooool00oooo`030000
<ol0<ol001Dco`000`000?ooooooo`1foooo001Xoooo00?o09Woooooool07Oooo`800005oooo00<0
000co`0co`0053?o00030000oooooooo07Ooool006Soool00ol0VOooooooo`0Toooo00<0000co`0c
o`0053?o00030000oooooooo07Ooool006Soool00ol0VOooooooo`0Toooo00<0000co`0co`004c?o
00030000oooooooo07Soool006Soool00ol0VOooooooo`0Toooo0P0001@co`000`000?ooooooo`1h
oooo001Xoooo00?o09Woooooool09?ooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo001X
oooo00?o09Woooooool09?ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001Xoooo00?o
09Woooooool09?ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001Xoooo00?o09Wooooo
ool09?ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001Xoooo00?o09Woooooool09?oo
o`030000<ol0<ol0014co`000`000?ooooooo`1joooo001Xoooo00?o09Woooooool09?ooo`80000B
<ol000<0003oooooool0N_ooo`00J?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000A<ol000<0
003oooooool0N_ooo`00J?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000A<ol000<0003ooooo
ool0N_ooo`00J?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000@<ol000<0003oooooool0Nooo
o`00J?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00J?oo
o`03o`2Ioooooooo02Coool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00J?ooo`03o`2I
oooooooo02Coool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00J?ooo`03o`2Ioooooooo
02Coool2000043?o00030000oooooooo07coool006Soool00ol0VOooooooo`0Toooo00<0000co`0c
o`003c?o00030000oooooooo07coool006Soool00ol0VOooooooo`0Toooo00<0000co`0co`003c?o
00030000oooooooo07coool006Soool00ol0VOooooooo`0Toooo00<0000co`0co`003c?o00030000
oooooooo07coool006Soool00ol0VOooooooo`0Toooo00<0000co`0co`003c?o00030000oooooooo
07coool006Soool00ol0VOooooooo`0Toooo00<0000co`0co`003S?o00030000oooooooo07goool0
06Soool00ol0VOooooooo`0Toooo0P0000lco`000`000?ooooooo`1moooo001Xoooo00?o09Wooooo
ool09?ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001Xoooo00?o09Woooooool09?oo
o`030000<ol0<ol000hco`000`000?ooooooo`1moooo001Xoooo00?o09Woooooool09?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001Xoooo00?o09Woooooool07?ooo`@00004oooo00<0
000co`0co`003C?o00030000oooooooo07koool006Soool00ol0VOooooooo`0Loooo00<0003ooooo
ool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo001Xoooo00?o09Woooooool07Ooo
o`030000oooooooo00Coool300003C?o00030000oooooooo07koool006Soool00ol0VOooooooo`0N
oooo00<0003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo001Xoooo00?o
09Woooooool07?ooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001Xoooo00?o09Woooooool07Oooo`800005oooo00<0000co`0co`0033?o00030000oooooooo
07ooool006Soool00ol0VOooooooo`0Toooo00<0000co`0co`0033?o00030000oooooooo07ooool0
06Soool00ol0VOooooooo`0Toooo00<0000co`0co`0033?o00030000oooooooo07ooool006Soool0
0ol0VOooooooo`0Toooo0P0000dco`000`000?ooooooo`1ooooo001Xoooo00?o09Woooooool09?oo
o`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001Xoooo00?o09Woooooool09?ooo`030000
<ol0<ol000/co`000`000?ooooooo`20oooo001Xoooo00?o09Woooooool09?ooo`030000<ol0<ol0
00/co`000`000?ooooooo`20oooo001Xoooo00?o09Woooooool09?ooo`030000<ol0<ol000/co`00
0`000?ooooooo`20oooo001Xoooo00?o09Woooooool09?ooo`030000<ol0<ol000/co`000`000?oo
ooooo`20oooo001Xoooo00?o09Woooooool09?ooo`030000<ol0<ol000/co`000`000?ooooooo`20
oooo001Xoooo00?o09Woooooool09?ooo`80000<<ol000<0003oooooool0P?ooo`00J?ooo`03o`2I
oooooooo02Coool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00J?ooo`03o`2Ioooooooo
02Coool00`0003?o03?o000:<ol000<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo02Coool0
0`0003?o03?o000:<ol000<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo02Coool00`0003?o
03?o000:<ol000<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo02Coool00`0003?o03?o000:
<ol000<0003oooooool0POooo`00J?ooo`03o`2Ioooooooo02Coool200002c?o00030000oooooooo
087oool006Soool00ol0VOooooooo`0Toooo00<0000co`0co`002S?o00030000oooooooo087oool0
06Soool00ol0VOooooooo`0Toooo00<0000co`0co`002S?o00030000oooooooo087oool006Soool0
0ol0VOooooooo`0Toooo00<0000co`0co`002C?o00030000oooooooo08;oool006Soool00ol0VOoo
ooooo`0Toooo00<0000co`0co`002C?o00030000oooooooo08;oool006Soool00ol0VOooooooo`0T
oooo00<0000co`0co`002C?o00030000oooooooo08;oool006Soool00ol0VOooooooo`0Toooo0P00
00Xco`000`000?ooooooo`22oooo001Xoooo00?o09Woooooool09?ooo`030000<ol0<ol000Tco`00
0`000?ooooooo`22oooo001Xoooo00?o09Woooooool09?ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`22oooo001Xoooo00?o09Woooooool09?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001Xoooo00?o09Woooooool07Oooo`800005oooo00<0000co`0co`0023?o00030000oooooooo
08?oool006Soool00ol0VOooooooo`0Loooo00@0003oooooool00004oooo00<0000co`0co`0023?o
00030000oooooooo08?oool006Soool00ol0VOooooooo`0Noooo00<0003oooooool00oooo`<00008
<ol000<0003oooooool0Poooo`00J?ooo`03o`2Ioooooooo01ooool00`000?ooooooo`02oooo00<0
000co`0co`0023?o00030000oooooooo08?oool006Soool00ol0VOooooooo`0Loooo00@0003ooooo
ool00004oooo00<0000co`0co`0023?o00030000oooooooo08?oool006Soool00ol0VOooooooo`0M
oooo0P0000Goool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00J?ooo`03o`2Ioooooooo
02Coool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00J?ooo`03o`2Ioooooooo02Coool0
0`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00J?ooo`03o`2Ioooooooo02Coool00`0003?o
03?o0007<ol000<0003oooooool0Q?ooo`00J?ooo`03o`2Ioooooooo02Coool2000023?o00030000
oooooooo08Coool006Soool00ol0VOooooooo`0Toooo00<0000co`0co`001c?o00030000oooooooo
08Coool006Soool00ol0VOooooooo`0Toooo00<0000co`0co`001c?o00030000oooooooo08Coool0
06Soool00ol0VOooooooo`0Toooo00<0000co`0co`001c?o00030000oooooooo08Coool006Soool0
0ol0VOooooooo`0Toooo00<0000co`0co`001S?o00030000oooooooo08Goool006Soool00ol0VOoo
ooooo`0Toooo00<0000co`0co`001S?o00030000oooooooo08Goool006Soool00ol0VOooooooo`0T
oooo0P0000Lco`000`000?ooooooo`25oooo001Xoooo00?o09Woooooool09?ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`25oooo001Xoooo00?o09Woooooool09?ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`25oooo001Xoooo00?o09Woooooool09?ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`25oooo001Xoooo00?o09Woooooool09?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25
oooo001Xoooo00?o09Woooooool09?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001X
oooo00?o09Woooooool09?ooo`800006<ol000<0003oooooool0Q_ooo`00J?ooo`03o`2Ioooooooo
02Coool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00J?ooo`03o`2Ioooooooo02Coool0
0`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00J?ooo`03o`2Ioooooooo02Coool00`0003?o
03?o0005<ol000<0003oooooool0Q_ooo`00J?ooo`03o`2Ioooooooo02Coool00`0003?o03?o0005
<ol000<0003oooooool0Q_ooo`00J?ooo`03o`2Ioooooooo02Coool00`0003?o03?o0005<ol000<0
003oooooool0Q_ooo`00J?ooo`03o`2Ioooooooo02Coool200001S?o00030000oooooooo08Koool0
06Soool00ol0VOooooooo`0Toooo00<0000co`0co`001C?o00030000oooooooo08Koool006Soool0
0ol0VOooooooo`0Toooo00<0000co`0co`001C?o00030000oooooooo08Koool006Soool00ol0VOoo
ooooo`0Toooo00<0000co`0co`0013?o00030000oooooooo08Ooool006Soool00ol0VOooooooo`0T
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool006Soool00ol0VOooooooo`0Noooo0`00
00?oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00J?ooo`03o`2Ioooooooo01ooool0
0`000?ooooooo`02oooo00<0000co`0co`0013?o00030000oooooooo08Ooool006Soool00ol0VOoo
ooooo`0Loooo1@0000?oool3000013?o00030000oooooooo08Ooool008Ooool010000?ooooooo`00
00Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o
08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o
00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01oooo`800004<ol00P000004<ol0oooooooooooo0P0000?oool300001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Goool010000?ooooooo`0000Hco`02oooo00@0003oooooool00002oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0
003oooooool00006<ol01?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00006<ol01Ooo
o`030000oooooooo00<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00ooool010000?ooooooo`0000Hco`02oooo00@0003oooooool00003oooo00<0003oooooool00ooo
o`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`03oooo0P0000Coool3
00000_ooo`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.33304 .12361 L
.33788 .12361 L
.34309 .12361 L
.34566 .12361 L
.34811 .12361 L
.35031 .12361 L
.35156 .12361 L
s
.35156 .12361 m
.35202 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Ooool00ol0VOooo`00000;oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
01?oool00ol0VOooooooo`0Soooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00JOooo`03o`2Ioooooooo02?oool00`0003?o03?o000c<ol01P0005Goool006Woool00ol0VOoo
ooooo`0Soooo00<0000co`0co`00<C?o0080001Koooo001Yoooo00?o09Woooooool08oooo`030000
<ol0<ol002lco`020000GOooo`00JOooo`03o`2Ioooooooo02?oool00`0003?o03?o000/<ol00`00
05ooool006Woool00ol0VOooooooo`0Soooo0P0002Xco`030000H_ooo`00JOooo`03o`2Ioooooooo
02?oool00`0003?o03?o000W<ol00P0006Goool006Woool00ol0VOooooooo`0Soooo00<0000co`0c
o`009S?o00030000oooooooo06Goool006Woool00ol0VOooooooo`0Soooo00<0000co`0co`009C?o
00030000oooooooo06Koool006Woool00ol0VOooooooo`0Soooo00<0000co`0co`0093?o00030000
oooooooo06Ooool006Woool00ol0VOooooooo`0Soooo00<0000co`0co`008S?o0080001Zoooo001Y
oooo00?o09Woooooool08oooo`80000R<ol000<0003oooooool0J_ooo`00JOooo`03o`2Ioooooooo
02?oool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00JOooo`03o`2Ioooooooo02?oool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00JOooo`03o`2Ioooooooo02?oool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00JOooo`03o`2Ioooooooo02?oool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00JOooo`03o`2Ioooooooo02?oool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00JOooo`03o`2Ioooooooo02?oool200007C?o00030000oooooooo06ooool0
06Woool00ol0VOooooooo`0Soooo00<0000co`0co`006c?o00030000oooooooo073oool006Woool0
0ol0VOooooooo`0Soooo00<0000co`0co`006c?o00030000oooooooo073oool006Woool00ol0VOoo
ooooo`0Soooo00<0000co`0co`006S?o00030000oooooooo077oool006Woool00ol0VOooooooo`0S
oooo00<0000co`0co`006S?o00030000oooooooo077oool006Woool00ol0VOooooooo`0Soooo00<0
000co`0co`006C?o00030000oooooooo07;oool006Woool00ol0VOooooooo`0Soooo0P0001Xco`00
0`000?ooooooo`1boooo001Yoooo00?o09Woooooool08oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001Yoooo00?o09Woooooool08oooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo001Yoooo00?o09Woooooool08oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001Y
oooo00?o09Woooooool08oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001Yoooo00?o
09Woooooool06oooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool006Woool0
0ol0VOooooooo`0Moooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo001Yoooo00?o09Woooooool07Oooo`030000oooooooo00?oool300005C?o00030000oooooooo
07Koool006Woool00ol0VOooooooo`0Moooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1foooo001Yoooo00?o09Woooooool07Oooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00JOooo`03o`2Ioooooooo01coool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001Yoooo00?o09Woooooool08oooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo001Yoooo00?o09Woooooool08oooo`030000<ol0<ol001<co`00
0`000?ooooooo`1hoooo001Yoooo00?o09Woooooool08oooo`80000D<ol000<0003oooooool0N?oo
o`00JOooo`03o`2Ioooooooo02?oool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00JOoo
o`03o`2Ioooooooo02?oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00JOooo`03o`2I
oooooooo02?oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00JOooo`03o`2Ioooooooo
02?oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00JOooo`03o`2Ioooooooo02?oool0
0`0003?o03?o000A<ol000<0003oooooool0N_ooo`00JOooo`03o`2Ioooooooo02?oool200004S?o
00030000oooooooo07[oool006Woool00ol0VOooooooo`0Soooo00<0000co`0co`004C?o00030000
oooooooo07[oool006Woool00ol0VOooooooo`0Soooo00<0000co`0co`004C?o00030000oooooooo
07[oool006Woool00ol0VOooooooo`0Soooo00<0000co`0co`0043?o00030000oooooooo07_oool0
06Woool00ol0VOooooooo`0Soooo00<0000co`0co`0043?o00030000oooooooo07_oool006Woool0
0ol0VOooooooo`0Soooo00<0000co`0co`0043?o00030000oooooooo07_oool006Woool00ol0VOoo
ooooo`0Soooo00<0000co`0co`0043?o00030000oooooooo07_oool006Woool00ol0VOooooooo`0S
oooo0P00010co`000`000?ooooooo`1loooo001Yoooo00?o09Woooooool08oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001Yoooo00?o09Woooooool08oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001Yoooo00?o09Woooooool08oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001Yoooo00?o09Woooooool08oooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo001Yoooo00?o09Woooooool08oooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001Y
oooo00?o09Woooooool08oooo`80000?<ol000<0003oooooool0OOooo`00JOooo`03o`2Ioooooooo
02?oool00`0003?o03?o000><ol000<0003oooooool0OOooo`00JOooo`03o`2Ioooooooo02?oool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00JOooo`03o`2Ioooooooo02?oool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00JOooo`03o`2Ioooooooo01_oool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001Yoooo00?o09Woooooool06oooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00JOooo`03o`2Ioooooooo01coool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001Yoooo00?o09Woooooool07Ooo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00JOooo`03o`2I
oooooooo01_oool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00JOooo`03o`2Ioooooooo01coool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001Yoooo00?o09Woooooool08oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001Y
oooo00?o09Woooooool08oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001Yoooo00?o
09Woooooool08oooo`80000=<ol000<0003oooooool0Ooooo`00JOooo`03o`2Ioooooooo02?oool0
0`0003?o03?o000<<ol000<0003oooooool0Ooooo`00JOooo`03o`2Ioooooooo02?oool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00JOooo`03o`2Ioooooooo02?oool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00JOooo`03o`2Ioooooooo02?oool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00JOooo`03o`2Ioooooooo02?oool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00JOooo`03o`2Ioooooooo02?oool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00JOooo`03o`2Ioooooooo02?oool2000033?o00030000oooooooo083oool006Woool00ol0VOoo
ooooo`0Soooo00<0000co`0co`002c?o00030000oooooooo083oool006Woool00ol0VOooooooo`0S
oooo00<0000co`0co`002S?o00030000oooooooo087oool006Woool00ol0VOooooooo`0Soooo00<0
000co`0co`002S?o00030000oooooooo087oool006Woool00ol0VOooooooo`0Soooo00<0000co`0c
o`002S?o00030000oooooooo087oool006Woool00ol0VOooooooo`0Soooo00<0000co`0co`002S?o
00030000oooooooo087oool006Woool00ol0VOooooooo`0Soooo0P0000/co`000`000?ooooooo`21
oooo001Yoooo00?o09Woooooool08oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Y
oooo00?o09Woooooool08oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001Yoooo00?o
09Woooooool08oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Yoooo00?o09Wooooo
ool08oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Yoooo00?o09Woooooool08ooo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001Yoooo00?o09Woooooool08oooo`80000:
<ol000<0003oooooool0P_ooo`00JOooo`03o`2Ioooooooo02?oool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00JOooo`03o`2Ioooooooo02?oool00`0003?o03?o0009<ol000<0003ooooo
ool0P_ooo`00JOooo`03o`2Ioooooooo02?oool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00JOooo`03o`2Ioooooooo01coool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001Yoooo00?o09Woooooool06oooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo001Yoooo00?o09Woooooool07Oooo`030000oooooooo00?oool3000023?o
00030000oooooooo08?oool006Woool00ol0VOooooooo`0Noooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo001Yoooo00?o09Woooooool06oooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001Yoooo00?o09Woooooool07?oo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool006Woool00ol0VOooooooo`0S
oooo00<0000co`0co`001c?o00030000oooooooo08Coool006Woool00ol0VOooooooo`0Soooo00<0
000co`0co`001c?o00030000oooooooo08Coool006Woool00ol0VOooooooo`0Soooo00<0000co`0c
o`001c?o00030000oooooooo08Coool006Woool00ol0VOooooooo`0Soooo0P0000Pco`000`000?oo
ooooo`24oooo001Yoooo00?o09Woooooool08oooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001Yoooo00?o09Woooooool08oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Y
oooo00?o09Woooooool08oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001Yoooo00?o
09Woooooool08oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Yoooo00?o09Wooooo
ool08oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001Yoooo00?o09Woooooool08ooo
o`800007<ol000<0003oooooool0QOooo`00JOooo`03o`2Ioooooooo02?oool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00JOooo`03o`2Ioooooooo02?oool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00JOooo`03o`2Ioooooooo02?oool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00JOooo`03o`2Ioooooooo02?oool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00JOooo`03o`2Ioooooooo02?oool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00JOoo
o`03o`2Ioooooooo02?oool200001S?o00030000oooooooo08Koool006Woool00ol0VOooooooo`0S
oooo00<0000co`0co`001C?o00030000oooooooo08Koool006Woool00ol0VOooooooo`0Soooo00<0
000co`0co`001C?o00030000oooooooo08Koool006Woool00ol0VOooooooo`0Soooo00<0000co`0c
o`001C?o00030000oooooooo08Koool006Woool00ol0VOooooooo`0Soooo00<0000co`0co`001C?o
00030000oooooooo08Koool006Woool00ol0VOooooooo`0Soooo00<0000co`0co`001C?o00030000
oooooooo08Koool006Woool00ol0VOooooooo`0Soooo0P0000Hco`000`000?ooooooo`26oooo001Y
oooo00?o09Woooooool08oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Yoooo00?o
09Woooooool08oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001Yoooo00?o09Wooooo
ool08oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Yoooo00?o09Woooooool08ooo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Yoooo00?o09Woooooool07Oooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool006Woool00ol0VOooooooo`0Noooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001Yoooo00?o09Wooooo
ool06oooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool2000013?o0080000013?o0?ooooooooooo`800004oooo0P0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05
oooo00@0003oooooool00006<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000
oooooooo00001S?o00Coool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00001S?o00Goool0
10000?ooooooooooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00ooool010000?ooooooo`0000Hco`02oooo00@0003oooooool00002oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200001c?o00?oool200001?oo
o`800003oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.33304 .12361 L
.34309 .12361 L
.34772 .12361 L
.35028 .12361 L
.35271 .12361 L
.35496 .12361 L
.35624 .12361 L
s
.35624 .12361 m
.35671 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
01Goool00ol0VOooooooo`0Qoooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00Joooo`03o`2Ioooooooo027oool00`0003?o03?o000c<ol01P0005Goool006_oool00ol0VOoo
ooooo`0Qoooo00<0000co`0co`00<C?o0080001Koooo001[oooo00?o09Woooooool08Oooo`030000
<ol0<ol002lco`020000GOooo`00Joooo`03o`2Ioooooooo027oool00`0003?o03?o000/<ol00`00
05ooool006_oool00ol0VOooooooo`0Qoooo0P0002Xco`030000H_ooo`00Joooo`03o`2Ioooooooo
027oool00`0003?o03?o000W<ol00P0006Goool006_oool00ol0VOooooooo`0Qoooo00<0000co`0c
o`009S?o00030000oooooooo06Goool006_oool00ol0VOooooooo`0Qoooo00<0000co`0co`009C?o
00030000oooooooo06Koool006_oool00ol0VOooooooo`0Qoooo00<0000co`0co`0093?o00030000
oooooooo06Ooool006_oool00ol0VOooooooo`0Qoooo00<0000co`0co`008S?o0080001Zoooo001[
oooo00?o09Woooooool08Oooo`80000R<ol000<0003oooooool0J_ooo`00Joooo`03o`2Ioooooooo
027oool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00Joooo`03o`2Ioooooooo027oool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Joooo`03o`2Ioooooooo027oool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00Joooo`03o`2Ioooooooo027oool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00Joooo`03o`2Ioooooooo027oool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00Joooo`03o`2Ioooooooo027oool200007C?o00030000oooooooo06ooool0
06_oool00ol0VOooooooo`0Qoooo00<0000co`0co`006c?o00030000oooooooo073oool006_oool0
0ol0VOooooooo`0Qoooo00<0000co`0co`006c?o00030000oooooooo073oool006_oool00ol0VOoo
ooooo`0Qoooo00<0000co`0co`006S?o00030000oooooooo077oool006_oool00ol0VOooooooo`0Q
oooo00<0000co`0co`006S?o00030000oooooooo077oool006_oool00ol0VOooooooo`0Qoooo00<0
000co`0co`006C?o00030000oooooooo07;oool006_oool00ol0VOooooooo`0Qoooo0P0001Xco`00
0`000?ooooooo`1boooo001[oooo00?o09Woooooool08Oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001[oooo00?o09Woooooool08Oooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo001[oooo00?o09Woooooool08Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001[
oooo00?o09Woooooool08Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001[oooo00?o
09Woooooool06Oooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool006_oool0
0ol0VOooooooo`0Koooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo001[oooo00?o09Woooooool06oooo`030000oooooooo00?oool300005C?o00030000oooooooo
07Koool006_oool00ol0VOooooooo`0Koooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1foooo001[oooo00?o09Woooooool06oooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00Joooo`03o`2Ioooooooo01[oool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001[oooo00?o09Woooooool08Oooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo001[oooo00?o09Woooooool08Oooo`030000<ol0<ol001<co`00
0`000?ooooooo`1hoooo001[oooo00?o09Woooooool08Oooo`80000D<ol000<0003oooooool0N?oo
o`00Joooo`03o`2Ioooooooo027oool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00Jooo
o`03o`2Ioooooooo027oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Joooo`03o`2I
oooooooo027oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Joooo`03o`2Ioooooooo
027oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Joooo`03o`2Ioooooooo027oool0
0`0003?o03?o000A<ol000<0003oooooool0N_ooo`00Joooo`03o`2Ioooooooo027oool200004S?o
00030000oooooooo07[oool006_oool00ol0VOooooooo`0Qoooo00<0000co`0co`004C?o00030000
oooooooo07[oool006_oool00ol0VOooooooo`0Qoooo00<0000co`0co`004C?o00030000oooooooo
07[oool006_oool00ol0VOooooooo`0Qoooo00<0000co`0co`0043?o00030000oooooooo07_oool0
06_oool00ol0VOooooooo`0Qoooo00<0000co`0co`0043?o00030000oooooooo07_oool006_oool0
0ol0VOooooooo`0Qoooo00<0000co`0co`0043?o00030000oooooooo07_oool006_oool00ol0VOoo
ooooo`0Qoooo00<0000co`0co`0043?o00030000oooooooo07_oool006_oool00ol0VOooooooo`0Q
oooo0P00010co`000`000?ooooooo`1loooo001[oooo00?o09Woooooool08Oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001[oooo00?o09Woooooool08Oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001[oooo00?o09Woooooool08Oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001[oooo00?o09Woooooool08Oooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo001[oooo00?o09Woooooool08Oooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001[
oooo00?o09Woooooool08Oooo`80000?<ol000<0003oooooool0OOooo`00Joooo`03o`2Ioooooooo
027oool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Joooo`03o`2Ioooooooo027oool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00Joooo`03o`2Ioooooooo027oool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00Joooo`03o`2Ioooooooo01Woool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001[oooo00?o09Woooooool06Oooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Joooo`03o`2Ioooooooo01[oool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001[oooo00?o09Woooooool06ooo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Joooo`03o`2I
oooooooo01Woool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00Joooo`03o`2Ioooooooo01[oool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001[oooo00?o09Woooooool08Oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001[
oooo00?o09Woooooool08Oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001[oooo00?o
09Woooooool08Oooo`80000=<ol000<0003oooooool0Ooooo`00Joooo`03o`2Ioooooooo027oool0
0`0003?o03?o000<<ol000<0003oooooool0Ooooo`00Joooo`03o`2Ioooooooo027oool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00Joooo`03o`2Ioooooooo027oool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00Joooo`03o`2Ioooooooo027oool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00Joooo`03o`2Ioooooooo027oool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Joooo`03o`2Ioooooooo027oool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00Joooo`03o`2Ioooooooo027oool2000033?o00030000oooooooo083oool006_oool00ol0VOoo
ooooo`0Qoooo00<0000co`0co`002c?o00030000oooooooo083oool006_oool00ol0VOooooooo`0Q
oooo00<0000co`0co`002S?o00030000oooooooo087oool006_oool00ol0VOooooooo`0Qoooo00<0
000co`0co`002S?o00030000oooooooo087oool006_oool00ol0VOooooooo`0Qoooo00<0000co`0c
o`002S?o00030000oooooooo087oool006_oool00ol0VOooooooo`0Qoooo00<0000co`0co`002S?o
00030000oooooooo087oool006_oool00ol0VOooooooo`0Qoooo0P0000/co`000`000?ooooooo`21
oooo001[oooo00?o09Woooooool08Oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001[
oooo00?o09Woooooool08Oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001[oooo00?o
09Woooooool08Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001[oooo00?o09Wooooo
ool08Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001[oooo00?o09Woooooool08Ooo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001[oooo00?o09Woooooool08Oooo`80000:
<ol000<0003oooooool0P_ooo`00Joooo`03o`2Ioooooooo027oool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00Joooo`03o`2Ioooooooo027oool00`0003?o03?o0009<ol000<0003ooooo
ool0P_ooo`00Joooo`03o`2Ioooooooo027oool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00Joooo`03o`2Ioooooooo01[oool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001[oooo00?o09Woooooool06Oooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo001[oooo00?o09Woooooool06oooo`030000oooooooo00?oool3000023?o
00030000oooooooo08?oool006_oool00ol0VOooooooo`0Loooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo001[oooo00?o09Woooooool06Oooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001[oooo00?o09Woooooool06_oo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool006_oool00ol0VOooooooo`0Q
oooo00<0000co`0co`001c?o00030000oooooooo08Coool006_oool00ol0VOooooooo`0Qoooo00<0
000co`0co`001c?o00030000oooooooo08Coool006_oool00ol0VOooooooo`0Qoooo00<0000co`0c
o`001c?o00030000oooooooo08Coool006_oool00ol0VOooooooo`0Qoooo0P0000Pco`000`000?oo
ooooo`24oooo001[oooo00?o09Woooooool08Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001[oooo00?o09Woooooool08Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001[
oooo00?o09Woooooool08Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001[oooo00?o
09Woooooool08Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001[oooo00?o09Wooooo
ool08Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001[oooo00?o09Woooooool08Ooo
o`800007<ol000<0003oooooool0QOooo`00Joooo`03o`2Ioooooooo027oool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00Joooo`03o`2Ioooooooo027oool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00Joooo`03o`2Ioooooooo027oool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00Joooo`03o`2Ioooooooo027oool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00Joooo`03o`2Ioooooooo027oool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00Jooo
o`03o`2Ioooooooo027oool200001S?o00030000oooooooo08Koool006_oool00ol0VOooooooo`0Q
oooo00<0000co`0co`001C?o00030000oooooooo08Koool006_oool00ol0VOooooooo`0Qoooo00<0
000co`0co`001C?o00030000oooooooo08Koool006_oool00ol0VOooooooo`0Qoooo00<0000co`0c
o`001C?o00030000oooooooo08Koool006_oool00ol0VOooooooo`0Qoooo00<0000co`0co`001C?o
00030000oooooooo08Koool006_oool00ol0VOooooooo`0Qoooo00<0000co`0co`001C?o00030000
oooooooo08Koool006_oool00ol0VOooooooo`0Qoooo0P0000Hco`000`000?ooooooo`26oooo001[
oooo00?o09Woooooool08Oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001[oooo00?o
09Woooooool08Oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001[oooo00?o09Wooooo
ool08Oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001[oooo00?o09Woooooool08Ooo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo001[oooo00?o09Woooooool06oooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool006_oool00ol0VOooooooo`0Loooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001[oooo00?o09Wooooo
ool06Oooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00O?ooo`030000oooooooo013oool7<ol02ooo
o`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool01_ooo`Lco`0<
oooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Koool00c?o000000000004<ol00P0000Goool300000_ooo`030000oooooooo07_oool007_oool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0100003?o
03?o000000<co`08oooo00D0003oooooooooool00000OOooo`00N_ooo`030000oooooooo00;oool0
0`000?ooooooo`0=oooo00@0000co`0co`000003<ol01Oooo`D00003oooo00<0003oooooool0N_oo
o`00Noooo`030000oooooooo00D0000<oooo00@0000co`0co`000003<ol01Oooo`040000oooooooo
00000oooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0000co`0c
o`000003<ol01_ooo`030000oooo000000?oool00`000?ooooooo`1koooo001loooo00<0003ooooo
ool04?ooo`03<ol00000000000@co`07oooo0P0000;oool00`000?ooooooo`1loooo002?oooo1c?o
08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.35271 .12361 L
.35742 .12361 L
.35948 .12361 L
.36057 .12361 L
.36173 .12361 L
s
.36173 .12361 m
.36221 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?l0VOooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
01Koool00ol0VOooooooo`0Poooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00K?ooo`03o`2Ioooooooo023oool00`0003?o03?o000c<ol01P0005Goool006coool00ol0VOoo
ooooo`0Poooo00<0000co`0co`00<C?o0080001Koooo001/oooo00?o09Woooooool08?ooo`030000
<ol0<ol002lco`020000GOooo`00K?ooo`03o`2Ioooooooo023oool00`0003?o03?o000/<ol00`00
05ooool006coool00ol0VOooooooo`0Poooo0P0002Xco`030000H_ooo`00K?ooo`03o`2Ioooooooo
023oool00`0003?o03?o000W<ol00P0006Goool006coool00ol0VOooooooo`0Poooo00<0000co`0c
o`009S?o00030000oooooooo06Goool006coool00ol0VOooooooo`0Poooo00<0000co`0co`009C?o
00030000oooooooo06Koool006coool00ol0VOooooooo`0Poooo00<0000co`0co`0093?o00030000
oooooooo06Ooool006coool00ol0VOooooooo`0Poooo00<0000co`0co`008S?o0080001Zoooo001/
oooo00?o09Woooooool08?ooo`80000R<ol000<0003oooooool0J_ooo`00K?ooo`03o`2Ioooooooo
023oool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00K?ooo`03o`2Ioooooooo023oool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00K?ooo`03o`2Ioooooooo023oool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00K?ooo`03o`2Ioooooooo023oool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00K?ooo`03o`2Ioooooooo023oool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00K?ooo`03o`2Ioooooooo023oool200007C?o00030000oooooooo06ooool0
06coool00ol0VOooooooo`0Poooo00<0000co`0co`006c?o00030000oooooooo073oool006coool0
0ol0VOooooooo`0Poooo00<0000co`0co`006c?o00030000oooooooo073oool006coool00ol0VOoo
ooooo`0Poooo00<0000co`0co`006S?o00030000oooooooo077oool006coool00ol0VOooooooo`0P
oooo00<0000co`0co`006S?o00030000oooooooo077oool006coool00ol0VOooooooo`0Poooo00<0
000co`0co`006C?o00030000oooooooo07;oool006coool00ol0VOooooooo`0Poooo0P0001Xco`00
0`000?ooooooo`1boooo001/oooo00?o09Woooooool08?ooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001/oooo00?o09Woooooool08?ooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo001/oooo00?o09Woooooool08?ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001/
oooo00?o09Woooooool08?ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001/oooo00?o
09Woooooool06?ooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool006coool0
0ol0VOooooooo`0Joooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo001/oooo00?o09Woooooool06_ooo`030000oooooooo00?oool300005C?o00030000oooooooo
07Koool006coool00ol0VOooooooo`0Joooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1foooo001/oooo00?o09Woooooool06_ooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00K?ooo`03o`2Ioooooooo01Woool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001/oooo00?o09Woooooool08?ooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo001/oooo00?o09Woooooool08?ooo`030000<ol0<ol001<co`00
0`000?ooooooo`1hoooo001/oooo00?o09Woooooool08?ooo`80000D<ol000<0003oooooool0N?oo
o`00K?ooo`03o`2Ioooooooo023oool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00K?oo
o`03o`2Ioooooooo023oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00K?ooo`03o`2I
oooooooo023oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00K?ooo`03o`2Ioooooooo
023oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00K?ooo`03o`2Ioooooooo023oool0
0`0003?o03?o000A<ol000<0003oooooool0N_ooo`00K?ooo`03o`2Ioooooooo023oool200004S?o
00030000oooooooo07[oool006coool00ol0VOooooooo`0Poooo00<0000co`0co`004C?o00030000
oooooooo07[oool006coool00ol0VOooooooo`0Poooo00<0000co`0co`004C?o00030000oooooooo
07[oool006coool00ol0VOooooooo`0Poooo00<0000co`0co`0043?o00030000oooooooo07_oool0
06coool00ol0VOooooooo`0Poooo00<0000co`0co`0043?o00030000oooooooo07_oool006coool0
0ol0VOooooooo`0Poooo00<0000co`0co`0043?o00030000oooooooo07_oool006coool00ol0VOoo
ooooo`0Poooo00<0000co`0co`0043?o00030000oooooooo07_oool006coool00ol0VOooooooo`0P
oooo0P00010co`000`000?ooooooo`1loooo001/oooo00?o09Woooooool08?ooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001/oooo00?o09Woooooool08?ooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001/oooo00?o09Woooooool08?ooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001/oooo00?o09Woooooool08?ooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo001/oooo00?o09Woooooool08?ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001/
oooo00?o09Woooooool08?ooo`80000?<ol000<0003oooooool0OOooo`00K?ooo`03o`2Ioooooooo
023oool00`0003?o03?o000><ol000<0003oooooool0OOooo`00K?ooo`03o`2Ioooooooo023oool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00K?ooo`03o`2Ioooooooo023oool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00K?ooo`03o`2Ioooooooo01Soool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001/oooo00?o09Woooooool06?ooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00K?ooo`03o`2Ioooooooo01Woool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001/oooo00?o09Woooooool06_oo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00K?ooo`03o`2I
oooooooo01Soool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00K?ooo`03o`2Ioooooooo01Woool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001/oooo00?o09Woooooool08?ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001/
oooo00?o09Woooooool08?ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001/oooo00?o
09Woooooool08?ooo`80000=<ol000<0003oooooool0Ooooo`00K?ooo`03o`2Ioooooooo023oool0
0`0003?o03?o000<<ol000<0003oooooool0Ooooo`00K?ooo`03o`2Ioooooooo023oool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00K?ooo`03o`2Ioooooooo023oool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00K?ooo`03o`2Ioooooooo023oool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00K?ooo`03o`2Ioooooooo023oool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00K?ooo`03o`2Ioooooooo023oool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00K?ooo`03o`2Ioooooooo023oool2000033?o00030000oooooooo083oool006coool00ol0VOoo
ooooo`0Poooo00<0000co`0co`002c?o00030000oooooooo083oool006coool00ol0VOooooooo`0P
oooo00<0000co`0co`002S?o00030000oooooooo087oool006coool00ol0VOooooooo`0Poooo00<0
000co`0co`002S?o00030000oooooooo087oool006coool00ol0VOooooooo`0Poooo00<0000co`0c
o`002S?o00030000oooooooo087oool006coool00ol0VOooooooo`0Poooo00<0000co`0co`002S?o
00030000oooooooo087oool006coool00ol0VOooooooo`0Poooo0P0000/co`000`000?ooooooo`21
oooo001/oooo00?o09Woooooool08?ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001/
oooo00?o09Woooooool08?ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001/oooo00?o
09Woooooool08?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001/oooo00?o09Wooooo
ool08?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001/oooo00?o09Woooooool08?oo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001/oooo00?o09Woooooool08?ooo`80000:
<ol000<0003oooooool0P_ooo`00K?ooo`03o`2Ioooooooo023oool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00K?ooo`03o`2Ioooooooo023oool00`0003?o03?o0009<ol000<0003ooooo
ool0P_ooo`00K?ooo`03o`2Ioooooooo023oool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00K?ooo`03o`2Ioooooooo01Woool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001/oooo00?o09Woooooool06?ooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo001/oooo00?o09Woooooool06_ooo`030000oooooooo00?oool3000023?o
00030000oooooooo08?oool006coool00ol0VOooooooo`0Koooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo001/oooo00?o09Woooooool06?ooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001/oooo00?o09Woooooool06Ooo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool006coool00ol0VOooooooo`0P
oooo00<0000co`0co`001c?o00030000oooooooo08Coool006coool00ol0VOooooooo`0Poooo00<0
000co`0co`001c?o00030000oooooooo08Coool006coool00ol0VOooooooo`0Poooo00<0000co`0c
o`001c?o00030000oooooooo08Coool006coool00ol0VOooooooo`0Poooo0P0000Pco`000`000?oo
ooooo`24oooo001/oooo00?o09Woooooool08?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001/oooo00?o09Woooooool08?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001/
oooo00?o09Woooooool08?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001/oooo00?o
09Woooooool08?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001/oooo00?o09Wooooo
ool08?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001/oooo00?o09Woooooool08?oo
o`800007<ol000<0003oooooool0QOooo`00K?ooo`03o`2Ioooooooo023oool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00K?ooo`03o`2Ioooooooo023oool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00K?ooo`03o`2Ioooooooo023oool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00K?ooo`03o`2Ioooooooo023oool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00K?ooo`03o`2Ioooooooo023oool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00K?oo
o`03o`2Ioooooooo023oool200001S?o00030000oooooooo08Koool006coool00ol0VOooooooo`0P
oooo00<0000co`0co`001C?o00030000oooooooo08Koool006coool00ol0VOooooooo`0Poooo00<0
000co`0co`001C?o00030000oooooooo08Koool006coool00ol0VOooooooo`0Poooo00<0000co`0c
o`001C?o00030000oooooooo08Koool006coool00ol0VOooooooo`0Poooo00<0000co`0co`001C?o
00030000oooooooo08Koool006coool00ol0VOooooooo`0Poooo00<0000co`0co`001C?o00030000
oooooooo08Koool006coool00ol0VOooooooo`0Poooo0P0000Hco`000`000?ooooooo`26oooo001/
oooo00?o09Woooooool08?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001/oooo00?o
09Woooooool08?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001/oooo00?o09Wooooo
ool08?ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001/oooo00?o09Woooooool08?oo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo001/oooo00?o09Woooooool06_ooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool006coool00ol0VOooooooo`0Koooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001/oooo00?o09Wooooo
ool06?ooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool2000013?o008000000c?o0?ooooooo`02oooo0`000003oooo0000000000800003oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`040000oooooooo00001S?o00Goool010000?ooooooo`0000Koool00`000?oo
ooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`00
00Hco`02oooo1@0000;oool00`000?ooooooo`04oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000<oooo00@0003oooooool00006<ol00_ooo`040000oooooooo00001?ooo`030000
oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000
oooooooo00001S?o00?oool00`000?ooo`000002oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo017oool200001c?o00Coool200000oooo`800003oooo00<0
003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.35271 .12361 L
.36173 .12361 L
.36405 .12361 L
.3652 .12361 L
.36626 .12361 L
s
.36626 .12361 m
.36675 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooool0V@09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
01Ooool00ol0VOooooooo`0Ooooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00KOooo`03o`2Ioooooooo01ooool00`0003?o03?o000c<ol01P0005Goool006goool00ol0VOoo
ooooo`0Ooooo00<0000co`0co`00<C?o0080001Koooo001]oooo00?o09Woooooool07oooo`030000
<ol0<ol002lco`020000GOooo`00KOooo`03o`2Ioooooooo01ooool00`0003?o03?o000/<ol00`00
05ooool006goool00ol0VOooooooo`0Ooooo0P0002Xco`030000H_ooo`00KOooo`03o`2Ioooooooo
01ooool00`0003?o03?o000W<ol00P0006Goool006goool00ol0VOooooooo`0Ooooo00<0000co`0c
o`009S?o00030000oooooooo06Goool006goool00ol0VOooooooo`0Ooooo00<0000co`0co`009C?o
00030000oooooooo06Koool006goool00ol0VOooooooo`0Ooooo00<0000co`0co`0093?o00030000
oooooooo06Ooool006goool00ol0VOooooooo`0Ooooo00<0000co`0co`008S?o0080001Zoooo001]
oooo00?o09Woooooool07oooo`80000R<ol000<0003oooooool0J_ooo`00KOooo`03o`2Ioooooooo
01ooool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00KOooo`03o`2Ioooooooo01ooool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00KOooo`03o`2Ioooooooo01ooool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00KOooo`03o`2Ioooooooo01ooool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00KOooo`03o`2Ioooooooo01ooool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00KOooo`03o`2Ioooooooo01ooool200007C?o00030000oooooooo06ooool0
06goool00ol0VOooooooo`0Ooooo00<0000co`0co`006c?o00030000oooooooo073oool006goool0
0ol0VOooooooo`0Ooooo00<0000co`0co`006c?o00030000oooooooo073oool006goool00ol0VOoo
ooooo`0Ooooo00<0000co`0co`006S?o00030000oooooooo077oool006goool00ol0VOooooooo`0O
oooo00<0000co`0co`006S?o00030000oooooooo077oool006goool00ol0VOooooooo`0Ooooo00<0
000co`0co`006C?o00030000oooooooo07;oool006goool00ol0VOooooooo`0Ooooo0P0001Xco`00
0`000?ooooooo`1boooo001]oooo00?o09Woooooool07oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001]oooo00?o09Woooooool07oooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo001]oooo00?o09Woooooool07oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001]
oooo00?o09Woooooool07oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001]oooo00?o
09Woooooool05oooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool006goool0
0ol0VOooooooo`0Ioooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo001]oooo00?o09Woooooool06Oooo`030000oooooooo00?oool300005C?o00030000oooooooo
07Koool006goool00ol0VOooooooo`0Ioooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1foooo001]oooo00?o09Woooooool06Oooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00KOooo`03o`2Ioooooooo01Soool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001]oooo00?o09Woooooool07oooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo001]oooo00?o09Woooooool07oooo`030000<ol0<ol001<co`00
0`000?ooooooo`1hoooo001]oooo00?o09Woooooool07oooo`80000D<ol000<0003oooooool0N?oo
o`00KOooo`03o`2Ioooooooo01ooool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00KOoo
o`03o`2Ioooooooo01ooool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00KOooo`03o`2I
oooooooo01ooool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00KOooo`03o`2Ioooooooo
01ooool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00KOooo`03o`2Ioooooooo01ooool0
0`0003?o03?o000A<ol000<0003oooooool0N_ooo`00KOooo`03o`2Ioooooooo01ooool200004S?o
00030000oooooooo07[oool006goool00ol0VOooooooo`0Ooooo00<0000co`0co`004C?o00030000
oooooooo07[oool006goool00ol0VOooooooo`0Ooooo00<0000co`0co`004C?o00030000oooooooo
07[oool006goool00ol0VOooooooo`0Ooooo00<0000co`0co`0043?o00030000oooooooo07_oool0
06goool00ol0VOooooooo`0Ooooo00<0000co`0co`0043?o00030000oooooooo07_oool006goool0
0ol0VOooooooo`0Ooooo00<0000co`0co`0043?o00030000oooooooo07_oool006goool00ol0VOoo
ooooo`0Ooooo00<0000co`0co`0043?o00030000oooooooo07_oool006goool00ol0VOooooooo`0O
oooo0P00010co`000`000?ooooooo`1loooo001]oooo00?o09Woooooool07oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001]oooo00?o09Woooooool07oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001]oooo00?o09Woooooool07oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001]oooo00?o09Woooooool07oooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo001]oooo00?o09Woooooool07oooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001]
oooo00?o09Woooooool07oooo`80000?<ol000<0003oooooool0OOooo`00KOooo`03o`2Ioooooooo
01ooool00`0003?o03?o000><ol000<0003oooooool0OOooo`00KOooo`03o`2Ioooooooo01ooool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00KOooo`03o`2Ioooooooo01ooool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00KOooo`03o`2Ioooooooo01Ooool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001]oooo00?o09Woooooool05oooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00KOooo`03o`2Ioooooooo01Soool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001]oooo00?o09Woooooool06Ooo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00KOooo`03o`2I
oooooooo01Ooool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00KOooo`03o`2Ioooooooo01Soool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001]oooo00?o09Woooooool07oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001]
oooo00?o09Woooooool07oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001]oooo00?o
09Woooooool07oooo`80000=<ol000<0003oooooool0Ooooo`00KOooo`03o`2Ioooooooo01ooool0
0`0003?o03?o000<<ol000<0003oooooool0Ooooo`00KOooo`03o`2Ioooooooo01ooool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00KOooo`03o`2Ioooooooo01ooool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00KOooo`03o`2Ioooooooo01ooool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00KOooo`03o`2Ioooooooo01ooool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00KOooo`03o`2Ioooooooo01ooool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00KOooo`03o`2Ioooooooo01ooool2000033?o00030000oooooooo083oool006goool00ol0VOoo
ooooo`0Ooooo00<0000co`0co`002c?o00030000oooooooo083oool006goool00ol0VOooooooo`0O
oooo00<0000co`0co`002S?o00030000oooooooo087oool006goool00ol0VOooooooo`0Ooooo00<0
000co`0co`002S?o00030000oooooooo087oool006goool00ol0VOooooooo`0Ooooo00<0000co`0c
o`002S?o00030000oooooooo087oool006goool00ol0VOooooooo`0Ooooo00<0000co`0co`002S?o
00030000oooooooo087oool006goool00ol0VOooooooo`0Ooooo0P0000/co`000`000?ooooooo`21
oooo001]oooo00?o09Woooooool07oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001]
oooo00?o09Woooooool07oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001]oooo00?o
09Woooooool07oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001]oooo00?o09Wooooo
ool07oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001]oooo00?o09Woooooool07ooo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001]oooo00?o09Woooooool07oooo`80000:
<ol000<0003oooooool0P_ooo`00KOooo`03o`2Ioooooooo01ooool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00KOooo`03o`2Ioooooooo01ooool00`0003?o03?o0009<ol000<0003ooooo
ool0P_ooo`00KOooo`03o`2Ioooooooo01ooool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00KOooo`03o`2Ioooooooo01Soool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001]oooo00?o09Woooooool05oooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo001]oooo00?o09Woooooool06Oooo`030000oooooooo00?oool3000023?o
00030000oooooooo08?oool006goool00ol0VOooooooo`0Joooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo001]oooo00?o09Woooooool05oooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001]oooo00?o09Woooooool06?oo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool006goool00ol0VOooooooo`0O
oooo00<0000co`0co`001c?o00030000oooooooo08Coool006goool00ol0VOooooooo`0Ooooo00<0
000co`0co`001c?o00030000oooooooo08Coool006goool00ol0VOooooooo`0Ooooo00<0000co`0c
o`001c?o00030000oooooooo08Coool006goool00ol0VOooooooo`0Ooooo0P0000Pco`000`000?oo
ooooo`24oooo001]oooo00?o09Woooooool07oooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001]oooo00?o09Woooooool07oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001]
oooo00?o09Woooooool07oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001]oooo00?o
09Woooooool07oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001]oooo00?o09Wooooo
ool07oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001]oooo00?o09Woooooool07ooo
o`800007<ol000<0003oooooool0QOooo`00KOooo`03o`2Ioooooooo01ooool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00KOooo`03o`2Ioooooooo01ooool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00KOooo`03o`2Ioooooooo01ooool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00KOooo`03o`2Ioooooooo01ooool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00KOooo`03o`2Ioooooooo01ooool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00KOoo
o`03o`2Ioooooooo01ooool200001S?o00030000oooooooo08Koool006goool00ol0VOooooooo`0O
oooo00<0000co`0co`001C?o00030000oooooooo08Koool006goool00ol0VOooooooo`0Ooooo00<0
000co`0co`001C?o00030000oooooooo08Koool006goool00ol0VOooooooo`0Ooooo00<0000co`0c
o`001C?o00030000oooooooo08Koool006goool00ol0VOooooooo`0Ooooo00<0000co`0co`001C?o
00030000oooooooo08Koool006goool00ol0VOooooooo`0Ooooo00<0000co`0co`001C?o00030000
oooooooo08Koool006goool00ol0VOooooooo`0Ooooo0P0000Hco`000`000?ooooooo`26oooo001]
oooo00?o09Woooooool07oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001]oooo00?o
09Woooooool07oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001]oooo00?o09Wooooo
ool07oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001]oooo00?o09Woooooool07ooo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo001]oooo00?o09Woooooool06Oooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool006goool00ol0VOooooooo`0Joooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001]oooo00?o09Wooooo
ool05oooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool2000013?o008000000c?o0?ooooooo`02oooo0`0000?oool300000_ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Goool010000?ooooooo`0000Hco`05oooo00<0003oooooool00oooo`050000oooooooooooo0000
07[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00001S?o
00;oool5000000?oool0000000000`0000?oool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0000coool010000?ooooooo`0000Hco`02oooo00@0003oooooool00002oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Hco`03oooo00<0003oool000000oooo`030000oooo000000?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool04Oooo`800007<ol01?ooo`800004oooo0P0000;oool00`000?oo
ooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.36173 .12361 L
.36626 .12361 L
.36876 .12361 L
.36999 .12361 L
.37114 .12361 L
s
.37114 .12361 m
.3714 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool010000?ooooooool0V@Soool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0
003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003ooooo
ool06?ooo`03o`2Ioooooooo01koool00`0003?o03?o000i<ol02@0003Coool00`000?ooooooo`0E
oooo001^oooo00?o09Woooooool07_ooo`030000<ol0<ol003<co`060000EOooo`00K_ooo`03o`2I
oooooooo01koool00`0003?o03?o000a<ol00P0005_oool006koool00ol0VOooooooo`0Noooo00<0
000co`0co`00;c?o0080001Moooo001^oooo00?o09Woooooool07_ooo`030000<ol0<ol002`co`03
0000Goooo`00K_ooo`03o`2Ioooooooo01koool20000:S?o00<0001Roooo001^oooo00?o09Wooooo
ool07_ooo`030000<ol0<ol002Lco`020000IOooo`00K_ooo`03o`2Ioooooooo01koool00`0003?o
03?o000V<ol000<0003oooooool0IOooo`00K_ooo`03o`2Ioooooooo01koool00`0003?o03?o000U
<ol000<0003oooooool0I_ooo`00K_ooo`03o`2Ioooooooo01koool00`0003?o03?o000T<ol000<0
003oooooool0Ioooo`00K_ooo`03o`2Ioooooooo01koool00`0003?o03?o000R<ol00P0006[oool0
06koool00ol0VOooooooo`0Noooo0P00028co`000`000?ooooooo`1Zoooo001^oooo00?o09Wooooo
ool07_ooo`030000<ol0<ol0020co`000`000?ooooooo`1[oooo001^oooo00?o09Woooooool07_oo
o`030000<ol0<ol001lco`000`000?ooooooo`1/oooo001^oooo00?o09Woooooool07_ooo`030000
<ol0<ol001lco`000`000?ooooooo`1/oooo001^oooo00?o09Woooooool07_ooo`030000<ol0<ol0
01hco`000`000?ooooooo`1]oooo001^oooo00?o09Woooooool07_ooo`030000<ol0<ol001dco`00
0`000?ooooooo`1^oooo001^oooo00?o09Woooooool07_ooo`80000M<ol000<0003oooooool0Kooo
o`00K_ooo`03o`2Ioooooooo01koool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00K_oo
o`03o`2Ioooooooo01koool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00K_ooo`03o`2I
oooooooo01koool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00K_ooo`03o`2Ioooooooo
01koool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00K_ooo`03o`2Ioooooooo01koool0
0`0003?o03?o000I<ol000<0003oooooool0L_ooo`00K_ooo`03o`2Ioooooooo01koool200006S?o
00030000oooooooo07;oool006koool00ol0VOooooooo`0Noooo00<0000co`0co`0063?o00030000
oooooooo07?oool006koool00ol0VOooooooo`0Noooo00<0000co`0co`0063?o00030000oooooooo
07?oool006koool00ol0VOooooooo`0Noooo00<0000co`0co`005c?o00030000oooooooo07Coool0
06koool00ol0VOooooooo`0Noooo00<0000co`0co`005c?o00030000oooooooo07Coool006koool0
0ol0VOooooooo`0Foooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00K_oo
o`03o`2Ioooooooo01Soool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo
07Goool006koool00ol0VOooooooo`0Hoooo00<0003oooooool00oooo`<0000E<ol000<0003ooooo
ool0M_ooo`00K_ooo`03o`2Ioooooooo01Soool00`000?ooooooo`03oooo00<0000co`0co`005C?o
00030000oooooooo07Koool006koool00ol0VOooooooo`0Hoooo00<0003oooooool00oooo`030000
<ol0<ol001Dco`000`000?ooooooo`1foooo001^oooo00?o09Woooooool05oooo`800005oooo00<0
000co`0co`0053?o00030000oooooooo07Ooool006koool00ol0VOooooooo`0Noooo00<0000co`0c
o`0053?o00030000oooooooo07Ooool006koool00ol0VOooooooo`0Noooo00<0000co`0co`004c?o
00030000oooooooo07Soool006koool00ol0VOooooooo`0Noooo0P0001@co`000`000?ooooooo`1h
oooo001^oooo00?o09Woooooool07_ooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo001^
oooo00?o09Woooooool07_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001^oooo00?o
09Woooooool07_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001^oooo00?o09Wooooo
ool07_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001^oooo00?o09Woooooool07_oo
o`030000<ol0<ol0014co`000`000?ooooooo`1joooo001^oooo00?o09Woooooool07_ooo`80000B
<ol000<0003oooooool0N_ooo`00K_ooo`03o`2Ioooooooo01koool00`0003?o03?o000A<ol000<0
003oooooool0N_ooo`00K_ooo`03o`2Ioooooooo01koool00`0003?o03?o000A<ol000<0003ooooo
ool0N_ooo`00K_ooo`03o`2Ioooooooo01koool00`0003?o03?o000@<ol000<0003oooooool0Nooo
o`00K_ooo`03o`2Ioooooooo01koool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00K_oo
o`03o`2Ioooooooo01koool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00K_ooo`03o`2I
oooooooo01koool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00K_ooo`03o`2Ioooooooo
01koool2000043?o00030000oooooooo07coool006koool00ol0VOooooooo`0Noooo00<0000co`0c
o`003c?o00030000oooooooo07coool006koool00ol0VOooooooo`0Noooo00<0000co`0co`003c?o
00030000oooooooo07coool006koool00ol0VOooooooo`0Noooo00<0000co`0co`003c?o00030000
oooooooo07coool006koool00ol0VOooooooo`0Noooo00<0000co`0co`003c?o00030000oooooooo
07coool006koool00ol0VOooooooo`0Noooo00<0000co`0co`003S?o00030000oooooooo07goool0
06koool00ol0VOooooooo`0Noooo0P0000lco`000`000?ooooooo`1moooo001^oooo00?o09Wooooo
ool07_ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001^oooo00?o09Woooooool07_oo
o`030000<ol0<ol000hco`000`000?ooooooo`1moooo001^oooo00?o09Woooooool07_ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001^oooo00?o09Woooooool05_ooo`@00004oooo00<0
000co`0co`003C?o00030000oooooooo07koool006koool00ol0VOooooooo`0Foooo00<0003ooooo
ool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo001^oooo00?o09Woooooool05ooo
o`030000oooooooo00Coool300003C?o00030000oooooooo07koool006koool00ol0VOooooooo`0H
oooo00<0003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo001^oooo00?o
09Woooooool05_ooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001^oooo00?o09Woooooool05oooo`800005oooo00<0000co`0co`0033?o00030000oooooooo
07ooool006koool00ol0VOooooooo`0Noooo00<0000co`0co`0033?o00030000oooooooo07ooool0
06koool00ol0VOooooooo`0Noooo00<0000co`0co`0033?o00030000oooooooo07ooool006koool0
0ol0VOooooooo`0Noooo0P0000dco`000`000?ooooooo`1ooooo001^oooo00?o09Woooooool07_oo
o`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001^oooo00?o09Woooooool07_ooo`030000
<ol0<ol000/co`000`000?ooooooo`20oooo001^oooo00?o09Woooooool07_ooo`030000<ol0<ol0
00/co`000`000?ooooooo`20oooo001^oooo00?o09Woooooool07_ooo`030000<ol0<ol000/co`00
0`000?ooooooo`20oooo001^oooo00?o09Woooooool07_ooo`030000<ol0<ol000/co`000`000?oo
ooooo`20oooo001^oooo00?o09Woooooool07_ooo`030000<ol0<ol000/co`000`000?ooooooo`20
oooo001^oooo00?o09Woooooool07_ooo`80000<<ol000<0003oooooool0P?ooo`00K_ooo`03o`2I
oooooooo01koool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00K_ooo`03o`2Ioooooooo
01koool00`0003?o03?o000:<ol000<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo01koool0
0`0003?o03?o000:<ol000<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo01koool00`0003?o
03?o000:<ol000<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo01koool00`0003?o03?o000:
<ol000<0003oooooool0POooo`00K_ooo`03o`2Ioooooooo01koool200002c?o00030000oooooooo
087oool006koool00ol0VOooooooo`0Noooo00<0000co`0co`002S?o00030000oooooooo087oool0
06koool00ol0VOooooooo`0Noooo00<0000co`0co`002S?o00030000oooooooo087oool006koool0
0ol0VOooooooo`0Noooo00<0000co`0co`002C?o00030000oooooooo08;oool006koool00ol0VOoo
ooooo`0Noooo00<0000co`0co`002C?o00030000oooooooo08;oool006koool00ol0VOooooooo`0N
oooo00<0000co`0co`002C?o00030000oooooooo08;oool006koool00ol0VOooooooo`0Noooo0P00
00Xco`000`000?ooooooo`22oooo001^oooo00?o09Woooooool07_ooo`030000<ol0<ol000Tco`00
0`000?ooooooo`22oooo001^oooo00?o09Woooooool07_ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`22oooo001^oooo00?o09Woooooool07_ooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001^oooo00?o09Woooooool05oooo`800005oooo00<0000co`0co`0023?o00030000oooooooo
08?oool006koool00ol0VOooooooo`0Foooo00@0003oooooool00004oooo00<0000co`0co`0023?o
00030000oooooooo08?oool006koool00ol0VOooooooo`0Hoooo00<0003oooooool00oooo`<00008
<ol000<0003oooooool0Poooo`00K_ooo`03o`2Ioooooooo01Woool00`000?ooooooo`02oooo00<0
000co`0co`0023?o00030000oooooooo08?oool006koool00ol0VOooooooo`0Foooo00@0003ooooo
ool00004oooo00<0000co`0co`0023?o00030000oooooooo08?oool006koool00ol0VOooooooo`0G
oooo0P0000Goool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00K_ooo`03o`2Ioooooooo
01koool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00K_ooo`03o`2Ioooooooo01koool0
0`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00K_ooo`03o`2Ioooooooo01koool00`0003?o
03?o0007<ol000<0003oooooool0Q?ooo`00K_ooo`03o`2Ioooooooo01koool2000023?o00030000
oooooooo08Coool006koool00ol0VOooooooo`0Noooo00<0000co`0co`001c?o00030000oooooooo
08Coool006koool00ol0VOooooooo`0Noooo00<0000co`0co`001c?o00030000oooooooo08Coool0
06koool00ol0VOooooooo`0Noooo00<0000co`0co`001c?o00030000oooooooo08Coool006koool0
0ol0VOooooooo`0Noooo00<0000co`0co`001S?o00030000oooooooo08Goool006koool00ol0VOoo
ooooo`0Noooo00<0000co`0co`001S?o00030000oooooooo08Goool006koool00ol0VOooooooo`0N
oooo0P0000Lco`000`000?ooooooo`25oooo001^oooo00?o09Woooooool07_ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`25oooo001^oooo00?o09Woooooool07_ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`25oooo001^oooo00?o09Woooooool07_ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`25oooo001^oooo00?o09Woooooool07_ooo`030000<ol0<ol000Hco`000`000?ooooooo`25
oooo001^oooo00?o09Woooooool07_ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001^
oooo00?o09Woooooool07_ooo`800006<ol000<0003oooooool0Q_ooo`00K_ooo`03o`2Ioooooooo
01koool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00K_ooo`03o`2Ioooooooo01koool0
0`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00K_ooo`03o`2Ioooooooo01koool00`0003?o
03?o0005<ol000<0003oooooool0Q_ooo`00K_ooo`03o`2Ioooooooo01koool00`0003?o03?o0005
<ol000<0003oooooool0Q_ooo`00K_ooo`03o`2Ioooooooo01koool00`0003?o03?o0005<ol000<0
003oooooool0Q_ooo`00K_ooo`03o`2Ioooooooo01koool200001S?o00030000oooooooo08Koool0
06koool00ol0VOooooooo`0Noooo00<0000co`0co`001C?o00030000oooooooo08Koool006koool0
0ol0VOooooooo`0Noooo00<0000co`0co`001C?o00030000oooooooo08Koool006koool00ol0VOoo
ooooo`0Noooo00<0000co`0co`0013?o00030000oooooooo08Ooool006koool00ol0VOooooooo`0N
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool006koool00ol0VOooooooo`0Hoooo0`00
00?oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00K_ooo`03o`2Ioooooooo01Woool0
0`000?ooooooo`02oooo00<0000co`0co`0013?o00030000oooooooo08Ooool006koool00ol0VOoo
ooooo`0Foooo1@0000?oool3000013?o00030000oooooooo08Ooool008Ooool010000?ooooooo`00
00Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o
08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o
00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01oooo`800004<ol00P000003<ol0oooooooo00;oool3000000Coool0000000000004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`040000oooooooo00001S?o00Goool010000?ooooooo`0000;oool01@000?oo
ooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?oo
ooooo`0000Hco`02oooo1@000005oooo0000oooooooo000000Coool00`000?ooooooo`1goooo001h
oooo00<0003oooooool01@0000coool010000?ooooooo`0000Hco`02oooo00@0003oooooool00002
oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000
oooooooo00001S?o00?oool00`000?ooo`000003oooo00<0003oooooool00oooo`030000oooooooo
07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`04oooo0P0000?oool300000_ooo`030000
oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.36173 .12361 L
.36626 .12361 L
.37114 .12361 L
.37257 .12361 L
.37393 .12361 L
.37515 .12361 L
.37585 .12361 L
s
.37585 .12361 m
.3761 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool01@000?ooooooooooool0V@07oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_oo
o`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000
oooooooo01Woool00ol0VOooooooo`0Moooo00<0000co`0co`00>C?o00T0000doooo00<0003ooooo
ool05Oooo`00Koooo`03o`2Ioooooooo01goool00`0003?o03?o000c<ol01P0005Goool006ooool0
0ol0VOooooooo`0Moooo00<0000co`0co`00<C?o0080001Koooo001_oooo00?o09Woooooool07Ooo
o`030000<ol0<ol002lco`020000GOooo`00Koooo`03o`2Ioooooooo01goool00`0003?o03?o000/
<ol00`0005ooool006ooool00ol0VOooooooo`0Moooo0P0002Xco`030000H_ooo`00Koooo`03o`2I
oooooooo01goool00`0003?o03?o000W<ol00P0006Goool006ooool00ol0VOooooooo`0Moooo00<0
000co`0co`009S?o00030000oooooooo06Goool006ooool00ol0VOooooooo`0Moooo00<0000co`0c
o`009C?o00030000oooooooo06Koool006ooool00ol0VOooooooo`0Moooo00<0000co`0co`0093?o
00030000oooooooo06Ooool006ooool00ol0VOooooooo`0Moooo00<0000co`0co`008S?o0080001Z
oooo001_oooo00?o09Woooooool07Oooo`80000R<ol000<0003oooooool0J_ooo`00Koooo`03o`2I
oooooooo01goool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00Koooo`03o`2Ioooooooo
01goool00`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Koooo`03o`2Ioooooooo01goool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Koooo`03o`2Ioooooooo01goool00`0003?o
03?o000N<ol000<0003oooooool0KOooo`00Koooo`03o`2Ioooooooo01goool00`0003?o03?o000M
<ol000<0003oooooool0K_ooo`00Koooo`03o`2Ioooooooo01goool200007C?o00030000oooooooo
06ooool006ooool00ol0VOooooooo`0Moooo00<0000co`0co`006c?o00030000oooooooo073oool0
06ooool00ol0VOooooooo`0Moooo00<0000co`0co`006c?o00030000oooooooo073oool006ooool0
0ol0VOooooooo`0Moooo00<0000co`0co`006S?o00030000oooooooo077oool006ooool00ol0VOoo
ooooo`0Moooo00<0000co`0co`006S?o00030000oooooooo077oool006ooool00ol0VOooooooo`0M
oooo00<0000co`0co`006C?o00030000oooooooo07;oool006ooool00ol0VOooooooo`0Moooo0P00
01Xco`000`000?ooooooo`1boooo001_oooo00?o09Woooooool07Oooo`030000<ol0<ol001Pco`00
0`000?ooooooo`1coooo001_oooo00?o09Woooooool07Oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001_oooo00?o09Woooooool07Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1d
oooo001_oooo00?o09Woooooool07Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001_
oooo00?o09Woooooool05Oooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool0
06ooool00ol0VOooooooo`0Goooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001_oooo00?o09Woooooool05oooo`030000oooooooo00?oool300005C?o00030000
oooooooo07Koool006ooool00ol0VOooooooo`0Goooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`1foooo001_oooo00?o09Woooooool05oooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00Koooo`03o`2Ioooooooo01Koool200001Ooo
o`030000<ol0<ol001@co`000`000?ooooooo`1goooo001_oooo00?o09Woooooool07Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001_oooo00?o09Woooooool07Oooo`030000<ol0<ol0
01<co`000`000?ooooooo`1hoooo001_oooo00?o09Woooooool07Oooo`80000D<ol000<0003ooooo
ool0N?ooo`00Koooo`03o`2Ioooooooo01goool00`0003?o03?o000C<ol000<0003oooooool0N?oo
o`00Koooo`03o`2Ioooooooo01goool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Kooo
o`03o`2Ioooooooo01goool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Koooo`03o`2I
oooooooo01goool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Koooo`03o`2Ioooooooo
01goool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00Koooo`03o`2Ioooooooo01goool2
00004S?o00030000oooooooo07[oool006ooool00ol0VOooooooo`0Moooo00<0000co`0co`004C?o
00030000oooooooo07[oool006ooool00ol0VOooooooo`0Moooo00<0000co`0co`004C?o00030000
oooooooo07[oool006ooool00ol0VOooooooo`0Moooo00<0000co`0co`0043?o00030000oooooooo
07_oool006ooool00ol0VOooooooo`0Moooo00<0000co`0co`0043?o00030000oooooooo07_oool0
06ooool00ol0VOooooooo`0Moooo00<0000co`0co`0043?o00030000oooooooo07_oool006ooool0
0ol0VOooooooo`0Moooo00<0000co`0co`0043?o00030000oooooooo07_oool006ooool00ol0VOoo
ooooo`0Moooo0P00010co`000`000?ooooooo`1loooo001_oooo00?o09Woooooool07Oooo`030000
<ol0<ol000lco`000`000?ooooooo`1loooo001_oooo00?o09Woooooool07Oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001_oooo00?o09Woooooool07Oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001_oooo00?o09Woooooool07Oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001_oooo00?o09Woooooool07Oooo`030000<ol0<ol000hco`000`000?ooooooo`1m
oooo001_oooo00?o09Woooooool07Oooo`80000?<ol000<0003oooooool0OOooo`00Koooo`03o`2I
oooooooo01goool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Koooo`03o`2Ioooooooo
01goool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Koooo`03o`2Ioooooooo01goool0
0`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Koooo`03o`2Ioooooooo01Goool400001?oo
o`030000<ol0<ol000dco`000`000?ooooooo`1noooo001_oooo00?o09Woooooool05Oooo`030000
oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Koooo`03o`2Ioooooooo
01Koool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001`oooo00?o09Wooooo
ool05_ooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00L?oo
o`03o`2Ioooooooo01Coool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00L?ooo`03o`2Ioooooooo01Goool200001Oooo`030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001`oooo00?o09Woooooool07?ooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001`oooo00?o09Woooooool07?ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001`
oooo00?o09Woooooool07?ooo`80000=<ol000<0003oooooool0Ooooo`00L?ooo`03o`2Ioooooooo
01coool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00L?ooo`03o`2Ioooooooo01coool0
0`0003?o03?o000;<ol000<0003oooooool0P?ooo`00L?ooo`03o`2Ioooooooo01coool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00L?ooo`03o`2Ioooooooo01coool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00L?ooo`03o`2Ioooooooo01coool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00L?ooo`03o`2Ioooooooo01coool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00L?ooo`03o`2Ioooooooo01coool2000033?o00030000oooooooo083oool0073oool0
0ol0VOooooooo`0Loooo00<0000co`0co`002c?o00030000oooooooo083oool0073oool00ol0VOoo
ooooo`0Loooo00<0000co`0co`002S?o00030000oooooooo087oool0073oool00ol0VOooooooo`0L
oooo00<0000co`0co`002S?o00030000oooooooo087oool0073oool00ol0VOooooooo`0Loooo00<0
000co`0co`002S?o00030000oooooooo087oool0073oool00ol0VOooooooo`0Loooo00<0000co`0c
o`002S?o00030000oooooooo087oool0073oool00ol0VOooooooo`0Loooo0P0000/co`000`000?oo
ooooo`21oooo001`oooo00?o09Woooooool07?ooo`030000<ol0<ol000Xco`000`000?ooooooo`21
oooo001`oooo00?o09Woooooool07?ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001`
oooo00?o09Woooooool07?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001`oooo00?o
09Woooooool07?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001`oooo00?o09Wooooo
ool07?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001`oooo00?o09Woooooool07?oo
o`80000:<ol000<0003oooooool0P_ooo`00L?ooo`03o`2Ioooooooo01coool00`0003?o03?o0009
<ol000<0003oooooool0P_ooo`00L?ooo`03o`2Ioooooooo01coool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00L?ooo`03o`2Ioooooooo01coool00`0003?o03?o0008<ol000<0003ooooo
ool0Poooo`00L?ooo`03o`2Ioooooooo01Goool200001Oooo`030000<ol0<ol000Pco`000`000?oo
ooooo`23oooo001`oooo00?o09Woooooool05?ooo`040000oooooooo00001?ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`23oooo001`oooo00?o09Woooooool05_ooo`030000oooooooo00?oool3
000023?o00030000oooooooo08?oool0073oool00ol0VOooooooo`0Goooo00<0003oooooool00_oo
o`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001`oooo00?o09Woooooool05?ooo`040000
oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001`oooo00?o09Wooooo
ool05Oooo`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool0073oool00ol0VOoo
ooooo`0Loooo00<0000co`0co`001c?o00030000oooooooo08Coool0073oool00ol0VOooooooo`0L
oooo00<0000co`0co`001c?o00030000oooooooo08Coool0073oool00ol0VOooooooo`0Loooo00<0
000co`0co`001c?o00030000oooooooo08Coool0073oool00ol0VOooooooo`0Loooo0P0000Pco`00
0`000?ooooooo`24oooo001`oooo00?o09Woooooool07?ooo`030000<ol0<ol000Lco`000`000?oo
ooooo`24oooo001`oooo00?o09Woooooool07?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001`oooo00?o09Woooooool07?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001`
oooo00?o09Woooooool07?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001`oooo00?o
09Woooooool07?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001`oooo00?o09Wooooo
ool07?ooo`800007<ol000<0003oooooool0QOooo`00L?ooo`03o`2Ioooooooo01coool00`0003?o
03?o0006<ol000<0003oooooool0QOooo`00L?ooo`03o`2Ioooooooo01coool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00L?ooo`03o`2Ioooooooo01coool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00L?ooo`03o`2Ioooooooo01coool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00L?ooo`03o`2Ioooooooo01coool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00L?ooo`03o`2Ioooooooo01coool200001S?o00030000oooooooo08Koool0073oool00ol0VOoo
ooooo`0Loooo00<0000co`0co`001C?o00030000oooooooo08Koool0073oool00ol0VOooooooo`0L
oooo00<0000co`0co`001C?o00030000oooooooo08Koool0073oool00ol0VOooooooo`0Loooo00<0
000co`0co`001C?o00030000oooooooo08Koool0073oool00ol0VOooooooo`0Loooo00<0000co`0c
o`001C?o00030000oooooooo08Koool0073oool00ol0VOooooooo`0Loooo00<0000co`0co`001C?o
00030000oooooooo08Koool0073oool00ol0VOooooooo`0Loooo0P0000Hco`000`000?ooooooo`26
oooo001`oooo00?o09Woooooool07?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001`
oooo00?o09Woooooool07?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001`oooo00?o
09Woooooool07?ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001`oooo00?o09Wooooo
ool07?ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001`oooo00?o09Woooooool05_oo
o`<00003oooo00<0000co`0co`0013?o00030000oooooooo08Ooool0073oool00ol0VOooooooo`0G
oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001`oooo00?o
09Woooooool05?ooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003ooooo
ool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?oo
o`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7
<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Ooo
o`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Ooool2000013?o008000000c?o0?ooooooo`02oooo0`0000;oool200001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Goool010000?ooooooo`0000Hco`05oooo00@0003oooooool00002oooo00D0003ooooo
ooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003ooooo
ool00006<ol00_ooo`D000001Oooo`000?ooooooo`000004oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000<oooo00@0003oooooool00006<ol00_ooo`040000oooooooo00000ooo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Hco`03oooo00<0003oool000000_ooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`04oooo0P0000?oool200000oooo`030000
oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.36173 .12361 L
.37114 .12361 L
.37372 .12361 L
.37649 .12361 L
.37783 .12361 L
.3791 .12361 L
.38025 .12361 L
s
.38025 .12361 m
.38075 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`03oooo00?o09Woooooool00oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0Koooo00?o09Woooooool06oooo`030000<ol0<ol003Tco`090000=?oo
o`030000oooooooo01Goool0077oool00ol0VOooooooo`0Koooo00<0000co`0co`00<c?o00H0001E
oooo001aoooo00?o09Woooooool06oooo`030000<ol0<ol0034co`020000Foooo`00LOooo`03o`2I
oooooooo01_oool00`0003?o03?o000_<ol00P0005goool0077oool00ol0VOooooooo`0Koooo00<0
000co`0co`00;3?o00<0001Ooooo001aoooo00?o09Woooooool06oooo`80000Z<ol00`0006;oool0
077oool00ol0VOooooooo`0Koooo00<0000co`0co`009c?o0080001Uoooo001aoooo00?o09Wooooo
ool06oooo`030000<ol0<ol002Hco`000`000?ooooooo`1Uoooo001aoooo00?o09Woooooool06ooo
o`030000<ol0<ol002Dco`000`000?ooooooo`1Voooo001aoooo00?o09Woooooool06oooo`030000
<ol0<ol002@co`000`000?ooooooo`1Woooo001aoooo00?o09Woooooool06oooo`030000<ol0<ol0
028co`020000J_ooo`00LOooo`03o`2Ioooooooo01_oool200008S?o00030000oooooooo06[oool0
077oool00ol0VOooooooo`0Koooo00<0000co`0co`0083?o00030000oooooooo06_oool0077oool0
0ol0VOooooooo`0Koooo00<0000co`0co`007c?o00030000oooooooo06coool0077oool00ol0VOoo
ooooo`0Koooo00<0000co`0co`007c?o00030000oooooooo06coool0077oool00ol0VOooooooo`0K
oooo00<0000co`0co`007S?o00030000oooooooo06goool0077oool00ol0VOooooooo`0Koooo00<0
000co`0co`007C?o00030000oooooooo06koool0077oool00ol0VOooooooo`0Koooo0P0001dco`00
0`000?ooooooo`1_oooo001aoooo00?o09Woooooool06oooo`030000<ol0<ol001/co`000`000?oo
ooooo`1`oooo001aoooo00?o09Woooooool06oooo`030000<ol0<ol001/co`000`000?ooooooo`1`
oooo001aoooo00?o09Woooooool06oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001a
oooo00?o09Woooooool06oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001aoooo00?o
09Woooooool06oooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo001aoooo00?o09Wooooo
ool06oooo`80000J<ol000<0003oooooool0L_ooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o
03?o000H<ol000<0003oooooool0Loooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o000H
<ol000<0003oooooool0Loooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o000G<ol000<0
003oooooool0M?ooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o000G<ol000<0003ooooo
ool0M?ooo`00LOooo`03o`2Ioooooooo01?oool500000oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001aoooo00?o09Woooooool05Oooo`030000oooooooo00?oool00`0003?o03?o000F
<ol000<0003oooooool0MOooo`00LOooo`03o`2Ioooooooo01Goool00`000?ooooooo`03oooo0`00
01Dco`000`000?ooooooo`1foooo001aoooo00?o09Woooooool05Oooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00LOooo`03o`2Ioooooooo01Goool00`000?oo
ooooo`03oooo00<0000co`0co`005C?o00030000oooooooo07Koool0077oool00ol0VOooooooo`0D
oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00LOooo`03o`2Ioooooooo
01_oool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00LOooo`03o`2Ioooooooo01_oool0
0`0003?o03?o000C<ol000<0003oooooool0N?ooo`00LOooo`03o`2Ioooooooo01_oool2000053?o
00030000oooooooo07Soool0077oool00ol0VOooooooo`0Koooo00<0000co`0co`004c?o00030000
oooooooo07Soool0077oool00ol0VOooooooo`0Koooo00<0000co`0co`004S?o00030000oooooooo
07Woool0077oool00ol0VOooooooo`0Koooo00<0000co`0co`004S?o00030000oooooooo07Woool0
077oool00ol0VOooooooo`0Koooo00<0000co`0co`004S?o00030000oooooooo07Woool0077oool0
0ol0VOooooooo`0Koooo00<0000co`0co`004C?o00030000oooooooo07[oool0077oool00ol0VOoo
ooooo`0Koooo0P00018co`000`000?ooooooo`1joooo001aoooo00?o09Woooooool06oooo`030000
<ol0<ol0014co`000`000?ooooooo`1joooo001aoooo00?o09Woooooool06oooo`030000<ol0<ol0
014co`000`000?ooooooo`1joooo001aoooo00?o09Woooooool06oooo`030000<ol0<ol0010co`00
0`000?ooooooo`1koooo001aoooo00?o09Woooooool06oooo`030000<ol0<ol0010co`000`000?oo
ooooo`1koooo001aoooo00?o09Woooooool06oooo`030000<ol0<ol0010co`000`000?ooooooo`1k
oooo001aoooo00?o09Woooooool06oooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo001a
oooo00?o09Woooooool06oooo`80000@<ol000<0003oooooool0O?ooo`00LOooo`03o`2Ioooooooo
01_oool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00LOooo`03o`2Ioooooooo01_oool0
0`0003?o03?o000?<ol000<0003oooooool0O?ooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o
03?o000?<ol000<0003oooooool0O?ooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o000?
<ol000<0003oooooool0O?ooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o000><ol000<0
003oooooool0OOooo`00LOooo`03o`2Ioooooooo01_oool200003c?o00030000oooooooo07goool0
077oool00ol0VOooooooo`0Koooo00<0000co`0co`003S?o00030000oooooooo07goool0077oool0
0ol0VOooooooo`0Koooo00<0000co`0co`003S?o00030000oooooooo07goool0077oool00ol0VOoo
ooooo`0Koooo00<0000co`0co`003C?o00030000oooooooo07koool0077oool00ol0VOooooooo`0C
oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00LOooo`03o`2Ioooooooo
01?oool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo07koool0077oool0
0ol0VOooooooo`0Doooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0O_ooo`00LOoo
o`03o`2Ioooooooo01Goool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo
07koool0077oool00ol0VOooooooo`0Coooo00@0003oooooool00004oooo00<0000co`0co`0033?o
00030000oooooooo07ooool0077oool00ol0VOooooooo`0Doooo0P0000Goool00`0003?o03?o000<
<ol000<0003oooooool0Ooooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o000<<ol000<0
003oooooool0Ooooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00LOooo`03o`2Ioooooooo01_oool200003C?o00030000oooooooo07ooool0077oool0
0ol0VOooooooo`0Koooo00<0000co`0co`0033?o00030000oooooooo07ooool0077oool00ol0VOoo
ooooo`0Koooo00<0000co`0co`002c?o00030000oooooooo083oool0077oool00ol0VOooooooo`0K
oooo00<0000co`0co`002c?o00030000oooooooo083oool0077oool00ol0VOooooooo`0Koooo00<0
000co`0co`002c?o00030000oooooooo083oool0077oool00ol0VOooooooo`0Koooo00<0000co`0c
o`002c?o00030000oooooooo083oool0077oool00ol0VOooooooo`0Koooo00<0000co`0co`002c?o
00030000oooooooo083oool0077oool00ol0VOooooooo`0Koooo0P0000`co`000`000?ooooooo`20
oooo001aoooo00?o09Woooooool06oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001a
oooo00?o09Woooooool06oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001aoooo00?o
09Woooooool06oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001aoooo00?o09Wooooo
ool06oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001aoooo00?o09Woooooool06ooo
o`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001aoooo00?o09Woooooool06oooo`80000;
<ol000<0003oooooool0POooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o000:<ol000<0003ooooo
ool0POooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o0009<ol000<0003oooooool0P_oo
o`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00LOoo
o`03o`2Ioooooooo01_oool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00LOooo`03o`2I
oooooooo01_oool200002S?o00030000oooooooo08;oool0077oool00ol0VOooooooo`0Koooo00<0
000co`0co`002C?o00030000oooooooo08;oool0077oool00ol0VOooooooo`0Koooo00<0000co`0c
o`002C?o00030000oooooooo08;oool0077oool00ol0VOooooooo`0Koooo00<0000co`0co`0023?o
00030000oooooooo08?oool0077oool00ol0VOooooooo`0Doooo0P0000Goool00`0003?o03?o0008
<ol000<0003oooooool0Poooo`00LOooo`03o`2Ioooooooo01?oool010000?ooooooo`0000Coool0
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00LOooo`03o`2Ioooooooo01Goool00`000?oo
ooooo`03oooo0`0000Pco`000`000?ooooooo`23oooo001aoooo00?o09Woooooool05_ooo`030000
oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00LOooo`03o`2Ioooooooo
01?oool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00LOoo
o`03o`2Ioooooooo01Coool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001a
oooo00?o09Woooooool06oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001aoooo00?o
09Woooooool06oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001aoooo00?o09Wooooo
ool06oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001aoooo00?o09Woooooool06ooo
o`800008<ol000<0003oooooool0Q?ooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o0007<ol000<0
003oooooool0Q?ooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o0007<ol000<0003ooooo
ool0Q?ooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00LOoo
o`03o`2Ioooooooo01_oool200001c?o00030000oooooooo08Goool0077oool00ol0VOooooooo`0K
oooo00<0000co`0co`001S?o00030000oooooooo08Goool0077oool00ol0VOooooooo`0Koooo00<0
000co`0co`001S?o00030000oooooooo08Goool0077oool00ol0VOooooooo`0Koooo00<0000co`0c
o`001S?o00030000oooooooo08Goool0077oool00ol0VOooooooo`0Koooo00<0000co`0co`001S?o
00030000oooooooo08Goool0077oool00ol0VOooooooo`0Koooo00<0000co`0co`001S?o00030000
oooooooo08Goool0077oool00ol0VOooooooo`0Koooo0P0000Hco`000`000?ooooooo`26oooo001a
oooo00?o09Woooooool06oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001aoooo00?o
09Woooooool06oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001aoooo00?o09Wooooo
ool06oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001aoooo00?o09Woooooool06ooo
o`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001aoooo00?o09Woooooool06oooo`030000
<ol0<ol000Dco`000`000?ooooooo`26oooo001aoooo00?o09Woooooool06oooo`800006<ol000<0
003oooooool0Q_ooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o0005<ol000<0003oooooool0Q_oo
o`00LOooo`03o`2Ioooooooo01_oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00LOoo
o`03o`2Ioooooooo01_oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00LOooo`03o`2I
oooooooo01Goool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001aoooo00?o
09Woooooool05_ooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0Qooo
o`00LOooo`03o`2Ioooooooo01?oool500000oooo`<00004<ol000<0003oooooool0Qoooo`00Qooo
o`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029
oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007coool00`000?oo
ooooo`0@oooo1c?o00_oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000
oooooooo00Koool7<ol03?ooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo00<co`000000000013?o00800004oooo0P0000Coool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0000co`0co`000003<ol01Oooo`040000oooooooo00000oooo`030000oooooooo
07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000<ol0<ol000000c?o
00Soool00`000?ooooooo`02oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<
oooo00@0000co`0co`000003<ol01_ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo000000ooool0100003?o03?o000000<co`06oooo00<0003oooooool00oooo`030000
oooooooo07_oool007coool00`000?ooooooo`0@oooo00<co`000000000013?o00Koool300000_oo
o`030000oooooooo07coool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.52) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.36136 .12361 L
.37176 .12361 L
.37685 .12361 L
.3815 .12361 L
.38384 .12361 L
.38448 .12361 L
.38517 .12361 L
s
.38517 .12361 m
.38566 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.52) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`04oooo00?o09Woooooool00_ooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0Loooo00?o09Woooooool06_ooo`030000<ol0<ol003Tco`090000=?oo
o`030000oooooooo01Goool007;oool00ol0VOooooooo`0Joooo00<0000co`0co`00<c?o00H0001E
oooo001boooo00?o09Woooooool06_ooo`030000<ol0<ol0034co`020000Foooo`00L_ooo`03o`2I
oooooooo01[oool00`0003?o03?o000_<ol00P0005goool007;oool00ol0VOooooooo`0Joooo00<0
000co`0co`00;3?o00<0001Ooooo001boooo00?o09Woooooool06_ooo`80000Z<ol00`0006;oool0
07;oool00ol0VOooooooo`0Joooo00<0000co`0co`009c?o0080001Uoooo001boooo00?o09Wooooo
ool06_ooo`030000<ol0<ol002Hco`000`000?ooooooo`1Uoooo001boooo00?o09Woooooool06_oo
o`030000<ol0<ol002Dco`000`000?ooooooo`1Voooo001boooo00?o09Woooooool06_ooo`030000
<ol0<ol002@co`000`000?ooooooo`1Woooo001boooo00?o09Woooooool06_ooo`030000<ol0<ol0
028co`020000J_ooo`00L_ooo`03o`2Ioooooooo01[oool200008S?o00030000oooooooo06[oool0
07;oool00ol0VOooooooo`0Joooo00<0000co`0co`0083?o00030000oooooooo06_oool007;oool0
0ol0VOooooooo`0Joooo00<0000co`0co`007c?o00030000oooooooo06coool007;oool00ol0VOoo
ooooo`0Joooo00<0000co`0co`007c?o00030000oooooooo06coool007;oool00ol0VOooooooo`0J
oooo00<0000co`0co`007S?o00030000oooooooo06goool007;oool00ol0VOooooooo`0Joooo00<0
000co`0co`007C?o00030000oooooooo06koool007;oool00ol0VOooooooo`0Joooo0P0001dco`00
0`000?ooooooo`1_oooo001boooo00?o09Woooooool06_ooo`030000<ol0<ol001/co`000`000?oo
ooooo`1`oooo001boooo00?o09Woooooool06_ooo`030000<ol0<ol001/co`000`000?ooooooo`1`
oooo001boooo00?o09Woooooool06_ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001b
oooo00?o09Woooooool06_ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001boooo00?o
09Woooooool06_ooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo001boooo00?o09Wooooo
ool06_ooo`80000J<ol000<0003oooooool0L_ooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o
03?o000H<ol000<0003oooooool0Loooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000H
<ol000<0003oooooool0Loooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000G<ol000<0
003oooooool0M?ooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000G<ol000<0003ooooo
ool0M?ooo`00L_ooo`03o`2Ioooooooo01;oool500000oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001boooo00?o09Woooooool05?ooo`030000oooooooo00?oool00`0003?o03?o000F
<ol000<0003oooooool0MOooo`00L_ooo`03o`2Ioooooooo01Coool00`000?ooooooo`03oooo0`00
01Dco`000`000?ooooooo`1foooo001boooo00?o09Woooooool05?ooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00L_ooo`03o`2Ioooooooo01Coool00`000?oo
ooooo`03oooo00<0000co`0co`005C?o00030000oooooooo07Koool007;oool00ol0VOooooooo`0C
oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00L_ooo`03o`2Ioooooooo
01[oool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00L_ooo`03o`2Ioooooooo01[oool0
0`0003?o03?o000C<ol000<0003oooooool0N?ooo`00L_ooo`03o`2Ioooooooo01[oool2000053?o
00030000oooooooo07Soool007;oool00ol0VOooooooo`0Joooo00<0000co`0co`004c?o00030000
oooooooo07Soool007;oool00ol0VOooooooo`0Joooo00<0000co`0co`004S?o00030000oooooooo
07Woool007;oool00ol0VOooooooo`0Joooo00<0000co`0co`004S?o00030000oooooooo07Woool0
07;oool00ol0VOooooooo`0Joooo00<0000co`0co`004S?o00030000oooooooo07Woool007;oool0
0ol0VOooooooo`0Joooo00<0000co`0co`004C?o00030000oooooooo07[oool007;oool00ol0VOoo
ooooo`0Joooo0P00018co`000`000?ooooooo`1joooo001boooo00?o09Woooooool06_ooo`030000
<ol0<ol0014co`000`000?ooooooo`1joooo001boooo00?o09Woooooool06_ooo`030000<ol0<ol0
014co`000`000?ooooooo`1joooo001boooo00?o09Woooooool06_ooo`030000<ol0<ol0010co`00
0`000?ooooooo`1koooo001boooo00?o09Woooooool06_ooo`030000<ol0<ol0010co`000`000?oo
ooooo`1koooo001boooo00?o09Woooooool06_ooo`030000<ol0<ol0010co`000`000?ooooooo`1k
oooo001boooo00?o09Woooooool06_ooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo001b
oooo00?o09Woooooool06_ooo`80000@<ol000<0003oooooool0O?ooo`00L_ooo`03o`2Ioooooooo
01[oool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00L_ooo`03o`2Ioooooooo01[oool0
0`0003?o03?o000?<ol000<0003oooooool0O?ooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o
03?o000?<ol000<0003oooooool0O?ooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000?
<ol000<0003oooooool0O?ooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000><ol000<0
003oooooool0OOooo`00L_ooo`03o`2Ioooooooo01[oool200003c?o00030000oooooooo07goool0
07;oool00ol0VOooooooo`0Joooo00<0000co`0co`003S?o00030000oooooooo07goool007;oool0
0ol0VOooooooo`0Joooo00<0000co`0co`003S?o00030000oooooooo07goool007;oool00ol0VOoo
ooooo`0Joooo00<0000co`0co`003C?o00030000oooooooo07koool007;oool00ol0VOooooooo`0B
oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00L_ooo`03o`2Ioooooooo
01;oool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo07koool007;oool0
0ol0VOooooooo`0Coooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0O_ooo`00L_oo
o`03o`2Ioooooooo01Coool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo
07koool007;oool00ol0VOooooooo`0Boooo00@0003oooooool00004oooo00<0000co`0co`0033?o
00030000oooooooo07ooool007;oool00ol0VOooooooo`0Coooo0P0000Goool00`0003?o03?o000<
<ol000<0003oooooool0Ooooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000<<ol000<0
003oooooool0Ooooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00L_ooo`03o`2Ioooooooo01[oool200003C?o00030000oooooooo07ooool007;oool0
0ol0VOooooooo`0Joooo00<0000co`0co`0033?o00030000oooooooo07ooool007;oool00ol0VOoo
ooooo`0Joooo00<0000co`0co`002c?o00030000oooooooo083oool007;oool00ol0VOooooooo`0J
oooo00<0000co`0co`002c?o00030000oooooooo083oool007;oool00ol0VOooooooo`0Joooo00<0
000co`0co`002c?o00030000oooooooo083oool007;oool00ol0VOooooooo`0Joooo00<0000co`0c
o`002c?o00030000oooooooo083oool007;oool00ol0VOooooooo`0Joooo00<0000co`0co`002c?o
00030000oooooooo083oool007;oool00ol0VOooooooo`0Joooo0P0000`co`000`000?ooooooo`20
oooo001boooo00?o09Woooooool06_ooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001b
oooo00?o09Woooooool06_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001boooo00?o
09Woooooool06_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001boooo00?o09Wooooo
ool06_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001boooo00?o09Woooooool06_oo
o`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001boooo00?o09Woooooool06_ooo`80000;
<ol000<0003oooooool0POooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o000:<ol000<0003ooooo
ool0POooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o0009<ol000<0003oooooool0P_oo
o`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00L_oo
o`03o`2Ioooooooo01[oool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00L_ooo`03o`2I
oooooooo01[oool200002S?o00030000oooooooo08;oool007;oool00ol0VOooooooo`0Joooo00<0
000co`0co`002C?o00030000oooooooo08;oool007;oool00ol0VOooooooo`0Joooo00<0000co`0c
o`002C?o00030000oooooooo08;oool007;oool00ol0VOooooooo`0Joooo00<0000co`0co`0023?o
00030000oooooooo08?oool007;oool00ol0VOooooooo`0Coooo0P0000Goool00`0003?o03?o0008
<ol000<0003oooooool0Poooo`00L_ooo`03o`2Ioooooooo01;oool010000?ooooooo`0000Coool0
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00L_ooo`03o`2Ioooooooo01Coool00`000?oo
ooooo`03oooo0`0000Pco`000`000?ooooooo`23oooo001boooo00?o09Woooooool05Oooo`030000
oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00L_ooo`03o`2Ioooooooo
01;oool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00L_oo
o`03o`2Ioooooooo01?oool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001b
oooo00?o09Woooooool06_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001boooo00?o
09Woooooool06_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001boooo00?o09Wooooo
ool06_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001boooo00?o09Woooooool06_oo
o`800008<ol000<0003oooooool0Q?ooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o0007<ol000<0
003oooooool0Q?ooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o0007<ol000<0003ooooo
ool0Q?ooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00L_oo
o`03o`2Ioooooooo01[oool200001c?o00030000oooooooo08Goool007;oool00ol0VOooooooo`0J
oooo00<0000co`0co`001S?o00030000oooooooo08Goool007;oool00ol0VOooooooo`0Joooo00<0
000co`0co`001S?o00030000oooooooo08Goool007;oool00ol0VOooooooo`0Joooo00<0000co`0c
o`001S?o00030000oooooooo08Goool007;oool00ol0VOooooooo`0Joooo00<0000co`0co`001S?o
00030000oooooooo08Goool007;oool00ol0VOooooooo`0Joooo00<0000co`0co`001S?o00030000
oooooooo08Goool007;oool00ol0VOooooooo`0Joooo0P0000Hco`000`000?ooooooo`26oooo001b
oooo00?o09Woooooool06_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001boooo00?o
09Woooooool06_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001boooo00?o09Wooooo
ool06_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001boooo00?o09Woooooool06_oo
o`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001boooo00?o09Woooooool06_ooo`030000
<ol0<ol000Dco`000`000?ooooooo`26oooo001boooo00?o09Woooooool06_ooo`800006<ol000<0
003oooooool0Q_ooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o0005<ol000<0003oooooool0Q_oo
o`00L_ooo`03o`2Ioooooooo01[oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00L_oo
o`03o`2Ioooooooo01[oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00L_ooo`03o`2I
oooooooo01Coool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001boooo00?o
09Woooooool05Oooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0Qooo
o`00L_ooo`03o`2Ioooooooo01;oool500000oooo`<00004<ol000<0003oooooool0Qoooo`00Qooo
o`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029
oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?oo
ooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000@co`02000000@co`3oooooooooool200000oooo`@00003
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`040000oooooooo00001S?o00;oool010000?ooooooo`0000;oool0
0`000?ooooooo`04oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0=oooo00@0003oooooool00006<ol01Oooo`050000oooooooooooo000000Koool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`0000Hco`03oooo0P00
00Goool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00ooool010000?ooooooo`0000Hco`03oooo00<0003oooooool00_ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`03oooo0`0000?oool2
00000oooo`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.54) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.36136 .12361 L
.37176 .12361 L
.37685 .12361 L
.3815 .12361 L
.38384 .12361 L
.3864 .12361 L
.38757 .12361 L
.38881 .12361 L
.38999 .12361 L
s
.38999 .12361 m
.39042 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.54) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`05oooo00Go09Woooooooooool000002ooo
o`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_oo
o`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000
oooooooo01goool00ol0VOooooooo`0Ioooo00<0000co`0co`00>C?o00T0000doooo00<0003ooooo
ool05Oooo`00Loooo`03o`2Ioooooooo01Woool00`0003?o03?o000c<ol01P0005Goool007?oool0
0ol0VOooooooo`0Ioooo00<0000co`0co`00<C?o0080001Koooo001coooo00?o09Woooooool06Ooo
o`030000<ol0<ol002lco`020000GOooo`00Loooo`03o`2Ioooooooo01Woool00`0003?o03?o000/
<ol00`0005ooool007?oool00ol0VOooooooo`0Ioooo0P0002Xco`030000H_ooo`00Loooo`03o`2I
oooooooo01Woool00`0003?o03?o000W<ol00P0006Goool007?oool00ol0VOooooooo`0Ioooo00<0
000co`0co`009S?o00030000oooooooo06Goool007?oool00ol0VOooooooo`0Ioooo00<0000co`0c
o`009C?o00030000oooooooo06Koool007?oool00ol0VOooooooo`0Ioooo00<0000co`0co`0093?o
00030000oooooooo06Ooool007?oool00ol0VOooooooo`0Ioooo00<0000co`0co`008S?o0080001Z
oooo001coooo00?o09Woooooool06Oooo`80000R<ol000<0003oooooool0J_ooo`00Loooo`03o`2I
oooooooo01Woool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00Loooo`03o`2Ioooooooo
01Woool00`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Loooo`03o`2Ioooooooo01Woool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Loooo`03o`2Ioooooooo01Woool00`0003?o
03?o000N<ol000<0003oooooool0KOooo`00Loooo`03o`2Ioooooooo01Woool00`0003?o03?o000M
<ol000<0003oooooool0K_ooo`00Loooo`03o`2Ioooooooo01Woool200007C?o00030000oooooooo
06ooool007?oool00ol0VOooooooo`0Ioooo00<0000co`0co`006c?o00030000oooooooo073oool0
07?oool00ol0VOooooooo`0Ioooo00<0000co`0co`006c?o00030000oooooooo073oool007?oool0
0ol0VOooooooo`0Ioooo00<0000co`0co`006S?o00030000oooooooo077oool007?oool00ol0VOoo
ooooo`0Ioooo00<0000co`0co`006S?o00030000oooooooo077oool007?oool00ol0VOooooooo`0I
oooo00<0000co`0co`006C?o00030000oooooooo07;oool007?oool00ol0VOooooooo`0Ioooo0P00
01Xco`000`000?ooooooo`1boooo001coooo00?o09Woooooool06Oooo`030000<ol0<ol001Pco`00
0`000?ooooooo`1coooo001coooo00?o09Woooooool06Oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001coooo00?o09Woooooool06Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1d
oooo001coooo00?o09Woooooool06Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001c
oooo00?o09Woooooool04Oooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool0
07?oool00ol0VOooooooo`0Coooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001coooo00?o09Woooooool04oooo`030000oooooooo00?oool300005C?o00030000
oooooooo07Koool007?oool00ol0VOooooooo`0Coooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`1foooo001coooo00?o09Woooooool04oooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00Loooo`03o`2Ioooooooo01;oool200001Ooo
o`030000<ol0<ol001@co`000`000?ooooooo`1goooo001coooo00?o09Woooooool06Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001coooo00?o09Woooooool06Oooo`030000<ol0<ol0
01<co`000`000?ooooooo`1hoooo001coooo00?o09Woooooool06Oooo`80000D<ol000<0003ooooo
ool0N?ooo`00Loooo`03o`2Ioooooooo01Woool00`0003?o03?o000C<ol000<0003oooooool0N?oo
o`00Loooo`03o`2Ioooooooo01Woool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Looo
o`03o`2Ioooooooo01Woool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Loooo`03o`2I
oooooooo01Woool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Loooo`03o`2Ioooooooo
01Woool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00Loooo`03o`2Ioooooooo01Woool2
00004S?o00030000oooooooo07[oool007?oool00ol0VOooooooo`0Ioooo00<0000co`0co`004C?o
00030000oooooooo07[oool007?oool00ol0VOooooooo`0Ioooo00<0000co`0co`004C?o00030000
oooooooo07[oool007?oool00ol0VOooooooo`0Ioooo00<0000co`0co`0043?o00030000oooooooo
07_oool007?oool00ol0VOooooooo`0Ioooo00<0000co`0co`0043?o00030000oooooooo07_oool0
07?oool00ol0VOooooooo`0Ioooo00<0000co`0co`0043?o00030000oooooooo07_oool007?oool0
0ol0VOooooooo`0Ioooo00<0000co`0co`0043?o00030000oooooooo07_oool007?oool00ol0VOoo
ooooo`0Ioooo0P00010co`000`000?ooooooo`1loooo001coooo00?o09Woooooool06Oooo`030000
<ol0<ol000lco`000`000?ooooooo`1loooo001coooo00?o09Woooooool06Oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001coooo00?o09Woooooool06Oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001coooo00?o09Woooooool06Oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001coooo00?o09Woooooool06Oooo`030000<ol0<ol000hco`000`000?ooooooo`1m
oooo001coooo00?o09Woooooool06Oooo`80000?<ol000<0003oooooool0OOooo`00Loooo`03o`2I
oooooooo01Woool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Loooo`03o`2Ioooooooo
01Woool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Loooo`03o`2Ioooooooo01Woool0
0`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Loooo`03o`2Ioooooooo017oool400001?oo
o`030000<ol0<ol000dco`000`000?ooooooo`1noooo001coooo00?o09Woooooool04Oooo`030000
oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Loooo`03o`2Ioooooooo
01;oool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001coooo00?o09Wooooo
ool04oooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Looo
o`03o`2Ioooooooo017oool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00Loooo`03o`2Ioooooooo01;oool200001Oooo`030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001coooo00?o09Woooooool06Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001coooo00?o09Woooooool06Oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001c
oooo00?o09Woooooool06Oooo`80000=<ol000<0003oooooool0Ooooo`00Loooo`03o`2Ioooooooo
01Woool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00Loooo`03o`2Ioooooooo01Woool0
0`0003?o03?o000;<ol000<0003oooooool0P?ooo`00Loooo`03o`2Ioooooooo01Woool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00Loooo`03o`2Ioooooooo01Woool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00Loooo`03o`2Ioooooooo01Woool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00Loooo`03o`2Ioooooooo01Woool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Loooo`03o`2Ioooooooo01Woool2000033?o00030000oooooooo083oool007?oool0
0ol0VOooooooo`0Ioooo00<0000co`0co`002c?o00030000oooooooo083oool007?oool00ol0VOoo
ooooo`0Ioooo00<0000co`0co`002S?o00030000oooooooo087oool007?oool00ol0VOooooooo`0I
oooo00<0000co`0co`002S?o00030000oooooooo087oool007?oool00ol0VOooooooo`0Ioooo00<0
000co`0co`002S?o00030000oooooooo087oool007?oool00ol0VOooooooo`0Ioooo00<0000co`0c
o`002S?o00030000oooooooo087oool007?oool00ol0VOooooooo`0Ioooo0P0000/co`000`000?oo
ooooo`21oooo001coooo00?o09Woooooool06Oooo`030000<ol0<ol000Xco`000`000?ooooooo`21
oooo001coooo00?o09Woooooool06Oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001c
oooo00?o09Woooooool06Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001coooo00?o
09Woooooool06Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001coooo00?o09Wooooo
ool06Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001coooo00?o09Woooooool06Ooo
o`80000:<ol000<0003oooooool0P_ooo`00Loooo`03o`2Ioooooooo01Woool00`0003?o03?o0009
<ol000<0003oooooool0P_ooo`00Loooo`03o`2Ioooooooo01Woool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00Loooo`03o`2Ioooooooo01Woool00`0003?o03?o0008<ol000<0003ooooo
ool0Poooo`00Loooo`03o`2Ioooooooo01;oool200001Oooo`030000<ol0<ol000Pco`000`000?oo
ooooo`23oooo001coooo00?o09Woooooool04Oooo`040000oooooooo00001?ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`23oooo001coooo00?o09Woooooool04oooo`030000oooooooo00?oool3
000023?o00030000oooooooo08?oool007?oool00ol0VOooooooo`0Doooo00<0003oooooool00_oo
o`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001coooo00?o09Woooooool04Oooo`040000
oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001coooo00?o09Wooooo
ool04_ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool007?oool00ol0VOoo
ooooo`0Ioooo00<0000co`0co`001c?o00030000oooooooo08Coool007?oool00ol0VOooooooo`0I
oooo00<0000co`0co`001c?o00030000oooooooo08Coool007?oool00ol0VOooooooo`0Ioooo00<0
000co`0co`001c?o00030000oooooooo08Coool007?oool00ol0VOooooooo`0Ioooo0P0000Pco`00
0`000?ooooooo`24oooo001coooo00?o09Woooooool06Oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`24oooo001coooo00?o09Woooooool06Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001coooo00?o09Woooooool06Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001c
oooo00?o09Woooooool06Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001coooo00?o
09Woooooool06Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001coooo00?o09Wooooo
ool06Oooo`800007<ol000<0003oooooool0QOooo`00Loooo`03o`2Ioooooooo01Woool00`0003?o
03?o0006<ol000<0003oooooool0QOooo`00Loooo`03o`2Ioooooooo01Woool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00Loooo`03o`2Ioooooooo01Woool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00Loooo`03o`2Ioooooooo01Woool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00Loooo`03o`2Ioooooooo01Woool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00Loooo`03o`2Ioooooooo01Woool200001S?o00030000oooooooo08Koool007?oool00ol0VOoo
ooooo`0Ioooo00<0000co`0co`001C?o00030000oooooooo08Koool007?oool00ol0VOooooooo`0I
oooo00<0000co`0co`001C?o00030000oooooooo08Koool007?oool00ol0VOooooooo`0Ioooo00<0
000co`0co`001C?o00030000oooooooo08Koool007?oool00ol0VOooooooo`0Ioooo00<0000co`0c
o`001C?o00030000oooooooo08Koool007?oool00ol0VOooooooo`0Ioooo00<0000co`0co`001C?o
00030000oooooooo08Koool007?oool00ol0VOooooooo`0Ioooo0P0000Hco`000`000?ooooooo`26
oooo001coooo00?o09Woooooool06Oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001c
oooo00?o09Woooooool06Oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001coooo00?o
09Woooooool06Oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001coooo00?o09Wooooo
ool06Oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001coooo00?o09Woooooool04ooo
o`<00003oooo00<0000co`0co`0013?o00030000oooooooo08Ooool007?oool00ol0VOooooooo`0D
oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001coooo00?o
09Woooooool04Oooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003ooooo
ool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?oo
o`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7
<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Ooo
o`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Ooool2000013?o0080000013?o0?ooooooooooo`800005oooo0`0000;oool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0003oooooool00006<ol00_ooo`040000oooooooo00001Oooo`050000oooooooo
oooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo
00001S?o00Goool00`000?ooooooo`0500000oooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500003?ooo`040000oooooooo00001S?o00?oool200000oooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00006
<ol00oooo`030000oooooooo00?oool00`000?ooo`000003oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo017oool200001c?o00?oool300001?ooo`800002oooo00<0003oooooool0NOoo
o`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.56) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.36136 .12361 L
.37176 .12361 L
.3815 .12361 L
.3864 .12361 L
.39106 .12361 L
.39362 .12361 L
.39433 .12361 L
.39508 .12361 L
s
.39508 .12361 m
.39536 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.56) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`06oooo00Co09Woooooool0000;oooo00<0
003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0
003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003ooooo
ool07_ooo`03o`2Ioooooooo01Soool00`0003?o03?o000i<ol02@0003Coool00`000?ooooooo`0E
oooo001doooo00?o09Woooooool06?ooo`030000<ol0<ol003<co`060000EOooo`00M?ooo`03o`2I
oooooooo01Soool00`0003?o03?o000a<ol00P0005_oool007Coool00ol0VOooooooo`0Hoooo00<0
000co`0co`00;c?o0080001Moooo001doooo00?o09Woooooool06?ooo`030000<ol0<ol002`co`03
0000Goooo`00M?ooo`03o`2Ioooooooo01Soool20000:S?o00<0001Roooo001doooo00?o09Wooooo
ool06?ooo`030000<ol0<ol002Lco`020000IOooo`00M?ooo`03o`2Ioooooooo01Soool00`0003?o
03?o000V<ol000<0003oooooool0IOooo`00M?ooo`03o`2Ioooooooo01Soool00`0003?o03?o000U
<ol000<0003oooooool0I_ooo`00M?ooo`03o`2Ioooooooo01Soool00`0003?o03?o000T<ol000<0
003oooooool0Ioooo`00M?ooo`03o`2Ioooooooo01Soool00`0003?o03?o000R<ol00P0006[oool0
07Coool00ol0VOooooooo`0Hoooo0P00028co`000`000?ooooooo`1Zoooo001doooo00?o09Wooooo
ool06?ooo`030000<ol0<ol0020co`000`000?ooooooo`1[oooo001doooo00?o09Woooooool06?oo
o`030000<ol0<ol001lco`000`000?ooooooo`1/oooo001doooo00?o09Woooooool06?ooo`030000
<ol0<ol001lco`000`000?ooooooo`1/oooo001doooo00?o09Woooooool06?ooo`030000<ol0<ol0
01hco`000`000?ooooooo`1]oooo001doooo00?o09Woooooool06?ooo`030000<ol0<ol001dco`00
0`000?ooooooo`1^oooo001doooo00?o09Woooooool06?ooo`80000M<ol000<0003oooooool0Kooo
o`00M?ooo`03o`2Ioooooooo01Soool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00M?oo
o`03o`2Ioooooooo01Soool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00M?ooo`03o`2I
oooooooo01Soool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00M?ooo`03o`2Ioooooooo
01Soool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00M?ooo`03o`2Ioooooooo01Soool0
0`0003?o03?o000I<ol000<0003oooooool0L_ooo`00M?ooo`03o`2Ioooooooo01Soool200006S?o
00030000oooooooo07;oool007Coool00ol0VOooooooo`0Hoooo00<0000co`0co`0063?o00030000
oooooooo07?oool007Coool00ol0VOooooooo`0Hoooo00<0000co`0co`0063?o00030000oooooooo
07?oool007Coool00ol0VOooooooo`0Hoooo00<0000co`0co`005c?o00030000oooooooo07Coool0
07Coool00ol0VOooooooo`0Hoooo00<0000co`0co`005c?o00030000oooooooo07Coool007Coool0
0ol0VOooooooo`0@oooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00M?oo
o`03o`2Ioooooooo01;oool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo
07Goool007Coool00ol0VOooooooo`0Boooo00<0003oooooool00oooo`<0000E<ol000<0003ooooo
ool0M_ooo`00M?ooo`03o`2Ioooooooo01;oool00`000?ooooooo`03oooo00<0000co`0co`005C?o
00030000oooooooo07Koool007Coool00ol0VOooooooo`0Boooo00<0003oooooool00oooo`030000
<ol0<ol001Dco`000`000?ooooooo`1foooo001doooo00?o09Woooooool04Oooo`800005oooo00<0
000co`0co`0053?o00030000oooooooo07Ooool007Coool00ol0VOooooooo`0Hoooo00<0000co`0c
o`0053?o00030000oooooooo07Ooool007Coool00ol0VOooooooo`0Hoooo00<0000co`0co`004c?o
00030000oooooooo07Soool007Coool00ol0VOooooooo`0Hoooo0P0001@co`000`000?ooooooo`1h
oooo001doooo00?o09Woooooool06?ooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo001d
oooo00?o09Woooooool06?ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001doooo00?o
09Woooooool06?ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001doooo00?o09Wooooo
ool06?ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001doooo00?o09Woooooool06?oo
o`030000<ol0<ol0014co`000`000?ooooooo`1joooo001doooo00?o09Woooooool06?ooo`80000B
<ol000<0003oooooool0N_ooo`00M?ooo`03o`2Ioooooooo01Soool00`0003?o03?o000A<ol000<0
003oooooool0N_ooo`00M?ooo`03o`2Ioooooooo01Soool00`0003?o03?o000A<ol000<0003ooooo
ool0N_ooo`00M?ooo`03o`2Ioooooooo01Soool00`0003?o03?o000@<ol000<0003oooooool0Nooo
o`00M?ooo`03o`2Ioooooooo01Soool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00M?oo
o`03o`2Ioooooooo01Soool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00M?ooo`03o`2I
oooooooo01Soool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00M?ooo`03o`2Ioooooooo
01Soool2000043?o00030000oooooooo07coool007Coool00ol0VOooooooo`0Hoooo00<0000co`0c
o`003c?o00030000oooooooo07coool007Coool00ol0VOooooooo`0Hoooo00<0000co`0co`003c?o
00030000oooooooo07coool007Coool00ol0VOooooooo`0Hoooo00<0000co`0co`003c?o00030000
oooooooo07coool007Coool00ol0VOooooooo`0Hoooo00<0000co`0co`003c?o00030000oooooooo
07coool007Coool00ol0VOooooooo`0Hoooo00<0000co`0co`003S?o00030000oooooooo07goool0
07Coool00ol0VOooooooo`0Hoooo0P0000lco`000`000?ooooooo`1moooo001doooo00?o09Wooooo
ool06?ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001doooo00?o09Woooooool06?oo
o`030000<ol0<ol000hco`000`000?ooooooo`1moooo001doooo00?o09Woooooool06?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001doooo00?o09Woooooool04?ooo`@00004oooo00<0
000co`0co`003C?o00030000oooooooo07koool007Coool00ol0VOooooooo`0@oooo00<0003ooooo
ool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo001doooo00?o09Woooooool04Ooo
o`030000oooooooo00Coool300003C?o00030000oooooooo07koool007Coool00ol0VOooooooo`0B
oooo00<0003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo001doooo00?o
09Woooooool04?ooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001doooo00?o09Woooooool04Oooo`800005oooo00<0000co`0co`0033?o00030000oooooooo
07ooool007Coool00ol0VOooooooo`0Hoooo00<0000co`0co`0033?o00030000oooooooo07ooool0
07Coool00ol0VOooooooo`0Hoooo00<0000co`0co`0033?o00030000oooooooo07ooool007Coool0
0ol0VOooooooo`0Hoooo0P0000dco`000`000?ooooooo`1ooooo001doooo00?o09Woooooool06?oo
o`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001doooo00?o09Woooooool06?ooo`030000
<ol0<ol000/co`000`000?ooooooo`20oooo001doooo00?o09Woooooool06?ooo`030000<ol0<ol0
00/co`000`000?ooooooo`20oooo001doooo00?o09Woooooool06?ooo`030000<ol0<ol000/co`00
0`000?ooooooo`20oooo001doooo00?o09Woooooool06?ooo`030000<ol0<ol000/co`000`000?oo
ooooo`20oooo001doooo00?o09Woooooool06?ooo`030000<ol0<ol000/co`000`000?ooooooo`20
oooo001doooo00?o09Woooooool06?ooo`80000<<ol000<0003oooooool0P?ooo`00M?ooo`03o`2I
oooooooo01Soool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00M?ooo`03o`2Ioooooooo
01Soool00`0003?o03?o000:<ol000<0003oooooool0POooo`00M?ooo`03o`2Ioooooooo01Soool0
0`0003?o03?o000:<ol000<0003oooooool0POooo`00M?ooo`03o`2Ioooooooo01Soool00`0003?o
03?o000:<ol000<0003oooooool0POooo`00M?ooo`03o`2Ioooooooo01Soool00`0003?o03?o000:
<ol000<0003oooooool0POooo`00M?ooo`03o`2Ioooooooo01Soool200002c?o00030000oooooooo
087oool007Coool00ol0VOooooooo`0Hoooo00<0000co`0co`002S?o00030000oooooooo087oool0
07Coool00ol0VOooooooo`0Hoooo00<0000co`0co`002S?o00030000oooooooo087oool007Coool0
0ol0VOooooooo`0Hoooo00<0000co`0co`002C?o00030000oooooooo08;oool007Coool00ol0VOoo
ooooo`0Hoooo00<0000co`0co`002C?o00030000oooooooo08;oool007Coool00ol0VOooooooo`0H
oooo00<0000co`0co`002C?o00030000oooooooo08;oool007Coool00ol0VOooooooo`0Hoooo0P00
00Xco`000`000?ooooooo`22oooo001doooo00?o09Woooooool06?ooo`030000<ol0<ol000Tco`00
0`000?ooooooo`22oooo001doooo00?o09Woooooool06?ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`22oooo001doooo00?o09Woooooool06?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001doooo00?o09Woooooool04Oooo`800005oooo00<0000co`0co`0023?o00030000oooooooo
08?oool007Coool00ol0VOooooooo`0@oooo00@0003oooooool00004oooo00<0000co`0co`0023?o
00030000oooooooo08?oool007Coool00ol0VOooooooo`0Boooo00<0003oooooool00oooo`<00008
<ol000<0003oooooool0Poooo`00M?ooo`03o`2Ioooooooo01?oool00`000?ooooooo`02oooo00<0
000co`0co`0023?o00030000oooooooo08?oool007Coool00ol0VOooooooo`0@oooo00@0003ooooo
ool00004oooo00<0000co`0co`0023?o00030000oooooooo08?oool007Coool00ol0VOooooooo`0A
oooo0P0000Goool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00M?ooo`03o`2Ioooooooo
01Soool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00M?ooo`03o`2Ioooooooo01Soool0
0`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00M?ooo`03o`2Ioooooooo01Soool00`0003?o
03?o0007<ol000<0003oooooool0Q?ooo`00M?ooo`03o`2Ioooooooo01Soool2000023?o00030000
oooooooo08Coool007Coool00ol0VOooooooo`0Hoooo00<0000co`0co`001c?o00030000oooooooo
08Coool007Coool00ol0VOooooooo`0Hoooo00<0000co`0co`001c?o00030000oooooooo08Coool0
07Coool00ol0VOooooooo`0Hoooo00<0000co`0co`001c?o00030000oooooooo08Coool007Coool0
0ol0VOooooooo`0Hoooo00<0000co`0co`001S?o00030000oooooooo08Goool007Coool00ol0VOoo
ooooo`0Hoooo00<0000co`0co`001S?o00030000oooooooo08Goool007Coool00ol0VOooooooo`0H
oooo0P0000Lco`000`000?ooooooo`25oooo001doooo00?o09Woooooool06?ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`25oooo001doooo00?o09Woooooool06?ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`25oooo001doooo00?o09Woooooool06?ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`25oooo001doooo00?o09Woooooool06?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25
oooo001doooo00?o09Woooooool06?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001d
oooo00?o09Woooooool06?ooo`800006<ol000<0003oooooool0Q_ooo`00M?ooo`03o`2Ioooooooo
01Soool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00M?ooo`03o`2Ioooooooo01Soool0
0`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00M?ooo`03o`2Ioooooooo01Soool00`0003?o
03?o0005<ol000<0003oooooool0Q_ooo`00M?ooo`03o`2Ioooooooo01Soool00`0003?o03?o0005
<ol000<0003oooooool0Q_ooo`00M?ooo`03o`2Ioooooooo01Soool00`0003?o03?o0005<ol000<0
003oooooool0Q_ooo`00M?ooo`03o`2Ioooooooo01Soool200001S?o00030000oooooooo08Koool0
07Coool00ol0VOooooooo`0Hoooo00<0000co`0co`001C?o00030000oooooooo08Koool007Coool0
0ol0VOooooooo`0Hoooo00<0000co`0co`001C?o00030000oooooooo08Koool007Coool00ol0VOoo
ooooo`0Hoooo00<0000co`0co`0013?o00030000oooooooo08Ooool007Coool00ol0VOooooooo`0H
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool007Coool00ol0VOooooooo`0Boooo0`00
00?oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00M?ooo`03o`2Ioooooooo01?oool0
0`000?ooooooo`02oooo00<0000co`0co`0013?o00030000oooooooo08Ooool007Coool00ol0VOoo
ooooo`0@oooo1@0000?oool3000013?o00030000oooooooo08Ooool008Ooool010000?ooooooo`00
00Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o
08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o
00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01oooo`800004<ol00P000004<ol0oooooooooooo0P0000?oool300001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Goool010000?ooooooo`0000Hco`02oooo00@0003oooooool00002oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0
003oooooool00006<ol01Oooo`040000oooooooo00000_ooo`030000oooooooo00;oool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`0000Hco`03oooo0P00
00?oool300001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0
003oooooool00006<ol00oooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo017oool200001c?o00?oool300000oooo`<00002oooo00<0
003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.58) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.36136 .12361 L
.37176 .12361 L
.3815 .12361 L
.39106 .12361 L
.39381 .12361 L
.39642 .12361 L
.39756 .12361 L
.39877 .12361 L
.39947 .12361 L
s
.39947 .12361 m
.39972 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.58) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`07oooo00?o09Woool000002oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
01ooool00ol0VOooooooo`0Goooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00MOooo`03o`2Ioooooooo01Ooool00`0003?o03?o000c<ol01P0005Goool007Goool00ol0VOoo
ooooo`0Goooo00<0000co`0co`00<C?o0080001Koooo001eoooo00?o09Woooooool05oooo`030000
<ol0<ol002lco`020000GOooo`00MOooo`03o`2Ioooooooo01Ooool00`0003?o03?o000/<ol00`00
05ooool007Goool00ol0VOooooooo`0Goooo0P0002Xco`030000H_ooo`00MOooo`03o`2Ioooooooo
01Ooool00`0003?o03?o000W<ol00P0006Goool007Goool00ol0VOooooooo`0Goooo00<0000co`0c
o`009S?o00030000oooooooo06Goool007Goool00ol0VOooooooo`0Goooo00<0000co`0co`009C?o
00030000oooooooo06Koool007Goool00ol0VOooooooo`0Goooo00<0000co`0co`0093?o00030000
oooooooo06Ooool007Goool00ol0VOooooooo`0Goooo00<0000co`0co`008S?o0080001Zoooo001e
oooo00?o09Woooooool05oooo`80000R<ol000<0003oooooool0J_ooo`00MOooo`03o`2Ioooooooo
01Ooool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00MOooo`03o`2Ioooooooo01Ooool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00MOooo`03o`2Ioooooooo01Ooool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00MOooo`03o`2Ioooooooo01Ooool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00MOooo`03o`2Ioooooooo01Ooool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00MOooo`03o`2Ioooooooo01Ooool200007C?o00030000oooooooo06ooool0
07Goool00ol0VOooooooo`0Goooo00<0000co`0co`006c?o00030000oooooooo073oool007Goool0
0ol0VOooooooo`0Goooo00<0000co`0co`006c?o00030000oooooooo073oool007Goool00ol0VOoo
ooooo`0Goooo00<0000co`0co`006S?o00030000oooooooo077oool007Goool00ol0VOooooooo`0G
oooo00<0000co`0co`006S?o00030000oooooooo077oool007Goool00ol0VOooooooo`0Goooo00<0
000co`0co`006C?o00030000oooooooo07;oool007Goool00ol0VOooooooo`0Goooo0P0001Xco`00
0`000?ooooooo`1boooo001eoooo00?o09Woooooool05oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001eoooo00?o09Woooooool05oooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo001eoooo00?o09Woooooool05oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001e
oooo00?o09Woooooool05oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001eoooo00?o
09Woooooool03oooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool007Goool0
0ol0VOooooooo`0Aoooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo001eoooo00?o09Woooooool04Oooo`030000oooooooo00?oool300005C?o00030000oooooooo
07Koool007Goool00ol0VOooooooo`0Aoooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1foooo001eoooo00?o09Woooooool04Oooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00MOooo`03o`2Ioooooooo013oool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001eoooo00?o09Woooooool05oooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo001eoooo00?o09Woooooool05oooo`030000<ol0<ol001<co`00
0`000?ooooooo`1hoooo001eoooo00?o09Woooooool05oooo`80000D<ol000<0003oooooool0N?oo
o`00MOooo`03o`2Ioooooooo01Ooool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00MOoo
o`03o`2Ioooooooo01Ooool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00MOooo`03o`2I
oooooooo01Ooool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00MOooo`03o`2Ioooooooo
01Ooool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00MOooo`03o`2Ioooooooo01Ooool0
0`0003?o03?o000A<ol000<0003oooooool0N_ooo`00MOooo`03o`2Ioooooooo01Ooool200004S?o
00030000oooooooo07[oool007Goool00ol0VOooooooo`0Goooo00<0000co`0co`004C?o00030000
oooooooo07[oool007Goool00ol0VOooooooo`0Goooo00<0000co`0co`004C?o00030000oooooooo
07[oool007Goool00ol0VOooooooo`0Goooo00<0000co`0co`0043?o00030000oooooooo07_oool0
07Goool00ol0VOooooooo`0Goooo00<0000co`0co`0043?o00030000oooooooo07_oool007Goool0
0ol0VOooooooo`0Goooo00<0000co`0co`0043?o00030000oooooooo07_oool007Goool00ol0VOoo
ooooo`0Goooo00<0000co`0co`0043?o00030000oooooooo07_oool007Goool00ol0VOooooooo`0G
oooo0P00010co`000`000?ooooooo`1loooo001eoooo00?o09Woooooool05oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001eoooo00?o09Woooooool05oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001eoooo00?o09Woooooool05oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001eoooo00?o09Woooooool05oooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo001eoooo00?o09Woooooool05oooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001e
oooo00?o09Woooooool05oooo`80000?<ol000<0003oooooool0OOooo`00MOooo`03o`2Ioooooooo
01Ooool00`0003?o03?o000><ol000<0003oooooool0OOooo`00MOooo`03o`2Ioooooooo01Ooool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00MOooo`03o`2Ioooooooo01Ooool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00MOooo`03o`2Ioooooooo00ooool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001eoooo00?o09Woooooool03oooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00MOooo`03o`2Ioooooooo013oool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001foooo00?o09Woooooool04?oo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00M_ooo`03o`2I
oooooooo00koool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00M_ooo`03o`2Ioooooooo00ooool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001foooo00?o09Woooooool05_ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001f
oooo00?o09Woooooool05_ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001foooo00?o
09Woooooool05_ooo`80000=<ol000<0003oooooool0Ooooo`00M_ooo`03o`2Ioooooooo01Koool0
0`0003?o03?o000<<ol000<0003oooooool0Ooooo`00M_ooo`03o`2Ioooooooo01Koool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00M_ooo`03o`2Ioooooooo01Koool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00M_ooo`03o`2Ioooooooo01Koool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00M_ooo`03o`2Ioooooooo01Koool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00M_ooo`03o`2Ioooooooo01Koool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00M_ooo`03o`2Ioooooooo01Koool2000033?o00030000oooooooo083oool007Koool00ol0VOoo
ooooo`0Foooo00<0000co`0co`002c?o00030000oooooooo083oool007Koool00ol0VOooooooo`0F
oooo00<0000co`0co`002S?o00030000oooooooo087oool007Koool00ol0VOooooooo`0Foooo00<0
000co`0co`002S?o00030000oooooooo087oool007Koool00ol0VOooooooo`0Foooo00<0000co`0c
o`002S?o00030000oooooooo087oool007Koool00ol0VOooooooo`0Foooo00<0000co`0co`002S?o
00030000oooooooo087oool007Koool00ol0VOooooooo`0Foooo0P0000/co`000`000?ooooooo`21
oooo001foooo00?o09Woooooool05_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001f
oooo00?o09Woooooool05_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001foooo00?o
09Woooooool05_ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001foooo00?o09Wooooo
ool05_ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001foooo00?o09Woooooool05_oo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001foooo00?o09Woooooool05_ooo`80000:
<ol000<0003oooooool0P_ooo`00M_ooo`03o`2Ioooooooo01Koool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00M_ooo`03o`2Ioooooooo01Koool00`0003?o03?o0009<ol000<0003ooooo
ool0P_ooo`00M_ooo`03o`2Ioooooooo01Koool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00M_ooo`03o`2Ioooooooo00ooool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001foooo00?o09Woooooool03_ooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo001foooo00?o09Woooooool04?ooo`030000oooooooo00?oool3000023?o
00030000oooooooo08?oool007Koool00ol0VOooooooo`0Aoooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo001foooo00?o09Woooooool03_ooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001foooo00?o09Woooooool03ooo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool007Koool00ol0VOooooooo`0F
oooo00<0000co`0co`001c?o00030000oooooooo08Coool007Koool00ol0VOooooooo`0Foooo00<0
000co`0co`001c?o00030000oooooooo08Coool007Koool00ol0VOooooooo`0Foooo00<0000co`0c
o`001c?o00030000oooooooo08Coool007Koool00ol0VOooooooo`0Foooo0P0000Pco`000`000?oo
ooooo`24oooo001foooo00?o09Woooooool05_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001foooo00?o09Woooooool05_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001f
oooo00?o09Woooooool05_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001foooo00?o
09Woooooool05_ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001foooo00?o09Wooooo
ool05_ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001foooo00?o09Woooooool05_oo
o`800007<ol000<0003oooooool0QOooo`00M_ooo`03o`2Ioooooooo01Koool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00M_ooo`03o`2Ioooooooo01Koool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00M_ooo`03o`2Ioooooooo01Koool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00M_ooo`03o`2Ioooooooo01Koool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00M_ooo`03o`2Ioooooooo01Koool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00M_oo
o`03o`2Ioooooooo01Koool200001S?o00030000oooooooo08Koool007Koool00ol0VOooooooo`0F
oooo00<0000co`0co`001C?o00030000oooooooo08Koool007Koool00ol0VOooooooo`0Foooo00<0
000co`0co`001C?o00030000oooooooo08Koool007Koool00ol0VOooooooo`0Foooo00<0000co`0c
o`001C?o00030000oooooooo08Koool007Koool00ol0VOooooooo`0Foooo00<0000co`0co`001C?o
00030000oooooooo08Koool007Koool00ol0VOooooooo`0Foooo00<0000co`0co`001C?o00030000
oooooooo08Koool007Koool00ol0VOooooooo`0Foooo0P0000Hco`000`000?ooooooo`26oooo001f
oooo00?o09Woooooool05_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001foooo00?o
09Woooooool05_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001foooo00?o09Wooooo
ool05_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001foooo00?o09Woooooool05_oo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo001foooo00?o09Woooooool04?ooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool007Koool00ol0VOooooooo`0Aoooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001foooo00?o09Wooooo
ool03_ooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool2000013?o0080000013?o0?ooooooooooo`800004oooo0P0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05
oooo00@0003oooooool00006<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000
oooooooo00001S?o00Goool010000?ooooooo`0000;oool00`000?ooooooo`02oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00006<ol00oooo`800004
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000
oooooooo00001S?o00?oool00`000?ooooooo`02oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo017oool200001c?o00?oool300000oooo`800003oooo00<0
003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.39174 .12361 L
.39675 .12361 L
.40134 .12361 L
.40252 .12361 L
.40381 .12361 L
s
.40381 .12361 m
.4043 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
027oool00ol0VOooooooo`0Eoooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00Moooo`03o`2Ioooooooo01Goool00`0003?o03?o000c<ol01P0005Goool007Ooool00ol0VOoo
ooooo`0Eoooo00<0000co`0co`00<C?o0080001Koooo001goooo00?o09Woooooool05Oooo`030000
<ol0<ol002lco`020000GOooo`00Moooo`03o`2Ioooooooo01Goool00`0003?o03?o000/<ol00`00
05ooool007Ooool00ol0VOooooooo`0Eoooo0P0002Xco`030000H_ooo`00Moooo`03o`2Ioooooooo
01Goool00`0003?o03?o000W<ol00P0006Goool007Ooool00ol0VOooooooo`0Eoooo00<0000co`0c
o`009S?o00030000oooooooo06Goool007Ooool00ol0VOooooooo`0Eoooo00<0000co`0co`009C?o
00030000oooooooo06Koool007Ooool00ol0VOooooooo`0Eoooo00<0000co`0co`0093?o00030000
oooooooo06Ooool007Ooool00ol0VOooooooo`0Eoooo00<0000co`0co`008S?o0080001Zoooo001g
oooo00?o09Woooooool05Oooo`80000R<ol000<0003oooooool0J_ooo`00Moooo`03o`2Ioooooooo
01Goool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00Moooo`03o`2Ioooooooo01Goool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Moooo`03o`2Ioooooooo01Goool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00Moooo`03o`2Ioooooooo01Goool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00Moooo`03o`2Ioooooooo01Goool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00Moooo`03o`2Ioooooooo01Goool200007C?o00030000oooooooo06ooool0
07Ooool00ol0VOooooooo`0Eoooo00<0000co`0co`006c?o00030000oooooooo073oool007Ooool0
0ol0VOooooooo`0Eoooo00<0000co`0co`006c?o00030000oooooooo073oool007Ooool00ol0VOoo
ooooo`0Eoooo00<0000co`0co`006S?o00030000oooooooo077oool007Ooool00ol0VOooooooo`0E
oooo00<0000co`0co`006S?o00030000oooooooo077oool007Ooool00ol0VOooooooo`0Eoooo00<0
000co`0co`006C?o00030000oooooooo07;oool007Ooool00ol0VOooooooo`0Eoooo0P0001Xco`00
0`000?ooooooo`1boooo001goooo00?o09Woooooool05Oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001goooo00?o09Woooooool05Oooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo001goooo00?o09Woooooool05Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001g
oooo00?o09Woooooool05Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001goooo00?o
09Woooooool03Oooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool007Ooool0
0ol0VOooooooo`0?oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo001goooo00?o09Woooooool03oooo`030000oooooooo00?oool300005C?o00030000oooooooo
07Koool007Ooool00ol0VOooooooo`0?oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1foooo001goooo00?o09Woooooool03oooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00Moooo`03o`2Ioooooooo00koool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001goooo00?o09Woooooool05Oooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo001goooo00?o09Woooooool05Oooo`030000<ol0<ol001<co`00
0`000?ooooooo`1hoooo001goooo00?o09Woooooool05Oooo`80000D<ol000<0003oooooool0N?oo
o`00Moooo`03o`2Ioooooooo01Goool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00Mooo
o`03o`2Ioooooooo01Goool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Moooo`03o`2I
oooooooo01Goool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Moooo`03o`2Ioooooooo
01Goool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Moooo`03o`2Ioooooooo01Goool0
0`0003?o03?o000A<ol000<0003oooooool0N_ooo`00Moooo`03o`2Ioooooooo01Goool200004S?o
00030000oooooooo07[oool007Ooool00ol0VOooooooo`0Eoooo00<0000co`0co`004C?o00030000
oooooooo07[oool007Ooool00ol0VOooooooo`0Eoooo00<0000co`0co`004C?o00030000oooooooo
07[oool007Ooool00ol0VOooooooo`0Eoooo00<0000co`0co`0043?o00030000oooooooo07_oool0
07Ooool00ol0VOooooooo`0Eoooo00<0000co`0co`0043?o00030000oooooooo07_oool007Ooool0
0ol0VOooooooo`0Eoooo00<0000co`0co`0043?o00030000oooooooo07_oool007Ooool00ol0VOoo
ooooo`0Eoooo00<0000co`0co`0043?o00030000oooooooo07_oool007Ooool00ol0VOooooooo`0E
oooo0P00010co`000`000?ooooooo`1loooo001goooo00?o09Woooooool05Oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001goooo00?o09Woooooool05Oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001goooo00?o09Woooooool05Oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001goooo00?o09Woooooool05Oooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo001goooo00?o09Woooooool05Oooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001g
oooo00?o09Woooooool05Oooo`80000?<ol000<0003oooooool0OOooo`00Moooo`03o`2Ioooooooo
01Goool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Moooo`03o`2Ioooooooo01Goool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00Moooo`03o`2Ioooooooo01Goool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00Moooo`03o`2Ioooooooo00goool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001goooo00?o09Woooooool03Oooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Moooo`03o`2Ioooooooo00koool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001goooo00?o09Woooooool03ooo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Moooo`03o`2I
oooooooo00goool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00Moooo`03o`2Ioooooooo00koool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001goooo00?o09Woooooool05Oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001g
oooo00?o09Woooooool05Oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001goooo00?o
09Woooooool05Oooo`80000=<ol000<0003oooooool0Ooooo`00Moooo`03o`2Ioooooooo01Goool0
0`0003?o03?o000<<ol000<0003oooooool0Ooooo`00Moooo`03o`2Ioooooooo01Goool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00Moooo`03o`2Ioooooooo01Goool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00Moooo`03o`2Ioooooooo01Goool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00Moooo`03o`2Ioooooooo01Goool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Moooo`03o`2Ioooooooo01Goool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00Moooo`03o`2Ioooooooo01Goool2000033?o00030000oooooooo083oool007Ooool00ol0VOoo
ooooo`0Eoooo00<0000co`0co`002c?o00030000oooooooo083oool007Ooool00ol0VOooooooo`0E
oooo00<0000co`0co`002S?o00030000oooooooo087oool007Ooool00ol0VOooooooo`0Eoooo00<0
000co`0co`002S?o00030000oooooooo087oool007Ooool00ol0VOooooooo`0Eoooo00<0000co`0c
o`002S?o00030000oooooooo087oool007Ooool00ol0VOooooooo`0Eoooo00<0000co`0co`002S?o
00030000oooooooo087oool007Ooool00ol0VOooooooo`0Eoooo0P0000/co`000`000?ooooooo`21
oooo001goooo00?o09Woooooool05Oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001g
oooo00?o09Woooooool05Oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001goooo00?o
09Woooooool05Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001goooo00?o09Wooooo
ool05Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001goooo00?o09Woooooool05Ooo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001goooo00?o09Woooooool05Oooo`80000:
<ol000<0003oooooool0P_ooo`00Moooo`03o`2Ioooooooo01Goool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00Moooo`03o`2Ioooooooo01Goool00`0003?o03?o0009<ol000<0003ooooo
ool0P_ooo`00Moooo`03o`2Ioooooooo01Goool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00Moooo`03o`2Ioooooooo00koool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001goooo00?o09Woooooool03Oooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo001goooo00?o09Woooooool03oooo`030000oooooooo00?oool3000023?o
00030000oooooooo08?oool007Ooool00ol0VOooooooo`0@oooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo001goooo00?o09Woooooool03Oooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001goooo00?o09Woooooool03_oo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool007Ooool00ol0VOooooooo`0E
oooo00<0000co`0co`001c?o00030000oooooooo08Coool007Ooool00ol0VOooooooo`0Eoooo00<0
000co`0co`001c?o00030000oooooooo08Coool007Ooool00ol0VOooooooo`0Eoooo00<0000co`0c
o`001c?o00030000oooooooo08Coool007Ooool00ol0VOooooooo`0Eoooo0P0000Pco`000`000?oo
ooooo`24oooo001goooo00?o09Woooooool05Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001goooo00?o09Woooooool05Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001g
oooo00?o09Woooooool05Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001goooo00?o
09Woooooool05Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001goooo00?o09Wooooo
ool05Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001goooo00?o09Woooooool05Ooo
o`800007<ol000<0003oooooool0QOooo`00Moooo`03o`2Ioooooooo01Goool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00Moooo`03o`2Ioooooooo01Goool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00Moooo`03o`2Ioooooooo01Goool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00Moooo`03o`2Ioooooooo01Goool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00Moooo`03o`2Ioooooooo01Goool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00Mooo
o`03o`2Ioooooooo01Goool200001S?o00030000oooooooo08Koool007Ooool00ol0VOooooooo`0E
oooo00<0000co`0co`001C?o00030000oooooooo08Koool007Ooool00ol0VOooooooo`0Eoooo00<0
000co`0co`001C?o00030000oooooooo08Koool007Ooool00ol0VOooooooo`0Eoooo00<0000co`0c
o`001C?o00030000oooooooo08Koool007Ooool00ol0VOooooooo`0Eoooo00<0000co`0co`001C?o
00030000oooooooo08Koool007Ooool00ol0VOooooooo`0Eoooo00<0000co`0co`001C?o00030000
oooooooo08Koool007Ooool00ol0VOooooooo`0Eoooo0P0000Hco`000`000?ooooooo`26oooo001g
oooo00?o09Woooooool05Oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001goooo00?o
09Woooooool05Oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001goooo00?o09Wooooo
ool05Oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001goooo00?o09Woooooool05Ooo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo001goooo00?o09Woooooool03oooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool007Ooool00ol0VOooooooo`0@oooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001goooo00?o09Wooooo
ool03Oooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00O?ooo`030000oooooooo013oool7<ol02ooo
o`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool01_ooo`Lco`0<
oooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Koool00c?o000000000004<ol00P0000?oool300001?ooo`030000oooooooo07_oool007_oool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0100003?o
03?o000000<co`05oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000
oooooooo00;oool00`000?ooooooo`0=oooo00@0000co`0co`000003<ol01Oooo`040000oooooooo
00001?ooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003?ooo`040000<ol0<ol0
00000c?o00Goool300001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000?
oooo00@0000co`0co`000003<ol01_ooo`030000oooooooo00?oool00`000?ooooooo`1koooo001l
oooo00<0003oooooool04?ooo`03<ol00000000000@co`06oooo0`0000;oool00`000?ooooooo`1l
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.62) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.39174 .12361 L
.40134 .12361 L
.40616 .12361 L
.40755 .12361 L
.40887 .12361 L
s
.40887 .12361 m
.40934 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.62) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003o09Woool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
02;oool00ol0VOooooooo`0Doooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00N?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000c<ol01P0005Goool007Soool00ol0VOoo
ooooo`0Doooo00<0000co`0co`00<C?o0080001Koooo001hoooo00?o09Woooooool05?ooo`030000
<ol0<ol002lco`020000GOooo`00N?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000/<ol00`00
05ooool007Soool00ol0VOooooooo`0Doooo0P0002Xco`030000H_ooo`00N?ooo`03o`2Ioooooooo
01Coool00`0003?o03?o000W<ol00P0006Goool007Soool00ol0VOooooooo`0Doooo00<0000co`0c
o`009S?o00030000oooooooo06Goool007Soool00ol0VOooooooo`0Doooo00<0000co`0co`009C?o
00030000oooooooo06Koool007Soool00ol0VOooooooo`0Doooo00<0000co`0co`0093?o00030000
oooooooo06Ooool007Soool00ol0VOooooooo`0Doooo00<0000co`0co`008S?o0080001Zoooo001h
oooo00?o09Woooooool05?ooo`80000R<ol000<0003oooooool0J_ooo`00N?ooo`03o`2Ioooooooo
01Coool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00N?ooo`03o`2Ioooooooo01Coool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00N?ooo`03o`2Ioooooooo01Coool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00N?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00N?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00N?ooo`03o`2Ioooooooo01Coool200007C?o00030000oooooooo06ooool0
07Soool00ol0VOooooooo`0Doooo00<0000co`0co`006c?o00030000oooooooo073oool007Soool0
0ol0VOooooooo`0Doooo00<0000co`0co`006c?o00030000oooooooo073oool007Soool00ol0VOoo
ooooo`0Doooo00<0000co`0co`006S?o00030000oooooooo077oool007Soool00ol0VOooooooo`0D
oooo00<0000co`0co`006S?o00030000oooooooo077oool007Soool00ol0VOooooooo`0Doooo00<0
000co`0co`006C?o00030000oooooooo07;oool007Soool00ol0VOooooooo`0Doooo0P0001Xco`00
0`000?ooooooo`1boooo001hoooo00?o09Woooooool05?ooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001hoooo00?o09Woooooool05?ooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo001hoooo00?o09Woooooool05?ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001h
oooo00?o09Woooooool05?ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001hoooo00?o
09Woooooool03?ooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool007Soool0
0ol0VOooooooo`0>oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo001hoooo00?o09Woooooool03_ooo`030000oooooooo00?oool300005C?o00030000oooooooo
07Koool007Soool00ol0VOooooooo`0>oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1foooo001hoooo00?o09Woooooool03_ooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00N?ooo`03o`2Ioooooooo00goool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001hoooo00?o09Woooooool05?ooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo001hoooo00?o09Woooooool05?ooo`030000<ol0<ol001<co`00
0`000?ooooooo`1hoooo001hoooo00?o09Woooooool05?ooo`80000D<ol000<0003oooooool0N?oo
o`00N?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00N?oo
o`03o`2Ioooooooo01Coool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00N?ooo`03o`2I
oooooooo01Coool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00N?ooo`03o`2Ioooooooo
01Coool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00N?ooo`03o`2Ioooooooo01Coool0
0`0003?o03?o000A<ol000<0003oooooool0N_ooo`00N?ooo`03o`2Ioooooooo01Coool200004S?o
00030000oooooooo07[oool007Soool00ol0VOooooooo`0Doooo00<0000co`0co`004C?o00030000
oooooooo07[oool007Soool00ol0VOooooooo`0Doooo00<0000co`0co`004C?o00030000oooooooo
07[oool007Soool00ol0VOooooooo`0Doooo00<0000co`0co`0043?o00030000oooooooo07_oool0
07Soool00ol0VOooooooo`0Doooo00<0000co`0co`0043?o00030000oooooooo07_oool007Soool0
0ol0VOooooooo`0Doooo00<0000co`0co`0043?o00030000oooooooo07_oool007Soool00ol0VOoo
ooooo`0Doooo00<0000co`0co`0043?o00030000oooooooo07_oool007Soool00ol0VOooooooo`0D
oooo0P00010co`000`000?ooooooo`1loooo001hoooo00?o09Woooooool05?ooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001hoooo00?o09Woooooool05?ooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001hoooo00?o09Woooooool05?ooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001hoooo00?o09Woooooool05?ooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo001hoooo00?o09Woooooool05?ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001h
oooo00?o09Woooooool05?ooo`80000?<ol000<0003oooooool0OOooo`00N?ooo`03o`2Ioooooooo
01Coool00`0003?o03?o000><ol000<0003oooooool0OOooo`00N?ooo`03o`2Ioooooooo01Coool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00N?ooo`03o`2Ioooooooo01Coool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00N?ooo`03o`2Ioooooooo00coool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001hoooo00?o09Woooooool03?ooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00N?ooo`03o`2Ioooooooo00goool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001hoooo00?o09Woooooool03_oo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00N?ooo`03o`2I
oooooooo00coool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00N?ooo`03o`2Ioooooooo00goool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001hoooo00?o09Woooooool05?ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001h
oooo00?o09Woooooool05?ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001hoooo00?o
09Woooooool05?ooo`80000=<ol000<0003oooooool0Ooooo`00N?ooo`03o`2Ioooooooo01Coool0
0`0003?o03?o000<<ol000<0003oooooool0Ooooo`00N?ooo`03o`2Ioooooooo01Coool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00N?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00N?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00N?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00N?ooo`03o`2Ioooooooo01Coool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00N?ooo`03o`2Ioooooooo01Coool2000033?o00030000oooooooo083oool007Soool00ol0VOoo
ooooo`0Doooo00<0000co`0co`002c?o00030000oooooooo083oool007Soool00ol0VOooooooo`0D
oooo00<0000co`0co`002S?o00030000oooooooo087oool007Soool00ol0VOooooooo`0Doooo00<0
000co`0co`002S?o00030000oooooooo087oool007Soool00ol0VOooooooo`0Doooo00<0000co`0c
o`002S?o00030000oooooooo087oool007Soool00ol0VOooooooo`0Doooo00<0000co`0co`002S?o
00030000oooooooo087oool007Soool00ol0VOooooooo`0Doooo0P0000/co`000`000?ooooooo`21
oooo001hoooo00?o09Woooooool05?ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001h
oooo00?o09Woooooool05?ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001hoooo00?o
09Woooooool05?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001hoooo00?o09Wooooo
ool05?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001hoooo00?o09Woooooool05?oo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001hoooo00?o09Woooooool05?ooo`80000:
<ol000<0003oooooool0P_ooo`00N?ooo`03o`2Ioooooooo01Coool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00N?ooo`03o`2Ioooooooo01Coool00`0003?o03?o0009<ol000<0003ooooo
ool0P_ooo`00N?ooo`03o`2Ioooooooo01Coool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00N?ooo`03o`2Ioooooooo00goool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001hoooo00?o09Woooooool03?ooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo001hoooo00?o09Woooooool03_ooo`030000oooooooo00?oool3000023?o
00030000oooooooo08?oool007Soool00ol0VOooooooo`0?oooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo001hoooo00?o09Woooooool03?ooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001hoooo00?o09Woooooool03Ooo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool007Soool00ol0VOooooooo`0D
oooo00<0000co`0co`001c?o00030000oooooooo08Coool007Soool00ol0VOooooooo`0Doooo00<0
000co`0co`001c?o00030000oooooooo08Coool007Soool00ol0VOooooooo`0Doooo00<0000co`0c
o`001c?o00030000oooooooo08Coool007Soool00ol0VOooooooo`0Doooo0P0000Pco`000`000?oo
ooooo`24oooo001hoooo00?o09Woooooool05?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001hoooo00?o09Woooooool05?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001h
oooo00?o09Woooooool05?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001hoooo00?o
09Woooooool05?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001hoooo00?o09Wooooo
ool05?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001hoooo00?o09Woooooool05?oo
o`800007<ol000<0003oooooool0QOooo`00N?ooo`03o`2Ioooooooo01Coool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00N?ooo`03o`2Ioooooooo01Coool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00N?ooo`03o`2Ioooooooo01Coool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00N?ooo`03o`2Ioooooooo01Coool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00N?ooo`03o`2Ioooooooo01Coool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00N?oo
o`03o`2Ioooooooo01Coool200001S?o00030000oooooooo08Koool007Soool00ol0VOooooooo`0D
oooo00<0000co`0co`001C?o00030000oooooooo08Koool007Soool00ol0VOooooooo`0Doooo00<0
000co`0co`001C?o00030000oooooooo08Koool007Soool00ol0VOooooooo`0Doooo00<0000co`0c
o`001C?o00030000oooooooo08Koool007Soool00ol0VOooooooo`0Doooo00<0000co`0co`001C?o
00030000oooooooo08Koool007Soool00ol0VOooooooo`0Doooo00<0000co`0co`001C?o00030000
oooooooo08Koool007Soool00ol0VOooooooo`0Doooo0P0000Hco`000`000?ooooooo`26oooo001h
oooo00?o09Woooooool05?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001hoooo00?o
09Woooooool05?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001hoooo00?o09Wooooo
ool05?ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001hoooo00?o09Woooooool05?oo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo001hoooo00?o09Woooooool03_ooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool007Soool00ol0VOooooooo`0?oooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001hoooo00?o09Wooooo
ool03?ooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool2000013?o008000000c?o0?ooooooo`0300000oooo`@00003oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo00001S?o00;oool010000?ooooooo`0000;oool00`000?ooooooo`04oooo00<0
003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003ooooo
ool00006<ol00_ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`1g
oooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`0000Hco`02oooo0`0000Goool0
0`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool0
10000?ooooooo`0000Hco`03oooo00<0003oooooool00_ooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`03oooo0`0000?oool200000ooo
o`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.64) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40134 .12361 L
.40616 .12361 L
.40882 .12361 L
.41134 .12361 L
.41276 .12361 L
.41357 .12361 L
s
.41357 .12361 m
.41387 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.64) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo09T02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
02?oool00ol0VOooooooo`0Coooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00NOooo`03o`2Ioooooooo01?oool00`0003?o03?o000c<ol01P0005Goool007Woool00ol0VOoo
ooooo`0Coooo00<0000co`0co`00<C?o0080001Koooo001ioooo00?o09Woooooool04oooo`030000
<ol0<ol002lco`020000GOooo`00NOooo`03o`2Ioooooooo01?oool00`0003?o03?o000/<ol00`00
05ooool007Woool00ol0VOooooooo`0Coooo0P0002Xco`030000H_ooo`00NOooo`03o`2Ioooooooo
01?oool00`0003?o03?o000W<ol00P0006Goool007Woool00ol0VOooooooo`0Coooo00<0000co`0c
o`009S?o00030000oooooooo06Goool007Woool00ol0VOooooooo`0Coooo00<0000co`0co`009C?o
00030000oooooooo06Koool007Woool00ol0VOooooooo`0Coooo00<0000co`0co`0093?o00030000
oooooooo06Ooool007Woool00ol0VOooooooo`0Coooo00<0000co`0co`008S?o0080001Zoooo001i
oooo00?o09Woooooool04oooo`80000R<ol000<0003oooooool0J_ooo`00NOooo`03o`2Ioooooooo
01?oool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00NOooo`03o`2Ioooooooo01?oool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00NOooo`03o`2Ioooooooo01?oool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00NOooo`03o`2Ioooooooo01?oool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00NOooo`03o`2Ioooooooo01?oool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00NOooo`03o`2Ioooooooo01?oool200007C?o00030000oooooooo06ooool0
07Woool00ol0VOooooooo`0Coooo00<0000co`0co`006c?o00030000oooooooo073oool007Woool0
0ol0VOooooooo`0Coooo00<0000co`0co`006c?o00030000oooooooo073oool007Woool00ol0VOoo
ooooo`0Coooo00<0000co`0co`006S?o00030000oooooooo077oool007Woool00ol0VOooooooo`0C
oooo00<0000co`0co`006S?o00030000oooooooo077oool007Woool00ol0VOooooooo`0Coooo00<0
000co`0co`006C?o00030000oooooooo07;oool007Woool00ol0VOooooooo`0Coooo0P0001Xco`00
0`000?ooooooo`1boooo001ioooo00?o09Woooooool04oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001ioooo00?o09Woooooool04oooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo001ioooo00?o09Woooooool04oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001i
oooo00?o09Woooooool04oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001ioooo00?o
09Woooooool02oooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool007Woool0
0ol0VOooooooo`0=oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo001ioooo00?o09Woooooool03Oooo`030000oooooooo00?oool300005C?o00030000oooooooo
07Koool007Woool00ol0VOooooooo`0=oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1foooo001ioooo00?o09Woooooool03Oooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00NOooo`03o`2Ioooooooo00coool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001ioooo00?o09Woooooool04oooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo001ioooo00?o09Woooooool04oooo`030000<ol0<ol001<co`00
0`000?ooooooo`1hoooo001ioooo00?o09Woooooool04oooo`80000D<ol000<0003oooooool0N?oo
o`00NOooo`03o`2Ioooooooo01?oool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00NOoo
o`03o`2Ioooooooo01?oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00NOooo`03o`2I
oooooooo01?oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00NOooo`03o`2Ioooooooo
01?oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00NOooo`03o`2Ioooooooo01?oool0
0`0003?o03?o000A<ol000<0003oooooool0N_ooo`00NOooo`03o`2Ioooooooo01?oool200004S?o
00030000oooooooo07[oool007Woool00ol0VOooooooo`0Coooo00<0000co`0co`004C?o00030000
oooooooo07[oool007Woool00ol0VOooooooo`0Coooo00<0000co`0co`004C?o00030000oooooooo
07[oool007Woool00ol0VOooooooo`0Coooo00<0000co`0co`0043?o00030000oooooooo07_oool0
07Woool00ol0VOooooooo`0Coooo00<0000co`0co`0043?o00030000oooooooo07_oool007Woool0
0ol0VOooooooo`0Coooo00<0000co`0co`0043?o00030000oooooooo07_oool007Woool00ol0VOoo
ooooo`0Coooo00<0000co`0co`0043?o00030000oooooooo07_oool007Woool00ol0VOooooooo`0C
oooo0P00010co`000`000?ooooooo`1loooo001ioooo00?o09Woooooool04oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001ioooo00?o09Woooooool04oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001ioooo00?o09Woooooool04oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001ioooo00?o09Woooooool04oooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo001ioooo00?o09Woooooool04oooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001i
oooo00?o09Woooooool04oooo`80000?<ol000<0003oooooool0OOooo`00NOooo`03o`2Ioooooooo
01?oool00`0003?o03?o000><ol000<0003oooooool0OOooo`00NOooo`03o`2Ioooooooo01?oool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00NOooo`03o`2Ioooooooo01?oool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00NOooo`03o`2Ioooooooo00_oool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001ioooo00?o09Woooooool02oooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00NOooo`03o`2Ioooooooo00coool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001ioooo00?o09Woooooool03Ooo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00NOooo`03o`2I
oooooooo00_oool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00NOooo`03o`2Ioooooooo00coool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001ioooo00?o09Woooooool04oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001i
oooo00?o09Woooooool04oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001ioooo00?o
09Woooooool04oooo`80000=<ol000<0003oooooool0Ooooo`00NOooo`03o`2Ioooooooo01?oool0
0`0003?o03?o000<<ol000<0003oooooool0Ooooo`00NOooo`03o`2Ioooooooo01?oool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00NOooo`03o`2Ioooooooo01?oool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00NOooo`03o`2Ioooooooo01?oool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00NOooo`03o`2Ioooooooo01?oool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00NOooo`03o`2Ioooooooo01?oool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00NOooo`03o`2Ioooooooo01?oool2000033?o00030000oooooooo083oool007Woool00ol0VOoo
ooooo`0Coooo00<0000co`0co`002c?o00030000oooooooo083oool007Woool00ol0VOooooooo`0C
oooo00<0000co`0co`002S?o00030000oooooooo087oool007Woool00ol0VOooooooo`0Coooo00<0
000co`0co`002S?o00030000oooooooo087oool007Woool00ol0VOooooooo`0Coooo00<0000co`0c
o`002S?o00030000oooooooo087oool007Woool00ol0VOooooooo`0Coooo00<0000co`0co`002S?o
00030000oooooooo087oool007Woool00ol0VOooooooo`0Coooo0P0000/co`000`000?ooooooo`21
oooo001ioooo00?o09Woooooool04oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001i
oooo00?o09Woooooool04oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001ioooo00?o
09Woooooool04oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001ioooo00?o09Wooooo
ool04oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001ioooo00?o09Woooooool04ooo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001ioooo00?o09Woooooool04oooo`80000:
<ol000<0003oooooool0P_ooo`00NOooo`03o`2Ioooooooo01?oool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00NOooo`03o`2Ioooooooo01?oool00`0003?o03?o0009<ol000<0003ooooo
ool0P_ooo`00NOooo`03o`2Ioooooooo01?oool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00NOooo`03o`2Ioooooooo00coool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001ioooo00?o09Woooooool02oooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo001ioooo00?o09Woooooool03Oooo`030000oooooooo00?oool3000023?o
00030000oooooooo08?oool007Woool00ol0VOooooooo`0>oooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo001ioooo00?o09Woooooool02oooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001ioooo00?o09Woooooool03?oo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool007Woool00ol0VOooooooo`0C
oooo00<0000co`0co`001c?o00030000oooooooo08Coool007Woool00ol0VOooooooo`0Coooo00<0
000co`0co`001c?o00030000oooooooo08Coool007Woool00ol0VOooooooo`0Coooo00<0000co`0c
o`001c?o00030000oooooooo08Coool007Woool00ol0VOooooooo`0Coooo0P0000Pco`000`000?oo
ooooo`24oooo001ioooo00?o09Woooooool04oooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001ioooo00?o09Woooooool04oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001i
oooo00?o09Woooooool04oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001ioooo00?o
09Woooooool04oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001ioooo00?o09Wooooo
ool04oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001ioooo00?o09Woooooool04ooo
o`800007<ol000<0003oooooool0QOooo`00NOooo`03o`2Ioooooooo01?oool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00NOooo`03o`2Ioooooooo01?oool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00NOooo`03o`2Ioooooooo01?oool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00NOooo`03o`2Ioooooooo01?oool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00NOooo`03o`2Ioooooooo01?oool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00NOoo
o`03o`2Ioooooooo01?oool200001S?o00030000oooooooo08Koool007Woool00ol0VOooooooo`0C
oooo00<0000co`0co`001C?o00030000oooooooo08Koool007Woool00ol0VOooooooo`0Coooo00<0
000co`0co`001C?o00030000oooooooo08Koool007Woool00ol0VOooooooo`0Coooo00<0000co`0c
o`001C?o00030000oooooooo08Koool007Woool00ol0VOooooooo`0Coooo00<0000co`0co`001C?o
00030000oooooooo08Koool007Woool00ol0VOooooooo`0Coooo00<0000co`0co`001C?o00030000
oooooooo08Koool007Woool00ol0VOooooooo`0Coooo0P0000Hco`000`000?ooooooo`26oooo001i
oooo00?o09Woooooool04oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001ioooo00?o
09Woooooool04oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001ioooo00?o09Wooooo
ool04oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001ioooo00?o09Woooooool04ooo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo001ioooo00?o09Woooooool03Oooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool007Woool00ol0VOooooooo`0>oooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001ioooo00?o09Wooooo
ool02oooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool2000013?o008000000c?o0?ooooooo`0300001Oooo`<00002oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo00001S?o00;oool010000?ooooooo`0000Goool01@000?ooooooooooo`00001j
oooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Hco`02
oooo00@0003oooooool00002oooo1@0000?oool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0000coool010000?ooooooo`0000Hco`02oooo0`0000?oool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00001S?o
00?oool00`000?ooooooo`03oooo00<0003oool000000oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Aoooo0P0000Lco`03oooo0`0000Coool200000_ooo`030000oooooooo07Woool0
08ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.66) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40134 .12361 L
.41134 .12361 L
.41408 .12361 L
.4156 .12361 L
.41703 .12361 L
.41768 .12361 L
.41837 .12361 L
s
.41837 .12361 m
.41867 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.66) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00@0003ooooooooo09T8oooo00<0
003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0
003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003ooooo
ool09?ooo`03o`2Ioooooooo01;oool00`0003?o03?o000i<ol02@0003Coool00`000?ooooooo`0E
oooo001joooo00?o09Woooooool04_ooo`030000<ol0<ol003<co`060000EOooo`00N_ooo`03o`2I
oooooooo01;oool00`0003?o03?o000a<ol00P0005_oool007[oool00ol0VOooooooo`0Boooo00<0
000co`0co`00;c?o0080001Moooo001joooo00?o09Woooooool04_ooo`030000<ol0<ol002`co`03
0000Goooo`00N_ooo`03o`2Ioooooooo01;oool20000:S?o00<0001Roooo001joooo00?o09Wooooo
ool04_ooo`030000<ol0<ol002Lco`020000IOooo`00N_ooo`03o`2Ioooooooo01;oool00`0003?o
03?o000V<ol000<0003oooooool0IOooo`00N_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000U
<ol000<0003oooooool0I_ooo`00N_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000T<ol000<0
003oooooool0Ioooo`00N_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000R<ol00P0006[oool0
07[oool00ol0VOooooooo`0Boooo0P00028co`000`000?ooooooo`1Zoooo001joooo00?o09Wooooo
ool04_ooo`030000<ol0<ol0020co`000`000?ooooooo`1[oooo001joooo00?o09Woooooool04_oo
o`030000<ol0<ol001lco`000`000?ooooooo`1/oooo001joooo00?o09Woooooool04_ooo`030000
<ol0<ol001lco`000`000?ooooooo`1/oooo001joooo00?o09Woooooool04_ooo`030000<ol0<ol0
01hco`000`000?ooooooo`1]oooo001joooo00?o09Woooooool04_ooo`030000<ol0<ol001dco`00
0`000?ooooooo`1^oooo001joooo00?o09Woooooool04_ooo`80000M<ol000<0003oooooool0Kooo
o`00N_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00N_oo
o`03o`2Ioooooooo01;oool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00N_ooo`03o`2I
oooooooo01;oool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00N_ooo`03o`2Ioooooooo
01;oool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00N_ooo`03o`2Ioooooooo01;oool0
0`0003?o03?o000I<ol000<0003oooooool0L_ooo`00N_ooo`03o`2Ioooooooo01;oool200006S?o
00030000oooooooo07;oool007[oool00ol0VOooooooo`0Boooo00<0000co`0co`0063?o00030000
oooooooo07?oool007[oool00ol0VOooooooo`0Boooo00<0000co`0co`0063?o00030000oooooooo
07?oool007[oool00ol0VOooooooo`0Boooo00<0000co`0co`005c?o00030000oooooooo07Coool0
07[oool00ol0VOooooooo`0Boooo00<0000co`0co`005c?o00030000oooooooo07Coool007[oool0
0ol0VOooooooo`0:oooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00N_oo
o`03o`2Ioooooooo00coool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo
07Goool007[oool00ol0VOooooooo`0<oooo00<0003oooooool00oooo`<0000E<ol000<0003ooooo
ool0M_ooo`00N_ooo`03o`2Ioooooooo00coool00`000?ooooooo`03oooo00<0000co`0co`005C?o
00030000oooooooo07Koool007[oool00ol0VOooooooo`0<oooo00<0003oooooool00oooo`030000
<ol0<ol001Dco`000`000?ooooooo`1foooo001joooo00?o09Woooooool02oooo`800005oooo00<0
000co`0co`0053?o00030000oooooooo07Ooool007[oool00ol0VOooooooo`0Boooo00<0000co`0c
o`0053?o00030000oooooooo07Ooool007[oool00ol0VOooooooo`0Boooo00<0000co`0co`004c?o
00030000oooooooo07Soool007[oool00ol0VOooooooo`0Boooo0P0001@co`000`000?ooooooo`1h
oooo001joooo00?o09Woooooool04_ooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo001j
oooo00?o09Woooooool04_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001joooo00?o
09Woooooool04_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001joooo00?o09Wooooo
ool04_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo001joooo00?o09Woooooool04_oo
o`030000<ol0<ol0014co`000`000?ooooooo`1joooo001joooo00?o09Woooooool04_ooo`80000B
<ol000<0003oooooool0N_ooo`00N_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000A<ol000<0
003oooooool0N_ooo`00N_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000A<ol000<0003ooooo
ool0N_ooo`00N_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000@<ol000<0003oooooool0Nooo
o`00N_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00N_oo
o`03o`2Ioooooooo01;oool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00N_ooo`03o`2I
oooooooo01;oool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00N_ooo`03o`2Ioooooooo
01;oool2000043?o00030000oooooooo07coool007[oool00ol0VOooooooo`0Boooo00<0000co`0c
o`003c?o00030000oooooooo07coool007[oool00ol0VOooooooo`0Boooo00<0000co`0co`003c?o
00030000oooooooo07coool007[oool00ol0VOooooooo`0Boooo00<0000co`0co`003c?o00030000
oooooooo07coool007[oool00ol0VOooooooo`0Boooo00<0000co`0co`003c?o00030000oooooooo
07coool007[oool00ol0VOooooooo`0Boooo00<0000co`0co`003S?o00030000oooooooo07goool0
07[oool00ol0VOooooooo`0Boooo0P0000lco`000`000?ooooooo`1moooo001joooo00?o09Wooooo
ool04_ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo001joooo00?o09Woooooool04_oo
o`030000<ol0<ol000hco`000`000?ooooooo`1moooo001joooo00?o09Woooooool04_ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo001joooo00?o09Woooooool02_ooo`@00004oooo00<0
000co`0co`003C?o00030000oooooooo07koool007[oool00ol0VOooooooo`0:oooo00<0003ooooo
ool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo001joooo00?o09Woooooool02ooo
o`030000oooooooo00Coool300003C?o00030000oooooooo07koool007[oool00ol0VOooooooo`0<
oooo00<0003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo001joooo00?o
09Woooooool02_ooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001joooo00?o09Woooooool02oooo`800005oooo00<0000co`0co`0033?o00030000oooooooo
07ooool007[oool00ol0VOooooooo`0Boooo00<0000co`0co`0033?o00030000oooooooo07ooool0
07[oool00ol0VOooooooo`0Boooo00<0000co`0co`0033?o00030000oooooooo07ooool007[oool0
0ol0VOooooooo`0Boooo0P0000dco`000`000?ooooooo`1ooooo001joooo00?o09Woooooool04_oo
o`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001joooo00?o09Woooooool04_ooo`030000
<ol0<ol000/co`000`000?ooooooo`20oooo001joooo00?o09Woooooool04_ooo`030000<ol0<ol0
00/co`000`000?ooooooo`20oooo001joooo00?o09Woooooool04_ooo`030000<ol0<ol000/co`00
0`000?ooooooo`20oooo001joooo00?o09Woooooool04_ooo`030000<ol0<ol000/co`000`000?oo
ooooo`20oooo001joooo00?o09Woooooool04_ooo`030000<ol0<ol000/co`000`000?ooooooo`20
oooo001joooo00?o09Woooooool04_ooo`80000<<ol000<0003oooooool0P?ooo`00N_ooo`03o`2I
oooooooo01;oool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00N_ooo`03o`2Ioooooooo
01;oool00`0003?o03?o000:<ol000<0003oooooool0POooo`00N_ooo`03o`2Ioooooooo01;oool0
0`0003?o03?o000:<ol000<0003oooooool0POooo`00N_ooo`03o`2Ioooooooo01;oool00`0003?o
03?o000:<ol000<0003oooooool0POooo`00N_ooo`03o`2Ioooooooo01;oool00`0003?o03?o000:
<ol000<0003oooooool0POooo`00N_ooo`03o`2Ioooooooo01;oool200002c?o00030000oooooooo
087oool007[oool00ol0VOooooooo`0Boooo00<0000co`0co`002S?o00030000oooooooo087oool0
07[oool00ol0VOooooooo`0Boooo00<0000co`0co`002S?o00030000oooooooo087oool007[oool0
0ol0VOooooooo`0Boooo00<0000co`0co`002C?o00030000oooooooo08;oool007[oool00ol0VOoo
ooooo`0Boooo00<0000co`0co`002C?o00030000oooooooo08;oool007[oool00ol0VOooooooo`0B
oooo00<0000co`0co`002C?o00030000oooooooo08;oool007[oool00ol0VOooooooo`0Boooo0P00
00Xco`000`000?ooooooo`22oooo001joooo00?o09Woooooool04_ooo`030000<ol0<ol000Tco`00
0`000?ooooooo`22oooo001joooo00?o09Woooooool04_ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`22oooo001joooo00?o09Woooooool04_ooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo001joooo00?o09Woooooool02oooo`800005oooo00<0000co`0co`0023?o00030000oooooooo
08?oool007[oool00ol0VOooooooo`0:oooo00@0003oooooool00004oooo00<0000co`0co`0023?o
00030000oooooooo08?oool007[oool00ol0VOooooooo`0<oooo00<0003oooooool00oooo`<00008
<ol000<0003oooooool0Poooo`00N_ooo`03o`2Ioooooooo00goool00`000?ooooooo`02oooo00<0
000co`0co`0023?o00030000oooooooo08?oool007[oool00ol0VOooooooo`0:oooo00@0003ooooo
ool00004oooo00<0000co`0co`0023?o00030000oooooooo08?oool007[oool00ol0VOooooooo`0;
oooo0P0000Goool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00N_ooo`03o`2Ioooooooo
01;oool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00N_ooo`03o`2Ioooooooo01;oool0
0`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00N_ooo`03o`2Ioooooooo01;oool00`0003?o
03?o0007<ol000<0003oooooool0Q?ooo`00N_ooo`03o`2Ioooooooo01;oool2000023?o00030000
oooooooo08Coool007[oool00ol0VOooooooo`0Boooo00<0000co`0co`001c?o00030000oooooooo
08Coool007[oool00ol0VOooooooo`0Boooo00<0000co`0co`001c?o00030000oooooooo08Coool0
07[oool00ol0VOooooooo`0Boooo00<0000co`0co`001c?o00030000oooooooo08Coool007[oool0
0ol0VOooooooo`0Boooo00<0000co`0co`001S?o00030000oooooooo08Goool007[oool00ol0VOoo
ooooo`0Boooo00<0000co`0co`001S?o00030000oooooooo08Goool007[oool00ol0VOooooooo`0B
oooo0P0000Lco`000`000?ooooooo`25oooo001joooo00?o09Woooooool04_ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`25oooo001joooo00?o09Woooooool04_ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`25oooo001joooo00?o09Woooooool04_ooo`030000<ol0<ol000Hco`000`000?oo
ooooo`25oooo001joooo00?o09Woooooool04_ooo`030000<ol0<ol000Hco`000`000?ooooooo`25
oooo001joooo00?o09Woooooool04_ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001j
oooo00?o09Woooooool04_ooo`800006<ol000<0003oooooool0Q_ooo`00N_ooo`03o`2Ioooooooo
01;oool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00N_ooo`03o`2Ioooooooo01;oool0
0`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00N_ooo`03o`2Ioooooooo01;oool00`0003?o
03?o0005<ol000<0003oooooool0Q_ooo`00N_ooo`03o`2Ioooooooo01;oool00`0003?o03?o0005
<ol000<0003oooooool0Q_ooo`00N_ooo`03o`2Ioooooooo01;oool00`0003?o03?o0005<ol000<0
003oooooool0Q_ooo`00N_ooo`03o`2Ioooooooo01;oool200001S?o00030000oooooooo08Koool0
07[oool00ol0VOooooooo`0Boooo00<0000co`0co`001C?o00030000oooooooo08Koool007[oool0
0ol0VOooooooo`0Boooo00<0000co`0co`001C?o00030000oooooooo08Koool007[oool00ol0VOoo
ooooo`0Boooo00<0000co`0co`0013?o00030000oooooooo08Ooool007[oool00ol0VOooooooo`0B
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool007[oool00ol0VOooooooo`0<oooo0`00
00?oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00N_ooo`03o`2Ioooooooo00goool0
0`000?ooooooo`02oooo00<0000co`0co`0013?o00030000oooooooo08Ooool007[oool00ol0VOoo
ooooo`0:oooo1@0000?oool3000013?o00030000oooooooo08Ooool008Ooool010000?ooooooo`00
00Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o
08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o
00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01oooo`800004<ol00P000003<ol0oooooooo00<00003oooo0`0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05
oooo00@0003oooooool00006<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000
oooooooo00001S?o00;oool010000?ooooooo`0000;oool010000?ooooooo`0000Coool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`0000Hco`02oooo0`00
00?oool300001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0
003oooooool00006<ol00oooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo017oool200001c?o00?oool300000oooo`<00002oooo00<0
003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.68) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.41696 .12361 L
.41976 .12361 L
.42113 .12361 L
.42237 .12361 L
.42363 .12361 L
s
.42363 .12361 m
.42411 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.68) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool00_ooo`03o`2I
oooooooo00Coool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0Voooo00?o09Woooooool04?ooo`030000<ol0<ol003Tco`090000=?oo
o`030000oooooooo01Goool007coool00ol0VOooooooo`0@oooo00<0000co`0co`00<c?o00H0001E
oooo001loooo00?o09Woooooool04?ooo`030000<ol0<ol0034co`020000Foooo`00O?ooo`03o`2I
oooooooo013oool00`0003?o03?o000_<ol00P0005goool007coool00ol0VOooooooo`0@oooo00<0
000co`0co`00;3?o00<0001Ooooo001loooo00?o09Woooooool04?ooo`80000Z<ol00`0006;oool0
07coool00ol0VOooooooo`0@oooo00<0000co`0co`009c?o0080001Uoooo001loooo00?o09Wooooo
ool04?ooo`030000<ol0<ol002Hco`000`000?ooooooo`1Uoooo001loooo00?o09Woooooool04?oo
o`030000<ol0<ol002Dco`000`000?ooooooo`1Voooo001loooo00?o09Woooooool04?ooo`030000
<ol0<ol002@co`000`000?ooooooo`1Woooo001loooo00?o09Woooooool04?ooo`030000<ol0<ol0
028co`020000J_ooo`00O?ooo`03o`2Ioooooooo013oool200008S?o00030000oooooooo06[oool0
07coool00ol0VOooooooo`0@oooo00<0000co`0co`0083?o00030000oooooooo06_oool007coool0
0ol0VOooooooo`0@oooo00<0000co`0co`007c?o00030000oooooooo06coool007coool00ol0VOoo
ooooo`0@oooo00<0000co`0co`007c?o00030000oooooooo06coool007coool00ol0VOooooooo`0@
oooo00<0000co`0co`007S?o00030000oooooooo06goool007coool00ol0VOooooooo`0@oooo00<0
000co`0co`007C?o00030000oooooooo06koool007coool00ol0VOooooooo`0@oooo0P0001dco`00
0`000?ooooooo`1_oooo001loooo00?o09Woooooool04?ooo`030000<ol0<ol001/co`000`000?oo
ooooo`1`oooo001loooo00?o09Woooooool04?ooo`030000<ol0<ol001/co`000`000?ooooooo`1`
oooo001loooo00?o09Woooooool04?ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001l
oooo00?o09Woooooool04?ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001loooo00?o
09Woooooool04?ooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo001loooo00?o09Wooooo
ool04?ooo`80000J<ol000<0003oooooool0L_ooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o
03?o000H<ol000<0003oooooool0Loooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o000H
<ol000<0003oooooool0Loooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o000G<ol000<0
003oooooool0M?ooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o000G<ol000<0003ooooo
ool0M?ooo`00O?ooo`03o`2Ioooooooo00Soool500000oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001loooo00?o09Woooooool02_ooo`030000oooooooo00?oool00`0003?o03?o000F
<ol000<0003oooooool0MOooo`00O?ooo`03o`2Ioooooooo00[oool00`000?ooooooo`03oooo0`00
01Dco`000`000?ooooooo`1foooo001loooo00?o09Woooooool02_ooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00O?ooo`03o`2Ioooooooo00[oool00`000?oo
ooooo`03oooo00<0000co`0co`005C?o00030000oooooooo07Koool007coool00ol0VOooooooo`09
oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00O?ooo`03o`2Ioooooooo
013oool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00O?ooo`03o`2Ioooooooo013oool0
0`0003?o03?o000C<ol000<0003oooooool0N?ooo`00O?ooo`03o`2Ioooooooo013oool2000053?o
00030000oooooooo07Soool007coool00ol0VOooooooo`0@oooo00<0000co`0co`004c?o00030000
oooooooo07Soool007coool00ol0VOooooooo`0@oooo00<0000co`0co`004S?o00030000oooooooo
07Woool007coool00ol0VOooooooo`0@oooo00<0000co`0co`004S?o00030000oooooooo07Woool0
07coool00ol0VOooooooo`0@oooo00<0000co`0co`004S?o00030000oooooooo07Woool007coool0
0ol0VOooooooo`0@oooo00<0000co`0co`004C?o00030000oooooooo07[oool007coool00ol0VOoo
ooooo`0@oooo0P00018co`000`000?ooooooo`1joooo001loooo00?o09Woooooool04?ooo`030000
<ol0<ol0014co`000`000?ooooooo`1joooo001loooo00?o09Woooooool04?ooo`030000<ol0<ol0
014co`000`000?ooooooo`1joooo001loooo00?o09Woooooool04?ooo`030000<ol0<ol0010co`00
0`000?ooooooo`1koooo001loooo00?o09Woooooool04?ooo`030000<ol0<ol0010co`000`000?oo
ooooo`1koooo001loooo00?o09Woooooool04?ooo`030000<ol0<ol0010co`000`000?ooooooo`1k
oooo001loooo00?o09Woooooool04?ooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo001l
oooo00?o09Woooooool04?ooo`80000@<ol000<0003oooooool0O?ooo`00O?ooo`03o`2Ioooooooo
013oool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00O?ooo`03o`2Ioooooooo013oool0
0`0003?o03?o000?<ol000<0003oooooool0O?ooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o
03?o000?<ol000<0003oooooool0O?ooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o000?
<ol000<0003oooooool0O?ooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o000><ol000<0
003oooooool0OOooo`00O?ooo`03o`2Ioooooooo013oool200003c?o00030000oooooooo07goool0
07coool00ol0VOooooooo`0@oooo00<0000co`0co`003S?o00030000oooooooo07goool007coool0
0ol0VOooooooo`0@oooo00<0000co`0co`003S?o00030000oooooooo07goool007coool00ol0VOoo
ooooo`0@oooo00<0000co`0co`003C?o00030000oooooooo07koool007coool00ol0VOooooooo`08
oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00O?ooo`03o`2Ioooooooo
00Soool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo07koool007coool0
0ol0VOooooooo`09oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0O_ooo`00O?oo
o`03o`2Ioooooooo00[oool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo
07koool007coool00ol0VOooooooo`08oooo00@0003oooooool00004oooo00<0000co`0co`0033?o
00030000oooooooo07ooool007coool00ol0VOooooooo`09oooo0P0000Goool00`0003?o03?o000<
<ol000<0003oooooool0Ooooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o000<<ol000<0
003oooooool0Ooooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00O?ooo`03o`2Ioooooooo013oool200003C?o00030000oooooooo07ooool007coool0
0ol0VOooooooo`0@oooo00<0000co`0co`0033?o00030000oooooooo07ooool007coool00ol0VOoo
ooooo`0@oooo00<0000co`0co`002c?o00030000oooooooo083oool007coool00ol0VOooooooo`0@
oooo00<0000co`0co`002c?o00030000oooooooo083oool007coool00ol0VOooooooo`0@oooo00<0
000co`0co`002c?o00030000oooooooo083oool007coool00ol0VOooooooo`0@oooo00<0000co`0c
o`002c?o00030000oooooooo083oool007coool00ol0VOooooooo`0@oooo00<0000co`0co`002c?o
00030000oooooooo083oool007coool00ol0VOooooooo`0@oooo0P0000`co`000`000?ooooooo`20
oooo001loooo00?o09Woooooool04?ooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001l
oooo00?o09Woooooool04?ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001loooo00?o
09Woooooool04?ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001loooo00?o09Wooooo
ool04?ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001loooo00?o09Woooooool04?oo
o`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001loooo00?o09Woooooool04?ooo`80000;
<ol000<0003oooooool0POooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o000:<ol000<0003ooooo
ool0POooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o0009<ol000<0003oooooool0P_oo
o`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00O?oo
o`03o`2Ioooooooo013oool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00O?ooo`03o`2I
oooooooo013oool200002S?o00030000oooooooo08;oool007coool00ol0VOooooooo`0@oooo00<0
000co`0co`002C?o00030000oooooooo08;oool007coool00ol0VOooooooo`0@oooo00<0000co`0c
o`002C?o00030000oooooooo08;oool007coool00ol0VOooooooo`0@oooo00<0000co`0co`0023?o
00030000oooooooo08?oool007coool00ol0VOooooooo`09oooo0P0000Goool00`0003?o03?o0008
<ol000<0003oooooool0Poooo`00O?ooo`03o`2Ioooooooo00Soool010000?ooooooo`0000Coool0
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00O?ooo`03o`2Ioooooooo00[oool00`000?oo
ooooo`03oooo0`0000Pco`000`000?ooooooo`23oooo001loooo00?o09Woooooool02oooo`030000
oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00O?ooo`03o`2Ioooooooo
00Soool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00O?oo
o`03o`2Ioooooooo00Woool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001l
oooo00?o09Woooooool04?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001loooo00?o
09Woooooool04?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001loooo00?o09Wooooo
ool04?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001loooo00?o09Woooooool04?oo
o`800008<ol000<0003oooooool0Q?ooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o0007<ol000<0
003oooooool0Q?ooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o0007<ol000<0003ooooo
ool0Q?ooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00O?oo
o`03o`2Ioooooooo013oool200001c?o00030000oooooooo08Goool007coool00ol0VOooooooo`0@
oooo00<0000co`0co`001S?o00030000oooooooo08Goool007coool00ol0VOooooooo`0@oooo00<0
000co`0co`001S?o00030000oooooooo08Goool007coool00ol0VOooooooo`0@oooo00<0000co`0c
o`001S?o00030000oooooooo08Goool007coool00ol0VOooooooo`0@oooo00<0000co`0co`001S?o
00030000oooooooo08Goool007coool00ol0VOooooooo`0@oooo00<0000co`0co`001S?o00030000
oooooooo08Goool007coool00ol0VOooooooo`0@oooo0P0000Hco`000`000?ooooooo`26oooo001l
oooo00?o09Woooooool04?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001loooo00?o
09Woooooool04?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001loooo00?o09Wooooo
ool04?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001loooo00?o09Woooooool04?oo
o`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001loooo00?o09Woooooool04?ooo`030000
<ol0<ol000Dco`000`000?ooooooo`26oooo001loooo00?o09Woooooool04?ooo`800006<ol000<0
003oooooool0Q_ooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o0005<ol000<0003oooooool0Q_oo
o`00O?ooo`03o`2Ioooooooo013oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00O?oo
o`03o`2Ioooooooo013oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00O?ooo`03o`2I
oooooooo00[oool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001loooo00?o
09Woooooool02oooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0Qooo
o`00O?ooo`03o`2Ioooooooo00Soool500000oooo`<00004<ol000<0003oooooool0Qoooo`00Qooo
o`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029
oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?oo
ooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000@co`02000000<co`3oooooool00`0000Coool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool010000?ooooooo`0000Hco`02oooo00@0003oooooool00002oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0=oooo00@0003oooooool00006<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo
00001?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo
00001S?o00;oool300001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Hco`03oooo00<0003oooooool00_ooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`03oooo0`00
00?oool200000oooo`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.41696 .12361 L
.42237 .12361 L
.42482 .12361 L
.42617 .12361 L
.42744 .12361 L
.42816 .12361 L
s
.42816 .12361 m
.42847 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool00oooo`03o`2I
oooooooo00?oool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0Woooo00?o09Woooooool03oooo`030000<ol0<ol003Tco`090000=?oo
o`030000oooooooo01Goool007goool00ol0VOooooooo`0?oooo00<0000co`0co`00<c?o00H0001E
oooo001moooo00?o09Woooooool03oooo`030000<ol0<ol0034co`020000Foooo`00OOooo`03o`2I
oooooooo00ooool00`0003?o03?o000_<ol00P0005goool007goool00ol0VOooooooo`0?oooo00<0
000co`0co`00;3?o00<0001Ooooo001moooo00?o09Woooooool03oooo`80000Z<ol00`0006;oool0
07goool00ol0VOooooooo`0?oooo00<0000co`0co`009c?o0080001Uoooo001moooo00?o09Wooooo
ool03oooo`030000<ol0<ol002Hco`000`000?ooooooo`1Uoooo001moooo00?o09Woooooool03ooo
o`030000<ol0<ol002Dco`000`000?ooooooo`1Voooo001moooo00?o09Woooooool03oooo`030000
<ol0<ol002@co`000`000?ooooooo`1Woooo001moooo00?o09Woooooool03oooo`030000<ol0<ol0
028co`020000J_ooo`00OOooo`03o`2Ioooooooo00ooool200008S?o00030000oooooooo06[oool0
07goool00ol0VOooooooo`0?oooo00<0000co`0co`0083?o00030000oooooooo06_oool007goool0
0ol0VOooooooo`0?oooo00<0000co`0co`007c?o00030000oooooooo06coool007goool00ol0VOoo
ooooo`0?oooo00<0000co`0co`007c?o00030000oooooooo06coool007goool00ol0VOooooooo`0?
oooo00<0000co`0co`007S?o00030000oooooooo06goool007goool00ol0VOooooooo`0?oooo00<0
000co`0co`007C?o00030000oooooooo06koool007goool00ol0VOooooooo`0?oooo0P0001dco`00
0`000?ooooooo`1_oooo001moooo00?o09Woooooool03oooo`030000<ol0<ol001/co`000`000?oo
ooooo`1`oooo001moooo00?o09Woooooool03oooo`030000<ol0<ol001/co`000`000?ooooooo`1`
oooo001moooo00?o09Woooooool03oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001m
oooo00?o09Woooooool03oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001moooo00?o
09Woooooool03oooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo001moooo00?o09Wooooo
ool03oooo`80000J<ol000<0003oooooool0L_ooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o
03?o000H<ol000<0003oooooool0Loooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000H
<ol000<0003oooooool0Loooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000G<ol000<0
003oooooool0M?ooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000G<ol000<0003ooooo
ool0M?ooo`00OOooo`03o`2Ioooooooo00Ooool500000oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001moooo00?o09Woooooool02Oooo`030000oooooooo00?oool00`0003?o03?o000F
<ol000<0003oooooool0MOooo`00OOooo`03o`2Ioooooooo00Woool00`000?ooooooo`03oooo0`00
01Dco`000`000?ooooooo`1foooo001moooo00?o09Woooooool02Oooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00OOooo`03o`2Ioooooooo00Woool00`000?oo
ooooo`03oooo00<0000co`0co`005C?o00030000oooooooo07Koool007goool00ol0VOooooooo`08
oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00OOooo`03o`2Ioooooooo
00ooool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00OOooo`03o`2Ioooooooo00ooool0
0`0003?o03?o000C<ol000<0003oooooool0N?ooo`00OOooo`03o`2Ioooooooo00ooool2000053?o
00030000oooooooo07Soool007goool00ol0VOooooooo`0?oooo00<0000co`0co`004c?o00030000
oooooooo07Soool007goool00ol0VOooooooo`0?oooo00<0000co`0co`004S?o00030000oooooooo
07Woool007goool00ol0VOooooooo`0?oooo00<0000co`0co`004S?o00030000oooooooo07Woool0
07goool00ol0VOooooooo`0?oooo00<0000co`0co`004S?o00030000oooooooo07Woool007goool0
0ol0VOooooooo`0?oooo00<0000co`0co`004C?o00030000oooooooo07[oool007goool00ol0VOoo
ooooo`0?oooo0P00018co`000`000?ooooooo`1joooo001moooo00?o09Woooooool03oooo`030000
<ol0<ol0014co`000`000?ooooooo`1joooo001moooo00?o09Woooooool03oooo`030000<ol0<ol0
014co`000`000?ooooooo`1joooo001moooo00?o09Woooooool03oooo`030000<ol0<ol0010co`00
0`000?ooooooo`1koooo001moooo00?o09Woooooool03oooo`030000<ol0<ol0010co`000`000?oo
ooooo`1koooo001moooo00?o09Woooooool03oooo`030000<ol0<ol0010co`000`000?ooooooo`1k
oooo001moooo00?o09Woooooool03oooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo001m
oooo00?o09Woooooool03oooo`80000@<ol000<0003oooooool0O?ooo`00OOooo`03o`2Ioooooooo
00ooool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00OOooo`03o`2Ioooooooo00ooool0
0`0003?o03?o000?<ol000<0003oooooool0O?ooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o
03?o000?<ol000<0003oooooool0O?ooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000?
<ol000<0003oooooool0O?ooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000><ol000<0
003oooooool0OOooo`00OOooo`03o`2Ioooooooo00ooool200003c?o00030000oooooooo07goool0
07goool00ol0VOooooooo`0?oooo00<0000co`0co`003S?o00030000oooooooo07goool007goool0
0ol0VOooooooo`0?oooo00<0000co`0co`003S?o00030000oooooooo07goool007goool00ol0VOoo
ooooo`0?oooo00<0000co`0co`003C?o00030000oooooooo07koool007goool00ol0VOooooooo`07
oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00OOooo`03o`2Ioooooooo
00Ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo07koool007goool0
0ol0VOooooooo`08oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0O_ooo`00OOoo
o`03o`2Ioooooooo00Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo
07koool007goool00ol0VOooooooo`07oooo00@0003oooooool00004oooo00<0000co`0co`0033?o
00030000oooooooo07ooool007goool00ol0VOooooooo`08oooo0P0000Goool00`0003?o03?o000<
<ol000<0003oooooool0Ooooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000<<ol000<0
003oooooool0Ooooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00OOooo`03o`2Ioooooooo00ooool200003C?o00030000oooooooo07ooool007goool0
0ol0VOooooooo`0?oooo00<0000co`0co`0033?o00030000oooooooo07ooool007goool00ol0VOoo
ooooo`0?oooo00<0000co`0co`002c?o00030000oooooooo083oool007goool00ol0VOooooooo`0?
oooo00<0000co`0co`002c?o00030000oooooooo083oool007goool00ol0VOooooooo`0?oooo00<0
000co`0co`002c?o00030000oooooooo083oool007goool00ol0VOooooooo`0?oooo00<0000co`0c
o`002c?o00030000oooooooo083oool007goool00ol0VOooooooo`0?oooo00<0000co`0co`002c?o
00030000oooooooo083oool007goool00ol0VOooooooo`0?oooo0P0000`co`000`000?ooooooo`20
oooo001moooo00?o09Woooooool03oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001m
oooo00?o09Woooooool03oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001moooo00?o
09Woooooool03oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001moooo00?o09Wooooo
ool03oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001moooo00?o09Woooooool03ooo
o`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001moooo00?o09Woooooool03oooo`80000;
<ol000<0003oooooool0POooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o000:<ol000<0003ooooo
ool0POooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o0009<ol000<0003oooooool0P_oo
o`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00OOoo
o`03o`2Ioooooooo00ooool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00OOooo`03o`2I
oooooooo00ooool200002S?o00030000oooooooo08;oool007goool00ol0VOooooooo`0?oooo00<0
000co`0co`002C?o00030000oooooooo08;oool007goool00ol0VOooooooo`0?oooo00<0000co`0c
o`002C?o00030000oooooooo08;oool007goool00ol0VOooooooo`0?oooo00<0000co`0co`0023?o
00030000oooooooo08?oool007goool00ol0VOooooooo`08oooo0P0000Goool00`0003?o03?o0008
<ol000<0003oooooool0Poooo`00OOooo`03o`2Ioooooooo00Ooool010000?ooooooo`0000Coool0
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00OOooo`03o`2Ioooooooo00Woool00`000?oo
ooooo`03oooo0`0000Pco`000`000?ooooooo`23oooo001moooo00?o09Woooooool02_ooo`030000
oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00OOooo`03o`2Ioooooooo
00Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00OOoo
o`03o`2Ioooooooo00Soool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001m
oooo00?o09Woooooool03oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001moooo00?o
09Woooooool03oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001moooo00?o09Wooooo
ool03oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001moooo00?o09Woooooool03ooo
o`800008<ol000<0003oooooool0Q?ooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o0007<ol000<0
003oooooool0Q?ooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o0007<ol000<0003ooooo
ool0Q?ooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00OOoo
o`03o`2Ioooooooo00ooool200001c?o00030000oooooooo08Goool007goool00ol0VOooooooo`0?
oooo00<0000co`0co`001S?o00030000oooooooo08Goool007goool00ol0VOooooooo`0?oooo00<0
000co`0co`001S?o00030000oooooooo08Goool007goool00ol0VOooooooo`0?oooo00<0000co`0c
o`001S?o00030000oooooooo08Goool007goool00ol0VOooooooo`0?oooo00<0000co`0co`001S?o
00030000oooooooo08Goool007goool00ol0VOooooooo`0?oooo00<0000co`0co`001S?o00030000
oooooooo08Goool007goool00ol0VOooooooo`0?oooo0P0000Hco`000`000?ooooooo`26oooo001m
oooo00?o09Woooooool03oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001moooo00?o
09Woooooool03oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001moooo00?o09Wooooo
ool03oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001moooo00?o09Woooooool03ooo
o`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001moooo00?o09Woooooool03oooo`030000
<ol0<ol000Dco`000`000?ooooooo`26oooo001moooo00?o09Woooooool03oooo`800006<ol000<0
003oooooool0Q_ooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o0005<ol000<0003oooooool0Q_oo
o`00OOooo`03o`2Ioooooooo00ooool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00OOoo
o`03o`2Ioooooooo00ooool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00OOooo`03o`2I
oooooooo00Woool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001moooo00?o
09Woooooool02_ooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0Qooo
o`00OOooo`03o`2Ioooooooo00Ooool500000oooo`<00004<ol000<0003oooooool0Qoooo`00Qooo
o`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029
oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007coool00`000?oo
ooooo`0@oooo1c?o00_oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000
oooooooo00Koool7<ol03?ooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo00<co`000000000013?o00800005oooo00<0003oooooool00_oo
o`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool0100003?o03?o000000<co`07oooo00<0003oooooool00_ooo`030000
oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000<ol0<ol0
00000c?o00Ooool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000<oooo00@0000co`0co`000003<ol02?ooo`050000oooooooooooo000007goool007_oool0
1@000?ooooooooooo`00000?oooo00@0000co`0co`000003<ol01Oooo`040000oooooooo00000ooo
o`030000oooooooo07_oool007coool00`000?ooooooo`0@oooo00<co`000000000013?o00Goool4
00000_ooo`030000oooooooo07coool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.72) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.42237 .12361 L
.42781 .12361 L
.43049 .12361 L
.43179 .12361 L
.43298 .12361 L
s
.43298 .12361 m
.43344 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.72) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool01?ooo`03o`2I
oooooooo00;oool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0Xoooo00?o09Woooooool03_ooo`030000<ol0<ol003Tco`090000=?oo
o`030000oooooooo01Goool007koool00ol0VOooooooo`0>oooo00<0000co`0co`00<c?o00H0001E
oooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol0034co`020000Foooo`00O_ooo`03o`2I
oooooooo00koool00`0003?o03?o000_<ol00P0005goool007koool00ol0VOooooooo`0>oooo00<0
000co`0co`00;3?o00<0001Ooooo001noooo00?o09Woooooool03_ooo`80000Z<ol00`0006;oool0
07koool00ol0VOooooooo`0>oooo00<0000co`0co`009c?o0080001Uoooo001noooo00?o09Wooooo
ool03_ooo`030000<ol0<ol002Hco`000`000?ooooooo`1Uoooo001noooo00?o09Woooooool03_oo
o`030000<ol0<ol002Dco`000`000?ooooooo`1Voooo001noooo00?o09Woooooool03_ooo`030000
<ol0<ol002@co`000`000?ooooooo`1Woooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol0
028co`020000J_ooo`00O_ooo`03o`2Ioooooooo00koool200008S?o00030000oooooooo06[oool0
07koool00ol0VOooooooo`0>oooo00<0000co`0co`0083?o00030000oooooooo06_oool007koool0
0ol0VOooooooo`0>oooo00<0000co`0co`007c?o00030000oooooooo06coool007koool00ol0VOoo
ooooo`0>oooo00<0000co`0co`007c?o00030000oooooooo06coool007koool00ol0VOooooooo`0>
oooo00<0000co`0co`007S?o00030000oooooooo06goool007koool00ol0VOooooooo`0>oooo00<0
000co`0co`007C?o00030000oooooooo06koool007koool00ol0VOooooooo`0>oooo0P0001dco`00
0`000?ooooooo`1_oooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol001/co`000`000?oo
ooooo`1`oooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol001/co`000`000?ooooooo`1`
oooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001n
oooo00?o09Woooooool03_ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo001noooo00?o
09Woooooool03_ooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo001noooo00?o09Wooooo
ool03_ooo`80000J<ol000<0003oooooool0L_ooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o
03?o000H<ol000<0003oooooool0Loooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000H
<ol000<0003oooooool0Loooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000G<ol000<0
003oooooool0M?ooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000G<ol000<0003ooooo
ool0M?ooo`00O_ooo`03o`2Ioooooooo00Koool500000oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001noooo00?o09Woooooool02?ooo`030000oooooooo00?oool00`0003?o03?o000F
<ol000<0003oooooool0MOooo`00O_ooo`03o`2Ioooooooo00Soool00`000?ooooooo`03oooo0`00
01Dco`000`000?ooooooo`1foooo001noooo00?o09Woooooool02?ooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00O_ooo`03o`2Ioooooooo00Soool00`000?oo
ooooo`03oooo00<0000co`0co`005C?o00030000oooooooo07Koool007koool00ol0VOooooooo`07
oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00O_ooo`03o`2Ioooooooo
00koool00`0003?o03?o000D<ol000<0003oooooool0Moooo`00O_ooo`03o`2Ioooooooo00koool0
0`0003?o03?o000C<ol000<0003oooooool0N?ooo`00O_ooo`03o`2Ioooooooo00koool2000053?o
00030000oooooooo07Soool007koool00ol0VOooooooo`0>oooo00<0000co`0co`004c?o00030000
oooooooo07Soool007koool00ol0VOooooooo`0>oooo00<0000co`0co`004S?o00030000oooooooo
07Woool007koool00ol0VOooooooo`0>oooo00<0000co`0co`004S?o00030000oooooooo07Woool0
07koool00ol0VOooooooo`0>oooo00<0000co`0co`004S?o00030000oooooooo07Woool007koool0
0ol0VOooooooo`0>oooo00<0000co`0co`004C?o00030000oooooooo07[oool007koool00ol0VOoo
ooooo`0>oooo0P00018co`000`000?ooooooo`1joooo001noooo00?o09Woooooool03_ooo`030000
<ol0<ol0014co`000`000?ooooooo`1joooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol0
014co`000`000?ooooooo`1joooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol0010co`00
0`000?ooooooo`1koooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol0010co`000`000?oo
ooooo`1koooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol0010co`000`000?ooooooo`1k
oooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo001n
oooo00?o09Woooooool03_ooo`80000@<ol000<0003oooooool0O?ooo`00O_ooo`03o`2Ioooooooo
00koool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00O_ooo`03o`2Ioooooooo00koool0
0`0003?o03?o000?<ol000<0003oooooool0O?ooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o
03?o000?<ol000<0003oooooool0O?ooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000?
<ol000<0003oooooool0O?ooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000><ol000<0
003oooooool0OOooo`00O_ooo`03o`2Ioooooooo00koool200003c?o00030000oooooooo07goool0
07koool00ol0VOooooooo`0>oooo00<0000co`0co`003S?o00030000oooooooo07goool007koool0
0ol0VOooooooo`0>oooo00<0000co`0co`003S?o00030000oooooooo07goool007koool00ol0VOoo
ooooo`0>oooo00<0000co`0co`003C?o00030000oooooooo07koool007koool00ol0VOooooooo`06
oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00O_ooo`03o`2Ioooooooo
00Koool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo07koool007koool0
0ol0VOooooooo`07oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0O_ooo`00O_oo
o`03o`2Ioooooooo00Soool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo
07koool007koool00ol0VOooooooo`06oooo00@0003oooooool00004oooo00<0000co`0co`0033?o
00030000oooooooo07ooool007koool00ol0VOooooooo`07oooo0P0000Goool00`0003?o03?o000<
<ol000<0003oooooool0Ooooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000<<ol000<0
003oooooool0Ooooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00O_ooo`03o`2Ioooooooo00koool200003C?o00030000oooooooo07ooool007koool0
0ol0VOooooooo`0>oooo00<0000co`0co`0033?o00030000oooooooo07ooool007koool00ol0VOoo
ooooo`0>oooo00<0000co`0co`002c?o00030000oooooooo083oool007koool00ol0VOooooooo`0>
oooo00<0000co`0co`002c?o00030000oooooooo083oool007koool00ol0VOooooooo`0>oooo00<0
000co`0co`002c?o00030000oooooooo083oool007koool00ol0VOooooooo`0>oooo00<0000co`0c
o`002c?o00030000oooooooo083oool007koool00ol0VOooooooo`0>oooo00<0000co`0co`002c?o
00030000oooooooo083oool007koool00ol0VOooooooo`0>oooo0P0000`co`000`000?ooooooo`20
oooo001noooo00?o09Woooooool03_ooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo001n
oooo00?o09Woooooool03_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001noooo00?o
09Woooooool03_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001noooo00?o09Wooooo
ool03_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001noooo00?o09Woooooool03_oo
o`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001noooo00?o09Woooooool03_ooo`80000;
<ol000<0003oooooool0POooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o000:<ol000<0003ooooo
ool0POooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o0009<ol000<0003oooooool0P_oo
o`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00O_oo
o`03o`2Ioooooooo00koool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00O_ooo`03o`2I
oooooooo00koool200002S?o00030000oooooooo08;oool007koool00ol0VOooooooo`0>oooo00<0
000co`0co`002C?o00030000oooooooo08;oool007koool00ol0VOooooooo`0>oooo00<0000co`0c
o`002C?o00030000oooooooo08;oool007koool00ol0VOooooooo`0>oooo00<0000co`0co`0023?o
00030000oooooooo08?oool007koool00ol0VOooooooo`07oooo0P0000Goool00`0003?o03?o0008
<ol000<0003oooooool0Poooo`00O_ooo`03o`2Ioooooooo00Koool010000?ooooooo`0000Coool0
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00O_ooo`03o`2Ioooooooo00Soool00`000?oo
ooooo`03oooo0`0000Pco`000`000?ooooooo`23oooo001noooo00?o09Woooooool02Oooo`030000
oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00O_ooo`03o`2Ioooooooo
00Koool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00O_oo
o`03o`2Ioooooooo00Ooool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001n
oooo00?o09Woooooool03_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001noooo00?o
09Woooooool03_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001noooo00?o09Wooooo
ool03_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001noooo00?o09Woooooool03_oo
o`800008<ol000<0003oooooool0Q?ooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o0007<ol000<0
003oooooool0Q?ooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o0007<ol000<0003ooooo
ool0Q?ooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00O_oo
o`03o`2Ioooooooo00koool200001c?o00030000oooooooo08Goool007koool00ol0VOooooooo`0>
oooo00<0000co`0co`001S?o00030000oooooooo08Goool007koool00ol0VOooooooo`0>oooo00<0
000co`0co`001S?o00030000oooooooo08Goool007koool00ol0VOooooooo`0>oooo00<0000co`0c
o`001S?o00030000oooooooo08Goool007koool00ol0VOooooooo`0>oooo00<0000co`0co`001S?o
00030000oooooooo08Goool007koool00ol0VOooooooo`0>oooo00<0000co`0co`001S?o00030000
oooooooo08Goool007koool00ol0VOooooooo`0>oooo0P0000Hco`000`000?ooooooo`26oooo001n
oooo00?o09Woooooool03_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001noooo00?o
09Woooooool03_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001noooo00?o09Wooooo
ool03_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001noooo00?o09Woooooool03_oo
o`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001noooo00?o09Woooooool03_ooo`030000
<ol0<ol000Dco`000`000?ooooooo`26oooo001noooo00?o09Woooooool03_ooo`800006<ol000<0
003oooooool0Q_ooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o0005<ol000<0003oooooool0Q_oo
o`00O_ooo`03o`2Ioooooooo00koool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00O_oo
o`03o`2Ioooooooo00koool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00O_ooo`03o`2I
oooooooo00Soool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001noooo00?o
09Woooooool02Oooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0Qooo
o`00O_ooo`03o`2Ioooooooo00Koool500000oooo`<00004<ol000<0003oooooool0Qoooo`00Qooo
o`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029
oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?oo
ooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000@co`02000000<co`3oooooool00_ooo`040000oooooooo
oooo100000?oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00006<ol01?ooo`050000oooooooo
oooo000000Koool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo
00goool010000?ooooooo`0000Hco`04oooo00<0003oooooool00_ooo`030000oooooooo00Coool0
0`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`0000Hco`05
oooo00<0003oooooool00_ooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000003oooo`040000oooooooo00001S?o00;oool010000?ooooooo`0000;oool0
10000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007
<ol00_ooo`@00003oooo0P0000?oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7
<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.74) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.42237 .12361 L
.42781 .12361 L
.43298 .12361 L
.43522 .12361 L
.43646 .12361 L
.43762 .12361 L
s
.43762 .12361 m
.43788 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.74) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool01Oooo`05o`2I
oooooooooooo000000_oool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_oo
o`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000
oooooooo02Woool00ol0VOooooooo`0=oooo00<0000co`0co`00>C?o00T0000doooo00<0003ooooo
ool05Oooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000c<ol01P0005Goool007ooool0
0ol0VOooooooo`0=oooo00<0000co`0co`00<C?o0080001Koooo001ooooo00?o09Woooooool03Ooo
o`030000<ol0<ol002lco`020000GOooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000/
<ol00`0005ooool007ooool00ol0VOooooooo`0=oooo0P0002Xco`030000H_ooo`00Ooooo`03o`2I
oooooooo00goool00`0003?o03?o000W<ol00P0006Goool007ooool00ol0VOooooooo`0=oooo00<0
000co`0co`009S?o00030000oooooooo06Goool007ooool00ol0VOooooooo`0=oooo00<0000co`0c
o`009C?o00030000oooooooo06Koool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`0093?o
00030000oooooooo06Ooool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`008S?o0080001Z
oooo001ooooo00?o09Woooooool03Oooo`80000R<ol000<0003oooooool0J_ooo`00Ooooo`03o`2I
oooooooo00goool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00Ooooo`03o`2Ioooooooo
00goool00`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Ooooo`03o`2Ioooooooo00goool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o
03?o000N<ol000<0003oooooool0KOooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000M
<ol000<0003oooooool0K_ooo`00Ooooo`03o`2Ioooooooo00goool200007C?o00030000oooooooo
06ooool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`006c?o00030000oooooooo073oool0
07ooool00ol0VOooooooo`0=oooo00<0000co`0co`006c?o00030000oooooooo073oool007ooool0
0ol0VOooooooo`0=oooo00<0000co`0co`006S?o00030000oooooooo077oool007ooool00ol0VOoo
ooooo`0=oooo00<0000co`0co`006S?o00030000oooooooo077oool007ooool00ol0VOooooooo`0=
oooo00<0000co`0co`006C?o00030000oooooooo07;oool007ooool00ol0VOooooooo`0=oooo0P00
01Xco`000`000?ooooooo`1boooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol001Pco`00
0`000?ooooooo`1coooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1d
oooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo001o
oooo00?o09Woooooool01Oooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool0
07ooool00ol0VOooooooo`07oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo001ooooo00?o09Woooooool01oooo`030000oooooooo00?oool300005C?o00030000
oooooooo07Koool007ooool00ol0VOooooooo`07oooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`1foooo001ooooo00?o09Woooooool01oooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00Ooooo`03o`2Ioooooooo00Koool200001Ooo
o`030000<ol0<ol001@co`000`000?ooooooo`1goooo001ooooo00?o09Woooooool03Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol0
01<co`000`000?ooooooo`1hoooo001ooooo00?o09Woooooool03Oooo`80000D<ol000<0003ooooo
ool0N?ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000C<ol000<0003oooooool0N?oo
o`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Oooo
o`03o`2Ioooooooo00goool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Ooooo`03o`2I
oooooooo00goool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Ooooo`03o`2Ioooooooo
00goool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00Ooooo`03o`2Ioooooooo00goool2
00004S?o00030000oooooooo07[oool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`004C?o
00030000oooooooo07[oool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`004C?o00030000
oooooooo07[oool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`0043?o00030000oooooooo
07_oool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`0043?o00030000oooooooo07_oool0
07ooool00ol0VOooooooo`0=oooo00<0000co`0co`0043?o00030000oooooooo07_oool007ooool0
0ol0VOooooooo`0=oooo00<0000co`0co`0043?o00030000oooooooo07_oool007ooool00ol0VOoo
ooooo`0=oooo0P00010co`000`000?ooooooo`1loooo001ooooo00?o09Woooooool03Oooo`030000
<ol0<ol000lco`000`000?ooooooo`1loooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol000hco`000`000?ooooooo`1m
oooo001ooooo00?o09Woooooool03Oooo`80000?<ol000<0003oooooool0OOooo`00Ooooo`03o`2I
oooooooo00goool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Ooooo`03o`2Ioooooooo
00goool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Ooooo`03o`2Ioooooooo00goool0
0`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Ooooo`03o`2Ioooooooo00Goool400001?oo
o`030000<ol0<ol000dco`000`000?ooooooo`1noooo001ooooo00?o09Woooooool01Oooo`030000
oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Ooooo`03o`2Ioooooooo
00Koool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo001ooooo00?o09Wooooo
ool01oooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Oooo
o`03o`2Ioooooooo00Goool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00Ooooo`03o`2Ioooooooo00Koool200001Oooo`030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo001o
oooo00?o09Woooooool03Oooo`80000=<ol000<0003oooooool0Ooooo`00Ooooo`03o`2Ioooooooo
00goool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00Ooooo`03o`2Ioooooooo00goool0
0`0003?o03?o000;<ol000<0003oooooool0P?ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Ooooo`03o`2Ioooooooo00goool2000033?o00030000oooooooo083oool007ooool0
0ol0VOooooooo`0=oooo00<0000co`0co`002c?o00030000oooooooo083oool007ooool00ol0VOoo
ooooo`0=oooo00<0000co`0co`002S?o00030000oooooooo087oool007ooool00ol0VOooooooo`0=
oooo00<0000co`0co`002S?o00030000oooooooo087oool007ooool00ol0VOooooooo`0=oooo00<0
000co`0co`002S?o00030000oooooooo087oool007ooool00ol0VOooooooo`0=oooo00<0000co`0c
o`002S?o00030000oooooooo087oool007ooool00ol0VOooooooo`0=oooo0P0000/co`000`000?oo
ooooo`21oooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol000Xco`000`000?ooooooo`21
oooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo001o
oooo00?o09Woooooool03Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001ooooo00?o
09Woooooool03Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001ooooo00?o09Wooooo
ool03Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo001ooooo00?o09Woooooool03Ooo
o`80000:<ol000<0003oooooool0P_ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o0009
<ol000<0003oooooool0P_ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o0008<ol000<0003ooooo
ool0Poooo`00Ooooo`03o`2Ioooooooo00Koool200001Oooo`030000<ol0<ol000Pco`000`000?oo
ooooo`23oooo001ooooo00?o09Woooooool01Oooo`040000oooooooo00001?ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`23oooo001ooooo00?o09Woooooool01oooo`030000oooooooo00?oool3
000023?o00030000oooooooo08?oool007ooool00ol0VOooooooo`08oooo00<0003oooooool00_oo
o`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001ooooo00?o09Woooooool01Oooo`040000
oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo001ooooo00?o09Wooooo
ool01_ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool007ooool00ol0VOoo
ooooo`0=oooo00<0000co`0co`001c?o00030000oooooooo08Coool007ooool00ol0VOooooooo`0=
oooo00<0000co`0co`001c?o00030000oooooooo08Coool007ooool00ol0VOooooooo`0=oooo00<0
000co`0co`001c?o00030000oooooooo08Coool007ooool00ol0VOooooooo`0=oooo0P0000Pco`00
0`000?ooooooo`24oooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`24oooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo001o
oooo00?o09Woooooool03Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001ooooo00?o
09Woooooool03Oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo001ooooo00?o09Wooooo
ool03Oooo`800007<ol000<0003oooooool0QOooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o
03?o0006<ol000<0003oooooool0QOooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00Ooooo`03o`2Ioooooooo00goool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00Ooooo`03o`2Ioooooooo00goool200001S?o00030000oooooooo08Koool007ooool00ol0VOoo
ooooo`0=oooo00<0000co`0co`001C?o00030000oooooooo08Koool007ooool00ol0VOooooooo`0=
oooo00<0000co`0co`001C?o00030000oooooooo08Koool007ooool00ol0VOooooooo`0=oooo00<0
000co`0co`001C?o00030000oooooooo08Koool007ooool00ol0VOooooooo`0=oooo00<0000co`0c
o`001C?o00030000oooooooo08Koool007ooool00ol0VOooooooo`0=oooo00<0000co`0co`001C?o
00030000oooooooo08Koool007ooool00ol0VOooooooo`0=oooo0P0000Hco`000`000?ooooooo`26
oooo001ooooo00?o09Woooooool03Oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001o
oooo00?o09Woooooool03Oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo001ooooo00?o
09Woooooool03Oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001ooooo00?o09Wooooo
ool03Oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001ooooo00?o09Woooooool01ooo
o`<00003oooo00<0000co`0co`0013?o00030000oooooooo08Ooool007ooool00ol0VOooooooo`08
oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo001ooooo00?o
09Woooooool01Oooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003ooooo
ool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?oo
o`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7
<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Ooo
o`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Ooool2000013?o008000000c?o0?ooooooo`02oooo00<0003oooooool00oooo`<00002
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`040000oooooooo00001S?o00Coool00`000?ooooooo`04oooo00D0
003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0
003oooooool00006<ol01?ooo`040000oooooooooooo1@0000?oool00`000?ooooooo`1goooo001h
oooo00<0003oooooool01@0000coool010000?ooooooo`0000Hco`05oooo00@0003oooooool00002
oooo00D0003oooooooooool00000N_ooo`00N?ooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Hco`02oooo00@0003oooooool00003oooo00<0003oool000000oooo`030000oooooooo
07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`02oooo100000Coool200000_ooo`030000
oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.76) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.43755 .12361 L
.44021 .12361 L
.44151 .12361 L
.44268 .12361 L
s
.44268 .12361 m
.44316 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.76) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool01_ooo`04o`2I
oooooooo00002oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0
003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003ooooo
ool0:_ooo`03o`2Ioooooooo00coool00`0003?o03?o000i<ol02@0003Coool00`000?ooooooo`0E
oooo0020oooo00?o09Woooooool03?ooo`030000<ol0<ol003<co`060000EOooo`00P?ooo`03o`2I
oooooooo00coool00`0003?o03?o000a<ol00P0005_oool0083oool00ol0VOooooooo`0<oooo00<0
000co`0co`00;c?o0080001Moooo0020oooo00?o09Woooooool03?ooo`030000<ol0<ol002`co`03
0000Goooo`00P?ooo`03o`2Ioooooooo00coool20000:S?o00<0001Roooo0020oooo00?o09Wooooo
ool03?ooo`030000<ol0<ol002Lco`020000IOooo`00P?ooo`03o`2Ioooooooo00coool00`0003?o
03?o000V<ol000<0003oooooool0IOooo`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o000U
<ol000<0003oooooool0I_ooo`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o000T<ol000<0
003oooooool0Ioooo`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o000R<ol00P0006[oool0
083oool00ol0VOooooooo`0<oooo0P00028co`000`000?ooooooo`1Zoooo0020oooo00?o09Wooooo
ool03?ooo`030000<ol0<ol0020co`000`000?ooooooo`1[oooo0020oooo00?o09Woooooool03?oo
o`030000<ol0<ol001lco`000`000?ooooooo`1/oooo0020oooo00?o09Woooooool03?ooo`030000
<ol0<ol001lco`000`000?ooooooo`1/oooo0020oooo00?o09Woooooool03?ooo`030000<ol0<ol0
01hco`000`000?ooooooo`1]oooo0020oooo00?o09Woooooool03?ooo`030000<ol0<ol001dco`00
0`000?ooooooo`1^oooo0020oooo00?o09Woooooool03?ooo`80000M<ol000<0003oooooool0Kooo
o`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00P?oo
o`03o`2Ioooooooo00coool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00P?ooo`03o`2I
oooooooo00coool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00P?ooo`03o`2Ioooooooo
00coool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00P?ooo`03o`2Ioooooooo00coool0
0`0003?o03?o000I<ol000<0003oooooool0L_ooo`00P?ooo`03o`2Ioooooooo00coool200006S?o
00030000oooooooo07;oool0083oool00ol0VOooooooo`0<oooo00<0000co`0co`0063?o00030000
oooooooo07?oool0083oool00ol0VOooooooo`0<oooo00<0000co`0co`0063?o00030000oooooooo
07?oool0083oool00ol0VOooooooo`0<oooo00<0000co`0co`005c?o00030000oooooooo07Coool0
083oool00ol0VOooooooo`0<oooo00<0000co`0co`005c?o00030000oooooooo07Coool0083oool0
0ol0VOooooooo`04oooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00P?oo
o`03o`2Ioooooooo00Koool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo
07Goool0083oool00ol0VOooooooo`06oooo00<0003oooooool00oooo`<0000E<ol000<0003ooooo
ool0M_ooo`00P?ooo`03o`2Ioooooooo00Koool00`000?ooooooo`03oooo00<0000co`0co`005C?o
00030000oooooooo07Koool0083oool00ol0VOooooooo`06oooo00<0003oooooool00oooo`030000
<ol0<ol001Dco`000`000?ooooooo`1foooo0020oooo00?o09Woooooool01Oooo`800005oooo00<0
000co`0co`0053?o00030000oooooooo07Ooool0083oool00ol0VOooooooo`0<oooo00<0000co`0c
o`0053?o00030000oooooooo07Ooool0083oool00ol0VOooooooo`0<oooo00<0000co`0co`004c?o
00030000oooooooo07Soool0083oool00ol0VOooooooo`0<oooo0P0001@co`000`000?ooooooo`1h
oooo0020oooo00?o09Woooooool03?ooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo0020
oooo00?o09Woooooool03?ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo0020oooo00?o
09Woooooool03?ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo0020oooo00?o09Wooooo
ool03?ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo0020oooo00?o09Woooooool03?oo
o`030000<ol0<ol0014co`000`000?ooooooo`1joooo0020oooo00?o09Woooooool03?ooo`80000B
<ol000<0003oooooool0N_ooo`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o000A<ol000<0
003oooooool0N_ooo`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o000A<ol000<0003ooooo
ool0N_ooo`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o000@<ol000<0003oooooool0Nooo
o`00P?ooo`03o`2Ioooooooo00coool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00P?oo
o`03o`2Ioooooooo00coool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00P?ooo`03o`2I
oooooooo00coool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00P?ooo`03o`2Ioooooooo
00coool2000043?o00030000oooooooo07coool0083oool00ol0VOooooooo`0<oooo00<0000co`0c
o`003c?o00030000oooooooo07coool0083oool00ol0VOooooooo`0<oooo00<0000co`0co`003c?o
00030000oooooooo07coool0083oool00ol0VOooooooo`0<oooo00<0000co`0co`003c?o00030000
oooooooo07coool0083oool00ol0VOooooooo`0<oooo00<0000co`0co`003c?o00030000oooooooo
07coool0083oool00ol0VOooooooo`0<oooo00<0000co`0co`003S?o00030000oooooooo07goool0
083oool00ol0VOooooooo`0<oooo0P0000lco`000`000?ooooooo`1moooo0020oooo00?o09Wooooo
ool03?ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo0020oooo00?o09Woooooool03?oo
o`030000<ol0<ol000hco`000`000?ooooooo`1moooo0020oooo00?o09Woooooool03?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo0020oooo00?o09Woooooool01?ooo`@00004oooo00<0
000co`0co`003C?o00030000oooooooo07koool0083oool00ol0VOooooooo`04oooo00<0003ooooo
ool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo0020oooo00?o09Woooooool01Ooo
o`030000oooooooo00Coool300003C?o00030000oooooooo07koool0087oool00ol0VOooooooo`05
oooo00<0003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo0021oooo00?o
09Woooooool00oooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo0021oooo00?o09Woooooool01?ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo
07ooool0087oool00ol0VOooooooo`0;oooo00<0000co`0co`0033?o00030000oooooooo07ooool0
087oool00ol0VOooooooo`0;oooo00<0000co`0co`0033?o00030000oooooooo07ooool0087oool0
0ol0VOooooooo`0;oooo0P0000dco`000`000?ooooooo`1ooooo0021oooo00?o09Woooooool02ooo
o`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0021oooo00?o09Woooooool02oooo`030000
<ol0<ol000/co`000`000?ooooooo`20oooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol0
00/co`000`000?ooooooo`20oooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol000/co`00
0`000?ooooooo`20oooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol000/co`000`000?oo
ooooo`20oooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol000/co`000`000?ooooooo`20
oooo0021oooo00?o09Woooooool02oooo`80000<<ol000<0003oooooool0P?ooo`00POooo`03o`2I
oooooooo00_oool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00POooo`03o`2Ioooooooo
00_oool00`0003?o03?o000:<ol000<0003oooooool0POooo`00POooo`03o`2Ioooooooo00_oool0
0`0003?o03?o000:<ol000<0003oooooool0POooo`00POooo`03o`2Ioooooooo00_oool00`0003?o
03?o000:<ol000<0003oooooool0POooo`00POooo`03o`2Ioooooooo00_oool00`0003?o03?o000:
<ol000<0003oooooool0POooo`00POooo`03o`2Ioooooooo00_oool200002c?o00030000oooooooo
087oool0087oool00ol0VOooooooo`0;oooo00<0000co`0co`002S?o00030000oooooooo087oool0
087oool00ol0VOooooooo`0;oooo00<0000co`0co`002S?o00030000oooooooo087oool0087oool0
0ol0VOooooooo`0;oooo00<0000co`0co`002C?o00030000oooooooo08;oool0087oool00ol0VOoo
ooooo`0;oooo00<0000co`0co`002C?o00030000oooooooo08;oool0087oool00ol0VOooooooo`0;
oooo00<0000co`0co`002C?o00030000oooooooo08;oool0087oool00ol0VOooooooo`0;oooo0P00
00Xco`000`000?ooooooo`22oooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol000Tco`00
0`000?ooooooo`22oooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol000Tco`000`000?oo
ooooo`22oooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo0021oooo00?o09Woooooool01?ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo
08?oool0087oool00ol0VOooooooo`03oooo00@0003oooooool00004oooo00<0000co`0co`0023?o
00030000oooooooo08?oool0087oool00ol0VOooooooo`05oooo00<0003oooooool00oooo`<00008
<ol000<0003oooooool0Poooo`00POooo`03o`2Ioooooooo00Koool00`000?ooooooo`02oooo00<0
000co`0co`0023?o00030000oooooooo08?oool0087oool00ol0VOooooooo`03oooo00@0003ooooo
ool00004oooo00<0000co`0co`0023?o00030000oooooooo08?oool0087oool00ol0VOooooooo`04
oooo0P0000Goool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00POooo`03o`2Ioooooooo
00_oool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00POooo`03o`2Ioooooooo00_oool0
0`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00POooo`03o`2Ioooooooo00_oool00`0003?o
03?o0007<ol000<0003oooooool0Q?ooo`00POooo`03o`2Ioooooooo00_oool2000023?o00030000
oooooooo08Coool0087oool00ol0VOooooooo`0;oooo00<0000co`0co`001c?o00030000oooooooo
08Coool0087oool00ol0VOooooooo`0;oooo00<0000co`0co`001c?o00030000oooooooo08Coool0
087oool00ol0VOooooooo`0;oooo00<0000co`0co`001c?o00030000oooooooo08Coool0087oool0
0ol0VOooooooo`0;oooo00<0000co`0co`001S?o00030000oooooooo08Goool0087oool00ol0VOoo
ooooo`0;oooo00<0000co`0co`001S?o00030000oooooooo08Goool0087oool00ol0VOooooooo`0;
oooo0P0000Lco`000`000?ooooooo`25oooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol0
00Hco`000`000?ooooooo`25oooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol000Hco`00
0`000?ooooooo`25oooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol000Hco`000`000?oo
ooooo`25oooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol000Hco`000`000?ooooooo`25
oooo0021oooo00?o09Woooooool02oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo0021
oooo00?o09Woooooool02oooo`800006<ol000<0003oooooool0Q_ooo`00POooo`03o`2Ioooooooo
00_oool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00POooo`03o`2Ioooooooo00_oool0
0`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00POooo`03o`2Ioooooooo00_oool00`0003?o
03?o0005<ol000<0003oooooool0Q_ooo`00POooo`03o`2Ioooooooo00_oool00`0003?o03?o0005
<ol000<0003oooooool0Q_ooo`00POooo`03o`2Ioooooooo00_oool00`0003?o03?o0005<ol000<0
003oooooool0Q_ooo`00POooo`03o`2Ioooooooo00_oool200001S?o00030000oooooooo08Koool0
087oool00ol0VOooooooo`0;oooo00<0000co`0co`001C?o00030000oooooooo08Koool0087oool0
0ol0VOooooooo`0;oooo00<0000co`0co`001C?o00030000oooooooo08Koool0087oool00ol0VOoo
ooooo`0;oooo00<0000co`0co`0013?o00030000oooooooo08Ooool0087oool00ol0VOooooooo`0;
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool0087oool00ol0VOooooooo`05oooo0`00
00?oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00POooo`03o`2Ioooooooo00Koool0
0`000?ooooooo`02oooo00<0000co`0co`0013?o00030000oooooooo08Ooool0087oool00ol0VOoo
ooooo`03oooo1@0000?oool3000013?o00030000oooooooo08Ooool008Ooool010000?ooooooo`00
00Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o
08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o
00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01oooo`800004<ol00P000003<ol0oooooooo00;oool010000?ooooooooooo`<00004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`040000oooooooo00001S?o00Coool01@000?ooooooooooo`000002oooo00D0
003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0
003oooooool00006<ol01?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00006<ol01Ooo
o`030000oooooooo00<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00ooool010000?ooooooo`0000Hco`02oooo00@0003oooooool00003oooo00<0003oooooool00ooo
o`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`02oooo100000?oool3
00000_ooo`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.78) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.43755 .12361 L
.44268 .12361 L
.44498 .12361 L
.44625 .12361 L
.44744 .12361 L
s
.44744 .12361 m
.44771 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.78) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02?ooo`03o`2I
0000oooo00[oool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
02coool00ol0VOooooooo`0:oooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000c<ol01P0005Goool008;oool00ol0VOoo
ooooo`0:oooo00<0000co`0co`00<C?o0080001Koooo0022oooo00?o09Woooooool02_ooo`030000
<ol0<ol002lco`020000GOooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000/<ol00`00
05ooool008;oool00ol0VOooooooo`0:oooo0P0002Xco`030000H_ooo`00P_ooo`03o`2Ioooooooo
00[oool00`0003?o03?o000W<ol00P0006Goool008;oool00ol0VOooooooo`0:oooo00<0000co`0c
o`009S?o00030000oooooooo06Goool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`009C?o
00030000oooooooo06Koool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`0093?o00030000
oooooooo06Ooool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`008S?o0080001Zoooo0022
oooo00?o09Woooooool02_ooo`80000R<ol000<0003oooooool0J_ooo`00P_ooo`03o`2Ioooooooo
00[oool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00P_ooo`03o`2Ioooooooo00[oool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00P_ooo`03o`2Ioooooooo00[oool200007C?o00030000oooooooo06ooool0
08;oool00ol0VOooooooo`0:oooo00<0000co`0co`006c?o00030000oooooooo073oool008;oool0
0ol0VOooooooo`0:oooo00<0000co`0co`006c?o00030000oooooooo073oool008;oool00ol0VOoo
ooooo`0:oooo00<0000co`0co`006S?o00030000oooooooo077oool008;oool00ol0VOooooooo`0:
oooo00<0000co`0co`006S?o00030000oooooooo077oool008;oool00ol0VOooooooo`0:oooo00<0
000co`0co`006C?o00030000oooooooo07;oool008;oool00ol0VOooooooo`0:oooo0P0001Xco`00
0`000?ooooooo`1boooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo0022
oooo00?o09Woooooool02_ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo0022oooo00?o
09Woooooool00_ooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool008;oool0
0ol0VOooooooo`04oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo0022oooo00?o09Woooooool01?ooo`030000oooooooo00?oool300005C?o00030000oooooooo
07Koool008;oool00ol0VOooooooo`04oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1foooo0022oooo00?o09Woooooool01?ooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00P_ooo`03o`2Ioooooooo00?oool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`1goooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol001<co`00
0`000?ooooooo`1hoooo0022oooo00?o09Woooooool02_ooo`80000D<ol000<0003oooooool0N?oo
o`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00P_oo
o`03o`2Ioooooooo00[oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00P_ooo`03o`2I
oooooooo00[oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00P_ooo`03o`2Ioooooooo
00[oool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00P_ooo`03o`2Ioooooooo00[oool0
0`0003?o03?o000A<ol000<0003oooooool0N_ooo`00P_ooo`03o`2Ioooooooo00[oool200004S?o
00030000oooooooo07[oool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`004C?o00030000
oooooooo07[oool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`004C?o00030000oooooooo
07[oool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`0043?o00030000oooooooo07_oool0
08;oool00ol0VOooooooo`0:oooo00<0000co`0co`0043?o00030000oooooooo07_oool008;oool0
0ol0VOooooooo`0:oooo00<0000co`0co`0043?o00030000oooooooo07_oool008;oool00ol0VOoo
ooooo`0:oooo00<0000co`0co`0043?o00030000oooooooo07_oool008;oool00ol0VOooooooo`0:
oooo0P00010co`000`000?ooooooo`1loooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo0022
oooo00?o09Woooooool02_ooo`80000?<ol000<0003oooooool0OOooo`00P_ooo`03o`2Ioooooooo
00[oool00`0003?o03?o000><ol000<0003oooooool0OOooo`00P_ooo`03o`2Ioooooooo00[oool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00P_ooo`03o`2Ioooooooo00;oool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo0022oooo00?o09Woooooool00_ooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00P_ooo`03o`2Ioooooooo00?oool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1noooo0022oooo00?o09Woooooool01?oo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00P_ooo`03o`2I
oooooooo00;oool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00P_ooo`03o`2Ioooooooo00?oool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1o
oooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0022
oooo00?o09Woooooool02_ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0022oooo00?o
09Woooooool02_ooo`80000=<ol000<0003oooooool0Ooooo`00P_ooo`03o`2Ioooooooo00[oool0
0`0003?o03?o000<<ol000<0003oooooool0Ooooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000;
<ol000<0003oooooool0P?ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00P_ooo`03o`2Ioooooooo00[oool2000033?o00030000oooooooo083oool008;oool00ol0VOoo
ooooo`0:oooo00<0000co`0co`002c?o00030000oooooooo083oool008;oool00ol0VOooooooo`0:
oooo00<0000co`0co`002S?o00030000oooooooo087oool008;oool00ol0VOooooooo`0:oooo00<0
000co`0co`002S?o00030000oooooooo087oool008;oool00ol0VOooooooo`0:oooo00<0000co`0c
o`002S?o00030000oooooooo087oool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`002S?o
00030000oooooooo087oool008;oool00ol0VOooooooo`0:oooo0P0000/co`000`000?ooooooo`21
oooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0022
oooo00?o09Woooooool02_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0022oooo00?o
09Woooooool02_ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo0022oooo00?o09Wooooo
ool02_ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo0022oooo00?o09Woooooool02_oo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo0022oooo00?o09Woooooool02_ooo`80000:
<ol000<0003oooooool0P_ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o0009<ol000<0
003oooooool0P_ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o0009<ol000<0003ooooo
ool0P_ooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00P_ooo`03o`2Ioooooooo00?oool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23
oooo0022oooo00?o09Woooooool00_ooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`23oooo0022oooo00?o09Woooooool01?ooo`030000oooooooo00?oool3000023?o
00030000oooooooo08?oool008;oool00ol0VOooooooo`05oooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo0022oooo00?o09Woooooool00_ooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo0022oooo00?o09Woooooool00ooo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool008;oool00ol0VOooooooo`0:
oooo00<0000co`0co`001c?o00030000oooooooo08Coool008;oool00ol0VOooooooo`0:oooo00<0
000co`0co`001c?o00030000oooooooo08Coool008;oool00ol0VOooooooo`0:oooo00<0000co`0c
o`001c?o00030000oooooooo08Coool008;oool00ol0VOooooooo`0:oooo0P0000Pco`000`000?oo
ooooo`24oooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo0022oooo00?o09Woooooool02_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0022
oooo00?o09Woooooool02_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0022oooo00?o
09Woooooool02_ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo0022oooo00?o09Wooooo
ool02_ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo0022oooo00?o09Woooooool02_oo
o`800007<ol000<0003oooooool0QOooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00P_ooo`03o`2Ioooooooo00[oool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00P_oo
o`03o`2Ioooooooo00[oool200001S?o00030000oooooooo08Koool008;oool00ol0VOooooooo`0:
oooo00<0000co`0co`001C?o00030000oooooooo08Koool008;oool00ol0VOooooooo`0:oooo00<0
000co`0co`001C?o00030000oooooooo08Koool008;oool00ol0VOooooooo`0:oooo00<0000co`0c
o`001C?o00030000oooooooo08Koool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`001C?o
00030000oooooooo08Koool008;oool00ol0VOooooooo`0:oooo00<0000co`0co`001C?o00030000
oooooooo08Koool008;oool00ol0VOooooooo`0:oooo0P0000Hco`000`000?ooooooo`26oooo0022
oooo00?o09Woooooool02_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0022oooo00?o
09Woooooool02_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0022oooo00?o09Wooooo
ool02_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo0022oooo00?o09Woooooool02_oo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo0022oooo00?o09Woooooool01?ooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool008;oool00ol0VOooooooo`05oooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo0022oooo00?o09Wooooo
ool00_ooo`D00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool2000013?o008000000c?o0?ooooooo`02oooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`040000oooooooo00001S?o00Coool01@000?ooooooooooo`000002oooo00D0
003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0
003oooooool00006<ol01?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00006<ol01Ooo
o`040000oooooooooooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00003oooo`040000oooooooo00001S?o00;oool010000?ooooooo`0000;oool010000?ooooooo`00
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007<ol00_ooo`@00003
oooo0P0000?oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.43755 .12361 L
.44268 .12361 L
.44744 .12361 L
.44874 .12361 L
.45013 .12361 L
.45143 .12361 L
s
.45143 .12361 m
.45191 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
02goool00ol0VOooooooo`09oooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000c<ol01P0005Goool008?oool00ol0VOoo
ooooo`09oooo00<0000co`0co`00<C?o0080001Koooo0023oooo00?o09Woooooool02Oooo`030000
<ol0<ol002lco`020000GOooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000/<ol00`00
05ooool008?oool00ol0VOooooooo`09oooo0P0002Xco`030000H_ooo`00Poooo`03o`2Ioooooooo
00Woool00`0003?o03?o000W<ol00P0006Goool008?oool00ol0VOooooooo`09oooo00<0000co`0c
o`009S?o00030000oooooooo06Goool008?oool00ol0VOooooooo`09oooo00<0000co`0co`009C?o
00030000oooooooo06Koool008?oool00ol0VOooooooo`09oooo00<0000co`0co`0093?o00030000
oooooooo06Ooool008?oool00ol0VOooooooo`09oooo00<0000co`0co`008S?o0080001Zoooo0023
oooo00?o09Woooooool02Oooo`80000R<ol000<0003oooooool0J_ooo`00Poooo`03o`2Ioooooooo
00Woool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00Poooo`03o`2Ioooooooo00Woool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00Poooo`03o`2Ioooooooo00Woool200007C?o00030000oooooooo06ooool0
08?oool00ol0VOooooooo`09oooo00<0000co`0co`006c?o00030000oooooooo073oool008?oool0
0ol0VOooooooo`09oooo00<0000co`0co`006c?o00030000oooooooo073oool008?oool00ol0VOoo
ooooo`09oooo00<0000co`0co`006S?o00030000oooooooo077oool008?oool00ol0VOooooooo`09
oooo00<0000co`0co`006S?o00030000oooooooo077oool008?oool00ol0VOooooooo`09oooo00<0
000co`0co`006C?o00030000oooooooo07;oool008?oool00ol0VOooooooo`09oooo0P0001Xco`00
0`000?ooooooo`1boooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo0023
oooo00?o09Woooooool02Oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo0023oooo00Co
09Woooooooooool500000oooo`030000<ol0<ol001Hco`000`000?ooooooo`1eoooo0023oooo00?o
09Woooooool00oooo`030000oooooooo00?oool00`0003?o03?o000F<ol000<0003oooooool0MOoo
o`00Poooo`03o`2Ioooooooo00?oool00`000?ooooooo`03oooo0`0001Dco`000`000?ooooooo`1f
oooo0023oooo00?o09Woooooool00oooo`030000oooooooo00?oool00`0003?o03?o000E<ol000<0
003oooooool0M_ooo`00Poooo`03o`2Ioooooooo00?oool00`000?ooooooo`03oooo00<0000co`0c
o`005C?o00030000oooooooo07Koool008?oool00ol0VOooooooo`02oooo0P0000Goool00`0003?o
03?o000D<ol000<0003oooooool0Moooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000D
<ol000<0003oooooool0Moooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000C<ol000<0
003oooooool0N?ooo`00Poooo`03o`2Ioooooooo00Woool2000053?o00030000oooooooo07Soool0
08?oool00ol0VOooooooo`09oooo00<0000co`0co`004c?o00030000oooooooo07Soool008?oool0
0ol0VOooooooo`09oooo00<0000co`0co`004S?o00030000oooooooo07Woool008?oool00ol0VOoo
ooooo`09oooo00<0000co`0co`004S?o00030000oooooooo07Woool008?oool00ol0VOooooooo`09
oooo00<0000co`0co`004S?o00030000oooooooo07Woool008?oool00ol0VOooooooo`09oooo00<0
000co`0co`004C?o00030000oooooooo07[oool008?oool00ol0VOooooooo`09oooo0P00018co`00
0`000?ooooooo`1joooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol0014co`000`000?oo
ooooo`1joooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol0014co`000`000?ooooooo`1j
oooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo0023
oooo00?o09Woooooool02Oooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo0023oooo00?o
09Woooooool02Oooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo0023oooo00?o09Wooooo
ool02Oooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo0023oooo00?o09Woooooool02Ooo
o`80000@<ol000<0003oooooool0O?ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000?
<ol000<0003oooooool0O?ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000?<ol000<0
003oooooool0O?ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000?<ol000<0003ooooo
ool0O?ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000?<ol000<0003oooooool0O?oo
o`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000><ol000<0003oooooool0OOooo`00Pooo
o`03o`2Ioooooooo00Woool200003c?o00030000oooooooo07goool008?oool00ol0VOooooooo`09
oooo00<0000co`0co`003S?o00030000oooooooo07goool008?oool00ol0VOooooooo`09oooo00<0
000co`0co`003S?o00030000oooooooo07goool008?oool00ol0VOooooooo`09oooo00<0000co`0c
o`003C?o00030000oooooooo07koool008?oool01?l0VOooooooooooo`@00004oooo00<0000co`0c
o`003C?o00030000oooooooo07koool008?oool01Ol0VOooooooooooo`000007oooo00<0000co`0c
o`003C?o00030000oooooooo07koool008?oool00ol0VOooooooo`02oooo00<0003oooooool01?oo
o`<0000=<ol000<0003oooooool0O_ooo`00Poooo`03o`2Ioooooooo00?oool00`000?ooooooo`03
oooo00<0000co`0co`003C?o00030000oooooooo07koool008?oool01Ol0VOooooooooooo`000002
oooo00<0003oooooool00_ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0023oooo00?o
09Woooooool00_ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo07ooool008?oool0
0ol0VOooooooo`09oooo00<0000co`0co`0033?o00030000oooooooo07ooool008?oool00ol0VOoo
ooooo`09oooo00<0000co`0co`0033?o00030000oooooooo07ooool008?oool00ol0VOooooooo`09
oooo0P0000dco`000`000?ooooooo`1ooooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol0
00`co`000`000?ooooooo`1ooooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol000/co`00
0`000?ooooooo`20oooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol000/co`000`000?oo
ooooo`20oooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol000/co`000`000?ooooooo`20
oooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo0023
oooo00?o09Woooooool02Oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo0023oooo00?o
09Woooooool02Oooo`80000<<ol000<0003oooooool0P?ooo`00Poooo`03o`2Ioooooooo00Woool0
0`0003?o03?o000;<ol000<0003oooooool0P?ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o
03?o000:<ol000<0003oooooool0POooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000:
<ol000<0003oooooool0POooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o000:<ol000<0003ooooo
ool0POooo`00Poooo`03o`2Ioooooooo00Woool200002c?o00030000oooooooo087oool008?oool0
0ol0VOooooooo`09oooo00<0000co`0co`002S?o00030000oooooooo087oool008?oool00ol0VOoo
ooooo`09oooo00<0000co`0co`002S?o00030000oooooooo087oool008?oool00ol0VOooooooo`09
oooo00<0000co`0co`002C?o00030000oooooooo08;oool008?oool00ol0VOooooooo`09oooo00<0
000co`0co`002C?o00030000oooooooo08;oool008?oool00ol0VOooooooo`09oooo00<0000co`0c
o`002C?o00030000oooooooo08;oool008?oool00ol0VOooooooo`09oooo0P0000Xco`000`000?oo
ooooo`22oooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22
oooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo0023
oooo00?o09Woooooool02Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo0023oooo00?o
09Woooooool00_ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo08?oool008?oool0
1Ol0VOooooooooooo`000002oooo00<0003oooooool00_ooo`030000<ol0<ol000Pco`000`000?oo
ooooo`23oooo0023oooo00?o09Woooooool00oooo`030000oooooooo00?oool3000023?o00030000
oooooooo08?oool008?oool00ol0VOooooooo`04oooo00<0003oooooool00_ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`23oooo0023oooo00Go09Woooooooooool000000_ooo`030000oooooooo
00;oool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00Poooo`03o`2Ioooooooo00;oool2
00001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0023oooo00?o09Woooooool02Ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0023oooo00?o09Woooooool02Oooo`030000
<ol0<ol000Lco`000`000?ooooooo`24oooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol0
00Lco`000`000?ooooooo`24oooo0023oooo00?o09Woooooool02Oooo`800008<ol000<0003ooooo
ool0Q?ooo`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o0007<ol000<0003oooooool0Q?oo
o`00Poooo`03o`2Ioooooooo00Woool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00Pooo
o`03o`2Ioooooooo00Woool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00Poooo`03o`2I
oooooooo00Woool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00Poooo`03o`2Ioooooooo
00Woool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00Poooo`03o`2Ioooooooo00Woool2
00001c?o00030000oooooooo08Goool008?oool00ol0VOooooooo`09oooo00<0000co`0co`001S?o
00030000oooooooo08Goool008?oool00ol0VOooooooo`09oooo00<0000co`0co`001S?o00030000
oooooooo08Goool008?oool00ol0VOooooooo`09oooo00<0000co`0co`001S?o00030000oooooooo
08Goool008?oool00ol0VOooooooo`09oooo00<0000co`0co`001S?o00030000oooooooo08Goool0
08?oool00ol0VOooooooo`09oooo00<0000co`0co`001S?o00030000oooooooo08Goool008?oool0
0ol0VOooooooo`09oooo0P0000Hco`000`000?ooooooo`26oooo0023oooo00?o09Woooooool02Ooo
o`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0023oooo00?o09Woooooool02Oooo`030000
<ol0<ol000Dco`000`000?ooooooo`26oooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol0
00Dco`000`000?ooooooo`26oooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol000Dco`00
0`000?ooooooo`26oooo0023oooo00?o09Woooooool02Oooo`030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo0023oooo00?o09Woooooool02Oooo`800006<ol000<0003oooooool0Q_ooo`00Pooo
o`03o`2Ioooooooo00Woool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00Poooo`03o`2I
oooooooo00Woool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00Poooo`03o`2Ioooooooo
00Woool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00Poooo`03o`2Ioooooooo00Woool0
0`0003?o03?o0004<ol000<0003oooooool0Qoooo`00Poooo`03o`2Ioooooooo00?oool300000ooo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo0023oooo00?o09Woooooool01?ooo`030000
oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00Poooo`04o`2Ioooooooo
oooo1@0000?oool3000013?o00030000oooooooo08Ooool008Ooool010000?ooooooo`0000Coool7
<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool0
08ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001loooo00<0003oooooool04?ooo`Lco`0;oooo00<0
003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`06oooo1c?o00coool0
0`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_oo
o`03<ol00000000000@co`0200001?ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000<ol0<ol0
00000c?o00Goool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0003ooooo
ool00_ooo`030000oooooooo00goool0100003?o03?o000000<co`05oooo00@0003oooooool00004
oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<oooo00@0000co`0co`000003
<ol01_ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool0
100003?o03?o000000<co`05oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?oo
o`030000oooooooo013oool00c?o000000000004<ol01_ooo`800003oooo00<0003oooooool0O?oo
o`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.82) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.44268 .12361 L
.44778 .12361 L
.45262 .12361 L
.45473 .12361 L
.45588 .12361 L
.45697 .12361 L
s
.45697 .12361 m
.45749 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.82) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
o`2Ioooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
02koool00ol0VOooooooo`08oooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o000c<ol01P0005Goool008Coool00ol0VOoo
ooooo`08oooo00<0000co`0co`00<C?o0080001Koooo0024oooo00?o09Woooooool02?ooo`030000
<ol0<ol002lco`020000GOooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o000/<ol00`00
05ooool008Coool00ol0VOooooooo`08oooo0P0002Xco`030000H_ooo`00Q?ooo`03o`2Ioooooooo
00Soool00`0003?o03?o000W<ol00P0006Goool008Coool00ol0VOooooooo`08oooo00<0000co`0c
o`009S?o00030000oooooooo06Goool008Coool00ol0VOooooooo`08oooo00<0000co`0co`009C?o
00030000oooooooo06Koool008Coool00ol0VOooooooo`08oooo00<0000co`0co`0093?o00030000
oooooooo06Ooool008Coool00ol0VOooooooo`08oooo00<0000co`0co`008S?o0080001Zoooo0024
oooo00?o09Woooooool02?ooo`80000R<ol000<0003oooooool0J_ooo`00Q?ooo`03o`2Ioooooooo
00Soool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00Q?ooo`03o`2Ioooooooo00Soool200007C?o00030000oooooooo06ooool0
08Coool00ol0VOooooooo`08oooo00<0000co`0co`006c?o00030000oooooooo073oool008Coool0
0ol0VOooooooo`08oooo00<0000co`0co`006c?o00030000oooooooo073oool008Coool00ol0VOoo
ooooo`08oooo00<0000co`0co`006S?o00030000oooooooo077oool008Coool00ol0VOooooooo`08
oooo00<0000co`0co`006S?o00030000oooooooo077oool008Coool00ol0VOooooooo`08oooo00<0
000co`0co`006C?o00030000oooooooo07;oool008Coool00ol0VOooooooo`08oooo0P0001Xco`00
0`000?ooooooo`1boooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo0024
oooo00?o09Woooooool02?ooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo0024oooo00?o
09Woooooool01@0000?oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00Q?ooo`03o`2I
oooooooo00;oool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo07Goool0
08Coool00ol0VOooooooo`02oooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0M_oo
o`00Q?ooo`03o`2Ioooooooo00;oool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000
oooooooo07Koool008Coool00ol0VOooooooo`02oooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`1foooo0024oooo00Co09Woooooooooool200001Oooo`030000<ol0<ol0
01@co`000`000?ooooooo`1goooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol001@co`00
0`000?ooooooo`1goooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol001<co`000`000?oo
ooooo`1hoooo0024oooo00?o09Woooooool02?ooo`80000D<ol000<0003oooooool0N?ooo`00Q?oo
o`03o`2Ioooooooo00Soool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00Q?ooo`03o`2I
oooooooo00Soool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Q?ooo`03o`2Ioooooooo
00Soool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`0003?o03?o000B<ol000<0003oooooool0NOooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o
03?o000A<ol000<0003oooooool0N_ooo`00Q?ooo`03o`2Ioooooooo00Soool200004S?o00030000
oooooooo07[oool008Coool00ol0VOooooooo`08oooo00<0000co`0co`004C?o00030000oooooooo
07[oool008Coool00ol0VOooooooo`08oooo00<0000co`0co`004C?o00030000oooooooo07[oool0
08Coool00ol0VOooooooo`08oooo00<0000co`0co`0043?o00030000oooooooo07_oool008Coool0
0ol0VOooooooo`08oooo00<0000co`0co`0043?o00030000oooooooo07_oool008Coool00ol0VOoo
ooooo`08oooo00<0000co`0co`0043?o00030000oooooooo07_oool008Coool00ol0VOooooooo`08
oooo00<0000co`0co`0043?o00030000oooooooo07_oool008Coool00ol0VOooooooo`08oooo0P00
010co`000`000?ooooooo`1loooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol000lco`000`000?oo
ooooo`1loooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol000lco`000`000?ooooooo`1l
oooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo0024
oooo00?o09Woooooool02?ooo`030000<ol0<ol000hco`000`000?ooooooo`1moooo0024oooo00?o
09Woooooool02?ooo`80000?<ol000<0003oooooool0OOooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`0003?o03?o000><ol000<0003oooooool0OOooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o
03?o000><ol000<0003oooooool0OOooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o000=
<ol000<0003oooooool0O_ooo`00Q?ooo`03o`2Ioooooooo00@00004oooo00<0000co`0co`003C?o
00030000oooooooo07koool008Coool01?l0VOooooooo`0000Ooool00`0003?o03?o000=<ol000<0
003oooooool0O_ooo`00Q?ooo`05o`2Ioooooooooooo000000Koool300003C?o00030000oooooooo
07koool008Coool00ol0VOooooooo`02oooo00<0003oooooool00oooo`030000<ol0<ol000dco`00
0`000?ooooooo`1noooo0024oooo00Co09Woooooool00002oooo00<0003oooooool00_ooo`030000
<ol0<ol000`co`000`000?ooooooo`1ooooo0024oooo00Co09Woooooooooool200001Oooo`030000
<ol0<ol000`co`000`000?ooooooo`1ooooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol0
00`co`000`000?ooooooo`1ooooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol000`co`00
0`000?ooooooo`1ooooo0024oooo00?o09Woooooool02?ooo`80000=<ol000<0003oooooool0Oooo
o`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00Q?oo
o`03o`2Ioooooooo00Soool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00Q?ooo`03o`2I
oooooooo00Soool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00Q?ooo`03o`2Ioooooooo
00Soool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`0003?o03?o000;<ol000<0003oooooool0P?ooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00Q?ooo`03o`2Ioooooooo00Soool2000033?o00030000
oooooooo083oool008Coool00ol0VOooooooo`08oooo00<0000co`0co`002c?o00030000oooooooo
083oool008Coool00ol0VOooooooo`08oooo00<0000co`0co`002S?o00030000oooooooo087oool0
08Coool00ol0VOooooooo`08oooo00<0000co`0co`002S?o00030000oooooooo087oool008Coool0
0ol0VOooooooo`08oooo00<0000co`0co`002S?o00030000oooooooo087oool008Coool00ol0VOoo
ooooo`08oooo00<0000co`0co`002S?o00030000oooooooo087oool008Coool00ol0VOooooooo`08
oooo0P0000/co`000`000?ooooooo`21oooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol0
00Xco`000`000?ooooooo`21oooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol000Xco`00
0`000?ooooooo`21oooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`22oooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22
oooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo0024
oooo00?o09Woooooool02?ooo`80000:<ol000<0003oooooool0P_ooo`00Q?ooo`03o`2Ioooooooo
00Soool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`0003?o03?o0009<ol000<0003oooooool0P_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Q?ooo`04o`2Ioooooooooooo0P0000Goool00`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Q?ooo`04o`2Ioooooooo00000_ooo`030000oooooooo
00;oool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00Q?ooo`03o`2Ioooooooo00;oool0
0`000?ooooooo`03oooo0`0000Pco`000`000?ooooooo`23oooo0024oooo00?o09Woooooool00ooo
o`030000oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00Q?ooo`04o`2I
oooooooo00000_ooo`030000oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00Q?ooo`04o`2Ioooooooooooo0P0000Goool00`0003?o03?o0007<ol000<0003oooooool0Q?oo
o`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00Q?oo
o`03o`2Ioooooooo00Soool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00Q?ooo`03o`2I
oooooooo00Soool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00Q?ooo`03o`2Ioooooooo
00Soool2000023?o00030000oooooooo08Coool008Coool00ol0VOooooooo`08oooo00<0000co`0c
o`001c?o00030000oooooooo08Coool008Coool00ol0VOooooooo`08oooo00<0000co`0co`001c?o
00030000oooooooo08Coool008Coool00ol0VOooooooo`08oooo00<0000co`0co`001c?o00030000
oooooooo08Coool008Coool00ol0VOooooooo`08oooo00<0000co`0co`001S?o00030000oooooooo
08Goool008Coool00ol0VOooooooo`08oooo00<0000co`0co`001S?o00030000oooooooo08Goool0
08Coool00ol0VOooooooo`08oooo0P0000Lco`000`000?ooooooo`25oooo0024oooo00?o09Wooooo
ool02?ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo0024oooo00?o09Woooooool02?oo
o`030000<ol0<ol000Hco`000`000?ooooooo`25oooo0024oooo00?o09Woooooool02?ooo`030000
<ol0<ol000Hco`000`000?ooooooo`25oooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol0
00Hco`000`000?ooooooo`25oooo0024oooo00?o09Woooooool02?ooo`030000<ol0<ol000Hco`00
0`000?ooooooo`25oooo0024oooo00?o09Woooooool02?ooo`800006<ol000<0003oooooool0Q_oo
o`00Q?ooo`03o`2Ioooooooo00Soool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00Q?oo
o`03o`2Ioooooooo00Soool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00Q?ooo`03o`2I
oooooooo00Soool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00Q?ooo`03o`2Ioooooooo
00Soool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00Q?ooo`03o`2Ioooooooo00Soool200001S?o
00030000oooooooo08Koool008Coool00ol0VOooooooo`08oooo00<0000co`0co`001C?o00030000
oooooooo08Koool008Coool00ol0VOooooooo`08oooo00<0000co`0co`001C?o00030000oooooooo
08Koool008Coool00ol0VOooooooo`08oooo00<0000co`0co`0013?o00030000oooooooo08Ooool0
08Coool00ol0VOooooooo`08oooo00<0000co`0co`0013?o00030000oooooooo08Ooool008Coool0
0ol0VOooooooo`02oooo0`0000?oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00Q?oo
o`03o`2Ioooooooo00?oool00`000?ooooooo`02oooo00<0000co`0co`0013?o00030000oooooooo
08Ooool008Coool00ol0VOooooooo`0500000oooo`<00004<ol000<0003oooooool0Qoooo`00Qooo
o`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029
oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?oo
ooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000@co`02000000@co`3oooooooooool200000oooo`@00003
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`040000oooooooo00001S?o00;oool010000?ooooooo`0000;oool0
0`000?ooooooo`04oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0=oooo00@0003oooooool00006<ol00_ooo`040000oooooooo00000oooo`030000oooooooo
00Coool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`00
00Hco`03oooo0P0000Goool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000ooool010000?ooooooo`0000Hco`02oooo00@0003oooooool00002oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200001c?o
00?oool200001?ooo`800003oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o
08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.84) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.45734 .12361 L
.45963 .12361 L
.46063 .12361 L
.46172 .12361 L
s
.46172 .12361 m
.46216 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.84) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
ooooo`2I00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
02ooool00ol0VOooooooo`07oooo00<0000co`0co`00>C?o00T0000doooo00<0003oooooool05Ooo
o`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000c<ol01P0005Goool008Goool00ol0VOoo
ooooo`07oooo00<0000co`0co`00<C?o0080001Koooo0025oooo00?o09Woooooool01oooo`030000
<ol0<ol002lco`020000GOooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000/<ol00`00
05ooool008Goool00ol0VOooooooo`07oooo0P0002Xco`030000H_ooo`00QOooo`03o`2Ioooooooo
00Ooool00`0003?o03?o000W<ol00P0006Goool008Goool00ol0VOooooooo`07oooo00<0000co`0c
o`009S?o00030000oooooooo06Goool008Goool00ol0VOooooooo`07oooo00<0000co`0co`009C?o
00030000oooooooo06Koool008Goool00ol0VOooooooo`07oooo00<0000co`0co`0093?o00030000
oooooooo06Ooool008Goool00ol0VOooooooo`07oooo00<0000co`0co`008S?o0080001Zoooo0025
oooo00?o09Woooooool01oooo`80000R<ol000<0003oooooool0J_ooo`00QOooo`03o`2Ioooooooo
00Ooool00`0003?o03?o000P<ol000<0003oooooool0Joooo`00QOooo`03o`2Ioooooooo00Ooool0
0`0003?o03?o000O<ol000<0003oooooool0K?ooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000N
<ol000<0003oooooool0KOooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000M<ol000<0
003oooooool0K_ooo`00QOooo`03o`2Ioooooooo00Ooool200007C?o00030000oooooooo06ooool0
08Goool00ol0VOooooooo`07oooo00<0000co`0co`006c?o00030000oooooooo073oool008Goool0
0ol0VOooooooo`07oooo00<0000co`0co`006c?o00030000oooooooo073oool008Goool00ol0VOoo
ooooo`07oooo00<0000co`0co`006S?o00030000oooooooo077oool008Goool00ol0VOooooooo`07
oooo00<0000co`0co`006S?o00030000oooooooo077oool008Goool00ol0VOooooooo`07oooo00<0
000co`0co`006C?o00030000oooooooo07;oool008Goool00ol0VOooooooo`07oooo0P0001Xco`00
0`000?ooooooo`1boooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol001Pco`000`000?oo
ooooo`1coooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol001Pco`000`000?ooooooo`1c
oooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo0025
oooo00?o09Woooooool01oooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo0025oooo00?o
09Woool00000100000?oool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00QOooo`05o`2I
oooooooooooo000000Goool00`0003?o03?o000F<ol000<0003oooooool0MOooo`00QOooo`05o`2I
oooooooooooo000000Goool300005C?o00030000oooooooo07Koool008Goool01Ol0VOoooooooooo
o`000005oooo00<0000co`0co`005C?o00030000oooooooo07Koool008Goool01Ol0VOoooooooooo
o`000005oooo00<0000co`0co`005C?o00030000oooooooo07Koool008Goool00ol0VOooooooo`02
00001Oooo`030000<ol0<ol001@co`000`000?ooooooo`1goooo0025oooo00?o09Woooooool01ooo
o`030000<ol0<ol001@co`000`000?ooooooo`1goooo0025oooo00?o09Woooooool01oooo`030000
<ol0<ol001<co`000`000?ooooooo`1hoooo0025oooo00?o09Woooooool01oooo`80000D<ol000<0
003oooooool0N?ooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000C<ol000<0003ooooo
ool0N?ooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000B<ol000<0003oooooool0NOoo
o`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00QOoo
o`03o`2Ioooooooo00Ooool00`0003?o03?o000B<ol000<0003oooooool0NOooo`00QOooo`03o`2I
oooooooo00Ooool00`0003?o03?o000A<ol000<0003oooooool0N_ooo`00QOooo`03o`2Ioooooooo
00Ooool200004S?o00030000oooooooo07[oool008Goool00ol0VOooooooo`07oooo00<0000co`0c
o`004C?o00030000oooooooo07[oool008Goool00ol0VOooooooo`07oooo00<0000co`0co`004C?o
00030000oooooooo07[oool008Goool00ol0VOooooooo`07oooo00<0000co`0co`0043?o00030000
oooooooo07_oool008Goool00ol0VOooooooo`07oooo00<0000co`0co`0043?o00030000oooooooo
07_oool008Goool00ol0VOooooooo`07oooo00<0000co`0co`0043?o00030000oooooooo07_oool0
08Goool00ol0VOooooooo`07oooo00<0000co`0co`0043?o00030000oooooooo07_oool008Goool0
0ol0VOooooooo`07oooo0P00010co`000`000?ooooooo`1loooo0025oooo00?o09Woooooool01ooo
o`030000<ol0<ol000lco`000`000?ooooooo`1loooo0025oooo00?o09Woooooool01oooo`030000
<ol0<ol000lco`000`000?ooooooo`1loooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol0
00lco`000`000?ooooooo`1loooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol000lco`00
0`000?ooooooo`1loooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol000hco`000`000?oo
ooooo`1moooo0025oooo00?o09Woooooool01oooo`80000?<ol000<0003oooooool0OOooo`00QOoo
o`03o`2Ioooooooo00Ooool00`0003?o03?o000><ol000<0003oooooool0OOooo`00QOooo`03o`2I
oooooooo00Ooool00`0003?o03?o000><ol000<0003oooooool0OOooo`00QOooo`03o`2Ioooooooo
00Ooool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00QOooo`03o`2Ioooo000000<00004
oooo00<0000co`0co`003C?o00030000oooooooo07koool008Goool00ol0VOooo`000007oooo00<0
000co`0co`003C?o00030000oooooooo07koool008Goool01?l0VOooooooo`0000Koool300003C?o
00030000oooooooo07koool008Goool01Ol0VOooooooooooo`000005oooo00<0000co`0co`003C?o
00030000oooooooo07koool008Goool00ol0VOooo`000002oooo00<0003oooooool00_ooo`030000
<ol0<ol000`co`000`000?ooooooo`1ooooo0025oooo00?o09Woooooool00P0000Goool00`0003?o
03?o000<<ol000<0003oooooool0Ooooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000<
<ol000<0003oooooool0Ooooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000<<ol000<0
003oooooool0Ooooo`00QOooo`03o`2Ioooooooo00Ooool200003C?o00030000oooooooo07ooool0
08Goool00ol0VOooooooo`07oooo00<0000co`0co`0033?o00030000oooooooo07ooool008Goool0
0ol0VOooooooo`07oooo00<0000co`0co`002c?o00030000oooooooo083oool008Goool00ol0VOoo
ooooo`07oooo00<0000co`0co`002c?o00030000oooooooo083oool008Goool00ol0VOooooooo`07
oooo00<0000co`0co`002c?o00030000oooooooo083oool008Goool00ol0VOooooooo`07oooo00<0
000co`0co`002c?o00030000oooooooo083oool008Goool00ol0VOooooooo`07oooo00<0000co`0c
o`002c?o00030000oooooooo083oool008Goool00ol0VOooooooo`07oooo0P0000`co`000`000?oo
ooooo`20oooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol000/co`000`000?ooooooo`20
oooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0025
oooo00?o09Woooooool01oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0025oooo00?o
09Woooooool01oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0025oooo00?o09Wooooo
ool01oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0025oooo00?o09Woooooool01ooo
o`80000;<ol000<0003oooooool0POooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000:
<ol000<0003oooooool0POooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o000:<ol000<0
003oooooool0POooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o0009<ol000<0003ooooo
ool0P_ooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o0009<ol000<0003oooooool0P_oo
o`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00QOoo
o`03o`2Ioooooooo00Ooool200002S?o00030000oooooooo08;oool008Goool00ol0VOooooooo`07
oooo00<0000co`0co`002C?o00030000oooooooo08;oool008Goool00ol0VOooooooo`07oooo00<0
000co`0co`002C?o00030000oooooooo08;oool008Goool00ol0VOooooooo`07oooo00<0000co`0c
o`0023?o00030000oooooooo08?oool008Goool00ol0VOooooooo`0200001Oooo`030000<ol0<ol0
00Pco`000`000?ooooooo`23oooo0025oooo00?o09Woool000000_ooo`030000oooooooo00;oool0
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00QOooo`05o`2Ioooooooooooo000000Goool3
000023?o00030000oooooooo08?oool008Goool00ol0VOooooooo`02oooo00<0003oooooool00_oo
o`030000<ol0<ol000Pco`000`000?ooooooo`23oooo0025oooo00?o09Woool000000_ooo`030000
oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00QOooo`03o`2Ioooooooo
00800005oooo00<0000co`0co`001c?o00030000oooooooo08Coool008Goool00ol0VOooooooo`07
oooo00<0000co`0co`001c?o00030000oooooooo08Coool008Goool00ol0VOooooooo`07oooo00<0
000co`0co`001c?o00030000oooooooo08Coool008Goool00ol0VOooooooo`07oooo00<0000co`0c
o`001c?o00030000oooooooo08Coool008Goool00ol0VOooooooo`07oooo0P0000Pco`000`000?oo
ooooo`24oooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo0025oooo00?o09Woooooool01oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0025
oooo00?o09Woooooool01oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0025oooo00?o
09Woooooool01oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo0025oooo00?o09Wooooo
ool01oooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo0025oooo00?o09Woooooool01ooo
o`800007<ol000<0003oooooool0QOooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00QOooo`03o`2Ioooooooo00Ooool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00QOoo
o`03o`2Ioooooooo00Ooool200001S?o00030000oooooooo08Koool008Goool00ol0VOooooooo`07
oooo00<0000co`0co`001C?o00030000oooooooo08Koool008Goool00ol0VOooooooo`07oooo00<0
000co`0co`001C?o00030000oooooooo08Koool008Goool00ol0VOooooooo`07oooo00<0000co`0c
o`001C?o00030000oooooooo08Koool008Goool00ol0VOooooooo`07oooo00<0000co`0co`001C?o
00030000oooooooo08Koool008Goool00ol0VOooooooo`07oooo00<0000co`0co`001C?o00030000
oooooooo08Koool008Goool00ol0VOooooooo`07oooo0P0000Hco`000`000?ooooooo`26oooo0025
oooo00?o09Woooooool01oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0025oooo00?o
09Woooooool01oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0025oooo00?o09Wooooo
ool01oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo0025oooo00?o09Woooooool01ooo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo0025oooo00Co09Woooooooooool300000ooo
o`030000<ol0<ol000@co`000`000?ooooooo`27oooo0025oooo00?o09Woooooool00_ooo`030000
oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00QOooo`03o`2Ioooo0000
00@00003oooo0`0000@co`000`000?ooooooo`27oooo0027oooo00@0003oooooool00004oooo1c?o
08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?
oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_ooo`030000
oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?oooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool2
000013?o0080000013?o0?ooooooooooo`800005oooo0`0000;oool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0
003oooooool00006<ol00_ooo`040000oooooooo00001Oooo`050000oooooooooooo000007[oool0
07Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00001S?o00;oool0
10000?ooooooo`0000;oool500000oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00003?ooo`040000oooooooo00001S?o00?oool200000oooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00006<ol00_oo
o`040000oooooooo00000oooo`030000oooo000000?oool00`000?ooooooo`1hoooo001ioooo00<0
003oooooool04Oooo`800007<ol00oooo`800005oooo0P0000;oool00`000?ooooooo`1ioooo002?
oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.86) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.46172 .12361 L
.46388 .12361 L
.46507 .12361 L
.46618 .12361 L
s
.46618 .12361 m
.46644 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.86) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`040000
ooooooooo`2I2?ooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0
003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003ooooo
ool0<?ooo`03o`2Ioooooooo00Koool00`0003?o03?o000i<ol02@0003Coool00`000?ooooooo`0E
oooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol003<co`060000EOooo`00Q_ooo`03o`2I
oooooooo00Koool00`0003?o03?o000a<ol00P0005_oool008Koool00ol0VOooooooo`06oooo00<0
000co`0co`00;c?o0080001Moooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol002`co`03
0000Goooo`00Q_ooo`03o`2Ioooooooo00Koool20000:S?o00<0001Roooo0026oooo00?o09Wooooo
ool01_ooo`030000<ol0<ol002Lco`020000IOooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o
03?o000V<ol000<0003oooooool0IOooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000U
<ol000<0003oooooool0I_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000T<ol000<0
003oooooool0Ioooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000R<ol00P0006[oool0
08Koool00ol0VOooooooo`06oooo0P00028co`000`000?ooooooo`1Zoooo0026oooo00?o09Wooooo
ool01_ooo`030000<ol0<ol0020co`000`000?ooooooo`1[oooo0026oooo00?o09Woooooool01_oo
o`030000<ol0<ol001lco`000`000?ooooooo`1/oooo0026oooo00?o09Woooooool01_ooo`030000
<ol0<ol001lco`000`000?ooooooo`1/oooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol0
01hco`000`000?ooooooo`1]oooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol001dco`00
0`000?ooooooo`1^oooo0026oooo00?o09Woooooool01_ooo`80000M<ol000<0003oooooool0Kooo
o`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00Q_oo
o`03o`2Ioooooooo00Koool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00Q_ooo`03o`2I
oooooooo00Koool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00Q_ooo`03o`2Ioooooooo
00Koool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00Q_ooo`03o`2Ioooooooo00Koool0
0`0003?o03?o000I<ol000<0003oooooool0L_ooo`00Q_ooo`03o`2Ioooooooo00Koool200006S?o
00030000oooooooo07;oool008Koool00ol0VOooooooo`06oooo00<0000co`0co`0063?o00030000
oooooooo07?oool008Koool00ol0VOooooooo`06oooo00<0000co`0co`0063?o00030000oooooooo
07?oool008Koool00ol0VOooooooo`06oooo00<0000co`0co`005c?o00030000oooooooo07Coool0
08Koool00ol0VOooooooo`06oooo00<0000co`0co`005c?o00030000oooooooo07Coool008Koool0
0ol0V@000000000300000oooo`030000<ol0<ol001Hco`000`000?ooooooo`1eoooo0026oooo00Co
09Woooooool00005oooo00<0000co`0co`005S?o00030000oooooooo07Goool008Koool01?l0VOoo
ooooo`0000Goool300005C?o00030000oooooooo07Koool008Koool01?l0VOooooooo`0000Goool0
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00Q_ooo`04o`2Ioooooooo00001Oooo`030000
<ol0<ol001Dco`000`000?ooooooo`1foooo0026oooo00Co09Woool000000005oooo00<0000co`0c
o`0053?o00030000oooooooo07Ooool008Koool00ol0VOooooooo`06oooo00<0000co`0co`0053?o
00030000oooooooo07Ooool008Koool00ol0VOooooooo`06oooo00<0000co`0co`004c?o00030000
oooooooo07Soool008Koool00ol0VOooooooo`06oooo0P0001@co`000`000?ooooooo`1hoooo0026
oooo00?o09Woooooool01_ooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo0026oooo00?o
09Woooooool01_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo0026oooo00?o09Wooooo
ool01_ooo`030000<ol0<ol0018co`000`000?ooooooo`1ioooo0026oooo00?o09Woooooool01_oo
o`030000<ol0<ol0018co`000`000?ooooooo`1ioooo0026oooo00?o09Woooooool01_ooo`030000
<ol0<ol0014co`000`000?ooooooo`1joooo0026oooo00?o09Woooooool01_ooo`80000B<ol000<0
003oooooool0N_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000A<ol000<0003ooooo
ool0N_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000A<ol000<0003oooooool0N_oo
o`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Q_oo
o`03o`2Ioooooooo00Koool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Q_ooo`03o`2I
oooooooo00Koool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Q_ooo`03o`2Ioooooooo
00Koool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Q_ooo`03o`2Ioooooooo00Koool2
000043?o00030000oooooooo07coool008Koool00ol0VOooooooo`06oooo00<0000co`0co`003c?o
00030000oooooooo07coool008Koool00ol0VOooooooo`06oooo00<0000co`0co`003c?o00030000
oooooooo07coool008Koool00ol0VOooooooo`06oooo00<0000co`0co`003c?o00030000oooooooo
07coool008Koool00ol0VOooooooo`06oooo00<0000co`0co`003c?o00030000oooooooo07coool0
08Koool00ol0VOooooooo`06oooo00<0000co`0co`003S?o00030000oooooooo07goool008Koool0
0ol0VOooooooo`06oooo0P0000lco`000`000?ooooooo`1moooo0026oooo00?o09Woooooool01_oo
o`030000<ol0<ol000hco`000`000?ooooooo`1moooo0026oooo00?o09Woooooool01_ooo`030000
<ol0<ol000hco`000`000?ooooooo`1moooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol0
00dco`000`000?ooooooo`1noooo0026oooo00?o09T0000000000P0000Coool00`0003?o03?o000=
<ol000<0003oooooool0O_ooo`00Q_ooo`03o`2I0000oooo00Koool00`0003?o03?o000=<ol000<0
003oooooool0O_ooo`00Q_ooo`03o`2Ioooo000000Koool300003C?o00030000oooooooo07koool0
08Koool01?l0VOooooooo`0000Goool00`0003?o03?o000=<ol000<0003oooooool0O_ooo`00Q_oo
o`05o`2I0000oooooooo000000Coool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00Q_oo
o`04o`2Ioooo000000001Oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0026oooo00?o
09Woooooool01_ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0026oooo00?o09Wooooo
ool01_ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0026oooo00?o09Woooooool01_oo
o`80000=<ol000<0003oooooool0Ooooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000<
<ol000<0003oooooool0Ooooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00Q_oo
o`03o`2Ioooooooo00Koool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00Q_ooo`03o`2I
oooooooo00Koool2000033?o00030000oooooooo083oool008Koool00ol0VOooooooo`06oooo00<0
000co`0co`002c?o00030000oooooooo083oool008Koool00ol0VOooooooo`06oooo00<0000co`0c
o`002S?o00030000oooooooo087oool008Koool00ol0VOooooooo`06oooo00<0000co`0co`002S?o
00030000oooooooo087oool008Koool00ol0VOooooooo`06oooo00<0000co`0co`002S?o00030000
oooooooo087oool008Koool00ol0VOooooooo`06oooo00<0000co`0co`002S?o00030000oooooooo
087oool008Koool00ol0VOooooooo`06oooo0P0000/co`000`000?ooooooo`21oooo0026oooo00?o
09Woooooool01_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0026oooo00?o09Wooooo
ool01_ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0026oooo00?o09Woooooool01_oo
o`030000<ol0<ol000Tco`000`000?ooooooo`22oooo0026oooo00?o09Woooooool01_ooo`030000
<ol0<ol000Tco`000`000?ooooooo`22oooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol0
00Tco`000`000?ooooooo`22oooo0026oooo00?o09Woooooool01_ooo`80000:<ol000<0003ooooo
ool0P_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o0009<ol000<0003oooooool0P_oo
o`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00Q_oo
o`03o`2Ioooooooo00Koool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00Q_ooo`04o`2I
oooo000000001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo0026oooo00Go09T0003o
ooooool000001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo0026oooo00Co09Wooooo
ool00005oooo0`0000Pco`000`000?ooooooo`23oooo0026oooo00Go09Woooooooooool000001?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`23oooo0026oooo00Go09T0003oooooool000001?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`23oooo0026oooo00Co09Woool000000005oooo00<0
000co`0co`001c?o00030000oooooooo08Coool008Koool00ol0VOooooooo`06oooo00<0000co`0c
o`001c?o00030000oooooooo08Coool008Koool00ol0VOooooooo`06oooo00<0000co`0co`001c?o
00030000oooooooo08Coool008Koool00ol0VOooooooo`06oooo00<0000co`0co`001c?o00030000
oooooooo08Coool008Koool00ol0VOooooooo`06oooo0P0000Pco`000`000?ooooooo`24oooo0026
oooo00?o09Woooooool01_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0026oooo00?o
09Woooooool01_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0026oooo00?o09Wooooo
ool01_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0026oooo00?o09Woooooool01_oo
o`030000<ol0<ol000Hco`000`000?ooooooo`25oooo0026oooo00?o09Woooooool01_ooo`030000
<ol0<ol000Hco`000`000?ooooooo`25oooo0026oooo00?o09Woooooool01_ooo`800007<ol000<0
003oooooool0QOooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00Q_ooo`03o`2Ioooooooo00Koool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00Q_oo
o`03o`2Ioooooooo00Koool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00Q_ooo`03o`2I
oooooooo00Koool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00Q_ooo`03o`2Ioooooooo
00Koool200001S?o00030000oooooooo08Koool008Koool00ol0VOooooooo`06oooo00<0000co`0c
o`001C?o00030000oooooooo08Koool008Koool00ol0VOooooooo`06oooo00<0000co`0co`001C?o
00030000oooooooo08Koool008Koool00ol0VOooooooo`06oooo00<0000co`0co`001C?o00030000
oooooooo08Koool008Koool00ol0VOooooooo`06oooo00<0000co`0co`001C?o00030000oooooooo
08Koool008Koool00ol0VOooooooo`06oooo00<0000co`0co`001C?o00030000oooooooo08Koool0
08Koool00ol0VOooooooo`06oooo0P0000Hco`000`000?ooooooo`26oooo0026oooo00?o09Wooooo
ool01_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0026oooo00?o09Woooooool01_oo
o`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0026oooo00?o09Woooooool01_ooo`030000
<ol0<ol000@co`000`000?ooooooo`27oooo0026oooo00?o09Woooooool01_ooo`030000<ol0<ol0
00@co`000`000?ooooooo`27oooo0026oooo00?o09Woooooool00`0000?oool00`0003?o03?o0004
<ol000<0003oooooool0Qoooo`00Q_ooo`05o`2Ioooooooooooo000000Coool00`0003?o03?o0004
<ol000<0003oooooool0Qoooo`00Q_ooo`03o`2I0000000000<00003oooo0`0000@co`000`000?oo
ooooo`27oooo0027oooo00@0003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004
oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_oo
o`00NOooo`030000oooooooo01?oool7<ol03_ooo`030000oooooooo07Woool007Soool00`000?oo
ooooo`08oooo00<0003oooooool02Oooo`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Ooool2000013?o0080000013?o0?oooooooooo
o`800003oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00006<ol00_ooo`040000
oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?oo
ooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00001S?o00;oool010000?ooooooo`00
00;oool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
00coool010000?ooooooo`0000Hco`03oooo0P0000?oool300001?ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00006<ol00_ooo`040000oooooooo
00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Ooo
o`800007<ol00oooo`800004oooo0`0000;oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool0
08ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.88) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.46172 .12361 L
.46618 .12361 L
.46854 .12361 L
.46984 .12361 L
.47106 .12361 L
s
.47106 .12361 m
.47153 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.88) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00;oool00ol0VOooooooo`04oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0boooo00?o09Woooooool01?ooo`030000<ol0<ol003Tco`090000=?oo
o`030000oooooooo01Goool008Soool00ol0VOooooooo`04oooo00<0000co`0co`00<c?o00H0001E
oooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol0034co`020000Foooo`00R?ooo`03o`2I
oooooooo00Coool00`0003?o03?o000_<ol00P0005goool008Soool00ol0VOooooooo`04oooo00<0
000co`0co`00;3?o00<0001Ooooo0028oooo00?o09Woooooool01?ooo`80000Z<ol00`0006;oool0
08Soool00ol0VOooooooo`04oooo00<0000co`0co`009c?o0080001Uoooo0028oooo00?o09Wooooo
ool01?ooo`030000<ol0<ol002Hco`000`000?ooooooo`1Uoooo0028oooo00?o09Woooooool01?oo
o`030000<ol0<ol002Dco`000`000?ooooooo`1Voooo0028oooo00?o09Woooooool01?ooo`030000
<ol0<ol002@co`000`000?ooooooo`1Woooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol0
028co`020000J_ooo`00R?ooo`03o`2Ioooooooo00Coool200008S?o00030000oooooooo06[oool0
08Soool00ol0VOooooooo`04oooo00<0000co`0co`0083?o00030000oooooooo06_oool008Soool0
0ol0VOooooooo`04oooo00<0000co`0co`007c?o00030000oooooooo06coool008Soool00ol0VOoo
ooooo`04oooo00<0000co`0co`007c?o00030000oooooooo06coool008Soool00ol0VOooooooo`04
oooo00<0000co`0co`007S?o00030000oooooooo06goool008Soool00ol0VOooooooo`04oooo00<0
000co`0co`007C?o00030000oooooooo06koool008Soool00ol0VOooooooo`04oooo0P0001dco`00
0`000?ooooooo`1_oooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol001/co`000`000?oo
ooooo`1`oooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol001/co`000`000?ooooooo`1`
oooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo0028
oooo00?o09Woooooool01?ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo0028oooo00?o
09Woooooool01?ooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo0028oooo00?o09Wooooo
ool01?ooo`80000J<ol000<0003oooooool0L_ooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o
03?o000H<ol000<0003oooooool0Loooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000H
<ol000<0003oooooool0Loooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000G<ol000<0
003oooooool0M?ooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000G<ol000<0003ooooo
ool0M?ooo`00Qoooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool008Soool0
0ol0V@000?ooo`04oooo00<0000co`0co`005S?o00030000oooooooo07Goool008Soool00ol0V@00
0?ooo`04oooo0`0001Dco`000`000?ooooooo`1foooo0028oooo00?o09T0003oool01?ooo`030000
<ol0<ol001Dco`000`000?ooooooo`1foooo0028oooo00?o09T0003oool01?ooo`030000<ol0<ol0
01Dco`000`000?ooooooo`1foooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003ooooo
ool0Moooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000D<ol000<0003oooooool0Mooo
o`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00R?oo
o`03o`2Ioooooooo00Coool2000053?o00030000oooooooo07Soool008Soool00ol0VOooooooo`04
oooo00<0000co`0co`004c?o00030000oooooooo07Soool008Soool00ol0VOooooooo`04oooo00<0
000co`0co`004S?o00030000oooooooo07Woool008Soool00ol0VOooooooo`04oooo00<0000co`0c
o`004S?o00030000oooooooo07Woool008Soool00ol0VOooooooo`04oooo00<0000co`0co`004S?o
00030000oooooooo07Woool008Soool00ol0VOooooooo`04oooo00<0000co`0co`004C?o00030000
oooooooo07[oool008Soool00ol0VOooooooo`04oooo0P00018co`000`000?ooooooo`1joooo0028
oooo00?o09Woooooool01?ooo`030000<ol0<ol0014co`000`000?ooooooo`1joooo0028oooo00?o
09Woooooool01?ooo`030000<ol0<ol0014co`000`000?ooooooo`1joooo0028oooo00?o09Wooooo
ool01?ooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo0028oooo00?o09Woooooool01?oo
o`030000<ol0<ol0010co`000`000?ooooooo`1koooo0028oooo00?o09Woooooool01?ooo`030000
<ol0<ol0010co`000`000?ooooooo`1koooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol0
010co`000`000?ooooooo`1koooo0028oooo00?o09Woooooool01?ooo`80000@<ol000<0003ooooo
ool0O?ooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000?<ol000<0003oooooool0O?oo
o`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00R?oo
o`03o`2Ioooooooo00Coool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00R?ooo`03o`2I
oooooooo00Coool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00R?ooo`03o`2Ioooooooo
00Coool00`0003?o03?o000><ol000<0003oooooool0OOooo`00R?ooo`03o`2Ioooooooo00Coool2
00003c?o00030000oooooooo07goool008Soool00ol0VOooooooo`04oooo00<0000co`0co`003S?o
00030000oooooooo07goool008Soool00ol0VOooooooo`04oooo00<0000co`0co`003S?o00030000
oooooooo07goool008Soool00ol0VOooooooo`04oooo00<0000co`0co`003C?o00030000oooooooo
07koool008Ooool400001?ooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo0027oooo00<0
003o09Woool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo0028oooo00<0003ooooo
ool01?ooo`<0000=<ol000<0003oooooool0O_ooo`00R?ooo`03o`2I0000oooo00Coool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00Qoooo`040000o`2Ioooo00001?ooo`030000<ol0<ol0
00`co`000`000?ooooooo`1ooooo0028oooo0P0000Goool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00R?oo
o`03o`2Ioooooooo00Coool200003C?o00030000oooooooo07ooool008Soool00ol0VOooooooo`04
oooo00<0000co`0co`0033?o00030000oooooooo07ooool008Soool00ol0VOooooooo`04oooo00<0
000co`0co`002c?o00030000oooooooo083oool008Soool00ol0VOooooooo`04oooo00<0000co`0c
o`002c?o00030000oooooooo083oool008Soool00ol0VOooooooo`04oooo00<0000co`0co`002c?o
00030000oooooooo083oool008Soool00ol0VOooooooo`04oooo00<0000co`0co`002c?o00030000
oooooooo083oool008Soool00ol0VOooooooo`04oooo00<0000co`0co`002c?o00030000oooooooo
083oool008Soool00ol0VOooooooo`04oooo0P0000`co`000`000?ooooooo`20oooo0028oooo00?o
09Woooooool01?ooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo0028oooo00?o09Wooooo
ool01?ooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0028oooo00?o09Woooooool01?oo
o`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0028oooo00?o09Woooooool01?ooo`030000
<ol0<ol000Xco`000`000?ooooooo`21oooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol0
00Xco`000`000?ooooooo`21oooo0028oooo00?o09Woooooool01?ooo`80000;<ol000<0003ooooo
ool0POooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000:<ol000<0003oooooool0POoo
o`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o000:<ol000<0003oooooool0POooo`00R?oo
o`03o`2Ioooooooo00Coool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00R?ooo`03o`2I
oooooooo00Coool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00R?ooo`03o`2Ioooooooo
00Coool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00R?ooo`03o`2Ioooooooo00Coool2
00002S?o00030000oooooooo08;oool008Soool00ol0VOooooooo`04oooo00<0000co`0co`002C?o
00030000oooooooo08;oool008Soool00ol0VOooooooo`04oooo00<0000co`0co`002C?o00030000
oooooooo08;oool008Soool00ol0VOooooooo`04oooo00<0000co`0co`0023?o00030000oooooooo
08?oool008Soool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo0027oooo00@0
003o09Woool00004oooo00<0000co`0co`0023?o00030000oooooooo08?oool008Soool00ol0V@00
0?ooo`04oooo0`0000Pco`000`000?ooooooo`23oooo0028oooo00?o09Woool000001?ooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo0027oooo00@0003o09Woool00004oooo00<0000co`0c
o`0023?o00030000oooooooo08?oool008Soool200001Oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`24oooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0028
oooo00?o09Woooooool01?ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0028oooo00?o
09Woooooool01?ooo`800008<ol000<0003oooooool0Q?ooo`00R?ooo`03o`2Ioooooooo00Coool0
0`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o
03?o0007<ol000<0003oooooool0Q?ooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00R?ooo`03o`2Ioooooooo00Coool200001c?o00030000oooooooo08Goool008Soool0
0ol0VOooooooo`04oooo00<0000co`0co`001S?o00030000oooooooo08Goool008Soool00ol0VOoo
ooooo`04oooo00<0000co`0co`001S?o00030000oooooooo08Goool008Soool00ol0VOooooooo`04
oooo00<0000co`0co`001S?o00030000oooooooo08Goool008Soool00ol0VOooooooo`04oooo00<0
000co`0co`001S?o00030000oooooooo08Goool008Soool00ol0VOooooooo`04oooo00<0000co`0c
o`001S?o00030000oooooooo08Goool008Soool00ol0VOooooooo`04oooo0P0000Hco`000`000?oo
ooooo`26oooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26
oooo0028oooo00?o09Woooooool01?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0028
oooo00?o09Woooooool01?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0028oooo00?o
09Woooooool01?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0028oooo00?o09Wooooo
ool01?ooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0028oooo00?o09Woooooool01?oo
o`800006<ol000<0003oooooool0Q_ooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o0005
<ol000<0003oooooool0Q_ooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o0005<ol000<0
003oooooool0Q_ooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o0004<ol000<0003ooooo
ool0Qoooo`00R?ooo`03o`2Ioooooooo00Coool00`0003?o03?o0004<ol000<0003oooooool0Qooo
o`00R?ooo`04o`2I0000000000000oooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo0028
oooo00?o09Woool000001?ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo0027oooo1@00
00?oool3000013?o00030000oooooooo08Ooool008Ooool010000?ooooooo`0000Coool7<ol0R_oo
o`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7
<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>oooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o00ooool00`000?oo
ooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004
<ol00P000004<ol0oooooooooooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?oo
ooooo`0000Hco`02oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00006
<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500003?ooo`040000oooooooo00001S?o00?oool200001?ooo`800004
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Hco`02oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo017oool200001c?o00?oool200001?ooo`800003oooo00<0003ooooo
ool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.46172 .12361 L
.46618 .12361 L
.47106 .12361 L
.47329 .12361 L
.47451 .12361 L
.47567 .12361 L
s
.47567 .12361 m
.4761 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00?oool00ol0VOooooooo`03oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0coooo00?o09Woooooool00oooo`030000<ol0<ol003Tco`090000=?oo
o`030000oooooooo01Goool008Woool00ol0VOooooooo`03oooo00<0000co`0co`00<c?o00H0001E
oooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol0034co`020000Foooo`00ROooo`03o`2I
oooooooo00?oool00`0003?o03?o000_<ol00P0005goool008Woool00ol0VOooooooo`03oooo00<0
000co`0co`00;3?o00<0001Ooooo0029oooo00?o09Woooooool00oooo`80000Z<ol00`0006;oool0
08Woool00ol0VOooooooo`03oooo00<0000co`0co`009c?o0080001Uoooo0029oooo00?o09Wooooo
ool00oooo`030000<ol0<ol002Hco`000`000?ooooooo`1Uoooo0029oooo00?o09Woooooool00ooo
o`030000<ol0<ol002Dco`000`000?ooooooo`1Voooo0029oooo00?o09Woooooool00oooo`030000
<ol0<ol002@co`000`000?ooooooo`1Woooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol0
028co`020000J_ooo`00ROooo`03o`2Ioooooooo00?oool200008S?o00030000oooooooo06[oool0
08Woool00ol0VOooooooo`03oooo00<0000co`0co`0083?o00030000oooooooo06_oool008Woool0
0ol0VOooooooo`03oooo00<0000co`0co`007c?o00030000oooooooo06coool008Woool00ol0VOoo
ooooo`03oooo00<0000co`0co`007c?o00030000oooooooo06coool008Woool00ol0VOooooooo`03
oooo00<0000co`0co`007S?o00030000oooooooo06goool008Woool00ol0VOooooooo`03oooo00<0
000co`0co`007C?o00030000oooooooo06koool008Woool00ol0VOooooooo`03oooo0P0001dco`00
0`000?ooooooo`1_oooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol001/co`000`000?oo
ooooo`1`oooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol001/co`000`000?ooooooo`1`
oooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo0029
oooo00?o09Woooooool00oooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo0029oooo00?o
09Woooooool00oooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo0029oooo00?o09Wooooo
ool00oooo`80000J<ol000<0003oooooool0L_ooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o
03?o000H<ol000<0003oooooool0Loooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000H
<ol000<0003oooooool0Loooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000G<ol000<0
003oooooool0M?ooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000G<ol000<0003ooooo
ool0M?ooo`00Qoooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo07Goool008Woool00`000?oo
ooooo`03oooo0`0001Dco`000`000?ooooooo`1foooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol001Dco`000`000?ooooooo`1foooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`1foooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003ooooo
ool0Moooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000D<ol000<0003oooooool0Mooo
o`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000C<ol000<0003oooooool0N?ooo`00ROoo
o`03o`2Ioooooooo00?oool2000053?o00030000oooooooo07Soool008Woool00ol0VOooooooo`03
oooo00<0000co`0co`004c?o00030000oooooooo07Soool008Woool00ol0VOooooooo`03oooo00<0
000co`0co`004S?o00030000oooooooo07Woool008Woool00ol0VOooooooo`03oooo00<0000co`0c
o`004S?o00030000oooooooo07Woool008Woool00ol0VOooooooo`03oooo00<0000co`0co`004S?o
00030000oooooooo07Woool008Woool00ol0VOooooooo`03oooo00<0000co`0co`004C?o00030000
oooooooo07[oool008Woool00ol0VOooooooo`03oooo0P00018co`000`000?ooooooo`1joooo0029
oooo00?o09Woooooool00oooo`030000<ol0<ol0014co`000`000?ooooooo`1joooo0029oooo00?o
09Woooooool00oooo`030000<ol0<ol0014co`000`000?ooooooo`1joooo0029oooo00?o09Wooooo
ool00oooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo0029oooo00?o09Woooooool00ooo
o`030000<ol0<ol0010co`000`000?ooooooo`1koooo0029oooo00?o09Woooooool00oooo`030000
<ol0<ol0010co`000`000?ooooooo`1koooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol0
010co`000`000?ooooooo`1koooo0029oooo00?o09Woooooool00oooo`80000@<ol000<0003ooooo
ool0O?ooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000?<ol000<0003oooooool0O?oo
o`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00ROoo
o`03o`2Ioooooooo00?oool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00ROooo`03o`2I
oooooooo00?oool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00ROooo`03o`2Ioooooooo
00?oool00`0003?o03?o000><ol000<0003oooooool0OOooo`00ROooo`03o`2Ioooooooo00?oool2
00003c?o00030000oooooooo07goool008Woool00ol0VOooooooo`03oooo00<0000co`0co`003S?o
00030000oooooooo07goool008Woool00ol0VOooooooo`03oooo00<0000co`0co`003S?o00030000
oooooooo07goool008Woool00ol0VOooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo
07koool008Ooool400001?ooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo0027oooo00<0
003ooooo09T01Oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo0028oooo00<0003o09Wo
ool01?ooo`<0000=<ol000<0003oooooool0O_ooo`00ROooo`030000oooooooo00?oool00`0003?o
03?o000=<ol000<0003oooooool0O_ooo`00Qoooo`040000ooooo`2I00001?ooo`030000<ol0<ol0
00`co`000`000?ooooooo`1ooooo0028oooo0P0000Goool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00ROoo
o`03o`2Ioooooooo00?oool200003C?o00030000oooooooo07ooool008Woool00ol0VOooooooo`03
oooo00<0000co`0co`0033?o00030000oooooooo07ooool008Woool00ol0VOooooooo`03oooo00<0
000co`0co`002c?o00030000oooooooo083oool008Woool00ol0VOooooooo`03oooo00<0000co`0c
o`002c?o00030000oooooooo083oool008Woool00ol0VOooooooo`03oooo00<0000co`0co`002c?o
00030000oooooooo083oool008Woool00ol0VOooooooo`03oooo00<0000co`0co`002c?o00030000
oooooooo083oool008Woool00ol0VOooooooo`03oooo00<0000co`0co`002c?o00030000oooooooo
083oool008Woool00ol0VOooooooo`03oooo0P0000`co`000`000?ooooooo`20oooo0029oooo00?o
09Woooooool00oooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo0029oooo00?o09Wooooo
ool00oooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0029oooo00?o09Woooooool00ooo
o`030000<ol0<ol000Xco`000`000?ooooooo`21oooo0029oooo00?o09Woooooool00oooo`030000
<ol0<ol000Xco`000`000?ooooooo`21oooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol0
00Xco`000`000?ooooooo`21oooo0029oooo00?o09Woooooool00oooo`80000;<ol000<0003ooooo
ool0POooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000:<ol000<0003oooooool0POoo
o`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o000:<ol000<0003oooooool0POooo`00ROoo
o`03o`2Ioooooooo00?oool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00ROooo`03o`2I
oooooooo00?oool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00ROooo`03o`2Ioooooooo
00?oool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00ROooo`03o`2Ioooooooo00?oool2
00002S?o00030000oooooooo08;oool008Woool00ol0VOooooooo`03oooo00<0000co`0co`002C?o
00030000oooooooo08;oool008Woool00ol0VOooooooo`03oooo00<0000co`0co`002C?o00030000
oooooooo08;oool008Woool00ol0VOooooooo`03oooo00<0000co`0co`0023?o00030000oooooooo
08?oool008Soool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`23oooo0027oooo00@0
003ooooo09T00004oooo00<0000co`0co`0023?o00030000oooooooo08?oool008Woool00`000?oo
ooooo`03oooo0`0000Pco`000`000?ooooooo`23oooo0029oooo00?o09T0003oool00oooo`030000
<ol0<ol000Pco`000`000?ooooooo`23oooo0027oooo00@0003ooooo09T00004oooo00<0000co`0c
o`0023?o00030000oooooooo08?oool008Soool200001Oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`24oooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol000Lco`000`000?ooooooo`24
oooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0029
oooo00?o09Woooooool00oooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo0029oooo00?o
09Woooooool00oooo`800008<ol000<0003oooooool0Q?ooo`00ROooo`03o`2Ioooooooo00?oool0
0`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o
03?o0007<ol000<0003oooooool0Q?ooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o0007
<ol000<0003oooooool0Q?ooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o0006<ol000<0003ooooo
ool0QOooo`00ROooo`03o`2Ioooooooo00?oool200001c?o00030000oooooooo08Goool008Woool0
0ol0VOooooooo`03oooo00<0000co`0co`001S?o00030000oooooooo08Goool008Woool00ol0VOoo
ooooo`03oooo00<0000co`0co`001S?o00030000oooooooo08Goool008Woool00ol0VOooooooo`03
oooo00<0000co`0co`001S?o00030000oooooooo08Goool008Woool00ol0VOooooooo`03oooo00<0
000co`0co`001S?o00030000oooooooo08Goool008Woool00ol0VOooooooo`03oooo00<0000co`0c
o`001S?o00030000oooooooo08Goool008Woool00ol0VOooooooo`03oooo0P0000Hco`000`000?oo
ooooo`26oooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol000Dco`000`000?ooooooo`26
oooo0029oooo00?o09Woooooool00oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0029
oooo00?o09Woooooool00oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0029oooo00?o
09Woooooool00oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0029oooo00?o09Wooooo
ool00oooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo0029oooo00?o09Woooooool00ooo
o`800006<ol000<0003oooooool0Q_ooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o0005
<ol000<0003oooooool0Q_ooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o0005<ol000<0
003oooooool0Q_ooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o0004<ol000<0003ooooo
ool0Qoooo`00ROooo`03o`2Ioooooooo00?oool00`0003?o03?o0004<ol000<0003oooooool0Qooo
o`00ROooo`<00003oooo00<0000co`0co`0013?o00030000oooooooo08Ooool008Woool00ol0V@00
0?ooo`03oooo00<0000co`0co`0013?o00030000oooooooo08Ooool008Ooool500000oooo`<00004
<ol000<0003oooooool0Qoooo`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0
003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?
oooo1c?o08[oool007coool00`000?ooooooo`0@oooo1c?o00_oool00`000?ooooooo`1loooo001k
oooo00<0003oooooool02?ooo`030000oooooooo00Koool7<ol03?ooo`030000oooooooo07_oool0
07_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo00<co`000000000013?o
00800003oooo0`0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`05oooo00@0000co`0co`000003<ol01oooo`030000
oooooooo00;oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo
00goool0100003?o03?o000000<co`06oooo0`0000Coool00`000?ooooooo`1joooo001koooo00<0
003oooooool01@0000coool0100003?o03?o000000<co`05oooo00@0003oooooool00003oooo00<0
003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool0100003?o03?o000000<co`05
oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo013oool0
0c?o000000000004<ol01_ooo`<00002oooo00<0003oooooool0O?ooo`00Soooo`Lco`2:oooo002?
oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.92) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47106 .12361 L
.47567 .12361 L
.47791 .12361 L
.47889 .12361 L
.47994 .12361 L
s
.47994 .12361 m
.48043 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.92) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Coool00ol0VOooooooo`02oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0doooo00?o09Woooooool00_ooo`030000<ol0<ol003Tco`090000=?oo
o`030000oooooooo01Goool008[oool00ol0VOooooooo`02oooo00<0000co`0co`00<c?o00H0001E
oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol0034co`020000Foooo`00R_ooo`03o`2I
oooooooo00;oool00`0003?o03?o000_<ol00P0005goool008[oool00ol0VOooooooo`02oooo00<0
000co`0co`00;3?o00<0001Ooooo002:oooo00?o09Woooooool00_ooo`80000Z<ol00`0006;oool0
08[oool00ol0VOooooooo`02oooo00<0000co`0co`009c?o0080001Uoooo002:oooo00?o09Wooooo
ool00_ooo`030000<ol0<ol002Hco`000`000?ooooooo`1Uoooo002:oooo00?o09Woooooool00_oo
o`030000<ol0<ol002Dco`000`000?ooooooo`1Voooo002:oooo00?o09Woooooool00_ooo`030000
<ol0<ol002@co`000`000?ooooooo`1Woooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol0
028co`020000J_ooo`00R_ooo`03o`2Ioooooooo00;oool200008S?o00030000oooooooo06[oool0
08[oool00ol0VOooooooo`02oooo00<0000co`0co`0083?o00030000oooooooo06_oool008[oool0
0ol0VOooooooo`02oooo00<0000co`0co`007c?o00030000oooooooo06coool008[oool00ol0VOoo
ooooo`02oooo00<0000co`0co`007c?o00030000oooooooo06coool008[oool00ol0VOooooooo`02
oooo00<0000co`0co`007S?o00030000oooooooo06goool008[oool00ol0VOooooooo`02oooo00<0
000co`0co`007C?o00030000oooooooo06koool008[oool00ol0VOooooooo`02oooo0P0001dco`00
0`000?ooooooo`1_oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol001/co`000`000?oo
ooooo`1`oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol001/co`000`000?ooooooo`1`
oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo002:
oooo00?o09Woooooool00_ooo`030000<ol0<ol001Xco`000`000?ooooooo`1aoooo002:oooo00?o
09Woooooool00_ooo`030000<ol0<ol001Tco`000`000?ooooooo`1boooo002:oooo00?o09Wooooo
ool00_ooo`80000J<ol000<0003oooooool0L_ooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o
03?o000H<ol000<0003oooooool0Loooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000H
<ol000<0003oooooool0Loooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000G<ol000<0
003oooooool0M?ooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000G<ol000<0003ooooo
ool0M?ooo`00Qoooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo07Goool008Woool0
0`000?l0VOooo`03oooo00<0000co`0co`005S?o00030000oooooooo07Goool008Woool00`000?l0
VOooo`03oooo0`0001Dco`000`000?ooooooo`1foooo0029oooo00<0003o09Woool00oooo`030000
<ol0<ol001Dco`000`000?ooooooo`1foooo0029oooo00<0003o09Woool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`1foooo0028oooo0P000003o`2Ioooooooo00;oool00`0003?o03?o000D
<ol000<0003oooooool0Moooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000D<ol000<0
003oooooool0Moooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000C<ol000<0003ooooo
ool0N?ooo`00R_ooo`03o`2Ioooooooo00;oool2000053?o00030000oooooooo07Soool008[oool0
0ol0VOooooooo`02oooo00<0000co`0co`004c?o00030000oooooooo07Soool008[oool00ol0VOoo
ooooo`02oooo00<0000co`0co`004S?o00030000oooooooo07Woool008[oool00ol0VOooooooo`02
oooo00<0000co`0co`004S?o00030000oooooooo07Woool008[oool00ol0VOooooooo`02oooo00<0
000co`0co`004S?o00030000oooooooo07Woool008[oool00ol0VOooooooo`02oooo00<0000co`0c
o`004C?o00030000oooooooo07[oool008[oool00ol0VOooooooo`02oooo0P00018co`000`000?oo
ooooo`1joooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol0014co`000`000?ooooooo`1j
oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol0014co`000`000?ooooooo`1joooo002:
oooo00?o09Woooooool00_ooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo002:oooo00?o
09Woooooool00_ooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo002:oooo00?o09Wooooo
ool00_ooo`030000<ol0<ol0010co`000`000?ooooooo`1koooo002:oooo00?o09Woooooool00_oo
o`030000<ol0<ol0010co`000`000?ooooooo`1koooo002:oooo00?o09Woooooool00_ooo`80000@
<ol000<0003oooooool0O?ooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000?<ol000<0
003oooooool0O?ooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000?<ol000<0003ooooo
ool0O?ooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000?<ol000<0003oooooool0O?oo
o`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000?<ol000<0003oooooool0O?ooo`00R_oo
o`03o`2Ioooooooo00;oool00`0003?o03?o000><ol000<0003oooooool0OOooo`00R_ooo`03o`2I
oooooooo00;oool200003c?o00030000oooooooo07goool008[oool00ol0VOooooooo`02oooo00<0
000co`0co`003S?o00030000oooooooo07goool008[oool00ol0VOooooooo`02oooo00<0000co`0c
o`003S?o00030000oooooooo07goool008[oool00ol0VOooooooo`02oooo00<0000co`0co`003C?o
00030000oooooooo07koool008Ooool400001?ooo`030000<ol0<ol000dco`000`000?ooooooo`1n
oooo0027oooo00@0003ooooooooo09T4oooo00<0000co`0co`003C?o00030000oooooooo07koool0
08Soool00`000?ooool0V@04oooo0`0000dco`000`000?ooooooo`1noooo0029oooo00<0003o09Wo
ool00oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0033?o00030000oooooooo07ooool008Soool2000000?o09Woooooool00_oo
o`030000<ol0<ol000`co`000`000?ooooooo`1ooooo002:oooo00?o09Woooooool00_ooo`030000
<ol0<ol000`co`000`000?ooooooo`1ooooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol0
00`co`000`000?ooooooo`1ooooo002:oooo00?o09Woooooool00_ooo`80000=<ol000<0003ooooo
ool0Ooooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000<<ol000<0003oooooool0Oooo
o`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00R_oo
o`03o`2Ioooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00R_ooo`03o`2I
oooooooo00;oool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00R_ooo`03o`2Ioooooooo
00;oool00`0003?o03?o000;<ol000<0003oooooool0P?ooo`00R_ooo`03o`2Ioooooooo00;oool0
0`0003?o03?o000;<ol000<0003oooooool0P?ooo`00R_ooo`03o`2Ioooooooo00;oool2000033?o
00030000oooooooo083oool008[oool00ol0VOooooooo`02oooo00<0000co`0co`002c?o00030000
oooooooo083oool008[oool00ol0VOooooooo`02oooo00<0000co`0co`002S?o00030000oooooooo
087oool008[oool00ol0VOooooooo`02oooo00<0000co`0co`002S?o00030000oooooooo087oool0
08[oool00ol0VOooooooo`02oooo00<0000co`0co`002S?o00030000oooooooo087oool008[oool0
0ol0VOooooooo`02oooo00<0000co`0co`002S?o00030000oooooooo087oool008[oool00ol0VOoo
ooooo`02oooo0P0000/co`000`000?ooooooo`21oooo002:oooo00?o09Woooooool00_ooo`030000
<ol0<ol000Xco`000`000?ooooooo`21oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol0
00Xco`000`000?ooooooo`21oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol000Tco`00
0`000?ooooooo`22oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol000Tco`000`000?oo
ooooo`22oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol000Tco`000`000?ooooooo`22
oooo002:oooo00?o09Woooooool00_ooo`80000:<ol000<0003oooooool0P_ooo`00R_ooo`03o`2I
oooooooo00;oool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00R_ooo`03o`2Ioooooooo
00;oool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00R_ooo`03o`2Ioooooooo00;oool0
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00R?ooo`8000000ol0VOooooooo`02oooo00<0
000co`0co`0023?o00030000oooooooo08?oool008Ooool010000?ooooooo`0000Coool00`0003?o
03?o0008<ol000<0003oooooool0Poooo`00ROooo`030000o`2Ioooo00?oool3000023?o00030000
oooooooo08?oool008[oool00`000?ooooooo`02oooo00<0000co`0co`0023?o00030000oooooooo
08?oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00R?ooo`8000000ol0VOooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo08Coool0
08[oool00ol0VOooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo08Coool008[oool0
0ol0VOooooooo`02oooo00<0000co`0co`001c?o00030000oooooooo08Coool008[oool00ol0VOoo
ooooo`02oooo00<0000co`0co`001c?o00030000oooooooo08Coool008[oool00ol0VOooooooo`02
oooo0P0000Pco`000`000?ooooooo`24oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol0
00Lco`000`000?ooooooo`24oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol000Lco`00
0`000?ooooooo`24oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol000Lco`000`000?oo
ooooo`24oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol000Hco`000`000?ooooooo`25
oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo002:
oooo00?o09Woooooool00_ooo`800007<ol000<0003oooooool0QOooo`00R_ooo`03o`2Ioooooooo
00;oool00`0003?o03?o0006<ol000<0003oooooool0QOooo`00R_ooo`03o`2Ioooooooo00;oool0
0`0003?o03?o0006<ol000<0003oooooool0QOooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o
03?o0006<ol000<0003oooooool0QOooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00R_ooo`03o`2Ioooooooo00;oool00`0003?o03?o0006<ol000<0
003oooooool0QOooo`00R_ooo`03o`2Ioooooooo00;oool200001S?o00030000oooooooo08Koool0
08[oool00ol0VOooooooo`02oooo00<0000co`0co`001C?o00030000oooooooo08Koool008[oool0
0ol0VOooooooo`02oooo00<0000co`0co`001C?o00030000oooooooo08Koool008[oool00ol0VOoo
ooooo`02oooo00<0000co`0co`001C?o00030000oooooooo08Koool008[oool00ol0VOooooooo`02
oooo00<0000co`0co`001C?o00030000oooooooo08Koool008[oool00ol0VOooooooo`02oooo00<0
000co`0co`001C?o00030000oooooooo08Koool008[oool00ol0VOooooooo`02oooo0P0000Hco`00
0`000?ooooooo`26oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol000Dco`000`000?ooooooo`26
oooo002:oooo00?o09Woooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo002:
oooo00?o09Woooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`27oooo0029oooo0`00
00?oool00`0003?o03?o0004<ol000<0003oooooool0Qoooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o0004<ol000<0003oooooool0Qoooo`00Qoooo`D00003oooo0`0000@co`000`000?oo
ooooo`27oooo0027oooo00@0003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004
oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_oo
o`00NOooo`030000oooooooo01?oool7<ol03_ooo`030000oooooooo07Woool007Soool00`000?oo
ooooo`08oooo00<0003oooooool02Oooo`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Ooool2000013?o008000000c?o0?ooooooo`03
00000oooo`@00003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00001S?o00Coool01@000?oo
ooooooooo`000006oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0=oooo00@0003oooooool00006<ol00oooo`<00003oooo00<0003oooooool01?ooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00001S?o00;oool0
10000?ooooooo`0000Coool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000ooool010000?ooooooo`0000Hco`02oooo00@0003oooooool00002oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200001c?o
00?oool300000oooo`800003oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o
08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.94) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47106 .12361 L
.47994 .12361 L
.48231 .12361 L
.48361 .12361 L
.48484 .12361 L
.48554 .12361 L
s
.48554 .12361 m
.48584 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.94) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Goool01Ol0VOooooooooooo`00000;<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_oo
o`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000
oooooooo03Goool01Ol0VOooooooooooo`00000k<ol02@0003Coool00`000?ooooooo`0Eoooo002;
oooo00Go09Woooooooooool00000=C?o00H0001Eoooo002;oooo00Go09Woooooooooool00000<c?o
0080001Koooo002;oooo00Go09Woooooooooool00000<C?o0080001Moooo002;oooo00Go09Wooooo
ooooool00000;S?o00<0001Ooooo002;oooo00Co09Woooooooooool20000:S?o00<0001Roooo002;
oooo00Go09Woooooooooool00000:C?o0080001Uoooo002;oooo00Go09Woooooooooool00000:3?o
00030000oooooooo06Goool008_oool01Ol0VOooooooooooo`00000W<ol000<0003oooooool0I_oo
o`00Roooo`05o`2Ioooooooooooo000002Hco`000`000?ooooooo`1Woooo002;oooo00Go09Wooooo
ooooool0000093?o0080001Zoooo002;oooo00Co09Woooooooooool200008S?o00030000oooooooo
06[oool008_oool01Ol0VOooooooooooo`00000R<ol000<0003oooooool0Joooo`00Roooo`05o`2I
oooooooooooo0000024co`000`000?ooooooo`1/oooo002;oooo00Go09Woooooooooool000008C?o
00030000oooooooo06coool008_oool01Ol0VOooooooooooo`00000P<ol000<0003oooooool0KOoo
o`00Roooo`05o`2Ioooooooooooo000001lco`000`000?ooooooo`1^oooo002;oooo00Co09Wooooo
ooooool200007C?o00030000oooooooo06ooool008_oool01Ol0VOooooooooooo`00000M<ol000<0
003oooooool0L?ooo`00Roooo`05o`2Ioooooooooooo000001dco`000`000?ooooooo`1`oooo002;
oooo00Go09Woooooooooool0000073?o00030000oooooooo077oool008_oool01Ol0VOoooooooooo
o`00000L<ol000<0003oooooool0LOooo`00Roooo`05o`2Ioooooooooooo000001/co`000`000?oo
ooooo`1boooo002;oooo00Co09Woooooooooool200006S?o00030000oooooooo07;oool008_oool0
1Ol0VOooooooooooo`00000J<ol000<0003oooooool0Loooo`00Roooo`05o`2Ioooooooooooo0000
01Xco`000`000?ooooooo`1coooo002;oooo00Go09Woooooooooool000006C?o00030000oooooooo
07Coool008_oool01Ol0VOooooooooooo`00000I<ol000<0003oooooool0M?ooo`00Qoooo`D00003
oooo00<0000co`0co`005S?o00030000oooooooo07Goool008Woool00`000?ooool0V@03oooo00<0
000co`0co`005S?o00030000oooooooo07Goool008Woool00`000?ooool0V@03oooo0`0001Dco`00
0`000?ooooooo`1foooo0029oooo00<0003ooooo09T00oooo`030000<ol0<ol001Dco`000`000?oo
ooooo`1foooo0029oooo00<0003ooooo09T00oooo`030000<ol0<ol001Dco`000`000?ooooooo`1f
oooo0028oooo0P000003ooooo`2Ioooo00;oool00`0003?o03?o000D<ol000<0003oooooool0Mooo
o`00Roooo`05o`2Ioooooooooooo000001Hco`000`000?ooooooo`1goooo002;oooo00Go09Wooooo
ooooool000005C?o00030000oooooooo07Soool008_oool01?l0VOooooooooooo`80000D<ol000<0
003oooooool0N?ooo`00Roooo`05o`2Ioooooooooooo000001Dco`000`000?ooooooo`1hoooo002;
oooo00Go09Woooooooooool0000053?o00030000oooooooo07Woool008_oool01Ol0VOoooooooooo
o`00000D<ol000<0003oooooool0NOooo`00Roooo`05o`2Ioooooooooooo000001@co`000`000?oo
ooooo`1ioooo002;oooo00Go09Woooooooooool000004c?o00030000oooooooo07[oool008_oool0
1?l0VOooooooooooo`80000B<ol000<0003oooooool0N_ooo`00Roooo`05o`2Ioooooooooooo0000
01<co`000`000?ooooooo`1joooo002;oooo00Go09Woooooooooool000004c?o00030000oooooooo
07[oool008_oool01Ol0VOooooooooooo`00000B<ol000<0003oooooool0Noooo`00Roooo`05o`2I
oooooooooooo0000018co`000`000?ooooooo`1koooo002;oooo00Go09Woooooooooool000004S?o
00030000oooooooo07_oool008_oool01Ol0VOooooooooooo`00000B<ol000<0003oooooool0Nooo
o`00Roooo`04o`2Ioooooooooooo0P00010co`000`000?ooooooo`1loooo002;oooo00Go09Wooooo
ooooool000004C?o00030000oooooooo07coool008_oool01Ol0VOooooooooooo`00000A<ol000<0
003oooooool0O?ooo`00Roooo`05o`2Ioooooooooooo0000014co`000`000?ooooooo`1loooo002;
oooo00Go09Woooooooooool000004C?o00030000oooooooo07coool008_oool01Ol0VOoooooooooo
o`00000@<ol000<0003oooooool0OOooo`00Roooo`04o`2Ioooooooooooo0P0000lco`000`000?oo
ooooo`1moooo002;oooo00Go09Woooooooooool0000043?o00030000oooooooo07goool008_oool0
1Ol0VOooooooooooo`00000@<ol000<0003oooooool0OOooo`00Roooo`05o`2Ioooooooooooo0000
00lco`000`000?ooooooo`1noooo0027oooo10000005o`2Ioooooooooooo000000lco`000`000?oo
ooooo`1noooo0027oooo00D0003ooooooooooooo09T00oooo`030000<ol0<ol000dco`000`000?oo
ooooo`1noooo0028oooo00@0003ooooooooo09T3oooo0`0000dco`000`000?ooooooo`1noooo0029
oooo00<0003ooooo09T00oooo`030000<ol0<ol000dco`000`000?ooooooo`1noooo0027oooo00D0
003oooooool0003o09T00oooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0028oooo0P00
0003ooooo`2Ioooo00;oool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00Roooo`05o`2I
oooooooooooo000000hco`000`000?ooooooo`1ooooo002;oooo00Go09Woooooooooool000003S?o
00030000oooooooo07ooool008_oool01?l0VOooooooooooo`80000=<ol000<0003oooooool0Oooo
o`00Roooo`05o`2Ioooooooooooo000000hco`000`000?ooooooo`1ooooo002;oooo00Go09Wooooo
ooooool000003C?o00030000oooooooo083oool008_oool01Ol0VOooooooooooo`00000=<ol000<0
003oooooool0P?ooo`00Roooo`05o`2Ioooooooooooo000000dco`000`000?ooooooo`20oooo002;
oooo00Go09Woooooooooool000003C?o00030000oooooooo083oool008_oool01Ol0VOoooooooooo
o`00000=<ol000<0003oooooool0P?ooo`00Roooo`04o`2Ioooooooooooo0P0000`co`000`000?oo
ooooo`20oooo002;oooo00Go09Woooooooooool000003C?o00030000oooooooo083oool008_oool0
1Ol0VOooooooooooo`00000<<ol000<0003oooooool0POooo`00Roooo`05o`2Ioooooooooooo0000
00`co`000`000?ooooooo`21oooo002;oooo00Go09Woooooooooool0000033?o00030000oooooooo
087oool008_oool01Ol0VOooooooooooo`00000<<ol000<0003oooooool0POooo`00Roooo`04o`2I
oooooooooooo0P0000/co`000`000?ooooooo`21oooo002;oooo00Go09Woooooooooool0000033?o
00030000oooooooo087oool008_oool01Ol0VOooooooooooo`00000<<ol000<0003oooooool0POoo
o`00Roooo`05o`2Ioooooooooooo000000/co`000`000?ooooooo`22oooo002;oooo00Go09Wooooo
ooooool000002c?o00030000oooooooo08;oool008_oool01Ol0VOooooooooooo`00000;<ol000<0
003oooooool0P_ooo`00Roooo`04o`2Ioooooooooooo0P0000Xco`000`000?ooooooo`22oooo002;
oooo00Go09Woooooooooool000002c?o00030000oooooooo08;oool008_oool01Ol0VOoooooooooo
o`00000;<ol000<0003oooooool0P_ooo`00Roooo`05o`2Ioooooooooooo000000Xco`000`000?oo
ooooo`23oooo0028oooo0P000003ooooo`2Ioooo00;oool00`0003?o03?o0008<ol000<0003ooooo
ool0Poooo`00Qoooo`050000oooooooo0000o`2I00?oool00`0003?o03?o0008<ol000<0003ooooo
ool0Poooo`00ROooo`030000ooooo`2I00?oool3000023?o00030000oooooooo08?oool008[oool0
0`000?l0VOooo`02oooo00<0000co`0co`0023?o00030000oooooooo08?oool008Ooool01@000?oo
ooooo`000?l0V@03oooo00<0000co`0co`0023?o00030000oooooooo08?oool008Soool2000000?o
oooo09Woool00_ooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo002;oooo00Go09Wooooo
ooooool000002C?o00030000oooooooo08Coool008_oool01Ol0VOooooooooooo`000009<ol000<0
003oooooool0Q?ooo`00Roooo`05o`2Ioooooooooooo000000Tco`000`000?ooooooo`24oooo002;
oooo00Co09Woooooooooool2000023?o00030000oooooooo08Coool008_oool01Ol0VOoooooooooo
o`000009<ol000<0003oooooool0Q?ooo`00Roooo`05o`2Ioooooooooooo000000Tco`000`000?oo
ooooo`24oooo002;oooo00Go09Woooooooooool000002C?o00030000oooooooo08Coool008_oool0
1Ol0VOooooooooooo`000008<ol000<0003oooooool0QOooo`00Roooo`05o`2Ioooooooooooo0000
00Pco`000`000?ooooooo`25oooo002;oooo00Co09Woooooooooool200001c?o00030000oooooooo
08Goool008_oool01Ol0VOooooooooooo`000008<ol000<0003oooooool0QOooo`00Roooo`05o`2I
oooooooooooo000000Pco`000`000?ooooooo`25oooo002;oooo00Go09Woooooooooool0000023?o
00030000oooooooo08Goool008_oool01Ol0VOooooooooooo`000008<ol000<0003oooooool0QOoo
o`00Roooo`05o`2Ioooooooooooo000000Pco`000`000?ooooooo`25oooo002;oooo00Co09Wooooo
ooooool200001S?o00030000oooooooo08Koool008_oool01Ol0VOooooooooooo`000007<ol000<0
003oooooool0Q_ooo`00Roooo`05o`2Ioooooooooooo000000Lco`000`000?ooooooo`26oooo002;
oooo00Go09Woooooooooool000001c?o00030000oooooooo08Koool008_oool01Ol0VOoooooooooo
o`000007<ol000<0003oooooool0Q_ooo`00Roooo`05o`2Ioooooooooooo000000Lco`000`000?oo
ooooo`26oooo002;oooo00Co09Woooooooooool200001S?o00030000oooooooo08Koool008_oool0
1Ol0VOooooooooooo`000007<ol000<0003oooooool0Q_ooo`00Roooo`05o`2Ioooooooooooo0000
00Lco`000`000?ooooooo`26oooo002;oooo00Go09Woooooooooool000001S?o00030000oooooooo
08Ooool008_oool01Ol0VOooooooooooo`000006<ol000<0003oooooool0Qoooo`00ROooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo08Ooool008[oool00`000?l0VOooo`02oooo00<0
000co`0co`0013?o00030000oooooooo08Ooool008Ooool500000oooo`<00004<ol000<0003ooooo
ool0Qoooo`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?oo
o`Lco`2:oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool0
07Woool00`000?ooooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000@co`02000000<co`3oooooool00`00
00Goool300000_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Hco`04oooo00<0003ooooo
ool01?ooo`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003ooooo
ool03Oooo`040000oooooooo00001S?o00?oool300000_ooo`D00003oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00006<ol00_ooo`040000oooooooo
00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`00000?oooo00@0003oooooool00006<ol00_ooo`040000oooooooo00000oooo`030000oooo0000
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007<ol00oooo`<00004
oooo0P0000;oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.96) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47994 .12361 L
.48519 .12361 L
.48778 .12361 L
.48904 .12361 L
.49018 .12361 L
s
.49018 .12361 m
.49063 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.96) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Koool01?l0VOooooooo`0000/co`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0
003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003ooooo
ool0=_ooo`04o`2Ioooooooo0000>c?o00T0000doooo00<0003oooooool05Oooo`00S?ooo`04o`2I
oooooooo0000=C?o00H0001Eoooo002<oooo00Co09Woooooool0000c<ol00P0005_oool008coool0
1?l0VOooooooo`00034co`020000GOooo`00S?ooo`04o`2Ioooooooo0000;S?o00<0001Ooooo002<
oooo00?o09Woooooool00P0002Xco`030000H_ooo`00S?ooo`04o`2Ioooooooo0000:C?o0080001U
oooo002<oooo00Co09Woooooool0000X<ol000<0003oooooool0IOooo`00S?ooo`04o`2Ioooooooo
00009c?o00030000oooooooo06Koool008coool01?l0VOooooooo`0002Hco`000`000?ooooooo`1W
oooo002<oooo00Co09Woooooool0000T<ol00P0006[oool008coool00ol0VOooooooo`0200008S?o
00030000oooooooo06[oool008coool01?l0VOooooooo`00028co`000`000?ooooooo`1[oooo002<
oooo00Co09Woooooool0000Q<ol000<0003oooooool0K?ooo`00S?ooo`04o`2Ioooooooo00008C?o
00030000oooooooo06coool008coool01?l0VOooooooo`00020co`000`000?ooooooo`1]oooo002<
oooo00Co09Woooooool0000O<ol000<0003oooooool0K_ooo`00S?ooo`03o`2Ioooooooo0080000M
<ol000<0003oooooool0Koooo`00S?ooo`04o`2Ioooooooo00007C?o00030000oooooooo073oool0
08coool01?l0VOooooooo`0001dco`000`000?ooooooo`1`oooo002<oooo00Co09Woooooool0000L
<ol000<0003oooooool0LOooo`00S?ooo`04o`2Ioooooooo000073?o00030000oooooooo077oool0
08coool01?l0VOooooooo`0001/co`000`000?ooooooo`1boooo002<oooo00?o09Woooooool00P00
01Xco`000`000?ooooooo`1boooo002<oooo00Co09Woooooool0000J<ol000<0003oooooool0Looo
o`00S?ooo`04o`2Ioooooooo00006S?o00030000oooooooo07?oool008coool01?l0VOooooooo`00
01Tco`000`000?ooooooo`1doooo002<oooo00Co09Woooooool0000I<ol000<0003oooooool0M?oo
o`00Qoooo`D000001?l0VOooooooo`0001Pco`000`000?ooooooo`1eoooo0029oooo00@0003ooooo
oooo09T2oooo00<0000co`0co`005S?o00030000oooooooo07Goool008Woool010000?ooooooool0
V@;oool300005C?o00030000oooooooo07Koool008Woool010000?ooooooool0V@;oool00`0003?o
03?o000E<ol000<0003oooooool0M_ooo`00ROooo`040000ooooooooo`2I0_ooo`030000<ol0<ol0
01Dco`000`000?ooooooo`1foooo0028oooo0P0000;oool01?l0VOooooooo`0001Hco`000`000?oo
ooooo`1goooo002<oooo00Co09Woooooool0000F<ol000<0003oooooool0Moooo`00S?ooo`04o`2I
oooooooo00005C?o00030000oooooooo07Soool008coool00ol0VOooooooo`02000053?o00030000
oooooooo07Soool008coool01?l0VOooooooo`0001Dco`000`000?ooooooo`1hoooo002<oooo00Co
09Woooooool0000D<ol000<0003oooooool0NOooo`00S?ooo`04o`2Ioooooooo000053?o00030000
oooooooo07Woool008coool01?l0VOooooooo`0001@co`000`000?ooooooo`1ioooo002<oooo00Co
09Woooooool0000C<ol000<0003oooooool0N_ooo`00S?ooo`03o`2Ioooooooo0080000B<ol000<0
003oooooool0N_ooo`00S?ooo`04o`2Ioooooooo00004c?o00030000oooooooo07[oool008coool0
1?l0VOooooooo`0001<co`000`000?ooooooo`1joooo002<oooo00Co09Woooooool0000B<ol000<0
003oooooool0Noooo`00S?ooo`04o`2Ioooooooo00004S?o00030000oooooooo07_oool008coool0
1?l0VOooooooo`00018co`000`000?ooooooo`1koooo002<oooo00Co09Woooooool0000B<ol000<0
003oooooool0Noooo`00S?ooo`03o`2Ioooooooo0080000@<ol000<0003oooooool0O?ooo`00S?oo
o`04o`2Ioooooooo00004C?o00030000oooooooo07coool008coool01?l0VOooooooo`00014co`00
0`000?ooooooo`1loooo002<oooo00Co09Woooooool0000A<ol000<0003oooooool0O?ooo`00S?oo
o`04o`2Ioooooooo00004C?o00030000oooooooo07coool008coool01?l0VOooooooo`00010co`00
0`000?ooooooo`1moooo002<oooo00?o09Woooooool00P0000lco`000`000?ooooooo`1moooo002<
oooo00Co09Woooooool0000@<ol000<0003oooooool0OOooo`00S?ooo`04o`2Ioooooooo000043?o
00030000oooooooo07goool008coool01?l0VOooooooo`0000lco`000`000?ooooooo`1noooo0027
oooo10000005ooooo`2Ioooooooo000000lco`000`000?ooooooo`1noooo0027oooo00<0003ooooo
ool00_ooo`04o`2Ioooooooo00003c?o00030000oooooooo07koool008Soool01@000?oooooooooo
ool0V@02oooo0`0000dco`000`000?ooooooo`1noooo0029oooo00L0003ooooooooooooo09Woool0
00003c?o00030000oooooooo07koool008Ooool010000?ooooooo`0000;oool00ol0VOooo`00000>
<ol000<0003oooooool0Ooooo`00R?ooo`800003oooo00?o09Woool000003S?o00030000oooooooo
07ooool008goool00ol0VOooo`00000><ol000<0003oooooool0Ooooo`00SOooo`03o`2Ioooo0000
00hco`000`000?ooooooo`1ooooo002=oooo00Co09Woool00000000=<ol000<0003oooooool0Oooo
o`00SOooo`03o`2Ioooo000000hco`000`000?ooooooo`1ooooo002=oooo00?o09Woool000003C?o
00030000oooooooo083oool008goool00ol0VOooo`00000=<ol000<0003oooooool0P?ooo`00SOoo
o`03o`2Ioooo000000dco`000`000?ooooooo`20oooo002=oooo00?o09Woool000003C?o00030000
oooooooo083oool008goool00ol0VOooo`00000=<ol000<0003oooooool0P?ooo`00SOooo`04o`2I
oooo0000000033?o00030000oooooooo083oool008goool00ol0VOooo`00000=<ol000<0003ooooo
ool0P?ooo`00SOooo`03o`2Ioooo000000`co`000`000?ooooooo`21oooo002=oooo00?o09Woool0
000033?o00030000oooooooo087oool008goool00ol0VOooo`00000<<ol000<0003oooooool0POoo
o`00SOooo`03o`2Ioooo000000`co`000`000?ooooooo`21oooo002=oooo00Co09Woool00000000;
<ol000<0003oooooool0POooo`00SOooo`03o`2Ioooo000000`co`000`000?ooooooo`21oooo002=
oooo00?o09Woool0000033?o00030000oooooooo087oool008goool00ol0VOooo`00000;<ol000<0
003oooooool0P_ooo`00SOooo`03o`2Ioooo000000/co`000`000?ooooooo`22oooo002=oooo00?o
09Woool000002c?o00030000oooooooo08;oool008goool01?l0VOooo`00000000Xco`000`000?oo
ooooo`22oooo002=oooo00?o09Woool000002c?o00030000oooooooo08;oool008goool00ol0VOoo
o`00000;<ol000<0003oooooool0P_ooo`00SOooo`03o`2Ioooo000000Xco`000`000?ooooooo`23
oooo0028oooo0P0000?oool00ol0VOooo`00000:<ol000<0003oooooool0Poooo`00Qoooo`040000
oooooooo00000_ooo`03o`2Ioooo000000Xco`000`000?ooooooo`23oooo0029oooo00H0003ooooo
oooooooo09Woool3000023?o00030000oooooooo08?oool008[oool01P000?ooooooool0VOooo`00
00Xco`000`000?ooooooo`23oooo0027oooo00@0003oooooool00002oooo00?o09Woool000002S?o
00030000oooooooo08?oool008Soool200000oooo`03o`2Ioooo000000Tco`000`000?ooooooo`24
oooo002=oooo00?o09Woool000002C?o00030000oooooooo08Coool008goool00ol0VOooo`000009
<ol000<0003oooooool0Q?ooo`00SOooo`03o`2Ioooo000000Tco`000`000?ooooooo`24oooo002=
oooo00Co09Woool000000008<ol000<0003oooooool0Q?ooo`00SOooo`03o`2Ioooo000000Tco`00
0`000?ooooooo`24oooo002=oooo00?o09Woool000002C?o00030000oooooooo08Coool008goool0
0ol0VOooo`000009<ol000<0003oooooool0Q?ooo`00SOooo`03o`2Ioooo000000Pco`000`000?oo
ooooo`25oooo002=oooo00?o09Woool0000023?o00030000oooooooo08Goool008goool01?l0VOoo
o`00000000Lco`000`000?ooooooo`25oooo002=oooo00?o09Woool0000023?o00030000oooooooo
08Goool008goool00ol0VOooo`000008<ol000<0003oooooool0QOooo`00SOooo`03o`2Ioooo0000
00Pco`000`000?ooooooo`25oooo002=oooo00?o09Woool0000023?o00030000oooooooo08Goool0
08goool00ol0VOooo`000008<ol000<0003oooooool0QOooo`00SOooo`04o`2Ioooo000000001S?o
00030000oooooooo08Koool008goool00ol0VOooo`000007<ol000<0003oooooool0Q_ooo`00SOoo
o`03o`2Ioooo000000Lco`000`000?ooooooo`26oooo002=oooo00?o09Woool000001c?o00030000
oooooooo08Koool008goool00ol0VOooo`000007<ol000<0003oooooool0Q_ooo`00SOooo`03o`2I
oooo000000Lco`000`000?ooooooo`26oooo002=oooo00Co09Woool000000006<ol000<0003ooooo
ool0Q_ooo`00SOooo`03o`2Ioooo000000Lco`000`000?ooooooo`26oooo002=oooo00?o09Woool0
00001c?o00030000oooooooo08Koool008goool00ol0VOooo`000006<ol000<0003oooooool0Qooo
o`00SOooo`03o`2Ioooo000000Hco`000`000?ooooooo`27oooo0029oooo0`000004ooooo`2Ioooo
00001S?o00030000oooooooo08Ooool008[oool01P000?ooooooool0VOooo`0000Hco`000`000?oo
ooooo`27oooo0027oooo1@000003ooooo`2Ioooo00<00004<ol000<0003oooooool0Qoooo`00Qooo
o`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029
oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?oo
ooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000@co`02000000<co`3oooooool00`0000?oool300001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool010000?ooooooo`0000Hco`04oooo00D0003oooooooooool000000_oo
o`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Ooo
o`040000oooooooo00001S?o00?oool300000_ooo`040000oooooooo00001?ooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00001S?o00;oool010000?oo
ooooo`0000;oool300001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?
oooo00@0003oooooool00006<ol00_ooo`040000oooooooo00000oooo`030000oooooooo00?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007<ol00oooo`<00003oooo0`00
00;oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.98) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47994 .12361 L
.48519 .12361 L
.49018 .12361 L
.49235 .12361 L
.49354 .12361 L
.49466 .12361 L
s
.49466 .12361 m
.49492 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.98) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Soool00ol0V@0003?o000:<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
03Soool00ol0V@0003?o000j<ol02@0003Coool00`000?ooooooo`0Eoooo002>oooo00?o09T0000c
o`00=3?o00H0001Eoooo002>oooo00?o09T0000co`00<S?o0080001Koooo002>oooo00?o09T0000c
o`00<3?o0080001Moooo002>oooo00?o09T0000co`00;C?o00<0001Ooooo002>oooo00?o09T00000
0000:S?o00<0001Roooo002>oooo00?o09T0000co`00:3?o0080001Uoooo002>oooo00?o09T0000c
o`009c?o00030000oooooooo06Goool008koool00ol0V@0003?o000V<ol000<0003oooooool0I_oo
o`00S_ooo`03o`2I0000<ol002Dco`000`000?ooooooo`1Woooo002>oooo00?o09T0000co`008c?o
0080001Zoooo002>oooo00?o09T0000000008S?o00030000oooooooo06[oool008koool00ol0V@00
03?o000Q<ol000<0003oooooool0Joooo`00S_ooo`03o`2I0000<ol0020co`000`000?ooooooo`1/
oooo002>oooo00?o09T0000co`0083?o00030000oooooooo06coool008koool00ol0V@0003?o000O
<ol000<0003oooooool0KOooo`00S_ooo`03o`2I0000<ol001hco`000`000?ooooooo`1^oooo002>
oooo00?o09T0000000007C?o00030000oooooooo06ooool008koool00ol0V@0003?o000L<ol000<0
003oooooool0L?ooo`00S_ooo`03o`2I0000<ol001`co`000`000?ooooooo`1`oooo002>oooo00?o
09T0000co`006c?o00030000oooooooo077oool008koool00ol0V@0003?o000K<ol000<0003ooooo
ool0LOooo`00S_ooo`03o`2I0000<ol001Xco`000`000?ooooooo`1boooo002>oooo00?o09T00000
00006S?o00030000oooooooo07;oool008koool00ol0V@0003?o000I<ol000<0003oooooool0Looo
o`00S_ooo`03o`2I0000<ol001Tco`000`000?ooooooo`1coooo002>oooo00?o09T0000co`0063?o
00030000oooooooo07Coool008koool00ol0V@0003?o000H<ol000<0003oooooool0M?ooo`00Qooo
o`D00002oooo00?o09T0000co`005c?o00030000oooooooo07Goool008Woool00`000?ooooooo`02
oooo00?o09T0000co`005c?o00030000oooooooo07Goool008Woool00`000?ooooooo`02oooo00Co
09T000000000000E<ol000<0003oooooool0M_ooo`00ROooo`030000oooooooo00;oool00ol0V@00
03?o000F<ol000<0003oooooool0M_ooo`00ROooo`030000oooooooo00;oool00ol0V@0003?o000F
<ol000<0003oooooool0M_ooo`00R?ooo`800004oooo00?o09T0000co`005C?o00030000oooooooo
07Ooool008koool00ol0V@0003?o000E<ol000<0003oooooool0Moooo`00S_ooo`03o`2I0000<ol0
01@co`000`000?ooooooo`1hoooo002>oooo00?o09T00000000053?o00030000oooooooo07Soool0
08koool00ol0V@0003?o000D<ol000<0003oooooool0N?ooo`00S_ooo`03o`2I0000<ol001<co`00
0`000?ooooooo`1ioooo002>oooo00?o09T0000co`004c?o00030000oooooooo07Woool008koool0
0ol0V@0003?o000C<ol000<0003oooooool0NOooo`00S_ooo`03o`2I0000<ol0018co`000`000?oo
ooooo`1joooo002>oooo00?o09T0000000004S?o00030000oooooooo07[oool008koool00ol0V@00
03?o000B<ol000<0003oooooool0N_ooo`00S_ooo`03o`2I0000<ol0018co`000`000?ooooooo`1j
oooo002>oooo00?o09T0000co`004C?o00030000oooooooo07_oool008koool00ol0V@0003?o000A
<ol000<0003oooooool0Noooo`00S_ooo`03o`2I0000<ol0014co`000`000?ooooooo`1koooo002>
oooo00?o09T0000co`004C?o00030000oooooooo07_oool008koool00ol0V@000000000@<ol000<0
003oooooool0O?ooo`00S_ooo`03o`2I0000<ol0010co`000`000?ooooooo`1loooo002>oooo00?o
09T0000co`0043?o00030000oooooooo07coool008koool00ol0V@0003?o000@<ol000<0003ooooo
ool0O?ooo`00S_ooo`03o`2I0000<ol0010co`000`000?ooooooo`1loooo002>oooo00?o09T0000c
o`003c?o00030000oooooooo07goool008koool00ol0V@000000000?<ol000<0003oooooool0OOoo
o`00S_ooo`03o`2I0000<ol000lco`000`000?ooooooo`1moooo002>oooo00?o09T0000co`003c?o
00030000oooooooo07goool008koool00ol0V@0003?o000><ol000<0003oooooool0O_ooo`00Qooo
o`@00003oooo00?o09T0000co`003S?o00030000oooooooo07koool008Ooool00`000?ooooooo`04
oooo00?o09T0000co`003S?o00030000oooooooo07koool008Soool00`000?ooooooo`03oooo00Co
09T000000000000=<ol000<0003oooooool0O_ooo`00ROooo`030000oooooooo00;oool00ol0V@00
03?o000><ol000<0003oooooool0O_ooo`00Qoooo`040000oooooooo00000oooo`03o`2I0000<ol0
00dco`000`000?ooooooo`1ooooo0028oooo0P0000Coool00ol0V@0003?o000=<ol000<0003ooooo
ool0Ooooo`00S_ooo`03o`2I0000<ol000dco`000`000?ooooooo`1ooooo002>oooo00?o09T0000c
o`003C?o00030000oooooooo07ooool008koool00ol0V@000000000=<ol000<0003oooooool0Oooo
o`00S_ooo`03o`2I0000<ol000dco`000`000?ooooooo`1ooooo002>oooo00?o09T0000co`0033?o
00030000oooooooo083oool008koool00ol0V@0003?o000<<ol000<0003oooooool0P?ooo`00S_oo
o`03o`2I0000<ol000`co`000`000?ooooooo`20oooo002>oooo00?o09T0000co`0033?o00030000
oooooooo083oool008koool00ol0V@0003?o000<<ol000<0003oooooool0P?ooo`00S_ooo`03o`2I
0000000000`co`000`000?ooooooo`20oooo002>oooo00?o09T0000co`0033?o00030000oooooooo
083oool008koool00ol0V@0003?o000;<ol000<0003oooooool0POooo`00S_ooo`03o`2I0000<ol0
00/co`000`000?ooooooo`21oooo002>oooo00?o09T0000co`002c?o00030000oooooooo087oool0
08koool00ol0V@0003?o000;<ol000<0003oooooool0POooo`00S_ooo`03o`2I0000000000/co`00
0`000?ooooooo`21oooo002>oooo00?o09T0000co`002c?o00030000oooooooo087oool008koool0
0ol0V@0003?o000;<ol000<0003oooooool0POooo`00S_ooo`03o`2I0000<ol000Xco`000`000?oo
ooooo`22oooo002>oooo00?o09T0000co`002S?o00030000oooooooo08;oool008koool00ol0V@00
03?o000:<ol000<0003oooooool0P_ooo`00S_ooo`03o`2I0000000000Xco`000`000?ooooooo`22
oooo002>oooo00?o09T0000co`002S?o00030000oooooooo08;oool008koool00ol0V@0003?o000:
<ol000<0003oooooool0P_ooo`00S_ooo`03o`2I0000<ol000Tco`000`000?ooooooo`23oooo0028
oooo0P0000Coool00ol0V@0003?o0009<ol000<0003oooooool0Poooo`00Qoooo`040000oooooooo
00000oooo`03o`2I0000<ol000Tco`000`000?ooooooo`23oooo0029oooo00<0003oooooool00_oo
o`04o`2I00000000000023?o00030000oooooooo08?oool008[oool01P000?ooooooooooool0V@00
00Xco`000`000?ooooooo`23oooo0027oooo00@0003oooooool00003oooo00?o09T0000co`002C?o
00030000oooooooo08?oool008Soool200001?ooo`03o`2I0000<ol000Pco`000`000?ooooooo`24
oooo002>oooo00?o09T0000co`0023?o00030000oooooooo08Coool008koool00ol0V@0003?o0008
<ol000<0003oooooool0Q?ooo`00S_ooo`03o`2I0000<ol000Pco`000`000?ooooooo`24oooo002>
oooo00?o09T00000000023?o00030000oooooooo08Coool008koool00ol0V@0003?o0008<ol000<0
003oooooool0Q?ooo`00S_ooo`03o`2I0000<ol000Pco`000`000?ooooooo`24oooo002>oooo00?o
09T0000co`0023?o00030000oooooooo08Coool008koool00ol0V@0003?o0007<ol000<0003ooooo
ool0QOooo`00S_ooo`03o`2I0000<ol000Lco`000`000?ooooooo`25oooo002>oooo00?o09T00000
00001c?o00030000oooooooo08Goool008koool00ol0V@0003?o0007<ol000<0003oooooool0QOoo
o`00S_ooo`03o`2I0000<ol000Lco`000`000?ooooooo`25oooo002>oooo00?o09T0000co`001c?o
00030000oooooooo08Goool008koool00ol0V@0003?o0007<ol000<0003oooooool0QOooo`00S_oo
o`03o`2I0000<ol000Lco`000`000?ooooooo`25oooo002>oooo00?o09T0000000001S?o00030000
oooooooo08Koool008koool00ol0V@0003?o0006<ol000<0003oooooool0Q_ooo`00S_ooo`03o`2I
0000<ol000Hco`000`000?ooooooo`26oooo002>oooo00?o09T0000co`001S?o00030000oooooooo
08Koool008koool00ol0V@0003?o0006<ol000<0003oooooool0Q_ooo`00S_ooo`03o`2I0000<ol0
00Hco`000`000?ooooooo`26oooo002>oooo00?o09T0000000001S?o00030000oooooooo08Koool0
08koool00ol0V@0003?o0006<ol000<0003oooooool0Q_ooo`00S_ooo`03o`2I0000<ol000Hco`00
0`000?ooooooo`26oooo002>oooo00?o09T0000co`001C?o00030000oooooooo08Ooool008koool0
0ol0V@0003?o0005<ol000<0003oooooool0Qoooo`00ROooo`<00002oooo00?o09T0000co`001C?o
00030000oooooooo08Ooool008[oool01P000?ooooooooooool0V@0000Hco`000`000?ooooooo`27
oooo0027oooo1@0000;oool01?l0V@000000000000@co`000`000?ooooooo`27oooo0027oooo00@0
003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool2
00001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo
01?oool7<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool02Oooo`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Ooool2000013?o008000000c?o0?ooooooo`0300001?ooo`800004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`040000oooooooo00001S?o00Coool01@000?ooooooooooo`000002oooo00D0
003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0
003oooooool00006<ol00oooo`<00002oooo00@0003oooooool00004oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00006<ol00_ooo`040000oooooooo
00000oooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool0
10000?ooooooo`0000Hco`02oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo017oool200001c?o00?oool300000oooo`800003
oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50007 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.93871 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
03Woool00`0003?o03?o000i<ol02@0003Coool00`000?ooooooo`0Eoooo002?oooo00<0000co`0c
o`00<c?o00H0001Eoooo002?oooo00<0000co`0co`00<C?o0080001Koooo002?oooo00<0000co`0c
o`00;c?o0080001Moooo002?oooo00<0000co`0co`00;3?o00<0001Ooooo002?oooo0P0002Xco`03
0000H_ooo`00Soooo`030000<ol0<ol002Lco`020000IOooo`00Soooo`030000<ol0<ol002Hco`00
0`000?ooooooo`1Uoooo002?oooo00<0000co`0co`009C?o00030000oooooooo06Koool008ooool0
0`0003?o03?o000T<ol000<0003oooooool0Ioooo`00Soooo`030000<ol0<ol0028co`020000J_oo
o`00Soooo`80000R<ol000<0003oooooool0J_ooo`00Soooo`030000<ol0<ol0020co`000`000?oo
ooooo`1[oooo002?oooo00<0000co`0co`007c?o00030000oooooooo06coool008ooool00`0003?o
03?o000O<ol000<0003oooooool0K?ooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`1]
oooo002?oooo00<0000co`0co`007C?o00030000oooooooo06koool008ooool200007C?o00030000
oooooooo06ooool008ooool00`0003?o03?o000K<ol000<0003oooooool0L?ooo`00Soooo`030000
<ol0<ol001/co`000`000?ooooooo`1`oooo002?oooo00<0000co`0co`006S?o00030000oooooooo
077oool008ooool00`0003?o03?o000J<ol000<0003oooooool0LOooo`00Soooo`030000<ol0<ol0
01Tco`000`000?ooooooo`1boooo002?oooo0P0001Xco`000`000?ooooooo`1boooo002?oooo00<0
000co`0co`0063?o00030000oooooooo07?oool008ooool00`0003?o03?o000H<ol000<0003ooooo
ool0Loooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`1doooo002?oooo00<0000co`0c
o`005c?o00030000oooooooo07Coool008Ooool500000oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1eoooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`1e
oooo0029oooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0M_ooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool0M_ooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000E<ol000<0003oooooool0M_ooo`00R?ooo`800005oooo00<0000co`0c
o`0053?o00030000oooooooo07Ooool008ooool00`0003?o03?o000D<ol000<0003oooooool0Mooo
o`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`1hoooo002?oooo0P0001@co`000`000?oo
ooooo`1hoooo002?oooo00<0000co`0co`004c?o00030000oooooooo07Soool008ooool00`0003?o
03?o000B<ol000<0003oooooool0NOooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`1i
oooo002?oooo00<0000co`0co`004S?o00030000oooooooo07Woool008ooool00`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00Soooo`80000B<ol000<0003oooooool0N_ooo`00Soooo`030000
<ol0<ol0014co`000`000?ooooooo`1joooo002?oooo00<0000co`0co`004C?o00030000oooooooo
07[oool008ooool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Soooo`030000<ol0<ol0
010co`000`000?ooooooo`1koooo002?oooo00<0000co`0co`0043?o00030000oooooooo07_oool0
08ooool00`0003?o03?o000@<ol000<0003oooooool0Noooo`00Soooo`80000@<ol000<0003ooooo
ool0O?ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo002?oooo00<0000co`0c
o`003c?o00030000oooooooo07coool008ooool00`0003?o03?o000?<ol000<0003oooooool0O?oo
o`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`1loooo002?oooo00<0000co`0co`003S?o
00030000oooooooo07goool008ooool200003c?o00030000oooooooo07goool008ooool00`0003?o
03?o000><ol000<0003oooooool0OOooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`1m
oooo002?oooo00<0000co`0co`003C?o00030000oooooooo07koool008Ooool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`1noooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol0
00dco`000`000?ooooooo`1noooo0028oooo00<0003oooooool01?ooo`<0000=<ol000<0003ooooo
ool0O_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0O_oo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1ooooo0028
oooo0P0000Goool00`0003?o03?o000<<ol000<0003oooooool0Ooooo`00Soooo`030000<ol0<ol0
00`co`000`000?ooooooo`1ooooo002?oooo00<0000co`0co`0033?o00030000oooooooo07ooool0
08ooool200003C?o00030000oooooooo07ooool008ooool00`0003?o03?o000<<ol000<0003ooooo
ool0Ooooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo002?oooo00<0000co`0c
o`002c?o00030000oooooooo083oool008ooool00`0003?o03?o000;<ol000<0003oooooool0P?oo
o`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`20oooo002?oooo00<0000co`0co`002c?o
00030000oooooooo083oool008ooool2000033?o00030000oooooooo083oool008ooool00`0003?o
03?o000;<ol000<0003oooooool0P?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`21
oooo002?oooo00<0000co`0co`002S?o00030000oooooooo087oool008ooool00`0003?o03?o000:
<ol000<0003oooooool0POooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`21oooo002?
oooo0P0000/co`000`000?ooooooo`21oooo002?oooo00<0000co`0co`002S?o00030000oooooooo
087oool008ooool00`0003?o03?o000:<ol000<0003oooooool0POooo`00Soooo`030000<ol0<ol0
00Tco`000`000?ooooooo`22oooo002?oooo00<0000co`0co`002C?o00030000oooooooo08;oool0
08ooool00`0003?o03?o0009<ol000<0003oooooool0P_ooo`00Soooo`80000:<ol000<0003ooooo
ool0P_ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`22oooo002?oooo00<0000co`0c
o`002C?o00030000oooooooo08;oool008ooool00`0003?o03?o0008<ol000<0003oooooool0Pooo
o`00R?ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo08?oool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0Poooo`00ROooo`030000oooooooo
00?oool3000023?o00030000oooooooo08?oool008[oool00`000?ooooooo`02oooo00<0000co`0c
o`0023?o00030000oooooooo08?oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008
<ol000<0003oooooool0Poooo`00R?ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo
08Coool008ooool00`0003?o03?o0007<ol000<0003oooooool0Q?ooo`00Soooo`030000<ol0<ol0
00Lco`000`000?ooooooo`24oooo002?oooo00<0000co`0co`001c?o00030000oooooooo08Coool0
08ooool2000023?o00030000oooooooo08Coool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool0Q?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`24oooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo08Coool008ooool00`0003?o03?o0006<ol000<0003oooooool0QOoo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`25oooo002?oooo0P0000Lco`000`000?oo
ooooo`25oooo002?oooo00<0000co`0co`001S?o00030000oooooooo08Goool008ooool00`0003?o
03?o0006<ol000<0003oooooool0QOooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`25
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo08Goool008ooool00`0003?o03?o0006
<ol000<0003oooooool0QOooo`00Soooo`800006<ol000<0003oooooool0Q_ooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`26oooo002?oooo00<0000co`0co`001C?o00030000oooooooo
08Koool008ooool00`0003?o03?o0005<ol000<0003oooooool0Q_ooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`26oooo002?oooo00<0000co`0co`001C?o00030000oooooooo08Koool0
08ooool200001S?o00030000oooooooo08Koool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool0Q_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`26oooo002?oooo00<0000co`0c
o`0013?o00030000oooooooo08Ooool008ooool00`0003?o03?o0004<ol000<0003oooooool0Qooo
o`00ROooo`<00003oooo00<0000co`0co`0013?o00030000oooooooo08Ooool008[oool00`000?oo
ooooo`02oooo00<0000co`0co`0013?o00030000oooooooo08Ooool008Ooool500000oooo`<00004
<ol000<0003oooooool0Qoooo`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0
003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?
oooo1c?o08[oool007ooool00`000?ooooooo`0=oooo1c?o00Soool00`000?ooooooo`1ooooo001n
oooo00<0003oooooool02?ooo`030000oooooooo00?oool7<ol02Oooo`030000oooooooo07koool0
07koool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`03oooo0c?o00D00002oooo0P00
00Coool00`000?ooooooo`1noooo001noooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`02oooo1C?o00030000<ol0oooo00Soool00`000?ooooooo`1noooo001m
oooo00<0003oooooool00_ooo`030000oooooooo00[oool5<ol000<0000co`3oool02Oooo`030000
oooooooo07goool007koool00`000?ooooooo`0500002Oooo`Dco`000`0003?o0?ooo`08oooo00<0
003oooooool0O_ooo`00O_ooo`050000oooooooooooo000000coool5<ol000<0000co`3oool02?oo
o`030000oooooooo07koool007ooool00`000?ooooooo`0=oooo13?o008000000c?o0?ooooooo`06
oooo00<0003oooooool0Ooooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49955 .12361 L
.50205 .12361 L
.50342 .12361 L
.50471 .12361 L
s
.50471 .12361 m
.50519 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47994 .12361 L
.48519 .12361 L
.49018 .12361 L
.49235 .12361 L
.49354 .12361 L
.49466 .12361 L
.4953 .12354 L
.49599 .12283 L
.4972 .1216 L
.49955 .11925 L
.50192 .11695 L
.50323 .11571 L
.50447 .11456 L
.50562 .12361 L
.50687 .12361 L
.50906 .12361 L
.51949 .12361 L
.54055 .12361 L
.58134 .12361 L
.6206 .12361 L
.65835 .12361 L
.69856 .12361 L
.73724 .12361 L
.77838 .12361 L
.81801 .12361 L
.85612 .12361 L
.89668 .12361 L
.93572 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<00000I_ooool0S_ooo`00Soooo`030000
06Kooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?l0VC?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
03Woool00`000?l0VC?o000i<ol02@0003Coool00`000?ooooooo`0Eoooo002?oooo00<0003o09Tc
o`00<c?o00H0001Eoooo002?oooo00<0003o09Tco`00<C?o0080001Koooo002?oooo00<0003o09Tc
o`00;c?o0080001Moooo002?oooo00<0003o09Tco`00;3?o00<0001Ooooo002?oooo0P0002Xco`03
0000H_ooo`00Soooo`030000o`2I<ol002Lco`020000IOooo`00Soooo`030000o`2I<ol002Hco`00
0`000?ooooooo`1Uoooo002?oooo00<0003o09Tco`009C?o00030000oooooooo06Koool008ooool0
0`000?l0VC?o000T<ol000<0003oooooool0Ioooo`00Soooo`030000o`2I<ol0028co`020000J_oo
o`00Soooo`80000R<ol000<0003oooooool0J_ooo`00Soooo`030000o`2I<ol0020co`000`000?oo
ooooo`1[oooo002?oooo00<0003o09Tco`007c?o00030000oooooooo06coool008ooool00`000?l0
VC?o000O<ol000<0003oooooool0K?ooo`00Soooo`030000o`2I<ol001hco`000`000?ooooooo`1]
oooo002?oooo00<0003o09Tco`007C?o00030000oooooooo06koool008ooool200007C?o00030000
oooooooo06ooool008ooool00`000?l0VC?o000K<ol000<0003oooooool0L?ooo`00Soooo`030000
o`2I<ol001/co`000`000?ooooooo`1`oooo002?oooo00<0003o09Tco`006S?o00030000oooooooo
077oool008ooool00`000?l0VC?o000J<ol000<0003oooooool0LOooo`00Soooo`030000o`2I<ol0
01Tco`000`000?ooooooo`1boooo002?oooo0P0001Xco`000`000?ooooooo`1boooo002?oooo00<0
003o09Tco`0063?o00030000oooooooo07?oool008ooool00`000?l0VC?o000H<ol000<0003ooooo
ool0Loooo`00Soooo`030000o`2I<ol001Lco`000`000?ooooooo`1doooo002?oooo00<0003o09Tc
o`005c?o00030000oooooooo07Coool008Ooool500000oooo`030000o`2I<ol001Hco`000`000?oo
ooooo`1eoooo0029oooo00<0003oooooool00oooo`030000o`2I<ol001Hco`000`000?ooooooo`1e
oooo0029oooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0M_ooo`00ROooo`030000
oooooooo00?oool00`000?l0VC?o000E<ol000<0003oooooool0M_ooo`00ROooo`030000oooooooo
00?oool00`000?l0VC?o000E<ol000<0003oooooool0M_ooo`00R?ooo`800005oooo00<0003o09Tc
o`0053?o00030000oooooooo07Ooool008ooool00`000?l0VC?o000D<ol000<0003oooooool0Mooo
o`00Soooo`030000o`2I<ol001<co`000`000?ooooooo`1hoooo002?oooo0P0001@co`000`000?oo
ooooo`1hoooo002?oooo00<0003o09Tco`004c?o00030000oooooooo07Soool008ooool00`000?l0
VC?o000B<ol000<0003oooooool0NOooo`00Soooo`030000o`2I<ol0018co`000`000?ooooooo`1i
oooo002?oooo00<0003o09Tco`004S?o00030000oooooooo07Woool008ooool00`000?l0VC?o000A
<ol000<0003oooooool0N_ooo`00Soooo`80000B<ol000<0003oooooool0N_ooo`00Soooo`030000
o`2I<ol0014co`000`000?ooooooo`1joooo002?oooo00<0003o09Tco`004C?o00030000oooooooo
07[oool008ooool00`000?l0VC?o000@<ol000<0003oooooool0Noooo`00Soooo`030000o`2I<ol0
010co`000`000?ooooooo`1koooo002?oooo00<0003o09Tco`0043?o00030000oooooooo07_oool0
08ooool00`000?l0VC?o000@<ol000<0003oooooool0Noooo`00Soooo`80000@<ol000<0003ooooo
ool0O?ooo`00Soooo`030000o`2I<ol000lco`000`000?ooooooo`1loooo002?oooo00<0003o09Tc
o`003c?o00030000oooooooo07coool008ooool00`000?l0VC?o000?<ol000<0003oooooool0O?oo
o`00Soooo`030000o`2I<ol000lco`000`000?ooooooo`1loooo002?oooo00<0003o09Tco`003S?o
00030000oooooooo07goool008ooool200003c?o00030000oooooooo07goool008ooool00`000?l0
VC?o000><ol000<0003oooooool0OOooo`00Soooo`030000o`2I<ol000hco`000`000?ooooooo`1m
oooo002?oooo00<0003o09Tco`003C?o00030000oooooooo07koool008Ooool400001?ooo`030000
o`2I<ol000dco`000`000?ooooooo`1noooo0027oooo00<0003oooooool01Oooo`030000o`2I<ol0
00dco`000`000?ooooooo`1noooo0028oooo00<0003oooooool01?ooo`<0000=<ol000<0003ooooo
ool0O_ooo`00ROooo`030000oooooooo00?oool00`000?l0VC?o000=<ol000<0003oooooool0O_oo
o`00Qoooo`040000oooooooo00001?ooo`030000o`2I<ol000`co`000`000?ooooooo`1ooooo0028
oooo0P0000Goool00`000?l0VC?o000<<ol000<0003oooooool0Ooooo`00Soooo`030000o`2I<ol0
00`co`000`000?ooooooo`1ooooo002?oooo00<0003o09Tco`0033?o00030000oooooooo07ooool0
08ooool200003C?o00030000oooooooo07ooool008ooool00`000?l0VC?o000<<ol000<0003ooooo
ool0Ooooo`00Soooo`030000o`2I<ol000/co`000`000?ooooooo`20oooo002?oooo00<0003o09Tc
o`002c?o00030000oooooooo083oool008ooool00`000?l0VC?o000;<ol000<0003oooooool0P?oo
o`00Soooo`030000o`2I<ol000/co`000`000?ooooooo`20oooo002?oooo00<0003o09Tco`002c?o
00030000oooooooo083oool008ooool2000033?o00030000oooooooo083oool008ooool00`000?l0
VC?o000;<ol000<0003oooooool0P?ooo`00Soooo`030000o`2I<ol000Xco`000`000?ooooooo`21
oooo002?oooo00<0003o09Tco`002S?o00030000oooooooo087oool008ooool00`000?l0VC?o000:
<ol000<0003oooooool0POooo`00Soooo`030000o`2I<ol000Xco`000`000?ooooooo`21oooo002?
oooo0P0000/co`000`000?ooooooo`21oooo002?oooo00<0003o09Tco`002S?o00030000oooooooo
087oool008ooool00`000?l0VC?o000:<ol000<0003oooooool0POooo`00Soooo`030000o`2I<ol0
00Tco`000`000?ooooooo`22oooo002?oooo00<0003o09Tco`002C?o00030000oooooooo08;oool0
08ooool00`000?l0VC?o0009<ol000<0003oooooool0P_ooo`00Soooo`80000:<ol000<0003ooooo
ool0P_ooo`00Soooo`030000o`2I<ol000Tco`000`000?ooooooo`22oooo002?oooo00<0003o09Tc
o`002C?o00030000oooooooo08;oool008ooool00`000?l0VC?o0008<ol000<0003oooooool0Pooo
o`00R?ooo`800005oooo00<0003o09Tco`0023?o00030000oooooooo08?oool008Ooool010000?oo
ooooo`0000Coool00`000?l0VC?o0008<ol000<0003oooooool0Poooo`00ROooo`030000oooooooo
00?oool3000023?o00030000oooooooo08?oool008[oool00`000?ooooooo`02oooo00<0003o09Tc
o`0023?o00030000oooooooo08?oool008Ooool010000?ooooooo`0000Coool00`000?l0VC?o0008
<ol000<0003oooooool0Poooo`00R?ooo`800005oooo00<0003o09Tco`001c?o00030000oooooooo
08Coool008ooool00`000?l0VC?o0007<ol000<0003oooooool0Q?ooo`00Soooo`030000o`2I<ol0
00Lco`000`000?ooooooo`24oooo002?oooo00<0003o09Tco`001c?o00030000oooooooo08Coool0
08ooool2000023?o00030000oooooooo08Coool008ooool00`000?l0VC?o0007<ol000<0003ooooo
ool0Q?ooo`00Soooo`030000o`2I<ol000Lco`000`000?ooooooo`24oooo002?oooo00<0003o09Tc
o`001c?o00030000oooooooo08Coool008ooool00`000?l0VC?o0006<ol000<0003oooooool0QOoo
o`00Soooo`030000o`2I<ol000Hco`000`000?ooooooo`25oooo002?oooo0P0000Lco`000`000?oo
ooooo`25oooo002?oooo00<0003o09Tco`001S?o00030000oooooooo08Goool008ooool00`000?l0
VC?o0006<ol000<0003oooooool0QOooo`00Soooo`030000o`2I<ol000Hco`000`000?ooooooo`25
oooo002?oooo00<0003o09Tco`001S?o00030000oooooooo08Goool008ooool00`000?l0VC?o0006
<ol000<0003oooooool0QOooo`00Soooo`800006<ol000<0003oooooool0Q_ooo`00Soooo`030000
o`2I<ol000Dco`000`000?ooooooo`26oooo002?oooo00<0003o09Tco`001C?o00030000oooooooo
08Koool008ooool00`000?l0VC?o0005<ol000<0003oooooool0Q_ooo`00Soooo`030000o`2I<ol0
00Dco`000`000?ooooooo`26oooo002?oooo00<0003o09Tco`001C?o00030000oooooooo08Koool0
08ooool200001S?o00030000oooooooo08Koool008ooool00`000?l0VC?o0005<ol000<0003ooooo
ool0Q_ooo`00Soooo`030000o`2I<ol000Dco`000`000?ooooooo`26oooo002?oooo00<0003o09Tc
o`0013?o00030000oooooooo08Ooool008ooool00`000?l0VC?o0004<ol000<0003oooooool0Qooo
o`00ROooo`<00003oooo00<0003o09Tco`0013?o00030000oooooooo08Ooool008[oool00`000?oo
ooooo`02oooo00<0003o09Tco`0013?o00030000oooooooo08Ooool008Ooool500000oooo`<00004
<ol000<0003oooooool0Qoooo`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0
003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?
oooo1c?o08[oool007Woool00`000?ooooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo00Woool7<ol03oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@00008co`02000000@c
o`3oooooooooool200000oooo`@00003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000<ol0<ol000Dco`02
oooo00@0003oooooool00002oooo00<0003oooooool01?ooo`030000oooooooo07Soool007Ooool0
0`000?ooooooo`02oooo00<0003oooooool03oooo`030000<ol0<ol000Dco`02oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00003_ooo`030000<ol0<ol000Dco`02oooo00@0003oooooool00004oooo00<0003oooooool00_oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Aoooo00<0000co`0co`001C?o
00;oool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool04Oooo`800007<ol00oooo`800004oooo0P0000?oool00`000?ooooooo`1i
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49955 .12361 L
.50431 .12361 L
.50682 .12361 L
.5082 .12361 L
.5095 .12361 L
s
.5095 .12361 m
.51 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47994 .12361 L
.48519 .12361 L
.48778 .12361 L
.48904 .12361 L
.49018 .12361 L
.4913 .12276 L
.49235 .12168 L
.49466 .11937 L
.49955 .11471 L
.5046 .11017 L
.50707 .10805 L
.50814 .10714 L
.50931 .10616 L
.51053 .12361 L
.51169 .12361 L
.51423 .12361 L
.51963 .12361 L
.5381 .12361 L
.57888 .12361 L
.61815 .12361 L
.6559 .12361 L
.6961 .12361 L
.73479 .12361 L
.77593 .12361 L
.81556 .12361 L
.85366 .12361 L
.89423 .12361 L
.93327 .12361 L
.97477 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
03Woool20000>oooo`80000Goooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooo06Ko
08koool008ooool00`00001Vo`1Vo`2>oooo002?oooo00<0003oool0I_l0S_ooo`00S_ooo`0506Ko
0000oooooooo06Ko08goool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`0003?o0?l0V@09<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_oo
o`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000
oooooooo03Woool00`0003?o0?l0V@0i<ol02@0003Coool00`000?ooooooo`0Eoooo002?oooo00<0
000co`3o09T0<c?o00H0001Eoooo002?oooo00<0000co`3o09T0<C?o0080001Koooo002?oooo00<0
000co`3o09T0;c?o0080001Moooo002?oooo00<0000co`3o09T0;3?o00<0001Ooooo002?oooo0P00
0003o`2I<ol0<ol002Lco`030000H_ooo`00Soooo`030000<ol0o`2I02Lco`020000IOooo`00Sooo
o`030000<ol0o`2I02Hco`000`000?ooooooo`1Uoooo002?oooo00<0000co`3o09T09C?o00030000
oooooooo06Koool008ooool00`0003?o0?l0V@0T<ol000<0003oooooool0Ioooo`00Soooo`030000
<ol0o`2I028co`020000J_ooo`00Soooo`8000000ol0VC?o03?o000O<ol000<0003oooooool0J_oo
o`00Soooo`030000<ol0o`2I020co`000`000?ooooooo`1[oooo002?oooo00<0000co`3o09T07c?o
00030000oooooooo06coool008ooool00`0003?o0?l0V@0O<ol000<0003oooooool0K?ooo`00Sooo
o`030000<ol0o`2I01hco`000`000?ooooooo`1]oooo002?oooo00<0000co`3o09T07C?o00030000
oooooooo06koool008ooool2000000?o09Tco`0co`006S?o00030000oooooooo06ooool008ooool0
0`0003?o0?l0V@0K<ol000<0003oooooool0L?ooo`00Soooo`030000<ol0o`2I01/co`000`000?oo
ooooo`1`oooo002?oooo00<0000co`3o09T06S?o00030000oooooooo077oool008ooool00`0003?o
0?l0V@0J<ol000<0003oooooool0LOooo`00Soooo`030000<ol0o`2I01Tco`000`000?ooooooo`1b
oooo002?oooo0P000003o`2I<ol0<ol001Lco`000`000?ooooooo`1boooo002?oooo00<0000co`3o
09T063?o00030000oooooooo07?oool008ooool00`0003?o0?l0V@0H<ol000<0003oooooool0Looo
o`00Soooo`030000<ol0o`2I01Lco`000`000?ooooooo`1doooo002?oooo00<0000co`3o09T05c?o
00030000oooooooo07Coool008Ooool500000oooo`030000<ol0o`2I01Hco`000`000?ooooooo`1e
oooo0029oooo00<0003oooooool00oooo`030000<ol0o`2I01Hco`000`000?ooooooo`1eoooo0029
oooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0M_ooo`00ROooo`030000oooooooo
00?oool00`0003?o0?l0V@0E<ol000<0003oooooool0M_ooo`00ROooo`030000oooooooo00?oool0
0`0003?o0?l0V@0E<ol000<0003oooooool0M_ooo`00R?ooo`800005oooo00<0000co`3o09T053?o
00030000oooooooo07Ooool008ooool00`0003?o0?l0V@0D<ol000<0003oooooool0Moooo`00Sooo
o`030000<ol0o`2I01<co`000`000?ooooooo`1hoooo002?oooo0P000003o`2I<ol0<ol0014co`00
0`000?ooooooo`1hoooo002?oooo00<0000co`3o09T04c?o00030000oooooooo07Soool008ooool0
0`0003?o0?l0V@0B<ol000<0003oooooool0NOooo`00Soooo`030000<ol0o`2I018co`000`000?oo
ooooo`1ioooo002?oooo00<0000co`3o09T04S?o00030000oooooooo07Woool008ooool00`0003?o
0?l0V@0A<ol000<0003oooooool0N_ooo`00Soooo`8000000ol0VC?o03?o000?<ol000<0003ooooo
ool0N_ooo`00Soooo`030000<ol0o`2I014co`000`000?ooooooo`1joooo002?oooo00<0000co`3o
09T04C?o00030000oooooooo07[oool008ooool00`0003?o0?l0V@0@<ol000<0003oooooool0Nooo
o`00Soooo`030000<ol0o`2I010co`000`000?ooooooo`1koooo002?oooo00<0000co`3o09T043?o
00030000oooooooo07_oool008ooool00`0003?o0?l0V@0@<ol000<0003oooooool0Noooo`00Sooo
o`8000000ol0VC?o03?o000=<ol000<0003oooooool0O?ooo`00Soooo`030000<ol0o`2I00lco`00
0`000?ooooooo`1loooo002?oooo00<0000co`3o09T03c?o00030000oooooooo07coool008ooool0
0`0003?o0?l0V@0?<ol000<0003oooooool0O?ooo`00Soooo`030000<ol0o`2I00lco`000`000?oo
ooooo`1loooo002?oooo00<0000co`3o09T03S?o00030000oooooooo07goool008ooool2000000?o
09Tco`0co`0033?o00030000oooooooo07goool008ooool00`0003?o0?l0V@0><ol000<0003ooooo
ool0OOooo`00Soooo`030000<ol0o`2I00hco`000`000?ooooooo`1moooo002?oooo00<0000co`3o
09T03C?o00030000oooooooo07koool008Ooool400001?ooo`030000<ol0o`2I00dco`000`000?oo
ooooo`1noooo0027oooo00<0003oooooool01Oooo`030000<ol0o`2I00dco`000`000?ooooooo`1n
oooo0028oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0O_ooo`00ROooo`030000
oooooooo00?oool0100003?o03?o0?l0V@`co`000`000?ooooooo`1noooo0027oooo00@0003ooooo
ool00004oooo00@0000co`0co`3o09T;<ol000<0003oooooool0Ooooo`00R?ooo`800005oooo00@0
000co`0co`3o09T;<ol000<0003oooooool0Ooooo`00Soooo`040000<ol0<ol0o`2I2c?o00030000
oooooooo07ooool008ooool0100003?o03?o0?l0V@/co`000`000?ooooooo`1ooooo002?oooo0P00
0003<ol0o`2I<ol000Xco`000`000?ooooooo`1ooooo002?oooo00@0000co`0co`3o09T;<ol000<0
003oooooool0Ooooo`00Soooo`040000<ol0<ol0o`2I2S?o00030000oooooooo083oool008ooool0
100003?o03?o0?l0V@Xco`000`000?ooooooo`20oooo002?oooo00@0000co`0co`3o09T:<ol000<0
003oooooool0P?ooo`00Soooo`040000<ol0<ol0o`2I2S?o00030000oooooooo083oool008ooool0
100003?o03?o0?l0V@Xco`000`000?ooooooo`20oooo002?oooo0P000003<ol0o`2I<ol000Tco`00
0`000?ooooooo`20oooo002?oooo00@0000co`0co`3o09T:<ol000<0003oooooool0P?ooo`00Sooo
o`040000<ol0<ol0o`2I2C?o00030000oooooooo087oool008ooool0100003?o03?o0?l0V@Tco`00
0`000?ooooooo`21oooo002?oooo00@0000co`0co`3o09T9<ol000<0003oooooool0POooo`00Sooo
o`040000<ol0<ol0o`2I2C?o00030000oooooooo087oool008ooool2000000<co`3o09Tco`0023?o
00030000oooooooo087oool008ooool0100003?o03?o0?l0V@Tco`000`000?ooooooo`21oooo002?
oooo00@0000co`0co`3o09T9<ol000<0003oooooool0POooo`00Soooo`040000<ol0<ol0o`2I23?o
00030000oooooooo08;oool008ooool0100003?o03?o0?l0V@Pco`000`000?ooooooo`22oooo002?
oooo00@0000co`0co`3o09T8<ol000<0003oooooool0P_ooo`00Soooo`8000000c?o0?l0VC?o0007
<ol000<0003oooooool0P_ooo`00Soooo`040000<ol0<ol0o`2I23?o00030000oooooooo08;oool0
08ooool0100003?o03?o0?l0V@Pco`000`000?ooooooo`22oooo002?oooo00@0000co`0co`3o09T7
<ol000<0003oooooool0Poooo`00R?ooo`800005oooo00@0000co`0co`3o09T7<ol000<0003ooooo
ool0Poooo`00Qoooo`040000oooooooo00001?ooo`040000<ol0<ol0o`2I1c?o00030000oooooooo
08?oool008Woool00`000?ooooooo`03oooo0`000003o`2I<ol0<ol000Dco`000`000?ooooooo`23
oooo002:oooo00<0003oooooool00_ooo`040000<ol0<ol0o`2I1c?o00030000oooooooo08?oool0
08Ooool010000?ooooooo`0000Coool0100003?o03?o0?l0V@Lco`000`000?ooooooo`23oooo0028
oooo0P0000Goool0100003?o03?o0?l0V@Hco`000`000?ooooooo`24oooo002?oooo00@0000co`0c
o`3o09T6<ol000<0003oooooool0Q?ooo`00Soooo`040000<ol0<ol0o`2I1S?o00030000oooooooo
08Coool008ooool0100003?o03?o0?l0V@Hco`000`000?ooooooo`24oooo002?oooo0P000003<ol0
o`2I<ol000Dco`000`000?ooooooo`24oooo002?oooo00@0000co`0co`3o09T6<ol000<0003ooooo
ool0Q?ooo`00Soooo`040000<ol0<ol0o`2I1S?o00030000oooooooo08Coool008ooool0100003?o
03?o0?l0V@Hco`000`000?ooooooo`24oooo002?oooo00@0000co`0co`3o09T5<ol000<0003ooooo
ool0QOooo`00Soooo`040000<ol0<ol0o`2I1C?o00030000oooooooo08Goool008ooool2000000<c
o`3o09Tco`0013?o00030000oooooooo08Goool008ooool0100003?o03?o0?l0V@Dco`000`000?oo
ooooo`25oooo002?oooo00@0000co`0co`3o09T5<ol000<0003oooooool0QOooo`00Soooo`040000
<ol0<ol0o`2I1C?o00030000oooooooo08Goool008ooool0100003?o03?o0?l0V@Dco`000`000?oo
ooooo`25oooo002?oooo00@0000co`0co`3o09T5<ol000<0003oooooool0QOooo`00Soooo`800000
0c?o0?l0VC?o0003<ol000<0003oooooool0Q_ooo`00Soooo`040000<ol0<ol0o`2I13?o00030000
oooooooo08Koool008ooool0100003?o03?o0?l0V@@co`000`000?ooooooo`26oooo002?oooo00@0
000co`0co`3o09T4<ol000<0003oooooool0Q_ooo`00Soooo`040000<ol0<ol0o`2I13?o00030000
oooooooo08Koool008ooool0100003?o03?o0?l0V@@co`000`000?ooooooo`26oooo002?oooo0P00
0003<ol0o`2I<ol000<co`000`000?ooooooo`26oooo002?oooo00@0000co`0co`3o09T4<ol000<0
003oooooool0Q_ooo`00Soooo`040000<ol0<ol0o`2I13?o00030000oooooooo08Koool008ooool0
100003?o03?o0?l0V@<co`000`000?ooooooo`27oooo002?oooo00@0000co`0co`3o09T3<ol000<0
003oooooool0Qoooo`00ROooo`<00003oooo00@0000co`0co`3o09T3<ol000<0003oooooool0Qooo
o`00R_ooo`030000oooooooo00;oool0100003?o03?o0?l0V@<co`000`000?ooooooo`27oooo0027
oooo1@0000?oool3000000Go09Tco`0co`0co`000000ROooo`00Qoooo`040000oooooooo00001?oo
o`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7<ol0R_oo
o`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?ooooooo`0Coooo1c?o00koool0
0`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo00Woool7<ol03ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06
oooo1@00008co`02000000@co`3oooooooooool200001Oooo`<00002oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01ooo
o`030000<ol0<ol000Dco`02oooo00@0003oooooool00005oooo00D0003oooooooooool00000N_oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0000co`0co`001C?o00;oool0
10000?ooooooo`0000;oool500000oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00003_ooo`030000<ol0<ol000Dco`02oooo00@0003oooooool00002oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000017oool00`0003?o03?o0005
<ol00_ooo`040000oooooooo00000oooo`030000oooo000000?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool04Oooo`800007<ol00oooo`800005oooo0P0000;oool00`000?ooooooo`1i
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49955 .12361 L
.50431 .12361 L
.50682 .12361 L
.5095 .12361 L
.51083 .12361 L
.51207 .12361 L
.51319 .12361 L
s
.51319 .12361 m
.51368 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47106 .12361 L
.47994 .12361 L
.48231 .12361 L
.48361 .12361 L
.48484 .12361 L
.48554 .12361 L
.48629 .12301 L
.48761 .12166 L
.49018 .1191 L
.49955 .11044 L
.50414 .10655 L
.50906 .10259 L
.51051 .10146 L
.51188 .10041 L
.51311 .09947 L
.51381 .09895 L
.51445 .12361 L
.51561 .12361 L
.5169 .12361 L
.51949 .12361 L
.54055 .12361 L
.58076 .12361 L
.61945 .12361 L
.66059 .12361 L
.70021 .12361 L
.73832 .12361 L
.77888 .12361 L
.81792 .12361 L
.85942 .12361 L
.8994 .12361 L
.93787 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
0003oooo06Kooooo03Koool20000>oooo`80000Goooo002?oooo00@0003oool0I_l0I_n=oooo002?
oooo00@00000I_ooool0I_n=oooo002?oooo00@0003oooooool0I_n=oooo002=oooo0P1Vo`050000
oooooooooooo06Ko08coool008coool0101Vooooooooo`0000?oool00`1Vooooooooo`2:oooo000@
ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00@0
000co`0co`3o09T8<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000oooooooo00Woool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool0100003?o
03?o0?l0VCPco`090000=?ooo`030000oooooooo01Goool008ooool0100003?o03?o0?l0VC8co`06
0000EOooo`00Soooo`040000<ol0<ol0o`2I<3?o0080001Koooo002?oooo00@0000co`0co`3o09T^
<ol00P0005goool008ooool0100003?o03?o0?l0VB/co`030000Goooo`00Soooo`8000000c?o0?l0
VC?o000W<ol00`0006;oool008ooool0100003?o03?o0?l0VBHco`020000IOooo`00Soooo`040000
<ol0<ol0o`2I9C?o00030000oooooooo06Goool008ooool0100003?o03?o0?l0VB@co`000`000?oo
ooooo`1Voooo002?oooo00@0000co`0co`3o09TS<ol000<0003oooooool0Ioooo`00Soooo`040000
<ol0<ol0o`2I8C?o0080001Zoooo002?oooo0P000003<ol0o`2I<ol001lco`000`000?ooooooo`1Z
oooo002?oooo00@0000co`0co`3o09TO<ol000<0003oooooool0Joooo`00Soooo`040000<ol0<ol0
o`2I7S?o00030000oooooooo06coool008ooool0100003?o03?o0?l0VAhco`000`000?ooooooo`1/
oooo002?oooo00@0000co`0co`3o09TM<ol000<0003oooooool0KOooo`00Soooo`040000<ol0<ol0
o`2I73?o00030000oooooooo06koool008ooool2000000<co`3o09Tco`006S?o00030000oooooooo
06ooool008ooool0100003?o03?o0?l0VAXco`000`000?ooooooo`1`oooo002?oooo00@0000co`0c
o`3o09TJ<ol000<0003oooooool0L?ooo`00Soooo`040000<ol0<ol0o`2I6C?o00030000oooooooo
077oool008ooool0100003?o03?o0?l0VATco`000`000?ooooooo`1aoooo002?oooo00@0000co`0c
o`3o09TH<ol000<0003oooooool0L_ooo`00Soooo`8000000c?o0?l0VC?o000G<ol000<0003ooooo
ool0L_ooo`00Soooo`040000<ol0<ol0o`2I5c?o00030000oooooooo07?oool008ooool0100003?o
03?o0?l0VALco`000`000?ooooooo`1coooo002?oooo00@0000co`0co`3o09TF<ol000<0003ooooo
ool0M?ooo`00Soooo`040000<ol0<ol0o`2I5S?o00030000oooooooo07Coool008Ooool500000ooo
o`040000<ol0<ol0o`2I5C?o00030000oooooooo07Goool008Woool00`000?ooooooo`03oooo00@0
000co`0co`3o09TE<ol000<0003oooooool0MOooo`00ROooo`030000oooooooo00?oool3000000?o
09Tco`0co`004S?o00030000oooooooo07Koool008Woool00`000?ooooooo`03oooo00@0000co`0c
o`3o09TD<ol000<0003oooooool0M_ooo`00ROooo`030000oooooooo00?oool0100003?o03?o0?l0
VA@co`000`000?ooooooo`1foooo0028oooo0P0000Goool0100003?o03?o0?l0VA<co`000`000?oo
ooooo`1goooo002?oooo00@0000co`0co`3o09TC<ol000<0003oooooool0Moooo`00Soooo`040000
<ol0<ol0o`2I4S?o00030000oooooooo07Soool008ooool2000000<co`3o09Tco`004C?o00030000
oooooooo07Soool008ooool0100003?o03?o0?l0VA8co`000`000?ooooooo`1hoooo002?oooo00@0
000co`0co`3o09TA<ol000<0003oooooool0NOooo`00Soooo`040000<ol0<ol0o`2I4C?o00030000
oooooooo07Woool008ooool0100003?o03?o0?l0VA4co`000`000?ooooooo`1ioooo002?oooo00@0
000co`0co`3o09T@<ol000<0003oooooool0N_ooo`00Soooo`8000000c?o0?l0VC?o000?<ol000<0
003oooooool0N_ooo`00Soooo`040000<ol0<ol0o`2I43?o00030000oooooooo07[oool008ooool0
100003?o03?o0?l0VA0co`000`000?ooooooo`1joooo002?oooo00@0000co`0co`3o09T?<ol000<0
003oooooool0Noooo`00Soooo`040000<ol0<ol0o`2I3c?o00030000oooooooo07_oool008ooool0
100003?o03?o0?l0V@lco`000`000?ooooooo`1koooo002?oooo00@0000co`0co`3o09T?<ol000<0
003oooooool0Noooo`00Soooo`8000000c?o0?l0VC?o000=<ol000<0003oooooool0O?ooo`00Sooo
o`040000<ol0<ol0o`2I3S?o00030000oooooooo07coool008ooool0100003?o03?o0?l0V@hco`00
0`000?ooooooo`1loooo002?oooo00@0000co`0co`3o09T><ol000<0003oooooool0O?ooo`00Sooo
o`040000<ol0<ol0o`2I3S?o00030000oooooooo07coool008ooool0100003?o03?o0?l0V@dco`00
0`000?ooooooo`1moooo002?oooo0P000003<ol0o`2I<ol000`co`000`000?ooooooo`1moooo002?
oooo00@0000co`0co`3o09T=<ol000<0003oooooool0OOooo`00Soooo`040000<ol0<ol0o`2I3C?o
00030000oooooooo07goool008ooool0100003?o03?o0?l0V@`co`000`000?ooooooo`1noooo0027
oooo100000Coool0100003?o03?o0?l0V@`co`000`000?ooooooo`1noooo0027oooo00<0003ooooo
ool01Oooo`040000<ol0<ol0o`2I33?o00030000oooooooo07koool008Soool00`000?ooooooo`04
oooo0`000003o`2I<ol0<ol000Xco`000`000?ooooooo`1noooo0029oooo00<0003oooooool00ooo
o`040000<ol0<ol0o`2I33?o00030000oooooooo07koool008Ooool010000?ooooooo`0000Coool0
100003?o03?o0?l0V@/co`000`000?ooooooo`1ooooo0028oooo0P0000Goool0100003?o03?o0?l0
V@/co`000`000?ooooooo`1ooooo002?oooo00@0000co`0co`3o09T;<ol000<0003oooooool0Oooo
o`00Soooo`040000<ol0<ol0o`2I2c?o00030000oooooooo07ooool008ooool2000000<co`3o09Tc
o`002S?o00030000oooooooo07ooool008ooool0100003?o03?o0?l0V@/co`000`000?ooooooo`1o
oooo002?oooo00@0000co`0co`3o09T:<ol000<0003oooooool0P?ooo`00Soooo`040000<ol0<ol0
o`2I2S?o00030000oooooooo083oool008ooool0100003?o03?o0?l0V@Xco`000`000?ooooooo`20
oooo002?oooo00@0000co`0co`3o09T:<ol000<0003oooooool0P?ooo`00Soooo`040000<ol0<ol0
o`2I2S?o00030000oooooooo083oool008ooool2000000<co`3o09Tco`002C?o00030000oooooooo
083oool008ooool0100003?o03?o0?l0V@Xco`000`000?ooooooo`20oooo002?oooo00@0000co`0c
o`3o09T9<ol000<0003oooooool0POooo`00Soooo`040000<ol0<ol0o`2I2C?o00030000oooooooo
087oool008ooool0100003?o03?o0?l0V@Tco`000`000?ooooooo`21oooo002?oooo00@0000co`0c
o`3o09T9<ol000<0003oooooool0POooo`00Soooo`8000000c?o0?l0VC?o0008<ol000<0003ooooo
ool0POooo`00Soooo`040000<ol0<ol0o`2I2C?o00030000oooooooo087oool008ooool0100003?o
03?o0?l0V@Tco`000`000?ooooooo`21oooo002?oooo00@0000co`0co`3o09T8<ol000<0003ooooo
ool0P_ooo`00Soooo`040000<ol0<ol0o`2I23?o00030000oooooooo08;oool008ooool0100003?o
03?o0?l0V@Pco`000`000?ooooooo`22oooo002?oooo0P000003<ol0o`2I<ol000Lco`000`000?oo
ooooo`22oooo002?oooo00@0000co`0co`3o09T8<ol000<0003oooooool0P_ooo`00Soooo`040000
<ol0<ol0o`2I23?o00030000oooooooo08;oool008ooool0100003?o03?o0?l0V@Lco`000`000?oo
ooooo`23oooo0028oooo0P0000Goool0100003?o03?o0?l0V@Lco`000`000?ooooooo`23oooo0027
oooo00@0003oooooool00004oooo00@0000co`0co`3o09T7<ol000<0003oooooool0Poooo`00ROoo
o`030000oooooooo00?oool3000000?o09Tco`0co`001C?o00030000oooooooo08?oool008[oool0
0`000?ooooooo`02oooo00@0000co`0co`3o09T7<ol000<0003oooooool0Poooo`00Qoooo`040000
oooooooo00001?ooo`040000<ol0<ol0o`2I1c?o00030000oooooooo08?oool008Soool200001Ooo
o`040000<ol0<ol0o`2I1S?o00030000oooooooo08Coool008ooool0100003?o03?o0?l0V@Hco`00
0`000?ooooooo`24oooo002?oooo00@0000co`0co`3o09T6<ol000<0003oooooool0Q?ooo`00Sooo
o`040000<ol0<ol0o`2I1S?o00030000oooooooo08Coool008ooool2000000<co`3o09Tco`001C?o
00030000oooooooo08Coool008ooool0100003?o03?o0?l0V@Hco`000`000?ooooooo`24oooo002?
oooo00@0000co`0co`3o09T6<ol000<0003oooooool0Q?ooo`00Soooo`040000<ol0<ol0o`2I1S?o
00030000oooooooo08Coool008ooool0100003?o03?o0?l0V@Dco`000`000?ooooooo`25oooo002?
oooo00@0000co`0co`3o09T5<ol000<0003oooooool0QOooo`00Soooo`8000000c?o0?l0VC?o0004
<ol000<0003oooooool0QOooo`00Soooo`040000<ol0<ol0o`2I1C?o00030000oooooooo08Goool0
08ooool0100003?o03?o0?l0V@Dco`000`000?ooooooo`25oooo002?oooo00@0000co`0co`3o09T5
<ol000<0003oooooool0QOooo`00Soooo`040000<ol0<ol0o`2I1C?o00030000oooooooo08Goool0
08ooool0100003?o03?o0?l0V@Dco`000`000?ooooooo`25oooo002?oooo0P000003<ol0o`2I<ol0
00<co`000`000?ooooooo`26oooo002?oooo00@0000co`0co`3o09T4<ol000<0003oooooool0Q_oo
o`00Soooo`040000<ol0<ol0o`2I13?o00030000oooooooo08Koool008ooool0100003?o03?o0?l0
V@@co`000`000?ooooooo`26oooo002?oooo00@0000co`0co`3o09T4<ol000<0003oooooool0Q_oo
o`00Soooo`040000<ol0<ol0o`2I13?o00030000oooooooo08Koool008ooool2000000<co`3o09Tc
o`000c?o00030000oooooooo08Koool008ooool0100003?o03?o0?l0V@@co`000`000?ooooooo`26
oooo002?oooo00@0000co`0co`3o09T4<ol000<0003oooooool0Q_ooo`00Soooo`040000<ol0<ol0
o`2I0c?o00030000oooooooo08Ooool008ooool0100003?o03?o0?l0V@<co`000`000?ooooooo`27
oooo0029oooo0`0000?oool0100003?o03?o0?l0V@<co`000`000?ooooooo`27oooo002:oooo00<0
003oooooool00_ooo`040000<ol0<ol0o`2I0c?o00030000oooooooo08Ooool008Ooool500000ooo
o`<000001Ol0VC?o03?o03?o00000029oooo0027oooo00@0003oooooool00004oooo1c?o08[oool0
08Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o
08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?oooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000S?o
0080000013?o0?ooooooooooo`800003oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0000co`0c
o`001C?o00;oool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1h
oooo001goooo00<0003oooooool00_ooo`030000oooooooo00ooool00`0003?o03?o0005<ol00_oo
o`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500003_ooo`030000<ol0<ol000Dco`02oooo00@0003oooooool00002oooo0`00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000004Oooo`030000<ol0<ol0
00Dco`02oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo07Soool0
07Woool00`000?ooooooo`0Aoooo0P0000Lco`03oooo0P0000Coool300000_ooo`030000oooooooo
07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.5095 .12361 L
.51441 .12361 L
.5168 .12361 L
.51784 .12361 L
.51896 .12361 L
s
.51896 .12361 m
.51948 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.46172 .12361 L
.47106 .12361 L
.47567 .12361 L
.47791 .12361 L
.47889 .12361 L
.47994 .12361 L
.48116 .12339 L
.48231 .12221 L
.48484 .11967 L
.49018 .11456 L
.49955 .10643 L
.50906 .09904 L
.51166 .09713 L
.51445 .09514 L
.51581 .0942 L
.51709 .09331 L
.51824 .09253 L
.51949 .12361 L
.52079 .12361 L
.52201 .12361 L
.5248 .12361 L
.53043 .12361 L
.54055 .12361 L
.57924 .12361 L
.62038 .12361 L
.66001 .12361 L
.69811 .12361 L
.73868 .12361 L
.77772 .12361 L
.81922 .12361 L
.8592 .12361 L
.89767 .12361 L
.93859 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0foooo00@0003oooooooooool2
06Ko=_ooo`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000h
oooo0P000080I_l00oooo`1Vooooo`0doooo0P0003_oool200005oooo`00Soooo`03000006Kooooo
00;oool00`1Vooooooooo`29oooo002?oooo00<0003oooooool00_ooo`0306Kooooooooo08Woool0
08goool206Ko00<0003oooooool00_ooo`0306Kooooooooo08Woool008coool0101Vooooooooo`00
00Coool00`1Vooooooooo`29oooo002;oooo00D0I_ooooooooooool000001?ooo`0306Kooooooooo
08Woool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`0003?o03?o0002<ol000?o09Tco`0co`0013?o00030000<ol0<ol000Tco`000`0003?o
03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006<ol08P00
00Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool0
0`000?ooooooo`0ioooo00<0000co`0co`000S?o0003o`2I<ol0<ol003@co`090000=?ooo`030000
oooooooo01Goool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`00;S?o00H0001Eoooo002?
oooo00<0000co`0co`000S?o0003o`2I<ol0<ol002`co`020000Foooo`00Soooo`030000<ol0<ol0
008co`000ol0VC?o03?o000Z<ol00P0005goool008ooool00`0003?o03?o0002<ol000?o09Tco`0c
o`009c?o00<0001Ooooo002?oooo0P0000<co`000ol0VC?o03?o000T<ol00`0006;oool008ooool0
0`0003?o03?o0002<ol000?o09Tco`0co`008S?o0080001Uoooo002?oooo00<0000co`0co`000S?o
0003o`2I<ol0<ol0024co`000`000?ooooooo`1Uoooo002?oooo00<0000co`0co`000S?o0003o`2I
<ol0<ol0020co`000`000?ooooooo`1Voooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol0
01lco`000`000?ooooooo`1Woooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol001dco`02
0000J_ooo`00Soooo`800003<ol000?o09Tco`0co`0073?o00030000oooooooo06[oool008ooool0
0`0003?o03?o0002<ol000?o09Tco`0co`006c?o00030000oooooooo06_oool008ooool00`0003?o
03?o0002<ol000?o09Tco`0co`006S?o00030000oooooooo06coool008ooool00`0003?o03?o0002
<ol000?o09Tco`0co`006S?o00030000oooooooo06coool008ooool00`0003?o03?o0002<ol000?o
09Tco`0co`006C?o00030000oooooooo06goool008ooool00`0003?o03?o0002<ol000?o09Tco`0c
o`0063?o00030000oooooooo06koool008ooool200000c?o0003o`2I<ol0<ol001Lco`000`000?oo
ooooo`1_oooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol001Hco`000`000?ooooooo`1`
oooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol001Hco`000`000?ooooooo`1`oooo002?
oooo00<0000co`0co`000S?o0003o`2I<ol0<ol001Dco`000`000?ooooooo`1aoooo002?oooo00<0
000co`0co`000S?o0003o`2I<ol0<ol001Dco`000`000?ooooooo`1aoooo002?oooo00<0000co`0c
o`000S?o0003o`2I<ol0<ol001@co`000`000?ooooooo`1boooo002?oooo0P0000<co`000ol0VC?o
03?o000D<ol000<0003oooooool0L_ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000C
<ol000<0003oooooool0Loooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000C<ol000<0
003oooooool0Loooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000B<ol000<0003ooooo
ool0M?ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000B<ol000<0003oooooool0M?oo
o`00Qoooo`D00003oooo00<0000co`0co`000S?o0003o`2I<ol0<ol0014co`000`000?ooooooo`1e
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0008co`000ol0VC?o03?o000A<ol000<0
003oooooool0MOooo`00ROooo`030000oooooooo00?oool300000S?o0003o`2I<ol0<ol0010co`00
0`000?ooooooo`1foooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0008co`000ol0VC?o
03?o000@<ol000<0003oooooool0M_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o0002
<ol000?o09Tco`0co`0043?o00030000oooooooo07Koool008Soool200001Oooo`030000<ol0<ol0
008co`000ol0VC?o03?o000?<ol000<0003oooooool0Moooo`00Soooo`030000<ol0<ol0008co`00
0ol0VC?o03?o000?<ol000<0003oooooool0Moooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o
03?o000><ol000<0003oooooool0N?ooo`00Soooo`800003<ol000?o09Tco`0co`003S?o00030000
oooooooo07Soool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`003S?o00030000oooooooo
07Soool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`003C?o00030000oooooooo07Woool0
08ooool00`0003?o03?o0002<ol000?o09Tco`0co`003C?o00030000oooooooo07Woool008ooool0
0`0003?o03?o0002<ol000?o09Tco`0co`003C?o00030000oooooooo07Woool008ooool00`0003?o
03?o0002<ol000?o09Tco`0co`0033?o00030000oooooooo07[oool008ooool200000c?o0003o`2I
<ol0<ol000`co`000`000?ooooooo`1joooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol0
00`co`000`000?ooooooo`1joooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol000`co`00
0`000?ooooooo`1joooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol000/co`000`000?oo
ooooo`1koooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1k
oooo002?oooo00<0000co`0co`000S?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1koooo002?
oooo00<0000co`0co`000S?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1koooo002?oooo0P00
00<co`000ol0VC?o03?o000:<ol000<0003oooooool0O?ooo`00Soooo`030000<ol0<ol0008co`00
0ol0VC?o03?o000:<ol000<0003oooooool0O?ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o
03?o000:<ol000<0003oooooool0O?ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000:
<ol000<0003oooooool0O?ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o000:<ol000<0
003oooooool0O?ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o0009<ol000<0003ooooo
ool0OOooo`00Soooo`800003<ol000?o09Tco`0co`002C?o00030000oooooooo07goool008ooool0
0`0003?o03?o0002<ol000?o09Tco`0co`002C?o00030000oooooooo07goool008ooool00`0003?o
03?o0002<ol000?o09Tco`0co`002C?o00030000oooooooo07goool008ooool00`0003?o03?o0002
<ol000?o09Tco`0co`0023?o00030000oooooooo07koool008Ooool400001?ooo`030000<ol0<ol0
008co`000ol0VC?o03?o0008<ol000<0003oooooool0O_ooo`00Qoooo`030000oooooooo00Goool0
0`0003?o03?o0002<ol000?o09Tco`0co`0023?o00030000oooooooo07koool008Soool00`000?oo
ooooo`04oooo0`00008co`000ol0VC?o03?o0008<ol000<0003oooooool0O_ooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o0002<ol000?o09Tco`0co`0023?o00030000oooooooo07koool0
08Ooool010000?ooooooo`0000Coool00`0003?o03?o0002<ol000?o09Tco`0co`001c?o00030000
oooooooo07ooool008Soool200001Oooo`030000<ol0<ol0008co`000ol0VC?o03?o0007<ol000<0
003oooooool0Ooooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o0007<ol000<0003ooooo
ool0Ooooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o0007<ol000<0003oooooool0Oooo
o`00Soooo`800003<ol000?o09Tco`0co`001c?o00030000oooooooo07ooool008ooool00`0003?o
03?o0002<ol000?o09Tco`0co`001c?o00030000oooooooo07ooool008ooool00`0003?o03?o0002
<ol000?o09Tco`0co`001S?o00030000oooooooo083oool008ooool00`0003?o03?o0002<ol000?o
09Tco`0co`001S?o00030000oooooooo083oool008ooool00`0003?o03?o0002<ol000?o09Tco`0c
o`001S?o00030000oooooooo083oool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`001S?o
00030000oooooooo083oool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`001S?o00030000
oooooooo083oool008ooool200000c?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`20oooo002?
oooo00<0000co`0co`000S?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`20oooo002?oooo00<0
000co`0co`000S?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`21oooo002?oooo00<0000co`0c
o`000S?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`21oooo002?oooo00<0000co`0co`000S?o
0003o`2I<ol0<ol000Dco`000`000?ooooooo`21oooo002?oooo00<0000co`0co`000S?o0003o`2I
<ol0<ol000Dco`000`000?ooooooo`21oooo002?oooo0P0000<co`000ol0VC?o03?o0005<ol000<0
003oooooool0POooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o0005<ol000<0003ooooo
ool0POooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o0005<ol000<0003oooooool0POoo
o`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o0004<ol000<0003oooooool0P_ooo`00Sooo
o`030000<ol0<ol0008co`000ol0VC?o03?o0004<ol000<0003oooooool0P_ooo`00Soooo`030000
<ol0<ol0008co`000ol0VC?o03?o0004<ol000<0003oooooool0P_ooo`00Soooo`800003<ol000?o
09Tco`0co`0013?o00030000oooooooo08;oool008ooool00`0003?o03?o0002<ol000?o09Tco`0c
o`0013?o00030000oooooooo08;oool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`0013?o
00030000oooooooo08;oool008ooool00`0003?o03?o0002<ol000?o09Tco`0co`000c?o00030000
oooooooo08?oool008Soool200001Oooo`030000<ol0<ol0008co`000ol0VC?o03?o0003<ol000<0
003oooooool0Poooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol0008co`000ol0VC?o
03?o0003<ol000<0003oooooool0Poooo`00ROooo`030000oooooooo00?oool300000S?o0003o`2I
<ol0<ol000<co`000`000?ooooooo`23oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol0
008co`000ol0VC?o03?o0003<ol000<0003oooooool0Poooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol0008co`000ol0VC?o03?o0003<ol000<0003oooooool0Poooo`00R?ooo`800005
oooo00<0000co`0co`000S?o0003o`2I<ol0<ol0008co`000`000?ooooooo`24oooo002?oooo00<0
000co`0co`000S?o0003o`2I<ol0<ol0008co`000`000?ooooooo`24oooo002?oooo00<0000co`0c
o`000S?o0003o`2I<ol0<ol0008co`000`000?ooooooo`24oooo002?oooo00<0000co`0co`000S?o
0003o`2I<ol0<ol0008co`000`000?ooooooo`24oooo002?oooo0P0000<co`000ol0VC?o03?o0002
<ol000<0003oooooool0Q?ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o0002<ol000<0
003oooooool0Q?ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o0002<ol000<0003ooooo
ool0Q?ooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o03?o0002<ol000<0003oooooool0Q?oo
o`00Soooo`030000<ol0<ol0008co`001Ol0VC?o03?o03?o00000027oooo002?oooo00<0000co`0c
o`000S?o0005o`2I<ol0<ol0<ol0000008Ooool008ooool200000c?o0005o`2I<ol0<ol0<ol00000
08Ooool008ooool00`0003?o03?o0002<ol000Go09Tco`0co`0co`000000Qoooo`00Soooo`030000
<ol0<ol0008co`001Ol0VC?o03?o03?o00000027oooo002?oooo00<0000co`0co`000S?o0005o`2I
<ol0<ol0<ol0000008Ooool008ooool00`0003?o03?o0002<ol000Go09Tco`0co`0co`000000Qooo
o`00Soooo`030000<ol0<ol0008co`001Ol0VC?o03?o03?o00000027oooo002?oooo0P0000<co`00
1?l0VC?o03?o000008Soool008ooool00`0003?o03?o0002<ol000Co09Tco`0co`000028oooo002?
oooo00<0000co`0co`000S?o0004o`2I<ol0<ol00000R?ooo`00Soooo`030000<ol0<ol0008co`00
1?l0VC?o03?o000008Soool008ooool00`0003?o03?o0002<ol000Co09Tco`0co`000028oooo002?
oooo00<0000co`0co`000S?o0004o`2I<ol0<ol00000R?ooo`00Soooo`800003<ol000Co09Tco`0c
o`000028oooo002?oooo00<0000co`0co`000S?o0004o`2I<ol0<ol00000R?ooo`00Soooo`030000
<ol0<ol0008co`001?l0VC?o03?o000008Soool008ooool00`0003?o03?o0002<ol000?o09Tco`00
0000ROooo`00Soooo`030000<ol0<ol0008co`000ol0VC?o00000029oooo0029oooo0`0000?oool0
0`0003?o03?o0002<ol000?o09Tco`000000ROooo`00R_ooo`030000oooooooo00;oool00`0003?o
03?o0002<ol000?o09Tco`000000ROooo`00Qoooo`D00003oooo0`00008co`000ol0VC?o00000029
oooo0027oooo00@0003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o
08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOoo
o`030000oooooooo01?oool7<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool02Oooo`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool500000S?o0080000013?o0?ooooooooooo`800004
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`07oooo00<0000co`0co`001C?o00;oool010000?ooooooo`00
00;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_oo
o`030000oooooooo00ooool00`0003?o03?o0005<ol00_ooo`040000oooooooo00000_ooo`040000
oooooooo00001?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000
<ol0<ol000Dco`02oooo00@0003oooooool00003oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000004Oooo`030000<ol0<ol000Dco`02oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool2
00001c?o00?oool200001?ooo`800003oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?
oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.5095 .12361 L
.51441 .12361 L
.51896 .12361 L
.52148 .12361 L
.52221 .12361 L
.52289 .12361 L
s
.52289 .12361 m
.52341 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.46172 .12361 L
.46618 .12361 L
.47106 .12361 L
.47329 .12361 L
.47451 .12361 L
.47567 .12361 L
.47674 .12303 L
.47791 .12184 L
.47994 .1198 L
.49955 .10266 L
.50986 .09515 L
.5149 .09174 L
.51949 .08875 L
.52068 .088 L
.52198 .08719 L
.5232 .08643 L
.52434 .12361 L
.52553 .12361 L
.52686 .12361 L
.52953 .12361 L
.54055 .12361 L
.58076 .12361 L
.61945 .12361 L
.66059 .12361 L
.70021 .12361 L
.73832 .12361 L
.77888 .12361 L
.81792 .12361 L
.85942 .12361 L
.8994 .12361 L
.93787 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000H
oooo00<0003oooooool0>oooo`030000oooooooo03Koool00`000?ooooooo`02oooo0P1VocGoool0
0`000?ooooooo`0ioooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool0<_oo
o`@00004oooo00<0003oooooool0=_ooo`040000oooooooooooo0`1VocGoool00`000?ooooooo`0j
oooo00<0003oooooool05Oooo`005oooo`040000oooooooo0000>oooo`030000oooooooo03Koool0
10000?ooo`1Vo`1Vo`;oool00`1Vooooooooo`0coooo00<0003oooooool0>?ooo`040000oooooooo
00005_ooo`006?ooo`80000koooo0P0003Soool200001?ooo`0306Kooooooooo03;oool20000>ooo
o`80000Goooo002?oooo00<0003oooooool00oooo`0306Kooooooooo08Soool008koool00`1Vo`00
0?ooo`04oooo00<0I_ooooooool0R?ooo`00S?ooo`80I_l00oooo`000?ooo`04oooo00<0I_oooooo
ool0R?ooo`00Roooo`0506Kooooooooooooo000000Goool00`1Vooooooooo`28oooo002:oooo00<0
I_ooooooool00_ooo`030000oooooooo00?oool00`1Vooooooooo`28oooo000@ooooo`00017oool0
01Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`000c?o
0003o`2I<ol0<ol000<co`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0003oooooool02Ooo
o`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000
<ol0<ol000<co`000ol0VC?o03?o000c<ol02@0003Coool00`000?ooooooo`0Eoooo002?oooo00<0
000co`0co`000c?o0003o`2I<ol0<ol002dco`060000EOooo`00Soooo`030000<ol0<ol000<co`00
0ol0VC?o03?o000[<ol00P0005_oool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`00:C?o
0080001Moooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol002Hco`030000Goooo`00Sooo
o`800004<ol000?o09Tco`0co`008c?o00<0001Roooo002?oooo00<0000co`0co`000c?o0003o`2I
<ol0<ol0024co`020000IOooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000P<ol000<0
003oooooool0IOooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000O<ol000<0003ooooo
ool0I_ooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000N<ol000<0003oooooool0Iooo
o`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000L<ol00P0006[oool008ooool2000013?o
0003o`2I<ol0<ol001/co`000`000?ooooooo`1Zoooo002?oooo00<0000co`0co`000c?o0003o`2I
<ol0<ol001Xco`000`000?ooooooo`1[oooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol0
01Tco`000`000?ooooooo`1/oooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol001Tco`00
0`000?ooooooo`1/oooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol001Pco`000`000?oo
ooooo`1]oooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol001Lco`000`000?ooooooo`1^
oooo002?oooo0P0000@co`000ol0VC?o03?o000F<ol000<0003oooooool0Koooo`00Soooo`030000
<ol0<ol000<co`000ol0VC?o03?o000E<ol000<0003oooooool0L?ooo`00Soooo`030000<ol0<ol0
00<co`000ol0VC?o03?o000E<ol000<0003oooooool0L?ooo`00Soooo`030000<ol0<ol000<co`00
0ol0VC?o03?o000D<ol000<0003oooooool0LOooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o
03?o000D<ol000<0003oooooool0LOooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000C
<ol000<0003oooooool0L_ooo`00Soooo`800004<ol000?o09Tco`0co`004c?o00030000oooooooo
07;oool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`004S?o00030000oooooooo07?oool0
08ooool00`0003?o03?o0003<ol000?o09Tco`0co`004S?o00030000oooooooo07?oool008ooool0
0`0003?o03?o0003<ol000?o09Tco`0co`004C?o00030000oooooooo07Coool008ooool00`0003?o
03?o0003<ol000?o09Tco`0co`004C?o00030000oooooooo07Coool008Ooool500000oooo`030000
<ol0<ol000<co`000ol0VC?o03?o000@<ol000<0003oooooool0MOooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o0003<ol000?o09Tco`0co`0043?o00030000oooooooo07Goool008Woool0
0`000?ooooooo`03oooo0`0000<co`000ol0VC?o03?o000?<ol000<0003oooooool0M_ooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o0003<ol000?o09Tco`0co`003c?o00030000oooooooo
07Koool008Woool00`000?ooooooo`03oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000lco`00
0`000?ooooooo`1foooo0028oooo0P0000Goool00`0003?o03?o0003<ol000?o09Tco`0co`003S?o
00030000oooooooo07Ooool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`003S?o00030000
oooooooo07Ooool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`003C?o00030000oooooooo
07Soool008ooool2000013?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1hoooo002?oooo00<0
000co`0co`000c?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1hoooo002?oooo00<0000co`0c
o`000c?o0003o`2I<ol0<ol000`co`000`000?ooooooo`1ioooo002?oooo00<0000co`0co`000c?o
0003o`2I<ol0<ol000`co`000`000?ooooooo`1ioooo002?oooo00<0000co`0co`000c?o0003o`2I
<ol0<ol000`co`000`000?ooooooo`1ioooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol0
00/co`000`000?ooooooo`1joooo002?oooo0P0000@co`000ol0VC?o03?o000;<ol000<0003ooooo
ool0N_ooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000;<ol000<0003oooooool0N_oo
o`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o000;<ol000<0003oooooool0N_ooo`00Sooo
o`030000<ol0<ol000<co`000ol0VC?o03?o000:<ol000<0003oooooool0Noooo`00Soooo`030000
<ol0<ol000<co`000ol0VC?o03?o000:<ol000<0003oooooool0Noooo`00Soooo`030000<ol0<ol0
00<co`000ol0VC?o03?o000:<ol000<0003oooooool0Noooo`00Soooo`030000<ol0<ol000<co`00
0ol0VC?o03?o000:<ol000<0003oooooool0Noooo`00Soooo`800004<ol000?o09Tco`0co`002C?o
00030000oooooooo07coool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`002C?o00030000
oooooooo07coool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`002C?o00030000oooooooo
07coool008ooool00`0003?o03?o0003<ol000?o09Tco`0co`002C?o00030000oooooooo07coool0
08ooool00`0003?o03?o0003<ol000?o09Tco`0co`002C?o00030000oooooooo07coool008ooool0
0`0003?o03?o0003<ol000?o09Tco`0co`0023?o00030000oooooooo07goool008ooool2000013?o
0003o`2I<ol0<ol000Pco`000`000?ooooooo`1moooo002?oooo00<0000co`0co`000c?o0003o`2I
<ol0<ol000Pco`000`000?ooooooo`1moooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol0
00Pco`000`000?ooooooo`1moooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000Lco`00
0`000?ooooooo`1noooo0027oooo100000Coool00`0003?o03?o0003<ol000?o09Tco`0co`001c?o
00030000oooooooo07koool008Ooool00`000?ooooooo`05oooo00<0000co`0co`000c?o0003o`2I
<ol0<ol000Lco`000`000?ooooooo`1noooo0028oooo00<0003oooooool01?ooo`<00003<ol000?o
09Tco`0co`001c?o00030000oooooooo07koool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`000c?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1noooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1ooooo0028oooo0P00
00Goool00`0003?o03?o0003<ol000?o09Tco`0co`001S?o00030000oooooooo07ooool008ooool0
0`0003?o03?o0003<ol000?o09Tco`0co`001S?o00030000oooooooo07ooool008ooool00`0003?o
03?o0003<ol000?o09Tco`0co`001S?o00030000oooooooo07ooool008ooool2000013?o0003o`2I
<ol0<ol000Hco`000`000?ooooooo`1ooooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol0
00Hco`000`000?ooooooo`1ooooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000Dco`00
0`000?ooooooo`20oooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000Dco`000`000?oo
ooooo`20oooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`20
oooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`20oooo002?
oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`20oooo002?oooo0P00
00@co`000ol0VC?o03?o0005<ol000<0003oooooool0P?ooo`00Soooo`030000<ol0<ol000<co`00
0ol0VC?o03?o0005<ol000<0003oooooool0P?ooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o
03?o0004<ol000<0003oooooool0POooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o0004
<ol000<0003oooooool0POooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o0004<ol000<0
003oooooool0POooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o03?o0004<ol000<0003ooooo
ool0POooo`00Soooo`800004<ol000?o09Tco`0co`0013?o00030000oooooooo087oool008ooool0
0`0003?o03?o0003<ol000?o09Tco`0co`0013?o00030000oooooooo087oool008ooool00`0003?o
03?o0003<ol000?o09Tco`0co`0013?o00030000oooooooo087oool008ooool00`0003?o03?o0003
<ol000?o09Tco`0co`000c?o00030000oooooooo08;oool008ooool00`0003?o03?o0003<ol000?o
09Tco`0co`000c?o00030000oooooooo08;oool008ooool00`0003?o03?o0003<ol000?o09Tco`0c
o`000c?o00030000oooooooo08;oool008ooool2000013?o0003o`2I<ol0<ol000<co`000`000?oo
ooooo`22oooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000<co`000`000?ooooooo`22
oooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0<ol000<co`000`000?ooooooo`22oooo002?
oooo00<0000co`0co`000c?o0003o`2I<ol0<ol0008co`000`000?ooooooo`23oooo0028oooo0P00
00Goool00`0003?o03?o0003<ol000?o09Tco`0co`000S?o00030000oooooooo08?oool008Ooool0
10000?ooooooo`0000Coool00`0003?o03?o0003<ol000?o09Tco`0co`000S?o00030000oooooooo
08?oool008Woool00`000?ooooooo`03oooo0`0000<co`000ol0VC?o03?o0002<ol000<0003ooooo
ool0Poooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0003<ol000?o09Tco`0co`000S?o
00030000oooooooo08?oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0003<ol000?o
09Tco`0co`000S?o00030000oooooooo08?oool008Soool200001Oooo`030000<ol0<ol000<co`00
1Ol0VC?o03?o03?o00000026oooo002?oooo00<0000co`0co`000c?o0005o`2I<ol0<ol0<ol00000
08Koool008ooool00`0003?o03?o0003<ol000Go09Tco`0co`0co`000000Q_ooo`00Soooo`030000
<ol0<ol000<co`001Ol0VC?o03?o03?o00000026oooo002?oooo0P0000@co`001Ol0VC?o03?o03?o
00000026oooo002?oooo00<0000co`0co`000c?o0005o`2I<ol0<ol0<ol0000008Koool008ooool0
0`0003?o03?o0003<ol000Go09Tco`0co`0co`000000Q_ooo`00Soooo`030000<ol0<ol000<co`00
1Ol0VC?o03?o03?o00000026oooo002?oooo00<0000co`0co`000c?o0004o`2I<ol0<ol00000Qooo
o`00Soooo`030000<ol0<ol000<co`001?l0VC?o03?o000008Ooool008ooool2000013?o0004o`2I
<ol0<ol00000Qoooo`00Soooo`030000<ol0<ol000<co`001?l0VC?o03?o000008Ooool008ooool0
0`0003?o03?o0003<ol000Co09Tco`0co`000027oooo002?oooo00<0000co`0co`000c?o0004o`2I
<ol0<ol00000Qoooo`00Soooo`030000<ol0<ol000<co`001?l0VC?o03?o000008Ooool008ooool0
0`0003?o03?o0003<ol000Co09Tco`0co`000027oooo002?oooo0P0000@co`000ol0VC?o00000028
oooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0000008Soool008ooool00`0003?o03?o0003
<ol000?o09Tco`000000R?ooo`00Soooo`030000<ol0<ol000<co`000ol0VC?o00000028oooo002?
oooo00<0000co`0co`000c?o0003o`2I<ol0000008Soool008ooool00`0003?o03?o0003<ol000?o
09Tco`000000R?ooo`00Soooo`800004<ol000?o09Tco`000000R?ooo`00Soooo`030000<ol0<ol0
00<co`000ol0VC?o00000028oooo002?oooo00<0000co`0co`000c?o0003o`2I<ol0000008Soool0
08ooool00`0003?o03?o0003<ol000?o09T0003oool0R?ooo`00Soooo`030000<ol0<ol000<co`00
0ol0V@000?ooo`28oooo0029oooo0`0000?oool00`0003?o03?o0003<ol000?o09T0003oool0R?oo
o`00R_ooo`030000oooooooo00;oool00`0003?o03?o0003<ol000?o09T0003oool0R?ooo`00Qooo
o`D00003oooo0`0000<co`000ol0V@000?ooo`28oooo0027oooo00@0003oooooool00004oooo1c?o
08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?
oooo1c?o08[oool008ooool7<ol0R_ooo`00O?ooo`030000oooooooo013oool7<ol02oooo`030000
oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool01_ooo`Lco`0<oooo00<0
003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool5
00000S?o00800003oooo1@0000;oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo0S?o00030000<ol0<ol0008co`07
oooo00<0003oooooool00_ooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0
003oooooool03Oooo`8co`000`0003?o03?o0002<ol01oooo`030000oooooooo00?oool00`000?oo
ooooo`1joooo001koooo00<0003oooooool01@0000coool2<ol000<0000co`0co`000S?o00Ooool0
0`000?ooooooo`02oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool2
<ol000<0000co`0co`000S?o00Ooool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00O?oo
o`030000oooooooo013oool00c?o000000000004<ol01_ooo`800003oooo00<0003oooooool0O?oo
o`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.5095 .12361 L
.51896 .12361 L
.52417 .12361 L
.5256 .12361 L
.52712 .12361 L
.52786 .12361 L
.52856 .12361 L
s
.52856 .12361 m
.52908 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.46172 .12361 L
.46618 .12361 L
.46854 .12361 L
.46984 .12361 L
.47106 .12361 L
.47222 .12279 L
.47348 .12151 L
.47567 .11932 L
.47994 .11523 L
.49955 .09913 L
.50986 .09208 L
.51949 .08602 L
.52434 .08315 L
.52573 .08234 L
.52705 .08159 L
.52824 .08092 L
.52953 .12361 L
.53085 .12361 L
.53231 .12361 L
.53526 .12361 L
.54055 .12361 L
.58076 .12361 L
.61945 .12361 L
.66059 .12361 L
.70021 .12361 L
.73832 .12361 L
.77888 .12361 L
.81792 .12361 L
.85942 .12361 L
.8994 .12361 L
.93787 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`005oooo`@0000ioooo1@0003Koool0
0`000?ooooooo`0goooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0foooo00<0003oooooool00oooo`80I_ldoooo00<0003oooooool0>?ooo`030000oooooooo
01Ooool001Soool00`000?ooooooo`0koooo00<0003oooooool0=_ooo`040000oooooooooooo0P1V
o`03oooo06Kooooo03?oool00`000?ooooooo`0ioooo00<0003oooooool05_ooo`004Oooo`@00004
oooo00<0003oooooool0<_ooo`@00004oooo00<0003oooooool0=_ooo`040000oooo06Ko06Ko0ooo
o`0306Kooooooooo03;oool00`000?ooooooo`0joooo00<0003oooooool05Oooo`005oooo`040000
oooooooo0000>oooo`030000oooooooo03Koool00`00001Vooooo`04oooo00<0I_ooooooool0<_oo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000hoooo0P00
00Goool00`1Vooooooooo`0aoooo0P0003_oool200005oooo`00S_ooo`0306Ko0000oooo00Goool0
0`1Vooooooooo`27oooo002<oooo0P1Vo`03oooo0000oooo00Goool00`1Vooooooooo`27oooo002;
oooo00D0I_ooooooooooool000001_ooo`0306Kooooooooo08Ooool008[oool00`1Vooooooooo`02
oooo00<0003oooooool01?ooo`0306Kooooooooo08Ooool008Woool00`1Vooooooooo`03oooo00<0
003oooooool01?ooo`0306Kooooooooo08Ooool0013ooooo00004Oooo`005_ooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0004<ol000?o09Tco`0co`000S?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0006<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`0013?o0003o`2I
<ol0<ol0038co`090000=?ooo`030000oooooooo01Goool008ooool00`0003?o03?o0004<ol000?o
09Tco`0co`00;3?o00H0001Eoooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol002Xco`02
0000Foooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o000X<ol00P0005goool008ooool0
0`0003?o03?o0004<ol000?o09Tco`0co`009C?o00<0001Ooooo002?oooo0P0000Dco`000ol0VC?o
03?o000R<ol00`0006;oool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`0083?o0080001U
oooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol001lco`000`000?ooooooo`1Uoooo002?
oooo00<0000co`0co`0013?o0003o`2I<ol0<ol001hco`000`000?ooooooo`1Voooo002?oooo00<0
000co`0co`0013?o0003o`2I<ol0<ol001dco`000`000?ooooooo`1Woooo002?oooo00<0000co`0c
o`0013?o0003o`2I<ol0<ol001/co`020000J_ooo`00Soooo`800005<ol000?o09Tco`0co`006S?o
00030000oooooooo06[oool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`006C?o00030000
oooooooo06_oool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`0063?o00030000oooooooo
06coool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`0063?o00030000oooooooo06coool0
08ooool00`0003?o03?o0004<ol000?o09Tco`0co`005c?o00030000oooooooo06goool008ooool0
0`0003?o03?o0004<ol000?o09Tco`0co`005S?o00030000oooooooo06koool008ooool200001C?o
0003o`2I<ol0<ol001Dco`000`000?ooooooo`1_oooo002?oooo00<0000co`0co`0013?o0003o`2I
<ol0<ol001@co`000`000?ooooooo`1`oooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol0
01@co`000`000?ooooooo`1`oooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol001<co`00
0`000?ooooooo`1aoooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol001<co`000`000?oo
ooooo`1aoooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol0018co`000`000?ooooooo`1b
oooo002?oooo0P0000Dco`000ol0VC?o03?o000B<ol000<0003oooooool0L_ooo`00Soooo`030000
<ol0<ol000@co`000ol0VC?o03?o000A<ol000<0003oooooool0Loooo`00Soooo`030000<ol0<ol0
00@co`000ol0VC?o03?o000A<ol000<0003oooooool0Loooo`00Soooo`030000<ol0<ol000@co`00
0ol0VC?o03?o000@<ol000<0003oooooool0M?ooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o
03?o000@<ol000<0003oooooool0M?ooo`00Qoooo`D00003oooo00<0000co`0co`0013?o0003o`2I
<ol0<ol000lco`000`000?ooooooo`1eoooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
00@co`000ol0VC?o03?o000?<ol000<0003oooooool0MOooo`00ROooo`030000oooooooo00?oool3
000013?o0003o`2I<ol0<ol000hco`000`000?ooooooo`1foooo0029oooo00<0003oooooool00ooo
o`030000<ol0<ol000@co`000ol0VC?o03?o000><ol000<0003oooooool0M_ooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o0004<ol000?o09Tco`0co`003S?o00030000oooooooo07Koool0
08Soool200001Oooo`030000<ol0<ol000@co`000ol0VC?o03?o000=<ol000<0003oooooool0Mooo
o`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o000=<ol000<0003oooooool0Moooo`00Sooo
o`030000<ol0<ol000@co`000ol0VC?o03?o000<<ol000<0003oooooool0N?ooo`00Soooo`800005
<ol000?o09Tco`0co`0033?o00030000oooooooo07Soool008ooool00`0003?o03?o0004<ol000?o
09Tco`0co`0033?o00030000oooooooo07Soool008ooool00`0003?o03?o0004<ol000?o09Tco`0c
o`002c?o00030000oooooooo07Woool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`002c?o
00030000oooooooo07Woool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`002c?o00030000
oooooooo07Woool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`002S?o00030000oooooooo
07[oool008ooool200001C?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1joooo002?oooo00<0
000co`0co`0013?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1joooo002?oooo00<0000co`0c
o`0013?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1joooo002?oooo00<0000co`0co`0013?o
0003o`2I<ol0<ol000Tco`000`000?ooooooo`1koooo002?oooo00<0000co`0co`0013?o0003o`2I
<ol0<ol000Tco`000`000?ooooooo`1koooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol0
00Tco`000`000?ooooooo`1koooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol000Tco`00
0`000?ooooooo`1koooo002?oooo0P0000Dco`000ol0VC?o03?o0008<ol000<0003oooooool0O?oo
o`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o0008<ol000<0003oooooool0O?ooo`00Sooo
o`030000<ol0<ol000@co`000ol0VC?o03?o0008<ol000<0003oooooool0O?ooo`00Soooo`030000
<ol0<ol000@co`000ol0VC?o03?o0008<ol000<0003oooooool0O?ooo`00Soooo`030000<ol0<ol0
00@co`000ol0VC?o03?o0008<ol000<0003oooooool0O?ooo`00Soooo`030000<ol0<ol000@co`00
0ol0VC?o03?o0007<ol000<0003oooooool0OOooo`00Soooo`800005<ol000?o09Tco`0co`001c?o
00030000oooooooo07goool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`001c?o00030000
oooooooo07goool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`001c?o00030000oooooooo
07goool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`001S?o00030000oooooooo07koool0
08Ooool400001?ooo`030000<ol0<ol000@co`000ol0VC?o03?o0006<ol000<0003oooooool0O_oo
o`00Qoooo`030000oooooooo00Goool00`0003?o03?o0004<ol000?o09Tco`0co`001S?o00030000
oooooooo07koool008Soool00`000?ooooooo`04oooo0`0000@co`000ol0VC?o03?o0006<ol000<0
003oooooool0O_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o0004<ol000?o09Tco`0c
o`001S?o00030000oooooooo07koool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0004
<ol000?o09Tco`0co`001C?o00030000oooooooo07ooool008Soool200001Oooo`030000<ol0<ol0
00@co`000ol0VC?o03?o0005<ol000<0003oooooool0Ooooo`00Soooo`030000<ol0<ol000@co`00
0ol0VC?o03?o0005<ol000<0003oooooool0Ooooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o
03?o0005<ol000<0003oooooool0Ooooo`00Soooo`800005<ol000?o09Tco`0co`001C?o00030000
oooooooo07ooool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`001C?o00030000oooooooo
07ooool008ooool00`0003?o03?o0004<ol000?o09Tco`0co`0013?o00030000oooooooo083oool0
08ooool00`0003?o03?o0004<ol000?o09Tco`0co`0013?o00030000oooooooo083oool008ooool0
0`0003?o03?o0004<ol000?o09Tco`0co`0013?o00030000oooooooo083oool008ooool00`0003?o
03?o0004<ol000?o09Tco`0co`0013?o00030000oooooooo083oool008ooool00`0003?o03?o0004
<ol000?o09Tco`0co`0013?o00030000oooooooo083oool008ooool200001C?o0003o`2I<ol0<ol0
00@co`000`000?ooooooo`20oooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol000@co`00
0`000?ooooooo`20oooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol000<co`000`000?oo
ooooo`21oooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol000<co`000`000?ooooooo`21
oooo002?oooo00<0000co`0co`0013?o0003o`2I<ol0<ol000<co`000`000?ooooooo`21oooo002?
oooo00<0000co`0co`0013?o0003o`2I<ol0<ol000<co`000`000?ooooooo`21oooo002?oooo0P00
00Dco`000ol0VC?o03?o0003<ol000<0003oooooool0POooo`00Soooo`030000<ol0<ol000@co`00
0ol0VC?o03?o0003<ol000<0003oooooool0POooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o
03?o0003<ol000<0003oooooool0POooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o0002
<ol000<0003oooooool0P_ooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o0002<ol000<0
003oooooool0P_ooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o03?o0002<ol000<0003ooooo
ool0P_ooo`00Soooo`800005<ol000?o09Tco`0co`000S?o00030000oooooooo08;oool008ooool0
0`0003?o03?o0004<ol000?o09Tco`0co`000S?o00030000oooooooo08;oool008ooool00`0003?o
03?o0004<ol000?o09Tco`0co`000S?o00030000oooooooo08;oool008ooool00`0003?o03?o0004
<ol000Go09Tco`0co`0co`000000QOooo`00R?ooo`800005oooo00<0000co`0co`0013?o0005o`2I
<ol0<ol0<ol0000008Goool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0004<ol000Go
09Tco`0co`0co`000000QOooo`00ROooo`030000oooooooo00?oool3000013?o0005o`2I<ol0<ol0
<ol0000008Goool008[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o0005o`2I<ol0<ol0
<ol0000008Goool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0004<ol000Go09Tco`0c
o`0co`000000QOooo`00R?ooo`800005oooo00<0000co`0co`0013?o0004o`2I<ol0<ol00000Q_oo
o`00Soooo`030000<ol0<ol000@co`001?l0VC?o03?o000008Koool008ooool00`0003?o03?o0004
<ol000Co09Tco`0co`000026oooo002?oooo00<0000co`0co`0013?o0004o`2I<ol0<ol00000Q_oo
o`00Soooo`800005<ol000Co09Tco`0co`000026oooo002?oooo00<0000co`0co`0013?o0004o`2I
<ol0<ol00000Q_ooo`00Soooo`030000<ol0<ol000@co`001?l0VC?o03?o000008Koool008ooool0
0`0003?o03?o0004<ol000Co09Tco`0co`000026oooo002?oooo00<0000co`0co`0013?o0003o`2I
<ol0000008Ooool008ooool00`0003?o03?o0004<ol000?o09Tco`000000Qoooo`00Soooo`800005
<ol000?o09Tco`000000Qoooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o00000027oooo002?
oooo00<0000co`0co`0013?o0003o`2I<ol0000008Ooool008ooool00`0003?o03?o0004<ol000?o
09Tco`000000Qoooo`00Soooo`030000<ol0<ol000@co`000ol0VC?o00000027oooo002?oooo00<0
000co`0co`0013?o0003o`2I<ol0000008Ooool008ooool200001C?o0003o`2I0000oooo08Ooool0
08ooool00`0003?o03?o0004<ol000?o09T0003oool0Qoooo`00Soooo`030000<ol0<ol000@co`00
0ol0V@000?ooo`27oooo002?oooo00<0000co`0co`0013?o0003o`2I0000oooo08Ooool008ooool0
0`0003?o03?o0004<ol000?o09T0003oool0Qoooo`00Soooo`030000<ol0<ol000@co`000ol0V@00
0?ooo`27oooo002?oooo0P0000Dco`000ol0V@000?ooo`27oooo002?oooo00<0000co`0co`0013?o
0003o`2I0000oooo08Ooool008ooool00`0003?o03?o0004<ol000?o09T0003oool0Qoooo`00Sooo
o`030000<ol0<ol000@co`000ol0VOooooooo`27oooo002?oooo00<0000co`0co`0013?o0003o`2I
oooooooo08Ooool008Woool300000oooo`030000<ol0<ol000@co`000ol0VOooooooo`27oooo002:
oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000ol0VOooooooo`27oooo0027oooo1@00
00?oool3000013?o0003o`2Ioooooooo08Ooool008Ooool010000?ooooooo`0000Coool7<ol0R_oo
o`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7
<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>oooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o00ooool00`000?oo
ooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002
<ol00P000003<ol0oooooooo00D000000oooo`000000000200000oooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool0
0`0003?o03?o0005<ol01?ooo`050000oooooooooooo000000Koool00`000?ooooooo`1hoooo001g
oooo00<0003oooooool00_ooo`030000oooooooo00ooool00`0003?o03?o0005<ol01?ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo
00D0000>oooo00<0000co`0co`001C?o00Coool00`000?ooooooo`03oooo00<0003oooooool00_oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Aoooo00<0000co`0co`001C?o
00Coool01@000?ooooooooooo`000002oooo00D0003oooooooooool00000N_ooo`00NOooo`030000
oooooooo017oool200001c?o00?oool200001?ooo`800003oooo00<0003oooooool0NOooo`00Sooo
o`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.51896 .12361 L
.52455 .12361 L
.52731 .12361 L
.52986 .12361 L
.53105 .12361 L
.53217 .12361 L
s
.53217 .12361 m
.53269 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.46172 .12361 L
.46388 .12361 L
.46507 .12361 L
.46618 .12361 L
.46682 .12345 L
.46751 .12274 L
.46871 .12151 L
.47106 .11917 L
.47994 .11093 L
.49955 .09583 L
.51949 .08348 L
.52434 .08075 L
.52953 .07794 L
.53106 .07713 L
.53182 .07674 L
.53251 .07637 L
.53382 .12361 L
.5345 .12361 L
.53523 .12361 L
.54055 .12361 L
.57831 .12361 L
.61851 .12361 L
.6572 .12361 L
.69834 .12361 L
.73796 .12361 L
.77607 .12361 L
.81663 .12361 L
.85567 .12361 L
.89717 .12361 L
.93715 .12361 L
.97562 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool200001_ooo`0306Kooooooooo08Koool001Ooool4
0000>Oooo`D0000foooo00<0003oooooool01?ooo`80I_laoooo1@0003Soool400005_ooo`005ooo
o`030000oooooooo03coool00`000?ooooooo`0foooo00<0003oooooool00_ooo`80I_l00oooo`1V
ooooo`0boooo00<0003oooooool0>?ooo`030000oooooooo01Ooool001Soool00`000?ooooooo`0k
oooo00<0003oooooool0=_ooo`030000oooooooo0080I_l3oooo00<0I_ooooooool0<Oooo`030000
oooooooo03Woool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0boooo1000
00Coool00`000?ooooooo`0foooo00<00000I_l0I_l01Oooo`0306Kooooooooo037oool00`000?oo
ooooo`0joooo00<0003oooooool05Oooo`005oooo`040000oooooooo0000>oooo`030000oooooooo
03Koool00`000?ooooooo`05oooo00<0I_ooooooool0<Oooo`030000oooooooo03Soool010000?oo
ooooo`0001Koool001Soool20000>oooo`80000goooo00<0I_l0000000001_ooo`0306Kooooooooo
033oool20000>oooo`80000Goooo002<oooo0P1Vo`03oooo0000oooo00Ooool00`1Vooooooooo`25
oooo002;oooo00D0I_ooooooooooool000002?ooo`0306Kooooooooo08Goool008[oool00`1Voooo
ooooo`02oooo00<0003oooooool01_ooo`0306Kooooooooo08Goool008Woool00`1Vooooooooo`03
oooo00<0003oooooool01_ooo`0306Kooooooooo08Goool008Soool00`1Vooooooooo`04oooo00<0
003oooooool01_ooo`0306Kooooooooo08Goool0013ooooo00004Oooo`005_ooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0005<ol000Go09Tco`0co`0co`00
00002c?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Hco`0R00001_ooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o0005<ol000?o09Tco`0co`00<C?o
00T0000doooo00<0003oooooool05Oooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000[
<ol01P0005Goool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`00:C?o0080001Koooo002?
oooo00<0000co`0co`001C?o0003o`2I<ol0<ol002Lco`020000GOooo`00Soooo`030000<ol0<ol0
00Dco`000ol0VC?o03?o000T<ol00`0005ooool008ooool200001S?o0003o`2I<ol0<ol0024co`03
0000H_ooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000O<ol00P0006Goool008ooool0
0`0003?o03?o0005<ol000?o09Tco`0co`007S?o00030000oooooooo06Goool008ooool00`0003?o
03?o0005<ol000?o09Tco`0co`007C?o00030000oooooooo06Koool008ooool00`0003?o03?o0005
<ol000?o09Tco`0co`0073?o00030000oooooooo06Ooool008ooool00`0003?o03?o0005<ol000?o
09Tco`0co`006S?o0080001Zoooo002?oooo0P0000Hco`000ol0VC?o03?o000I<ol000<0003ooooo
ool0J_ooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000H<ol000<0003oooooool0Jooo
o`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000G<ol000<0003oooooool0K?ooo`00Sooo
o`030000<ol0<ol000Dco`000ol0VC?o03?o000G<ol000<0003oooooool0K?ooo`00Soooo`030000
<ol0<ol000Dco`000ol0VC?o03?o000F<ol000<0003oooooool0KOooo`00Soooo`030000<ol0<ol0
00Dco`000ol0VC?o03?o000E<ol000<0003oooooool0K_ooo`00Soooo`800006<ol000?o09Tco`0c
o`0053?o00030000oooooooo06ooool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`004c?o
00030000oooooooo073oool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`004c?o00030000
oooooooo073oool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`004S?o00030000oooooooo
077oool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`004S?o00030000oooooooo077oool0
08ooool00`0003?o03?o0005<ol000?o09Tco`0co`004C?o00030000oooooooo07;oool008ooool2
00001S?o0003o`2I<ol0<ol0014co`000`000?ooooooo`1boooo002?oooo00<0000co`0co`001C?o
0003o`2I<ol0<ol0010co`000`000?ooooooo`1coooo002?oooo00<0000co`0co`001C?o0003o`2I
<ol0<ol0010co`000`000?ooooooo`1coooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol0
00lco`000`000?ooooooo`1doooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol000lco`00
0`000?ooooooo`1doooo0027oooo1@0000?oool00`0003?o03?o0005<ol000?o09Tco`0co`003S?o
00030000oooooooo07Goool008Woool00`000?ooooooo`03oooo00<0000co`0co`001C?o0003o`2I
<ol0<ol000hco`000`000?ooooooo`1eoooo0029oooo00<0003oooooool00oooo`<00005<ol000?o
09Tco`0co`003C?o00030000oooooooo07Koool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`001C?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1foooo0029oooo00<0003oooooool00ooo
o`030000<ol0<ol000Dco`000ol0VC?o03?o000=<ol000<0003oooooool0M_ooo`00R?ooo`800005
oooo00<0000co`0co`001C?o0003o`2I<ol0<ol000`co`000`000?ooooooo`1goooo002?oooo00<0
000co`0co`001C?o0003o`2I<ol0<ol000`co`000`000?ooooooo`1goooo002?oooo00<0000co`0c
o`001C?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1hoooo002?oooo0P0000Hco`000ol0VC?o
03?o000;<ol000<0003oooooool0N?ooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000;
<ol000<0003oooooool0N?ooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000:<ol000<0
003oooooool0NOooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000:<ol000<0003ooooo
ool0NOooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o000:<ol000<0003oooooool0NOoo
o`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o0009<ol000<0003oooooool0N_ooo`00Sooo
o`800006<ol000?o09Tco`0co`002C?o00030000oooooooo07[oool008ooool00`0003?o03?o0005
<ol000?o09Tco`0co`002C?o00030000oooooooo07[oool008ooool00`0003?o03?o0005<ol000?o
09Tco`0co`002C?o00030000oooooooo07[oool008ooool00`0003?o03?o0005<ol000?o09Tco`0c
o`0023?o00030000oooooooo07_oool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`0023?o
00030000oooooooo07_oool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`0023?o00030000
oooooooo07_oool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`0023?o00030000oooooooo
07_oool008ooool200001S?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1loooo002?oooo00<0
000co`0co`001C?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1loooo002?oooo00<0000co`0c
o`001C?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1loooo002?oooo00<0000co`0co`001C?o
0003o`2I<ol0<ol000Lco`000`000?ooooooo`1loooo002?oooo00<0000co`0co`001C?o0003o`2I
<ol0<ol000Lco`000`000?ooooooo`1loooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol0
00Hco`000`000?ooooooo`1moooo002?oooo0P0000Hco`000ol0VC?o03?o0006<ol000<0003ooooo
ool0OOooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o0006<ol000<0003oooooool0OOoo
o`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o0006<ol000<0003oooooool0OOooo`00Sooo
o`030000<ol0<ol000Dco`000ol0VC?o03?o0005<ol000<0003oooooool0O_ooo`00Qoooo`@00004
oooo00<0000co`0co`001C?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1noooo0027oooo00<0
003oooooool01Oooo`030000<ol0<ol000Dco`000ol0VC?o03?o0005<ol000<0003oooooool0O_oo
o`00R?ooo`030000oooooooo00Coool300001C?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1n
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000Dco`000ol0VC?o03?o0005<ol000<0
003oooooool0O_ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Dco`000ol0VC?o
03?o0004<ol000<0003oooooool0Ooooo`00R?ooo`800005oooo00<0000co`0co`001C?o0003o`2I
<ol0<ol000@co`000`000?ooooooo`1ooooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol0
00@co`000`000?ooooooo`1ooooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol000@co`00
0`000?ooooooo`1ooooo002?oooo0P0000Hco`000ol0VC?o03?o0004<ol000<0003oooooool0Oooo
o`00Soooo`030000<ol0<ol000Dco`000ol0VC?o03?o0004<ol000<0003oooooool0Ooooo`00Sooo
o`030000<ol0<ol000Dco`000ol0VC?o03?o0003<ol000<0003oooooool0P?ooo`00Soooo`030000
<ol0<ol000Dco`000ol0VC?o03?o0003<ol000<0003oooooool0P?ooo`00Soooo`030000<ol0<ol0
00Dco`000ol0VC?o03?o0003<ol000<0003oooooool0P?ooo`00Soooo`030000<ol0<ol000Dco`00
0ol0VC?o03?o0003<ol000<0003oooooool0P?ooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o
03?o0003<ol000<0003oooooool0P?ooo`00Soooo`800006<ol000?o09Tco`0co`000c?o00030000
oooooooo083oool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`000c?o00030000oooooooo
083oool008ooool00`0003?o03?o0005<ol000?o09Tco`0co`000S?o00030000oooooooo087oool0
08ooool00`0003?o03?o0005<ol000?o09Tco`0co`000S?o00030000oooooooo087oool008ooool0
0`0003?o03?o0005<ol000?o09Tco`0co`000S?o00030000oooooooo087oool008ooool00`0003?o
03?o0005<ol000?o09Tco`0co`000S?o00030000oooooooo087oool008ooool200001S?o0003o`2I
<ol0<ol0008co`000`000?ooooooo`21oooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol0
008co`000`000?ooooooo`21oooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0<ol0008co`00
0`000?ooooooo`21oooo002?oooo00<0000co`0co`001C?o0005o`2I<ol0<ol0<ol0000008Coool0
08ooool00`0003?o03?o0005<ol000Go09Tco`0co`0co`000000Q?ooo`00Soooo`030000<ol0<ol0
00Dco`001Ol0VC?o03?o03?o00000024oooo002?oooo0P0000Hco`001Ol0VC?o03?o03?o00000024
oooo002?oooo00<0000co`0co`001C?o0005o`2I<ol0<ol0<ol0000008Coool008ooool00`0003?o
03?o0005<ol000Go09Tco`0co`0co`000000Q?ooo`00Soooo`030000<ol0<ol000Dco`001?l0VC?o
03?o000008Goool008Soool200001Oooo`030000<ol0<ol000Dco`001?l0VC?o03?o000008Goool0
08Ooool010000?ooooooo`0000Coool00`0003?o03?o0005<ol000Co09Tco`0co`000025oooo0029
oooo00<0003oooooool00oooo`<00005<ol000Co09Tco`0co`000025oooo002:oooo00<0003ooooo
ool00_ooo`030000<ol0<ol000Dco`001?l0VC?o03?o000008Goool008Ooool010000?ooooooo`00
00Coool00`0003?o03?o0005<ol000Co09Tco`0co`000025oooo0028oooo0P0000Goool00`0003?o
03?o0005<ol000?o09Tco`000000Q_ooo`00Soooo`030000<ol0<ol000Dco`000ol0VC?o00000026
oooo002?oooo00<0000co`0co`001C?o0003o`2I<ol0000008Koool008ooool00`0003?o03?o0005
<ol000?o09Tco`000000Q_ooo`00Soooo`800006<ol000?o09Tco`000000Q_ooo`00Soooo`030000
<ol0<ol000Dco`000ol0VC?o00000026oooo002?oooo00<0000co`0co`001C?o0003o`2I<ol00000
08Koool008ooool00`0003?o03?o0005<ol000?o09Tco`000000Q_ooo`00Soooo`030000<ol0<ol0
00Dco`000ol0V@000?ooo`26oooo002?oooo00<0000co`0co`001C?o0003o`2I0000oooo08Koool0
08ooool200001S?o0003o`2I0000oooo08Koool008ooool00`0003?o03?o0005<ol000?o09T0003o
ool0Q_ooo`00Soooo`030000<ol0<ol000Dco`000ol0V@000?ooo`26oooo002?oooo00<0000co`0c
o`001C?o0003o`2I0000oooo08Koool008ooool00`0003?o03?o0005<ol000?o09T0003oool0Q_oo
o`00Soooo`030000<ol0<ol000Dco`000ol0V@000?ooo`26oooo002?oooo0P0000Hco`000ol0VOoo
ooooo`26oooo002?oooo00<0000co`0co`001C?o0003o`2Ioooooooo08Koool008ooool00`0003?o
03?o0005<ol000?o09Woooooool0Q_ooo`00Soooo`030000<ol0<ol000Dco`000ol0VOooooooo`26
oooo002?oooo00<0000co`0co`001C?o0003o`2Ioooooooo08Koool008ooool00`0003?o03?o0005
<ol000?o09Woooooool0Q_ooo`00Soooo`800006<ol000?o09Woooooool0Q_ooo`00Soooo`030000
<ol0<ol000Dco`000ol0VOooooooo`26oooo002?oooo00<0000co`0co`001C?o0003o`2Ioooooooo
08Koool008ooool00`0003?o03?o0004<ol000<0003o09Woool0Qoooo`00Soooo`030000<ol0<ol0
00@co`000`000?l0VOooo`27oooo0029oooo0`0000?oool00`0003?o03?o0004<ol000<0003o09Wo
ool0Qoooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003o09Woool0Qooo
o`00Qoooo`D00003oooo0`0000@co`000`000?l0VOooo`27oooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Koool500000S?o008000000c?o0?ooooooo`0500000oooo`<00002oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01ooo
o`030000<ol0<ol000Dco`04oooo00<0003oooooool01?ooo`050000oooooooooooo000007[oool0
07Ooool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000<ol0<ol000Dco`04oooo00@0
003oooooooooool500000oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_oo
o`030000<ol0<ol000Dco`04oooo00D0003oooooooooool000000_ooo`050000oooooooooooo0000
07[oool007Soool01@000?ooooooooooo`00000Aoooo00<0000co`0co`001C?o00Coool00`000?oo
ooooo`02oooo00<0003oool000000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0A
oooo0P0000Lco`03oooo0P0000Goool200000_ooo`030000oooooooo07Woool008ooool7<ol0R_oo
o`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.51896 .12361 L
.52455 .12361 L
.52986 .12361 L
.53463 .12361 L
.53594 .12361 L
.53666 .12361 L
.53733 .12361 L
s
.53733 .12361 m
.53786 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.44268 .12361 L
.45262 .12361 L
.45734 .12361 L
.45963 .12361 L
.46063 .12361 L
.46172 .12361 L
.46283 .12265 L
.46388 .12158 L
.46618 .11928 L
.47106 .11463 L
.47994 .10688 L
.49955 .09274 L
.51949 .08111 L
.52953 .07584 L
.53228 .07446 L
.53523 .07302 L
.53666 .07233 L
.53737 .07199 L
.53802 .07168 L
.53923 .12361 L
.54055 .12361 L
.57982 .12361 L
.61757 .12361 L
.65777 .12361 L
.69646 .12361 L
.7376 .12361 L
.77723 .12361 L
.81533 .12361 L
.8559 .12361 L
.89494 .12361 L
.93644 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo00Koool206KoQ_ooo`00Soooo`800005oooo101VohKoool001Ooool4
0000>Oooo`D0000foooo00<0003oooooool00oooo`0506Kooooooooooooo06Ko02ooool50000>?oo
o`@0000Foooo000Goooo00<0003oooooool0??ooo`030000oooooooo03Koool00`000?ooooooo`02
oooo00<0I_ooooooool00_ooo`0306Kooooooooo02ooool00`000?ooooooo`0hoooo00<0003ooooo
ool05oooo`006?ooo`030000oooooooo03_oool00`000?ooooooo`0foooo00<0003oooooool00P1V
o`Goool00`1Vooooooooo`0_oooo00<0003oooooool0>Oooo`030000oooooooo01Koool0017oool4
00001?ooo`030000oooooooo03;oool400001?ooo`030000oooooooo03Koool00`00001Vo`1Vo`07
oooo00<0I_ooooooool0;oooo`030000oooooooo03[oool00`000?ooooooo`0Eoooo000Goooo00@0
003oooooool0000koooo00<0003oooooool0=_ooo`030000oooooooo00Ooool00`1Vooooooooo`0_
oooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`80000koooo0P0003Koool2
06Ko0P0000Soool00`1Vooooooooo`0^oooo0P0003_oool200005oooo`00Roooo`80I_l2oooo00<0
003oooooool01oooo`0306Kooooooooo08Coool008[oool00`1Vooooooooo`02oooo00<0003ooooo
ool01oooo`0306Kooooooooo08Coool008Woool00`1Vooooooooo`03oooo00<0003oooooool01ooo
o`0306Kooooooooo08Coool008Soool00`1Vooooooooo`04oooo00<0003oooooool01oooo`0306Ko
oooooooo08Coool008Koool206Ko1oooo`030000oooooooo00Ooool00`1Vooooooooo`24oooo000@
ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
000co`0co`001S?o0004o`2I<ol0<ol000002c?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000oooooooo00Woool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o
03?o0006<ol000?o09Tco`0co`00<3?o00T0000doooo00<0003oooooool05Oooo`00Soooo`030000
<ol0<ol000Hco`000ol0VC?o03?o000Z<ol01P0005Goool008ooool00`0003?o03?o0006<ol000?o
09Tco`0co`00:3?o0080001Koooo002?oooo00<0000co`0co`001S?o0003o`2I<ol0<ol002Hco`02
0000GOooo`00Soooo`030000<ol0<ol000Hco`000ol0VC?o03?o000S<ol00`0005ooool008ooool2
00001c?o0003o`2I<ol0<ol0020co`030000H_ooo`00Soooo`030000<ol0<ol000Hco`000ol0VC?o
03?o000N<ol00P0006Goool008ooool00`0003?o03?o0006<ol000?o09Tco`0co`007C?o00030000
oooooooo06Goool008ooool00`0003?o03?o0006<ol000?o09Tco`0co`0073?o00030000oooooooo
06Koool008ooool00`0003?o03?o0006<ol000?o09Tco`0co`006c?o00030000oooooooo06Ooool0
08ooool00`0003?o03?o0006<ol000?o09Tco`0co`006C?o0080001Zoooo002?oooo0P0000Lco`00
0ol0VC?o03?o000H<ol000<0003oooooool0J_ooo`00Soooo`030000<ol0<ol000Hco`000ol0VC?o
03?o000G<ol000<0003oooooool0Joooo`00Soooo`030000<ol0<ol000Hco`000ol0VC?o03?o000F
<ol000<0003oooooool0K?ooo`00Soooo`030000<ol0<ol000Hco`000ol0VC?o03?o000F<ol000<0
003oooooool0K?ooo`00Soooo`030000<ol0<ol000Hco`000ol0VC?o03?o000E<ol000<0003ooooo
ool0KOooo`00Soooo`030000<ol0<ol000Hco`000ol0VC?o03?o000D<ol000<0003oooooool0K_oo
o`00Soooo`800007<ol000?o09Tco`0co`004c?o00030000oooooooo06ooool008ooool00`0003?o
03?o0006<ol000?o09Tco`0co`004S?o00030000oooooooo073oool008ooool00`0003?o03?o0006
<ol000?o09Tco`0co`004S?o00030000oooooooo073oool008ooool00`0003?o03?o0006<ol000?o
09Tco`0co`004C?o00030000oooooooo077oool008ooool00`0003?o03?o0006<ol000?o09Tco`0c
o`004C?o00030000oooooooo077oool008ooool00`0003?o03?o0006<ol000?o09Tco`0co`0043?o
00030000oooooooo07;oool008ooool200001c?o0003o`2I<ol0<ol0010co`000`000?ooooooo`1b
oooo002?oooo00<0000co`0co`001S?o0003o`2I<ol0<ol000lco`000`000?ooooooo`1coooo002?
oooo00<0000co`0co`001S?o0003o`2I<ol0<ol000lco`000`000?ooooooo`1coooo002?oooo00<0
000co`0co`001S?o0003o`2I<ol0<ol000hco`000`000?ooooooo`1doooo002?oooo00<0000co`0c
o`001S?o0003o`2I<ol0<ol000hco`000`000?ooooooo`1doooo0027oooo1@0000?oool00`0003?o
03?o0006<ol000?o09Tco`0co`003C?o00030000oooooooo07Goool008Woool00`000?ooooooo`03
oooo00<0000co`0co`001S?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1eoooo0029oooo00<0
003oooooool00oooo`<00006<ol000?o09Tco`0co`0033?o00030000oooooooo07Koool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`001S?o0003o`2I<ol0<ol000`co`000`000?ooooooo`1f
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000Hco`000ol0VC?o03?o000<<ol000<0
003oooooool0M_ooo`00R?ooo`800005oooo00<0000co`0co`001S?o0003o`2I<ol0<ol000/co`00
0`000?ooooooo`1goooo002?oooo00<0000co`0co`001S?o0003o`2I<ol0<ol000/co`000`000?oo
ooooo`1goooo002?oooo00<0000co`0co`001S?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1h
oooo002?oooo0P0000Lco`000ol0VC?o03?o000:<ol000<0003oooooool0N?ooo`00Soooo`030000
<ol0<ol000Hco`000ol0VC?o03?o000:<ol000<0003oooooool0N?ooo`00Soooo`030000<ol0<ol0
00Hco`000ol0VC?o03?o0009<ol000<0003oooooool0NOooo`00Soooo`030000<ol0<ol000Hco`00
0ol0VC?o03?o0009<ol000<0003oooooool0NOooo`00Soooo`030000<ol0<ol000Hco`000ol0VC?o
03?o0009<ol000<0003oooooool0NOooo`00Soooo`030000<ol0<ol000Hco`000ol0VC?o03?o0008
<ol000<0003oooooool0N_ooo`00Soooo`800007<ol000?o09Tco`0co`0023?o00030000oooooooo
07[oool008ooool00`0003?o03?o0006<ol000?o09Tco`0co`0023?o00030000oooooooo07[oool0
08ooool00`0003?o03?o0006<ol000?o09Tco`0co`0023?o00030000oooooooo07[oool008ooool0
0`0003?o03?o0006<ol000?o09Tco`0co`001c?o00030000oooooooo07_oool008ooool00`0003?o
03?o0006<ol000?o09Tco`0co`001c?o00030000oooooooo07_oool008ooool00`0003?o03?o0006
<ol000?o09Tco`0co`001c?o00030000oooooooo07_oool008ooool00`0003?o03?o0006<ol000?o
09Tco`0co`001c?o00030000oooooooo07_oool008ooool200001c?o0003o`2I<ol0<ol000Hco`00
0`000?ooooooo`1loooo002?oooo00<0000co`0co`001S?o0003o`2I<ol0<ol000Hco`000`000?oo
ooooo`1loooo002?oooo00<0000co`0co`001S?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1l
oooo002?oooo00<0000co`0co`001S?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1loooo002?
oooo00<0000co`0co`001S?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1loooo002?oooo00<0
000co`0co`001S?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1moooo002?oooo0P0000Lco`00
0ol0VC?o03?o0005<ol000<0003oooooool0OOooo`00Soooo`030000<ol0<ol000Hco`000ol0VC?o
03?o0005<ol000<0003oooooool0OOooo`00Soooo`030000<ol0<ol000Hco`000ol0VC?o03?o0005
<ol000<0003oooooool0OOooo`00Soooo`030000<ol0<ol000Hco`000ol0VC?o03?o0004<ol000<0
003oooooool0O_ooo`00Qoooo`@00004oooo00<0000co`0co`001S?o0003o`2I<ol0<ol000@co`00
0`000?ooooooo`1noooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol000Hco`000ol0VC?o
03?o0004<ol000<0003oooooool0O_ooo`00R?ooo`030000oooooooo00Coool300001S?o0003o`2I
<ol0<ol000@co`000`000?ooooooo`1noooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
00Lco`000ol0VC?o03?o0003<ol000<0003oooooool0O_ooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol000Lco`000ol0VC?o03?o0002<ol000<0003oooooool0Ooooo`00R?ooo`800005
oooo00<0000co`0co`001c?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1ooooo002?oooo00<0
000co`0co`001c?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1ooooo002?oooo00<0000co`0c
o`001c?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1ooooo002?oooo0P0000Pco`000ol0VC?o
03?o0002<ol000<0003oooooool0Ooooo`00Soooo`030000<ol0<ol000Lco`000ol0VC?o03?o0002
<ol000<0003oooooool0Ooooo`00Soooo`030000<ol0<ol000Lco`001Ol0VC?o03?o03?o00000022
oooo002?oooo00<0000co`0co`001c?o0005o`2I<ol0<ol0<ol0000008;oool008ooool00`0003?o
03?o0007<ol000Go09Tco`0co`0co`000000P_ooo`00Soooo`030000<ol0<ol000Lco`001Ol0VC?o
03?o03?o00000022oooo002?oooo00<0000co`0co`001c?o0005o`2I<ol0<ol0<ol0000008;oool0
08ooool2000023?o0005o`2I<ol0<ol0<ol0000008;oool008ooool00`0003?o03?o0007<ol000Go
09Tco`0co`0co`000000P_ooo`00Soooo`030000<ol0<ol000Lco`001?l0VC?o03?o000008?oool0
08ooool00`0003?o03?o0007<ol000Co09Tco`0co`000023oooo002?oooo00<0000co`0co`001c?o
0004o`2I<ol0<ol00000Poooo`00Soooo`030000<ol0<ol000Lco`001?l0VC?o03?o000008?oool0
08ooool2000023?o0004o`2I<ol0<ol00000Poooo`00Soooo`030000<ol0<ol000Lco`001?l0VC?o
03?o000008?oool008ooool00`0003?o03?o0007<ol000Co09Tco`0co`000023oooo002?oooo00<0
000co`0co`001c?o0003o`2I<ol0000008Coool008ooool00`0003?o03?o0007<ol000?o09Tco`00
0000Q?ooo`00Soooo`030000<ol0<ol000Lco`000ol0VC?o00000024oooo002?oooo0P0000Pco`00
0ol0VC?o00000024oooo002?oooo00<0000co`0co`001c?o0003o`2I<ol0000008Coool008ooool0
0`0003?o03?o0007<ol000?o09Tco`000000Q?ooo`00Soooo`030000<ol0<ol000Lco`000ol0V@00
0?ooo`24oooo0028oooo0P0000Goool00`0003?o03?o0007<ol000?o09T0003oool0Q?ooo`00Qooo
o`040000oooooooo00001?ooo`030000<ol0<ol000Lco`000ol0V@000?ooo`24oooo0029oooo00<0
003oooooool00oooo`<00007<ol000?o09T0003oool0Q?ooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o0007<ol000?o09T0003oool0Q?ooo`00Qoooo`040000oooooooo00001?ooo`030000
<ol0<ol000Lco`000ol0V@000?ooo`24oooo0028oooo0P0000Goool00`0003?o03?o0007<ol000?o
09Woooooool0Q?ooo`00Soooo`030000<ol0<ol000Lco`000ol0VOooooooo`24oooo002?oooo00<0
000co`0co`001c?o0003o`2Ioooooooo08Coool008ooool00`0003?o03?o0007<ol000?o09Wooooo
ool0Q?ooo`00Soooo`800008<ol000?o09Woooooool0Q?ooo`00Soooo`030000<ol0<ol000Lco`00
0ol0VOooooooo`24oooo002?oooo00<0000co`0co`001c?o0003o`2Ioooooooo08Coool008ooool0
0`0003?o03?o0007<ol000?o09Woooooool0Q?ooo`00Soooo`030000<ol0<ol000Hco`000`000?l0
VOooo`25oooo002?oooo00<0000co`0co`001S?o00030000o`2Ioooo08Goool008ooool200001c?o
00030000o`2Ioooo08Goool008ooool00`0003?o03?o0006<ol000<0003o09Woool0QOooo`00Sooo
o`030000<ol0<ol000Hco`000`000?l0VOooo`25oooo002?oooo00<0000co`0co`001S?o00030000
o`2Ioooo08Goool008ooool00`0003?o03?o0006<ol000<0003o09Woool0QOooo`00Soooo`030000
<ol0<ol000Hco`000`000?l0VOooo`25oooo002?oooo0P0000Hco`000`000?ooool0V@26oooo002?
oooo00<0000co`0co`001C?o00030000ooooo`2I08Koool008ooool00`0003?o03?o0005<ol000<0
003ooooo09T0Q_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooool0V@26oooo002?oooo00<0
000co`0co`001C?o00030000ooooo`2I08Koool008ooool00`0003?o03?o0005<ol000<0003ooooo
09T0Q_ooo`00Soooo`800006<ol000<0003ooooo09T0Q_ooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooool0V@26oooo002?oooo00<0000co`0co`001C?o00030000ooooo`2I08Koool008ooool0
0`0003?o03?o0004<ol000@0003ooooooooo09V6oooo002?oooo00<0000co`0co`0013?o00040000
ooooooooo`2IQ_ooo`00ROooo`<00003oooo00<0000co`0co`0013?o00040000ooooooooo`2IQ_oo
o`00R_ooo`030000oooooooo00;oool00`0003?o03?o0004<ol000@0003ooooooooo09V6oooo0027
oooo1@0000?oool3000013?o00040000ooooooooo`2IQ_ooo`00Qoooo`040000oooooooo00001?oo
o`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7<ol0R_oo
o`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?ooooooo`0Coooo1c?o00koool0
0`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo00Woool7<ol03ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06
oooo1@00008co`02000000<co`3oooooool01@000004oooo0000000000001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Ooool00`0003?o03?o0005<ol01?ooo`050000oooooooooooo000000;oool01@000?oooooooooo
o`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo00ooool00`0003?o03?o0005
<ol01?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000>oooo00<0000co`0co`001C?o00Coool010000?oooooooooo
o`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000017oool00`0003?o
03?o0005<ol01?ooo`030000oooooooo00;oool00`000?ooooooo`03oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo017oool200001c?o00?oool200001?ooo`<00002oooo00<0003ooooo
ool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53057 .12361 L
.53543 .12361 L
.53984 .12361 L
.54098 .12361 L
.54221 .12361 L
s
.54221 .12361 m
.54267 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.44268 .12361 L
.44778 .12361 L
.45262 .12361 L
.45473 .12361 L
.45588 .12361 L
.45697 .12361 L
.45826 .12245 L
.45943 .12126 L
.46172 .11899 L
.50027 .08944 L
.52021 .07855 L
.53037 .0735 L
.53597 .07087 L
.53872 .0696 L
.53993 .06906 L
.54127 .06846 L
.5425 .06791 L
.54366 .12361 L
.54488 .12361 L
.54619 .12361 L
.55154 .12361 L
.56091 .12361 L
.57924 .12361 L
.62038 .12361 L
.66001 .12361 L
.69811 .12361 L
.73868 .12361 L
.77772 .12361 L
.81922 .12361 L
.8592 .12361 L
.89767 .12361 L
.93859 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool01ooo
o`80I_n5oooo002?oooo00<0003oooooool01_ooo`<0I_n5oooo002?oooo0P0000Goool206Ko0_oo
o`0306Kooooooooo08?oool001Ooool40000>Oooo`D0000foooo00<0003oooooool00_ooo`80I_l4
oooo00<0I_ooooooool0;?ooo`D0000hoooo100001Koool001Ooool00`000?ooooooo`0loooo00<0
003oooooool0=_ooo`030000oooooooo0080I_l6oooo00<0I_ooooooool0;_ooo`030000oooooooo
03Soool00`000?ooooooo`0Goooo000Hoooo00<0003oooooool0>oooo`030000oooooooo03Koool0
0`00001Vo`1Vo`08oooo00<0I_ooooooool0;_ooo`030000oooooooo03Woool00`000?ooooooo`0F
oooo000Aoooo100000Coool00`000?ooooooo`0boooo100000Coool00`000?ooooooo`0foooo00<0
003oooooool02?ooo`0306Kooooooooo02koool00`000?ooooooo`0joooo00<0003oooooool05Ooo
o`005oooo`040000oooooooo0000>oooo`030000oooooooo03Coool206Ko00<0003oooooool02?oo
o`0306Kooooooooo02koool00`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo0P00
03_oool20000=Oooo`0306Kooooooooo00800009oooo00<0I_ooooooool0;Oooo`80000koooo0P00
01Ooool008_oool01@1Vooooooooooooo`00000:oooo00<0I_ooooooool0Poooo`00ROooo`80I_l4
oooo00<0003oooooool02?ooo`0306Kooooooooo08?oool008Soool00`1Vooooooooo`04oooo00<0
003oooooool02?ooo`0306Kooooooooo08?oool008Koool206Ko1oooo`030000oooooooo00Soool0
0`1Vooooooooo`23oooo0025oooo00<0I_ooooooool01oooo`030000oooooooo00Soool00`1Voooo
ooooo`23oooo000@ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0000co`0co`0023?o0003o`2I0000<ol000Xco`000`0003?o03?o0009<ol000<0
000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006<ol08P0000Koool00`000?oo
ooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0i
oooo00<0000co`0co`0023?o0003o`2I<ol0<ol002hco`090000=?ooo`030000oooooooo01Goool0
08ooool00`0003?o03?o0008<ol000?o09Tco`0co`00:3?o00H0001Eoooo002?oooo00<0000co`0c
o`0023?o0003o`2I<ol0<ol002Hco`020000Foooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o
03?o000T<ol00P0005goool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`008C?o00<0001O
oooo002?oooo0P0000Tco`000ol0VC?o03?o000N<ol00`0006;oool008ooool00`0003?o03?o0008
<ol000?o09Tco`0co`0073?o0080001Uoooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol0
01/co`000`000?ooooooo`1Uoooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol001Xco`00
0`000?ooooooo`1Voooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol001Tco`000`000?oo
ooooo`1Woooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol001Lco`020000J_ooo`00Sooo
o`800009<ol000?o09Tco`0co`005S?o00030000oooooooo06[oool008ooool00`0003?o03?o0008
<ol000?o09Tco`0co`005C?o00030000oooooooo06_oool008ooool00`0003?o03?o0008<ol000?o
09Tco`0co`0053?o00030000oooooooo06coool008ooool00`0003?o03?o0008<ol000?o09Tco`0c
o`0053?o00030000oooooooo06coool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`004c?o
00030000oooooooo06goool008ooool00`0003?o03?o0008<ol000?o09Tco`0co`004S?o00030000
oooooooo06koool008ooool200002C?o0003o`2I<ol0<ol0014co`000`000?ooooooo`1_oooo002?
oooo00<0000co`0co`0023?o0003o`2I<ol0<ol0010co`000`000?ooooooo`1`oooo002?oooo00<0
000co`0co`0023?o0003o`2I<ol0<ol0010co`000`000?ooooooo`1`oooo002?oooo00<0000co`0c
o`0023?o0003o`2I<ol0<ol000lco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`0023?o
0003o`2I<ol0<ol000lco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`0023?o0003o`2I
<ol0<ol000hco`000`000?ooooooo`1boooo002?oooo0P0000Tco`000ol0VC?o03?o000><ol000<0
003oooooool0L_ooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o000=<ol000<0003ooooo
ool0Loooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o000=<ol000<0003oooooool0Looo
o`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o000<<ol000<0003oooooool0M?ooo`00Sooo
o`030000<ol0<ol000Pco`000ol0VC?o03?o000<<ol000<0003oooooool0M?ooo`00Qoooo`D00003
oooo00<0000co`0co`0023?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1eoooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol000Pco`000ol0VC?o03?o000;<ol000<0003oooooool0MOoo
o`00ROooo`030000oooooooo00?oool3000023?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1f
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000Pco`000ol0VC?o03?o000:<ol000<0
003oooooool0M_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o0008<ol000?o09Tco`0c
o`002S?o00030000oooooooo07Koool008Soool200001Oooo`030000<ol0<ol000Pco`000ol0VC?o
03?o0009<ol000<0003oooooool0Moooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o0009
<ol000<0003oooooool0Moooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o0008<ol000<0
003oooooool0N?ooo`00Soooo`800009<ol000?o09Tco`0co`0023?o00030000oooooooo07Soool0
08ooool00`0003?o03?o0008<ol000?o09Tco`0co`0023?o00030000oooooooo07Soool008ooool0
0`0003?o03?o0008<ol000?o09Tco`0co`001c?o00030000oooooooo07Woool008ooool00`0003?o
03?o0008<ol000?o09Tco`0co`001c?o00030000oooooooo07Woool008ooool00`0003?o03?o0008
<ol000?o09Tco`0co`001c?o00030000oooooooo07Woool008ooool00`0003?o03?o0008<ol000?o
09Tco`0co`001S?o00030000oooooooo07[oool008ooool200002C?o0003o`2I<ol0<ol000Hco`00
0`000?ooooooo`1joooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol000Hco`000`000?oo
ooooo`1joooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1j
oooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1koooo002?
oooo00<0000co`0co`0023?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1koooo002?oooo00<0
000co`0co`0023?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1koooo002?oooo00<0000co`0c
o`0023?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1koooo002?oooo0P0000Tco`000ol0VC?o
03?o0004<ol000<0003oooooool0O?ooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o0004
<ol000<0003oooooool0O?ooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o0004<ol000<0
003oooooool0O?ooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o0004<ol000<0003ooooo
ool0O?ooo`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o0004<ol000<0003oooooool0O?oo
o`00Soooo`030000<ol0<ol000Pco`000ol0VC?o03?o0003<ol000<0003oooooool0OOooo`00Sooo
o`800009<ol000?o09Tco`0co`000c?o00030000oooooooo07goool008ooool00`0003?o03?o0008
<ol000?o09Tco`0co`000c?o00030000oooooooo07goool008ooool00`0003?o03?o0008<ol000?o
09Tco`0co`000c?o00030000oooooooo07goool008ooool00`0003?o03?o0008<ol000?o09Tco`0c
o`000S?o00030000oooooooo07koool008Ooool400001?ooo`030000<ol0<ol000Pco`000ol0VC?o
03?o0002<ol000<0003oooooool0O_ooo`00Qoooo`030000oooooooo00Goool00`0003?o03?o0008
<ol000?o09Tco`0co`000S?o00030000oooooooo07koool008Soool00`000?ooooooo`04oooo0`00
00Pco`000ol0VC?o03?o0002<ol000<0003oooooool0O_ooo`00ROooo`030000oooooooo00?oool0
0`0003?o03?o0008<ol000?o09Tco`0co`000S?o00030000oooooooo07koool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o0008<ol000Go09Tco`0co`0co`000000POooo`00R?ooo`800005
oooo00<0000co`0co`0023?o0005o`2I<ol0<ol0<ol00000087oool008ooool00`0003?o03?o0008
<ol000Go09Tco`0co`0co`000000POooo`00Soooo`030000<ol0<ol000Pco`001Ol0VC?o03?o03?o
00000021oooo002?oooo0P0000Tco`001Ol0VC?o03?o03?o00000021oooo002?oooo00<0000co`0c
o`0023?o0005o`2I<ol0<ol0<ol00000087oool008ooool00`0003?o03?o0008<ol000Co09Tco`0c
o`000022oooo002?oooo00<0000co`0co`0023?o0004o`2I<ol0<ol00000P_ooo`00Soooo`030000
<ol0<ol000Pco`001?l0VC?o03?o000008;oool008ooool00`0003?o03?o0008<ol000Co09Tco`0c
o`000022oooo002?oooo00<0000co`0co`0023?o0004o`2I<ol0<ol00000P_ooo`00Soooo`800009
<ol000Co09Tco`0co`000022oooo002?oooo00<0000co`0co`0023?o0004o`2I<ol0<ol00000P_oo
o`00Soooo`030000<ol0<ol000Pco`000ol0VC?o00000023oooo002?oooo00<0000co`0co`0023?o
0003o`2I<ol0000008?oool008ooool00`0003?o03?o0008<ol000?o09Tco`000000Poooo`00Sooo
o`030000<ol0<ol000Pco`000ol0VC?o00000023oooo002?oooo0P0000Tco`000ol0VC?o00000023
oooo002?oooo00<0000co`0co`0023?o0003o`2I<ol0000008?oool008ooool00`0003?o03?o0008
<ol000?o09Tco`000000Poooo`00Soooo`030000<ol0<ol000Pco`000ol0V@000?ooo`23oooo002?
oooo00<0000co`0co`0023?o0003o`2I0000oooo08?oool008ooool00`0003?o03?o0008<ol000?o
09T0003oool0Poooo`00Soooo`800009<ol000?o09T0003oool0Poooo`00Soooo`030000<ol0<ol0
00Pco`000ol0V@000?ooo`23oooo002?oooo00<0000co`0co`0023?o0003o`2I0000oooo08?oool0
08ooool00`0003?o03?o0008<ol000?o09Woooooool0Poooo`00R?ooo`800005oooo00<0000co`0c
o`0023?o0003o`2Ioooooooo08?oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008
<ol000?o09Woooooool0Poooo`00ROooo`030000oooooooo00?oool3000023?o0003o`2Ioooooooo
08?oool008[oool00`000?ooooooo`02oooo00<0000co`0co`0023?o0003o`2Ioooooooo08?oool0
08Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000?o09Woooooool0Poooo`00R?oo
o`800005oooo00<0000co`0co`001c?o00030000o`2Ioooo08Coool008ooool00`0003?o03?o0007
<ol000<0003o09Woool0Q?ooo`00Soooo`030000<ol0<ol000Lco`000`000?l0VOooo`24oooo002?
oooo00<0000co`0co`001c?o00030000o`2Ioooo08Coool008ooool2000023?o00030000o`2Ioooo
08Coool008ooool00`0003?o03?o0007<ol000<0003o09Woool0Q?ooo`00Soooo`030000<ol0<ol0
00Lco`000`000?l0VOooo`24oooo002?oooo00<0000co`0co`001c?o00030000o`2Ioooo08Coool0
08ooool00`0003?o03?o0006<ol000<0003ooooo09T0QOooo`00Soooo`030000<ol0<ol000Hco`00
0`000?ooool0V@25oooo002?oooo0P0000Lco`000`000?ooool0V@25oooo002?oooo00<0000co`0c
o`001S?o00030000ooooo`2I08Goool008ooool00`0003?o03?o0006<ol000<0003ooooo09T0QOoo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooool0V@25oooo002?oooo00<0000co`0co`001S?o
00030000ooooo`2I08Goool008ooool00`0003?o03?o0006<ol000<0003ooooo09T0QOooo`00Sooo
o`800006<ol000@0003ooooooooo09V5oooo002?oooo00<0000co`0co`001C?o00040000oooooooo
o`2IQOooo`00Soooo`030000<ol0<ol000Dco`0010000?ooooooool0VHGoool008ooool00`0003?o
03?o0005<ol000@0003ooooooooo09V5oooo002?oooo00<0000co`0co`001C?o00040000oooooooo
o`2IQOooo`00Soooo`030000<ol0<ol000Dco`0010000?ooooooool0VHGoool008ooool200001S?o
00040000ooooooooo`2IQOooo`00Soooo`030000<ol0<ol000Dco`0010000?ooooooool0VHGoool0
08ooool00`0003?o03?o0005<ol000@0003ooooooooo09V5oooo002?oooo00<0000co`0co`0013?o
00050000ooooooooooooo`2I08Goool008ooool00`0003?o03?o0004<ol000D0003ooooooooooooo
09T0QOooo`00ROooo`<00003oooo00<0000co`0co`0013?o00050000ooooooooooooo`2I08Goool0
08[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o00050000ooooooooooooo`2I08Goool0
08Ooool500000oooo`<00004<ol000D0003ooooooooooooo09T0QOooo`00Qoooo`040000oooooooo
00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7
<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?ooooooo`0Coooo1c?o
00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo00Woool7
<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`06oooo1@00008co`02000000<co`3oooooool01@0000;oool200001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Ooool00`0003?o03?o0005<ol01?ooo`050000oooooooooooo000000;oool01@000?oooooooooo
o`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo00ooool00`0003?o03?o0005
<ol01?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000>oooo00<0000co`0co`001C?o00Coool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000004Oooo`030000
<ol0<ol000Dco`04oooo00D0003oooooooooool000000_ooo`050000oooooooooooo000007[oool0
07Woool00`000?ooooooo`0Aoooo0P0000Lco`03oooo0P0000Coool200000oooo`030000oooooooo
07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53057 .12361 L
.53984 .12361 L
.54444 .12361 L
.54576 .12361 L
.54701 .12361 L
s
.54701 .12361 m
.54746 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.43755 .12361 L
.44268 .12361 L
.44744 .12361 L
.44874 .12361 L
.45013 .12361 L
.45143 .12361 L
.45262 .12336 L
.45379 .12215 L
.45487 .12106 L
.45731 .11865 L
.46172 .11447 L
.48214 .09797 L
.5012 .08627 L
.5207 .0763 L
.5303 .07177 L
.53918 .06781 L
.5439 .06579 L
.54505 .06531 L
.54629 .06479 L
.547 .0645 L
.54765 .12361 L
.54892 .12361 L
.55953 .12361 L
.57808 .12361 L
.61771 .12361 L
.65582 .12361 L
.69638 .12361 L
.73542 .12361 L
.77692 .12361 L
.8169 .12361 L
.85537 .12361 L
.89629 .12361 L
.93569 .12361 L
.97358 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`09oooo00<0I_ooooooool0P_ooo`00Sooo
o`030000oooooooo00Ooool306KoQ?ooo`00Soooo`030000oooooooo00Coool306Ko0_ooo`0306Ko
oooooooo08;oool008ooool200000oooo`80I_l5oooo00<0I_ooooooool0P_ooo`005oooo`@0000i
oooo1@0003Koool00`000?ooooooo`0206Ko1oooo`0306Kooooooooo02_oool50000>?ooo`@0000F
oooo000Goooo00<0003oooooool0??ooo`030000oooooooo03Koool00`00001Vo`1Vo`09oooo00<0
I_ooooooool0;Oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000Hoooo00<0003ooooo
ool0>oooo`030000oooooooo03Koool00`000?ooooooo`09oooo00<0I_ooooooool0;Oooo`030000
oooooooo03Woool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0boooo1000
00Coool00`000?ooooooo`0doooo0P1Vo`030000oooooooo00Woool00`1Vooooooooo`0]oooo00<0
003oooooool0>_ooo`030000oooooooo01Goool001Ooool010000?ooooooo`0003_oool00`000?oo
ooooo`0boooo0P1Vo`;oool00`000?ooooooo`09oooo00<0I_ooooooool0;Oooo`030000oooooooo
03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000coooo00<0I_ooooooool00_oo
o`80000:oooo00<0I_ooooooool0;?ooo`80000koooo0P0001Ooool008Woool00`1Vooooooooo`03
oooo00<0003oooooool02Oooo`0306Kooooooooo08;oool008Ooool206Ko1_ooo`030000oooooooo
00Woool00`1Vooooooooo`22oooo0026oooo00<0I_ooooooool01_ooo`030000oooooooo00Woool0
0`1Vooooooooo`22oooo0025oooo00<0I_ooooooool01oooo`030000oooooooo00Woool00`1Voooo
ooooo`22oooo0024oooo00<0I_ooooooool02?ooo`030000oooooooo00Woool00`1Vooooooooo`22
oooo000@ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006<ol08P0000Koool00`000?ooooooo`09
oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0
000co`0co`002C?o0003o`2I<ol0<ol002dco`090000=?ooo`030000oooooooo01Goool008ooool0
0`0003?o03?o0009<ol000?o09Tco`0co`009c?o00H0001Eoooo002?oooo00<0000co`0co`002C?o
0003o`2I<ol0<ol002Dco`020000Foooo`00Soooo`030000<ol0<ol000Tco`000ol0VC?o03?o000S
<ol00P0005goool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`0083?o00<0001Ooooo002?
oooo0P0000Xco`000ol0VC?o03?o000M<ol00`0006;oool008ooool00`0003?o03?o0009<ol000?o
09Tco`0co`006c?o0080001Uoooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol001Xco`00
0`000?ooooooo`1Uoooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol001Tco`000`000?oo
ooooo`1Voooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol001Pco`000`000?ooooooo`1W
oooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol001Hco`020000J_ooo`00Soooo`80000:
<ol000?o09Tco`0co`005C?o00030000oooooooo06[oool008ooool00`0003?o03?o0009<ol000?o
09Tco`0co`0053?o00030000oooooooo06_oool008ooool00`0003?o03?o0009<ol000?o09Tco`0c
o`004c?o00030000oooooooo06coool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`004c?o
00030000oooooooo06coool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`004S?o00030000
oooooooo06goool008ooool00`0003?o03?o0009<ol000?o09Tco`0co`004C?o00030000oooooooo
06koool008ooool200002S?o0003o`2I<ol0<ol0010co`000`000?ooooooo`1_oooo002?oooo00<0
000co`0co`002C?o0003o`2I<ol0<ol000lco`000`000?ooooooo`1`oooo002?oooo00<0000co`0c
o`002C?o0003o`2I<ol0<ol000lco`000`000?ooooooo`1`oooo002?oooo00<0000co`0co`002C?o
0003o`2I<ol0<ol000hco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`002C?o0003o`2I
<ol0<ol000hco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol0
00dco`000`000?ooooooo`1boooo002?oooo0P0000Xco`000ol0VC?o03?o000=<ol000<0003ooooo
ool0L_ooo`00Soooo`030000<ol0<ol000Tco`000ol0VC?o03?o000<<ol000<0003oooooool0Looo
o`00Soooo`030000<ol0<ol000Tco`000ol0VC?o03?o000<<ol000<0003oooooool0Loooo`00Sooo
o`030000<ol0<ol000Tco`000ol0VC?o03?o000;<ol000<0003oooooool0M?ooo`00Soooo`030000
<ol0<ol000Tco`000ol0VC?o03?o000;<ol000<0003oooooool0M?ooo`00Qoooo`D00003oooo00<0
000co`0co`002C?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1eoooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol000Tco`000ol0VC?o03?o000:<ol000<0003oooooool0MOooo`00ROoo
o`030000oooooooo00?oool300002C?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1foooo0029
oooo00<0003oooooool00oooo`030000<ol0<ol000Tco`000ol0VC?o03?o0009<ol000<0003ooooo
ool0M_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o0009<ol000?o09Tco`0co`002C?o
00030000oooooooo07Koool008Soool200001Oooo`030000<ol0<ol000Tco`000ol0VC?o03?o0008
<ol000<0003oooooool0Moooo`00Soooo`030000<ol0<ol000Tco`000ol0VC?o03?o0008<ol000<0
003oooooool0Moooo`00Soooo`030000<ol0<ol000Tco`000ol0VC?o03?o0007<ol000<0003ooooo
ool0N?ooo`00Soooo`80000:<ol000?o09Tco`0co`001c?o00030000oooooooo07Soool008ooool0
0`0003?o03?o0009<ol000?o09Tco`0co`001c?o00030000oooooooo07Soool008ooool00`0003?o
03?o0009<ol000?o09Tco`0co`001S?o00030000oooooooo07Woool008ooool00`0003?o03?o0009
<ol000?o09Tco`0co`001S?o00030000oooooooo07Woool008ooool00`0003?o03?o0009<ol000?o
09Tco`0co`001S?o00030000oooooooo07Woool008ooool00`0003?o03?o0009<ol000?o09Tco`0c
o`001C?o00030000oooooooo07[oool008ooool200002S?o0003o`2I<ol0<ol000Dco`000`000?oo
ooooo`1joooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1j
oooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1joooo002?
oooo00<0000co`0co`002C?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1koooo002?oooo00<0
000co`0co`002C?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1koooo002?oooo00<0000co`0c
o`002C?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1koooo002?oooo00<0000co`0co`002C?o
0003o`2I<ol0<ol000@co`000`000?ooooooo`1koooo002?oooo0P0000Xco`000ol0VC?o03?o0003
<ol000<0003oooooool0O?ooo`00Soooo`030000<ol0<ol000Tco`000ol0VC?o03?o0003<ol000<0
003oooooool0O?ooo`00Soooo`030000<ol0<ol000Tco`000ol0VC?o03?o0003<ol000<0003ooooo
ool0O?ooo`00Soooo`030000<ol0<ol000Tco`000ol0VC?o03?o0003<ol000<0003oooooool0O?oo
o`00Soooo`030000<ol0<ol000Tco`000ol0VC?o03?o0003<ol000<0003oooooool0O?ooo`00Sooo
o`030000<ol0<ol000Tco`000ol0VC?o03?o0002<ol000<0003oooooool0OOooo`00Soooo`80000:
<ol000?o09Tco`0co`000S?o00030000oooooooo07goool008ooool00`0003?o03?o0009<ol000?o
09Tco`0co`000S?o00030000oooooooo07goool008ooool00`0003?o03?o0009<ol000?o09Tco`0c
o`000S?o00030000oooooooo07goool008ooool00`0003?o03?o0009<ol000Go09Tco`0co`0co`00
0000P?ooo`00Qoooo`@00004oooo00<0000co`0co`002C?o0005o`2I<ol0<ol0<ol00000083oool0
08Ooool00`000?ooooooo`05oooo00<0000co`0co`002C?o0005o`2I<ol0<ol0<ol00000083oool0
08Soool00`000?ooooooo`04oooo0`0000Tco`001Ol0VC?o03?o03?o00000020oooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol000Tco`001Ol0VC?o03?o03?o00000020oooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`002C?o0004o`2I<ol0<ol00000POooo`00R?ooo`800005
oooo00<0000co`0co`002C?o0004o`2I<ol0<ol00000POooo`00Soooo`030000<ol0<ol000Tco`00
1?l0VC?o03?o0000087oool008ooool00`0003?o03?o0009<ol000Co09Tco`0co`000021oooo002?
oooo0P0000Xco`001?l0VC?o03?o0000087oool008ooool00`0003?o03?o0009<ol000Co09Tco`0c
o`000021oooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0000008;oool008ooool00`0003?o
03?o0009<ol000?o09Tco`000000P_ooo`00Soooo`030000<ol0<ol000Tco`000ol0VC?o00000022
oooo002?oooo00<0000co`0co`002C?o0003o`2I<ol0000008;oool008ooool00`0003?o03?o0009
<ol000?o09Tco`000000P_ooo`00Soooo`80000:<ol000?o09Tco`000000P_ooo`00Soooo`030000
<ol0<ol000Tco`000ol0VC?o00000022oooo002?oooo00<0000co`0co`002C?o0003o`2I0000oooo
08;oool008ooool00`0003?o03?o0009<ol000?o09T0003oool0P_ooo`00Soooo`030000<ol0<ol0
00Tco`000ol0V@000?ooo`22oooo002?oooo00<0000co`0co`002C?o0003o`2I0000oooo08;oool0
08ooool200002S?o0003o`2I0000oooo08;oool008ooool00`0003?o03?o0009<ol000?o09T0003o
ool0P_ooo`00Soooo`030000<ol0<ol000Tco`000ol0V@000?ooo`22oooo002?oooo00<0000co`0c
o`002C?o0003o`2Ioooooooo08;oool008ooool00`0003?o03?o0009<ol000?o09Woooooool0P_oo
o`00Soooo`030000<ol0<ol000Tco`000ol0VOooooooo`22oooo002?oooo0P0000Xco`000ol0VOoo
ooooo`22oooo002?oooo00<0000co`0co`002C?o0003o`2Ioooooooo08;oool008ooool00`0003?o
03?o0009<ol000?o09Woooooool0P_ooo`00Soooo`030000<ol0<ol000Pco`000`000?l0VOooo`23
oooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0003o09Woool0Poooo`00Qoooo`040000
oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?l0VOooo`23oooo0029oooo00<0003ooooo
ool00oooo`<00008<ol000<0003o09Woool0Poooo`00R_ooo`030000oooooooo00;oool00`0003?o
03?o0008<ol000<0003o09Woool0Poooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol0
00Pco`000`000?l0VOooo`23oooo0028oooo0P0000Goool00`0003?o03?o0007<ol000<0003ooooo
09T0Q?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooool0V@24oooo002?oooo00<0000co`0c
o`001c?o00030000ooooo`2I08Coool008ooool00`0003?o03?o0007<ol000<0003ooooo09T0Q?oo
o`00Soooo`800008<ol000<0003ooooo09T0Q?ooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ool0V@24oooo002?oooo00<0000co`0co`001c?o00030000ooooo`2I08Coool008ooool00`0003?o
03?o0007<ol000<0003ooooo09T0Q?ooo`00Soooo`030000<ol0<ol000Hco`0010000?ooooooool0
VHCoool008ooool00`0003?o03?o0006<ol000@0003ooooooooo09V4oooo002?oooo0P0000Lco`00
10000?ooooooool0VHCoool008ooool00`0003?o03?o0006<ol000@0003ooooooooo09V4oooo002?
oooo00<0000co`0co`001S?o00040000ooooooooo`2IQ?ooo`00Soooo`030000<ol0<ol000Hco`00
10000?ooooooool0VHCoool008ooool00`0003?o03?o0006<ol000@0003ooooooooo09V4oooo002?
oooo00<0000co`0co`001S?o00040000ooooooooo`2IQ?ooo`00Soooo`800006<ol000D0003ooooo
oooooooo09T0Q?ooo`00Soooo`030000<ol0<ol000Dco`001@000?ooooooooooool0V@24oooo002?
oooo00<0000co`0co`001C?o00050000ooooooooooooo`2I08Coool008ooool00`0003?o03?o0005
<ol000D0003ooooooooooooo09T0Q?ooo`00Soooo`030000<ol0<ol000Dco`001@000?oooooooooo
ool0V@24oooo002?oooo00<0000co`0co`001C?o00050000ooooooooooooo`2I08Coool008ooool2
00001S?o00050000ooooooooooooo`2I08Coool008ooool00`0003?o03?o0005<ol000D0003ooooo
oooooooo09T0Q?ooo`00Soooo`030000<ol0<ol000Dco`001@000?ooooooooooool0V@24oooo002?
oooo00<0000co`0co`0013?o00030000oooooooo00;oool00ol0VOooooooo`22oooo002?oooo00<0
000co`0co`0013?o00030000oooooooo00;oool00ol0VOooooooo`22oooo0029oooo0`0000?oool0
0`0003?o03?o0004<ol000<0003oooooool00_ooo`03o`2Ioooooooo08;oool008[oool00`000?oo
ooooo`02oooo00<0000co`0co`0013?o00030000oooooooo00;oool00ol0VOooooooo`22oooo0027
oooo1@0000?oool3000013?o00030000oooooooo00;oool00ol0VOooooooo`22oooo0027oooo00@0
003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool2
00001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00O?ooo`030000oooooooo
013oool7<ol02oooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003ooooo
ool01_ooo`Lco`0<oooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool500000S?o00800003oooo100000?oool00`000?ooooooo`1koooo001k
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo0S?o
00030000<ol0<ol0008co`05oooo00<0003oooooool01?ooo`030000oooooooo07_oool007[oool0
0`000?ooooooo`02oooo00<0003oooooool03Oooo`8co`000`0003?o03?o0002<ol01_ooo`030000
oooooooo00Coool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000coool2<ol000<0
000co`0co`000S?o00Ooool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo000000ooool2<ol000<0000co`0co`000S?o00Goool010000?ooooooo`0000?oool0
0`000?ooooooo`1koooo001loooo00<0003oooooool04?ooo`03<ol00000000000@co`06oooo0P00
00?oool00`000?ooooooo`1loooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54444 .12361 L
.54934 .12361 L
.5508 .12361 L
.55151 .12361 L
.55216 .12361 L
s
.55216 .12361 m
.55266 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.43755 .12361 L
.44268 .12361 L
.44498 .12361 L
.44625 .12361 L
.44744 .12361 L
.44811 .1231 L
.44885 .12234 L
.45013 .12105 L
.45262 .11857 L
.46172 .11021 L
.48126 .09532 L
.50272 .08306 L
.52337 .07324 L
.54221 .0651 L
.54701 .06317 L
.54954 .06217 L
.55092 .06163 L
.55223 .06113 L
.55335 .12361 L
.55457 .12361 L
.55716 .12361 L
.56172 .12361 L
.58263 .12361 L
.62377 .12361 L
.6634 .12361 L
.7015 .12361 L
.74207 .12361 L
.78111 .12361 L
.82261 .12361 L
.86259 .12361 L
.90106 .12361 L
.94197 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`09oooo0P1Voh?oool008ooool00`000?oo
ooooo`07oooo0P1Vo`03oooo06Kooooo08;oool008ooool00`000?ooooooo`05oooo0P1Vo`?oool0
0`1Vooooooooo`21oooo002?oooo0P0000?oool306Ko1Oooo`0306Kooooooooo087oool001Ooool4
0000>Oooo`D0000foooo00<0003oooooool00P1Vo`Soool00`1Vooooooooo`0Zoooo1@0003Soool4
00005_ooo`005oooo`030000oooooooo03coool00`000?ooooooo`0foooo00<00000I_l0I_l02_oo
o`0306Kooooooooo02coool00`000?ooooooo`0hoooo00<0003oooooool05oooo`006?ooo`030000
oooooooo03_oool00`000?ooooooo`0eoooo00<0I_l0003oool02oooo`0306Kooooooooo02coool0
0`000?ooooooo`0ioooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool0<_oo
o`@00004oooo00<0003oooooool0<oooo`80I_l00oooo`000?ooo`0;oooo00<0I_ooooooool0;?oo
o`030000oooooooo03[oool00`000?ooooooo`0Eoooo000Goooo00@0003oooooool0000koooo00<0
003oooooool0<Oooo`80I_l3oooo00<0003oooooool02_ooo`0306Kooooooooo02coool00`000?oo
ooooo`0hoooo00@0003oooooool0000Foooo000Hoooo0P0003_oool20000<_ooo`0306Kooooooooo
00?oool200002oooo`0306Kooooooooo02_oool20000>oooo`80000Goooo0027oooo0P1Vo`Koool0
0`000?ooooooo`0:oooo00<0I_ooooooool0POooo`00Q_ooo`0306Kooooooooo00Koool00`000?oo
ooooo`0:oooo00<0I_ooooooool0POooo`00QOooo`0306Kooooooooo00Ooool00`000?ooooooo`0:
oooo00<0I_ooooooool0POooo`00Q?ooo`0306Kooooooooo00Soool00`000?ooooooo`0:oooo00<0
I_ooooooool0POooo`00Poooo`0306Kooooooooo00Woool00`000?ooooooo`0:oooo00<0I_oooooo
ool0POooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000<ol0<ol000Tco`000`000?l0VC?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0003ooooo
ool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Ooo
o`030000<ol0<ol000Xco`000ol0VC?o03?o000/<ol02@0003Coool00`000?ooooooo`0Eoooo002?
oooo00<0000co`0co`002S?o0003o`2I<ol0<ol002Hco`060000EOooo`00Soooo`030000<ol0<ol0
00Xco`000ol0VC?o03?o000T<ol00P0005_oool008ooool00`0003?o03?o000:<ol000?o09Tco`0c
o`008S?o0080001Moooo002?oooo00<0000co`0co`002S?o0003o`2I<ol0<ol001lco`030000Gooo
o`00Soooo`80000;<ol000?o09Tco`0co`0073?o00<0001Roooo002?oooo00<0000co`0co`002S?o
0003o`2I<ol0<ol001Xco`020000IOooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o03?o000I
<ol000<0003oooooool0IOooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o03?o000H<ol000<0
003oooooool0I_ooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o03?o000G<ol000<0003ooooo
ool0Ioooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o03?o000E<ol00P0006[oool008ooool2
00002c?o0003o`2I<ol0<ol001@co`000`000?ooooooo`1Zoooo002?oooo00<0000co`0co`002S?o
0003o`2I<ol0<ol001<co`000`000?ooooooo`1[oooo002?oooo00<0000co`0co`002S?o0003o`2I
<ol0<ol0018co`000`000?ooooooo`1/oooo002?oooo00<0000co`0co`002S?o0003o`2I<ol0<ol0
018co`000`000?ooooooo`1/oooo002?oooo00<0000co`0co`002S?o0003o`2I<ol0<ol0014co`00
0`000?ooooooo`1]oooo002?oooo00<0000co`0co`002S?o0003o`2I<ol0<ol0010co`000`000?oo
ooooo`1^oooo002?oooo0P0000/co`000ol0VC?o03?o000?<ol000<0003oooooool0Koooo`00Sooo
o`030000<ol0<ol000Xco`000ol0VC?o03?o000><ol000<0003oooooool0L?ooo`00Soooo`030000
<ol0<ol000Xco`000ol0VC?o03?o000><ol000<0003oooooool0L?ooo`00Soooo`030000<ol0<ol0
00Xco`000ol0VC?o03?o000=<ol000<0003oooooool0LOooo`00Soooo`030000<ol0<ol000Xco`00
0ol0VC?o03?o000=<ol000<0003oooooool0LOooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o
03?o000<<ol000<0003oooooool0L_ooo`00Soooo`80000;<ol000?o09Tco`0co`0033?o00030000
oooooooo07;oool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`002c?o00030000oooooooo
07?oool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`002c?o00030000oooooooo07?oool0
08ooool00`0003?o03?o000:<ol000?o09Tco`0co`002S?o00030000oooooooo07Coool008ooool0
0`0003?o03?o000:<ol000?o09Tco`0co`002S?o00030000oooooooo07Coool008Ooool500000ooo
o`030000<ol0<ol000Xco`000ol0VC?o03?o0009<ol000<0003oooooool0MOooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000:<ol000?o09Tco`0co`002C?o00030000oooooooo07Goool0
08Woool00`000?ooooooo`03oooo0`0000Xco`000ol0VC?o03?o0008<ol000<0003oooooool0M_oo
o`00ROooo`030000oooooooo00?oool00`0003?o03?o000:<ol000?o09Tco`0co`0023?o00030000
oooooooo07Koool008Woool00`000?ooooooo`03oooo00<0000co`0co`002S?o0003o`2I<ol0<ol0
00Pco`000`000?ooooooo`1foooo0028oooo0P0000Goool00`0003?o03?o000:<ol000?o09Tco`0c
o`001c?o00030000oooooooo07Ooool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`001c?o
00030000oooooooo07Ooool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`001S?o00030000
oooooooo07Soool008ooool200002c?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1hoooo002?
oooo00<0000co`0co`002S?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1hoooo002?oooo00<0
000co`0co`002S?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1ioooo002?oooo00<0000co`0c
o`002S?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1ioooo002?oooo00<0000co`0co`002S?o
0003o`2I<ol0<ol000Dco`000`000?ooooooo`1ioooo002?oooo00<0000co`0co`002S?o0003o`2I
<ol0<ol000@co`000`000?ooooooo`1joooo002?oooo0P0000/co`000ol0VC?o03?o0004<ol000<0
003oooooool0N_ooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o03?o0004<ol000<0003ooooo
ool0N_ooo`00Soooo`030000<ol0<ol000Xco`000ol0VC?o03?o0004<ol000<0003oooooool0N_oo
o`00Soooo`030000<ol0<ol000Xco`000ol0VC?o03?o0003<ol000<0003oooooool0Noooo`00Sooo
o`030000<ol0<ol000Xco`000ol0VC?o03?o0003<ol000<0003oooooool0Noooo`00Soooo`030000
<ol0<ol000Xco`000ol0VC?o03?o0003<ol000<0003oooooool0Noooo`00Soooo`030000<ol0<ol0
00Xco`000ol0VC?o03?o0003<ol000<0003oooooool0Noooo`00Soooo`80000;<ol000?o09Tco`0c
o`000S?o00030000oooooooo07coool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`000S?o
00030000oooooooo07coool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`000S?o00030000
oooooooo07coool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`000S?o00030000oooooooo
07coool008ooool00`0003?o03?o000:<ol000?o09Tco`0co`000S?o00030000oooooooo07coool0
08ooool00`0003?o03?o000:<ol000Go09Tco`0co`0co`000000Ooooo`00Soooo`80000;<ol000Go
09Tco`0co`0co`000000Ooooo`00Soooo`030000<ol0<ol000Xco`001Ol0VC?o03?o03?o0000001o
oooo002?oooo00<0000co`0co`002S?o0005o`2I<ol0<ol0<ol0000007ooool008ooool00`0003?o
03?o000:<ol000Co09Tco`0co`000020oooo0027oooo100000Coool00`0003?o03?o000:<ol000Co
09Tco`0co`000020oooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol000Xco`001?l0VC?o
03?o0000083oool008Soool00`000?ooooooo`04oooo0`0000Xco`001?l0VC?o03?o0000083oool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`002S?o0004o`2I<ol0<ol00000P?ooo`00Qooo
o`040000oooooooo00001?ooo`030000<ol0<ol000Xco`000ol0VC?o00000021oooo0028oooo0P00
00Goool00`0003?o03?o000:<ol000?o09Tco`000000POooo`00Soooo`030000<ol0<ol000Xco`00
0ol0VC?o00000021oooo002?oooo00<0000co`0co`002S?o0003o`2I<ol00000087oool008ooool2
00002c?o0003o`2I<ol00000087oool008ooool00`0003?o03?o000:<ol000?o09Tco`000000POoo
o`00Soooo`030000<ol0<ol000Xco`000ol0V@000?ooo`21oooo002?oooo00<0000co`0co`002S?o
0003o`2I0000oooo087oool008ooool00`0003?o03?o000:<ol000?o09T0003oool0POooo`00Sooo
o`030000<ol0<ol000Xco`000ol0V@000?ooo`21oooo002?oooo00<0000co`0co`002S?o0003o`2I
0000oooo087oool008ooool200002c?o0003o`2I0000oooo087oool008ooool00`0003?o03?o000:
<ol000?o09T0003oool0POooo`00Soooo`030000<ol0<ol000Xco`000ol0VOooooooo`21oooo002?
oooo00<0000co`0co`002S?o0003o`2Ioooooooo087oool008ooool00`0003?o03?o000:<ol000?o
09Woooooool0POooo`00Soooo`030000<ol0<ol000Xco`000ol0VOooooooo`21oooo002?oooo0P00
00/co`000ol0VOooooooo`21oooo002?oooo00<0000co`0co`002S?o0003o`2Ioooooooo087oool0
08ooool00`0003?o03?o000:<ol000?o09Woooooool0POooo`00Soooo`030000<ol0<ol000Tco`00
0`000?l0VOooo`22oooo002?oooo00<0000co`0co`002C?o00030000o`2Ioooo08;oool008ooool0
0`0003?o03?o0009<ol000<0003o09Woool0P_ooo`00Soooo`80000:<ol000<0003o09Woool0P_oo
o`00Soooo`030000<ol0<ol000Tco`000`000?l0VOooo`22oooo002?oooo00<0000co`0co`002C?o
00030000o`2Ioooo08;oool008ooool00`0003?o03?o0008<ol000<0003ooooo09T0Poooo`00R?oo
o`800005oooo00<0000co`0co`0023?o00030000ooooo`2I08?oool008Ooool010000?ooooooo`00
00Coool00`0003?o03?o0008<ol000<0003ooooo09T0Poooo`00ROooo`030000oooooooo00?oool3
000023?o00030000ooooo`2I08?oool008[oool00`000?ooooooo`02oooo00<0000co`0co`0023?o
00030000ooooo`2I08?oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0
003ooooo09T0Poooo`00R?ooo`800005oooo00<0000co`0co`001c?o00040000ooooooooo`2IPooo
o`00Soooo`030000<ol0<ol000Lco`0010000?ooooooool0VH?oool008ooool00`0003?o03?o0007
<ol000@0003ooooooooo09V3oooo002?oooo00<0000co`0co`001c?o00040000ooooooooo`2IPooo
o`00Soooo`800008<ol000@0003ooooooooo09V3oooo002?oooo00<0000co`0co`001c?o00040000
ooooooooo`2IPoooo`00Soooo`030000<ol0<ol000Lco`0010000?ooooooool0VH?oool008ooool0
0`0003?o03?o0007<ol000@0003ooooooooo09V3oooo002?oooo00<0000co`0co`001S?o00050000
ooooooooooooo`2I08?oool008ooool00`0003?o03?o0006<ol000D0003ooooooooooooo09T0Pooo
o`00Soooo`800007<ol000D0003ooooooooooooo09T0Poooo`00Soooo`030000<ol0<ol000Hco`00
1@000?ooooooooooool0V@23oooo002?oooo00<0000co`0co`001S?o00050000ooooooooooooo`2I
08?oool008ooool00`0003?o03?o0006<ol000D0003ooooooooooooo09T0Poooo`00Soooo`030000
<ol0<ol000Hco`001@000?ooooooooooool0V@23oooo002?oooo00<0000co`0co`001S?o00050000
ooooooooooooo`2I08?oool008ooool200001S?o00030000oooooooo00;oool00ol0VOooooooo`21
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo00;oool00ol0VOooooooo`21oooo002?
oooo00<0000co`0co`001C?o00030000oooooooo00;oool00ol0VOooooooo`21oooo002?oooo00<0
000co`0co`001C?o00030000oooooooo00;oool00ol0VOooooooo`21oooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo00;oool00ol0VOooooooo`21oooo002?oooo00<0000co`0co`001C?o
00030000oooooooo00;oool00ol0VOooooooo`21oooo002?oooo0P0000Hco`000`000?ooooooo`02
oooo00?o09Woooooool0POooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`02oooo00?o
09Woooooool0POooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`02oooo00?o09Wooooo
ool0POooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`03oooo00?o09Woooooool0POoo
o`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`03oooo00?o09Woooooool0POooo`00ROoo
o`<00003oooo00<0000co`0co`0013?o00030000oooooooo00?oool00ol0VOooooooo`21oooo002:
oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`03oooo00?o09Wooooo
ool0POooo`00Qoooo`D00003oooo0`0000@co`000`000?ooooooo`03oooo00?o09Woooooool0POoo
o`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:
oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool0
0`000?ooooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?oo
o`030000oooooooo00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`06oooo1@00008co`02000000<co`3oooooool0100000;oool4
00000oooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Ooool00`0003?o03?o0005<ol00_ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0?oooo00<0000co`0co`001C?o00?oool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000<ol0<ol000Dco`04
oooo00<0003oooooool00oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000004Oooo`030000<ol0<ol000Dco`02oooo00@0003oooooool00002oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200001c?o
00?oool200001?ooo`800003oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o
08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54934 .12361 L
.55195 .12361 L
.55338 .12361 L
.55472 .12361 L
.55598 .12361 L
.55669 .12361 L
s
.55669 .12361 m
.55695 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.42237 .12361 L
.43215 .12361 L
.43755 .12361 L
.44021 .12361 L
.44151 .12361 L
.44268 .12361 L
.44387 .12256 L
.44498 .12143 L
.44744 .11899 L
.45262 .11407 L
.46172 .10621 L
.50027 .08199 L
.52021 .07297 L
.53037 .06863 L
.54127 .0642 L
.54655 .06214 L
.55154 .06025 L
.55372 .05945 L
.55491 .05901 L
.55603 .0586 L
.55723 .12361 L
.55787 .12361 L
.55856 .12361 L
.56091 .12361 L
.57924 .12361 L
.62038 .12361 L
.66001 .12361 L
.69811 .12361 L
.73868 .12361 L
.77772 .12361 L
.81922 .12361 L
.8592 .12361 L
.89767 .12361 L
.93859 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo00[oool206KoP_ooo`00Soooo`030000oooooooo00Ooool306Ko00?oool0I_oo
ool0POooo`00Soooo`030000oooooooo00Goool206Ko1?ooo`0306Kooooooooo083oool008ooool0
0`000?ooooooo`03oooo0P1Vo`Koool00`1Vooooooooo`20oooo002?oooo0P0000;oool206Ko2?oo
o`0306Kooooooooo083oool001Ooool40000>Oooo`D0000foooo00@0003oool0I_l0I_l:oooo00<0
I_ooooooool0:Oooo`D0000hoooo100001Koool001Ooool00`000?ooooooo`0loooo00<0003ooooo
ool0=_ooo`03000006Kooooo00_oool00`1Vooooooooo`0[oooo00<0003oooooool0>?ooo`030000
oooooooo01Ooool001Soool00`000?ooooooo`0koooo00<0003oooooool0=?ooo`80I_l00`000?oo
ooooo`0;oooo00<0I_ooooooool0:oooo`030000oooooooo03Woool00`000?ooooooo`0Foooo000A
oooo100000Coool00`000?ooooooo`0boooo100000Coool00`000?ooooooo`0boooo0P1Vo`;oool0
0`000?ooooooo`0;oooo00<0I_ooooooool0:oooo`030000oooooooo03[oool00`000?ooooooo`0E
oooo000Goooo00@0003oooooool0000koooo00<0003oooooool0<Oooo`0306Kooooooooo00;oool0
0`000?ooooooo`0;oooo00<0I_ooooooool0:oooo`030000oooooooo03Soool010000?ooooooo`00
01Koool001Soool20000>oooo`80000aoooo0P1Vo`Goool200003?ooo`0306Kooooooooo02[oool2
0000>oooo`80000Goooo0026oooo0P1Vo`Ooool00`000?ooooooo`0;oooo00<0I_ooooooool0P?oo
o`00QOooo`0306Kooooooooo00Ooool00`000?ooooooo`0;oooo00<0I_ooooooool0P?ooo`00Q?oo
o`0306Kooooooooo00Soool00`000?ooooooo`0;oooo00<0I_ooooooool0P?ooo`00Poooo`0306Ko
oooooooo00Woool00`000?ooooooo`0;oooo00<0I_ooooooool0P?ooo`00P_ooo`0306Kooooooooo
00[oool00`000?ooooooo`0;oooo00<0I_ooooooool0P?ooo`004?ooool0000Aoooo000Foooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02_oo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o
0?l0V@09<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0
000co`0co`001S?o02800006oooo00<0003oooooool02Oooo`030000oooooooo01Goool001Koool0
0`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol000/co`000ol0VC?o03?o000[
<ol02@0003Coool00`000?ooooooo`0Eoooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol0
02Dco`060000EOooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o000S<ol00P0005_oool0
08ooool00`0003?o03?o000;<ol000?o09Tco`0co`008C?o0080001Moooo002?oooo00<0000co`0c
o`002c?o0003o`2I<ol0<ol001hco`030000Goooo`00Soooo`80000<<ol000?o09Tco`0co`006c?o
00<0001Roooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol001Tco`020000IOooo`00Sooo
o`030000<ol0<ol000/co`000ol0VC?o03?o000H<ol000<0003oooooool0IOooo`00Soooo`030000
<ol0<ol000/co`000ol0VC?o03?o000G<ol000<0003oooooool0I_ooo`00Soooo`030000<ol0<ol0
00/co`000ol0VC?o03?o000F<ol000<0003oooooool0Ioooo`00Soooo`030000<ol0<ol000/co`00
0ol0VC?o03?o000D<ol00P0006[oool008ooool2000033?o0003o`2I<ol0<ol001<co`000`000?oo
ooooo`1Zoooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol0018co`000`000?ooooooo`1[
oooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol0014co`000`000?ooooooo`1/oooo002?
oooo00<0000co`0co`002c?o0003o`2I<ol0<ol0014co`000`000?ooooooo`1/oooo002?oooo00<0
000co`0co`002c?o0003o`2I<ol0<ol0010co`000`000?ooooooo`1]oooo002?oooo00<0000co`0c
o`002c?o0003o`2I<ol0<ol000lco`000`000?ooooooo`1^oooo002?oooo0P0000`co`000ol0VC?o
03?o000><ol000<0003oooooool0Koooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o000=
<ol000<0003oooooool0L?ooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o000=<ol000<0
003oooooool0L?ooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o000<<ol000<0003ooooo
ool0LOooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o000<<ol000<0003oooooool0LOoo
o`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o000;<ol000<0003oooooool0L_ooo`00Sooo
o`80000<<ol000?o09Tco`0co`002c?o00030000oooooooo07;oool008ooool00`0003?o03?o000;
<ol000?o09Tco`0co`002S?o00030000oooooooo07?oool008ooool00`0003?o03?o000;<ol000?o
09Tco`0co`002S?o00030000oooooooo07?oool008ooool00`0003?o03?o000;<ol000?o09Tco`0c
o`002C?o00030000oooooooo07Coool008ooool00`0003?o03?o000;<ol000?o09Tco`0co`002C?o
00030000oooooooo07Coool008Ooool500000oooo`030000<ol0<ol000/co`000ol0VC?o03?o0008
<ol000<0003oooooool0MOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000;<ol000?o
09Tco`0co`0023?o00030000oooooooo07Goool008Woool00`000?ooooooo`03oooo0`0000/co`00
0ol0VC?o03?o0007<ol000<0003oooooool0M_ooo`00ROooo`030000oooooooo00?oool00`0003?o
03?o000;<ol000?o09Tco`0co`001c?o00030000oooooooo07Koool008Woool00`000?ooooooo`03
oooo00<0000co`0co`002c?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1foooo0028oooo0P00
00Goool00`0003?o03?o000;<ol000?o09Tco`0co`001S?o00030000oooooooo07Ooool008ooool0
0`0003?o03?o000;<ol000?o09Tco`0co`001S?o00030000oooooooo07Ooool008ooool00`0003?o
03?o000;<ol000?o09Tco`0co`001C?o00030000oooooooo07Soool008ooool2000033?o0003o`2I
<ol0<ol000Dco`000`000?ooooooo`1hoooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol0
00Dco`000`000?ooooooo`1hoooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol000@co`00
0`000?ooooooo`1ioooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol000@co`000`000?oo
ooooo`1ioooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1i
oooo002?oooo00<0000co`0co`002c?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1joooo002?
oooo0P0000`co`000ol0VC?o03?o0003<ol000<0003oooooool0N_ooo`00Soooo`030000<ol0<ol0
00/co`000ol0VC?o03?o0003<ol000<0003oooooool0N_ooo`00Soooo`030000<ol0<ol000/co`00
0ol0VC?o03?o0003<ol000<0003oooooool0N_ooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o
03?o0002<ol000<0003oooooool0Noooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o0002
<ol000<0003oooooool0Noooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o0002<ol000<0
003oooooool0Noooo`00Soooo`030000<ol0<ol000/co`000ol0VC?o03?o0002<ol000<0003ooooo
ool0Noooo`00Soooo`80000<<ol000Go09Tco`0co`0co`000000O_ooo`00Soooo`030000<ol0<ol0
00/co`001Ol0VC?o03?o03?o0000001noooo002?oooo00<0000co`0co`002c?o0005o`2I<ol0<ol0
<ol0000007koool008ooool00`0003?o03?o000;<ol000Go09Tco`0co`0co`000000O_ooo`00Sooo
o`030000<ol0<ol000/co`001Ol0VC?o03?o03?o0000001noooo002?oooo00<0000co`0co`002c?o
0004o`2I<ol0<ol00000Ooooo`00Soooo`80000<<ol000Co09Tco`0co`00001ooooo002?oooo00<0
000co`0co`002c?o0004o`2I<ol0<ol00000Ooooo`00Soooo`030000<ol0<ol000/co`001?l0VC?o
03?o000007ooool008ooool00`0003?o03?o000;<ol000?o09Tco`000000P?ooo`00Qoooo`@00004
oooo00<0000co`0co`002c?o0003o`2I<ol00000083oool008Ooool00`000?ooooooo`05oooo00<0
000co`0co`002c?o0003o`2I<ol00000083oool008Soool00`000?ooooooo`04oooo0`0000/co`00
0ol0VC?o00000020oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000/co`000ol0VC?o
00000020oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`002c?o0003o`2I0000oooo
083oool008Soool200001Oooo`030000<ol0<ol000/co`000ol0V@000?ooo`20oooo002?oooo00<0
000co`0co`002c?o0003o`2I0000oooo083oool008ooool00`0003?o03?o000;<ol000?o09T0003o
ool0P?ooo`00Soooo`80000<<ol000?o09T0003oool0P?ooo`00Soooo`030000<ol0<ol000/co`00
0ol0V@000?ooo`20oooo002?oooo00<0000co`0co`002c?o0003o`2Ioooooooo083oool008ooool0
0`0003?o03?o000;<ol000?o09Woooooool0P?ooo`00Soooo`030000<ol0<ol000/co`000ol0VOoo
ooooo`20oooo002?oooo00<0000co`0co`002c?o0003o`2Ioooooooo083oool008ooool00`0003?o
03?o000;<ol000?o09Woooooool0P?ooo`00Soooo`80000<<ol000?o09Woooooool0P?ooo`00Sooo
o`030000<ol0<ol000/co`000ol0VOooooooo`20oooo002?oooo00<0000co`0co`002S?o00030000
o`2Ioooo087oool008ooool00`0003?o03?o000:<ol000<0003o09Woool0POooo`00Soooo`030000
<ol0<ol000Xco`000`000?l0VOooo`21oooo002?oooo00<0000co`0co`002S?o00030000o`2Ioooo
087oool008ooool200002c?o00030000o`2Ioooo087oool008ooool00`0003?o03?o000:<ol000<0
003o09Woool0POooo`00Soooo`030000<ol0<ol000Xco`000`000?l0VOooo`21oooo002?oooo00<0
000co`0co`002C?o00030000ooooo`2I08;oool008ooool00`0003?o03?o0009<ol000<0003ooooo
09T0P_ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooool0V@22oooo002?oooo0P0000Xco`00
0`000?ooool0V@22oooo002?oooo00<0000co`0co`002C?o00030000ooooo`2I08;oool008ooool0
0`0003?o03?o0009<ol000<0003ooooo09T0P_ooo`00Soooo`030000<ol0<ol000Pco`0010000?oo
ooooool0VH;oool008Soool200001Oooo`030000<ol0<ol000Pco`0010000?ooooooool0VH;oool0
08Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000@0003ooooooooo09V2oooo0029
oooo00<0003oooooool00oooo`<00008<ol000@0003ooooooooo09V2oooo002:oooo00<0003ooooo
ool00_ooo`030000<ol0<ol000Pco`0010000?ooooooool0VH;oool008Ooool010000?ooooooo`00
00Coool00`0003?o03?o0008<ol000@0003ooooooooo09V2oooo0028oooo0P0000Goool00`0003?o
03?o0007<ol000D0003ooooooooooooo09T0P_ooo`00Soooo`030000<ol0<ol000Lco`001@000?oo
ooooooooool0V@22oooo002?oooo00<0000co`0co`001c?o00050000ooooooooooooo`2I08;oool0
08ooool00`0003?o03?o0007<ol000D0003ooooooooooooo09T0P_ooo`00Soooo`800008<ol000D0
003ooooooooooooo09T0P_ooo`00Soooo`030000<ol0<ol000Lco`001@000?ooooooooooool0V@22
oooo002?oooo00<0000co`0co`001c?o00050000ooooooooooooo`2I08;oool008ooool00`0003?o
03?o0007<ol000D0003ooooooooooooo09T0P_ooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`02oooo00?o09Woooooool0P?ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`02
oooo00?o09Woooooool0P?ooo`00Soooo`800007<ol000<0003oooooool00_ooo`03o`2Ioooooooo
083oool008ooool00`0003?o03?o0006<ol000<0003oooooool00_ooo`03o`2Ioooooooo083oool0
08ooool00`0003?o03?o0006<ol000<0003oooooool00_ooo`03o`2Ioooooooo083oool008ooool0
0`0003?o03?o0006<ol000<0003oooooool00_ooo`03o`2Ioooooooo083oool008ooool00`0003?o
03?o0006<ol000<0003oooooool00_ooo`03o`2Ioooooooo083oool008ooool00`0003?o03?o0006
<ol000<0003oooooool00_ooo`03o`2Ioooooooo083oool008ooool200001S?o00030000oooooooo
00?oool00ol0VOooooooo`20oooo002?oooo00<0000co`0co`001C?o00030000oooooooo00?oool0
0ol0VOooooooo`20oooo002?oooo00<0000co`0co`001C?o00030000oooooooo00?oool00ol0VOoo
ooooo`20oooo002?oooo00<0000co`0co`001C?o00030000oooooooo00?oool00ol0VOooooooo`20
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo00?oool00ol0VOooooooo`20oooo002?
oooo00<0000co`0co`001C?o00030000oooooooo00?oool00ol0VOooooooo`20oooo002?oooo0P00
00Hco`000`000?ooooooo`03oooo00?o09Woooooool0P?ooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`03oooo00?o09Woooooool0P?ooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`03oooo00?o09Woooooool0P?ooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`04
oooo00?o09Woooooool0P?ooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`04oooo00?o
09Woooooool0P?ooo`00ROooo`<00003oooo00<0000co`0co`0013?o00030000oooooooo00Coool0
0ol0VOooooooo`20oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?oo
ooooo`04oooo00?o09Woooooool0P?ooo`00Qoooo`D00003oooo0`0000@co`000`000?ooooooo`04
oooo00?o09Woooooool0P?ooo`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0
003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?
oooo1c?o08[oool007Woool00`000?ooooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo00Woool7<ol03oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@00008co`02000000<c
o`3oooooool0100000Coool300000_ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`0003?o03?o0005<ol00_oo
o`030000oooooooo00Koool01@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_oo
o`030000oooooooo00ooool00`0003?o03?o0005<ol00oooo`030000oooooooo00;oool500000ooo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000<ol0<ol000Dco`04
oooo00D0003oooooooooool000000_ooo`050000oooooooooooo000007[oool007Soool01@000?oo
ooooooooo`00000Aoooo00<0000co`0co`001C?o00;oool010000?ooooooo`0000?oool00`000?oo
o`000003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200001c?o00?oool2
00001Oooo`800002oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54934 .12361 L
.55436 .12361 L
.55712 .12361 L
.55847 .12361 L
.55972 .12361 L
.56092 .12361 L
s
.56092 .12361 m
.56142 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.42237 .12361 L
.42781 .12361 L
.43298 .12361 L
.43522 .12361 L
.43646 .12361 L
.43762 .12361 L
.43828 .12342 L
.43899 .12268 L
.44024 .12141 L
.44268 .11898 L
.46172 .10246 L
.48166 .08919 L
.50272 .07879 L
.54069 .06325 L
.55071 .05952 L
.55564 .05776 L
.55781 .057 L
.5602 .05618 L
.56151 .05573 L
.56274 .12361 L
.56404 .12361 L
.56544 .12361 L
.57114 .12361 L
.58112 .12361 L
.62226 .12361 L
.66188 .12361 L
.69999 .12361 L
.74055 .12361 L
.77959 .12361 L
.82109 .12361 L
.86107 .12361 L
.89954 .12361 L
.94046 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool03?ooo`80I_n0
oooo002?oooo00<0003oooooool02Oooo`D0I_n0oooo002?oooo00<0003oooooool01_ooo`<0I_l4
oooo00<0I_ooooooool0O_ooo`00Soooo`030000oooooooo00Coool206Ko1oooo`0306Kooooooooo
07koool008ooool00`000?ooooooo`02oooo0P1Vo`Woool00`1Vooooooooo`1noooo002?oooo0P00
0003oooo06Ko06Ko00_oool00`1Vooooooooo`1noooo000Goooo100003Woool50000=_ooo`030000
06Ko06Ko00goool00`1Vooooooooo`0Woooo1@0003Soool400005_ooo`005oooo`030000oooooooo
03coool00`000?ooooooo`0eoooo00<0I_l0003oool03_ooo`0306Kooooooooo02Woool00`000?oo
ooooo`0hoooo00<0003oooooool05oooo`006?ooo`030000oooooooo03_oool00`000?ooooooo`0c
oooo0P1Vo`03oooo0000oooo00koool00`1Vooooooooo`0Yoooo00<0003oooooool0>Oooo`030000
oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?ooo`030000oooooooo
037oool206Ko0oooo`030000oooooooo00goool00`1Vooooooooo`0Yoooo00<0003oooooool0>_oo
o`030000oooooooo01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0_oooo0P1V
o`Goool00`000?ooooooo`0=oooo00<0I_ooooooool0:Oooo`030000oooooooo03Soool010000?oo
ooooo`0001Koool001Soool20000>oooo`80000_oooo0P1Vo`Ooool200003_ooo`0306Kooooooooo
02Soool20000>oooo`80000Goooo0025oooo00<0I_ooooooool01oooo`030000oooooooo00goool0
0`1Vooooooooo`1noooo0024oooo00<0I_ooooooool02?ooo`030000oooooooo00goool00`1Voooo
ooooo`1noooo0022oooo0P1Vo`_oool00`000?ooooooo`0=oooo00<0I_ooooooool0O_ooo`00POoo
o`0306Kooooooooo00_oool00`000?ooooooo`0=oooo00<0I_ooooooool0O_ooo`00P?ooo`0306Ko
oooooooo00coool00`000?ooooooo`0=oooo00<0I_ooooooool0O_ooo`004?ooool0000Aoooo000F
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`00
100003?o03?o0?l0V@Pco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0006<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`0033?o0003o`2I
<ol0<ol002Xco`090000=?ooo`030000oooooooo01Goool008ooool00`0003?o03?o000<<ol000?o
09Tco`0co`0093?o00H0001Eoooo002?oooo00<0000co`0co`0033?o0003o`2I<ol0<ol0028co`02
0000Foooo`00Soooo`030000<ol0<ol000`co`000ol0VC?o03?o000P<ol00P0005goool008ooool0
0`0003?o03?o000<<ol000?o09Tco`0co`007C?o00<0001Ooooo002?oooo0P0000dco`000ol0VC?o
03?o000J<ol00`0006;oool008ooool00`0003?o03?o000<<ol000?o09Tco`0co`0063?o0080001U
oooo002?oooo00<0000co`0co`0033?o0003o`2I<ol0<ol001Lco`000`000?ooooooo`1Uoooo002?
oooo00<0000co`0co`0033?o0003o`2I<ol0<ol001Hco`000`000?ooooooo`1Voooo002?oooo00<0
000co`0co`0033?o0003o`2I<ol0<ol001Dco`000`000?ooooooo`1Woooo002?oooo00<0000co`0c
o`0033?o0003o`2I<ol0<ol001<co`020000J_ooo`00Soooo`80000=<ol000?o09Tco`0co`004S?o
00030000oooooooo06[oool008ooool00`0003?o03?o000<<ol000?o09Tco`0co`004C?o00030000
oooooooo06_oool008ooool00`0003?o03?o000<<ol000?o09Tco`0co`0043?o00030000oooooooo
06coool008ooool00`0003?o03?o000<<ol000?o09Tco`0co`0043?o00030000oooooooo06coool0
08ooool00`0003?o03?o000<<ol000?o09Tco`0co`003c?o00030000oooooooo06goool008ooool0
0`0003?o03?o000<<ol000?o09Tco`0co`003S?o00030000oooooooo06koool008ooool200003C?o
0003o`2I<ol0<ol000dco`000`000?ooooooo`1_oooo002?oooo00<0000co`0co`0033?o0003o`2I
<ol0<ol000`co`000`000?ooooooo`1`oooo002?oooo00<0000co`0co`0033?o0003o`2I<ol0<ol0
00`co`000`000?ooooooo`1`oooo002?oooo00<0000co`0co`0033?o0003o`2I<ol0<ol000/co`00
0`000?ooooooo`1aoooo002?oooo00<0000co`0co`0033?o0003o`2I<ol0<ol000/co`000`000?oo
ooooo`1aoooo002?oooo00<0000co`0co`0033?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1b
oooo002?oooo0P0000dco`000ol0VC?o03?o000:<ol000<0003oooooool0L_ooo`00Soooo`030000
<ol0<ol000`co`000ol0VC?o03?o0009<ol000<0003oooooool0Loooo`00Soooo`030000<ol0<ol0
00`co`000ol0VC?o03?o0009<ol000<0003oooooool0Loooo`00Soooo`030000<ol0<ol000`co`00
0ol0VC?o03?o0008<ol000<0003oooooool0M?ooo`00Soooo`030000<ol0<ol000`co`000ol0VC?o
03?o0008<ol000<0003oooooool0M?ooo`00Qoooo`D00003oooo00<0000co`0co`0033?o0003o`2I
<ol0<ol000Lco`000`000?ooooooo`1eoooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
00`co`000ol0VC?o03?o0007<ol000<0003oooooool0MOooo`00ROooo`030000oooooooo00?oool3
000033?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1foooo0029oooo00<0003oooooool00ooo
o`030000<ol0<ol000`co`000ol0VC?o03?o0006<ol000<0003oooooool0M_ooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000<<ol000?o09Tco`0co`001S?o00030000oooooooo07Koool0
08Soool200001Oooo`030000<ol0<ol000`co`000ol0VC?o03?o0005<ol000<0003oooooool0Mooo
o`00Soooo`030000<ol0<ol000`co`000ol0VC?o03?o0005<ol000<0003oooooool0Moooo`00Sooo
o`030000<ol0<ol000`co`000ol0VC?o03?o0004<ol000<0003oooooool0N?ooo`00Soooo`80000=
<ol000?o09Tco`0co`0013?o00030000oooooooo07Soool008ooool00`0003?o03?o000<<ol000?o
09Tco`0co`0013?o00030000oooooooo07Soool008ooool00`0003?o03?o000<<ol000?o09Tco`0c
o`000c?o00030000oooooooo07Woool008ooool00`0003?o03?o000<<ol000?o09Tco`0co`000c?o
00030000oooooooo07Woool008ooool00`0003?o03?o000<<ol000?o09Tco`0co`000c?o00030000
oooooooo07Woool008ooool00`0003?o03?o000<<ol000?o09Tco`0co`000S?o00030000oooooooo
07[oool008ooool200003C?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1joooo002?oooo00<0
000co`0co`0033?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1joooo002?oooo00<0000co`0c
o`0033?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1joooo002?oooo00<0000co`0co`0033?o
0005o`2I<ol0<ol0<ol0000007goool008ooool00`0003?o03?o000<<ol000Go09Tco`0co`0co`00
0000OOooo`00Soooo`030000<ol0<ol000`co`001Ol0VC?o03?o03?o0000001moooo002?oooo00<0
000co`0co`0033?o0005o`2I<ol0<ol0<ol0000007goool008ooool200003C?o0004o`2I<ol0<ol0
0000O_ooo`00Soooo`030000<ol0<ol000`co`001?l0VC?o03?o000007koool008ooool00`0003?o
03?o000<<ol000Co09Tco`0co`00001noooo002?oooo00<0000co`0co`0033?o0004o`2I<ol0<ol0
0000O_ooo`00Soooo`030000<ol0<ol000`co`001?l0VC?o03?o000007koool008ooool00`0003?o
03?o000<<ol000?o09Tco`000000Ooooo`00Soooo`80000=<ol000?o09Tco`000000Ooooo`00Sooo
o`030000<ol0<ol000`co`000ol0VC?o0000001ooooo002?oooo00<0000co`0co`0033?o0003o`2I
<ol0000007ooool008ooool00`0003?o03?o000<<ol000?o09T0003oool0Ooooo`00Qoooo`@00004
oooo00<0000co`0co`0033?o0003o`2I0000oooo07ooool008Ooool00`000?ooooooo`05oooo00<0
000co`0co`0033?o0003o`2I0000oooo07ooool008Soool00`000?ooooooo`04oooo0`0000`co`00
0ol0V@000?ooo`1ooooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000dco`000ol0VOoo
ooooo`1noooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0033?o00030000o`2Ioooo
07ooool008Soool200001Oooo`030000<ol0<ol000`co`000`000?l0VOooo`1ooooo002?oooo00<0
000co`0co`0033?o00030000o`2Ioooo07ooool008ooool00`0003?o03?o000<<ol000<0003o09Wo
ool0Ooooo`00Soooo`80000=<ol000<0003o09Woool0Ooooo`00Soooo`030000<ol0<ol000`co`00
0`000?l0VOooo`1ooooo002?oooo00<0000co`0co`002c?o00030000ooooo`2I083oool008ooool0
0`0003?o03?o000;<ol000<0003ooooo09T0P?ooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ool0V@20oooo002?oooo00<0000co`0co`002c?o00030000ooooo`2I083oool008ooool00`0003?o
03?o000;<ol000<0003ooooo09T0P?ooo`00Soooo`80000<<ol000<0003ooooo09T0P?ooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooool0V@20oooo002?oooo00<0000co`0co`002S?o00040000
ooooooooo`2IP?ooo`00Soooo`030000<ol0<ol000Xco`0010000?ooooooool0VH3oool008ooool0
0`0003?o03?o000:<ol000@0003ooooooooo09V0oooo002?oooo00<0000co`0co`002S?o00040000
ooooooooo`2IP?ooo`00Soooo`80000;<ol000@0003ooooooooo09V0oooo002?oooo00<0000co`0c
o`002S?o00040000ooooooooo`2IP?ooo`00Soooo`030000<ol0<ol000Xco`0010000?ooooooool0
VH3oool008ooool00`0003?o03?o0009<ol000D0003ooooooooooooo09T0P?ooo`00Soooo`030000
<ol0<ol000Tco`001@000?ooooooooooool0V@20oooo002?oooo00<0000co`0co`002C?o00050000
ooooooooooooo`2I083oool008ooool200002S?o00050000ooooooooooooo`2I083oool008ooool0
0`0003?o03?o0009<ol000D0003ooooooooooooo09T0P?ooo`00Soooo`030000<ol0<ol000Tco`00
1@000?ooooooooooool0V@20oooo002?oooo00<0000co`0co`0023?o00030000oooooooo00;oool0
0ol0VOooooooo`1noooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0003oooooool00_oo
o`03o`2Ioooooooo07koool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0
003oooooool00_ooo`03o`2Ioooooooo07koool008Woool00`000?ooooooo`03oooo0`0000Pco`00
0`000?ooooooo`02oooo00?o09Woooooool0O_ooo`00R_ooo`030000oooooooo00;oool00`0003?o
03?o0008<ol000<0003oooooool00_ooo`03o`2Ioooooooo07koool008Ooool010000?ooooooo`00
00Coool00`0003?o03?o0008<ol000<0003oooooool00_ooo`03o`2Ioooooooo07koool008Soool2
00001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`03oooo00?o09Woooooool0O_ooo`00Sooo
o`030000<ol0<ol000Lco`000`000?ooooooo`03oooo00?o09Woooooool0O_ooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`03oooo00?o09Woooooool0O_ooo`00Soooo`030000<ol0<ol0
00Lco`000`000?ooooooo`03oooo00?o09Woooooool0O_ooo`00Soooo`800008<ol000<0003ooooo
ool00oooo`03o`2Ioooooooo07koool008ooool00`0003?o03?o0007<ol000<0003oooooool00ooo
o`03o`2Ioooooooo07koool008ooool00`0003?o03?o0007<ol000<0003oooooool00oooo`03o`2I
oooooooo07koool008ooool00`0003?o03?o0007<ol000<0003oooooool00oooo`03o`2Ioooooooo
07koool008ooool00`0003?o03?o0006<ol000<0003oooooool01?ooo`03o`2Ioooooooo07koool0
08ooool00`0003?o03?o0006<ol000<0003oooooool01?ooo`03o`2Ioooooooo07koool008ooool2
00001c?o00030000oooooooo00Coool00ol0VOooooooo`1noooo002?oooo00<0000co`0co`001S?o
00030000oooooooo00Coool00ol0VOooooooo`1noooo002?oooo00<0000co`0co`001S?o00030000
oooooooo00Coool00ol0VOooooooo`1noooo002?oooo00<0000co`0co`001S?o00030000oooooooo
00Coool00ol0VOooooooo`1noooo002?oooo00<0000co`0co`001S?o00030000oooooooo00Coool0
0ol0VOooooooo`1noooo002?oooo00<0000co`0co`001S?o00030000oooooooo00Coool00ol0VOoo
ooooo`1noooo002?oooo0P0000Hco`000`000?ooooooo`05oooo00?o09Woooooool0O_ooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`05oooo00?o09Woooooool0O_ooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`05oooo00?o09Woooooool0O_ooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`05oooo00?o09Woooooool0O_ooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`05oooo00?o09Woooooool0O_ooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`05oooo00?o09Woooooool0O_ooo`00Soooo`800006<ol000<0003oooooool01Oooo`03o`2I
oooooooo07koool008ooool00`0003?o03?o0005<ol000<0003oooooool01Oooo`03o`2Ioooooooo
07koool008ooool00`0003?o03?o0005<ol000<0003oooooool01Oooo`03o`2Ioooooooo07koool0
08ooool00`0003?o03?o0004<ol000<0003oooooool01_ooo`03o`2Ioooooooo07koool008ooool0
0`0003?o03?o0004<ol000<0003oooooool01_ooo`03o`2Ioooooooo07koool008Woool300000ooo
o`030000<ol0<ol000@co`000`000?ooooooo`06oooo00?o09Woooooool0O_ooo`00R_ooo`030000
oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool01_ooo`03o`2Ioooooooo07koool0
08Ooool500000oooo`<00004<ol000<0003oooooool01_ooo`03o`2Ioooooooo07koool008Ooool0
10000?ooooooo`0000Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROoo
o`800004oooo1c?o08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003ooooo
ool04oooo`Lco`0>oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?oo
ooooo`09oooo1c?o00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool01_ooo`D00002<ol00P000003<ol0oooooooo00@00002oooo0`0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`07oooo00<0000co`0co`001C?o00;oool00`000?ooooooo`03oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0?
oooo00<0000co`0co`001C?o00?oool00`000?ooooooo`02oooo00@0003oooooool00004oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0000co`0co`001C?o00Coool0
10000?ooooooooooo`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
017oool00`0003?o03?o0005<ol00_ooo`040000oooooooo00000oooo`030000oooooooo00?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007<ol00oooo`800004oooo0`00
00;oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54934 .12361 L
.55436 .12361 L
.55972 .12361 L
.56236 .12361 L
.56366 .12361 L
.56486 .12361 L
.56594 .12361 L
s
.56594 .12361 m
.5664 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.42237 .12361 L
.42781 .12361 L
.43049 .12361 L
.43179 .12361 L
.43298 .12361 L
.43413 .12278 L
.43522 .12167 L
.43762 .11928 L
.44268 .11445 L
.46172 .09895 L
.48179 .08646 L
.50027 .07787 L
.52069 .06977 L
.53975 .06253 L
.54917 .05914 L
.55808 .05606 L
.563 .05443 L
.56435 .05399 L
.56509 .05375 L
.56578 .05352 L
.56701 .12361 L
.56766 .12361 L
.56836 .12361 L
.57773 .12361 L
.61887 .12361 L
.65849 .12361 L
.6966 .12361 L
.73716 .12361 L
.77621 .12361 L
.8177 .12361 L
.85768 .12361 L
.89615 .12361 L
.93707 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool02oooo`@0I_mo
oooo002?oooo00<0003oooooool02Oooo`80I_l3oooo00<0I_ooooooool0OOooo`00Soooo`030000
oooooooo00Koool306Ko1Oooo`0306Kooooooooo07goool008ooool00`000?ooooooo`04oooo0P1V
o`Soool00`1Vooooooooo`1moooo002?oooo00@0003oooooooooool306Ko2_ooo`0306Kooooooooo
07goool008ooool200000P1Vo`goool00`1Vooooooooo`1moooo000Goooo100003Woool50000=Ooo
o`0306Ko000006Ko00ooool00`1Vooooooooo`0Voooo1@0003Soool400005_ooo`005oooo`030000
oooooooo03coool00`000?ooooooo`0coooo0P1Vo`03oooo0000oooo00ooool00`1Vooooooooo`0X
oooo00<0003oooooool0>?ooo`030000oooooooo01Ooool001Soool00`000?ooooooo`0koooo00<0
003oooooool0<Oooo`80I_l3oooo00<0003oooooool03_ooo`0306Kooooooooo02Soool00`000?oo
ooooo`0ioooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool0<_ooo`@00004
oooo00<0003oooooool0;oooo`80I_l5oooo00<0003oooooool03_ooo`0306Kooooooooo02Soool0
0`000?ooooooo`0joooo00<0003oooooool05Oooo`005oooo`040000oooooooo0000>oooo`030000
oooooooo02goool206Ko1oooo`030000oooooooo00koool00`1Vooooooooo`0Xoooo00<0003ooooo
ool0>?ooo`040000oooooooo00005_ooo`006?ooo`80000koooo0P0002koool00`1Vooooooooo`07
oooo0P0000ooool00`1Vooooooooo`0Woooo0P0003_oool200005oooo`00Q?ooo`0306Kooooooooo
00Soool00`000?ooooooo`0>oooo00<0I_ooooooool0OOooo`00P_ooo`80I_l;oooo00<0003ooooo
ool03_ooo`0306Kooooooooo07goool0087oool00`1Vooooooooo`0;oooo00<0003oooooool03_oo
o`0306Kooooooooo07goool0083oool00`1Vooooooooo`0<oooo00<0003oooooool03_ooo`0306Ko
oooooooo07goool007ooool00`1Vooooooooo`0=oooo00<0003oooooool03_ooo`0306Kooooooooo
07goool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`0003?o03?o0009<ol000<0000co`0co`000S?o0003o`2I<ol0<ol000@co`000`0003?o
03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006<ol08P00
00Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool0
0`000?ooooooo`0ioooo00<0000co`0co`003S?o0003o`2I<ol0<ol002Pco`090000=?ooo`030000
oooooooo01Goool008ooool00`0003?o03?o000><ol000?o09Tco`0co`008S?o00H0001Eoooo002?
oooo00<0000co`0co`003S?o0003o`2I<ol0<ol0020co`020000Foooo`00Soooo`030000<ol0<ol0
00hco`000ol0VC?o03?o000N<ol00P0005goool008ooool00`0003?o03?o000><ol000?o09Tco`0c
o`006c?o00<0001Ooooo002?oooo0P0000lco`000ol0VC?o03?o000H<ol00`0006;oool008ooool0
0`0003?o03?o000><ol000?o09Tco`0co`005S?o0080001Uoooo002?oooo00<0000co`0co`003S?o
0003o`2I<ol0<ol001Dco`000`000?ooooooo`1Uoooo002?oooo00<0000co`0co`003S?o0003o`2I
<ol0<ol001@co`000`000?ooooooo`1Voooo002?oooo00<0000co`0co`003S?o0003o`2I<ol0<ol0
01<co`000`000?ooooooo`1Woooo002?oooo00<0000co`0co`003S?o0003o`2I<ol0<ol0014co`02
0000J_ooo`00Soooo`80000?<ol000?o09Tco`0co`0043?o00030000oooooooo06[oool008ooool0
0`0003?o03?o000><ol000?o09Tco`0co`003c?o00030000oooooooo06_oool008ooool00`0003?o
03?o000><ol000?o09Tco`0co`003S?o00030000oooooooo06coool008ooool00`0003?o03?o000>
<ol000?o09Tco`0co`003S?o00030000oooooooo06coool008ooool00`0003?o03?o000><ol000?o
09Tco`0co`003C?o00030000oooooooo06goool008ooool00`0003?o03?o000><ol000?o09Tco`0c
o`0033?o00030000oooooooo06koool008ooool200003c?o0003o`2I<ol0<ol000/co`000`000?oo
ooooo`1_oooo002?oooo00<0000co`0co`003S?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1`
oooo002?oooo00<0000co`0co`003S?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1`oooo002?
oooo00<0000co`0co`003S?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1aoooo002?oooo00<0
000co`0co`003S?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1aoooo002?oooo00<0000co`0c
o`003S?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`1boooo002?oooo0P0000lco`000ol0VC?o
03?o0008<ol000<0003oooooool0L_ooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o03?o0007
<ol000<0003oooooool0Loooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o03?o0007<ol000<0
003oooooool0Loooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o03?o0006<ol000<0003ooooo
ool0M?ooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o03?o0006<ol000<0003oooooool0M?oo
o`00Qoooo`D00003oooo00<0000co`0co`003S?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1e
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000hco`000ol0VC?o03?o0005<ol000<0
003oooooool0MOooo`00ROooo`030000oooooooo00?oool300003S?o0003o`2I<ol0<ol000@co`00
0`000?ooooooo`1foooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000hco`000ol0VC?o
03?o0004<ol000<0003oooooool0M_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000>
<ol000?o09Tco`0co`0013?o00030000oooooooo07Koool008Soool200001Oooo`030000<ol0<ol0
00hco`000ol0VC?o03?o0003<ol000<0003oooooool0Moooo`00Soooo`030000<ol0<ol000hco`00
0ol0VC?o03?o0003<ol000<0003oooooool0Moooo`00Soooo`030000<ol0<ol000hco`000ol0VC?o
03?o0002<ol000<0003oooooool0N?ooo`00Soooo`80000?<ol000?o09Tco`0co`000S?o00030000
oooooooo07Soool008ooool00`0003?o03?o000><ol000?o09Tco`0co`000S?o00030000oooooooo
07Soool008ooool00`0003?o03?o000><ol000Go09Tco`0co`0co`000000Noooo`00Soooo`030000
<ol0<ol000hco`001Ol0VC?o03?o03?o0000001koooo002?oooo00<0000co`0co`003S?o0005o`2I
<ol0<ol0<ol0000007_oool008ooool00`0003?o03?o000><ol000Co09Tco`0co`00001loooo002?
oooo0P0000lco`001?l0VC?o03?o000007coool008ooool00`0003?o03?o000><ol000Co09Tco`0c
o`00001loooo002?oooo00<0000co`0co`003S?o0004o`2I<ol0<ol00000O?ooo`00Soooo`030000
<ol0<ol000hco`000ol0VC?o0000001moooo002?oooo00<0000co`0co`003S?o0003o`2I<ol00000
07goool008ooool00`0003?o03?o000><ol000?o09Tco`000000OOooo`00Soooo`030000<ol0<ol0
00hco`000ol0VC?o0000001moooo002?oooo0P0000lco`000ol0V@000?ooo`1moooo002?oooo00<0
000co`0co`003S?o0003o`2I0000oooo07goool008ooool00`0003?o03?o000><ol000?o09T0003o
ool0OOooo`00Soooo`030000<ol0<ol000hco`000ol0V@000?ooo`1moooo002?oooo00<0000co`0c
o`003S?o0003o`2I0000oooo07goool008ooool00`0003?o03?o000><ol000?o09Woooooool0OOoo
o`00Soooo`80000?<ol000?o09Woooooool0OOooo`00Soooo`030000<ol0<ol000hco`000ol0VOoo
ooooo`1moooo002?oooo00<0000co`0co`003S?o0003o`2Ioooooooo07goool008ooool00`0003?o
03?o000=<ol000<0003o09Woool0O_ooo`00Qoooo`@00004oooo00<0000co`0co`003C?o00030000
o`2Ioooo07koool008Ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000o`2Ioooo
07koool008Soool00`000?ooooooo`04oooo0`0000dco`000`000?l0VOooo`1noooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol000dco`000`000?l0VOooo`1noooo0027oooo00@0003ooooo
ool00004oooo00<0000co`0co`0033?o00030000ooooo`2I07ooool008Soool200001Oooo`030000
<ol0<ol000`co`000`000?ooool0V@1ooooo002?oooo00<0000co`0co`0033?o00030000ooooo`2I
07ooool008ooool00`0003?o03?o000<<ol000<0003ooooo09T0Ooooo`00Soooo`80000=<ol000<0
003ooooo09T0Ooooo`00Soooo`030000<ol0<ol000`co`000`000?ooool0V@1ooooo002?oooo00<0
000co`0co`002c?o00040000ooooooooo`2IOoooo`00Soooo`030000<ol0<ol000/co`0010000?oo
ooooool0VGooool008ooool00`0003?o03?o000;<ol000@0003ooooooooo09Uooooo002?oooo00<0
000co`0co`002c?o00040000ooooooooo`2IOoooo`00Soooo`030000<ol0<ol000/co`0010000?oo
ooooool0VGooool008ooool2000033?o00040000ooooooooo`2IOoooo`00Soooo`030000<ol0<ol0
00/co`0010000?ooooooool0VGooool008ooool00`0003?o03?o000:<ol000D0003ooooooooooooo
09T0Ooooo`00Soooo`030000<ol0<ol000Xco`001@000?ooooooooooool0V@1ooooo002?oooo00<0
000co`0co`002S?o00050000ooooooooooooo`2I07ooool008ooool00`0003?o03?o000:<ol000D0
003ooooooooooooo09T0Ooooo`00Soooo`80000;<ol000D0003ooooooooooooo09T0Ooooo`00Sooo
o`030000<ol0<ol000Xco`001@000?ooooooooooool0V@1ooooo002?oooo00<0000co`0co`002S?o
00050000ooooooooooooo`2I07ooool008ooool00`0003?o03?o0009<ol000<0003oooooool00_oo
o`03o`2Ioooooooo07goool008ooool00`0003?o03?o0009<ol000<0003oooooool00_ooo`03o`2I
oooooooo07goool008ooool00`0003?o03?o0009<ol000<0003oooooool00_ooo`03o`2Ioooooooo
07goool008ooool200002S?o00030000oooooooo00;oool00ol0VOooooooo`1moooo002?oooo00<0
000co`0co`002C?o00030000oooooooo00;oool00ol0VOooooooo`1moooo002?oooo00<0000co`0c
o`002C?o00030000oooooooo00;oool00ol0VOooooooo`1moooo002?oooo00<0000co`0co`0023?o
00030000oooooooo00?oool00ol0VOooooooo`1moooo0028oooo0P0000Goool00`0003?o03?o0008
<ol000<0003oooooool00oooo`03o`2Ioooooooo07goool008Ooool010000?ooooooo`0000Coool0
0`0003?o03?o0008<ol000<0003oooooool00oooo`03o`2Ioooooooo07goool008Woool00`000?oo
ooooo`03oooo0`0000Pco`000`000?ooooooo`03oooo00?o09Woooooool0OOooo`00R_ooo`030000
oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool00oooo`03o`2Ioooooooo07goool0
08Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool00oooo`03o`2I
oooooooo07goool008Soool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`04oooo00?o
09Woooooool0OOooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`04oooo00?o09Wooooo
ool0OOooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`04oooo00?o09Woooooool0OOoo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`04oooo00?o09Woooooool0OOooo`00Sooo
o`800008<ol000<0003oooooool01?ooo`03o`2Ioooooooo07goool008ooool00`0003?o03?o0007
<ol000<0003oooooool01?ooo`03o`2Ioooooooo07goool008ooool00`0003?o03?o0007<ol000<0
003oooooool01?ooo`03o`2Ioooooooo07goool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool01?ooo`03o`2Ioooooooo07goool008ooool00`0003?o03?o0006<ol000<0003oooooool01Ooo
o`03o`2Ioooooooo07goool008ooool00`0003?o03?o0006<ol000<0003oooooool01Oooo`03o`2I
oooooooo07goool008ooool200001c?o00030000oooooooo00Goool00ol0VOooooooo`1moooo002?
oooo00<0000co`0co`001S?o00030000oooooooo00Goool00ol0VOooooooo`1moooo002?oooo00<0
000co`0co`001S?o00030000oooooooo00Goool00ol0VOooooooo`1moooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo00Goool00ol0VOooooooo`1moooo002?oooo00<0000co`0co`001S?o
00030000oooooooo00Goool00ol0VOooooooo`1moooo002?oooo00<0000co`0co`001S?o00030000
oooooooo00Goool00ol0VOooooooo`1moooo002?oooo0P0000Hco`000`000?ooooooo`06oooo00?o
09Woooooool0OOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`06oooo00?o09Wooooo
ool0OOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`06oooo00?o09Woooooool0OOoo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`06oooo00?o09Woooooool0OOooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`06oooo00?o09Woooooool0OOooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`06oooo00?o09Woooooool0OOooo`00Soooo`800006<ol000<0
003oooooool01_ooo`03o`2Ioooooooo07goool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool01_ooo`03o`2Ioooooooo07goool008ooool00`0003?o03?o0005<ol000<0003oooooool01_oo
o`03o`2Ioooooooo07goool008ooool00`0003?o03?o0004<ol000<0003oooooool01oooo`03o`2I
oooooooo07goool008ooool00`0003?o03?o0004<ol000<0003oooooool01oooo`03o`2Ioooooooo
07goool008Woool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`07oooo00?o09Wooooo
ool0OOooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool01ooo
o`03o`2Ioooooooo07goool008Ooool500000oooo`<00004<ol000<0003oooooool01oooo`03o`2I
oooooooo07goool008Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?ooo`030000oooo0000
00Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:
oooo001ioooo00<0003oooooool04oooo`Lco`0>oooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`09oooo1c?o00ooool00`000?ooooooo`1hoooo001hoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002<ol00P000003<ol0oooooooo
00@00003oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`07oooo00<0000co`0co`001C?o00;oool00`000?oo
ooooo`03oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0?oooo00<0000co`0co`001C?o00?oool00`000?ooooooo`02oooo00@0
003oooooool00004oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0
000co`0co`001C?o00Coool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000004Oooo`030000<ol0<ol000Dco`02oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool2
00001c?o00?oool200001?ooo`800003oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?
oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54934 .12361 L
.55972 .12361 L
.56446 .12361 L
.56706 .12361 L
.56834 .12361 L
.56951 .12361 L
.57063 .12361 L
s
.57063 .12361 m
.5711 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.41696 .12361 L
.42237 .12361 L
.42482 .12361 L
.42617 .12361 L
.42744 .12361 L
.42816 .12361 L
.42894 .12322 L
.42966 .12249 L
.43031 .12182 L
.43298 .11916 L
.44268 .1102 L
.46172 .09566 L
.48054 .08464 L
.5012 .07569 L
.52235 .06785 L
.54163 .06091 L
.5512 .05761 L
.55625 .05592 L
.56161 .05417 L
.56628 .05269 L
.56756 .05229 L
.56894 .05186 L
.57025 .05146 L
.57144 .12361 L
.57254 .12361 L
.57356 .12361 L
.57587 .12361 L
.58054 .12361 L
.61958 .12361 L
.66108 .12361 L
.70106 .12361 L
.73953 .12361 L
.78045 .12361 L
.81985 .12361 L
.85774 .12361 L
.89808 .12361 L
.9369 .12361 L
.97619 .12361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80000?oooo0P1Vogkoool008ooool00`000?ooooooo`0;
oooo0`1Vo`03oooo06Kooooo07goool008ooool00`000?ooooooo`0:oooo00<0I_ooooooool00_oo
o`0306Kooooooooo07coool008ooool00`000?ooooooo`06oooo101Vo`Goool00`1Vooooooooo`1l
oooo002?oooo00<0003oooooool00_ooo`@0I_l9oooo00<0I_ooooooool0O?ooo`00Soooo`030000
oooo06Ko0080I_l=oooo00<0I_ooooooool0O?ooo`00Soooo`80000@oooo00<0I_ooooooool0O?oo
o`005oooo`@0000ioooo1@0003Coool206Ko00<0003oooooool03oooo`0306Kooooooooo02Goool5
0000>?ooo`@0000Foooo000Goooo00<0003oooooool0??ooo`030000oooooooo03;oool206Ko0_oo
o`030000oooooooo00ooool00`1Vooooooooo`0Woooo00<0003oooooool0>?ooo`030000oooooooo
01Ooool001Soool00`000?ooooooo`0koooo00<0003oooooool0<?ooo`80I_l4oooo00<0003ooooo
ool03oooo`0306Kooooooooo02Ooool00`000?ooooooo`0ioooo00<0003oooooool05_ooo`004Ooo
o`@00004oooo00<0003oooooool0<_ooo`@00004oooo00<0003oooooool0;_ooo`80I_l6oooo00<0
003oooooool03oooo`0306Kooooooooo02Ooool00`000?ooooooo`0joooo00<0003oooooool05Ooo
o`005oooo`040000oooooooo0000>oooo`030000oooooooo02coool206Ko2?ooo`030000oooooooo
00ooool00`1Vooooooooo`0Woooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`80000koooo0P0002goool00`1Vooooooooo`08oooo0P00013oool00`1Vooooooooo`0Voooo0P00
03_oool200005oooo`00P_ooo`80I_l;oooo00<0003oooooool03oooo`0306Kooooooooo07coool0
087oool00`1Vooooooooo`0;oooo00<0003oooooool03oooo`0306Kooooooooo07coool0083oool0
0`1Vooooooooo`0<oooo00<0003oooooool03oooo`0306Kooooooooo07coool007ooool00`1Voooo
ooooo`0=oooo00<0003oooooool03oooo`0306Kooooooooo07coool007koool00`1Vooooooooo`0>
oooo00<0003oooooool03oooo`0306Kooooooooo07coool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0c
o`000c?o0003o`2I<ol0<ol000<co`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0006<ol08P0000Koool00`000?ooooooo`09oooo00<0003ooooo
ool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`003c?o
0003o`2I<ol0<ol002Lco`090000=?ooo`030000oooooooo01Goool008ooool00`0003?o03?o000?
<ol000?o09Tco`0co`008C?o00H0001Eoooo002?oooo00<0000co`0co`003c?o0003o`2I<ol0<ol0
01lco`020000Foooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o000M<ol00P0005goool0
08ooool00`0003?o03?o000?<ol000?o09Tco`0co`006S?o00<0001Ooooo002?oooo0P00010co`00
0ol0VC?o03?o000G<ol00`0006;oool008ooool00`0003?o03?o000?<ol000?o09Tco`0co`005C?o
0080001Uoooo002?oooo00<0000co`0co`003c?o0003o`2I<ol0<ol001@co`000`000?ooooooo`1U
oooo002?oooo00<0000co`0co`003c?o0003o`2I<ol0<ol001<co`000`000?ooooooo`1Voooo002?
oooo00<0000co`0co`003c?o0003o`2I<ol0<ol0018co`000`000?ooooooo`1Woooo002?oooo00<0
000co`0co`003c?o0003o`2I<ol0<ol0010co`020000J_ooo`00Soooo`80000@<ol000?o09Tco`0c
o`003c?o00030000oooooooo06[oool008ooool00`0003?o03?o000?<ol000?o09Tco`0co`003S?o
00030000oooooooo06_oool008ooool00`0003?o03?o000?<ol000?o09Tco`0co`003C?o00030000
oooooooo06coool008ooool00`0003?o03?o000?<ol000?o09Tco`0co`003C?o00030000oooooooo
06coool008ooool00`0003?o03?o000?<ol000?o09Tco`0co`0033?o00030000oooooooo06goool0
08ooool00`0003?o03?o000?<ol000?o09Tco`0co`002c?o00030000oooooooo06koool008ooool2
000043?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1_oooo002?oooo00<0000co`0co`003c?o
0003o`2I<ol0<ol000Tco`000`000?ooooooo`1`oooo002?oooo00<0000co`0co`003c?o0003o`2I
<ol0<ol000Tco`000`000?ooooooo`1`oooo002?oooo00<0000co`0co`003c?o0003o`2I<ol0<ol0
00Pco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`003c?o0003o`2I<ol0<ol000Pco`00
0`000?ooooooo`1aoooo002?oooo00<0000co`0co`003c?o0003o`2I<ol0<ol000Lco`000`000?oo
ooooo`1boooo002?oooo0P00010co`000ol0VC?o03?o0007<ol000<0003oooooool0L_ooo`00Sooo
o`030000<ol0<ol000lco`000ol0VC?o03?o0006<ol000<0003oooooool0Loooo`00Soooo`030000
<ol0<ol000lco`000ol0VC?o03?o0006<ol000<0003oooooool0Loooo`00Soooo`030000<ol0<ol0
00lco`000ol0VC?o03?o0005<ol000<0003oooooool0M?ooo`00Soooo`030000<ol0<ol000lco`00
0ol0VC?o03?o0005<ol000<0003oooooool0M?ooo`00Qoooo`D00003oooo00<0000co`0co`003c?o
0003o`2I<ol0<ol000@co`000`000?ooooooo`1eoooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol000lco`000ol0VC?o03?o0004<ol000<0003oooooool0MOooo`00ROooo`030000oooooooo
00?oool300003c?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1foooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol000lco`000ol0VC?o03?o0003<ol000<0003oooooool0M_ooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000?<ol000?o09Tco`0co`000c?o00030000oooooooo
07Koool008Soool200001Oooo`030000<ol0<ol000lco`000ol0VC?o03?o0002<ol000<0003ooooo
ool0Moooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o03?o0002<ol000<0003oooooool0Mooo
o`00Soooo`030000<ol0<ol000lco`001Ol0VC?o03?o03?o0000001joooo002?oooo0P00010co`00
1Ol0VC?o03?o03?o0000001joooo002?oooo00<0000co`0co`003c?o0005o`2I<ol0<ol0<ol00000
07[oool008ooool00`0003?o03?o000?<ol000Co09Tco`0co`00001koooo002?oooo00<0000co`0c
o`003c?o0004o`2I<ol0<ol00000Noooo`00Soooo`030000<ol0<ol000lco`001?l0VC?o03?o0000
07_oool008ooool00`0003?o03?o000?<ol000?o09Tco`000000O?ooo`00Soooo`80000@<ol000?o
09Tco`000000O?ooo`00Soooo`030000<ol0<ol000lco`000ol0VC?o0000001loooo002?oooo00<0
000co`0co`003c?o0003o`2I<ol0000007coool008ooool00`0003?o03?o000?<ol000?o09T0003o
ool0O?ooo`00Soooo`030000<ol0<ol000lco`000ol0V@000?ooo`1loooo002?oooo00<0000co`0c
o`003c?o0003o`2I0000oooo07coool008ooool00`0003?o03?o000?<ol000?o09T0003oool0O?oo
o`00Soooo`80000@<ol000?o09Woooooool0O?ooo`00Soooo`030000<ol0<ol000lco`000ol0VOoo
ooooo`1loooo002?oooo00<0000co`0co`003c?o0003o`2Ioooooooo07coool008ooool00`0003?o
03?o000?<ol000?o09Woooooool0O?ooo`00Soooo`030000<ol0<ol000lco`000ol0VOooooooo`1l
oooo002?oooo00<0000co`0co`003S?o00030000o`2Ioooo07goool008ooool200003c?o00030000
o`2Ioooo07goool008ooool00`0003?o03?o000><ol000<0003o09Woool0OOooo`00Soooo`030000
<ol0<ol000hco`000`000?l0VOooo`1moooo002?oooo00<0000co`0co`003C?o00030000ooooo`2I
07koool008Ooool400001?ooo`030000<ol0<ol000dco`000`000?ooool0V@1noooo0027oooo00<0
003oooooool01Oooo`030000<ol0<ol000dco`000`000?ooool0V@1noooo0028oooo00<0003ooooo
ool01?ooo`<0000=<ol000<0003ooooo09T0O_ooo`00ROooo`030000oooooooo00?oool00`0003?o
03?o000=<ol000<0003ooooo09T0O_ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol0
00`co`0010000?ooooooool0VGkoool008Soool200001Oooo`030000<ol0<ol000`co`0010000?oo
ooooool0VGkoool008ooool00`0003?o03?o000<<ol000@0003ooooooooo09Unoooo002?oooo00<0
000co`0co`0033?o00040000ooooooooo`2IO_ooo`00Soooo`80000=<ol000@0003ooooooooo09Un
oooo002?oooo00<0000co`0co`0033?o00040000ooooooooo`2IO_ooo`00Soooo`030000<ol0<ol0
00/co`001@000?ooooooooooool0V@1noooo002?oooo00<0000co`0co`002c?o00050000oooooooo
ooooo`2I07koool008ooool00`0003?o03?o000;<ol000D0003ooooooooooooo09T0O_ooo`00Sooo
o`030000<ol0<ol000/co`001@000?ooooooooooool0V@1noooo002?oooo00<0000co`0co`002c?o
00050000ooooooooooooo`2I07koool008ooool2000033?o00050000ooooooooooooo`2I07koool0
08ooool00`0003?o03?o000;<ol000D0003ooooooooooooo09T0O_ooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`02oooo00?o09Woooooool0O?ooo`00Soooo`030000<ol0<ol000Xco`00
0`000?ooooooo`02oooo00?o09Woooooool0O?ooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`02oooo00?o09Woooooool0O?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`02
oooo00?o09Woooooool0O?ooo`00Soooo`80000;<ol000<0003oooooool00_ooo`03o`2Ioooooooo
07coool008ooool00`0003?o03?o000:<ol000<0003oooooool00_ooo`03o`2Ioooooooo07coool0
08ooool00`0003?o03?o000:<ol000<0003oooooool00_ooo`03o`2Ioooooooo07coool008ooool0
0`0003?o03?o0009<ol000<0003oooooool00oooo`03o`2Ioooooooo07coool008ooool00`0003?o
03?o0009<ol000<0003oooooool00oooo`03o`2Ioooooooo07coool008ooool00`0003?o03?o0009
<ol000<0003oooooool00oooo`03o`2Ioooooooo07coool008ooool200002S?o00030000oooooooo
00?oool00ol0VOooooooo`1loooo002?oooo00<0000co`0co`002C?o00030000oooooooo00?oool0
0ol0VOooooooo`1loooo002?oooo00<0000co`0co`002C?o00030000oooooooo00?oool00ol0VOoo
ooooo`1loooo002?oooo00<0000co`0co`0023?o00030000oooooooo00Coool00ol0VOooooooo`1l
oooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0003oooooool01?ooo`03o`2Ioooooooo
07coool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool01?oo
o`03o`2Ioooooooo07coool008Woool00`000?ooooooo`03oooo0`0000Pco`000`000?ooooooo`04
oooo00?o09Woooooool0O?ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008<ol000<0
003oooooool01?ooo`03o`2Ioooooooo07coool008Ooool010000?ooooooo`0000Coool00`0003?o
03?o0008<ol000<0003oooooool01?ooo`03o`2Ioooooooo07coool008Soool200001Oooo`030000
<ol0<ol000Lco`000`000?ooooooo`05oooo00?o09Woooooool0O?ooo`00Soooo`030000<ol0<ol0
00Lco`000`000?ooooooo`05oooo00?o09Woooooool0O?ooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`05oooo00?o09Woooooool0O?ooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ooooo`05oooo00?o09Woooooool0O?ooo`00Soooo`800008<ol000<0003oooooool01Oooo`03o`2I
oooooooo07coool008ooool00`0003?o03?o0007<ol000<0003oooooool01Oooo`03o`2Ioooooooo
07coool008ooool00`0003?o03?o0007<ol000<0003oooooool01Oooo`03o`2Ioooooooo07coool0
08ooool00`0003?o03?o0007<ol000<0003oooooool01Oooo`03o`2Ioooooooo07coool008ooool0
0`0003?o03?o0006<ol000<0003oooooool01_ooo`03o`2Ioooooooo07coool008ooool00`0003?o
03?o0006<ol000<0003oooooool01_ooo`03o`2Ioooooooo07coool008ooool200001c?o00030000
oooooooo00Koool00ol0VOooooooo`1loooo002?oooo00<0000co`0co`001S?o00030000oooooooo
00Koool00ol0VOooooooo`1loooo002?oooo00<0000co`0co`001S?o00030000oooooooo00Koool0
0ol0VOooooooo`1loooo002?oooo00<0000co`0co`001S?o00030000oooooooo00Koool00ol0VOoo
ooooo`1loooo002?oooo00<0000co`0co`001S?o00030000oooooooo00Koool00ol0VOooooooo`1l
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo00Koool00ol0VOooooooo`1loooo002?
oooo0P0000Hco`000`000?ooooooo`07oooo00?o09Woooooool0O?ooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`07oooo00?o09Woooooool0O?ooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`07oooo00?o09Woooooool0O?ooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`07oooo00?o09Woooooool0O?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`07
oooo00?o09Woooooool0O?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`07oooo00?o
09Woooooool0O?ooo`00Soooo`800006<ol000<0003oooooool01oooo`03o`2Ioooooooo07coool0
08ooool00`0003?o03?o0005<ol000<0003oooooool01oooo`03o`2Ioooooooo07coool008ooool0
0`0003?o03?o0005<ol000<0003oooooool01oooo`03o`2Ioooooooo07coool008ooool00`0003?o
03?o0004<ol000<0003oooooool02?ooo`03o`2Ioooooooo07coool008ooool00`0003?o03?o0004
<ol000<0003oooooool02?ooo`03o`2Ioooooooo07coool008Woool300000oooo`030000<ol0<ol0
00@co`000`000?ooooooo`08oooo00?o09Woooooool0O?ooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o0004<ol000<0003oooooool02?ooo`03o`2Ioooooooo07coool008Ooool500000ooo
o`<00004<ol000<0003oooooool02?ooo`03o`2Ioooooooo07coool008Ooool010000?ooooooo`00
00Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o
08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001loooo00<0003oooooool04?ooo`Lco`0;
oooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`06oooo1c?o
00coool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01_ooo`D00002<ol00P0000Coool200001?ooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool2<ol000<0000co`0c
o`000S?o00Goool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0003ooooo
ool00_ooo`030000oooooooo00goool2<ol000<0000co`0co`000S?o00Ooool00`000?ooooooo`03
oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<oooo0S?o00030000<ol0<ol0
008co`08oooo00D0003oooooooooool00000OOooo`00Noooo`050000oooooooooooo000000ooool2
<ol000<0000co`0co`000S?o00Goool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001l
oooo00<0003oooooool04?ooo`03<ol00000000000@co`06oooo0P0000?oool00`000?ooooooo`1l
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.52059 .12361 L
.53984 .12361 L
.54934 .12361 L
.55972 .12361 L
.56446 .12361 L
.56951 .12361 L
.57197 .12361 L
.57318 .12361 L
.57429 .12361 L
.5753 .12361 L
s
.5753 .12361 m
.57572 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40095 .12361 L
.41127 .12361 L
.41696 .12361 L
.41976 .12361 L
.42113 .12361 L
.42237 .12361 L
.42363 .12361 L
.42482 .12256 L
.42744 .11992 L
.43298 .11462 L
.44268 .1062 L
.46172 .09258 L
.48179 .08172 L
.50027 .07436 L
.52069 .06728 L
.53975 .06071 L
.55808 .05467 L
.56336 .05301 L
.56836 .05147 L
.57284 .05013 L
.57407 .04977 L
.57538 .04939 L
.5765 .12361 L
.57773 .12361 L
.61793 .12361 L
.65662 .12361 L
.69776 .12361 L
.73738 .12361 L
.77549 .12361 L
.81605 .12361 L
.8551 .12361 L
.89659 .12361 L
.93658 .12361 L
.97504 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80000?oooo0`1Voggoool008ooool00`000?ooooooo`0:
oooo101Vo`;oool00`1Vooooooooo`1koooo002?oooo00<0003oooooool01_ooo`@0I_l6oooo00<0
I_ooooooool0Noooo`00Soooo`030000oooooooo00Coool206Ko2_ooo`0306Kooooooooo07_oool0
08ooool010000?ooooooooooo`<0I_l<oooo00<0I_ooooooool0Noooo`00Soooo`040000oooo06Ko
06Ko3oooo`0306Kooooooooo07_oool008koool00`1Vo`000000000Aoooo00<0I_ooooooool0Nooo
o`005oooo`@0000ioooo1@0003?oool206Ko00?oool0003oool04Oooo`0306Kooooooooo02Coool5
0000>?ooo`@0000Foooo000Goooo00<0003oooooool0??ooo`030000oooooooo037oool206Ko0ooo
o`030000oooooooo013oool00`1Vooooooooo`0Voooo00<0003oooooool0>?ooo`030000oooooooo
01Ooool001Soool00`000?ooooooo`0koooo00<0003oooooool0;oooo`80I_l5oooo00<0003ooooo
ool04?ooo`0306Kooooooooo02Koool00`000?ooooooo`0ioooo00<0003oooooool05_ooo`004Ooo
o`@00004oooo00<0003oooooool0<_ooo`@00004oooo00<0003oooooool0;Oooo`80I_l7oooo00<0
003oooooool04?ooo`0306Kooooooooo02Koool00`000?ooooooo`0joooo00<0003oooooool05Ooo
o`005oooo`040000oooooooo0000>oooo`030000oooooooo02coool00`1Vooooooooo`07oooo00<0
003oooooool04?ooo`0306Kooooooooo02Koool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo0P0003_oool20000;?ooo`80I_l:oooo0P00017oool00`1Vooooooooo`0Uoooo0P00
03_oool200005oooo`00POooo`80I_l<oooo00<0003oooooool04?ooo`0306Kooooooooo07_oool0
083oool00`1Vooooooooo`0<oooo00<0003oooooool04?ooo`0306Kooooooooo07_oool007ooool0
0`1Vooooooooo`0=oooo00<0003oooooool04?ooo`0306Kooooooooo07_oool007koool00`1Voooo
ooooo`0>oooo00<0003oooooool04?ooo`0306Kooooooooo07_oool007goool00`1Vooooooooo`0?
oooo00<0003oooooool04?ooo`0306Kooooooooo07_oool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0c
o`0013?o0003o`2I<ol0<ol0008co`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0006<ol08P0000Koool00`000?ooooooo`09oooo00<0003ooooo
ool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`0043?o
0003o`2I<ol0<ol002Hco`090000=?ooo`030000oooooooo01Goool008ooool00`0003?o03?o000@
<ol000?o09Tco`0co`0083?o00H0001Eoooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol0
01hco`020000Foooo`00Soooo`030000<ol0<ol0010co`000ol0VC?o03?o000L<ol00P0005goool0
08ooool00`0003?o03?o000@<ol000?o09Tco`0co`006C?o00<0001Ooooo002?oooo0P00014co`00
0ol0VC?o03?o000F<ol00`0006;oool008ooool00`0003?o03?o000@<ol000?o09Tco`0co`0053?o
0080001Uoooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol001<co`000`000?ooooooo`1U
oooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol0018co`000`000?ooooooo`1Voooo002?
oooo00<0000co`0co`0043?o0003o`2I<ol0<ol0014co`000`000?ooooooo`1Woooo002?oooo00<0
000co`0co`0043?o0003o`2I<ol0<ol000lco`020000J_ooo`00Soooo`80000A<ol000?o09Tco`0c
o`003S?o00030000oooooooo06[oool008ooool00`0003?o03?o000@<ol000?o09Tco`0co`003C?o
00030000oooooooo06_oool008ooool00`0003?o03?o000@<ol000?o09Tco`0co`0033?o00030000
oooooooo06coool008ooool00`0003?o03?o000@<ol000?o09Tco`0co`0033?o00030000oooooooo
06coool008ooool00`0003?o03?o000@<ol000?o09Tco`0co`002c?o00030000oooooooo06goool0
08ooool00`0003?o03?o000@<ol000?o09Tco`0co`002S?o00030000oooooooo06koool008ooool2
00004C?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1_oooo002?oooo00<0000co`0co`0043?o
0003o`2I<ol0<ol000Pco`000`000?ooooooo`1`oooo002?oooo00<0000co`0co`0043?o0003o`2I
<ol0<ol000Pco`000`000?ooooooo`1`oooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol0
00Lco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol000Lco`00
0`000?ooooooo`1aoooo002?oooo00<0000co`0co`0043?o0003o`2I<ol0<ol000Hco`000`000?oo
ooooo`1boooo002?oooo0P00014co`000ol0VC?o03?o0006<ol000<0003oooooool0L_ooo`00Sooo
o`030000<ol0<ol0010co`000ol0VC?o03?o0005<ol000<0003oooooool0Loooo`00Soooo`030000
<ol0<ol0010co`000ol0VC?o03?o0005<ol000<0003oooooool0Loooo`00Soooo`030000<ol0<ol0
010co`000ol0VC?o03?o0004<ol000<0003oooooool0M?ooo`00Soooo`030000<ol0<ol0010co`00
0ol0VC?o03?o0004<ol000<0003oooooool0M?ooo`00Qoooo`D00003oooo00<0000co`0co`0043?o
0003o`2I<ol0<ol000<co`000`000?ooooooo`1eoooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol0010co`000ol0VC?o03?o0003<ol000<0003oooooool0MOooo`00ROooo`030000oooooooo
00?oool3000043?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1foooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol0010co`000ol0VC?o03?o0002<ol000<0003oooooool0M_ooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000@<ol000?o09Tco`0co`000S?o00030000oooooooo
07Koool008Soool200001Oooo`030000<ol0<ol0010co`001Ol0VC?o03?o03?o0000001ioooo002?
oooo00<0000co`0co`0043?o0005o`2I<ol0<ol0<ol0000007Woool008ooool00`0003?o03?o000@
<ol000Co09Tco`0co`00001joooo002?oooo0P00014co`001?l0VC?o03?o000007[oool008ooool0
0`0003?o03?o000@<ol000Co09Tco`0co`00001joooo002?oooo00<0000co`0co`0043?o0003o`2I
<ol0000007_oool008ooool00`0003?o03?o000@<ol000?o09Tco`000000Noooo`00Soooo`030000
<ol0<ol0010co`000ol0VC?o0000001koooo002?oooo00<0000co`0co`0043?o0003o`2I0000oooo
07_oool008ooool200004C?o0003o`2I0000oooo07_oool008ooool00`0003?o03?o000@<ol000?o
09T0003oool0Noooo`00Soooo`030000<ol0<ol0010co`000ol0V@000?ooo`1koooo002?oooo00<0
000co`0co`0043?o0003o`2Ioooooooo07_oool008ooool00`0003?o03?o000@<ol000?o09Wooooo
ool0Noooo`00Soooo`030000<ol0<ol0010co`000ol0VOooooooo`1koooo002?oooo00<0000co`0c
o`0043?o0003o`2Ioooooooo07_oool008ooool2000043?o00030000o`2Ioooo07coool008ooool0
0`0003?o03?o000?<ol000<0003o09Woool0O?ooo`00Soooo`030000<ol0<ol000lco`000`000?l0
VOooo`1loooo002?oooo00<0000co`0co`003c?o00030000o`2Ioooo07coool008ooool00`0003?o
03?o000?<ol000<0003o09Woool0O?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooool0V@1m
oooo002?oooo0P0000lco`000`000?ooool0V@1moooo002?oooo00<0000co`0co`003S?o00030000
ooooo`2I07goool008ooool00`0003?o03?o000><ol000<0003ooooo09T0OOooo`00Soooo`030000
<ol0<ol000dco`0010000?ooooooool0VGgoool008Ooool400001?ooo`030000<ol0<ol000dco`00
10000?ooooooool0VGgoool008Ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o00040000
ooooooooo`2IOOooo`00R?ooo`030000oooooooo00Coool300003C?o00040000ooooooooo`2IOOoo
o`00ROooo`030000oooooooo00?oool00`0003?o03?o000=<ol000@0003ooooooooo09Umoooo0027
oooo00@0003oooooool00004oooo00<0000co`0co`0033?o00050000ooooooooooooo`2I07goool0
08Soool200001Oooo`030000<ol0<ol000`co`001@000?ooooooooooool0V@1moooo002?oooo00<0
000co`0co`0033?o00050000ooooooooooooo`2I07goool008ooool00`0003?o03?o000<<ol000D0
003ooooooooooooo09T0OOooo`00Soooo`80000=<ol000D0003ooooooooooooo09T0OOooo`00Sooo
o`030000<ol0<ol000`co`001@000?ooooooooooool0V@1moooo002?oooo00<0000co`0co`002c?o
00030000oooooooo00;oool00ol0VOooooooo`1koooo002?oooo00<0000co`0co`002c?o00030000
oooooooo00;oool00ol0VOooooooo`1koooo002?oooo00<0000co`0co`002c?o00030000oooooooo
00;oool00ol0VOooooooo`1koooo002?oooo00<0000co`0co`002c?o00030000oooooooo00;oool0
0ol0VOooooooo`1koooo002?oooo00<0000co`0co`002c?o00030000oooooooo00;oool00ol0VOoo
ooooo`1koooo002?oooo0P0000`co`000`000?ooooooo`02oooo00?o09Woooooool0Noooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`02oooo00?o09Woooooool0Noooo`00Soooo`030000
<ol0<ol000Xco`000`000?ooooooo`03oooo00?o09Woooooool0Noooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`03oooo00?o09Woooooool0Noooo`00Soooo`030000<ol0<ol000Xco`00
0`000?ooooooo`03oooo00?o09Woooooool0Noooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`03oooo00?o09Woooooool0Noooo`00Soooo`80000;<ol000<0003oooooool00oooo`03o`2I
oooooooo07_oool008ooool00`0003?o03?o000:<ol000<0003oooooool00oooo`03o`2Ioooooooo
07_oool008ooool00`0003?o03?o000:<ol000<0003oooooool00oooo`03o`2Ioooooooo07_oool0
08ooool00`0003?o03?o0009<ol000<0003oooooool01?ooo`03o`2Ioooooooo07_oool008ooool0
0`0003?o03?o0009<ol000<0003oooooool01?ooo`03o`2Ioooooooo07_oool008ooool00`0003?o
03?o0009<ol000<0003oooooool01?ooo`03o`2Ioooooooo07_oool008ooool200002S?o00030000
oooooooo00Coool00ol0VOooooooo`1koooo002?oooo00<0000co`0co`002C?o00030000oooooooo
00Coool00ol0VOooooooo`1koooo002?oooo00<0000co`0co`002C?o00030000oooooooo00Coool0
0ol0VOooooooo`1koooo002?oooo00<0000co`0co`0023?o00030000oooooooo00Goool00ol0VOoo
ooooo`1koooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0003oooooool01Oooo`03o`2I
oooooooo07_oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003ooooo
ool01Oooo`03o`2Ioooooooo07_oool008Woool00`000?ooooooo`03oooo0`0000Pco`000`000?oo
ooooo`05oooo00?o09Woooooool0Noooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008
<ol000<0003oooooool01Oooo`03o`2Ioooooooo07_oool008Ooool010000?ooooooo`0000Coool0
0`0003?o03?o0008<ol000<0003oooooool01Oooo`03o`2Ioooooooo07_oool008Soool200001Ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`06oooo00?o09Woooooool0Noooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`06oooo00?o09Woooooool0Noooo`00Soooo`030000<ol0<ol0
00Lco`000`000?ooooooo`06oooo00?o09Woooooool0Noooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`06oooo00?o09Woooooool0Noooo`00Soooo`800008<ol000<0003oooooool01_oo
o`03o`2Ioooooooo07_oool008ooool00`0003?o03?o0007<ol000<0003oooooool01_ooo`03o`2I
oooooooo07_oool008ooool00`0003?o03?o0007<ol000<0003oooooool01_ooo`03o`2Ioooooooo
07_oool008ooool00`0003?o03?o0007<ol000<0003oooooool01_ooo`03o`2Ioooooooo07_oool0
08ooool00`0003?o03?o0006<ol000<0003oooooool01oooo`03o`2Ioooooooo07_oool008ooool0
0`0003?o03?o0006<ol000<0003oooooool01oooo`03o`2Ioooooooo07_oool008ooool200001c?o
00030000oooooooo00Ooool00ol0VOooooooo`1koooo002?oooo00<0000co`0co`001S?o00030000
oooooooo00Ooool00ol0VOooooooo`1koooo002?oooo00<0000co`0co`001S?o00030000oooooooo
00Ooool00ol0VOooooooo`1koooo002?oooo00<0000co`0co`001S?o00030000oooooooo00Ooool0
0ol0VOooooooo`1koooo002?oooo00<0000co`0co`001S?o00030000oooooooo00Ooool00ol0VOoo
ooooo`1koooo002?oooo00<0000co`0co`001S?o00030000oooooooo00Ooool00ol0VOooooooo`1k
oooo002?oooo0P0000Hco`000`000?ooooooo`08oooo00?o09Woooooool0Noooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`08oooo00?o09Woooooool0Noooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`08oooo00?o09Woooooool0Noooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`08oooo00?o09Woooooool0Noooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`08oooo00?o09Woooooool0Noooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`08
oooo00?o09Woooooool0Noooo`00Soooo`800006<ol000<0003oooooool02?ooo`03o`2Ioooooooo
07_oool008ooool00`0003?o03?o0005<ol000<0003oooooool02?ooo`03o`2Ioooooooo07_oool0
08ooool00`0003?o03?o0005<ol000<0003oooooool02?ooo`03o`2Ioooooooo07_oool008ooool0
0`0003?o03?o0004<ol000<0003oooooool02Oooo`03o`2Ioooooooo07_oool008ooool00`0003?o
03?o0004<ol000<0003oooooool02Oooo`03o`2Ioooooooo07_oool008Woool300000oooo`030000
<ol0<ol000@co`000`000?ooooooo`09oooo00?o09Woooooool0Noooo`00R_ooo`030000oooooooo
00;oool00`0003?o03?o0004<ol000<0003oooooool02Oooo`03o`2Ioooooooo07_oool008Ooool5
00000oooo`<00004<ol000<0003oooooool02Oooo`03o`2Ioooooooo07_oool008Ooool010000?oo
ooooo`0000Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004
oooo1c?o08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04ooo
o`Lco`0>oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09
oooo1c?o00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01_ooo`D00002<ol00P000004<ol0oooooooooooo0P0000?oool400000oooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Ooool00`0003?o03?o0005<ol00_ooo`040000oooooooo00000_ooo`030000oooooooo
00Coool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00ooool0
0`0003?o03?o0005<ol01?ooo`030000oooooooo00;oool00`000?ooooooo`04oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0000co`0co`001C?o00Goool00`000?oo
ooooo`02oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`00000Aoooo00<0000co`0co`001C?o00;oool010000?ooooooo`0000;oool010000?ooooooo`00
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007<ol00oooo`800004
oooo0P0000?oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.55838 .12361 L
.56817 .12361 L
.57355 .12361 L
.57618 .12361 L
.57861 .12361 L
.57995 .12361 L
.58063 .12361 L
s
.58063 .12361 m
.58093 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40134 .12361 L
.41134 .12361 L
.41408 .12361 L
.4156 .12361 L
.41703 .12361 L
.41768 .12361 L
.41837 .12361 L
.41912 .12353 L
.41982 .12281 L
.42237 .12023 L
.44234 .10271 L
.46395 .08842 L
.48482 .07834 L
.50401 .07162 L
.52444 .06497 L
.5435 .05873 L
.56183 .05296 L
.5671 .05137 L
.5721 .0499 L
.57659 .04861 L
.57782 .04826 L
.57913 .0479 L
.58024 .04759 L
.58147 .12361 L
.58269 .12361 L
.58382 .12361 L
.58639 .12361 L
.59157 .12361 L
.60082 .12361 L
.62168 .12361 L
.66072 .12361 L
.70222 .12361 L
.7422 .12361 L
.78067 .12361 L
.82159 .12361 L
.86099 .12361 L
.89888 .12361 L
.93922 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool04?ooo`80I_mloooo002?oooo0P0000goool406Ko00?oool0I_ooool0Nooo
o`00Soooo`030000oooooooo00[oool206Ko1Oooo`0306Kooooooooo07[oool008ooool00`000?oo
ooooo`07oooo0`1Vo`Ooool00`1Vooooooooo`1joooo002?oooo00<0003oooooool01Oooo`80I_l:
oooo00<0I_ooooooool0N_ooo`00Soooo`040000oooooooooooo101Vo`coool00`1Vooooooooo`1j
oooo002?oooo00@00000I_l0I_l0I_l@oooo00<0I_ooooooool0N_ooo`00SOooo`80I_l200004_oo
o`0306Kooooooooo07[oool001Ooool40000>Oooo`D0000aoooo0`1Vo`;oool00`000?ooooooo`0A
oooo00<0I_ooooooool08oooo`D0000hoooo100001Koool001Ooool00`000?ooooooo`0loooo00<0
003oooooool0;oooo`80I_l5oooo00<0003oooooool04Oooo`0306Kooooooooo02Goool00`000?oo
ooooo`0hoooo00<0003oooooool05oooo`006?ooo`030000oooooooo03_oool00`000?ooooooo`0]
oooo0P1Vo`Ooool00`000?ooooooo`0Boooo00<0I_ooooooool09?ooo`030000oooooooo03Woool0
0`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0boooo100000Coool00`000?oo
ooooo`0[oooo0P1Vo`Woool00`000?ooooooo`0Boooo00<0I_ooooooool09?ooo`030000oooooooo
03[oool00`000?ooooooo`0Eoooo000Goooo00@0003oooooool0000koooo00<0003oooooool0:_oo
o`0306Kooooooooo00Woool00`000?ooooooo`0Boooo00<0I_ooooooool09?ooo`030000oooooooo
03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000Zoooo0P1Vo`coool200004ooo
o`0306Kooooooooo02?oool20000>oooo`80000Goooo0020oooo00<0I_ooooooool03?ooo`030000
oooooooo01;oool00`1Vooooooooo`1ioooo001ooooo00<0I_ooooooool03Oooo`030000oooooooo
01;oool00`1Vooooooooo`1ioooo001noooo00<0I_ooooooool03_ooo`030000oooooooo01;oool0
0`1Vooooooooo`1ioooo001moooo00<0I_ooooooool03oooo`030000oooooooo01;oool00`1Voooo
ooooo`1ioooo001loooo00<0I_ooooooool04?ooo`030000oooooooo01;oool00`1Vooooooooo`1i
oooo000@ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0000co`0co`002C?o00030000<ol0<ol000Dco`001Ol0VC?o03?o03?o0000000;<ol000<0
000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006<ol08P0000Koool00`000?oo
ooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0i
oooo00<0000co`0co`004C?o0003o`2I<ol0<ol002Dco`090000=?ooo`030000oooooooo01Goool0
08ooool00`0003?o03?o000A<ol000?o09Tco`0co`007c?o00H0001Eoooo002?oooo00<0000co`0c
o`004C?o0003o`2I<ol0<ol001dco`020000Foooo`00Soooo`030000<ol0<ol0014co`000ol0VC?o
03?o000K<ol00P0005goool008ooool00`0003?o03?o000A<ol000?o09Tco`0co`0063?o00<0001O
oooo002?oooo0P00018co`000ol0VC?o03?o000E<ol00`0006;oool008ooool00`0003?o03?o000A
<ol000?o09Tco`0co`004c?o0080001Uoooo002?oooo00<0000co`0co`004C?o0003o`2I<ol0<ol0
018co`000`000?ooooooo`1Uoooo002?oooo00<0000co`0co`004C?o0003o`2I<ol0<ol0014co`00
0`000?ooooooo`1Voooo002?oooo00<0000co`0co`004C?o0003o`2I<ol0<ol0010co`000`000?oo
ooooo`1Woooo002?oooo00<0000co`0co`004C?o0003o`2I<ol0<ol000hco`020000J_ooo`00Sooo
o`80000B<ol000?o09Tco`0co`003C?o00030000oooooooo06[oool008ooool00`0003?o03?o000A
<ol000?o09Tco`0co`0033?o00030000oooooooo06_oool008ooool00`0003?o03?o000A<ol000?o
09Tco`0co`002c?o00030000oooooooo06coool008ooool00`0003?o03?o000A<ol000?o09Tco`0c
o`002c?o00030000oooooooo06coool008ooool00`0003?o03?o000A<ol000?o09Tco`0co`002S?o
00030000oooooooo06goool008ooool00`0003?o03?o000A<ol000?o09Tco`0co`002C?o00030000
oooooooo06koool008ooool200004S?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`1_oooo002?
oooo00<0000co`0co`004C?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1`oooo002?oooo00<0
000co`0co`004C?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1`oooo002?oooo00<0000co`0c
o`004C?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`004C?o
0003o`2I<ol0<ol000Hco`000`000?ooooooo`1aoooo002?oooo00<0000co`0co`004C?o0003o`2I
<ol0<ol000Dco`000`000?ooooooo`1boooo002?oooo0P00018co`000ol0VC?o03?o0005<ol000<0
003oooooool0L_ooo`00Soooo`030000<ol0<ol0014co`000ol0VC?o03?o0004<ol000<0003ooooo
ool0Loooo`00Soooo`030000<ol0<ol0014co`000ol0VC?o03?o0004<ol000<0003oooooool0Looo
o`00Soooo`030000<ol0<ol0014co`000ol0VC?o03?o0003<ol000<0003oooooool0M?ooo`00Sooo
o`030000<ol0<ol0014co`000ol0VC?o03?o0003<ol000<0003oooooool0M?ooo`00Qoooo`D00003
oooo00<0000co`0co`004C?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1eoooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol0014co`000ol0VC?o03?o0002<ol000<0003oooooool0MOoo
o`00ROooo`030000oooooooo00?oool300004C?o0005o`2I<ol0<ol0<ol0000007Soool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`004C?o0005o`2I<ol0<ol0<ol0000007Soool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`004C?o0005o`2I<ol0<ol0<ol0000007Soool008Soool2
00001Oooo`030000<ol0<ol0014co`001?l0VC?o03?o000007Woool008ooool00`0003?o03?o000A
<ol000Co09Tco`0co`00001ioooo002?oooo00<0000co`0co`004C?o0003o`2I<ol0000007[oool0
08ooool200004S?o0003o`2I<ol0000007[oool008ooool00`0003?o03?o000A<ol000?o09Tco`00
0000N_ooo`00Soooo`030000<ol0<ol0014co`000ol0V@000?ooo`1joooo002?oooo00<0000co`0c
o`004C?o0003o`2I0000oooo07[oool008ooool00`0003?o03?o000A<ol000?o09T0003oool0N_oo
o`00Soooo`030000<ol0<ol0014co`000ol0VOooooooo`1joooo002?oooo0P00018co`000ol0VOoo
ooooo`1joooo002?oooo00<0000co`0co`004C?o0003o`2Ioooooooo07[oool008ooool00`0003?o
03?o000A<ol000?o09Woooooool0N_ooo`00Soooo`030000<ol0<ol0010co`000`000?l0VOooo`1k
oooo002?oooo00<0000co`0co`0043?o00030000o`2Ioooo07_oool008ooool00`0003?o03?o000@
<ol000<0003o09Woool0Noooo`00Soooo`030000<ol0<ol0010co`000`000?l0VOooo`1koooo002?
oooo0P00010co`000`000?ooool0V@1loooo002?oooo00<0000co`0co`003c?o00030000ooooo`2I
07coool008ooool00`0003?o03?o000?<ol000<0003ooooo09T0O?ooo`00Soooo`030000<ol0<ol0
00lco`000`000?ooool0V@1loooo002?oooo00<0000co`0co`003c?o00030000ooooo`2I07coool0
08ooool00`0003?o03?o000><ol000@0003ooooooooo09Uloooo002?oooo0P0000lco`0010000?oo
ooooool0VGcoool008ooool00`0003?o03?o000><ol000@0003ooooooooo09Uloooo002?oooo00<0
000co`0co`003S?o00040000ooooooooo`2IO?ooo`00Soooo`030000<ol0<ol000dco`001@000?oo
ooooooooool0V@1loooo0027oooo100000Coool00`0003?o03?o000=<ol000D0003ooooooooooooo
09T0O?ooo`00Qoooo`030000oooooooo00Goool00`0003?o03?o000=<ol000D0003ooooooooooooo
09T0O?ooo`00R?ooo`030000oooooooo00Coool300003C?o00050000ooooooooooooo`2I07coool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o00050000ooooooooooooo`2I07coool0
08Ooool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool00_ooo`03o`2I
oooooooo07[oool008Soool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`02oooo00?o
09Woooooool0N_ooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`02oooo00?o09Wooooo
ool0N_ooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`02oooo00?o09Woooooool0N_oo
o`00Soooo`80000=<ol000<0003oooooool00_ooo`03o`2Ioooooooo07[oool008ooool00`0003?o
03?o000<<ol000<0003oooooool00_ooo`03o`2Ioooooooo07[oool008ooool00`0003?o03?o000;
<ol000<0003oooooool00oooo`03o`2Ioooooooo07[oool008ooool00`0003?o03?o000;<ol000<0
003oooooool00oooo`03o`2Ioooooooo07[oool008ooool00`0003?o03?o000;<ol000<0003ooooo
ool00oooo`03o`2Ioooooooo07[oool008ooool00`0003?o03?o000;<ol000<0003oooooool00ooo
o`03o`2Ioooooooo07[oool008ooool00`0003?o03?o000;<ol000<0003oooooool00oooo`03o`2I
oooooooo07[oool008ooool2000033?o00030000oooooooo00?oool00ol0VOooooooo`1joooo002?
oooo00<0000co`0co`002c?o00030000oooooooo00?oool00ol0VOooooooo`1joooo002?oooo00<0
000co`0co`002S?o00030000oooooooo00Coool00ol0VOooooooo`1joooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo00Coool00ol0VOooooooo`1joooo002?oooo00<0000co`0co`002S?o
00030000oooooooo00Coool00ol0VOooooooo`1joooo002?oooo00<0000co`0co`002S?o00030000
oooooooo00Coool00ol0VOooooooo`1joooo002?oooo0P0000/co`000`000?ooooooo`04oooo00?o
09Woooooool0N_ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`04oooo00?o09Wooooo
ool0N_ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`04oooo00?o09Woooooool0N_oo
o`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`05oooo00?o09Woooooool0N_ooo`00Sooo
o`030000<ol0<ol000Tco`000`000?ooooooo`05oooo00?o09Woooooool0N_ooo`00Soooo`030000
<ol0<ol000Tco`000`000?ooooooo`05oooo00?o09Woooooool0N_ooo`00Soooo`80000:<ol000<0
003oooooool01Oooo`03o`2Ioooooooo07[oool008ooool00`0003?o03?o0009<ol000<0003ooooo
ool01Oooo`03o`2Ioooooooo07[oool008ooool00`0003?o03?o0009<ol000<0003oooooool01Ooo
o`03o`2Ioooooooo07[oool008ooool00`0003?o03?o0008<ol000<0003oooooool01_ooo`03o`2I
oooooooo07[oool008Soool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`06oooo00?o
09Woooooool0N_ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?oo
ooooo`06oooo00?o09Woooooool0N_ooo`00ROooo`030000oooooooo00?oool3000023?o00030000
oooooooo00Koool00ol0VOooooooo`1joooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`06oooo00?o09Woooooool0N_ooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`06oooo00?o09Woooooool0N_ooo`00R?ooo`800005
oooo00<0000co`0co`001c?o00030000oooooooo00Ooool00ol0VOooooooo`1joooo002?oooo00<0
000co`0co`001c?o00030000oooooooo00Ooool00ol0VOooooooo`1joooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo00Ooool00ol0VOooooooo`1joooo002?oooo00<0000co`0co`001c?o
00030000oooooooo00Ooool00ol0VOooooooo`1joooo002?oooo0P0000Pco`000`000?ooooooo`07
oooo00?o09Woooooool0N_ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`07oooo00?o
09Woooooool0N_ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`07oooo00?o09Wooooo
ool0N_ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`07oooo00?o09Woooooool0N_oo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`08oooo00?o09Woooooool0N_ooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`08oooo00?o09Woooooool0N_ooo`00Soooo`800007
<ol000<0003oooooool02?ooo`03o`2Ioooooooo07[oool008ooool00`0003?o03?o0006<ol000<0
003oooooool02?ooo`03o`2Ioooooooo07[oool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool02?ooo`03o`2Ioooooooo07[oool008ooool00`0003?o03?o0006<ol000<0003oooooool02?oo
o`03o`2Ioooooooo07[oool008ooool00`0003?o03?o0006<ol000<0003oooooool02?ooo`03o`2I
oooooooo07[oool008ooool00`0003?o03?o0006<ol000<0003oooooool02?ooo`03o`2Ioooooooo
07[oool008ooool200001S?o00030000oooooooo00Woool00ol0VOooooooo`1joooo002?oooo00<0
000co`0co`001C?o00030000oooooooo00Woool00ol0VOooooooo`1joooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo00Woool00ol0VOooooooo`1joooo002?oooo00<0000co`0co`001C?o
00030000oooooooo00Woool00ol0VOooooooo`1joooo002?oooo00<0000co`0co`001C?o00030000
oooooooo00Woool00ol0VOooooooo`1joooo002?oooo00<0000co`0co`001C?o00030000oooooooo
00Woool00ol0VOooooooo`1joooo002?oooo0P0000Hco`000`000?ooooooo`09oooo00?o09Wooooo
ool0N_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`09oooo00?o09Woooooool0N_oo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`09oooo00?o09Woooooool0N_ooo`00Sooo
o`030000<ol0<ol000@co`000`000?ooooooo`0:oooo00?o09Woooooool0N_ooo`00Soooo`030000
<ol0<ol000@co`000`000?ooooooo`0:oooo00?o09Woooooool0N_ooo`00ROooo`<00003oooo00<0
000co`0co`0013?o00030000oooooooo00[oool00ol0VOooooooo`1joooo002:oooo00<0003ooooo
ool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`0:oooo00?o09Woooooool0N_ooo`00Qooo
o`D00003oooo0`0000@co`000`000?ooooooo`0:oooo00?o09Woooooool0N_ooo`00Qoooo`040000
oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029oooo0P00
00Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?ooooooo`0C
oooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo
00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`06oooo1@00008co`02000000@co`3oooooooooool200001Oooo`<00002oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01oooo`030000<ol0<ol000Dco`02oooo00@0003oooooool00005oooo00D0003ooooo
ooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0000co`0c
o`001C?o00Coool010000?ooooooooooo`D00003oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000>oooo00<0000co`0co`001C?o00Goool010000?ooooooo`0000;oool01@000?oo
ooooooooo`00001joooo001hoooo00D0003oooooooooool000004Oooo`030000<ol0<ol000Dco`02
oooo00@0003oooooool00003oooo00<0003oool000000oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Aoooo0P0000Lco`03oooo0P0000Goool200000_ooo`030000oooooooo07Woool0
08ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.55838 .12361 L
.56817 .12361 L
.57861 .12361 L
.58157 .12361 L
.58302 .12361 L
.58436 .12361 L
.58558 .12361 L
s
.58558 .12361 m
.58609 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.40134 .12361 L
.40616 .12361 L
.40882 .12361 L
.41134 .12361 L
.41276 .12361 L
.41357 .12361 L
.41432 .12358 L
.41563 .12222 L
.41703 .1208 L
.42237 .11563 L
.44234 .09918 L
.46395 .08583 L
.48482 .07648 L
.50401 .0703 L
.5435 .05811 L
.56336 .05206 L
.57204 .04954 L
.57661 .04825 L
.58147 .04692 L
.58395 .04625 L
.58462 .04607 L
.58536 .04588 L
.58668 .12361 L
.5879 .12361 L
.58919 .12361 L
.59149 .12361 L
.60098 .12361 L
.6219 .12361 L
.66001 .12361 L
.70057 .12361 L
.73961 .12361 L
.78111 .12361 L
.82109 .12361 L
.85956 .12361 L
.90048 .12361 L
.93988 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool04?ooo`@0I_mjoooo002?oooo0P0000goool406Ko0oooo`0306Kooooooooo
07Soool008ooool00`000?ooooooo`0:oooo0P1Vo`Ooool00`1Vooooooooo`1hoooo002?oooo00<0
003oooooool01oooo`<0I_l9oooo00<0I_ooooooool0N?ooo`00Soooo`030000oooooooo00Coool3
06Ko3?ooo`0306Kooooooooo07Soool008ooool00`000?ooooooo`0406Ko3oooo`0306Kooooooooo
07Soool008koool0101Vo`00001Vo`1Voa?oool00`1Vooooooooo`1hoooo002;oooo0`1Vo`03oooo
0000000001Coool00`1Vooooooooo`1hoooo000Goooo100003Woool50000<?ooo`80I_l4oooo00<0
003oooooool04oooo`0306Kooooooooo027oool50000>?ooo`@0000Foooo000Goooo00<0003ooooo
ool0??ooo`030000oooooooo02koool206Ko1_ooo`030000oooooooo01?oool00`1Vooooooooo`0S
oooo00<0003oooooool0>?ooo`030000oooooooo01Ooool001Soool00`000?ooooooo`0koooo00<0
003oooooool0;Oooo`0306Kooooooooo00Koool00`000?ooooooo`0Coooo00<0I_ooooooool08ooo
o`030000oooooooo03Woool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0b
oooo100000Coool00`000?ooooooo`0[oooo0P1Vo`Woool00`000?ooooooo`0Coooo00<0I_oooooo
ool08oooo`030000oooooooo03[oool00`000?ooooooo`0Eoooo000Goooo00@0003oooooool0000k
oooo00<0003oooooool0:Oooo`80I_l;oooo00<0003oooooool04oooo`0306Kooooooooo02?oool0
0`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo0P0003_oool20000:Oooo`80I_l=
oooo0P0001Coool00`1Vooooooooo`0Roooo0P0003_oool200005oooo`00Ooooo`0306Kooooooooo
00goool00`000?ooooooo`0Coooo00<0I_ooooooool0N?ooo`00OOooo`80I_l@oooo00<0003ooooo
ool04oooo`0306Kooooooooo07Soool007coool00`1Vooooooooo`0@oooo00<0003oooooool04ooo
o`0306Kooooooooo07Soool007_oool00`1Vooooooooo`0Aoooo00<0003oooooool04oooo`0306Ko
oooooooo07Soool007[oool00`1Vooooooooo`0Boooo00<0003oooooool04oooo`0306Kooooooooo
07Soool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`0003?o03?o0009<ol000<0000co`0co`001c?o0003o`2I<ol0000000/co`000`0003?o
03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000oooooooo
00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool0
0`0003?o03?o000C<ol000?o09Tco`0co`008c?o00T0000doooo00<0003oooooool05Oooo`00Sooo
o`030000<ol0<ol001<co`000ol0VC?o03?o000M<ol01P0005Goool008ooool00`0003?o03?o000C
<ol000?o09Tco`0co`006c?o0080001Koooo002?oooo00<0000co`0co`004c?o0003o`2I<ol0<ol0
01Tco`020000GOooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o03?o000F<ol00`0005ooool0
08ooool2000053?o0003o`2I<ol0<ol001<co`030000H_ooo`00Soooo`030000<ol0<ol001<co`00
0ol0VC?o03?o000A<ol00P0006Goool008ooool00`0003?o03?o000C<ol000?o09Tco`0co`0043?o
00030000oooooooo06Goool008ooool00`0003?o03?o000C<ol000?o09Tco`0co`003c?o00030000
oooooooo06Koool008ooool00`0003?o03?o000C<ol000?o09Tco`0co`003S?o00030000oooooooo
06Ooool008ooool00`0003?o03?o000C<ol000?o09Tco`0co`0033?o0080001Zoooo002?oooo0P00
01@co`000ol0VC?o03?o000;<ol000<0003oooooool0J_ooo`00Soooo`030000<ol0<ol001<co`00
0ol0VC?o03?o000:<ol000<0003oooooool0Joooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o
03?o0009<ol000<0003oooooool0K?ooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o03?o0009
<ol000<0003oooooool0K?ooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o03?o0008<ol000<0
003oooooool0KOooo`00Soooo`030000<ol0<ol001<co`000ol0VC?o03?o0007<ol000<0003ooooo
ool0K_ooo`00Soooo`80000D<ol000?o09Tco`0co`001S?o00030000oooooooo06ooool008ooool0
0`0003?o03?o000C<ol000?o09Tco`0co`001C?o00030000oooooooo073oool008ooool00`0003?o
03?o000C<ol000?o09Tco`0co`001C?o00030000oooooooo073oool008ooool00`0003?o03?o000C
<ol000?o09Tco`0co`0013?o00030000oooooooo077oool008ooool00`0003?o03?o000C<ol000?o
09Tco`0co`0013?o00030000oooooooo077oool008ooool00`0003?o03?o000C<ol000?o09Tco`0c
o`000c?o00030000oooooooo07;oool008ooool2000053?o0003o`2I<ol0<ol000<co`000`000?oo
ooooo`1boooo002?oooo00<0000co`0co`004c?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1c
oooo002?oooo00<0000co`0co`004c?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1coooo002?
oooo00<0000co`0co`004c?o0005o`2I<ol0<ol0<ol0000007Koool008ooool00`0003?o03?o000C
<ol000Go09Tco`0co`0co`000000M_ooo`00Qoooo`D00003oooo00<0000co`0co`004c?o0004o`2I
<ol0<ol00000Moooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000C<ol000Co09Tco`0c
o`00001goooo0029oooo00<0003oooooool00oooo`<0000C<ol000?o09Tco`000000N?ooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000C<ol000?o09Tco`000000N?ooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000C<ol000?o09Tco`000000N?ooo`00R?ooo`800005oooo00<0
000co`0co`004c?o0003o`2I0000oooo07Soool008ooool00`0003?o03?o000C<ol000?o09T0003o
ool0N?ooo`00Soooo`030000<ol0<ol001<co`000ol0VOooooooo`1hoooo002?oooo0P0001@co`00
0ol0VOooooooo`1hoooo002?oooo00<0000co`0co`004c?o0003o`2Ioooooooo07Soool008ooool0
0`0003?o03?o000B<ol000<0003o09Woool0NOooo`00Soooo`030000<ol0<ol0018co`000`000?l0
VOooo`1ioooo002?oooo00<0000co`0co`004S?o00030000o`2Ioooo07Woool008ooool00`0003?o
03?o000A<ol000<0003ooooo09T0N_ooo`00Soooo`80000B<ol000<0003ooooo09T0N_ooo`00Sooo
o`030000<ol0<ol0014co`000`000?ooool0V@1joooo002?oooo00<0000co`0co`004C?o00030000
ooooo`2I07[oool008ooool00`0003?o03?o000@<ol000@0003ooooooooo09Ujoooo002?oooo00<0
000co`0co`0043?o00040000ooooooooo`2IN_ooo`00Soooo`030000<ol0<ol0010co`0010000?oo
ooooool0VG[oool008ooool00`0003?o03?o000@<ol000@0003ooooooooo09Ujoooo002?oooo0P00
010co`001@000?ooooooooooool0V@1joooo002?oooo00<0000co`0co`003c?o00050000oooooooo
ooooo`2I07[oool008ooool00`0003?o03?o000?<ol000D0003ooooooooooooo09T0N_ooo`00Sooo
o`030000<ol0<ol000lco`001@000?ooooooooooool0V@1joooo002?oooo00<0000co`0co`003c?o
00050000ooooooooooooo`2I07[oool008ooool00`0003?o03?o000><ol000<0003oooooool00_oo
o`03o`2Ioooooooo07Soool008ooool200003c?o00030000oooooooo00;oool00ol0VOooooooo`1h
oooo002?oooo00<0000co`0co`003S?o00030000oooooooo00;oool00ol0VOooooooo`1hoooo002?
oooo00<0000co`0co`003S?o00030000oooooooo00;oool00ol0VOooooooo`1hoooo002?oooo00<0
000co`0co`003C?o00030000oooooooo00?oool00ol0VOooooooo`1hoooo0027oooo100000Coool0
0`0003?o03?o000=<ol000<0003oooooool00oooo`03o`2Ioooooooo07Soool008Ooool00`000?oo
ooooo`05oooo00<0000co`0co`003C?o00030000oooooooo00?oool00ol0VOooooooo`1hoooo0028
oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool00oooo`03o`2Ioooooooo07Soool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo00?oool00ol0VOoo
ooooo`1hoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0033?o00030000oooooooo
00Coool00ol0VOooooooo`1hoooo0028oooo0P0000Goool00`0003?o03?o000<<ol000<0003ooooo
ool01?ooo`03o`2Ioooooooo07Soool008ooool00`0003?o03?o000<<ol000<0003oooooool01?oo
o`03o`2Ioooooooo07Soool008ooool00`0003?o03?o000<<ol000<0003oooooool01?ooo`03o`2I
oooooooo07Soool008ooool200003C?o00030000oooooooo00Coool00ol0VOooooooo`1hoooo002?
oooo00<0000co`0co`0033?o00030000oooooooo00Coool00ol0VOooooooo`1hoooo002?oooo00<0
000co`0co`002c?o00030000oooooooo00Goool00ol0VOooooooo`1hoooo002?oooo00<0000co`0c
o`002c?o00030000oooooooo00Goool00ol0VOooooooo`1hoooo002?oooo00<0000co`0co`002c?o
00030000oooooooo00Goool00ol0VOooooooo`1hoooo002?oooo00<0000co`0co`002c?o00030000
oooooooo00Goool00ol0VOooooooo`1hoooo002?oooo00<0000co`0co`002c?o00030000oooooooo
00Goool00ol0VOooooooo`1hoooo002?oooo0P0000`co`000`000?ooooooo`05oooo00?o09Wooooo
ool0N?ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`05oooo00?o09Woooooool0N?oo
o`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`06oooo00?o09Woooooool0N?ooo`00Sooo
o`030000<ol0<ol000Xco`000`000?ooooooo`06oooo00?o09Woooooool0N?ooo`00Soooo`030000
<ol0<ol000Xco`000`000?ooooooo`06oooo00?o09Woooooool0N?ooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`06oooo00?o09Woooooool0N?ooo`00Soooo`80000;<ol000<0003ooooo
ool01_ooo`03o`2Ioooooooo07Soool008ooool00`0003?o03?o000:<ol000<0003oooooool01_oo
o`03o`2Ioooooooo07Soool008ooool00`0003?o03?o000:<ol000<0003oooooool01_ooo`03o`2I
oooooooo07Soool008ooool00`0003?o03?o0009<ol000<0003oooooool01oooo`03o`2Ioooooooo
07Soool008ooool00`0003?o03?o0009<ol000<0003oooooool01oooo`03o`2Ioooooooo07Soool0
08ooool00`0003?o03?o0009<ol000<0003oooooool01oooo`03o`2Ioooooooo07Soool008ooool2
00002S?o00030000oooooooo00Ooool00ol0VOooooooo`1hoooo002?oooo00<0000co`0co`002C?o
00030000oooooooo00Ooool00ol0VOooooooo`1hoooo002?oooo00<0000co`0co`002C?o00030000
oooooooo00Ooool00ol0VOooooooo`1hoooo002?oooo00<0000co`0co`0023?o00030000oooooooo
00Soool00ol0VOooooooo`1hoooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0003ooooo
ool02?ooo`03o`2Ioooooooo07Soool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008
<ol000<0003oooooool02?ooo`03o`2Ioooooooo07Soool008Woool00`000?ooooooo`03oooo0`00
00Pco`000`000?ooooooo`08oooo00?o09Woooooool0N?ooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o0008<ol000<0003oooooool02?ooo`03o`2Ioooooooo07Soool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool02?ooo`03o`2Ioooooooo07Soool0
08Soool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`09oooo00?o09Woooooool0N?oo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`09oooo00?o09Woooooool0N?ooo`00Sooo
o`030000<ol0<ol000Lco`000`000?ooooooo`09oooo00?o09Woooooool0N?ooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`09oooo00?o09Woooooool0N?ooo`00Soooo`800008<ol000<0
003oooooool02Oooo`03o`2Ioooooooo07Soool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool02Oooo`03o`2Ioooooooo07Soool008ooool00`0003?o03?o0007<ol000<0003oooooool02Ooo
o`03o`2Ioooooooo07Soool008ooool00`0003?o03?o0007<ol000<0003oooooool02Oooo`03o`2I
oooooooo07Soool008ooool00`0003?o03?o0006<ol000<0003oooooool02_ooo`03o`2Ioooooooo
07Soool008ooool00`0003?o03?o0006<ol000<0003oooooool02_ooo`03o`2Ioooooooo07Soool0
08ooool200001c?o00030000oooooooo00[oool00ol0VOooooooo`1hoooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo00[oool00ol0VOooooooo`1hoooo002?oooo00<0000co`0co`001S?o
00030000oooooooo00[oool00ol0VOooooooo`1hoooo002?oooo00<0000co`0co`001S?o00030000
oooooooo00[oool00ol0VOooooooo`1hoooo002?oooo00<0000co`0co`001S?o00030000oooooooo
00[oool00ol0VOooooooo`1hoooo002?oooo00<0000co`0co`001S?o00030000oooooooo00[oool0
0ol0VOooooooo`1hoooo002?oooo0P0000Hco`000`000?ooooooo`0;oooo00?o09Woooooool0N?oo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0;oooo00?o09Woooooool0N?ooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`0;oooo00?o09Woooooool0N?ooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`0;oooo00?o09Woooooool0N?ooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`0;oooo00?o09Woooooool0N?ooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`0;oooo00?o09Woooooool0N?ooo`00Soooo`800006<ol000<0003oooooool02ooo
o`03o`2Ioooooooo07Soool008ooool00`0003?o03?o0005<ol000<0003oooooool02oooo`03o`2I
oooooooo07Soool008ooool00`0003?o03?o0005<ol000<0003oooooool02oooo`03o`2Ioooooooo
07Soool008ooool00`0003?o03?o0004<ol000<0003oooooool03?ooo`03o`2Ioooooooo07Soool0
08ooool00`0003?o03?o0004<ol000<0003oooooool03?ooo`03o`2Ioooooooo07Soool008Woool3
00000oooo`030000<ol0<ol000@co`000`000?ooooooo`0<oooo00?o09Woooooool0N?ooo`00R_oo
o`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool03?ooo`03o`2Ioooooooo
07Soool008Ooool500000oooo`<00004<ol000<0003oooooool03?ooo`03o`2Ioooooooo07Soool0
08Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_oo
o`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0
003oooooool04oooo`Lco`0>oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool0
0`000?ooooooo`09oooo1c?o00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01_ooo`D00002<ol00P000004<ol0oooooooooooo0P0000?oool3
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Ooool00`0003?o03?o0005<ol00_ooo`040000oooooooo00000_oo
o`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0
003oooooool03oooo`030000<ol0<ol000Dco`04oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000koool00`0003?o
03?o0005<ol01Oooo`030000oooooooo00<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo0000017oool00`0003?o03?o0005<ol00_ooo`040000oooooooo00000oooo`030000
oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007<ol00ooo
o`800004oooo0`0000;oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.55838 .12361 L
.57861 .12361 L
.58392 .12361 L
.58683 .12361 L
.58826 .12361 L
.58957 .12361 L
s
.58957 .12361 m
.59007 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.39174 .12361 L
.40134 .12361 L
.40616 .12361 L
.40755 .12361 L
.40887 .12361 L
.41005 .12306 L
.41134 .12174 L
.42237 .11131 L
.44368 .09498 L
.46301 .08387 L
.48316 .07534 L
.50214 .0696 L
.54069 .05842 L
.56024 .05262 L
.57059 .04965 L
.57629 .04807 L
.58169 .04661 L
.58681 .04526 L
.58821 .0449 L
.58898 .04471 L
.5897 .04452 L
.59097 .12361 L
.59165 .12361 L
.59238 .12361 L
.60212 .12361 L
.62118 .12361 L
.66232 .12361 L
.70195 .12361 L
.74005 .12361 L
.78062 .12361 L
.81966 .12361 L
.86116 .12361 L
.90114 .12361 L
.93961 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0Coooo0P1V
ogWoool008ooool00`000?ooooooo`0@oooo1@1VogWoool008ooool200003?ooo`D0I_l4oooo00<0
I_ooooooool0Moooo`00Soooo`030000oooooooo00Woool206Ko2Oooo`0306Kooooooooo07Ooool0
08ooool00`000?ooooooo`06oooo0`1Vo`_oool00`1Vooooooooo`1goooo002?oooo00<0003ooooo
ool00oooo`<0I_l>oooo00<0I_ooooooool0Moooo`00Soooo`030000oooooooo00<0I_lAoooo00<0
I_ooooooool0Moooo`00S_ooo`0406Ko000006Ko06Ko5?ooo`0306Kooooooooo07Ooool008[oool4
06Ko00?oool0000000005Oooo`0306Kooooooooo07Ooool001Ooool40000>Oooo`D0000_oooo0P1V
o`Goool00`000?ooooooo`0Doooo00<0I_ooooooool08?ooo`D0000hoooo100001Koool001Ooool0
0`000?ooooooo`0loooo00<0003oooooool0;Oooo`80I_l7oooo00<0003oooooool05?ooo`0306Ko
oooooooo02;oool00`000?ooooooo`0hoooo00<0003oooooool05oooo`006?ooo`030000oooooooo
03_oool00`000?ooooooo`0[oooo0P1Vo`Woool00`000?ooooooo`0Doooo00<0I_ooooooool08_oo
o`030000oooooooo03Woool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0b
oooo100000Coool00`000?ooooooo`0Yoooo0P1Vo`_oool00`000?ooooooo`0Doooo00<0I_oooooo
ool08_ooo`030000oooooooo03[oool00`000?ooooooo`0Eoooo000Goooo00@0003oooooool0000k
oooo00<0003oooooool0:?ooo`0306Kooooooooo00_oool00`000?ooooooo`0Doooo00<0I_oooooo
ool08_ooo`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000X
oooo0P1Vo`koool200005Oooo`0306Kooooooooo027oool20000>oooo`80000Goooo001noooo00<0
I_ooooooool03_ooo`030000oooooooo01Coool00`1Vooooooooo`1goooo001loooo0P1Voa7oool0
0`000?ooooooo`0Doooo00<0I_ooooooool0Moooo`00Noooo`0306Kooooooooo017oool00`000?oo
ooooo`0Doooo00<0I_ooooooool0Moooo`00N_ooo`0306Kooooooooo01;oool00`000?ooooooo`0D
oooo00<0I_ooooooool0Moooo`00NOooo`0306Kooooooooo01?oool00`000?ooooooo`0Doooo00<0
I_ooooooool0Moooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0008<ol000?o09T0000co`002S?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0
003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003ooooo
ool0>Oooo`030000<ol0<ol001@co`000ol0VC?o03?o000R<ol02@0003Coool00`000?ooooooo`0E
oooo002?oooo00<0000co`0co`0053?o0003o`2I<ol0<ol001`co`060000EOooo`00Soooo`030000
<ol0<ol001@co`000ol0VC?o03?o000J<ol00P0005_oool008ooool00`0003?o03?o000D<ol000?o
09Tco`0co`0063?o0080001Moooo002?oooo00<0000co`0co`0053?o0003o`2I<ol0<ol001Dco`03
0000Goooo`00Soooo`80000E<ol000?o09Tco`0co`004S?o00<0001Roooo002?oooo00<0000co`0c
o`0053?o0003o`2I<ol0<ol0010co`020000IOooo`00Soooo`030000<ol0<ol001@co`000ol0VC?o
03?o000?<ol000<0003oooooool0IOooo`00Soooo`030000<ol0<ol001@co`000ol0VC?o03?o000>
<ol000<0003oooooool0I_ooo`00Soooo`030000<ol0<ol001@co`000ol0VC?o03?o000=<ol000<0
003oooooool0Ioooo`00Soooo`030000<ol0<ol001@co`000ol0VC?o03?o000;<ol00P0006[oool0
08ooool200005C?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1Zoooo002?oooo00<0000co`0c
o`0053?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1[oooo002?oooo00<0000co`0co`0053?o
0003o`2I<ol0<ol000Pco`000`000?ooooooo`1/oooo002?oooo00<0000co`0co`0053?o0003o`2I
<ol0<ol000Pco`000`000?ooooooo`1/oooo002?oooo00<0000co`0co`0053?o0003o`2I<ol0<ol0
00Lco`000`000?ooooooo`1]oooo002?oooo00<0000co`0co`0053?o0003o`2I<ol0<ol000Hco`00
0`000?ooooooo`1^oooo002?oooo0P0001Dco`000ol0VC?o03?o0005<ol000<0003oooooool0Kooo
o`00Soooo`030000<ol0<ol001@co`000ol0VC?o03?o0004<ol000<0003oooooool0L?ooo`00Sooo
o`030000<ol0<ol001@co`000ol0VC?o03?o0004<ol000<0003oooooool0L?ooo`00Soooo`030000
<ol0<ol001@co`000ol0VC?o03?o0003<ol000<0003oooooool0LOooo`00Soooo`030000<ol0<ol0
01@co`000ol0VC?o03?o0003<ol000<0003oooooool0LOooo`00Soooo`030000<ol0<ol001@co`00
0ol0VC?o03?o0002<ol000<0003oooooool0L_ooo`00Soooo`80000E<ol000?o09Tco`0co`000S?o
00030000oooooooo07;oool008ooool00`0003?o03?o000D<ol000Go09Tco`0co`0co`000000MOoo
o`00Soooo`030000<ol0<ol001@co`001Ol0VC?o03?o03?o0000001eoooo002?oooo00<0000co`0c
o`0053?o0004o`2I<ol0<ol00000M_ooo`00Soooo`030000<ol0<ol001@co`001?l0VC?o03?o0000
07Koool008Ooool500000oooo`030000<ol0<ol001@co`000ol0VC?o0000001goooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol001@co`000ol0VC?o0000001goooo0029oooo00<0003ooooo
ool00oooo`<0000D<ol000?o09T0003oool0Moooo`00ROooo`030000oooooooo00?oool00`0003?o
03?o000D<ol000?o09T0003oool0Moooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000D
<ol000?o09T0003oool0Moooo`00R?ooo`800005oooo00<0000co`0co`0053?o0003o`2Ioooooooo
07Ooool008ooool00`0003?o03?o000D<ol000?o09Woooooool0Moooo`00Soooo`030000<ol0<ol0
01<co`000`000?l0VOooo`1hoooo002?oooo0P0001@co`000`000?l0VOooo`1hoooo002?oooo00<0
000co`0co`004c?o00030000o`2Ioooo07Soool008ooool00`0003?o03?o000B<ol000<0003ooooo
09T0NOooo`00Soooo`030000<ol0<ol0018co`000`000?ooool0V@1ioooo002?oooo00<0000co`0c
o`004S?o00030000ooooo`2I07Woool008ooool00`0003?o03?o000A<ol000@0003ooooooooo09Ui
oooo002?oooo0P00018co`0010000?ooooooool0VGWoool008ooool00`0003?o03?o000A<ol000@0
003ooooooooo09Uioooo002?oooo00<0000co`0co`004C?o00040000ooooooooo`2INOooo`00Sooo
o`030000<ol0<ol0010co`001@000?ooooooooooool0V@1ioooo002?oooo00<0000co`0co`0043?o
00050000ooooooooooooo`2I07Woool008ooool00`0003?o03?o000@<ol000D0003ooooooooooooo
09T0NOooo`00Soooo`030000<ol0<ol0010co`001@000?ooooooooooool0V@1ioooo002?oooo0P00
010co`000`000?ooooooo`02oooo00?o09Woooooool0Moooo`00Soooo`030000<ol0<ol000lco`00
0`000?ooooooo`02oooo00?o09Woooooool0Moooo`00Soooo`030000<ol0<ol000lco`000`000?oo
ooooo`02oooo00?o09Woooooool0Moooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`02
oooo00?o09Woooooool0Moooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`02oooo00?o
09Woooooool0Moooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`03oooo00?o09Wooooo
ool0Moooo`00Soooo`80000?<ol000<0003oooooool00oooo`03o`2Ioooooooo07Ooool008ooool0
0`0003?o03?o000><ol000<0003oooooool00oooo`03o`2Ioooooooo07Ooool008ooool00`0003?o
03?o000><ol000<0003oooooool00oooo`03o`2Ioooooooo07Ooool008ooool00`0003?o03?o000=
<ol000<0003oooooool01?ooo`03o`2Ioooooooo07Ooool008Ooool400001?ooo`030000<ol0<ol0
00dco`000`000?ooooooo`04oooo00?o09Woooooool0Moooo`00Qoooo`030000oooooooo00Goool0
0`0003?o03?o000=<ol000<0003oooooool01?ooo`03o`2Ioooooooo07Ooool008Soool00`000?oo
ooooo`04oooo0`0000dco`000`000?ooooooo`04oooo00?o09Woooooool0Moooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool01?ooo`03o`2Ioooooooo07Ooool0
08Ooool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool01Oooo`03o`2I
oooooooo07Ooool008Soool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`05oooo00?o
09Woooooool0Moooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`05oooo00?o09Wooooo
ool0Moooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`05oooo00?o09Woooooool0Mooo
o`00Soooo`80000=<ol000<0003oooooool01Oooo`03o`2Ioooooooo07Ooool008ooool00`0003?o
03?o000<<ol000<0003oooooool01Oooo`03o`2Ioooooooo07Ooool008ooool00`0003?o03?o000;
<ol000<0003oooooool01_ooo`03o`2Ioooooooo07Ooool008ooool00`0003?o03?o000;<ol000<0
003oooooool01_ooo`03o`2Ioooooooo07Ooool008ooool00`0003?o03?o000;<ol000<0003ooooo
ool01_ooo`03o`2Ioooooooo07Ooool008ooool00`0003?o03?o000;<ol000<0003oooooool01_oo
o`03o`2Ioooooooo07Ooool008ooool00`0003?o03?o000;<ol000<0003oooooool01_ooo`03o`2I
oooooooo07Ooool008ooool2000033?o00030000oooooooo00Koool00ol0VOooooooo`1goooo002?
oooo00<0000co`0co`002c?o00030000oooooooo00Koool00ol0VOooooooo`1goooo002?oooo00<0
000co`0co`002S?o00030000oooooooo00Ooool00ol0VOooooooo`1goooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo00Ooool00ol0VOooooooo`1goooo002?oooo00<0000co`0co`002S?o
00030000oooooooo00Ooool00ol0VOooooooo`1goooo002?oooo00<0000co`0co`002S?o00030000
oooooooo00Ooool00ol0VOooooooo`1goooo002?oooo0P0000/co`000`000?ooooooo`07oooo00?o
09Woooooool0Moooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`07oooo00?o09Wooooo
ool0Moooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`07oooo00?o09Woooooool0Mooo
o`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`08oooo00?o09Woooooool0Moooo`00Sooo
o`030000<ol0<ol000Tco`000`000?ooooooo`08oooo00?o09Woooooool0Moooo`00Soooo`030000
<ol0<ol000Tco`000`000?ooooooo`08oooo00?o09Woooooool0Moooo`00Soooo`80000:<ol000<0
003oooooool02?ooo`03o`2Ioooooooo07Ooool008ooool00`0003?o03?o0009<ol000<0003ooooo
ool02?ooo`03o`2Ioooooooo07Ooool008ooool00`0003?o03?o0009<ol000<0003oooooool02?oo
o`03o`2Ioooooooo07Ooool008ooool00`0003?o03?o0008<ol000<0003oooooool02Oooo`03o`2I
oooooooo07Ooool008Soool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`09oooo00?o
09Woooooool0Moooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?oo
ooooo`09oooo00?o09Woooooool0Moooo`00ROooo`030000oooooooo00?oool3000023?o00030000
oooooooo00Woool00ol0VOooooooo`1goooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`09oooo00?o09Woooooool0Moooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`09oooo00?o09Woooooool0Moooo`00R?ooo`800005
oooo00<0000co`0co`001c?o00030000oooooooo00[oool00ol0VOooooooo`1goooo002?oooo00<0
000co`0co`001c?o00030000oooooooo00[oool00ol0VOooooooo`1goooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo00[oool00ol0VOooooooo`1goooo002?oooo00<0000co`0co`001c?o
00030000oooooooo00[oool00ol0VOooooooo`1goooo002?oooo0P0000Pco`000`000?ooooooo`0:
oooo00?o09Woooooool0Moooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0:oooo00?o
09Woooooool0Moooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0:oooo00?o09Wooooo
ool0Moooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0:oooo00?o09Woooooool0Mooo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0;oooo00?o09Woooooool0Moooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`0;oooo00?o09Woooooool0Moooo`00Soooo`800007
<ol000<0003oooooool02oooo`03o`2Ioooooooo07Ooool008ooool00`0003?o03?o0006<ol000<0
003oooooool02oooo`03o`2Ioooooooo07Ooool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool02oooo`03o`2Ioooooooo07Ooool008ooool00`0003?o03?o0006<ol000<0003oooooool02ooo
o`03o`2Ioooooooo07Ooool008ooool00`0003?o03?o0006<ol000<0003oooooool02oooo`03o`2I
oooooooo07Ooool008ooool00`0003?o03?o0006<ol000<0003oooooool02oooo`03o`2Ioooooooo
07Ooool008ooool200001S?o00030000oooooooo00coool00ol0VOooooooo`1goooo002?oooo00<0
000co`0co`001C?o00030000oooooooo00coool00ol0VOooooooo`1goooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo00coool00ol0VOooooooo`1goooo002?oooo00<0000co`0co`001C?o
00030000oooooooo00coool00ol0VOooooooo`1goooo002?oooo00<0000co`0co`001C?o00030000
oooooooo00coool00ol0VOooooooo`1goooo002?oooo00<0000co`0co`001C?o00030000oooooooo
00coool00ol0VOooooooo`1goooo002?oooo0P0000Hco`000`000?ooooooo`0<oooo00?o09Wooooo
ool0Moooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0<oooo00?o09Woooooool0Mooo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0<oooo00?o09Woooooool0Moooo`00Sooo
o`030000<ol0<ol000@co`000`000?ooooooo`0=oooo00?o09Woooooool0Moooo`00Soooo`030000
<ol0<ol000@co`000`000?ooooooo`0=oooo00?o09Woooooool0Moooo`00ROooo`<00003oooo00<0
000co`0co`0013?o00030000oooooooo00goool00ol0VOooooooo`1goooo002:oooo00<0003ooooo
ool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`0=oooo00?o09Woooooool0Moooo`00Qooo
o`D00003oooo0`0000@co`000`000?ooooooo`0=oooo00?o09Woooooool0Moooo`00Qoooo`040000
oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029oooo0P00
00Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?ooooooo`0C
oooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo
00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`06oooo1@00008co`02000000@co`3oooooooooool200001?ooo`800004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01oooo`030000<ol0<ol000Dco`02oooo00@0003oooooool00002oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0?
oooo00<0000co`0co`001C?o00Coool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000<ol0<ol000Dco`05
oooo00@0003oooooooooool200001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`00000Aoooo00<0000co`0co`001C?o00;oool010000?ooooooo`0000;oool010000?ooooooo`00
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007<ol00oooo`800004
oooo0P0000?oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.55838 .12361 L
.57861 .12361 L
.58392 .12361 L
.58957 .12361 L
.59232 .12361 L
.59367 .12361 L
.59491 .12361 L
s
.59491 .12361 m
.59536 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.39174 .12361 L
.39675 .12361 L
.40134 .12361 L
.40252 .12361 L
.40381 .12361 L
.40503 .12333 L
.40616 .12217 L
.41134 .11705 L
.42237 .10724 L
.44116 .09353 L
.4615 .08231 L
.47265 .07749 L
.48291 .07379 L
.50308 .06823 L
.54257 .05739 L
.56243 .05171 L
.58054 .04674 L
.58534 .04548 L
.58787 .04484 L
.59056 .04416 L
.5929 .04357 L
.59354 .04341 L
.59423 .04324 L
.59549 .12361 L
.59664 .12361 L
.59786 .12361 L
.60005 .12361 L
.62096 .12361 L
.65907 .12361 L
.69963 .12361 L
.73868 .12361 L
.78017 .12361 L
.82016 .12361 L
.85862 .12361 L
.89954 .12361 L
.93894 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0Coooo0`1V
ogSoool008ooool00`000?ooooooo`0@oooo101Vo`03oooo06Kooooo07Ooool008ooool200003Ooo
o`@0I_l5oooo00<0I_ooooooool0M_ooo`00Soooo`030000oooooooo00[oool206Ko2Oooo`0306Ko
oooooooo07Koool008ooool00`000?ooooooo`06oooo101Vo`_oool00`1Vooooooooo`1foooo002?
oooo00@0003oooooooooool506Ko3oooo`0306Kooooooooo07Koool008ooool01000001Vo`1Vo`1V
oaCoool00`1Vooooooooo`1foooo002=oooo0P1Vo`030000oooooooo01Goool00`1Vooooooooo`1f
oooo002:oooo0`1Vo`;oool200005_ooo`0306Kooooooooo07Koool001Ooool40000>Oooo`D0000^
oooo0`1Vo`Goool00`000?ooooooo`0Eoooo00<0I_ooooooool07oooo`D0000hoooo100001Koool0
01Ooool00`000?ooooooo`0loooo00<0003oooooool0;?ooo`80I_l8oooo00<0003oooooool05Ooo
o`0306Kooooooooo027oool00`000?ooooooo`0hoooo00<0003oooooool05oooo`006?ooo`030000
oooooooo03_oool00`000?ooooooo`0Zoooo0P1Vo`[oool00`000?ooooooo`0Eoooo00<0I_oooooo
ool08Oooo`030000oooooooo03Woool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?oo
ooooo`0boooo100000Coool00`000?ooooooo`0Xoooo0P1Vo`coool00`000?ooooooo`0Eoooo00<0
I_ooooooool08Oooo`030000oooooooo03[oool00`000?ooooooo`0Eoooo000Goooo00@0003ooooo
ool0000koooo00<0003oooooool09oooo`0306Kooooooooo00coool00`000?ooooooo`0Eoooo00<0
I_ooooooool08Oooo`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>ooo
o`80000Woooo0P1Vo`ooool200005_ooo`0306Kooooooooo023oool20000>oooo`80000Goooo001l
oooo0P1Voa7oool00`000?ooooooo`0Eoooo00<0I_ooooooool0M_ooo`00Noooo`0306Kooooooooo
017oool00`000?ooooooo`0Eoooo00<0I_ooooooool0M_ooo`00N_ooo`0306Kooooooooo01;oool0
0`000?ooooooo`0Eoooo00<0I_ooooooool0M_ooo`00NOooo`0306Kooooooooo01?oool00`000?oo
ooooo`0Eoooo00<0I_ooooooool0M_ooo`00N?ooo`0306Kooooooooo01Coool00`000?ooooooo`0E
oooo00<0I_ooooooool0M_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006
oooo00<0003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0
003oooooool0>Oooo`030000<ol0<ol001Dco`000ol0VC?o03?o000Q<ol02@0003Coool00`000?oo
ooooo`0Eoooo002?oooo00<0000co`0co`005C?o0003o`2I<ol0<ol001/co`060000EOooo`00Sooo
o`030000<ol0<ol001Dco`000ol0VC?o03?o000I<ol00P0005_oool008ooool00`0003?o03?o000E
<ol000?o09Tco`0co`005c?o0080001Moooo002?oooo00<0000co`0co`005C?o0003o`2I<ol0<ol0
01@co`030000Goooo`00Soooo`80000F<ol000?o09Tco`0co`004C?o00<0001Roooo002?oooo00<0
000co`0co`005C?o0003o`2I<ol0<ol000lco`020000IOooo`00Soooo`030000<ol0<ol001Dco`00
0ol0VC?o03?o000><ol000<0003oooooool0IOooo`00Soooo`030000<ol0<ol001Dco`000ol0VC?o
03?o000=<ol000<0003oooooool0I_ooo`00Soooo`030000<ol0<ol001Dco`000ol0VC?o03?o000<
<ol000<0003oooooool0Ioooo`00Soooo`030000<ol0<ol001Dco`000ol0VC?o03?o000:<ol00P00
06[oool008ooool200005S?o0003o`2I<ol0<ol000Tco`000`000?ooooooo`1Zoooo002?oooo00<0
000co`0co`005C?o0003o`2I<ol0<ol000Pco`000`000?ooooooo`1[oooo002?oooo00<0000co`0c
o`005C?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1/oooo002?oooo00<0000co`0co`005C?o
0003o`2I<ol0<ol000Lco`000`000?ooooooo`1/oooo002?oooo00<0000co`0co`005C?o0003o`2I
<ol0<ol000Hco`000`000?ooooooo`1]oooo002?oooo00<0000co`0co`005C?o0003o`2I<ol0<ol0
00Dco`000`000?ooooooo`1^oooo002?oooo0P0001Hco`000ol0VC?o03?o0004<ol000<0003ooooo
ool0Koooo`00Soooo`030000<ol0<ol001Dco`000ol0VC?o03?o0003<ol000<0003oooooool0L?oo
o`00Soooo`030000<ol0<ol001Dco`000ol0VC?o03?o0003<ol000<0003oooooool0L?ooo`00Sooo
o`030000<ol0<ol001Dco`000ol0VC?o03?o0002<ol000<0003oooooool0LOooo`00Soooo`030000
<ol0<ol001Dco`000ol0VC?o03?o0002<ol000<0003oooooool0LOooo`00Soooo`030000<ol0<ol0
01Dco`001Ol0VC?o03?o03?o0000001doooo002?oooo0P0001Hco`001Ol0VC?o03?o03?o0000001d
oooo002?oooo00<0000co`0co`005C?o0004o`2I<ol0<ol00000MOooo`00Soooo`030000<ol0<ol0
01Dco`001?l0VC?o03?o000007Goool008ooool00`0003?o03?o000E<ol000?o09Tco`000000M_oo
o`00Soooo`030000<ol0<ol001Dco`000ol0VC?o0000001foooo0027oooo1@0000?oool00`0003?o
03?o000E<ol000?o09T0003oool0M_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E
<ol000?o09T0003oool0M_ooo`00ROooo`030000oooooooo00?oool300005C?o0003o`2Ioooooooo
07Koool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o0003o`2Ioooooooo07Koool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o0003o`2Ioooooooo07Koool008Soool2
00001Oooo`030000<ol0<ol001@co`000`000?l0VOooo`1goooo002?oooo00<0000co`0co`0053?o
00030000o`2Ioooo07Ooool008ooool00`0003?o03?o000C<ol000<0003ooooo09T0N?ooo`00Sooo
o`80000D<ol000<0003ooooo09T0N?ooo`00Soooo`030000<ol0<ol001<co`000`000?ooool0V@1h
oooo002?oooo00<0000co`0co`004S?o00040000ooooooooo`2IN?ooo`00Soooo`030000<ol0<ol0
018co`0010000?ooooooool0VGSoool008ooool00`0003?o03?o000B<ol000@0003ooooooooo09Uh
oooo002?oooo00<0000co`0co`004C?o00050000ooooooooooooo`2I07Soool008ooool200004S?o
00050000ooooooooooooo`2I07Soool008ooool00`0003?o03?o000A<ol000D0003ooooooooooooo
09T0N?ooo`00Soooo`030000<ol0<ol0014co`001@000?ooooooooooool0V@1hoooo002?oooo00<0
000co`0co`0043?o00030000oooooooo00;oool00ol0VOooooooo`1foooo002?oooo00<0000co`0c
o`0043?o00030000oooooooo00;oool00ol0VOooooooo`1foooo002?oooo00<0000co`0co`0043?o
00030000oooooooo00;oool00ol0VOooooooo`1foooo002?oooo00<0000co`0co`0043?o00030000
oooooooo00;oool00ol0VOooooooo`1foooo002?oooo0P00010co`000`000?ooooooo`03oooo00?o
09Woooooool0M_ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`03oooo00?o09Wooooo
ool0M_ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`03oooo00?o09Woooooool0M_oo
o`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`03oooo00?o09Woooooool0M_ooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`03oooo00?o09Woooooool0M_ooo`00Soooo`030000
<ol0<ol000hco`000`000?ooooooo`04oooo00?o09Woooooool0M_ooo`00Soooo`80000?<ol000<0
003oooooool01?ooo`03o`2Ioooooooo07Koool008ooool00`0003?o03?o000><ol000<0003ooooo
ool01?ooo`03o`2Ioooooooo07Koool008ooool00`0003?o03?o000><ol000<0003oooooool01?oo
o`03o`2Ioooooooo07Koool008ooool00`0003?o03?o000=<ol000<0003oooooool01Oooo`03o`2I
oooooooo07Koool008Ooool400001?ooo`030000<ol0<ol000dco`000`000?ooooooo`05oooo00?o
09Woooooool0M_ooo`00Qoooo`030000oooooooo00Goool00`0003?o03?o000=<ol000<0003ooooo
ool01Oooo`03o`2Ioooooooo07Koool008Soool00`000?ooooooo`04oooo0`0000dco`000`000?oo
ooooo`05oooo00?o09Woooooool0M_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000=
<ol000<0003oooooool01Oooo`03o`2Ioooooooo07Koool008Ooool010000?ooooooo`0000Coool0
0`0003?o03?o000<<ol000<0003oooooool01_ooo`03o`2Ioooooooo07Koool008Soool200001Ooo
o`030000<ol0<ol000`co`000`000?ooooooo`06oooo00?o09Woooooool0M_ooo`00Soooo`030000
<ol0<ol000`co`000`000?ooooooo`06oooo00?o09Woooooool0M_ooo`00Soooo`030000<ol0<ol0
00`co`000`000?ooooooo`06oooo00?o09Woooooool0M_ooo`00Soooo`80000=<ol000<0003ooooo
ool01_ooo`03o`2Ioooooooo07Koool008ooool00`0003?o03?o000<<ol000<0003oooooool01_oo
o`03o`2Ioooooooo07Koool008ooool00`0003?o03?o000;<ol000<0003oooooool01oooo`03o`2I
oooooooo07Koool008ooool00`0003?o03?o000;<ol000<0003oooooool01oooo`03o`2Ioooooooo
07Koool008ooool00`0003?o03?o000;<ol000<0003oooooool01oooo`03o`2Ioooooooo07Koool0
08ooool00`0003?o03?o000;<ol000<0003oooooool01oooo`03o`2Ioooooooo07Koool008ooool0
0`0003?o03?o000;<ol000<0003oooooool01oooo`03o`2Ioooooooo07Koool008ooool2000033?o
00030000oooooooo00Ooool00ol0VOooooooo`1foooo002?oooo00<0000co`0co`002c?o00030000
oooooooo00Ooool00ol0VOooooooo`1foooo002?oooo00<0000co`0co`002S?o00030000oooooooo
00Soool00ol0VOooooooo`1foooo002?oooo00<0000co`0co`002S?o00030000oooooooo00Soool0
0ol0VOooooooo`1foooo002?oooo00<0000co`0co`002S?o00030000oooooooo00Soool00ol0VOoo
ooooo`1foooo002?oooo00<0000co`0co`002S?o00030000oooooooo00Soool00ol0VOooooooo`1f
oooo002?oooo0P0000/co`000`000?ooooooo`08oooo00?o09Woooooool0M_ooo`00Soooo`030000
<ol0<ol000Xco`000`000?ooooooo`08oooo00?o09Woooooool0M_ooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`08oooo00?o09Woooooool0M_ooo`00Soooo`030000<ol0<ol000Tco`00
0`000?ooooooo`09oooo00?o09Woooooool0M_ooo`00Soooo`030000<ol0<ol000Tco`000`000?oo
ooooo`09oooo00?o09Woooooool0M_ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`09
oooo00?o09Woooooool0M_ooo`00Soooo`80000:<ol000<0003oooooool02Oooo`03o`2Ioooooooo
07Koool008ooool00`0003?o03?o0009<ol000<0003oooooool02Oooo`03o`2Ioooooooo07Koool0
08ooool00`0003?o03?o0009<ol000<0003oooooool02Oooo`03o`2Ioooooooo07Koool008ooool0
0`0003?o03?o0008<ol000<0003oooooool02_ooo`03o`2Ioooooooo07Koool008Soool200001Ooo
o`030000<ol0<ol000Pco`000`000?ooooooo`0:oooo00?o09Woooooool0M_ooo`00Qoooo`040000
oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0:oooo00?o09Woooooool0M_oo
o`00ROooo`030000oooooooo00?oool3000023?o00030000oooooooo00[oool00ol0VOooooooo`1f
oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000Pco`000`000?ooooooo`0:oooo00?o
09Woooooool0M_ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0:oooo00?o09Woooooool0M_ooo`00R?ooo`800005oooo00<0000co`0co`001c?o00030000
oooooooo00_oool00ol0VOooooooo`1foooo002?oooo00<0000co`0co`001c?o00030000oooooooo
00_oool00ol0VOooooooo`1foooo002?oooo00<0000co`0co`001c?o00030000oooooooo00_oool0
0ol0VOooooooo`1foooo002?oooo00<0000co`0co`001c?o00030000oooooooo00_oool00ol0VOoo
ooooo`1foooo002?oooo0P0000Pco`000`000?ooooooo`0;oooo00?o09Woooooool0M_ooo`00Sooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0;oooo00?o09Woooooool0M_ooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`0;oooo00?o09Woooooool0M_ooo`00Soooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0;oooo00?o09Woooooool0M_ooo`00Soooo`030000<ol0<ol000Hco`00
0`000?ooooooo`0<oooo00?o09Woooooool0M_ooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`0<oooo00?o09Woooooool0M_ooo`00Soooo`800007<ol000<0003oooooool03?ooo`03o`2I
oooooooo07Koool008ooool00`0003?o03?o0006<ol000<0003oooooool03?ooo`03o`2Ioooooooo
07Koool008ooool00`0003?o03?o0006<ol000<0003oooooool03?ooo`03o`2Ioooooooo07Koool0
08ooool00`0003?o03?o0006<ol000<0003oooooool03?ooo`03o`2Ioooooooo07Koool008ooool0
0`0003?o03?o0006<ol000<0003oooooool03?ooo`03o`2Ioooooooo07Koool008ooool00`0003?o
03?o0006<ol000<0003oooooool03?ooo`03o`2Ioooooooo07Koool008ooool200001S?o00030000
oooooooo00goool00ol0VOooooooo`1foooo002?oooo00<0000co`0co`001C?o00030000oooooooo
00goool00ol0VOooooooo`1foooo002?oooo00<0000co`0co`001C?o00030000oooooooo00goool0
0ol0VOooooooo`1foooo002?oooo00<0000co`0co`001C?o00030000oooooooo00goool00ol0VOoo
ooooo`1foooo002?oooo00<0000co`0co`001C?o00030000oooooooo00goool00ol0VOooooooo`1f
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo00goool00ol0VOooooooo`1foooo002?
oooo0P0000Hco`000`000?ooooooo`0=oooo00?o09Woooooool0M_ooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`0=oooo00?o09Woooooool0M_ooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`0=oooo00?o09Woooooool0M_ooo`00Soooo`030000<ol0<ol000@co`000`000?oo
ooooo`0>oooo00?o09Woooooool0M_ooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0>
oooo00?o09Woooooool0M_ooo`00ROooo`<00003oooo00<0000co`0co`0013?o00030000oooooooo
00koool00ol0VOooooooo`1foooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`00
0`000?ooooooo`0>oooo00?o09Woooooool0M_ooo`00Qoooo`D00003oooo0`0000@co`000`000?oo
ooooo`0>oooo00?o09Woooooool0M_ooo`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028
oooo00<0003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:
oooo002?oooo1c?o08[oool007coool00`000?ooooooo`0@oooo1c?o00_oool00`000?ooooooo`1l
oooo001koooo00<0003oooooool02?ooo`030000oooooooo00Koool7<ol03?ooo`030000oooooooo
07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@00008co`02
00001Oooo`<00002oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`8co`000`0003?o03?o0002<ol02?ooo`050000
oooooooooooo000007goool007[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`8co`00
0`0003?o03?o0002<ol01Oooo`D00003oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000<oooo0S?o00030000<ol0<ol0008co`05oooo00@0003oooooool00003oooo00<0003ooooo
ool0Noooo`00Noooo`050000oooooooooooo000000ooool2<ol000<0000co`0co`000S?o00Koool0
0`000?ooo`000003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo013oool00c?o0000
00000004<ol01oooo`800002oooo00<0003oooooool0O?ooo`00Soooo`Lco`2:oooo002?oooo1c?o
08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.58872 .12361 L
.59405 .12361 L
.59698 .12361 L
.59842 .12361 L
.59905 .12361 L
.59975 .12361 L
s
.59975 .12361 m
.60026 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.36136 .12361 L
.37176 .12361 L
.3815 .12361 L
.39106 .12361 L
.39381 .12361 L
.39642 .12361 L
.39756 .12361 L
.39877 .12361 L
.39947 .12361 L
.4001 .1235 L
.40134 .12223 L
.42237 .10343 L
.44161 .09032 L
.46243 .07974 L
.48237 .07245 L
.49241 .06966 L
.50344 .06715 L
.54386 .05665 L
.5625 .05148 L
.58277 .04605 L
.58812 .04469 L
.5938 .04327 L
.59614 .04271 L
.59736 .04241 L
.59865 .04211 L
.59934 .04194 L
.60009 .12361 L
.60141 .12361 L
.60401 .12361 L
.62413 .12361 L
.66469 .12361 L
.70374 .12361 L
.74523 .12361 L
.78522 .12361 L
.82368 .12361 L
.8646 .12361 L
.904 .12361 L
.94189 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0Coooo101V
ogOoool008ooool00`000?ooooooo`0@oooo0`1Vo`?oool00`1Vooooooooo`1eoooo002?oooo0P00
00coool506Ko1_ooo`0306Kooooooooo07Goool008ooool00`000?ooooooo`07oooo101Vo`_oool0
0`1Vooooooooo`1eoooo002?oooo00<0003oooooool01?ooo`<0I_l?oooo00<0I_ooooooool0MOoo
o`00Soooo`030000oooooooo00@0I_lBoooo00<0I_ooooooool0MOooo`00Soooo`03000006Ko06Ko
01Koool00`1Vooooooooo`1eoooo002:oooo1@1Vo`030000oooooooo01Koool00`1Vooooooooo`1e
oooo0027oooo0`1Vo`Goool200005oooo`0306Kooooooooo07Goool001Ooool40000>Oooo`D0000/
oooo0P1Vo`Soool00`000?ooooooo`0Foooo00<0I_ooooooool07_ooo`D0000hoooo100001Koool0
01Ooool00`000?ooooooo`0loooo00<0003oooooool0:_ooo`80I_l:oooo00<0003oooooool05_oo
o`0306Kooooooooo023oool00`000?ooooooo`0hoooo00<0003oooooool05oooo`006?ooo`030000
oooooooo03_oool00`000?ooooooo`0Xoooo0P1Vo`coool00`000?ooooooo`0Foooo00<0I_oooooo
ool08?ooo`030000oooooooo03Woool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?oo
ooooo`0boooo100000Coool00`000?ooooooo`0Woooo00<0I_ooooooool03?ooo`030000oooooooo
01Koool00`1Vooooooooo`0Poooo00<0003oooooool0>_ooo`030000oooooooo01Goool001Ooool0
10000?ooooooo`0003_oool00`000?ooooooo`0Uoooo0P1Vo`ooool00`000?ooooooo`0Foooo00<0
I_ooooooool08?ooo`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>ooo
o`80000Uoooo0P1Voa7oool200005oooo`0306Kooooooooo01ooool20000>oooo`80000Goooo001k
oooo00<0I_ooooooool04Oooo`030000oooooooo01Koool00`1Vooooooooo`1eoooo001joooo00<0
I_ooooooool04_ooo`030000oooooooo01Koool00`1Vooooooooo`1eoooo001ioooo00<0I_oooooo
ool04oooo`030000oooooooo01Koool00`1Vooooooooo`1eoooo001hoooo00<0I_ooooooool05?oo
o`030000oooooooo01Koool00`1Vooooooooo`1eoooo001goooo00<0I_ooooooool05Oooo`030000
oooooooo01Koool00`1Vooooooooo`1eoooo000@ooooo`00017oool001Koool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`000?l0VC?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0ioooo00<0000co`0co`005S?o0003o`2I<ol0<ol0020co`090000=?oo
o`030000oooooooo01Goool008ooool00`0003?o03?o000F<ol000?o09Tco`0co`006S?o00H0001E
oooo002?oooo00<0000co`0co`005S?o0003o`2I<ol0<ol001Pco`020000Foooo`00Soooo`030000
<ol0<ol001Hco`000ol0VC?o03?o000F<ol00P0005goool008ooool00`0003?o03?o000F<ol000?o
09Tco`0co`004c?o00<0001Ooooo002?oooo0P0001Lco`000ol0VC?o03?o000@<ol00`0006;oool0
08ooool00`0003?o03?o000F<ol000?o09Tco`0co`003S?o0080001Uoooo002?oooo00<0000co`0c
o`005S?o0003o`2I<ol0<ol000dco`000`000?ooooooo`1Uoooo002?oooo00<0000co`0co`005S?o
0003o`2I<ol0<ol000`co`000`000?ooooooo`1Voooo002?oooo00<0000co`0co`005S?o0003o`2I
<ol0<ol000/co`000`000?ooooooo`1Woooo002?oooo00<0000co`0co`005S?o0003o`2I<ol0<ol0
00Tco`020000J_ooo`00Soooo`80000G<ol000?o09Tco`0co`0023?o00030000oooooooo06[oool0
08ooool00`0003?o03?o000F<ol000?o09Tco`0co`001c?o00030000oooooooo06_oool008ooool0
0`0003?o03?o000F<ol000?o09Tco`0co`001S?o00030000oooooooo06coool008ooool00`0003?o
03?o000F<ol000?o09Tco`0co`001S?o00030000oooooooo06coool008ooool00`0003?o03?o000F
<ol000?o09Tco`0co`001C?o00030000oooooooo06goool008ooool00`0003?o03?o000F<ol000?o
09Tco`0co`0013?o00030000oooooooo06koool008ooool200005c?o0003o`2I<ol0<ol000<co`00
0`000?ooooooo`1_oooo002?oooo00<0000co`0co`005S?o0003o`2I<ol0<ol0008co`000`000?oo
ooooo`1`oooo002?oooo00<0000co`0co`005S?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1`
oooo002?oooo00<0000co`0co`005S?o0005o`2I<ol0<ol0<ol0000007?oool008ooool00`0003?o
03?o000F<ol000Go09Tco`0co`0co`000000Loooo`00Soooo`030000<ol0<ol001Hco`001?l0VC?o
03?o000007Coool008ooool200005c?o0004o`2I<ol0<ol00000M?ooo`00Soooo`030000<ol0<ol0
01Hco`000ol0VC?o0000001eoooo002?oooo00<0000co`0co`005S?o0003o`2I<ol0000007Goool0
08ooool00`0003?o03?o000F<ol000?o09T0003oool0MOooo`00Soooo`030000<ol0<ol001Hco`00
0ol0V@000?ooo`1eoooo0027oooo1@0000?oool00`0003?o03?o000F<ol000?o09Woooooool0MOoo
o`00ROooo`030000oooooooo00?oool00`0003?o03?o000F<ol000?o09Woooooool0MOooo`00ROoo
o`030000oooooooo00?oool300005C?o00030000o`2Ioooo07Koool008Woool00`000?ooooooo`03
oooo00<0000co`0co`005C?o00030000o`2Ioooo07Koool008Woool00`000?ooooooo`03oooo00<0
000co`0co`005C?o00030000o`2Ioooo07Koool008Soool200001Oooo`030000<ol0<ol001@co`00
0`000?ooool0V@1goooo002?oooo00<0000co`0co`0053?o00030000ooooo`2I07Ooool008ooool0
0`0003?o03?o000C<ol000@0003ooooooooo09Ugoooo002?oooo0P0001@co`0010000?ooooooool0
VGOoool008ooool00`0003?o03?o000C<ol000@0003ooooooooo09Ugoooo002?oooo00<0000co`0c
o`004S?o00050000ooooooooooooo`2I07Ooool008ooool00`0003?o03?o000B<ol000D0003ooooo
oooooooo09T0Moooo`00Soooo`030000<ol0<ol0018co`001@000?ooooooooooool0V@1goooo002?
oooo00<0000co`0co`004C?o00030000oooooooo00;oool00ol0VOooooooo`1eoooo002?oooo0P00
018co`000`000?ooooooo`02oooo00?o09Woooooool0MOooo`00Soooo`030000<ol0<ol0014co`00
0`000?ooooooo`02oooo00?o09Woooooool0MOooo`00Soooo`030000<ol0<ol0014co`000`000?oo
ooooo`02oooo00?o09Woooooool0MOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`03
oooo00?o09Woooooool0MOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`03oooo00?o
09Woooooool0MOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`03oooo00?o09Wooooo
ool0MOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`03oooo00?o09Woooooool0MOoo
o`00Soooo`80000@<ol000<0003oooooool01?ooo`03o`2Ioooooooo07Goool008ooool00`0003?o
03?o000?<ol000<0003oooooool01?ooo`03o`2Ioooooooo07Goool008ooool00`0003?o03?o000?
<ol000<0003oooooool01?ooo`03o`2Ioooooooo07Goool008ooool00`0003?o03?o000?<ol000<0
003oooooool01?ooo`03o`2Ioooooooo07Goool008ooool00`0003?o03?o000?<ol000<0003ooooo
ool01?ooo`03o`2Ioooooooo07Goool008ooool00`0003?o03?o000><ol000<0003oooooool01Ooo
o`03o`2Ioooooooo07Goool008ooool200003c?o00030000oooooooo00Goool00ol0VOooooooo`1e
oooo002?oooo00<0000co`0co`003S?o00030000oooooooo00Goool00ol0VOooooooo`1eoooo002?
oooo00<0000co`0co`003S?o00030000oooooooo00Goool00ol0VOooooooo`1eoooo002?oooo00<0
000co`0co`003C?o00030000oooooooo00Koool00ol0VOooooooo`1eoooo0027oooo100000Coool0
0`0003?o03?o000=<ol000<0003oooooool01_ooo`03o`2Ioooooooo07Goool008Ooool00`000?oo
ooooo`05oooo00<0000co`0co`003C?o00030000oooooooo00Koool00ol0VOooooooo`1eoooo0028
oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool01_ooo`03o`2Ioooooooo07Goool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo00Koool00ol0VOoo
ooooo`1eoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0033?o00030000oooooooo
00Ooool00ol0VOooooooo`1eoooo0028oooo0P0000Goool00`0003?o03?o000<<ol000<0003ooooo
ool01oooo`03o`2Ioooooooo07Goool008ooool00`0003?o03?o000<<ol000<0003oooooool01ooo
o`03o`2Ioooooooo07Goool008ooool00`0003?o03?o000<<ol000<0003oooooool01oooo`03o`2I
oooooooo07Goool008ooool200003C?o00030000oooooooo00Ooool00ol0VOooooooo`1eoooo002?
oooo00<0000co`0co`0033?o00030000oooooooo00Ooool00ol0VOooooooo`1eoooo002?oooo00<0
000co`0co`002c?o00030000oooooooo00Soool00ol0VOooooooo`1eoooo002?oooo00<0000co`0c
o`002c?o00030000oooooooo00Soool00ol0VOooooooo`1eoooo002?oooo00<0000co`0co`002c?o
00030000oooooooo00Soool00ol0VOooooooo`1eoooo002?oooo00<0000co`0co`002c?o00030000
oooooooo00Soool00ol0VOooooooo`1eoooo002?oooo00<0000co`0co`002c?o00030000oooooooo
00Soool00ol0VOooooooo`1eoooo002?oooo0P0000`co`000`000?ooooooo`08oooo00?o09Wooooo
ool0MOooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`08oooo00?o09Woooooool0MOoo
o`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`09oooo00?o09Woooooool0MOooo`00Sooo
o`030000<ol0<ol000Xco`000`000?ooooooo`09oooo00?o09Woooooool0MOooo`00Soooo`030000
<ol0<ol000Xco`000`000?ooooooo`09oooo00?o09Woooooool0MOooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`09oooo00?o09Woooooool0MOooo`00Soooo`80000;<ol000<0003ooooo
ool02Oooo`03o`2Ioooooooo07Goool008ooool00`0003?o03?o000:<ol000<0003oooooool02Ooo
o`03o`2Ioooooooo07Goool008ooool00`0003?o03?o000:<ol000<0003oooooool02Oooo`03o`2I
oooooooo07Goool008ooool00`0003?o03?o0009<ol000<0003oooooool02_ooo`03o`2Ioooooooo
07Goool008ooool00`0003?o03?o0009<ol000<0003oooooool02_ooo`03o`2Ioooooooo07Goool0
08ooool00`0003?o03?o0009<ol000<0003oooooool02_ooo`03o`2Ioooooooo07Goool008ooool2
00002S?o00030000oooooooo00[oool00ol0VOooooooo`1eoooo002?oooo00<0000co`0co`002C?o
00030000oooooooo00[oool00ol0VOooooooo`1eoooo002?oooo00<0000co`0co`002C?o00030000
oooooooo00[oool00ol0VOooooooo`1eoooo002?oooo00<0000co`0co`0023?o00030000oooooooo
00_oool00ol0VOooooooo`1eoooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0003ooooo
ool02oooo`03o`2Ioooooooo07Goool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008
<ol000<0003oooooool02oooo`03o`2Ioooooooo07Goool008Woool00`000?ooooooo`03oooo0`00
00Pco`000`000?ooooooo`0;oooo00?o09Woooooool0MOooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o0008<ol000<0003oooooool02oooo`03o`2Ioooooooo07Goool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool02oooo`03o`2Ioooooooo07Goool0
08Soool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`0<oooo00?o09Woooooool0MOoo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0<oooo00?o09Woooooool0MOooo`00Sooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0<oooo00?o09Woooooool0MOooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`0<oooo00?o09Woooooool0MOooo`00Soooo`800008<ol000<0
003oooooool03?ooo`03o`2Ioooooooo07Goool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool03?ooo`03o`2Ioooooooo07Goool008ooool00`0003?o03?o0007<ol000<0003oooooool03?oo
o`03o`2Ioooooooo07Goool008ooool00`0003?o03?o0007<ol000<0003oooooool03?ooo`03o`2I
oooooooo07Goool008ooool00`0003?o03?o0006<ol000<0003oooooool03Oooo`03o`2Ioooooooo
07Goool008ooool00`0003?o03?o0006<ol000<0003oooooool03Oooo`03o`2Ioooooooo07Goool0
08ooool200001c?o00030000oooooooo00goool00ol0VOooooooo`1eoooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo00goool00ol0VOooooooo`1eoooo002?oooo00<0000co`0co`001S?o
00030000oooooooo00goool00ol0VOooooooo`1eoooo002?oooo00<0000co`0co`001S?o00030000
oooooooo00goool00ol0VOooooooo`1eoooo002?oooo00<0000co`0co`001S?o00030000oooooooo
00goool00ol0VOooooooo`1eoooo002?oooo00<0000co`0co`001S?o00030000oooooooo00goool0
0ol0VOooooooo`1eoooo002?oooo0P0000Hco`000`000?ooooooo`0>oooo00?o09Woooooool0MOoo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0>oooo00?o09Woooooool0MOooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`0>oooo00?o09Woooooool0MOooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`0>oooo00?o09Woooooool0MOooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`0>oooo00?o09Woooooool0MOooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`0>oooo00?o09Woooooool0MOooo`00Soooo`800006<ol000<0003oooooool03_oo
o`03o`2Ioooooooo07Goool008ooool00`0003?o03?o0005<ol000<0003oooooool03_ooo`03o`2I
oooooooo07Goool008ooool00`0003?o03?o0005<ol000<0003oooooool03_ooo`03o`2Ioooooooo
07Goool008ooool00`0003?o03?o0004<ol000<0003oooooool03oooo`03o`2Ioooooooo07Goool0
08ooool00`0003?o03?o0004<ol000<0003oooooool03oooo`03o`2Ioooooooo07Goool008Woool3
00000oooo`030000<ol0<ol000@co`000`000?ooooooo`0?oooo00?o09Woooooool0MOooo`00R_oo
o`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool03oooo`03o`2Ioooooooo
07Goool008Ooool500000oooo`<00004<ol000<0003oooooool03oooo`03o`2Ioooooooo07Goool0
08Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_oo
o`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0
003oooooool04oooo`Lco`0>oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool0
0`000?ooooooo`09oooo1c?o00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01_ooo`D00002<ol00P000003<ol0oooooooo00;oool3000000?o
ool0000000000P0000?oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`07oooo00<0000co`0co`001C?o00Goool010000?oo
ooooo`0000Koool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo
00ooool00`0003?o03?o0005<ol00_ooo`D00002oooo00<0003oooooool01?ooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500003_ooo`030000<ol0<ol000Dco`02oooo00@0003ooooo
ool00004oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`00000Aoooo00<0000co`0co`001C?o00?oool00`000?ooo`000002oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200001c?o00Coool200000ooo
o`800003oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.58872 .12361 L
.59405 .12361 L
.59698 .12361 L
.59975 .12361 L
.60237 .12361 L
.60309 .12361 L
.60385 .12361 L
.6045 .12361 L
s
.6045 .12361 m
.60478 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.36136 .12361 L
.37176 .12361 L
.3815 .12361 L
.3864 .12361 L
.39106 .12361 L
.39362 .12361 L
.39433 .12361 L
.39508 .12361 L
.39578 .12304 L
.39642 .12238 L
.40134 .11751 L
.42237 .09985 L
.44161 .0876 L
.46243 .07777 L
.48237 .07106 L
.49241 .06852 L
.50344 .06625 L
.54386 .05635 L
.58277 .04602 L
.59294 .04348 L
.59831 .04218 L
.60125 .04149 L
.60269 .04116 L
.60401 .04086 L
.60517 .12361 L
.6064 .12361 L
.60898 .12361 L
.61446 .12361 L
.62413 .12361 L
.66224 .12361 L
.7028 .12361 L
.74184 .12361 L
.78334 .12361 L
.82332 .12361 L
.86179 .12361 L
.90271 .12361 L
.94211 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo01Ooool00`1Vooooooooo`1doooo002?oooo00<0
003oooooool05?ooo`@0I_mfoooo002?oooo00<0003oooooool04?ooo`@0I_l3oooo00<0I_oooooo
ool0M?ooo`00Soooo`80000<oooo1@1Vo`Ooool00`1Vooooooooo`1doooo002?oooo00<0003ooooo
ool01oooo`@0I_l<oooo00<0I_ooooooool0M?ooo`00Soooo`030000oooooooo00Coool306Ko4?oo
o`0306Kooooooooo07Coool008ooool00`000?ooooooo`0406Ko4oooo`0306Kooooooooo07Coool0
08goool206Ko00<00000I_l0I_l05oooo`0306Kooooooooo07Coool008[oool306Ko0_ooo`030000
oooooooo01Ooool00`1Vooooooooo`1doooo0027oooo0`1Vo`Goool200006?ooo`0306Kooooooooo
07Coool001Ooool40000>Oooo`D0000[oooo0`1Vo`Soool00`000?ooooooo`0Goooo00<0I_oooooo
ool07Oooo`D0000hoooo100001Koool001Ooool00`000?ooooooo`0loooo00<0003oooooool0:Ooo
o`80I_l;oooo00<0003oooooool06?ooo`0306Kooooooooo01koool00`000?ooooooo`0hoooo00<0
003oooooool05oooo`006?ooo`030000oooooooo03_oool00`000?ooooooo`0Woooo0P1Vo`goool0
0`000?ooooooo`0Hoooo00<0I_ooooooool07_ooo`030000oooooooo03Woool00`000?ooooooo`0F
oooo000Aoooo100000Coool00`000?ooooooo`0boooo100000Coool00`000?ooooooo`0Uoooo0P1V
o`ooool00`000?ooooooo`0Hoooo00<0I_ooooooool07_ooo`030000oooooooo03[oool00`000?oo
ooooo`0Eoooo000Goooo00@0003oooooool0000koooo00<0003oooooool08oooo`80I_lAoooo00<0
003oooooool06?ooo`0306Kooooooooo01koool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo0P0003_oool200009?ooo`0306Kooooooooo017oool200006Oooo`0306Kooooooooo
01goool20000>oooo`80000Goooo001joooo00<0I_ooooooool04_ooo`030000oooooooo01Soool0
0`1Vooooooooo`1coooo001ioooo00<0I_ooooooool04oooo`030000oooooooo01Soool00`1Voooo
ooooo`1coooo001hoooo00<0I_ooooooool05?ooo`030000oooooooo01Soool00`1Vooooooooo`1c
oooo001goooo00<0I_ooooooool05Oooo`030000oooooooo01Soool00`1Vooooooooo`1coooo001f
oooo00<0I_ooooooool05_ooo`030000oooooooo01Soool00`1Vooooooooo`1coooo000@ooooo`00
017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`0003?o0?l0V@09<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0006<ol08P0000Koool00`000?ooooooo`09oooo00<0003ooooo
ool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`005c?o
0003o`2I<ol0<ol001lco`090000=?ooo`030000oooooooo01Goool008ooool00`0003?o03?o000G
<ol000?o09Tco`0co`006C?o00H0001Eoooo002?oooo00<0000co`0co`005c?o0003o`2I<ol0<ol0
01Lco`020000Foooo`00Soooo`030000<ol0<ol001Lco`000ol0VC?o03?o000E<ol00P0005goool0
08ooool00`0003?o03?o000G<ol000?o09Tco`0co`004S?o00<0001Ooooo002?oooo0P0001Pco`00
0ol0VC?o03?o000?<ol00`0006;oool008ooool00`0003?o03?o000G<ol000?o09Tco`0co`003C?o
0080001Uoooo002?oooo00<0000co`0co`005c?o0003o`2I<ol0<ol000`co`000`000?ooooooo`1U
oooo002?oooo00<0000co`0co`005c?o0003o`2I<ol0<ol000/co`000`000?ooooooo`1Voooo002?
oooo00<0000co`0co`005c?o0003o`2I<ol0<ol000Xco`000`000?ooooooo`1Woooo002?oooo00<0
000co`0co`005c?o0003o`2I<ol0<ol000Pco`020000J_ooo`00Soooo`80000H<ol000?o09Tco`0c
o`001c?o00030000oooooooo06[oool008ooool00`0003?o03?o000G<ol000?o09Tco`0co`001S?o
00030000oooooooo06_oool008ooool00`0003?o03?o000G<ol000?o09Tco`0co`001C?o00030000
oooooooo06coool008ooool00`0003?o03?o000G<ol000?o09Tco`0co`001C?o00030000oooooooo
06coool008ooool00`0003?o03?o000G<ol000?o09Tco`0co`0013?o00030000oooooooo06goool0
08ooool00`0003?o03?o000G<ol000?o09Tco`0co`000c?o00030000oooooooo06koool008ooool2
000063?o0003o`2I<ol0<ol0008co`000`000?ooooooo`1_oooo002?oooo00<0000co`0co`005c?o
0005o`2I<ol0<ol0<ol0000007;oool008ooool00`0003?o03?o000G<ol000Go09Tco`0co`0co`00
0000L_ooo`00Soooo`030000<ol0<ol001Lco`001?l0VC?o03?o000007?oool008ooool00`0003?o
03?o000G<ol000Co09Tco`0co`00001coooo002?oooo00<0000co`0co`005c?o0003o`2I<ol00000
07Coool008ooool2000063?o0003o`2I<ol0000007Coool008ooool00`0003?o03?o000G<ol000?o
09T0003oool0M?ooo`00Soooo`030000<ol0<ol001Lco`000ol0V@000?ooo`1doooo002?oooo00<0
000co`0co`005c?o0003o`2Ioooooooo07Coool008ooool00`0003?o03?o000G<ol000?o09Wooooo
ool0M?ooo`00Qoooo`D00003oooo00<0000co`0co`005S?o00030000o`2Ioooo07Goool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`005S?o00030000o`2Ioooo07Goool008Woool00`000?oo
ooooo`03oooo0`0001Dco`000`000?ooool0V@1foooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol001Dco`000`000?ooool0V@1foooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooool0V@1foooo0028oooo0P0000Goool00`0003?o03?o000D<ol000@0003ooooo
oooo09Ufoooo002?oooo00<0000co`0co`0053?o00040000ooooooooo`2IM_ooo`00Soooo`030000
<ol0<ol001<co`001@000?ooooooooooool0V@1foooo002?oooo0P0001@co`001@000?oooooooooo
ool0V@1foooo002?oooo00<0000co`0co`004c?o00050000ooooooooooooo`2I07Koool008ooool0
0`0003?o03?o000B<ol000<0003oooooool00_ooo`03o`2Ioooooooo07Coool008ooool00`0003?o
03?o000B<ol000<0003oooooool00_ooo`03o`2Ioooooooo07Coool008ooool00`0003?o03?o000B
<ol000<0003oooooool00_ooo`03o`2Ioooooooo07Coool008ooool00`0003?o03?o000A<ol000<0
003oooooool00oooo`03o`2Ioooooooo07Coool008ooool200004S?o00030000oooooooo00?oool0
0ol0VOooooooo`1doooo002?oooo00<0000co`0co`004C?o00030000oooooooo00?oool00ol0VOoo
ooooo`1doooo002?oooo00<0000co`0co`004C?o00030000oooooooo00?oool00ol0VOooooooo`1d
oooo002?oooo00<0000co`0co`0043?o00030000oooooooo00Coool00ol0VOooooooo`1doooo002?
oooo00<0000co`0co`0043?o00030000oooooooo00Coool00ol0VOooooooo`1doooo002?oooo00<0
000co`0co`0043?o00030000oooooooo00Coool00ol0VOooooooo`1doooo002?oooo00<0000co`0c
o`0043?o00030000oooooooo00Coool00ol0VOooooooo`1doooo002?oooo0P00010co`000`000?oo
ooooo`05oooo00?o09Woooooool0M?ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`05
oooo00?o09Woooooool0M?ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`05oooo00?o
09Woooooool0M?ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`05oooo00?o09Wooooo
ool0M?ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`05oooo00?o09Woooooool0M?oo
o`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`06oooo00?o09Woooooool0M?ooo`00Sooo
o`80000?<ol000<0003oooooool01_ooo`03o`2Ioooooooo07Coool008ooool00`0003?o03?o000>
<ol000<0003oooooool01_ooo`03o`2Ioooooooo07Coool008ooool00`0003?o03?o000><ol000<0
003oooooool01_ooo`03o`2Ioooooooo07Coool008ooool00`0003?o03?o000=<ol000<0003ooooo
ool01oooo`03o`2Ioooooooo07Coool008Ooool400001?ooo`030000<ol0<ol000dco`000`000?oo
ooooo`07oooo00?o09Woooooool0M?ooo`00Qoooo`030000oooooooo00Goool00`0003?o03?o000=
<ol000<0003oooooool01oooo`03o`2Ioooooooo07Coool008Soool00`000?ooooooo`04oooo0`00
00dco`000`000?ooooooo`07oooo00?o09Woooooool0M?ooo`00ROooo`030000oooooooo00?oool0
0`0003?o03?o000=<ol000<0003oooooool02?ooo`03o`2Ioooooooo07?oool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool02Oooo`03o`2Ioooooooo07?oool0
08Soool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`09oooo00?o09Woooooool0Looo
o`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`09oooo00?o09Woooooool0Loooo`00Sooo
o`030000<ol0<ol000`co`000`000?ooooooo`09oooo00?o09Woooooool0Loooo`00Soooo`80000=
<ol000<0003oooooool02Oooo`03o`2Ioooooooo07?oool008ooool00`0003?o03?o000<<ol000<0
003oooooool02Oooo`03o`2Ioooooooo07?oool008ooool00`0003?o03?o000;<ol000<0003ooooo
ool02_ooo`03o`2Ioooooooo07?oool008ooool00`0003?o03?o000;<ol000<0003oooooool02_oo
o`03o`2Ioooooooo07?oool008ooool00`0003?o03?o000;<ol000<0003oooooool02_ooo`03o`2I
oooooooo07?oool008ooool00`0003?o03?o000;<ol000<0003oooooool02_ooo`03o`2Ioooooooo
07?oool008ooool00`0003?o03?o000;<ol000<0003oooooool02_ooo`03o`2Ioooooooo07?oool0
08ooool2000033?o00030000oooooooo00[oool00ol0VOooooooo`1coooo002?oooo00<0000co`0c
o`002c?o00030000oooooooo00[oool00ol0VOooooooo`1coooo002?oooo00<0000co`0co`002S?o
00030000oooooooo00_oool00ol0VOooooooo`1coooo002?oooo00<0000co`0co`002S?o00030000
oooooooo00_oool00ol0VOooooooo`1coooo002?oooo00<0000co`0co`002S?o00030000oooooooo
00_oool00ol0VOooooooo`1coooo002?oooo00<0000co`0co`002S?o00030000oooooooo00_oool0
0ol0VOooooooo`1coooo002?oooo0P0000/co`000`000?ooooooo`0;oooo00?o09Woooooool0Looo
o`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0;oooo00?o09Woooooool0Loooo`00Sooo
o`030000<ol0<ol000Xco`000`000?ooooooo`0;oooo00?o09Woooooool0Loooo`00Soooo`030000
<ol0<ol000Tco`000`000?ooooooo`0<oooo00?o09Woooooool0Loooo`00Soooo`030000<ol0<ol0
00Tco`000`000?ooooooo`0<oooo00?o09Woooooool0Loooo`00Soooo`030000<ol0<ol000Tco`00
0`000?ooooooo`0<oooo00?o09Woooooool0Loooo`00Soooo`80000:<ol000<0003oooooool03?oo
o`03o`2Ioooooooo07?oool008ooool00`0003?o03?o0009<ol000<0003oooooool03?ooo`03o`2I
oooooooo07?oool008ooool00`0003?o03?o0009<ol000<0003oooooool03?ooo`03o`2Ioooooooo
07?oool008ooool00`0003?o03?o0008<ol000<0003oooooool03Oooo`03o`2Ioooooooo07?oool0
08Soool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`0=oooo00?o09Woooooool0Looo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0=oooo00?o
09Woooooool0Loooo`00ROooo`030000oooooooo00?oool3000023?o00030000oooooooo00goool0
0ol0VOooooooo`1coooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0=oooo00?o09Woooooool0Loooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`0=oooo00?o09Woooooool0Loooo`00R?ooo`800005oooo00<0000co`0c
o`001c?o00030000oooooooo00koool00ol0VOooooooo`1coooo002?oooo00<0000co`0co`001c?o
00030000oooooooo00koool00ol0VOooooooo`1coooo002?oooo00<0000co`0co`001c?o00030000
oooooooo00koool00ol0VOooooooo`1coooo002?oooo00<0000co`0co`001c?o00030000oooooooo
00koool00ol0VOooooooo`1coooo002?oooo0P0000Pco`000`000?ooooooo`0>oooo00?o09Wooooo
ool0Loooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0>oooo00?o09Woooooool0Looo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0>oooo00?o09Woooooool0Loooo`00Sooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0>oooo00?o09Woooooool0Loooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`0?oooo00?o09Woooooool0Loooo`00Soooo`030000<ol0<ol0
00Hco`000`000?ooooooo`0?oooo00?o09Woooooool0Loooo`00Soooo`800007<ol000<0003ooooo
ool03oooo`03o`2Ioooooooo07?oool008ooool00`0003?o03?o0006<ol000<0003oooooool03ooo
o`03o`2Ioooooooo07?oool008ooool00`0003?o03?o0006<ol000<0003oooooool03oooo`03o`2I
oooooooo07?oool008ooool00`0003?o03?o0006<ol000<0003oooooool03oooo`03o`2Ioooooooo
07?oool008ooool00`0003?o03?o0006<ol000<0003oooooool03oooo`03o`2Ioooooooo07?oool0
08ooool00`0003?o03?o0006<ol000<0003oooooool03oooo`03o`2Ioooooooo07?oool008ooool2
00001S?o00030000oooooooo013oool00ol0VOooooooo`1coooo002?oooo00<0000co`0co`001C?o
00030000oooooooo013oool00ol0VOooooooo`1coooo002?oooo00<0000co`0co`001C?o00030000
oooooooo013oool00ol0VOooooooo`1coooo002?oooo00<0000co`0co`001C?o00030000oooooooo
013oool00ol0VOooooooo`1coooo002?oooo00<0000co`0co`001C?o00030000oooooooo013oool0
0ol0VOooooooo`1coooo002?oooo00<0000co`0co`001C?o00030000oooooooo013oool00ol0VOoo
ooooo`1coooo002?oooo0P0000Hco`000`000?ooooooo`0@oooo00?o09Woooooool0Loooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`0@oooo00?o09Woooooool0Loooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`0@oooo00?o09Woooooool0Loooo`00Soooo`030000<ol0<ol0
00@co`000`000?ooooooo`0Aoooo00?o09Woooooool0Loooo`00Soooo`030000<ol0<ol000@co`00
0`000?ooooooo`0Aoooo00?o09Woooooool0Loooo`00ROooo`<00003oooo00<0000co`0co`0013?o
00030000oooooooo017oool00ol0VOooooooo`1coooo002:oooo00<0003oooooool00_ooo`030000
<ol0<ol000@co`000`000?ooooooo`0Aoooo00?o09Woooooool0Loooo`00Qoooo`D00003oooo0`00
00@co`000`000?ooooooo`0Aoooo00?o09Woooooool0Loooo`00Qoooo`040000oooooooo00001?oo
o`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7<ol0R_oo
o`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?ooooooo`0Coooo1c?o00koool0
0`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo00Woool7<ol03ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06
oooo1@00008co`02000000<co`3oooooool00_ooo`<00003oooo0`0000;oool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07
oooo00<0000co`0co`001C?o00Goool00`000?ooooooo`03oooo00D0003oooooooooool00000N_oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0000co`0co`001C?o00;oool5
000000?oool0000000000`0000?oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
00koool00`0003?o03?o0005<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Aoooo00<0000co`0co`001C?o
00?oool00`000?ooo`000003oooo00<0003oool000000oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Aoooo0P0000Lco`04oooo0P0000Coool200000_ooo`030000oooooooo07Woool0
08ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.58872 .12361 L
.59405 .12361 L
.59975 .12361 L
.60256 .12361 L
.60521 .12361 L
.60759 .12361 L
.60824 .12361 L
.60893 .12361 L
s
.60893 .12361 m
.60942 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.36136 .12361 L
.37176 .12361 L
.37685 .12361 L
.3815 .12361 L
.38384 .12361 L
.3864 .12361 L
.38757 .12361 L
.38881 .12361 L
.38999 .12361 L
.39106 .12301 L
.3917 .12235 L
.39238 .12165 L
.3936 .12043 L
.39635 .11773 L
.40134 .11308 L
.42237 .0965 L
.442 .08486 L
.46034 .07673 L
.47079 .07309 L
.48069 .07023 L
.49925 .0662 L
.53758 .05773 L
.55696 .05272 L
.57836 .04716 L
.5881 .04471 L
.59861 .04217 L
.60344 .04105 L
.60608 .04045 L
.60736 .04016 L
.60853 .0399 L
.60961 .12361 L
.61063 .12361 L
.61287 .12361 L
.61762 .12361 L
.65609 .12361 L
.69701 .12361 L
.73641 .12361 L
.7743 .12361 L
.81464 .12361 L
.85346 .12361 L
.89474 .12361 L
Mistroke
.9345 .12361 L
.97275 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo01Ooool206KoMOooo`00Soooo`030000oooooooo
01?oool406Ko00?oool0I_ooool0M?ooo`00Soooo`030000oooooooo00ooool406Ko1Oooo`0306Ko
oooooooo07?oool008ooool200002oooo`D0I_l9oooo00<0I_ooooooool0Loooo`00Soooo`030000
oooooooo00Soool206Ko3_ooo`0306Kooooooooo07?oool008ooool00`000?ooooooo`04oooo101V
oa3oool00`1Vooooooooo`1coooo002?oooo00<0003oooooool0101VoaCoool00`1Vooooooooo`1c
oooo002=oooo0P1Vo`03000006Ko06Ko01Soool00`1Vooooooooo`1coooo002:oooo0`1Vo`;oool0
0`000?ooooooo`0Hoooo00<0I_ooooooool0Loooo`00Qoooo`<0I_l5oooo0P0001Woool00`1Voooo
ooooo`1coooo000Goooo100003Woool50000:oooo`<0I_l8oooo00<0003oooooool06?ooo`0306Ko
oooooooo01coool50000>?ooo`@0000Foooo000Goooo00<0003oooooool0??ooo`030000oooooooo
02Woool206Ko2oooo`030000oooooooo01Woool00`1Vooooooooo`0Moooo00<0003oooooool0>?oo
o`030000oooooooo01Ooool001Soool00`000?ooooooo`0koooo00<0003oooooool09oooo`80I_l=
oooo00<0003oooooool06Oooo`0306Kooooooooo01goool00`000?ooooooo`0ioooo00<0003ooooo
ool05_ooo`004Oooo`@00004oooo00<0003oooooool0<_ooo`@00004oooo00<0003oooooool09Ooo
o`80I_l?oooo00<0003oooooool06Oooo`0306Kooooooooo01goool00`000?ooooooo`0joooo00<0
003oooooool05Oooo`005oooo`040000oooooooo0000>oooo`030000oooooooo02?oool206Ko4Ooo
o`030000oooooooo01Woool00`1Vooooooooo`0Moooo00<0003oooooool0>?ooo`040000oooooooo
00005_ooo`006?ooo`80000koooo0P0002Coool00`1Vooooooooo`0Aoooo0P0001[oool00`1Voooo
ooooo`0Loooo0P0003_oool200005oooo`00N_ooo`0306Kooooooooo01;oool00`000?ooooooo`0I
oooo00<0I_ooooooool0L_ooo`00N?ooo`80I_lEoooo00<0003oooooool06Oooo`0306Kooooooooo
07;oool007Ooool00`1Vooooooooo`0Eoooo00<0003oooooool06Oooo`0306Kooooooooo07;oool0
07Koool00`1Vooooooooo`0Foooo00<0003oooooool06Oooo`0306Kooooooooo07;oool007Goool0
0`1Vooooooooo`0Goooo00<0003oooooool06Oooo`0306Kooooooooo07;oool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009
<ol000<0000co`0co`002C?o00050000<ol0<ol0<ol0o`2I00Lco`000`0003?o03?o0009<ol000<0
000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000oooooooo00Woool00`000?oo
ooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000I
<ol000?o09Tco`0co`007C?o00T0000doooo00<0003oooooool05Oooo`00Soooo`030000<ol0<ol0
01Tco`000ol0VC?o03?o000G<ol01P0005Goool008ooool00`0003?o03?o000I<ol000?o09Tco`0c
o`005C?o0080001Koooo002?oooo00<0000co`0co`006C?o0003o`2I<ol0<ol001<co`020000GOoo
o`00Soooo`030000<ol0<ol001Tco`000ol0VC?o03?o000@<ol00`0005ooool008ooool200006S?o
0003o`2I<ol0<ol000dco`030000H_ooo`00Soooo`030000<ol0<ol001Tco`000ol0VC?o03?o000;
<ol00P0006Goool008ooool00`0003?o03?o000I<ol000?o09Tco`0co`002S?o00030000oooooooo
06Goool008ooool00`0003?o03?o000I<ol000?o09Tco`0co`002C?o00030000oooooooo06Koool0
08ooool00`0003?o03?o000I<ol000?o09Tco`0co`0023?o00030000oooooooo06Ooool008ooool0
0`0003?o03?o000I<ol000?o09Tco`0co`001S?o0080001Zoooo002?oooo0P0001Xco`000ol0VC?o
03?o0005<ol000<0003oooooool0J_ooo`00Soooo`030000<ol0<ol001Tco`000ol0VC?o03?o0004
<ol000<0003oooooool0Joooo`00Soooo`030000<ol0<ol001Tco`000ol0VC?o03?o0003<ol000<0
003oooooool0K?ooo`00Soooo`030000<ol0<ol001Tco`000ol0VC?o03?o0003<ol000<0003ooooo
ool0K?ooo`00Soooo`030000<ol0<ol001Tco`000ol0VC?o03?o0002<ol000<0003oooooool0KOoo
o`00Soooo`030000<ol0<ol001Tco`001Ol0VC?o03?o03?o0000001`oooo002?oooo0P0001Xco`00
1?l0VC?o03?o0000077oool008ooool00`0003?o03?o000I<ol000?o09Tco`000000L_ooo`00Sooo
o`030000<ol0<ol001Tco`000ol0VC?o0000001boooo002?oooo00<0000co`0co`006C?o0003o`2I
0000oooo07;oool008ooool00`0003?o03?o000I<ol000?o09T0003oool0L_ooo`00Soooo`030000
<ol0<ol001Tco`000ol0VOooooooo`1boooo002?oooo0P0001Xco`000ol0VOooooooo`1boooo002?
oooo00<0000co`0co`0063?o00030000o`2Ioooo07?oool008ooool00`0003?o03?o000H<ol000<0
003o09Woool0Loooo`00Soooo`030000<ol0<ol001Lco`000`000?ooool0V@1doooo002?oooo00<0
000co`0co`005c?o00030000ooooo`2I07Coool008Ooool500000oooo`030000<ol0<ol001Hco`00
10000?ooooooool0VGCoool008Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o00040000
ooooooooo`2IM?ooo`00ROooo`030000oooooooo00?oool300005C?o00050000ooooooooooooo`2I
07Coool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00050000ooooooooooooo`2I
07Coool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00050000ooooooooooooo`2I
07Coool008Soool200001Oooo`030000<ol0<ol001@co`000`000?ooooooo`02oooo00?o09Wooooo
ool0L_ooo`00Soooo`030000<ol0<ol001@co`000`000?ooooooo`02oooo00?o09Woooooool0L_oo
o`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`03oooo00?o09Woooooool0L_ooo`00Sooo
o`80000D<ol000<0003oooooool00oooo`03o`2Ioooooooo07;oool008ooool00`0003?o03?o000C
<ol000<0003oooooool00oooo`03o`2Ioooooooo07;oool008ooool00`0003?o03?o000B<ol000<0
003oooooool01?ooo`03o`2Ioooooooo07;oool008ooool00`0003?o03?o000B<ol000<0003ooooo
ool01?ooo`03o`2Ioooooooo07;oool008ooool00`0003?o03?o000B<ol000<0003oooooool01?oo
o`03o`2Ioooooooo07;oool008ooool00`0003?o03?o000A<ol000<0003oooooool01Oooo`03o`2I
oooooooo07;oool008ooool200004S?o00030000oooooooo00Goool00ol0VOooooooo`1boooo002?
oooo00<0000co`0co`004C?o00030000oooooooo00Goool00ol0VOooooooo`1boooo002?oooo00<0
000co`0co`004C?o00030000oooooooo00Goool00ol0VOooooooo`1boooo002?oooo00<0000co`0c
o`0043?o00030000oooooooo00Koool00ol0VOooooooo`1boooo002?oooo00<0000co`0co`0043?o
00030000oooooooo00Koool00ol0VOooooooo`1boooo002?oooo00<0000co`0co`0043?o00030000
oooooooo00Koool00ol0VOooooooo`1boooo002?oooo00<0000co`0co`0043?o00030000oooooooo
00Koool00ol0VOooooooo`1boooo002?oooo0P00010co`000`000?ooooooo`07oooo00?o09Wooooo
ool0L_ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`07oooo00?o09Woooooool0L_oo
o`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`07oooo00?o09Woooooool0L_ooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`07oooo00?o09Woooooool0L_ooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`07oooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol0
00hco`000`000?ooooooo`08oooo00?o09Woooooool0L_ooo`00Soooo`80000?<ol000<0003ooooo
ool02?ooo`03o`2Ioooooooo07;oool008ooool00`0003?o03?o000><ol000<0003oooooool02?oo
o`03o`2Ioooooooo07;oool008ooool00`0003?o03?o000><ol000<0003oooooool02?ooo`03o`2I
oooooooo07;oool008ooool00`0003?o03?o000=<ol000<0003oooooool02Oooo`03o`2Ioooooooo
07;oool008Ooool400001?ooo`030000<ol0<ol000dco`000`000?ooooooo`09oooo00?o09Wooooo
ool0L_ooo`00Qoooo`030000oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool02Ooo
o`03o`2Ioooooooo07;oool008Soool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`09
oooo00?o09Woooooool0L_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0
003oooooool02Oooo`03o`2Ioooooooo07;oool008Ooool010000?ooooooo`0000Coool00`0003?o
03?o000<<ol000<0003oooooool02_ooo`03o`2Ioooooooo07;oool008Soool200001Oooo`030000
<ol0<ol000`co`000`000?ooooooo`0:oooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol0
00`co`000`000?ooooooo`0:oooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol000`co`00
0`000?ooooooo`0:oooo00?o09Woooooool0L_ooo`00Soooo`80000=<ol000<0003oooooool02_oo
o`03o`2Ioooooooo07;oool008ooool00`0003?o03?o000<<ol000<0003oooooool02_ooo`03o`2I
oooooooo07;oool008ooool00`0003?o03?o000;<ol000<0003oooooool02oooo`03o`2Ioooooooo
07;oool008ooool00`0003?o03?o000;<ol000<0003oooooool02oooo`03o`2Ioooooooo07;oool0
08ooool00`0003?o03?o000;<ol000<0003oooooool02oooo`03o`2Ioooooooo07;oool008ooool0
0`0003?o03?o000;<ol000<0003oooooool02oooo`03o`2Ioooooooo07;oool008ooool00`0003?o
03?o000;<ol000<0003oooooool02oooo`03o`2Ioooooooo07;oool008ooool2000033?o00030000
oooooooo00_oool00ol0VOooooooo`1boooo002?oooo00<0000co`0co`002c?o00030000oooooooo
00_oool00ol0VOooooooo`1boooo002?oooo00<0000co`0co`002S?o00030000oooooooo00coool0
0ol0VOooooooo`1boooo002?oooo00<0000co`0co`002S?o00030000oooooooo00coool00ol0VOoo
ooooo`1boooo002?oooo00<0000co`0co`002S?o00030000oooooooo00coool00ol0VOooooooo`1b
oooo002?oooo00<0000co`0co`002S?o00030000oooooooo00coool00ol0VOooooooo`1boooo002?
oooo0P0000/co`000`000?ooooooo`0<oooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0<oooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0<oooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol000Tco`000`000?oo
ooooo`0=oooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0=
oooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0=oooo00?o
09Woooooool0L_ooo`00Soooo`80000:<ol000<0003oooooool03Oooo`03o`2Ioooooooo07;oool0
08ooool00`0003?o03?o0009<ol000<0003oooooool03Oooo`03o`2Ioooooooo07;oool008ooool0
0`0003?o03?o0009<ol000<0003oooooool03Oooo`03o`2Ioooooooo07;oool008ooool00`0003?o
03?o0008<ol000<0003oooooool03_ooo`03o`2Ioooooooo07;oool008Soool200001Oooo`030000
<ol0<ol000Pco`000`000?ooooooo`0>oooo00?o09Woooooool0L_ooo`00Qoooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0>oooo00?o09Woooooool0L_ooo`00ROoo
o`030000oooooooo00?oool3000023?o00030000oooooooo00koool00ol0VOooooooo`1boooo002:
oooo00<0003oooooool00_ooo`030000<ol0<ol000Pco`000`000?ooooooo`0>oooo00?o09Wooooo
ool0L_ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0>
oooo00?o09Woooooool0L_ooo`00R?ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo
00ooool00ol0VOooooooo`1boooo002?oooo00<0000co`0co`001c?o00030000oooooooo00ooool0
0ol0VOooooooo`1boooo002?oooo00<0000co`0co`001c?o00030000oooooooo00ooool00ol0VOoo
ooooo`1boooo002?oooo00<0000co`0co`001c?o00030000oooooooo00ooool00ol0VOooooooo`1b
oooo002?oooo0P0000Pco`000`000?ooooooo`0?oooo00?o09Woooooool0L_ooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`0?oooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0?oooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0?oooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`0@oooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0@
oooo00?o09Woooooool0L_ooo`00Soooo`800007<ol000<0003oooooool04?ooo`03o`2Ioooooooo
07;oool008ooool00`0003?o03?o0006<ol000<0003oooooool04?ooo`03o`2Ioooooooo07;oool0
08ooool00`0003?o03?o0006<ol000<0003oooooool04?ooo`03o`2Ioooooooo07;oool008ooool0
0`0003?o03?o0006<ol000<0003oooooool04?ooo`03o`2Ioooooooo07;oool008ooool00`0003?o
03?o0006<ol000<0003oooooool04?ooo`03o`2Ioooooooo07;oool008ooool00`0003?o03?o0006
<ol000<0003oooooool04?ooo`03o`2Ioooooooo07;oool008ooool200001S?o00030000oooooooo
017oool00ol0VOooooooo`1boooo002?oooo00<0000co`0co`001C?o00030000oooooooo017oool0
0ol0VOooooooo`1boooo002?oooo00<0000co`0co`001C?o00030000oooooooo017oool00ol0VOoo
ooooo`1boooo002?oooo00<0000co`0co`001C?o00030000oooooooo017oool00ol0VOooooooo`1b
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo017oool00ol0VOooooooo`1boooo002?
oooo00<0000co`0co`001C?o00030000oooooooo017oool00ol0VOooooooo`1boooo002?oooo0P00
00Hco`000`000?ooooooo`0Aoooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`0Aoooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`0Aoooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0B
oooo00?o09Woooooool0L_ooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0Boooo00?o
09Woooooool0L_ooo`00ROooo`<00003oooo00<0000co`0co`0013?o00030000oooooooo01;oool0
0ol0VOooooooo`1boooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?oo
ooooo`0Boooo00?o09Woooooool0L_ooo`00Qoooo`D00003oooo0`0000@co`000`000?ooooooo`0B
oooo00?o09Woooooool0L_ooo`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0
003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?
oooo1c?o08[oool007Woool00`000?ooooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo00Woool7<ol03oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@00008co`02000000<c
o`3oooooool00_ooo`<000001?ooo`000000000000Coool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0000co`0c
o`001C?o00Goool010000?ooooooo`0000;oool01@000?ooooooooooo`00001joooo001goooo00<0
003oooooool00_ooo`030000oooooooo00ooool00`0003?o03?o0005<ol00_ooo`D000001Oooo`00
0?ooooooo`000004oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0
000co`0co`001C?o00;oool010000?ooooooo`0000;oool300001?ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`00000Aoooo00<0000co`0co`001C?o00?oool00`000?ooo`000003
oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P00
00Lco`04oooo0P0000?oool300000_ooo`030000oooooooo07Woool008ooool7<ol0R_ooo`00Sooo
o`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.58872 .12361 L
.59975 .12361 L
.60479 .12361 L
.60756 .12361 L
.61016 .12361 L
.6126 .12361 L
.61327 .12361 L
.61397 .12361 L
s
.61397 .12361 m
.61448 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.36136 .12361 L
.37176 .12361 L
.37685 .12361 L
.3815 .12361 L
.38384 .12361 L
.38448 .12361 L
.38517 .12361 L
.3864 .1229 L
.38766 .12161 L
.38884 .12042 L
.39106 .11824 L
.40134 .1089 L
.42237 .09337 L
.44244 .08231 L
.46092 .07479 L
.47974 .06927 L
.49043 .06694 L
.5004 .06523 L
.53931 .05708 L
.55912 .05211 L
.58067 .04665 L
.59071 .04418 L
.60137 .04165 L
.60575 .04065 L
.61047 .0396 L
.61179 .03931 L
.61251 .03915 L
.61318 .03901 L
.61436 .12361 L
.61565 .12361 L
.62052 .12361 L
.65956 .12361 L
.70106 .12361 L
.74104 .12361 L
.77951 .12361 L
.82043 .12361 L
.85983 .12361 L
.89772 .12361 L
.93806 .12361 L
.97619 .12361 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo01Soool306KoLoooo`00Soooo`030000oooooooo
01?oool506Ko0_ooo`0306Kooooooooo077oool008ooool00`000?ooooooo`0?oooo101Vo`Ooool0
0`1Vooooooooo`1aoooo002?oooo0P0000coool406Ko2oooo`0306Kooooooooo077oool008ooool0
0`000?ooooooo`09oooo0P1Vo`ooool00`1Vooooooooo`1aoooo002?oooo00<0003oooooool01Ooo
o`@0I_lAoooo00<0I_ooooooool0LOooo`00Soooo`030000oooooooo00D0I_lEoooo00<0I_oooooo
ool0LOooo`00S?ooo`<0I_l00`00001Vo`1Vo`0Joooo00<0I_ooooooool0LOooo`00R?ooo`@0I_l3
oooo00<0003oooooool06_ooo`0306Kooooooooo077oool008Coool406Ko1oooo`80000Koooo00<0
I_ooooooool0LOooo`005oooo`@0000ioooo1@0002Woool206Ko2oooo`030000oooooooo01[oool0
0`1Vooooooooo`0Joooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0Woooo0P1Vo`goool00`000?ooooooo`0Joooo00<0I_ooooooool07?ooo`030000oooooooo
03Soool00`000?ooooooo`0Goooo000Hoooo00<0003oooooool0>oooo`030000oooooooo02Goool2
06Ko3oooo`030000oooooooo01[oool00`1Vooooooooo`0Loooo00<0003oooooool0>Oooo`030000
oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool400001?ooo`030000oooooooo
02?oool206Ko4Oooo`030000oooooooo01[oool00`1Vooooooooo`0Loooo00<0003oooooool0>_oo
o`030000oooooooo01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0Roooo00<0
I_ooooooool04Oooo`030000oooooooo01[oool00`1Vooooooooo`0Loooo00<0003oooooool0>?oo
o`040000oooooooo00005_ooo`006?ooo`80000koooo0P0002?oool00`1Vooooooooo`0Boooo0P00
01_oool00`1Vooooooooo`0Koooo0P0003_oool200005oooo`00N?ooo`80I_lEoooo00<0003ooooo
ool06_ooo`0306Kooooooooo077oool007Ooool00`1Vooooooooo`0Eoooo00<0003oooooool06_oo
o`0306Kooooooooo077oool007Koool00`1Vooooooooo`0Foooo00<0003oooooool06_ooo`0306Ko
oooooooo077oool007Coool206Ko6Oooo`030000oooooooo01[oool00`1Vooooooooo`1aoooo001c
oooo00<0I_ooooooool06Oooo`030000oooooooo01[oool00`1Vooooooooo`1aoooo000@ooooo`00
017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0002<ol000?o09Tco`0co`0013?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0003ooooo
ool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Ooo
o`030000<ol0<ol001Xco`000ol0VC?o03?o000L<ol02@0003Coool00`000?ooooooo`0Eoooo002?
oooo00<0000co`0co`006S?o0003o`2I<ol0<ol001Hco`060000EOooo`00Soooo`030000<ol0<ol0
01Xco`000ol0VC?o03?o000D<ol00P0005_oool008ooool00`0003?o03?o000J<ol000?o09Tco`0c
o`004S?o0080001Moooo002?oooo00<0000co`0co`006S?o0003o`2I<ol0<ol000lco`030000Gooo
o`00Soooo`80000K<ol000?o09Tco`0co`0033?o00<0001Roooo002?oooo00<0000co`0co`006S?o
0003o`2I<ol0<ol000Xco`020000IOooo`00Soooo`030000<ol0<ol001Xco`000ol0VC?o03?o0009
<ol000<0003oooooool0IOooo`00Soooo`030000<ol0<ol001Xco`000ol0VC?o03?o0008<ol000<0
003oooooool0I_ooo`00Soooo`030000<ol0<ol001Xco`000ol0VC?o03?o0007<ol000<0003ooooo
ool0Ioooo`00Soooo`030000<ol0<ol001Xco`000ol0VC?o03?o0005<ol00P0006[oool008ooool2
00006c?o0003o`2I<ol0<ol000@co`000`000?ooooooo`1Zoooo002?oooo00<0000co`0co`006S?o
0003o`2I<ol0<ol000<co`000`000?ooooooo`1[oooo002?oooo00<0000co`0co`006S?o0003o`2I
<ol0<ol0008co`000`000?ooooooo`1/oooo002?oooo00<0000co`0co`006S?o0003o`2I<ol0<ol0
008co`000`000?ooooooo`1/oooo002?oooo00<0000co`0co`006S?o0005o`2I<ol0<ol0<ol00000
06ooool008ooool00`0003?o03?o000J<ol000Co09Tco`0co`00001`oooo002?oooo0P0001/co`00
0ol0VC?o0000001aoooo002?oooo00<0000co`0co`006S?o0003o`2I0000oooo077oool008ooool0
0`0003?o03?o000J<ol000?o09T0003oool0LOooo`00Soooo`030000<ol0<ol001Xco`000ol0VOoo
ooooo`1aoooo002?oooo00<0000co`0co`006S?o0003o`2Ioooooooo077oool008ooool00`0003?o
03?o000I<ol000<0003o09Woool0L_ooo`00Soooo`80000J<ol000<0003o09Woool0L_ooo`00Sooo
o`030000<ol0<ol001Pco`000`000?ooool0V@1coooo002?oooo00<0000co`0co`0063?o00030000
ooooo`2I07?oool008ooool00`0003?o03?o000G<ol000@0003ooooooooo09Ucoooo002?oooo00<0
000co`0co`005c?o00040000ooooooooo`2ILoooo`00Qoooo`D00003oooo00<0000co`0co`005S?o
00050000ooooooooooooo`2I07?oool008Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o
00050000ooooooooooooo`2I07?oool008Woool00`000?ooooooo`03oooo0`0001Dco`000`000?oo
ooooo`02oooo00?o09Woooooool0LOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E
<ol000<0003oooooool00_ooo`03o`2Ioooooooo077oool008Woool00`000?ooooooo`03oooo00<0
000co`0co`005C?o00030000oooooooo00;oool00ol0VOooooooo`1aoooo0028oooo0P0000Goool0
0`0003?o03?o000D<ol000<0003oooooool00oooo`03o`2Ioooooooo077oool008ooool00`0003?o
03?o000D<ol000<0003oooooool00oooo`03o`2Ioooooooo077oool008ooool00`0003?o03?o000C
<ol000<0003oooooool01?ooo`03o`2Ioooooooo077oool008ooool2000053?o00030000oooooooo
00Coool00ol0VOooooooo`1aoooo002?oooo00<0000co`0co`004c?o00030000oooooooo00Coool0
0ol0VOooooooo`1aoooo002?oooo00<0000co`0co`004S?o00030000oooooooo00Goool00ol0VOoo
ooooo`1aoooo002?oooo00<0000co`0co`004S?o00030000oooooooo00Goool00ol0VOooooooo`1a
oooo002?oooo00<0000co`0co`004S?o00030000oooooooo00Goool00ol0VOooooooo`1aoooo002?
oooo00<0000co`0co`004C?o00030000oooooooo00Koool00ol0VOooooooo`1aoooo002?oooo0P00
018co`000`000?ooooooo`06oooo00?o09Woooooool0LOooo`00Soooo`030000<ol0<ol0014co`00
0`000?ooooooo`06oooo00?o09Woooooool0LOooo`00Soooo`030000<ol0<ol0014co`000`000?oo
ooooo`06oooo00?o09Woooooool0LOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`07
oooo00?o09Woooooool0LOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`07oooo00?o
09Woooooool0LOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`07oooo00?o09Wooooo
ool0LOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`07oooo00?o09Woooooool0LOoo
o`00Soooo`80000@<ol000<0003oooooool02?ooo`03o`2Ioooooooo077oool008ooool00`0003?o
03?o000?<ol000<0003oooooool02?ooo`03o`2Ioooooooo077oool008ooool00`0003?o03?o000?
<ol000<0003oooooool02?ooo`03o`2Ioooooooo077oool008ooool00`0003?o03?o000?<ol000<0
003oooooool02?ooo`03o`2Ioooooooo077oool008ooool00`0003?o03?o000?<ol000<0003ooooo
ool02?ooo`03o`2Ioooooooo077oool008ooool00`0003?o03?o000><ol000<0003oooooool02Ooo
o`03o`2Ioooooooo077oool008ooool200003c?o00030000oooooooo00Woool00ol0VOooooooo`1a
oooo002?oooo00<0000co`0co`003S?o00030000oooooooo00Woool00ol0VOooooooo`1aoooo002?
oooo00<0000co`0co`003S?o00030000oooooooo00Woool00ol0VOooooooo`1aoooo002?oooo00<0
000co`0co`003C?o00030000oooooooo00[oool00ol0VOooooooo`1aoooo0027oooo100000Coool0
0`0003?o03?o000=<ol000<0003oooooool02_ooo`03o`2Ioooooooo077oool008Ooool00`000?oo
ooooo`05oooo00<0000co`0co`003C?o00030000oooooooo00[oool00ol0VOooooooo`1aoooo0028
oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool02_ooo`03o`2Ioooooooo077oool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo00[oool00ol0VOoo
ooooo`1aoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0033?o00030000oooooooo
00_oool00ol0VOooooooo`1aoooo0028oooo0P0000Goool00`0003?o03?o000<<ol000<0003ooooo
ool02oooo`03o`2Ioooooooo077oool008ooool00`0003?o03?o000<<ol000<0003oooooool02ooo
o`03o`2Ioooooooo077oool008ooool00`0003?o03?o000<<ol000<0003oooooool02oooo`03o`2I
oooooooo077oool008ooool200003C?o00030000oooooooo00_oool00ol0VOooooooo`1aoooo002?
oooo00<0000co`0co`0033?o00030000oooooooo00_oool00ol0VOooooooo`1aoooo002?oooo00<0
000co`0co`002c?o00030000oooooooo00coool00ol0VOooooooo`1aoooo002?oooo00<0000co`0c
o`002c?o00030000oooooooo00coool00ol0VOooooooo`1aoooo002?oooo00<0000co`0co`002c?o
00030000oooooooo00coool00ol0VOooooooo`1aoooo002?oooo00<0000co`0co`002c?o00030000
oooooooo00coool00ol0VOooooooo`1aoooo002?oooo00<0000co`0co`002c?o00030000oooooooo
00coool00ol0VOooooooo`1aoooo002?oooo0P0000`co`000`000?ooooooo`0<oooo00?o09Wooooo
ool0LOooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0<oooo00?o09Woooooool0LOoo
o`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0=oooo00?o09Woooooool0LOooo`00Sooo
o`030000<ol0<ol000Xco`000`000?ooooooo`0=oooo00?o09Woooooool0LOooo`00Soooo`030000
<ol0<ol000Xco`000`000?ooooooo`0=oooo00?o09Woooooool0LOooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0=oooo00?o09Woooooool0LOooo`00Soooo`80000;<ol000<0003ooooo
ool03Oooo`03o`2Ioooooooo077oool008ooool00`0003?o03?o000:<ol000<0003oooooool03Ooo
o`03o`2Ioooooooo077oool008ooool00`0003?o03?o000:<ol000<0003oooooool03Oooo`03o`2I
oooooooo077oool008ooool00`0003?o03?o0009<ol000<0003oooooool03_ooo`03o`2Ioooooooo
077oool008ooool00`0003?o03?o0009<ol000<0003oooooool03_ooo`03o`2Ioooooooo077oool0
08ooool00`0003?o03?o0009<ol000<0003oooooool03_ooo`03o`2Ioooooooo077oool008ooool2
00002S?o00030000oooooooo00koool00ol0VOooooooo`1aoooo002?oooo00<0000co`0co`002C?o
00030000oooooooo00koool00ol0VOooooooo`1aoooo002?oooo00<0000co`0co`002C?o00030000
oooooooo00koool00ol0VOooooooo`1aoooo002?oooo00<0000co`0co`0023?o00030000oooooooo
00ooool00ol0VOooooooo`1aoooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0003ooooo
ool03oooo`03o`2Ioooooooo077oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008
<ol000<0003oooooool03oooo`03o`2Ioooooooo077oool008Woool00`000?ooooooo`03oooo0`00
00Pco`000`000?ooooooo`0?oooo00?o09Woooooool0LOooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o0008<ol000<0003oooooool03oooo`03o`2Ioooooooo077oool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool03oooo`03o`2Ioooooooo077oool0
08Soool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`0@oooo00?o09Woooooool0LOoo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0@oooo00?o09Woooooool0LOooo`00Sooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0@oooo00?o09Woooooool0LOooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`0@oooo00?o09Woooooool0LOooo`00Soooo`800008<ol000<0
003oooooool04?ooo`03o`2Ioooooooo077oool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool04?ooo`03o`2Ioooooooo077oool008ooool00`0003?o03?o0007<ol000<0003oooooool04?oo
o`03o`2Ioooooooo077oool008ooool00`0003?o03?o0007<ol000<0003oooooool04?ooo`03o`2I
oooooooo077oool008ooool00`0003?o03?o0006<ol000<0003oooooool04Oooo`03o`2Ioooooooo
077oool008ooool00`0003?o03?o0006<ol000<0003oooooool04Oooo`03o`2Ioooooooo077oool0
08ooool200001c?o00030000oooooooo017oool00ol0VOooooooo`1aoooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo017oool00ol0VOooooooo`1aoooo002?oooo00<0000co`0co`001S?o
00030000oooooooo017oool00ol0VOooooooo`1aoooo002?oooo00<0000co`0co`001S?o00030000
oooooooo017oool00ol0VOooooooo`1aoooo002?oooo00<0000co`0co`001S?o00030000oooooooo
017oool00ol0VOooooooo`1aoooo002?oooo00<0000co`0co`001S?o00030000oooooooo017oool0
0ol0VOooooooo`1aoooo002?oooo0P0000Hco`000`000?ooooooo`0Boooo00?o09Woooooool0LOoo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Boooo00?o09Woooooool0LOooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`0Boooo00?o09Woooooool0LOooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`0Boooo00?o09Woooooool0LOooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`0Boooo00?o09Woooooool0LOooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`0Boooo00?o09Woooooool0LOooo`00Soooo`800006<ol000<0003oooooool04_oo
o`03o`2Ioooooooo077oool008ooool00`0003?o03?o0005<ol000<0003oooooool04_ooo`03o`2I
oooooooo077oool008ooool00`0003?o03?o0005<ol000<0003oooooool04_ooo`03o`2Ioooooooo
077oool008ooool00`0003?o03?o0004<ol000<0003oooooool04oooo`03o`2Ioooooooo077oool0
08ooool00`0003?o03?o0004<ol000<0003oooooool04oooo`03o`2Ioooooooo077oool008Woool3
00000oooo`030000<ol0<ol000@co`000`000?ooooooo`0Coooo00?o09Woooooool0LOooo`00R_oo
o`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool04oooo`03o`2Ioooooooo
077oool008Ooool500000oooo`<00004<ol000<0003oooooool04oooo`03o`2Ioooooooo077oool0
08Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_oo
o`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0
003oooooool04oooo`Lco`0>oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool0
0`000?ooooooo`09oooo1c?o00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01_ooo`D00002<ol00P000003<ol0oooooooo00;oool300000_oo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01oooo`030000<ol0<ol000Dco`05oooo00@0003oooooool00002
oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0?
oooo00<0000co`0co`001C?o00;oool5000000Goool0003oooooool000001?ooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500003_ooo`030000<ol0<ol000Dco`02oooo00@0003ooooo
ool00003oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000004Ooo
o`030000<ol0<ol000Dco`03oooo00<0003oool000000_ooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`04oooo0P0000?oool200000ooo
o`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.58872 .12361 L
.59975 .12361 L
.60479 .12361 L
.61016 .12361 L
.61278 .12361 L
.61524 .12361 L
.61745 .12361 L
.61869 .12361 L
s
.61869 .12361 m
.61915 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.36173 .12361 L
.37114 .12361 L
.37372 .12361 L
.37649 .12361 L
.37783 .12361 L
.3791 .12361 L
.38025 .12361 L
.3815 .12304 L
.38215 .12238 L
.38283 .12168 L
.38405 .12045 L
.38681 .11774 L
.39182 .11307 L
.40117 .10512 L
.42214 .09057 L
.44178 .08044 L
.46012 .07346 L
.47057 .07039 L
.48047 .068 L
.49902 .06474 L
.53735 .0574 L
.57814 .04741 L
.59839 .04252 L
.60831 .04025 L
.61265 .0393 L
.61495 .0388 L
.61621 .03853 L
.6174 .03828 L
.61856 .03804 L
.6198 .12361 L
.62094 .12361 L
.62199 .12361 L
.62625 .12361 L
.63557 .12361 L
.65515 .12361 L
.69456 .12361 L
.73244 .12361 L
.77278 .12361 L
.81161 .12361 L
.85288 .12361 L
Mistroke
.89265 .12361 L
.93089 .12361 L
.97159 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo01Soool406KoL_ooo`00Soooo`030000oooooooo
01Coool406Ko0oooo`0306Kooooooooo073oool008ooool00`000?ooooooo`0@oooo101Vo`Ooool0
0`1Vooooooooo`1`oooo002?oooo0P0000goool406Ko2oooo`0306Kooooooooo073oool008ooool0
0`000?ooooooo`08oooo101Vo`ooool00`1Vooooooooo`1`oooo002?oooo00<0003oooooool00_oo
o`H0I_lCoooo00<0I_ooooooool0L?ooo`00SOooo`80I_l00`00001Vo`1Vo`0206Ko6Oooo`0306Ko
oooooooo073oool008[oool306Ko0_ooo`030000oooooooo01_oool00`1Vooooooooo`1`oooo0027
oooo0`1Vo`Goool00`000?ooooooo`0Koooo00<0I_ooooooool0L?ooo`00Poooo`@0I_l8oooo0P00
01coool00`1Vooooooooo`1`oooo000Goooo100003Woool500009oooo`<0I_l<oooo00<0003ooooo
ool06oooo`0306Kooooooooo01Woool50000>?ooo`@0000Foooo000Goooo00<0003oooooool0??oo
o`030000oooooooo02Goool206Ko3oooo`030000oooooooo01_oool00`1Vooooooooo`0Koooo00<0
003oooooool0>?ooo`030000oooooooo01Ooool001Soool00`000?ooooooo`0koooo00<0003ooooo
ool08oooo`80I_lAoooo00<0003oooooool06oooo`0306Kooooooooo01_oool00`000?ooooooo`0i
oooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool0<_ooo`@00004oooo00<0
003oooooool08_ooo`0306Kooooooooo017oool00`000?ooooooo`0Koooo00<0I_ooooooool06ooo
o`030000oooooooo03[oool00`000?ooooooo`0Eoooo000Goooo00@0003oooooool0000koooo00<0
003oooooool08Oooo`0306Kooooooooo01;oool00`000?ooooooo`0Koooo00<0I_ooooooool06ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>oooo`80000Qoooo0P1V
oaGoool200007?ooo`0306Kooooooooo01[oool20000>oooo`80000Goooo001goooo00<0I_oooooo
ool05Oooo`030000oooooooo01_oool00`1Vooooooooo`1`oooo001foooo00<0I_ooooooool05_oo
o`030000oooooooo01_oool00`1Vooooooooo`1`oooo001eoooo00<0I_ooooooool05oooo`030000
oooooooo01_oool00`1Vooooooooo`1`oooo001doooo00<0I_ooooooool06?ooo`030000oooooooo
01_oool00`1Vooooooooo`1`oooo001boooo0P1Voa_oool00`000?ooooooo`0Koooo00<0I_oooooo
ool0L?ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`000c?o0003o`2I
<ol0<ol000<co`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R
00001_ooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_oo
o`030000oooooooo03Woool00`0003?o03?o000K<ol000?o09Tco`0co`006c?o00T0000doooo00<0
003oooooool05Oooo`00Soooo`030000<ol0<ol001/co`000ol0VC?o03?o000E<ol01P0005Goool0
08ooool00`0003?o03?o000K<ol000?o09Tco`0co`004c?o0080001Koooo002?oooo00<0000co`0c
o`006c?o0003o`2I<ol0<ol0014co`020000GOooo`00Soooo`030000<ol0<ol001/co`000ol0VC?o
03?o000><ol00`0005ooool008ooool2000073?o0003o`2I<ol0<ol000/co`030000H_ooo`00Sooo
o`030000<ol0<ol001/co`000ol0VC?o03?o0009<ol00P0006Goool008ooool00`0003?o03?o000K
<ol000?o09Tco`0co`0023?o00030000oooooooo06Goool008ooool00`0003?o03?o000K<ol000?o
09Tco`0co`001c?o00030000oooooooo06Koool008ooool00`0003?o03?o000K<ol000?o09Tco`0c
o`001S?o00030000oooooooo06Ooool008ooool00`0003?o03?o000K<ol000?o09Tco`0co`0013?o
0080001Zoooo002?oooo0P0001`co`000ol0VC?o03?o0003<ol000<0003oooooool0J_ooo`00Sooo
o`030000<ol0<ol001/co`000ol0VC?o03?o0002<ol000<0003oooooool0Joooo`00Soooo`030000
<ol0<ol001/co`001Ol0VC?o03?o03?o0000001^oooo002?oooo00<0000co`0co`006c?o0005o`2I
<ol0<ol0<ol0000006koool008ooool00`0003?o03?o000K<ol000Co09Tco`0co`00001_oooo002?
oooo00<0000co`0co`006c?o0003o`2I<ol00000073oool008ooool2000073?o0003o`2I0000oooo
073oool008ooool00`0003?o03?o000K<ol000?o09Woooooool0L?ooo`00Soooo`030000<ol0<ol0
01/co`000ol0VOooooooo`1`oooo002?oooo00<0000co`0co`006S?o00030000o`2Ioooo077oool0
08ooool00`0003?o03?o000J<ol000<0003o09Woool0LOooo`00Soooo`030000<ol0<ol001Tco`00
0`000?ooool0V@1boooo002?oooo0P0001Xco`000`000?ooool0V@1boooo002?oooo00<0000co`0c
o`0063?o00040000ooooooooo`2IL_ooo`00Soooo`030000<ol0<ol001Pco`0010000?ooooooool0
VG;oool008ooool00`0003?o03?o000G<ol000D0003ooooooooooooo09T0L_ooo`00Soooo`030000
<ol0<ol001Lco`001@000?ooooooooooool0V@1boooo0027oooo1@0000?oool00`0003?o03?o000F
<ol000<0003oooooool00_ooo`03o`2Ioooooooo073oool008Woool00`000?ooooooo`03oooo00<0
000co`0co`005S?o00030000oooooooo00;oool00ol0VOooooooo`1`oooo0029oooo00<0003ooooo
ool00oooo`<0000E<ol000<0003oooooool00oooo`03o`2Ioooooooo073oool008Woool00`000?oo
ooooo`03oooo00<0000co`0co`005C?o00030000oooooooo00?oool00ol0VOooooooo`1`oooo0029
oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`03oooo00?o09Wooooo
ool0L?ooo`00R?ooo`800005oooo00<0000co`0co`0053?o00030000oooooooo00Coool00ol0VOoo
ooooo`1`oooo002?oooo00<0000co`0co`0053?o00030000oooooooo00Coool00ol0VOooooooo`1`
oooo002?oooo00<0000co`0co`004c?o00030000oooooooo00Goool00ol0VOooooooo`1`oooo002?
oooo0P0001@co`000`000?ooooooo`05oooo00?o09Woooooool0L?ooo`00Soooo`030000<ol0<ol0
01<co`000`000?ooooooo`05oooo00?o09Woooooool0L?ooo`00Soooo`030000<ol0<ol0018co`00
0`000?ooooooo`06oooo00?o09Woooooool0L?ooo`00Soooo`030000<ol0<ol0018co`000`000?oo
ooooo`06oooo00?o09Woooooool0L?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`06
oooo00?o09Woooooool0L?ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`07oooo00?o
09Woooooool0L?ooo`00Soooo`80000B<ol000<0003oooooool01oooo`03o`2Ioooooooo073oool0
08ooool00`0003?o03?o000A<ol000<0003oooooool01oooo`03o`2Ioooooooo073oool008ooool0
0`0003?o03?o000A<ol000<0003oooooool01oooo`03o`2Ioooooooo073oool008ooool00`0003?o
03?o000@<ol000<0003oooooool02?ooo`03o`2Ioooooooo073oool008ooool00`0003?o03?o000@
<ol000<0003oooooool02?ooo`03o`2Ioooooooo073oool008ooool00`0003?o03?o000@<ol000<0
003oooooool02?ooo`03o`2Ioooooooo073oool008ooool00`0003?o03?o000@<ol000<0003ooooo
ool02?ooo`03o`2Ioooooooo073oool008ooool2000043?o00030000oooooooo00Woool00ol0VOoo
ooooo`1`oooo002?oooo00<0000co`0co`003c?o00030000oooooooo00Woool00ol0VOooooooo`1`
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo00Woool00ol0VOooooooo`1`oooo002?
oooo00<0000co`0co`003c?o00030000oooooooo00Woool00ol0VOooooooo`1`oooo002?oooo00<0
000co`0co`003c?o00030000oooooooo00Woool00ol0VOooooooo`1`oooo002?oooo00<0000co`0c
o`003S?o00030000oooooooo00[oool00ol0VOooooooo`1`oooo002?oooo0P0000lco`000`000?oo
ooooo`0:oooo00?o09Woooooool0L?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0:
oooo00?o09Woooooool0L?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0:oooo00?o
09Woooooool0L?ooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`0;oooo00?o09Wooooo
ool0L?ooo`00Qoooo`@00004oooo00<0000co`0co`003C?o00030000oooooooo00_oool00ol0VOoo
ooooo`1`oooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`0;
oooo00?o09Woooooool0L?ooo`00R?ooo`030000oooooooo00Coool300003C?o00030000oooooooo
00_oool00ol0VOooooooo`1`oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000dco`00
0`000?ooooooo`0;oooo00?o09Woooooool0L?ooo`00Qoooo`040000oooooooo00001?ooo`030000
<ol0<ol000`co`000`000?ooooooo`0<oooo00?o09Woooooool0L?ooo`00R?ooo`800005oooo00<0
000co`0co`0033?o00030000oooooooo00coool00ol0VOooooooo`1`oooo002?oooo00<0000co`0c
o`0033?o00030000oooooooo00coool00ol0VOooooooo`1`oooo002?oooo00<0000co`0co`0033?o
00030000oooooooo00coool00ol0VOooooooo`1`oooo002?oooo0P0000dco`000`000?ooooooo`0<
oooo00?o09Woooooool0L?ooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0<oooo00?o
09Woooooool0L?ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0=oooo00?o09Wooooo
ool0L?ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0=oooo00?o09Woooooool0L?oo
o`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0=oooo00?o09Woooooool0L?ooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`0=oooo00?o09Woooooool0L?ooo`00Soooo`030000
<ol0<ol000/co`000`000?ooooooo`0=oooo00?o09Woooooool0L?ooo`00Soooo`80000<<ol000<0
003oooooool03Oooo`03o`2Ioooooooo073oool008ooool00`0003?o03?o000;<ol000<0003ooooo
ool03Oooo`03o`2Ioooooooo073oool008ooool00`0003?o03?o000:<ol000<0003oooooool03_oo
o`03o`2Ioooooooo073oool008ooool00`0003?o03?o000:<ol000<0003oooooool03_ooo`03o`2I
oooooooo073oool008ooool00`0003?o03?o000:<ol000<0003oooooool03_ooo`03o`2Ioooooooo
073oool008ooool00`0003?o03?o000:<ol000<0003oooooool03_ooo`03o`2Ioooooooo073oool0
08ooool200002c?o00030000oooooooo00koool00ol0VOooooooo`1`oooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo00koool00ol0VOooooooo`1`oooo002?oooo00<0000co`0co`002S?o
00030000oooooooo00koool00ol0VOooooooo`1`oooo002?oooo00<0000co`0co`002C?o00030000
oooooooo00ooool00ol0VOooooooo`1`oooo002?oooo00<0000co`0co`002C?o00030000oooooooo
00ooool00ol0VOooooooo`1`oooo002?oooo00<0000co`0co`002C?o00030000oooooooo00ooool0
0ol0VOooooooo`1`oooo002?oooo0P0000Xco`000`000?ooooooo`0?oooo00?o09Woooooool0L?oo
o`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0?oooo00?o09Woooooool0L?ooo`00Sooo
o`030000<ol0<ol000Tco`000`000?ooooooo`0?oooo00?o09Woooooool0L?ooo`00Soooo`030000
<ol0<ol000Pco`000`000?ooooooo`0@oooo00?o09Woooooool0L?ooo`00R?ooo`800005oooo00<0
000co`0co`0023?o00030000oooooooo013oool00ol0VOooooooo`1`oooo0027oooo00@0003ooooo
ool00004oooo00<0000co`0co`0023?o00030000oooooooo013oool00ol0VOooooooo`1`oooo0029
oooo00<0003oooooool00oooo`<00008<ol000<0003oooooool04?ooo`03o`2Ioooooooo073oool0
08[oool00`000?ooooooo`02oooo00<0000co`0co`0023?o00030000oooooooo013oool00ol0VOoo
ooooo`1`oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo
013oool00ol0VOooooooo`1`oooo0028oooo0P0000Goool00`0003?o03?o0007<ol000<0003ooooo
ool04Oooo`03o`2Ioooooooo073oool008ooool00`0003?o03?o0007<ol000<0003oooooool04Ooo
o`03o`2Ioooooooo073oool008ooool00`0003?o03?o0007<ol000<0003oooooool04Oooo`03o`2I
oooooooo073oool008ooool00`0003?o03?o0007<ol000<0003oooooool04Oooo`03o`2Ioooooooo
073oool008ooool2000023?o00030000oooooooo017oool00ol0VOooooooo`1`oooo002?oooo00<0
000co`0co`001c?o00030000oooooooo017oool00ol0VOooooooo`1`oooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo017oool00ol0VOooooooo`1`oooo002?oooo00<0000co`0co`001c?o
00030000oooooooo017oool00ol0VOooooooo`1`oooo002?oooo00<0000co`0co`001S?o00030000
oooooooo01;oool00ol0VOooooooo`1`oooo002?oooo00<0000co`0co`001S?o00030000oooooooo
01;oool00ol0VOooooooo`1`oooo002?oooo0P0000Lco`000`000?ooooooo`0Boooo00?o09Wooooo
ool0L?ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0Boooo00?o09Woooooool0L?oo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0Boooo00?o09Woooooool0L?ooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`0Boooo00?o09Woooooool0L?ooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`0Boooo00?o09Woooooool0L?ooo`00Soooo`030000<ol0<ol0
00Hco`000`000?ooooooo`0Boooo00?o09Woooooool0L?ooo`00Soooo`800006<ol000<0003ooooo
ool04oooo`03o`2Ioooooooo073oool008ooool00`0003?o03?o0005<ol000<0003oooooool04ooo
o`03o`2Ioooooooo073oool008ooool00`0003?o03?o0005<ol000<0003oooooool04oooo`03o`2I
oooooooo073oool008ooool00`0003?o03?o0005<ol000<0003oooooool04oooo`03o`2Ioooooooo
073oool008ooool00`0003?o03?o0005<ol000<0003oooooool04oooo`03o`2Ioooooooo073oool0
08ooool00`0003?o03?o0005<ol000<0003oooooool04oooo`03o`2Ioooooooo073oool008ooool2
00001S?o00030000oooooooo01?oool00ol0VOooooooo`1`oooo002?oooo00<0000co`0co`001C?o
00030000oooooooo01?oool00ol0VOooooooo`1`oooo002?oooo00<0000co`0co`001C?o00030000
oooooooo01?oool00ol0VOooooooo`1`oooo002?oooo00<0000co`0co`0013?o00030000oooooooo
01Coool00ol0VOooooooo`1`oooo002?oooo00<0000co`0co`0013?o00030000oooooooo01Coool0
0ol0VOooooooo`1`oooo0029oooo0`0000?oool00`0003?o03?o0004<ol000<0003oooooool05?oo
o`03o`2Ioooooooo073oool008[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o00030000
oooooooo01Coool00ol0VOooooooo`1`oooo0027oooo1@0000?oool3000013?o00030000oooooooo
01Coool00ol0VOooooooo`1`oooo0027oooo00@0003oooooool00004oooo1c?o08[oool008Soool0
0`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o08[oool0
08ooool7<ol0R_ooo`00O?ooo`030000oooooooo013oool7<ol02oooo`030000oooooooo07coool0
07_oool00`000?ooooooo`08oooo00<0003oooooool01_ooo`Lco`0<oooo00<0003oooooool0Nooo
o`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000S?o00800004
oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo0S?o00030000<ol0<ol0008co`05oooo00@0003ooooo
ool00003oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0=
oooo0S?o00030000<ol0<ol0008co`08oooo00<0003oooooool00_ooo`030000oooooooo07[oool0
07_oool00`000?ooooooo`0500003?ooo`8co`000`0003?o03?o0002<ol01_ooo`800004oooo00<0
003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool2<ol000<0000co`0co`000S?o
00Koool00`000?ooooooo`03oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo013oool0
0c?o000000000004<ol01_ooo`<00002oooo00<0003oooooool0O?ooo`00Soooo`Lco`2:oooo002?
oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.52) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.60873 .12361 L
.61445 .12361 L
.61726 .12361 L
.61984 .12361 L
.62236 .12361 L
.62363 .12361 L
s
.62363 .12361 m
.62392 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.36173 .12361 L
.36626 .12361 L
.37114 .12361 L
.37257 .12361 L
.37393 .12361 L
.37515 .12361 L
.37585 .12361 L
.37649 .1233 L
.37776 .12199 L
.37891 .12083 L
.3815 .11828 L
.40237 .10055 L
.42157 .08815 L
.44031 .07902 L
.44987 .07532 L
.46012 .07198 L
.47039 .06922 L
.47975 .06717 L
.49809 .06424 L
.53793 .05717 L
.57626 .04804 L
.59565 .04339 L
.60594 .04102 L
.61135 .03981 L
.61705 .03858 L
.61948 .03807 L
.62209 .03753 L
.62286 .03737 L
.62359 .03722 L
.62424 .12361 L
.62495 .12361 L
.62761 .12361 L
.6373 .12361 L
.65631 .12361 L
.69723 .12361 L
.73663 .12361 L
.77452 .12361 L
.81486 .12361 L
.85368 .12361 L
.89496 .12361 L
Mistroke
.93472 .12361 L
.97297 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.52) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool07?ooo`0306Kooooooooo06ooool008ooool00`000?ooooooo`0Goooo1P1Vog7oool0
08ooool00`000?ooooooo`0Coooo101Vo`Goool00`1Vooooooooo`1_oooo002?oooo00<0003ooooo
ool03oooo`@0I_l9oooo00<0I_ooooooool0Koooo`00Soooo`80000=oooo0`1Vo`goool00`1Voooo
ooooo`1_oooo002?oooo00<0003oooooool02Oooo`<0I_l@oooo00<0I_ooooooool0Koooo`00Sooo
o`030000oooooooo00;oool706Ko4oooo`0306Kooooooooo06ooool008goool206Ko00<00000I_l0
I_l00P1Voa[oool00`1Vooooooooo`1_oooo0029oooo101Vo`;oool00`000?ooooooo`0Loooo00<0
I_ooooooool0Koooo`00Q?ooo`D0I_l6oooo00<0003oooooool07?ooo`0306Kooooooooo06ooool0
08;oool206Ko2oooo`80000Moooo00<0I_ooooooool0Koooo`005oooo`@0000ioooo1@0002Koool3
06Ko3Oooo`030000oooooooo01coool00`1Vooooooooo`0Hoooo1@0003Soool400005_ooo`005ooo
o`030000oooooooo03coool00`000?ooooooo`0Toooo0P1Voa3oool00`000?ooooooo`0Loooo00<0
I_ooooooool06_ooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000Hoooo00<0003ooooo
ool0>oooo`030000oooooooo02;oool206Ko4_ooo`030000oooooooo01coool00`1Vooooooooo`0J
oooo00<0003oooooool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo
03;oool400001?ooo`030000oooooooo027oool00`1Vooooooooo`0Boooo00<0003oooooool07?oo
o`0306Kooooooooo01[oool00`000?ooooooo`0joooo00<0003oooooool05Oooo`005oooo`040000
oooooooo0000>oooo`030000oooooooo01ooool206Ko5Oooo`030000oooooooo01coool00`1Voooo
ooooo`0Joooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`80000koooo0P00
023oool00`1Vooooooooo`0Eoooo0P0001goool00`1Vooooooooo`0Ioooo0P0003_oool200005ooo
o`00M_ooo`0306Kooooooooo01Koool00`000?ooooooo`0Loooo00<0I_ooooooool0Koooo`00MOoo
o`0306Kooooooooo01Ooool00`000?ooooooo`0Loooo00<0I_ooooooool0Koooo`00Loooo`80I_lJ
oooo00<0003oooooool07?ooo`0306Kooooooooo06ooool007;oool00`1Vooooooooo`0Joooo00<0
003oooooool07?ooo`0306Kooooooooo06ooool0077oool00`1Vooooooooo`0Koooo00<0003ooooo
ool07?ooo`0306Kooooooooo06ooool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000@co`000ol0VC?o03?o0002<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0006<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_oo
o`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`0073?o0003o`2I<ol0<ol0
01Xco`090000=?ooo`030000oooooooo01Goool008ooool00`0003?o03?o000L<ol000?o09Tco`0c
o`0053?o00H0001Eoooo002?oooo00<0000co`0co`0073?o0003o`2I<ol0<ol0018co`020000Fooo
o`00Soooo`030000<ol0<ol001`co`000ol0VC?o03?o000@<ol00P0005goool008ooool00`0003?o
03?o000L<ol000?o09Tco`0co`003C?o00<0001Ooooo002?oooo0P0001dco`000ol0VC?o03?o000:
<ol00`0006;oool008ooool00`0003?o03?o000L<ol000?o09Tco`0co`0023?o0080001Uoooo002?
oooo00<0000co`0co`0073?o0003o`2I<ol0<ol000Lco`000`000?ooooooo`1Uoooo002?oooo00<0
000co`0co`0073?o0003o`2I<ol0<ol000Hco`000`000?ooooooo`1Voooo002?oooo00<0000co`0c
o`0073?o0003o`2I<ol0<ol000Dco`000`000?ooooooo`1Woooo002?oooo00<0000co`0co`0073?o
0003o`2I<ol0<ol000<co`020000J_ooo`00Soooo`80000M<ol000?o09Tco`0co`000S?o00030000
oooooooo06[oool008ooool00`0003?o03?o000L<ol000Go09Tco`0co`0co`000000KOooo`00Sooo
o`030000<ol0<ol001`co`001?l0VC?o03?o000006koool008ooool00`0003?o03?o000L<ol000Co
09Tco`0co`00001^oooo002?oooo00<0000co`0co`0073?o0003o`2I<ol0000006ooool008ooool0
0`0003?o03?o000L<ol000?o09T0003oool0Koooo`00Soooo`80000M<ol000?o09Woooooool0Kooo
o`00Soooo`030000<ol0<ol001/co`000`000?l0VOooo`1`oooo002?oooo00<0000co`0co`006c?o
00030000o`2Ioooo073oool008ooool00`0003?o03?o000J<ol000<0003ooooo09T0LOooo`00Sooo
o`030000<ol0<ol001Xco`000`000?ooool0V@1aoooo002?oooo00<0000co`0co`006C?o00040000
ooooooooo`2ILOooo`00Soooo`80000J<ol000@0003ooooooooo09Uaoooo002?oooo00<0000co`0c
o`0063?o00050000ooooooooooooo`2I077oool008ooool00`0003?o03?o000H<ol000D0003ooooo
oooooooo09T0LOooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`02oooo00?o09Wooooo
ool0Koooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`02oooo00?o09Woooooool0Kooo
o`00Qoooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo00?oool00ol0VOooooooo`1_
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`03oooo00?o
09Woooooool0Koooo`00ROooo`030000oooooooo00?oool300005C?o00030000oooooooo00Coool0
0ol0VOooooooo`1_oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?oo
ooooo`04oooo00?o09Woooooool0Koooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E
<ol000<0003oooooool01?ooo`03o`2Ioooooooo06ooool008Soool200001Oooo`030000<ol0<ol0
01@co`000`000?ooooooo`05oooo00?o09Woooooool0Koooo`00Soooo`030000<ol0<ol001@co`00
0`000?ooooooo`05oooo00?o09Woooooool0Koooo`00Soooo`030000<ol0<ol001<co`000`000?oo
ooooo`06oooo00?o09Woooooool0Koooo`00Soooo`80000D<ol000<0003oooooool01_ooo`03o`2I
oooooooo06ooool008ooool00`0003?o03?o000C<ol000<0003oooooool01_ooo`03o`2Ioooooooo
06ooool008ooool00`0003?o03?o000B<ol000<0003oooooool01oooo`03o`2Ioooooooo06ooool0
08ooool00`0003?o03?o000B<ol000<0003oooooool01oooo`03o`2Ioooooooo06ooool008ooool0
0`0003?o03?o000B<ol000<0003oooooool01oooo`03o`2Ioooooooo06ooool008ooool00`0003?o
03?o000A<ol000<0003oooooool02?ooo`03o`2Ioooooooo06ooool008ooool200004S?o00030000
oooooooo00Soool00ol0VOooooooo`1_oooo002?oooo00<0000co`0co`004C?o00030000oooooooo
00Soool00ol0VOooooooo`1_oooo002?oooo00<0000co`0co`004C?o00030000oooooooo00Soool0
0ol0VOooooooo`1_oooo002?oooo00<0000co`0co`0043?o00030000oooooooo00Woool00ol0VOoo
ooooo`1_oooo002?oooo00<0000co`0co`0043?o00030000oooooooo00Woool00ol0VOooooooo`1_
oooo002?oooo00<0000co`0co`0043?o00030000oooooooo00Woool00ol0VOooooooo`1_oooo002?
oooo00<0000co`0co`0043?o00030000oooooooo00Woool00ol0VOooooooo`1_oooo002?oooo0P00
010co`000`000?ooooooo`0:oooo00?o09Woooooool0Koooo`00Soooo`030000<ol0<ol000lco`00
0`000?ooooooo`0:oooo00?o09Woooooool0Koooo`00Soooo`030000<ol0<ol000lco`000`000?oo
ooooo`0:oooo00?o09Woooooool0Koooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0:
oooo00?o09Woooooool0Koooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0:oooo00?o
09Woooooool0Koooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0;oooo00?o09Wooooo
ool0Koooo`00Soooo`80000?<ol000<0003oooooool02oooo`03o`2Ioooooooo06ooool008ooool0
0`0003?o03?o000><ol000<0003oooooool02oooo`03o`2Ioooooooo06ooool008ooool00`0003?o
03?o000><ol000<0003oooooool02oooo`03o`2Ioooooooo06ooool008ooool00`0003?o03?o000=
<ol000<0003oooooool03?ooo`03o`2Ioooooooo06ooool008Ooool400001?ooo`030000<ol0<ol0
00dco`000`000?ooooooo`0<oooo00?o09Woooooool0Koooo`00Qoooo`030000oooooooo00Goool0
0`0003?o03?o000=<ol000<0003oooooool03?ooo`03o`2Ioooooooo06ooool008Soool00`000?oo
ooooo`04oooo0`0000dco`000`000?ooooooo`0<oooo00?o09Woooooool0Koooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool03?ooo`03o`2Ioooooooo06ooool0
08Ooool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool03Oooo`03o`2I
oooooooo06ooool008Soool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`0=oooo00?o
09Woooooool0Koooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0=oooo00?o09Wooooo
ool0Koooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0=oooo00?o09Woooooool0Kooo
o`00Soooo`80000=<ol000<0003oooooool03Oooo`03o`2Ioooooooo06ooool008ooool00`0003?o
03?o000<<ol000<0003oooooool03Oooo`03o`2Ioooooooo06ooool008ooool00`0003?o03?o000;
<ol000<0003oooooool03_ooo`03o`2Ioooooooo06ooool008ooool00`0003?o03?o000;<ol000<0
003oooooool03_ooo`03o`2Ioooooooo06ooool008ooool00`0003?o03?o000;<ol000<0003ooooo
ool03_ooo`03o`2Ioooooooo06ooool008ooool00`0003?o03?o000;<ol000<0003oooooool03_oo
o`03o`2Ioooooooo06ooool008ooool00`0003?o03?o000;<ol000<0003oooooool03_ooo`03o`2I
oooooooo06ooool008ooool2000033?o00030000oooooooo00koool00ol0VOooooooo`1_oooo002?
oooo00<0000co`0co`002c?o00030000oooooooo00koool00ol0VOooooooo`1_oooo002?oooo00<0
000co`0co`002S?o00030000oooooooo00ooool00ol0VOooooooo`1_oooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo00ooool00ol0VOooooooo`1_oooo002?oooo00<0000co`0co`002S?o
00030000oooooooo00ooool00ol0VOooooooo`1_oooo002?oooo00<0000co`0co`002S?o00030000
oooooooo00ooool00ol0VOooooooo`1_oooo002?oooo0P0000/co`000`000?ooooooo`0?oooo00?o
09Woooooool0Koooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0?oooo00?o09Wooooo
ool0Koooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0?oooo00?o09Woooooool0Kooo
o`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0@oooo00?o09Woooooool0Koooo`00Sooo
o`030000<ol0<ol000Tco`000`000?ooooooo`0@oooo00?o09Woooooool0Koooo`00Soooo`030000
<ol0<ol000Tco`000`000?ooooooo`0@oooo00?o09Woooooool0Koooo`00Soooo`80000:<ol000<0
003oooooool04?ooo`03o`2Ioooooooo06ooool008ooool00`0003?o03?o0009<ol000<0003ooooo
ool04?ooo`03o`2Ioooooooo06ooool008ooool00`0003?o03?o0009<ol000<0003oooooool04?oo
o`03o`2Ioooooooo06ooool008ooool00`0003?o03?o0008<ol000<0003oooooool04Oooo`03o`2I
oooooooo06ooool008Soool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`0Aoooo00?o
09Woooooool0Koooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0Aoooo00?o09Woooooool0Koooo`00ROooo`030000oooooooo00?oool3000023?o00030000
oooooooo017oool00ol0VOooooooo`1_oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`0Aoooo00?o09Woooooool0Koooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`0Aoooo00?o09Woooooool0Koooo`00R?ooo`800005
oooo00<0000co`0co`001c?o00030000oooooooo01;oool00ol0VOooooooo`1_oooo002?oooo00<0
000co`0co`001c?o00030000oooooooo01;oool00ol0VOooooooo`1_oooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo01;oool00ol0VOooooooo`1_oooo002?oooo00<0000co`0co`001c?o
00030000oooooooo01;oool00ol0VOooooooo`1_oooo002?oooo0P0000Pco`000`000?ooooooo`0B
oooo00?o09Woooooool0Koooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Boooo00?o
09Woooooool0Koooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Boooo00?o09Wooooo
ool0Koooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Boooo00?o09Woooooool0Kooo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0Coooo00?o09Woooooool0Koooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`0Coooo00?o09Woooooool0Koooo`00Soooo`800007
<ol000<0003oooooool04oooo`03o`2Ioooooooo06ooool008ooool00`0003?o03?o0006<ol000<0
003oooooool04oooo`03o`2Ioooooooo06ooool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool04oooo`03o`2Ioooooooo06ooool008ooool00`0003?o03?o0006<ol000<0003oooooool04ooo
o`03o`2Ioooooooo06ooool008ooool00`0003?o03?o0006<ol000<0003oooooool04oooo`03o`2I
oooooooo06ooool008ooool00`0003?o03?o0006<ol000<0003oooooool04oooo`03o`2Ioooooooo
06ooool008ooool200001S?o00030000oooooooo01Coool00ol0VOooooooo`1_oooo002?oooo00<0
000co`0co`001C?o00030000oooooooo01Coool00ol0VOooooooo`1_oooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo01Coool00ol0VOooooooo`1_oooo002?oooo00<0000co`0co`001C?o
00030000oooooooo01Coool00ol0VOooooooo`1_oooo002?oooo00<0000co`0co`001C?o00030000
oooooooo01Coool00ol0VOooooooo`1_oooo002?oooo00<0000co`0co`001C?o00030000oooooooo
01Coool00ol0VOooooooo`1_oooo002?oooo0P0000Hco`000`000?ooooooo`0Doooo00?o09Wooooo
ool0Koooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Doooo00?o09Woooooool0Kooo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Doooo00?o09Woooooool0Koooo`00Sooo
o`030000<ol0<ol000@co`000`000?ooooooo`0Eoooo00?o09Woooooool0Koooo`00Soooo`030000
<ol0<ol000@co`000`000?ooooooo`0Eoooo00?o09Woooooool0Koooo`00ROooo`<00003oooo00<0
000co`0co`0013?o00030000oooooooo01Goool00ol0VOooooooo`1_oooo002:oooo00<0003ooooo
ool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`0Eoooo00?o09Woooooool0Koooo`00Qooo
o`D00003oooo0`0000@co`000`000?ooooooo`0Eoooo00?o09Woooooool0Koooo`00Qoooo`040000
oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029oooo0P00
00Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?ooooooo`0C
oooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo
00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`06oooo1@00008co`02000000@co`3oooooooooool200000oooo`@00003oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01oooo`030000<ol0<ol000Dco`02oooo00@0003oooooool00002oooo00<0003ooooo
ool01?ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03ooo
o`030000<ol0<ol000Dco`05oooo00D0003oooooooooool000001_ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500003_ooo`030000<ol0<ol000Dco`03oooo0P0000Goool00`000?oo
ooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000017oool00`0003?o
03?o0005<ol00oooo`030000oooooooo00;oool010000?ooooooo`0000?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool04Oooo`800007<ol00oooo`<00003oooo0P0000?oool00`000?oo
ooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.54) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.60873 .12361 L
.61445 .12361 L
.61984 .12361 L
.62502 .12361 L
.62644 .12361 L
.62722 .12361 L
.62795 .12361 L
s
.62795 .12361 m
.62846 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.36173 .12361 L
.36626 .12361 L
.36876 .12361 L
.36999 .12361 L
.37114 .12361 L
.37178 .12324 L
.37247 .12253 L
.37393 .12105 L
.37649 .11852 L
.3815 .11379 L
.40147 .09777 L
.42308 .0848 L
.44395 .07574 L
.45388 .07243 L
.46315 .06984 L
.48197 .06589 L
.49194 .06442 L
.50264 .06322 L
.52388 .05995 L
.544 .05581 L
.58233 .04681 L
.60171 .04227 L
.61201 .03995 L
.61742 .03878 L
.62311 .03759 L
.62555 .03709 L
.62689 .03682 L
.62815 .03657 L
.62887 .12361 L
.62965 .12361 L
.63101 .12361 L
.63367 .12361 L
.64336 .12361 L
.66237 .12361 L
.70329 .12361 L
.7427 .12361 L
.78058 .12361 L
.82092 .12361 L
.85975 .12361 L
.90102 .12361 L
Mistroke
.94078 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.54) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool07Oooo`0306Kooooooooo06koool008ooool00`000?ooooooo`0Ioooo1@1Vog3oool0
08ooool00`000?ooooooo`0Eoooo101Vo`Coool00`1Vooooooooo`1^oooo002?oooo00<0003ooooo
ool04?ooo`D0I_l8oooo00<0I_ooooooool0K_ooo`00Soooo`80000<oooo1@1Vo`goool00`1Voooo
ooooo`1^oooo002?oooo00<0003oooooool01_ooo`D0I_lBoooo00<0I_ooooooool0K_ooo`00Sooo
o`040000oooooooooooo1@1VoaOoool00`1Vooooooooo`1^oooo002<oooo0`1Vo`04000006Ko06Ko
06Ko7?ooo`0306Kooooooooo06koool008Woool306Ko0oooo`030000oooooooo01goool00`1Voooo
ooooo`1^oooo0023oooo1P1Vo`Koool00`000?ooooooo`0Moooo00<0I_ooooooool0K_ooo`00POoo
o`80I_l<oooo0P0001koool00`1Vooooooooo`1^oooo000Goooo100003Woool500009_ooo`80I_l>
oooo00<0003oooooool07Oooo`0306Kooooooooo01Ooool50000>?ooo`@0000Foooo000Goooo00<0
003oooooool0??ooo`030000oooooooo02Coool206Ko4?ooo`030000oooooooo01koool00`1Voooo
ooooo`0Hoooo00<0003oooooool0>?ooo`030000oooooooo01Ooool001Soool00`000?ooooooo`0k
oooo00<0003oooooool08_ooo`80I_lBoooo00<0003oooooool07_ooo`0306Kooooooooo01Soool0
0`000?ooooooo`0ioooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool0<_oo
o`@00004oooo00<0003oooooool08?ooo`80I_lDoooo00<0003oooooool07_ooo`0306Kooooooooo
01Soool00`000?ooooooo`0joooo00<0003oooooool05Oooo`005oooo`040000oooooooo0000>ooo
o`030000oooooooo01koool206Ko5_ooo`030000oooooooo01koool00`1Vooooooooo`0Hoooo00<0
003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`80000koooo0P0001ooool00`1Voooo
ooooo`0Foooo0P0001ooool00`1Vooooooooo`0Goooo0P0003_oool200005oooo`00MOooo`0306Ko
oooooooo01Ooool00`000?ooooooo`0Noooo00<0I_ooooooool0KOooo`00Loooo`80I_lJoooo00<0
003oooooool07_ooo`0306Kooooooooo06goool007;oool00`1Vooooooooo`0Joooo00<0003ooooo
ool07_ooo`0306Kooooooooo06goool0077oool00`1Vooooooooo`0Koooo00<0003oooooool07_oo
o`0306Kooooooooo06goool0073oool00`1Vooooooooo`0Loooo00<0003oooooool07_ooo`0306Ko
oooooooo06goool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Dco`00
1Ol0VC?o03?o03?o0000000;<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_oo
o`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000
oooooooo03Woool00`0003?o03?o000M<ol000?o09Tco`0co`006C?o00T0000doooo00<0003ooooo
ool05Oooo`00Soooo`030000<ol0<ol001dco`000ol0VC?o03?o000C<ol01P0005Goool008ooool0
0`0003?o03?o000M<ol000?o09Tco`0co`004C?o0080001Koooo002?oooo00<0000co`0co`007C?o
0003o`2I<ol0<ol000lco`020000GOooo`00Soooo`030000<ol0<ol001dco`000ol0VC?o03?o000<
<ol00`0005ooool008ooool200007S?o0003o`2I<ol0<ol000Tco`030000H_ooo`00Soooo`030000
<ol0<ol001dco`000ol0VC?o03?o0007<ol00P0006Goool008ooool00`0003?o03?o000M<ol000?o
09Tco`0co`001S?o00030000oooooooo06Goool008ooool00`0003?o03?o000M<ol000?o09Tco`0c
o`001C?o00030000oooooooo06Koool008ooool00`0003?o03?o000M<ol000?o09Tco`0co`0013?o
00030000oooooooo06Ooool008ooool00`0003?o03?o000M<ol000?o09Tco`0co`000S?o0080001Z
oooo002?oooo0P0001hco`001Ol0VC?o03?o03?o0000001/oooo002?oooo00<0000co`0co`007C?o
0004o`2I<ol0<ol00000KOooo`00Soooo`030000<ol0<ol001dco`000ol0VC?o0000001^oooo002?
oooo00<0000co`0co`007C?o0003o`2I<ol0000006koool008ooool00`0003?o03?o000M<ol000?o
09T0003oool0K_ooo`00Soooo`030000<ol0<ol001dco`000ol0VOooooooo`1^oooo002?oooo0P00
01dco`000`000?l0VOooo`1_oooo002?oooo00<0000co`0co`006c?o00030000ooooo`2I073oool0
08ooool00`0003?o03?o000K<ol000<0003ooooo09T0L?ooo`00Soooo`030000<ol0<ol001Xco`00
10000?ooooooool0VG3oool008ooool00`0003?o03?o000J<ol000@0003ooooooooo09U`oooo002?
oooo00<0000co`0co`006C?o00050000ooooooooooooo`2I073oool008ooool200006S?o00050000
ooooooooooooo`2I073oool008ooool00`0003?o03?o000H<ol000<0003oooooool00_ooo`03o`2I
oooooooo06koool008ooool00`0003?o03?o000H<ol000<0003oooooool00_ooo`03o`2Ioooooooo
06koool008ooool00`0003?o03?o000G<ol000<0003oooooool00oooo`03o`2Ioooooooo06koool0
08ooool00`0003?o03?o000G<ol000<0003oooooool00oooo`03o`2Ioooooooo06koool008Ooool5
00000oooo`030000<ol0<ol001Hco`000`000?ooooooo`04oooo00?o09Woooooool0K_ooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000F<ol000<0003oooooool01?ooo`03o`2Ioooooooo
06koool008Woool00`000?ooooooo`03oooo0`0001Dco`000`000?ooooooo`05oooo00?o09Wooooo
ool0K_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool01Ooo
o`03o`2Ioooooooo06koool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000
oooooooo00Goool00ol0VOooooooo`1^oooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0
003oooooool01_ooo`03o`2Ioooooooo06koool008ooool00`0003?o03?o000D<ol000<0003ooooo
ool01_ooo`03o`2Ioooooooo06koool008ooool00`0003?o03?o000C<ol000<0003oooooool01ooo
o`03o`2Ioooooooo06koool008ooool2000053?o00030000oooooooo00Ooool00ol0VOooooooo`1^
oooo002?oooo00<0000co`0co`004c?o00030000oooooooo00Ooool00ol0VOooooooo`1^oooo002?
oooo00<0000co`0co`004S?o00030000oooooooo00Soool00ol0VOooooooo`1^oooo002?oooo00<0
000co`0co`004S?o00030000oooooooo00Soool00ol0VOooooooo`1^oooo002?oooo00<0000co`0c
o`004S?o00030000oooooooo00Soool00ol0VOooooooo`1^oooo002?oooo00<0000co`0co`004C?o
00030000oooooooo00Woool00ol0VOooooooo`1^oooo002?oooo0P00018co`000`000?ooooooo`09
oooo00?o09Woooooool0K_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`09oooo00?o
09Woooooool0K_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`09oooo00?o09Wooooo
ool0K_ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0:oooo00?o09Woooooool0K_oo
o`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0:oooo00?o09Woooooool0K_ooo`00Sooo
o`030000<ol0<ol0010co`000`000?ooooooo`0:oooo00?o09Woooooool0K_ooo`00Soooo`030000
<ol0<ol0010co`000`000?ooooooo`0:oooo00?o09Woooooool0K_ooo`00Soooo`80000@<ol000<0
003oooooool02oooo`03o`2Ioooooooo06koool008ooool00`0003?o03?o000?<ol000<0003ooooo
ool02oooo`03o`2Ioooooooo06koool008ooool00`0003?o03?o000?<ol000<0003oooooool02ooo
o`03o`2Ioooooooo06koool008ooool00`0003?o03?o000?<ol000<0003oooooool02oooo`03o`2I
oooooooo06koool008ooool00`0003?o03?o000?<ol000<0003oooooool02oooo`03o`2Ioooooooo
06koool008ooool00`0003?o03?o000><ol000<0003oooooool03?ooo`03o`2Ioooooooo06koool0
08ooool200003c?o00030000oooooooo00coool00ol0VOooooooo`1^oooo002?oooo00<0000co`0c
o`003S?o00030000oooooooo00coool00ol0VOooooooo`1^oooo002?oooo00<0000co`0co`003S?o
00030000oooooooo00coool00ol0VOooooooo`1^oooo002?oooo00<0000co`0co`003C?o00030000
oooooooo00goool00ol0VOooooooo`1^oooo0027oooo100000Coool00`0003?o03?o000=<ol000<0
003oooooool03Oooo`03o`2Ioooooooo06koool008Ooool00`000?ooooooo`05oooo00<0000co`0c
o`003C?o00030000oooooooo00goool00ol0VOooooooo`1^oooo0028oooo00<0003oooooool01?oo
o`<0000=<ol000<0003oooooool03Oooo`03o`2Ioooooooo06koool008Woool00`000?ooooooo`03
oooo00<0000co`0co`003C?o00030000oooooooo00koool00ol0VOooooooo`1]oooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`0033?o00030000oooooooo00ooool00ol0VOooooooo`1]
oooo0028oooo0P0000Goool00`0003?o03?o000<<ol000<0003oooooool03oooo`03o`2Ioooooooo
06goool008ooool00`0003?o03?o000<<ol000<0003oooooool03oooo`03o`2Ioooooooo06goool0
08ooool00`0003?o03?o000<<ol000<0003oooooool03oooo`03o`2Ioooooooo06goool008ooool2
00003C?o00030000oooooooo00ooool00ol0VOooooooo`1]oooo002?oooo00<0000co`0co`0033?o
00030000oooooooo00ooool00ol0VOooooooo`1]oooo002?oooo00<0000co`0co`002c?o00030000
oooooooo013oool00ol0VOooooooo`1]oooo002?oooo00<0000co`0co`002c?o00030000oooooooo
013oool00ol0VOooooooo`1]oooo002?oooo00<0000co`0co`002c?o00030000oooooooo013oool0
0ol0VOooooooo`1]oooo002?oooo00<0000co`0co`002c?o00030000oooooooo013oool00ol0VOoo
ooooo`1]oooo002?oooo00<0000co`0co`002c?o00030000oooooooo013oool00ol0VOooooooo`1]
oooo002?oooo0P0000`co`000`000?ooooooo`0@oooo00?o09Woooooool0KOooo`00Soooo`030000
<ol0<ol000/co`000`000?ooooooo`0@oooo00?o09Woooooool0KOooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0Aoooo00?o09Woooooool0KOooo`00Soooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0Aoooo00?o09Woooooool0KOooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0Aoooo00?o09Woooooool0KOooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0A
oooo00?o09Woooooool0KOooo`00Soooo`80000;<ol000<0003oooooool04Oooo`03o`2Ioooooooo
06goool008ooool00`0003?o03?o000:<ol000<0003oooooool04Oooo`03o`2Ioooooooo06goool0
08ooool00`0003?o03?o000:<ol000<0003oooooool04Oooo`03o`2Ioooooooo06goool008ooool0
0`0003?o03?o0009<ol000<0003oooooool04_ooo`03o`2Ioooooooo06goool008ooool00`0003?o
03?o0009<ol000<0003oooooool04_ooo`03o`2Ioooooooo06goool008ooool00`0003?o03?o0009
<ol000<0003oooooool04_ooo`03o`2Ioooooooo06goool008ooool200002S?o00030000oooooooo
01;oool00ol0VOooooooo`1]oooo002?oooo00<0000co`0co`002C?o00030000oooooooo01;oool0
0ol0VOooooooo`1]oooo002?oooo00<0000co`0co`002C?o00030000oooooooo01;oool00ol0VOoo
ooooo`1]oooo002?oooo00<0000co`0co`0023?o00030000oooooooo01?oool00ol0VOooooooo`1]
oooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0003oooooool04oooo`03o`2Ioooooooo
06goool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool04ooo
o`03o`2Ioooooooo06goool008Woool00`000?ooooooo`03oooo0`0000Pco`000`000?ooooooo`0C
oooo00?o09Woooooool0KOooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008<ol000<0
003oooooool04oooo`03o`2Ioooooooo06goool008Ooool010000?ooooooo`0000Coool00`0003?o
03?o0008<ol000<0003oooooool04oooo`03o`2Ioooooooo06goool008Soool200001Oooo`030000
<ol0<ol000Lco`000`000?ooooooo`0Doooo00?o09Woooooool0KOooo`00Soooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0Doooo00?o09Woooooool0KOooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0Doooo00?o09Woooooool0KOooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0Doooo00?o09Woooooool0KOooo`00Soooo`800008<ol000<0003oooooool05?ooo`03o`2I
oooooooo06goool008ooool00`0003?o03?o0007<ol000<0003oooooool05?ooo`03o`2Ioooooooo
06goool008ooool00`0003?o03?o0007<ol000<0003oooooool05?ooo`03o`2Ioooooooo06goool0
08ooool00`0003?o03?o0007<ol000<0003oooooool05?ooo`03o`2Ioooooooo06goool008ooool0
0`0003?o03?o0006<ol000<0003oooooool05Oooo`03o`2Ioooooooo06goool008ooool00`0003?o
03?o0006<ol000<0003oooooool05Oooo`03o`2Ioooooooo06goool008ooool200001c?o00030000
oooooooo01Goool00ol0VOooooooo`1]oooo002?oooo00<0000co`0co`001S?o00030000oooooooo
01Goool00ol0VOooooooo`1]oooo002?oooo00<0000co`0co`001S?o00030000oooooooo01Goool0
0ol0VOooooooo`1]oooo002?oooo00<0000co`0co`001S?o00030000oooooooo01Goool00ol0VOoo
ooooo`1]oooo002?oooo00<0000co`0co`001S?o00030000oooooooo01Goool00ol0VOooooooo`1]
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo01Goool00ol0VOooooooo`1]oooo002?
oooo0P0000Hco`000`000?ooooooo`0Foooo00?o09Woooooool0KOooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`0Foooo00?o09Woooooool0KOooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`0Foooo00?o09Woooooool0KOooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`0Foooo00?o09Woooooool0KOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0F
oooo00?o09Woooooool0KOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Foooo00?o
09Woooooool0KOooo`00Soooo`800006<ol000<0003oooooool05_ooo`03o`2Ioooooooo06goool0
08ooool00`0003?o03?o0005<ol000<0003oooooool05_ooo`03o`2Ioooooooo06goool008ooool0
0`0003?o03?o0005<ol000<0003oooooool05_ooo`03o`2Ioooooooo06goool008ooool00`0003?o
03?o0004<ol000<0003oooooool05oooo`03o`2Ioooooooo06goool008ooool00`0003?o03?o0004
<ol000<0003oooooool05oooo`03o`2Ioooooooo06goool008Woool300000oooo`030000<ol0<ol0
00@co`000`000?ooooooo`0Goooo00?o09Woooooool0KOooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o0004<ol000<0003oooooool05oooo`03o`2Ioooooooo06goool008Ooool500000ooo
o`<00004<ol000<0003oooooool05oooo`03o`2Ioooooooo06goool008Ooool010000?ooooooo`00
00Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o
08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o
00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01_ooo`D00002<ol00P000004<ol0oooooooooooo0P0000Goool300000_ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Ooool00`0003?o03?o0005<ol00_ooo`040000oooooooo00001Oooo`050000oooooooooooo0000
07[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000<ol0<ol000Dco`05
oooo00<0003oooooool01@0000?oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
00koool00`0003?o03?o0005<ol00oooo`800003oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo0000017oool00`0003?o03?o0005<ol00oooo`030000
oooooooo00?oool00`000?ooo`000003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo
017oool200001c?o00?oool300001?ooo`800002oooo00<0003oooooool0NOooo`00Soooo`Lco`2:
oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.56) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.60873 .12361 L
.61984 .12361 L
.6254 .12361 L
.62812 .12361 L
.63064 .12361 L
.63182 .12361 L
.63292 .12361 L
s
.63292 .12361 m
.63338 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.35271 .12361 L
.36173 .12361 L
.36405 .12361 L
.3652 .12361 L
.36626 .12361 L
.36748 .12277 L
.36812 .12211 L
.36881 .12141 L
.37114 .11909 L
.3815 .10958 L
.40147 .09456 L
.42308 .08246 L
.43323 .07802 L
.44395 .07408 L
.46315 .06868 L
.47263 .0667 L
.48279 .06502 L
.49238 .0638 L
.50112 .06296 L
.5202 .06045 L
.53099 .05852 L
.54096 .05651 L
.58023 .04759 L
.59993 .043 L
.61798 .03899 L
.62741 .03703 L
.6297 .03657 L
.63096 .03632 L
.63215 .03608 L
.63282 .03595 L
.63355 .12361 L
.63483 .12361 L
.63733 .12361 L
.65818 .12361 L
.6991 .12361 L
.73851 .12361 L
.77639 .12361 L
.81673 .12361 L
.85556 .12361 L
.89683 .12361 L
Mistroke
.9366 .12361 L
.97484 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.56) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool07Oooo`<0I_m^oooo002?oooo00<0003oooooool06Oooo`@0I_l2oooo00<0I_oooooo
ool0K?ooo`00Soooo`030000oooooooo01Coool506Ko1_ooo`0306Kooooooooo06coool008ooool0
0`000?ooooooo`0?oooo1@1Vo`_oool00`1Vooooooooo`1/oooo002?oooo0P0000_oool506Ko4?oo
o`0306Kooooooooo06coool008ooool00`000?ooooooo`07oooo0`1VoaGoool00`1Vooooooooo`1/
oooo002?oooo00<0003oooooool01`1VoaSoool00`1Vooooooooo`1/oooo002=oooo0P1Vo`030000
06Ko06Ko01ooool00`1Vooooooooo`1/oooo0025oooo201Vo`;oool00`000?ooooooo`0Ooooo00<0
I_ooooooool0K?ooo`00Poooo`80I_l:oooo00<0003oooooool07oooo`0306Kooooooooo06coool0
083oool306Ko3?ooo`80000Poooo00<0I_ooooooool0K?ooo`005oooo`@0000ioooo1@0002Coool3
06Ko3oooo`030000oooooooo01ooool00`1Vooooooooo`0Eoooo1@0003Soool400005_ooo`005ooo
o`030000oooooooo03coool00`000?ooooooo`0Roooo0P1Voa;oool00`000?ooooooo`0Ooooo00<0
I_ooooooool05oooo`030000oooooooo03Soool00`000?ooooooo`0Goooo000Hoooo00<0003ooooo
ool0>oooo`030000oooooooo023oool206Ko5?ooo`030000oooooooo01ooool00`1Vooooooooo`0G
oooo00<0003oooooool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo
03;oool400001?ooo`030000oooooooo01koool206Ko5_ooo`030000oooooooo01ooool00`1Voooo
ooooo`0Goooo00<0003oooooool0>_ooo`030000oooooooo01Goool001Ooool010000?ooooooo`00
03_oool00`000?ooooooo`0Moooo00<0I_ooooooool05_ooo`030000oooooooo01ooool00`1Voooo
ooooo`0Goooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`80000koooo0P00
01koool00`1Vooooooooo`0Goooo0P00023oool00`1Vooooooooo`0Foooo0P0003_oool200005ooo
o`00Loooo`80I_lJoooo00<0003oooooool07oooo`0306Kooooooooo06coool007;oool00`1Voooo
ooooo`0Joooo00<0003oooooool07oooo`0306Kooooooooo06coool0077oool00`1Vooooooooo`0K
oooo00<0003oooooool07oooo`0306Kooooooooo06coool006ooool206Ko7_ooo`030000oooooooo
01ooool00`1Vooooooooo`1/oooo001^oooo00<0I_ooooooool07_ooo`030000oooooooo01ooool0
0`1Vooooooooo`1/oooo000@ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0007
<ol000?o09Tco`0000002c?o00030000<ol0<ol000Tco`000`0003?o03?o0006<ol08P0000Koool0
0`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?oo
ooooo`0ioooo00<0000co`0co`007c?o0003o`2I<ol0<ol001Lco`090000=?ooo`030000oooooooo
01Goool008ooool00`0003?o03?o000O<ol000?o09Tco`0co`004C?o00H0001Eoooo002?oooo00<0
000co`0co`007c?o0003o`2I<ol0<ol000lco`020000Foooo`00Soooo`030000<ol0<ol001lco`00
0ol0VC?o03?o000=<ol00P0005goool008ooool00`0003?o03?o000O<ol000?o09Tco`0co`002S?o
00<0001Ooooo002?oooo0P00020co`000ol0VC?o03?o0007<ol00`0006;oool008ooool00`0003?o
03?o000O<ol000?o09Tco`0co`001C?o0080001Uoooo002?oooo00<0000co`0co`007c?o0003o`2I
<ol0<ol000@co`000`000?ooooooo`1Uoooo002?oooo00<0000co`0co`007c?o0003o`2I<ol0<ol0
00<co`000`000?ooooooo`1Voooo002?oooo00<0000co`0co`007c?o0003o`2I<ol0<ol0008co`00
0`000?ooooooo`1Woooo002?oooo00<0000co`0co`007c?o0003o`2I<ol0<ol00080001Zoooo002?
oooo0P00020co`000ol0VC?o0000001/oooo002?oooo00<0000co`0co`007c?o0003o`2I0000oooo
06coool008ooool00`0003?o03?o000O<ol000?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol0
01lco`000ol0VOooooooo`1/oooo002?oooo00<0000co`0co`007S?o00030000o`2Ioooo06goool0
08ooool00`0003?o03?o000M<ol000<0003ooooo09T0K_ooo`00Soooo`80000M<ol000@0003ooooo
oooo09U^oooo002?oooo00<0000co`0co`006c?o00050000ooooooooooooo`2I06koool008ooool0
0`0003?o03?o000K<ol000D0003ooooooooooooo09T0K_ooo`00Soooo`030000<ol0<ol001Xco`00
0`000?ooooooo`02oooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol001Xco`000`000?oo
ooooo`02oooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`03
oooo00?o09Woooooool0K?ooo`00Soooo`80000J<ol000<0003oooooool00oooo`03o`2Ioooooooo
06coool008ooool00`0003?o03?o000H<ol000<0003oooooool01?ooo`03o`2Ioooooooo06coool0
08ooool00`0003?o03?o000H<ol000<0003oooooool01?ooo`03o`2Ioooooooo06coool008ooool0
0`0003?o03?o000G<ol000<0003oooooool01Oooo`03o`2Ioooooooo06coool008ooool00`0003?o
03?o000G<ol000<0003oooooool01Oooo`03o`2Ioooooooo06coool008Ooool500000oooo`030000
<ol0<ol001Hco`000`000?ooooooo`06oooo00?o09Woooooool0K?ooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000F<ol000<0003oooooool01_ooo`03o`2Ioooooooo06coool008Woool0
0`000?ooooooo`03oooo0`0001Dco`000`000?ooooooo`07oooo00?o09Woooooool0K?ooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool01oooo`03o`2Ioooooooo
06coool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo00Ooool0
0ol0VOooooooo`1/oooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool02?oo
o`03o`2Ioooooooo06coool008ooool00`0003?o03?o000D<ol000<0003oooooool02?ooo`03o`2I
oooooooo06coool008ooool00`0003?o03?o000C<ol000<0003oooooool02Oooo`03o`2Ioooooooo
06coool008ooool2000053?o00030000oooooooo00Woool00ol0VOooooooo`1/oooo002?oooo00<0
000co`0co`004c?o00030000oooooooo00Woool00ol0VOooooooo`1/oooo002?oooo00<0000co`0c
o`004S?o00030000oooooooo00[oool00ol0VOooooooo`1/oooo002?oooo00<0000co`0co`004S?o
00030000oooooooo00[oool00ol0VOooooooo`1/oooo002?oooo00<0000co`0co`004S?o00030000
oooooooo00[oool00ol0VOooooooo`1/oooo002?oooo00<0000co`0co`004C?o00030000oooooooo
00_oool00ol0VOooooooo`1/oooo002?oooo0P00018co`000`000?ooooooo`0;oooo00?o09Wooooo
ool0K?ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0;oooo00?o09Woooooool0K?oo
o`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0;oooo00?o09Woooooool0K?ooo`00Sooo
o`030000<ol0<ol0010co`000`000?ooooooo`0<oooo00?o09Woooooool0K?ooo`00Soooo`030000
<ol0<ol0010co`000`000?ooooooo`0<oooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol0
010co`000`000?ooooooo`0<oooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol0010co`00
0`000?ooooooo`0<oooo00?o09Woooooool0K?ooo`00Soooo`80000@<ol000<0003oooooool03Ooo
o`03o`2Ioooooooo06coool008ooool00`0003?o03?o000?<ol000<0003oooooool03Oooo`03o`2I
oooooooo06coool008ooool00`0003?o03?o000?<ol000<0003oooooool03Oooo`03o`2Ioooooooo
06coool008ooool00`0003?o03?o000?<ol000<0003oooooool03Oooo`03o`2Ioooooooo06coool0
08ooool00`0003?o03?o000?<ol000<0003oooooool03Oooo`03o`2Ioooooooo06coool008ooool0
0`0003?o03?o000><ol000<0003oooooool03_ooo`03o`2Ioooooooo06coool008ooool200003c?o
00030000oooooooo00koool00ol0VOooooooo`1/oooo002?oooo00<0000co`0co`003S?o00030000
oooooooo00koool00ol0VOooooooo`1/oooo002?oooo00<0000co`0co`003S?o00030000oooooooo
00koool00ol0VOooooooo`1/oooo002?oooo00<0000co`0co`003C?o00030000oooooooo00ooool0
0ol0VOooooooo`1/oooo0027oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool03ooo
o`03o`2Ioooooooo06coool008Ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000
oooooooo00ooool00ol0VOooooooo`1/oooo0028oooo00<0003oooooool01?ooo`<0000=<ol000<0
003oooooool03oooo`03o`2Ioooooooo06coool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`003C?o00030000oooooooo00ooool00ol0VOooooooo`1/oooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0033?o00030000oooooooo013oool00ol0VOooooooo`1/oooo0028oooo0P00
00Goool00`0003?o03?o000<<ol000<0003oooooool04?ooo`03o`2Ioooooooo06coool008ooool0
0`0003?o03?o000<<ol000<0003oooooool04?ooo`03o`2Ioooooooo06coool008ooool00`0003?o
03?o000<<ol000<0003oooooool04?ooo`03o`2Ioooooooo06coool008ooool200003C?o00030000
oooooooo013oool00ol0VOooooooo`1/oooo002?oooo00<0000co`0co`0033?o00030000oooooooo
013oool00ol0VOooooooo`1/oooo002?oooo00<0000co`0co`002c?o00030000oooooooo017oool0
0ol0VOooooooo`1/oooo002?oooo00<0000co`0co`002c?o00030000oooooooo017oool00ol0VOoo
ooooo`1/oooo002?oooo00<0000co`0co`002c?o00030000oooooooo017oool00ol0VOooooooo`1/
oooo002?oooo00<0000co`0co`002c?o00030000oooooooo017oool00ol0VOooooooo`1/oooo002?
oooo00<0000co`0co`002c?o00030000oooooooo017oool00ol0VOooooooo`1/oooo002?oooo0P00
00`co`000`000?ooooooo`0Aoooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`0Aoooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0Boooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0B
oooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Boooo00?o
09Woooooool0K?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Boooo00?o09Wooooo
ool0K?ooo`00Soooo`80000;<ol000<0003oooooool04_ooo`03o`2Ioooooooo06coool008ooool0
0`0003?o03?o000:<ol000<0003oooooool04_ooo`03o`2Ioooooooo06coool008ooool00`0003?o
03?o000:<ol000<0003oooooool04_ooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o0009
<ol000<0003oooooool04oooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o0009<ol000<0
003oooooool04oooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o0009<ol000<0003ooooo
ool04oooo`03o`2Ioooooooo06coool008ooool200002S?o00030000oooooooo01?oool00ol0VOoo
ooooo`1/oooo002?oooo00<0000co`0co`002C?o00030000oooooooo01?oool00ol0VOooooooo`1/
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo01?oool00ol0VOooooooo`1/oooo002?
oooo00<0000co`0co`0023?o00030000oooooooo01Coool00ol0VOooooooo`1/oooo0028oooo0P00
00Goool00`0003?o03?o0008<ol000<0003oooooool05?ooo`03o`2Ioooooooo06coool008Ooool0
10000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool05?ooo`03o`2Ioooooooo
06coool008Woool00`000?ooooooo`03oooo0`0000Pco`000`000?ooooooo`0Doooo00?o09Wooooo
ool0K?ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool05?oo
o`03o`2Ioooooooo06coool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0
003oooooool05?ooo`03o`2Ioooooooo06coool008Soool200001Oooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0Eoooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0Eoooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0E
oooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Eoooo00?o
09Woooooool0K?ooo`00Soooo`800008<ol000<0003oooooool05Oooo`03o`2Ioooooooo06coool0
08ooool00`0003?o03?o0007<ol000<0003oooooool05Oooo`03o`2Ioooooooo06coool008ooool0
0`0003?o03?o0007<ol000<0003oooooool05Oooo`03o`2Ioooooooo06coool008ooool00`0003?o
03?o0007<ol000<0003oooooool05Oooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o0006
<ol000<0003oooooool05_ooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o0006<ol000<0
003oooooool05_ooo`03o`2Ioooooooo06coool008ooool200001c?o00030000oooooooo01Koool0
0ol0VOooooooo`1/oooo002?oooo00<0000co`0co`001S?o00030000oooooooo01Koool00ol0VOoo
ooooo`1/oooo002?oooo00<0000co`0co`001S?o00030000oooooooo01Koool00ol0VOooooooo`1/
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo01Koool00ol0VOooooooo`1/oooo002?
oooo00<0000co`0co`001S?o00030000oooooooo01Koool00ol0VOooooooo`1/oooo002?oooo00<0
000co`0co`001S?o00030000oooooooo01Koool00ol0VOooooooo`1/oooo002?oooo0P0000Hco`00
0`000?ooooooo`0Goooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`0Goooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0G
oooo00?o09Woooooool0K?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Goooo00?o
09Woooooool0K?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Goooo00?o09Wooooo
ool0K?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Goooo00?o09Woooooool0K?oo
o`00Soooo`800006<ol000<0003oooooool05oooo`03o`2Ioooooooo06coool008ooool00`0003?o
03?o0005<ol000<0003oooooool05oooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o0005
<ol000<0003oooooool05oooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o0004<ol000<0
003oooooool06?ooo`03o`2Ioooooooo06coool008ooool00`0003?o03?o0004<ol000<0003ooooo
ool06?ooo`03o`2Ioooooooo06coool008Woool300000oooo`030000<ol0<ol000@co`000`000?oo
ooooo`0Hoooo00?o09Woooooool0K?ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0004
<ol000<0003oooooool06?ooo`03o`2Ioooooooo06coool008Ooool500000oooo`<00004<ol000<0
003oooooool06?ooo`03o`2Ioooooooo06coool008Ooool010000?ooooooo`0000Coool7<ol0R_oo
o`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7
<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>oooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o00ooool00`000?oo
ooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002
<ol00P000004<ol0oooooooooooo0P0000?oool300001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`0003?o
03?o0005<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000<ol0<ol000Dco`05
oooo00@0003oooooool00002oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500003_ooo`030000<ol0<ol000Dco`03oooo0P0000?oool300001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`00000Aoooo00<0000co`0co`001C?o00?oool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool00`000?oo
ooooo`0Aoooo0P0000Lco`03oooo0`0000?oool300000_ooo`030000oooooooo07Woool008ooool7
<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.58) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.60873 .12361 L
.61984 .12361 L
.6254 .12361 L
.63064 .12361 L
.63534 .12361 L
.63663 .12361 L
.63733 .12361 L
.63799 .12361 L
s
.63799 .12361 m
.63845 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.34309 .12361 L
.35271 .12361 L
.35742 .12361 L
.35948 .12361 L
.36057 .12361 L
.36173 .12361 L
.36294 .12254 L
.36405 .1214 L
.36626 .1192 L
.37114 .11456 L
.3815 .10562 L
.40147 .09155 L
.42308 .08028 L
.43323 .07618 L
.44395 .07255 L
.46315 .06764 L
.47263 .06586 L
.48279 .06437 L
.49238 .06331 L
.50112 .06261 L
.51103 .06162 L
.5202 .06035 L
.54096 .05661 L
.58023 .04791 L
.61798 .03937 L
.62741 .03739 L
.63255 .03635 L
.63505 .03586 L
.63614 .03565 L
.63733 .03542 L
.63862 .12361 L
.63984 .12361 L
.64253 .12361 L
.64821 .12361 L
.65818 .12361 L
.6991 .12361 L
.73851 .12361 L
.77639 .12361 L
.81673 .12361 L
.85556 .12361 L
.89683 .12361 L
Mistroke
.9366 .12361 L
.97484 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.58) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool07oooo`80I_m]oooo002?oooo00<0003oooooool06Oooo`H0I_l00oooo`1Vooooo`1/
oooo002?oooo00<0003oooooool05?ooo`D0I_l7oooo00<0I_ooooooool0Joooo`00Soooo`030000
oooooooo00ooool506Ko3?ooo`0306Kooooooooo06_oool008ooool200002oooo`D0I_lAoooo00<0
I_ooooooool0Joooo`00Soooo`030000oooooooo00Goool506Ko5_ooo`0306Kooooooooo06_oool0
08ooool00`000?ooooooo`02oooo0`1Voa_oool00`1Vooooooooo`1[oooo002:oooo1@1Vo`030000
06Ko06Ko0080I_lNoooo00<0I_ooooooool0Joooo`00Q?ooo`H0I_l5oooo00<0003oooooool08?oo
o`0306Kooooooooo06_oool0083oool406Ko2oooo`030000oooooooo023oool00`1Vooooooooo`1[
oooo001moooo0`1Vo`ooool200008Oooo`0306Kooooooooo06_oool001Ooool40000>Oooo`D0000R
oooo0P1Voa;oool00`000?ooooooo`0Poooo00<0I_ooooooool05?ooo`D0000hoooo100001Koool0
01Ooool00`000?ooooooo`0loooo00<0003oooooool08?ooo`80I_lDoooo00<0003oooooool08?oo
o`0306Kooooooooo01Koool00`000?ooooooo`0hoooo00<0003oooooool05oooo`006?ooo`030000
oooooooo03_oool00`000?ooooooo`0Noooo0P1VoaKoool00`000?ooooooo`0Poooo00<0I_oooooo
ool05_ooo`030000oooooooo03Woool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?oo
ooooo`0boooo100000Coool00`000?ooooooo`0Moooo00<0I_ooooooool05_ooo`030000oooooooo
023oool00`1Vooooooooo`0Foooo00<0003oooooool0>_ooo`030000oooooooo01Goool001Ooool0
10000?ooooooo`0003_oool00`000?ooooooo`0Loooo00<0I_ooooooool05oooo`030000oooooooo
023oool00`1Vooooooooo`0Foooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`80000koooo0P0001coool206Ko6_ooo`80000Qoooo00<0I_ooooooool05Oooo`80000koooo0P00
01Ooool007;oool00`1Vooooooooo`0Joooo00<0003oooooool08?ooo`0306Kooooooooo06_oool0
077oool00`1Vooooooooo`0Koooo00<0003oooooool08?ooo`0306Kooooooooo06_oool006ooool2
06Ko7_ooo`030000oooooooo023oool00`1Vooooooooo`1[oooo001^oooo00<0I_ooooooool07_oo
o`030000oooooooo023oool00`1Vooooooooo`1[oooo001]oooo00<0I_ooooooool07oooo`030000
oooooooo023oool00`1Vooooooooo`1[oooo000@ooooo`00017oool001Koool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0008<ol000?o09T0000co`002S?o00030000<ol0<ol000Tco`000`0003?o03?o0006
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0ioooo00<0000co`0co`0083?o0003o`2I<ol0<ol001Hco`090000=?oo
o`030000oooooooo01Goool008ooool00`0003?o03?o000P<ol000?o09Tco`0co`0043?o00H0001E
oooo002?oooo00<0000co`0co`0083?o0003o`2I<ol0<ol000hco`020000Foooo`00Soooo`030000
<ol0<ol0020co`000ol0VC?o03?o000<<ol00P0005goool008ooool00`0003?o03?o000P<ol000?o
09Tco`0co`002C?o00<0001Ooooo002?oooo0P00024co`000ol0VC?o03?o0006<ol00`0006;oool0
08ooool00`0003?o03?o000P<ol000?o09Tco`0co`0013?o0080001Uoooo002?oooo00<0000co`0c
o`0083?o0003o`2I<ol0<ol000<co`000`000?ooooooo`1Uoooo002?oooo00<0000co`0co`0083?o
0003o`2I<ol0<ol0008co`000`000?ooooooo`1Voooo002?oooo00<0000co`0co`0083?o0005o`2I
<ol0<ol0<ol0000006Woool008ooool00`0003?o03?o000P<ol000Co09Tco`000000001Zoooo002?
oooo0P00024co`000ol0V@000?ooo`1[oooo002?oooo00<0000co`0co`0083?o0003o`2Ioooooooo
06_oool008ooool00`0003?o03?o000O<ol000<0003o09Woool0K?ooo`00Soooo`030000<ol0<ol0
01lco`000`000?l0VOooo`1/oooo002?oooo00<0000co`0co`007S?o00030000ooooo`2I06goool0
08ooool00`0003?o03?o000M<ol000@0003ooooooooo09U]oooo002?oooo0P0001dco`001@000?oo
ooooooooool0V@1]oooo002?oooo00<0000co`0co`006c?o00030000oooooooo00;oool00ol0VOoo
ooooo`1[oooo002?oooo00<0000co`0co`006c?o00030000oooooooo00;oool00ol0VOooooooo`1[
oooo002?oooo00<0000co`0co`006S?o00030000oooooooo00?oool00ol0VOooooooo`1[oooo002?
oooo00<0000co`0co`006S?o00030000oooooooo00?oool00ol0VOooooooo`1[oooo002?oooo00<0
000co`0co`006C?o00030000oooooooo00Coool00ol0VOooooooo`1[oooo002?oooo0P0001Xco`00
0`000?ooooooo`04oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol001Pco`000`000?oo
ooooo`05oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`05
oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`06oooo00?o
09Woooooool0Joooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`06oooo00?o09Wooooo
ool0Joooo`00Qoooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo00Ooool00ol0VOoo
ooooo`1[oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`07
oooo00?o09Woooooool0Joooo`00ROooo`030000oooooooo00?oool300005C?o00030000oooooooo
00Soool00ol0VOooooooo`1[oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`08oooo00?o09Woooooool0Joooo`00ROooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool02?ooo`03o`2Ioooooooo06_oool008Soool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`09oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol0
01@co`000`000?ooooooo`09oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol001<co`00
0`000?ooooooo`0:oooo00?o09Woooooool0Joooo`00Soooo`80000D<ol000<0003oooooool02_oo
o`03o`2Ioooooooo06_oool008ooool00`0003?o03?o000C<ol000<0003oooooool02_ooo`03o`2I
oooooooo06_oool008ooool00`0003?o03?o000B<ol000<0003oooooool02oooo`03o`2Ioooooooo
06_oool008ooool00`0003?o03?o000B<ol000<0003oooooool02oooo`03o`2Ioooooooo06_oool0
08ooool00`0003?o03?o000B<ol000<0003oooooool02oooo`03o`2Ioooooooo06_oool008ooool0
0`0003?o03?o000A<ol000<0003oooooool03?ooo`03o`2Ioooooooo06_oool008ooool200004S?o
00030000oooooooo00coool00ol0VOooooooo`1[oooo002?oooo00<0000co`0co`004C?o00030000
oooooooo00coool00ol0VOooooooo`1[oooo002?oooo00<0000co`0co`004C?o00030000oooooooo
00coool00ol0VOooooooo`1[oooo002?oooo00<0000co`0co`0043?o00030000oooooooo00goool0
0ol0VOooooooo`1[oooo002?oooo00<0000co`0co`0043?o00030000oooooooo00goool00ol0VOoo
ooooo`1[oooo002?oooo00<0000co`0co`0043?o00030000oooooooo00goool00ol0VOooooooo`1[
oooo002?oooo00<0000co`0co`0043?o00030000oooooooo00goool00ol0VOooooooo`1[oooo002?
oooo0P00010co`000`000?ooooooo`0>oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol0
00lco`000`000?ooooooo`0>oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol000lco`00
0`000?ooooooo`0>oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol000lco`000`000?oo
ooooo`0>oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0>
oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0?oooo00?o
09Woooooool0Joooo`00Soooo`80000?<ol000<0003oooooool03oooo`03o`2Ioooooooo06_oool0
08ooool00`0003?o03?o000><ol000<0003oooooool03oooo`03o`2Ioooooooo06_oool008ooool0
0`0003?o03?o000><ol000<0003oooooool03oooo`03o`2Ioooooooo06_oool008ooool00`0003?o
03?o000=<ol000<0003oooooool04?ooo`03o`2Ioooooooo06_oool008Ooool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`0@oooo00?o09Woooooool0Joooo`00Qoooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool04?ooo`03o`2Ioooooooo06_oool008Soool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`0@oooo00?o09Woooooool0Joooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool04?ooo`03o`2Ioooooooo
06_oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool04Ooo
o`03o`2Ioooooooo06_oool008Soool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`0A
oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0Aoooo00?o
09Woooooool0Joooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0Aoooo00?o09Wooooo
ool0Joooo`00Soooo`80000=<ol000<0003oooooool04Oooo`03o`2Ioooooooo06_oool008ooool0
0`0003?o03?o000<<ol000<0003oooooool04Oooo`03o`2Ioooooooo06_oool008ooool00`0003?o
03?o000;<ol000<0003oooooool04_ooo`03o`2Ioooooooo06_oool008ooool00`0003?o03?o000;
<ol000<0003oooooool04_ooo`03o`2Ioooooooo06_oool008ooool00`0003?o03?o000;<ol000<0
003oooooool04_ooo`03o`2Ioooooooo06_oool008ooool00`0003?o03?o000;<ol000<0003ooooo
ool04_ooo`03o`2Ioooooooo06_oool008ooool00`0003?o03?o000;<ol000<0003oooooool04_oo
o`03o`2Ioooooooo06_oool008ooool2000033?o00030000oooooooo01;oool00ol0VOooooooo`1[
oooo002?oooo00<0000co`0co`002c?o00030000oooooooo01;oool00ol0VOooooooo`1[oooo002?
oooo00<0000co`0co`002S?o00030000oooooooo01?oool00ol0VOooooooo`1[oooo002?oooo00<0
000co`0co`002S?o00030000oooooooo01?oool00ol0VOooooooo`1[oooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo01?oool00ol0VOooooooo`1[oooo002?oooo00<0000co`0co`002S?o
00030000oooooooo01?oool00ol0VOooooooo`1[oooo002?oooo0P0000/co`000`000?ooooooo`0C
oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Coooo00?o
09Woooooool0Joooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Coooo00?o09Wooooo
ool0Joooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0Doooo00?o09Woooooool0Jooo
o`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0Doooo00?o09Woooooool0Joooo`00Sooo
o`030000<ol0<ol000Tco`000`000?ooooooo`0Doooo00?o09Woooooool0Joooo`00Soooo`80000:
<ol000<0003oooooool05?ooo`03o`2Ioooooooo06_oool008ooool00`0003?o03?o0009<ol000<0
003oooooool05?ooo`03o`2Ioooooooo06_oool008ooool00`0003?o03?o0009<ol000<0003ooooo
ool05?ooo`03o`2Ioooooooo06_oool008ooool00`0003?o03?o0008<ol000<0003oooooool05Ooo
o`03o`2Ioooooooo06_oool008Soool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`0E
oooo00?o09Woooooool0Joooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0Eoooo00?o09Woooooool0Joooo`00ROooo`030000oooooooo00?oool3000023?o
00030000oooooooo01Goool00ol0VOooooooo`1[oooo002:oooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`0Eoooo00?o09Woooooool0Joooo`00Qoooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0Eoooo00?o09Woooooool0Joooo`00R?oo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo01Koool00ol0VOooooooo`1[oooo002?
oooo00<0000co`0co`001c?o00030000oooooooo01Koool00ol0VOooooooo`1[oooo002?oooo00<0
000co`0co`001c?o00030000oooooooo01Koool00ol0VOooooooo`1[oooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo01Koool00ol0VOooooooo`1[oooo002?oooo0P0000Pco`000`000?oo
ooooo`0Foooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0F
oooo00?o09Woooooool0Joooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Foooo00?o
09Woooooool0Joooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Foooo00?o09Wooooo
ool0Joooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0Goooo00?o09Woooooool0Jooo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0Goooo00?o09Woooooool0Joooo`00Sooo
o`800007<ol000<0003oooooool05oooo`03o`2Ioooooooo06_oool008ooool00`0003?o03?o0006
<ol000<0003oooooool05oooo`03o`2Ioooooooo06_oool008ooool00`0003?o03?o0006<ol000<0
003oooooool05oooo`03o`2Ioooooooo06_oool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool05oooo`03o`2Ioooooooo06_oool008ooool00`0003?o03?o0006<ol000<0003oooooool05ooo
o`03o`2Ioooooooo06_oool008ooool00`0003?o03?o0006<ol000<0003oooooool05oooo`03o`2I
oooooooo06_oool008ooool200001S?o00030000oooooooo01Soool00ol0VOooooooo`1[oooo002?
oooo00<0000co`0co`001C?o00030000oooooooo01Soool00ol0VOooooooo`1[oooo002?oooo00<0
000co`0co`001C?o00030000oooooooo01Soool00ol0VOooooooo`1[oooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo01Soool00ol0VOooooooo`1[oooo002?oooo00<0000co`0co`001C?o
00030000oooooooo01Soool00ol0VOooooooo`1[oooo002?oooo00<0000co`0co`001C?o00030000
oooooooo01Soool00ol0VOooooooo`1[oooo002?oooo0P0000Hco`000`000?ooooooo`0Hoooo00?o
09Woooooool0Joooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Hoooo00?o09Wooooo
ool0Joooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Hoooo00?o09Woooooool0Jooo
o`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0Ioooo00?o09Woooooool0Joooo`00Sooo
o`030000<ol0<ol000@co`000`000?ooooooo`0Ioooo00?o09Woooooool0Joooo`00ROooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo01Woool00ol0VOooooooo`1[oooo002:oooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`0Ioooo00?o09Woooooool0Jooo
o`00Qoooo`D00003oooo0`0000@co`000`000?ooooooo`0Ioooo00?o09Woooooool0Joooo`00Qooo
o`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029
oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?oo
ooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo1@00008co`02000000@co`3oooooooooool200001?ooo`800004
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01oooo`030000<ol0<ol000Dco`02oooo00@0003oooooool00002oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0?oooo00<0000co`0co`001C?o00Goool010000?ooooooo`0000;oool00`000?ooooooo`02
oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0000co`0co`001C?o
00?oool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
017oool00`0003?o03?o0005<ol00oooo`030000oooooooo00;oool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007<ol00oooo`<00003oooo0P00
00?oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.61984 .12361 L
.6298 .12361 L
.63527 .12361 L
.63796 .12361 L
.64043 .12361 L
.64164 .12361 L
.64277 .12361 L
s
.64277 .12361 m
.64324 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.33304 .12361 L
.34309 .12361 L
.34772 .12361 L
.35028 .12361 L
.35271 .12361 L
.35496 .12361 L
.35624 .12361 L
.35742 .12332 L
.35852 .12219 L
.35951 .12119 L
.36173 .11898 L
.3815 .10191 L
.40075 .08916 L
.42157 .0789 L
.4415 .07186 L
.45155 .06917 L
.46257 .06681 L
.47277 .06509 L
.48208 .06388 L
.48722 .06335 L
.49282 .06287 L
.49807 .06251 L
.50299 .0622 L
.50752 .06182 L
.51239 .06131 L
.52277 .05992 L
.54378 .05619 L
.58492 .0472 L
.60544 .04254 L
.61545 .04033 L
.62454 .03839 L
.62909 .03745 L
.63402 .03645 L
.63628 .03601 L
.63867 .03554 L
.64072 .03515 L
.64188 .03493 L
.64296 .12361 L
.64418 .12361 L
.64551 .12361 L
.64792 .12361 L
Mistroke
.65245 .12361 L
.66265 .12361 L
.70335 .12361 L
.74253 .12361 L
.78416 .12361 L
.82428 .12361 L
.86288 .12361 L
.90394 .12361 L
.94348 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool07oooo`<0I_m/oooo002?oooo00<0003oooooool06_ooo`D0I_l2oooo00<0I_oooooo
ool0J_ooo`00Soooo`030000oooooooo01Koool406Ko1oooo`0306Kooooooooo06[oool008ooool0
0`000?ooooooo`0Aoooo1@1Vo`_oool00`1Vooooooooo`1Zoooo002?oooo0P0000coool606Ko4?oo
o`0306Kooooooooo06[oool008ooool00`000?ooooooo`06oooo1@1VoaKoool00`1Vooooooooo`1Z
oooo002?oooo00<0003oooooool00_ooo`@0I_lKoooo00<0I_ooooooool0J_ooo`00R_ooo`D0I_l0
0`00001Vo`1Vo`0206Ko7oooo`0306Kooooooooo06[oool008Goool506Ko1Oooo`030000oooooooo
027oool00`1Vooooooooo`1Zoooo001ooooo1P1Vo`[oool00`000?ooooooo`0Qoooo00<0I_oooooo
ool0J_ooo`00OOooo`80I_l@oooo0P0002;oool00`1Vooooooooo`1Zoooo000Goooo100003Woool5
00008_ooo`80I_lBoooo00<0003oooooool08Oooo`0306Kooooooooo01?oool50000>?ooo`@0000F
oooo000Goooo00<0003oooooool0??ooo`030000oooooooo023oool206Ko5?ooo`030000oooooooo
027oool00`1Vooooooooo`0Eoooo00<0003oooooool0>?ooo`030000oooooooo01Ooool001Soool0
0`000?ooooooo`0koooo00<0003oooooool07_ooo`80I_lFoooo00<0003oooooool08Oooo`0306Ko
oooooooo01Goool00`000?ooooooo`0ioooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0
003oooooool0<_ooo`@00004oooo00<0003oooooool07Oooo`0306Kooooooooo01Koool00`000?oo
ooooo`0Qoooo00<0I_ooooooool05Oooo`030000oooooooo03[oool00`000?ooooooo`0Eoooo000G
oooo00@0003oooooool0000koooo00<0003oooooool06oooo`80I_lIoooo00<0003oooooool08Ooo
o`0306Kooooooooo01Goool00`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo0P00
03_oool200006oooo`80I_lKoooo0P0002;oool00`1Vooooooooo`0Doooo0P0003_oool200005ooo
o`00LOooo`0306Kooooooooo01_oool00`000?ooooooo`0Qoooo00<0I_ooooooool0J_ooo`00L?oo
o`0306Kooooooooo01coool00`000?ooooooo`0Qoooo00<0I_ooooooool0J_ooo`00K_ooo`80I_lO
oooo00<0003oooooool08Oooo`0306Kooooooooo06[oool006goool00`1Vooooooooo`0Ooooo00<0
003oooooool08Oooo`0306Kooooooooo06[oool006coool00`1Vooooooooo`0Poooo00<0003ooooo
ool08Oooo`0306Kooooooooo06[oool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R
00001_ooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_oo
o`030000oooooooo03Woool00`0003?o03?o000Q<ol000?o09Tco`0co`005C?o00T0000doooo00<0
003oooooool05Oooo`00Soooo`030000<ol0<ol0024co`000ol0VC?o03?o000?<ol01P0005Goool0
08ooool00`0003?o03?o000Q<ol000?o09Tco`0co`003C?o0080001Koooo002?oooo00<0000co`0c
o`008C?o0003o`2I<ol0<ol000/co`020000GOooo`00Soooo`030000<ol0<ol0024co`000ol0VC?o
03?o0008<ol00`0005ooool008ooool200008S?o0003o`2I<ol0<ol000Dco`030000H_ooo`00Sooo
o`030000<ol0<ol0024co`000ol0VC?o03?o0003<ol00P0006Goool008ooool00`0003?o03?o000Q
<ol000?o09Tco`0co`000S?o00030000oooooooo06Goool008ooool00`0003?o03?o000Q<ol000Go
09Tco`0co`0co`000000J?ooo`00Soooo`030000<ol0<ol0024co`001?l0VC?o03?o000006Woool0
08ooool00`0003?o03?o000Q<ol000?o09T000000000J_ooo`00Soooo`80000R<ol000?o09Wooooo
ool0J_ooo`00Soooo`030000<ol0<ol0020co`000`000?l0VOooo`1[oooo002?oooo00<0000co`0c
o`007c?o00030000ooooo`2I06coool008ooool00`0003?o03?o000O<ol000<0003ooooo09T0K?oo
o`00Soooo`030000<ol0<ol001hco`0010000?ooooooool0VFcoool008ooool00`0003?o03?o000M
<ol000D0003ooooooooooooo09T0K?ooo`00Soooo`80000M<ol000<0003oooooool00_ooo`03o`2I
oooooooo06[oool008ooool00`0003?o03?o000K<ol000<0003oooooool00oooo`03o`2Ioooooooo
06[oool008ooool00`0003?o03?o000K<ol000<0003oooooool00oooo`03o`2Ioooooooo06[oool0
08ooool00`0003?o03?o000J<ol000<0003oooooool01?ooo`03o`2Ioooooooo06[oool008ooool0
0`0003?o03?o000J<ol000<0003oooooool01?ooo`03o`2Ioooooooo06[oool008ooool00`0003?o
03?o000I<ol000<0003oooooool01Oooo`03o`2Ioooooooo06[oool008ooool200006S?o00030000
oooooooo00Goool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`0063?o00030000oooooooo
00Koool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`0063?o00030000oooooooo00Koool0
0ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`005c?o00030000oooooooo00Ooool00ol0VOoo
ooooo`1Zoooo002?oooo00<0000co`0co`005c?o00030000oooooooo00Ooool00ol0VOooooooo`1Z
oooo0027oooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool02?ooo`03o`2Ioooooooo
06[oool008Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo00Soool0
0ol0VOooooooo`1Zoooo0029oooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool02Ooo
o`03o`2Ioooooooo06[oool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000
oooooooo00Woool00ol0VOooooooo`1Zoooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`09oooo00?o09Woooooool0J_ooo`00R?ooo`800005oooo00<0000co`0c
o`0053?o00030000oooooooo00[oool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`0053?o
00030000oooooooo00[oool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`004c?o00030000
oooooooo00_oool00ol0VOooooooo`1Zoooo002?oooo0P0001@co`000`000?ooooooo`0;oooo00?o
09Woooooool0J_ooo`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`0;oooo00?o09Wooooo
ool0J_ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0<oooo00?o09Woooooool0J_oo
o`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0<oooo00?o09Woooooool0J_ooo`00Sooo
o`030000<ol0<ol0018co`000`000?ooooooo`0<oooo00?o09Woooooool0J_ooo`00Soooo`030000
<ol0<ol0014co`000`000?ooooooo`0=oooo00?o09Woooooool0J_ooo`00Soooo`80000B<ol000<0
003oooooool03Oooo`03o`2Ioooooooo06[oool008ooool00`0003?o03?o000A<ol000<0003ooooo
ool03Oooo`03o`2Ioooooooo06[oool008ooool00`0003?o03?o000A<ol000<0003oooooool03Ooo
o`03o`2Ioooooooo06[oool008ooool00`0003?o03?o000@<ol000<0003oooooool03_ooo`03o`2I
oooooooo06[oool008ooool00`0003?o03?o000@<ol000<0003oooooool03_ooo`03o`2Ioooooooo
06[oool008ooool00`0003?o03?o000@<ol000<0003oooooool03_ooo`03o`2Ioooooooo06[oool0
08ooool00`0003?o03?o000@<ol000<0003oooooool03_ooo`03o`2Ioooooooo06[oool008ooool2
000043?o00030000oooooooo00ooool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`003c?o
00030000oooooooo00ooool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`003c?o00030000
oooooooo00ooool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`003c?o00030000oooooooo
00ooool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`003c?o00030000oooooooo00ooool0
0ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`003S?o00030000oooooooo013oool00ol0VOoo
ooooo`1Zoooo002?oooo0P0000lco`000`000?ooooooo`0@oooo00?o09Woooooool0J_ooo`00Sooo
o`030000<ol0<ol000hco`000`000?ooooooo`0@oooo00?o09Woooooool0J_ooo`00Soooo`030000
<ol0<ol000hco`000`000?ooooooo`0@oooo00?o09Woooooool0J_ooo`00Soooo`030000<ol0<ol0
00dco`000`000?ooooooo`0Aoooo00?o09Woooooool0J_ooo`00Qoooo`@00004oooo00<0000co`0c
o`003C?o00030000oooooooo017oool00ol0VOooooooo`1Zoooo0027oooo00<0003oooooool01Ooo
o`030000<ol0<ol000dco`000`000?ooooooo`0Aoooo00?o09Woooooool0J_ooo`00R?ooo`030000
oooooooo00Coool300003C?o00030000oooooooo017oool00ol0VOooooooo`1Zoooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`0Aoooo00?o09Woooooool0J_oo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`0Boooo00?o
09Woooooool0J_ooo`00R?ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo01;oool0
0ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`0033?o00030000oooooooo01;oool00ol0VOoo
ooooo`1Zoooo002?oooo00<0000co`0co`0033?o00030000oooooooo01;oool00ol0VOooooooo`1Z
oooo002?oooo0P0000dco`000`000?ooooooo`0Boooo00?o09Woooooool0J_ooo`00Soooo`030000
<ol0<ol000`co`000`000?ooooooo`0Boooo00?o09Woooooool0J_ooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`0Coooo00?o09Woooooool0J_ooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`0Coooo00?o09Woooooool0J_ooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`0Coooo00?o09Woooooool0J_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0C
oooo00?o09Woooooool0J_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0Coooo00?o
09Woooooool0J_ooo`00Soooo`80000<<ol000<0003oooooool04oooo`03o`2Ioooooooo06[oool0
08ooool00`0003?o03?o000;<ol000<0003oooooool04oooo`03o`2Ioooooooo06[oool008ooool0
0`0003?o03?o000:<ol000<0003oooooool05?ooo`03o`2Ioooooooo06[oool008ooool00`0003?o
03?o000:<ol000<0003oooooool05?ooo`03o`2Ioooooooo06[oool008ooool00`0003?o03?o000:
<ol000<0003oooooool05?ooo`03o`2Ioooooooo06[oool008ooool00`0003?o03?o000:<ol000<0
003oooooool05?ooo`03o`2Ioooooooo06[oool008ooool200002c?o00030000oooooooo01Coool0
0ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`002S?o00030000oooooooo01Coool00ol0VOoo
ooooo`1Zoooo002?oooo00<0000co`0co`002S?o00030000oooooooo01Coool00ol0VOooooooo`1Z
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo01Goool00ol0VOooooooo`1Zoooo002?
oooo00<0000co`0co`002C?o00030000oooooooo01Goool00ol0VOooooooo`1Zoooo002?oooo00<0
000co`0co`002C?o00030000oooooooo01Goool00ol0VOooooooo`1Zoooo002?oooo0P0000Xco`00
0`000?ooooooo`0Eoooo00?o09Woooooool0J_ooo`00Soooo`030000<ol0<ol000Tco`000`000?oo
ooooo`0Eoooo00?o09Woooooool0J_ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0E
oooo00?o09Woooooool0J_ooo`00Soooo`030000<ol0<ol000Pco`000`000?ooooooo`0Foooo00?o
09Woooooool0J_ooo`00R?ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo01Koool0
0ol0VOooooooo`1Zoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000
oooooooo01Koool00ol0VOooooooo`1Zoooo0029oooo00<0003oooooool00oooo`<00008<ol000<0
003oooooool05_ooo`03o`2Ioooooooo06[oool008[oool00`000?ooooooo`02oooo00<0000co`0c
o`0023?o00030000oooooooo01Koool00ol0VOooooooo`1Zoooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0023?o00030000oooooooo01Koool00ol0VOooooooo`1Zoooo0028oooo0P00
00Goool00`0003?o03?o0007<ol000<0003oooooool05oooo`03o`2Ioooooooo06[oool008ooool0
0`0003?o03?o0007<ol000<0003oooooool05oooo`03o`2Ioooooooo06[oool008ooool00`0003?o
03?o0007<ol000<0003oooooool05oooo`03o`2Ioooooooo06[oool008ooool00`0003?o03?o0007
<ol000<0003oooooool05oooo`03o`2Ioooooooo06[oool008ooool2000023?o00030000oooooooo
01Ooool00ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`001c?o00030000oooooooo01Ooool0
0ol0VOooooooo`1Zoooo002?oooo00<0000co`0co`001c?o00030000oooooooo01Ooool00ol0VOoo
ooooo`1Zoooo002?oooo00<0000co`0co`001c?o00030000oooooooo01Ooool00ol0VOooooooo`1Z
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo01Soool00ol0VOooooooo`1Zoooo002?
oooo00<0000co`0co`001S?o00030000oooooooo01Soool00ol0VOooooooo`1Zoooo002?oooo0P00
00Lco`000`000?ooooooo`0Hoooo00?o09Woooooool0J_ooo`00Soooo`030000<ol0<ol000Hco`00
0`000?ooooooo`0Hoooo00?o09Woooooool0J_ooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`0Hoooo00?o09Woooooool0J_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0H
oooo00?o09Woooooool0J_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0Hoooo00?o
09Woooooool0J_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0Hoooo00?o09Wooooo
ool0J_ooo`00Soooo`800006<ol000<0003oooooool06Oooo`03o`2Ioooooooo06[oool008ooool0
0`0003?o03?o0005<ol000<0003oooooool06Oooo`03o`2Ioooooooo06[oool008ooool00`0003?o
03?o0005<ol000<0003oooooool06Oooo`03o`2Ioooooooo06[oool008ooool00`0003?o03?o0005
<ol000<0003oooooool06Oooo`03o`2Ioooooooo06[oool008ooool00`0003?o03?o0005<ol000<0
003oooooool06Oooo`03o`2Ioooooooo06[oool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool06Oooo`03o`2Ioooooooo06[oool008ooool200001S?o00030000oooooooo01Woool00ol0VOoo
ooooo`1Zoooo002?oooo00<0000co`0co`001C?o00030000oooooooo01Woool00ol0VOooooooo`1Z
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo01Woool00ol0VOooooooo`1Zoooo002?
oooo00<0000co`0co`0013?o00030000oooooooo01[oool00ol0VOooooooo`1Zoooo002?oooo00<0
000co`0co`0013?o00030000oooooooo01[oool00ol0VOooooooo`1Zoooo0029oooo0`0000?oool0
0`0003?o03?o0004<ol000<0003oooooool06_ooo`03o`2Ioooooooo06[oool008[oool00`000?oo
ooooo`02oooo00<0000co`0co`0013?o00030000oooooooo01[oool00ol0VOooooooo`1Zoooo0027
oooo1@0000?oool3000013?o00030000oooooooo01[oool00ol0VOooooooo`1Zoooo0027oooo00@0
003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool2
00001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00O?ooo`030000oooooooo
013oool7<ol02oooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003ooooo
ool01_ooo`Lco`0<oooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool500000S?o00800003oooo0`0000Coool00`000?ooooooo`1koooo001k
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo0S?o
00030000<ol0<ol0008co`05oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_oo
o`030000oooooooo00;oool00`000?ooooooo`0=oooo0S?o00030000<ol0<ol0008co`05oooo00@0
003oooooool00004oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<oooo0S?o
00030000<ol0<ol0008co`05oooo0`0000Coool00`000?ooooooo`1koooo001koooo00D0003ooooo
ooooool000003oooo`8co`000`0003?o03?o0002<ol01_ooo`030000oooooooo00?oool00`000?oo
ooooo`1koooo001loooo00<0003oooooool04?ooo`03<ol00000000000@co`06oooo0`0000;oool0
0`000?ooooooo`1loooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.62) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.61984 .12361 L
.6298 .12361 L
.63527 .12361 L
.64043 .12361 L
.64277 .12361 L
.64524 .12361 L
.64654 .12361 L
.64727 .12361 L
s
.64727 .12361 m
.64755 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.33304 .12361 L
.33788 .12361 L
.34309 .12361 L
.34566 .12361 L
.34811 .12361 L
.35031 .12361 L
.35156 .12361 L
.35271 .12326 L
.35389 .12205 L
.355 .12093 L
.35708 .11887 L
.36173 .11445 L
.3815 .09842 L
.40158 .08607 L
.42005 .07758 L
.43887 .07124 L
.44956 .06852 L
.45954 .06648 L
.46999 .06481 L
.47989 .0636 L
.48878 .06281 L
.4938 .06248 L
.49845 .06223 L
.50308 .062 L
.50568 .06183 L
.50807 .06164 L
.51711 .06069 L
.52715 .05929 L
.53771 .05752 L
.57582 .04966 L
.59707 .04487 L
.61638 .04059 L
.62602 .03853 L
.63647 .0364 L
.64126 .03546 L
.64388 .03496 L
.64516 .03472 L
.64633 .0345 L
.6474 .03431 L
.64842 .12361 L
.64949 .12361 L
Mistroke
.65066 .12361 L
.65543 .12361 L
.69612 .12361 L
.73531 .12361 L
.77694 .12361 L
.81706 .12361 L
.85566 .12361 L
.89672 .12361 L
.93626 .12361 L
.97428 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.62) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool07oooo`@0I_m[oooo002?oooo00<0003oooooool06Oooo`H0I_l3oooo00<0I_oooooo
ool0JOooo`00Soooo`030000oooooooo01Goool406Ko2Oooo`0306Kooooooooo06Woool008ooool0
0`000?ooooooo`0Boooo0`1Vo`goool00`1Vooooooooo`1Yoooo002?oooo0P0000ooool406Ko4?oo
o`0306Kooooooooo06Woool008ooool00`000?ooooooo`0:oooo101VoaCoool00`1Vooooooooo`1Y
oooo002?oooo00@0003oooooooooool906Ko6?ooo`0306Kooooooooo06Woool008Ooool806Ko00@0
0000I_l0I_l0I_lQoooo00<0I_ooooooool0JOooo`00POooo`H0I_l8oooo00<0003oooooool08_oo
o`0306Kooooooooo06Woool007ooool206Ko3_ooo`030000oooooooo02;oool00`1Vooooooooo`1Y
oooo001moooo0P1Voa3oool200008oooo`0306Kooooooooo06Woool001Ooool40000>Oooo`D0000Q
oooo0`1Voa;oool00`000?ooooooo`0Roooo00<0I_ooooooool04_ooo`D0000hoooo100001Koool0
01Ooool00`000?ooooooo`0loooo00<0003oooooool07oooo`80I_lEoooo00<0003oooooool08ooo
o`0306Kooooooooo01?oool00`000?ooooooo`0hoooo00<0003oooooool05oooo`006?ooo`030000
oooooooo03_oool00`000?ooooooo`0Moooo0P1VoaOoool00`000?ooooooo`0Soooo00<0I_oooooo
ool04oooo`030000oooooooo03Woool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?oo
ooooo`0boooo100000Coool00`000?ooooooo`0Koooo0P1VoaWoool00`000?ooooooo`0Soooo00<0
I_ooooooool04oooo`030000oooooooo03[oool00`000?ooooooo`0Eoooo000Goooo00@0003ooooo
ool0000koooo00<0003oooooool06Oooo`80I_lKoooo00<0003oooooool08oooo`0306Kooooooooo
01?oool00`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo0P0003_oool200006_oo
o`0306Kooooooooo01_oool200009?ooo`0306Kooooooooo01;oool20000>oooo`80000Goooo001`
oooo00<0I_ooooooool07?ooo`030000oooooooo02?oool00`1Vooooooooo`1Xoooo001^oooo0P1V
oaooool00`000?ooooooo`0Soooo00<0I_ooooooool0J?ooo`00KOooo`0306Kooooooooo01ooool0
0`000?ooooooo`0Soooo00<0I_ooooooool0J?ooo`00K?ooo`0306Kooooooooo023oool00`000?oo
ooooo`0Soooo00<0I_ooooooool0J?ooo`00Joooo`0306Kooooooooo027oool00`000?ooooooo`0S
oooo00<0I_ooooooool0J?ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000o`2I<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o02800006
oooo00<0003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0
003oooooool0>Oooo`030000<ol0<ol0028co`000ol0VC?o03?o000D<ol02@0003Coool00`000?oo
ooooo`0Eoooo002?oooo00<0000co`0co`008S?o0003o`2I<ol0<ol000hco`060000EOooo`00Sooo
o`030000<ol0<ol0028co`000ol0VC?o03?o000<<ol00P0005_oool008ooool00`0003?o03?o000R
<ol000?o09Tco`0co`002S?o0080001Moooo002?oooo00<0000co`0co`008S?o0003o`2I<ol0<ol0
00Lco`030000Goooo`00Soooo`80000S<ol000?o09Tco`0co`0013?o00<0001Roooo002?oooo00<0
000co`0co`008S?o0003o`2I<ol0<ol0008co`020000IOooo`00Soooo`030000<ol0<ol0028co`00
1Ol0VC?o03?o03?o0000001Woooo002?oooo00<0000co`0co`008S?o0004o`2I<ol0<ol00000J?oo
o`00Soooo`030000<ol0<ol0028co`000ol0VC?o0000001Yoooo002?oooo00<0000co`0co`008S?o
0003o`2I0000oooo06Woool008ooool200008S?o00030000o`2Ioooo06[oool008ooool00`0003?o
03?o000P<ol000<0003ooooo09T0Joooo`00Soooo`030000<ol0<ol001lco`0010000?ooooooool0
VF_oool008ooool00`0003?o03?o000O<ol000@0003ooooooooo09U[oooo002?oooo00<0000co`0c
o`007S?o00050000ooooooooooooo`2I06_oool008ooool00`0003?o03?o000M<ol000<0003ooooo
ool00_ooo`03o`2Ioooooooo06Woool008ooool200007C?o00030000oooooooo00?oool00ol0VOoo
ooooo`1Yoooo002?oooo00<0000co`0co`006c?o00030000oooooooo00Coool00ol0VOooooooo`1Y
oooo002?oooo00<0000co`0co`006c?o00030000oooooooo00Coool00ol0VOooooooo`1Yoooo002?
oooo00<0000co`0co`006S?o00030000oooooooo00Goool00ol0VOooooooo`1Yoooo002?oooo00<0
000co`0co`006S?o00030000oooooooo00Goool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0c
o`006C?o00030000oooooooo00Koool00ol0VOooooooo`1Yoooo002?oooo0P0001Xco`000`000?oo
ooooo`06oooo00?o09Woooooool0JOooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`07
oooo00?o09Woooooool0JOooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`07oooo00?o
09Woooooool0JOooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`08oooo00?o09Wooooo
ool0JOooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`08oooo00?o09Woooooool0JOoo
o`00Qoooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo00Woool00ol0VOooooooo`1Y
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`09oooo00?o
09Woooooool0JOooo`00ROooo`030000oooooooo00?oool300005C?o00030000oooooooo00[oool0
0ol0VOooooooo`1Yoooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?oo
ooooo`0:oooo00?o09Woooooool0JOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E
<ol000<0003oooooool02_ooo`03o`2Ioooooooo06Woool008Soool200001Oooo`030000<ol0<ol0
01@co`000`000?ooooooo`0;oooo00?o09Woooooool0JOooo`00Soooo`030000<ol0<ol001@co`00
0`000?ooooooo`0;oooo00?o09Woooooool0JOooo`00Soooo`030000<ol0<ol001<co`000`000?oo
ooooo`0<oooo00?o09Woooooool0JOooo`00Soooo`80000D<ol000<0003oooooool03?ooo`03o`2I
oooooooo06Woool008ooool00`0003?o03?o000C<ol000<0003oooooool03?ooo`03o`2Ioooooooo
06Woool008ooool00`0003?o03?o000B<ol000<0003oooooool03Oooo`03o`2Ioooooooo06Woool0
08ooool00`0003?o03?o000B<ol000<0003oooooool03Oooo`03o`2Ioooooooo06Woool008ooool0
0`0003?o03?o000B<ol000<0003oooooool03Oooo`03o`2Ioooooooo06Woool008ooool00`0003?o
03?o000A<ol000<0003oooooool03_ooo`03o`2Ioooooooo06Woool008ooool200004S?o00030000
oooooooo00koool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`004C?o00030000oooooooo
00koool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`004C?o00030000oooooooo00koool0
0ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`0043?o00030000oooooooo00ooool00ol0VOoo
ooooo`1Yoooo002?oooo00<0000co`0co`0043?o00030000oooooooo00ooool00ol0VOooooooo`1Y
oooo002?oooo00<0000co`0co`0043?o00030000oooooooo00ooool00ol0VOooooooo`1Yoooo002?
oooo00<0000co`0co`0043?o00030000oooooooo00ooool00ol0VOooooooo`1Yoooo002?oooo0P00
010co`000`000?ooooooo`0@oooo00?o09Woooooool0JOooo`00Soooo`030000<ol0<ol000lco`00
0`000?ooooooo`0@oooo00?o09Woooooool0JOooo`00Soooo`030000<ol0<ol000lco`000`000?oo
ooooo`0@oooo00?o09Woooooool0JOooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0@
oooo00?o09Woooooool0JOooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0@oooo00?o
09Woooooool0JOooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Aoooo00?o09Wooooo
ool0JOooo`00Soooo`80000?<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Woool008ooool0
0`0003?o03?o000><ol000<0003oooooool04Oooo`03o`2Ioooooooo06Woool008ooool00`0003?o
03?o000><ol000<0003oooooool04Oooo`03o`2Ioooooooo06Woool008ooool00`0003?o03?o000=
<ol000<0003oooooool04_ooo`03o`2Ioooooooo06Woool008Ooool400001?ooo`030000<ol0<ol0
00dco`000`000?ooooooo`0Boooo00?o09Woooooool0JOooo`00Qoooo`030000oooooooo00Goool0
0`0003?o03?o000=<ol000<0003oooooool04_ooo`03o`2Ioooooooo06Woool008Soool00`000?oo
ooooo`04oooo0`0000dco`000`000?ooooooo`0Boooo00?o09Woooooool0JOooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool04_ooo`03o`2Ioooooooo06Woool0
08Ooool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool04oooo`03o`2I
oooooooo06Woool008Soool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`0Coooo00?o
09Woooooool0JOooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0Coooo00?o09Wooooo
ool0JOooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0Coooo00?o09Woooooool0JOoo
o`00Soooo`80000=<ol000<0003oooooool04oooo`03o`2Ioooooooo06Woool008ooool00`0003?o
03?o000<<ol000<0003oooooool04oooo`03o`2Ioooooooo06Woool008ooool00`0003?o03?o000;
<ol000<0003oooooool05?ooo`03o`2Ioooooooo06Woool008ooool00`0003?o03?o000;<ol000<0
003oooooool05?ooo`03o`2Ioooooooo06Woool008ooool00`0003?o03?o000;<ol000<0003ooooo
ool05?ooo`03o`2Ioooooooo06Woool008ooool00`0003?o03?o000;<ol000<0003oooooool05?oo
o`03o`2Ioooooooo06Woool008ooool00`0003?o03?o000;<ol000<0003oooooool05?ooo`03o`2I
oooooooo06Woool008ooool2000033?o00030000oooooooo01Coool00ol0VOooooooo`1Yoooo002?
oooo00<0000co`0co`002c?o00030000oooooooo01Coool00ol0VOooooooo`1Yoooo002?oooo00<0
000co`0co`002S?o00030000oooooooo01Goool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo01Goool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`002S?o
00030000oooooooo01Goool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`002S?o00030000
oooooooo01Goool00ol0VOooooooo`1Yoooo002?oooo0P0000/co`000`000?ooooooo`0Eoooo00?o
09Woooooool0JOooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Eoooo00?o09Wooooo
ool0JOooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Eoooo00?o09Woooooool0JOoo
o`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0Foooo00?o09Woooooool0JOooo`00Sooo
o`030000<ol0<ol000Tco`000`000?ooooooo`0Foooo00?o09Woooooool0JOooo`00Soooo`030000
<ol0<ol000Tco`000`000?ooooooo`0Foooo00?o09Woooooool0JOooo`00Soooo`80000:<ol000<0
003oooooool05_ooo`03o`2Ioooooooo06Woool008ooool00`0003?o03?o0009<ol000<0003ooooo
ool05_ooo`03o`2Ioooooooo06Woool008ooool00`0003?o03?o0009<ol000<0003oooooool05_oo
o`03o`2Ioooooooo06Woool008ooool00`0003?o03?o0008<ol000<0003oooooool05oooo`03o`2I
oooooooo06Woool008Soool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`0Goooo00?o
09Woooooool0JOooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0Goooo00?o09Woooooool0JOooo`00ROooo`030000oooooooo00?oool3000023?o00030000
oooooooo01Ooool00ol0VOooooooo`1Yoooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`0Goooo00?o09Woooooool0JOooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`0Goooo00?o09Woooooool0JOooo`00R?ooo`800005
oooo00<0000co`0co`001c?o00030000oooooooo01Soool00ol0VOooooooo`1Yoooo002?oooo00<0
000co`0co`001c?o00030000oooooooo01Soool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo01Soool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`001c?o
00030000oooooooo01Soool00ol0VOooooooo`1Yoooo002?oooo0P0000Pco`000`000?ooooooo`0H
oooo00?o09Woooooool0JOooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Hoooo00?o
09Woooooool0JOooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Hoooo00?o09Wooooo
ool0JOooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Hoooo00?o09Woooooool0JOoo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0Ioooo00?o09Woooooool0JOooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`0Ioooo00?o09Woooooool0JOooo`00Soooo`800007
<ol000<0003oooooool06Oooo`03o`2Ioooooooo06Woool008ooool00`0003?o03?o0006<ol000<0
003oooooool06Oooo`03o`2Ioooooooo06Woool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool06Oooo`03o`2Ioooooooo06Woool008ooool00`0003?o03?o0006<ol000<0003oooooool06Ooo
o`03o`2Ioooooooo06Woool008ooool00`0003?o03?o0006<ol000<0003oooooool06Oooo`03o`2I
oooooooo06Woool008ooool00`0003?o03?o0006<ol000<0003oooooool06Oooo`03o`2Ioooooooo
06Woool008ooool200001S?o00030000oooooooo01[oool00ol0VOooooooo`1Yoooo002?oooo00<0
000co`0co`001C?o00030000oooooooo01[oool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo01[oool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`001C?o
00030000oooooooo01[oool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`001C?o00030000
oooooooo01[oool00ol0VOooooooo`1Yoooo002?oooo00<0000co`0co`001C?o00030000oooooooo
01[oool00ol0VOooooooo`1Yoooo002?oooo0P0000Hco`000`000?ooooooo`0Joooo00?o09Wooooo
ool0JOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Joooo00?o09Woooooool0JOoo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Joooo00?o09Woooooool0JOooo`00Sooo
o`030000<ol0<ol000@co`000`000?ooooooo`0Koooo00?o09Woooooool0JOooo`00Soooo`030000
<ol0<ol000@co`000`000?ooooooo`0Koooo00?o09Woooooool0JOooo`00ROooo`<00003oooo00<0
000co`0co`0013?o00030000oooooooo01_oool00ol0VOooooooo`1Yoooo002:oooo00<0003ooooo
ool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`0Koooo00?o09Woooooool0JOooo`00Qooo
o`D00003oooo0`0000@co`000`000?ooooooo`0Koooo00?o09Woooooool0JOooo`00Qoooo`040000
oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029oooo0P00
00Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?ooooooo`0C
oooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo
00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`06oooo1@00008co`02000000<co`3oooooool00`0000?oool400000oooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Ooool00`0003?o03?o0005<ol00_ooo`040000oooooooo00000_ooo`030000oooooooo
00Coool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00ooool0
0`0003?o03?o0005<ol00_ooo`040000oooooooo00000oooo`030000oooooooo00Coool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0000koool00`0003?o03?o0005<ol00_ooo`<00005
oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000A
oooo00<0000co`0co`001C?o00?oool00`000?ooooooo`02oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo017oool200001c?o00?oool300000oooo`800003
oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.64) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.61984 .12361 L
.6298 .12361 L
.64043 .12361 L
.64559 .12361 L
.64812 .12361 L
.64923 .12361 L
.65045 .12361 L
.65155 .12361 L
s
.65155 .12361 m
.65196 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.32392 .12361 L
.33304 .12361 L
.33788 .12361 L
.34055 .12361 L
.34309 .12361 L
.34549 .12361 L
.34615 .12361 L
.34685 .12361 L
.34811 .1231 L
.34935 .12182 L
.35053 .12064 L
.35271 .11849 L
.36173 .1102 L
.3815 .09517 L
.40158 .08364 L
.42005 .07577 L
.43887 .06996 L
.44956 .06749 L
.45954 .06566 L
.46999 .06418 L
.47989 .06315 L
.48878 .06249 L
.4938 .06222 L
.49845 .06204 L
.5007 .06197 L
.50308 .06187 L
.50568 .06172 L
.50807 .06156 L
.51711 .06071 L
.52695 .05943 L
.53771 .05772 L
.57827 .04954 L
.61732 .04088 L
.62756 .0387 L
.63866 .03644 L
.64376 .03544 L
.64654 .03491 L
.64915 .03442 L
.65029 .03421 L
.65137 .03401 L
.65261 .12361 L
.65375 .12361 L
Mistroke
.65882 .12361 L
.69706 .12361 L
.73776 .12361 L
.77694 .12361 L
.81858 .12361 L
.85869 .12361 L
.8973 .12361 L
.93835 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.64) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool07oooo`D0I_mZoooo002?oooo00<0003oooooool06_ooo`D0I_l4oooo00<0I_oooooo
ool0J?ooo`00Soooo`030000oooooooo01Ooool306Ko2Oooo`0306Kooooooooo06Soool008ooool0
0`000?ooooooo`0Coooo101Vo`coool00`1Vooooooooo`1Xoooo002?oooo0P00013oool406Ko4?oo
o`0306Kooooooooo06Soool008ooool00`000?ooooooo`0:oooo1@1VoaCoool00`1Vooooooooo`1X
oooo002?oooo00@0003oooooooooool906Ko6Oooo`0306Kooooooooo06Soool008Ooool806Ko00@0
0000I_l0I_l0I_lRoooo00<0I_ooooooool0J?ooo`00POooo`H0I_l8oooo00<0003oooooool08ooo
o`0306Kooooooooo06Soool007koool306Ko3_ooo`030000oooooooo02?oool00`1Vooooooooo`1X
oooo001joooo101Voa7oool200009?ooo`0306Kooooooooo06Soool001Ooool40000>Oooo`D0000O
oooo0P1VoaGoool00`000?ooooooo`0Soooo00<0I_ooooooool04Oooo`D0000hoooo100001Koool0
01Ooool00`000?ooooooo`0loooo00<0003oooooool07Oooo`80I_lGoooo00<0003oooooool09?oo
o`0306Kooooooooo01;oool00`000?ooooooo`0hoooo00<0003oooooool05oooo`006?ooo`030000
oooooooo03_oool00`000?ooooooo`0Koooo0P1VoaWoool00`000?ooooooo`0Toooo00<0I_oooooo
ool04_ooo`030000oooooooo03Woool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?oo
ooooo`0boooo100000Coool00`000?ooooooo`0Ioooo0P1Voa_oool00`000?ooooooo`0Toooo00<0
I_ooooooool04_ooo`030000oooooooo03[oool00`000?ooooooo`0Eoooo000Goooo00@0003ooooo
ool0000koooo00<0003oooooool06?ooo`0306Kooooooooo01_oool00`000?ooooooo`0Toooo00<0
I_ooooooool04_ooo`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool20000>ooo
o`80000Ioooo00<0I_ooooooool07?ooo`80000Uoooo00<0I_ooooooool04Oooo`80000koooo0P00
01Ooool006koool206Ko7oooo`030000oooooooo02Coool00`1Vooooooooo`1Woooo001]oooo00<0
I_ooooooool07oooo`030000oooooooo02Coool00`1Vooooooooo`1Woooo001/oooo00<0I_oooooo
ool08?ooo`030000oooooooo02Coool00`1Vooooooooo`1Woooo001[oooo00<0I_ooooooool08Ooo
o`030000oooooooo02Coool00`1Vooooooooo`1Woooo001Zoooo00<0I_ooooooool08_ooo`030000
oooooooo02Coool00`1Vooooooooo`1Woooo000@ooooo`00017oool001Koool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`3o09T02C?o00030000<ol0<ol000Tco`000`0003?o03?o0006
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0ioooo00<0000co`0co`008c?o0003o`2I<ol0<ol001<co`090000=?oo
o`030000oooooooo01Goool008ooool00`0003?o03?o000S<ol000?o09Tco`0co`003C?o00H0001E
oooo002?oooo00<0000co`0co`008c?o0003o`2I<ol0<ol000/co`020000Foooo`00Soooo`030000
<ol0<ol002<co`000ol0VC?o03?o0009<ol00P0005goool008ooool00`0003?o03?o000S<ol000?o
09Tco`0co`001S?o00<0001Ooooo002?oooo0P0002@co`000ol0VC?o03?o0003<ol00`0006;oool0
08ooool00`0003?o03?o000S<ol000Co09Tco`0co`0co`020000IOooo`00Soooo`030000<ol0<ol0
02<co`001?l0VC?o03?o000006Ooool008ooool00`0003?o03?o000S<ol000?o09Tco`000000J?oo
o`00Soooo`030000<ol0<ol002<co`000ol0V@000?ooo`1Xoooo002?oooo00<0000co`0co`008S?o
00030000o`2Ioooo06Woool008ooool200008S?o00030000ooooo`2I06[oool008ooool00`0003?o
03?o000P<ol000@0003ooooooooo09UZoooo002?oooo00<0000co`0co`007c?o00050000oooooooo
ooooo`2I06[oool008ooool00`0003?o03?o000O<ol000D0003ooooooooooooo09T0J_ooo`00Sooo
o`030000<ol0<ol001hco`000`000?ooooooo`02oooo00?o09Woooooool0J?ooo`00Soooo`030000
<ol0<ol001dco`000`000?ooooooo`03oooo00?o09Woooooool0J?ooo`00Soooo`80000M<ol000<0
003oooooool01?ooo`03o`2Ioooooooo06Soool008ooool00`0003?o03?o000K<ol000<0003ooooo
ool01Oooo`03o`2Ioooooooo06Soool008ooool00`0003?o03?o000K<ol000<0003oooooool01Ooo
o`03o`2Ioooooooo06Soool008ooool00`0003?o03?o000J<ol000<0003oooooool01_ooo`03o`2I
oooooooo06Soool008ooool00`0003?o03?o000J<ol000<0003oooooool01_ooo`03o`2Ioooooooo
06Soool008ooool00`0003?o03?o000I<ol000<0003oooooool01oooo`03o`2Ioooooooo06Soool0
08ooool200006S?o00030000oooooooo00Ooool00ol0VOooooooo`1Xoooo002?oooo00<0000co`0c
o`0063?o00030000oooooooo00Soool00ol0VOooooooo`1Xoooo002?oooo00<0000co`0co`0063?o
00030000oooooooo00Soool00ol0VOooooooo`1Xoooo002?oooo00<0000co`0co`005c?o00030000
oooooooo00Woool00ol0VOooooooo`1Xoooo002?oooo00<0000co`0co`005c?o00030000oooooooo
00Woool00ol0VOooooooo`1Xoooo0027oooo1@0000?oool00`0003?o03?o000F<ol000<0003ooooo
ool02_ooo`03o`2Ioooooooo06Soool008Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o
00030000oooooooo00[oool00ol0VOooooooo`1Xoooo0029oooo00<0003oooooool00oooo`<0000E
<ol000<0003oooooool02oooo`03o`2Ioooooooo06Soool008Woool00`000?ooooooo`03oooo00<0
000co`0co`005C?o00030000oooooooo00_oool00ol0VOooooooo`1Xoooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`0;oooo00?o09Woooooool0J?ooo`00R?oo
o`800005oooo00<0000co`0co`0053?o00030000oooooooo00coool00ol0VOooooooo`1Xoooo002?
oooo00<0000co`0co`0053?o00030000oooooooo00coool00ol0VOooooooo`1Xoooo002?oooo00<0
000co`0co`004c?o00030000oooooooo00goool00ol0VOooooooo`1Xoooo002?oooo0P0001@co`00
0`000?ooooooo`0=oooo00?o09Woooooool0J?ooo`00Soooo`030000<ol0<ol001<co`000`000?oo
ooooo`0=oooo00?o09Woooooool0J?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0>
oooo00?o09Woooooool0J?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0>oooo00?o
09Woooooool0J?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0>oooo00?o09Wooooo
ool0J?ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0?oooo00?o09Woooooool0J?oo
o`00Soooo`80000B<ol000<0003oooooool03oooo`03o`2Ioooooooo06Soool008ooool00`0003?o
03?o000A<ol000<0003oooooool03oooo`03o`2Ioooooooo06Soool008ooool00`0003?o03?o000A
<ol000<0003oooooool03oooo`03o`2Ioooooooo06Soool008ooool00`0003?o03?o000@<ol000<0
003oooooool04?ooo`03o`2Ioooooooo06Soool008ooool00`0003?o03?o000@<ol000<0003ooooo
ool04?ooo`03o`2Ioooooooo06Soool008ooool00`0003?o03?o000@<ol000<0003oooooool04?oo
o`03o`2Ioooooooo06Soool008ooool00`0003?o03?o000@<ol000<0003oooooool04?ooo`03o`2I
oooooooo06Soool008ooool2000043?o00030000oooooooo017oool00ol0VOooooooo`1Xoooo002?
oooo00<0000co`0co`003c?o00030000oooooooo017oool00ol0VOooooooo`1Xoooo002?oooo00<0
000co`0co`003c?o00030000oooooooo017oool00ol0VOooooooo`1Xoooo002?oooo00<0000co`0c
o`003c?o00030000oooooooo017oool00ol0VOooooooo`1Xoooo002?oooo00<0000co`0co`003c?o
00030000oooooooo017oool00ol0VOooooooo`1Xoooo002?oooo00<0000co`0co`003S?o00030000
oooooooo01;oool00ol0VOooooooo`1Xoooo002?oooo0P0000lco`000`000?ooooooo`0Boooo00?o
09Woooooool0J?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Boooo00?o09Wooooo
ool0J?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Boooo00?o09Woooooool0J?oo
o`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`0Coooo00?o09Woooooool0J?ooo`00Qooo
o`@00004oooo00<0000co`0co`003C?o00030000oooooooo01?oool00ol0VOooooooo`1Xoooo0027
oooo00<0003oooooool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`0Coooo00?o09Wooooo
ool0J?ooo`00R?ooo`030000oooooooo00Coool300003C?o00030000oooooooo01?oool00ol0VOoo
ooooo`1Xoooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`0D
oooo00?o09Woooooool0Ioooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`00
0`000?ooooooo`0Eoooo00?o09Woooooool0Ioooo`00R?ooo`800005oooo00<0000co`0co`0033?o
00030000oooooooo01Goool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`0033?o00030000
oooooooo01Goool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`0033?o00030000oooooooo
01Goool00ol0VOooooooo`1Woooo002?oooo0P0000dco`000`000?ooooooo`0Eoooo00?o09Wooooo
ool0Ioooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0Eoooo00?o09Woooooool0Iooo
o`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0Foooo00?o09Woooooool0Ioooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`0Foooo00?o09Woooooool0Ioooo`00Soooo`030000
<ol0<ol000/co`000`000?ooooooo`0Foooo00?o09Woooooool0Ioooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`0Foooo00?o09Woooooool0Ioooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`0Foooo00?o09Woooooool0Ioooo`00Soooo`80000<<ol000<0003oooooool05_oo
o`03o`2Ioooooooo06Ooool008ooool00`0003?o03?o000;<ol000<0003oooooool05_ooo`03o`2I
oooooooo06Ooool008ooool00`0003?o03?o000:<ol000<0003oooooool05oooo`03o`2Ioooooooo
06Ooool008ooool00`0003?o03?o000:<ol000<0003oooooool05oooo`03o`2Ioooooooo06Ooool0
08ooool00`0003?o03?o000:<ol000<0003oooooool05oooo`03o`2Ioooooooo06Ooool008ooool0
0`0003?o03?o000:<ol000<0003oooooool05oooo`03o`2Ioooooooo06Ooool008ooool200002c?o
00030000oooooooo01Ooool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`002S?o00030000
oooooooo01Ooool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`002S?o00030000oooooooo
01Ooool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`002C?o00030000oooooooo01Soool0
0ol0VOooooooo`1Woooo002?oooo00<0000co`0co`002C?o00030000oooooooo01Soool00ol0VOoo
ooooo`1Woooo002?oooo00<0000co`0co`002C?o00030000oooooooo01Soool00ol0VOooooooo`1W
oooo002?oooo0P0000Xco`000`000?ooooooo`0Hoooo00?o09Woooooool0Ioooo`00Soooo`030000
<ol0<ol000Tco`000`000?ooooooo`0Hoooo00?o09Woooooool0Ioooo`00Soooo`030000<ol0<ol0
00Tco`000`000?ooooooo`0Hoooo00?o09Woooooool0Ioooo`00Soooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0Ioooo00?o09Woooooool0Ioooo`00R?ooo`800005oooo00<0000co`0co`0023?o
00030000oooooooo01Woool00ol0VOooooooo`1Woooo0027oooo00@0003oooooool00004oooo00<0
000co`0co`0023?o00030000oooooooo01Woool00ol0VOooooooo`1Woooo0029oooo00<0003ooooo
ool00oooo`<00008<ol000<0003oooooool06Oooo`03o`2Ioooooooo06Ooool008[oool00`000?oo
ooooo`02oooo00<0000co`0co`0023?o00030000oooooooo01Woool00ol0VOooooooo`1Woooo0027
oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo01Woool00ol0VOoo
ooooo`1Woooo0028oooo0P0000Goool00`0003?o03?o0007<ol000<0003oooooool06_ooo`03o`2I
oooooooo06Ooool008ooool00`0003?o03?o0007<ol000<0003oooooool06_ooo`03o`2Ioooooooo
06Ooool008ooool00`0003?o03?o0007<ol000<0003oooooool06_ooo`03o`2Ioooooooo06Ooool0
08ooool00`0003?o03?o0007<ol000<0003oooooool06_ooo`03o`2Ioooooooo06Ooool008ooool2
000023?o00030000oooooooo01[oool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`001c?o
00030000oooooooo01[oool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`001c?o00030000
oooooooo01[oool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`001c?o00030000oooooooo
01[oool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`001S?o00030000oooooooo01_oool0
0ol0VOooooooo`1Woooo002?oooo00<0000co`0co`001S?o00030000oooooooo01_oool00ol0VOoo
ooooo`1Woooo002?oooo0P0000Lco`000`000?ooooooo`0Koooo00?o09Woooooool0Ioooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`0Koooo00?o09Woooooool0Ioooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`0Koooo00?o09Woooooool0Ioooo`00Soooo`030000<ol0<ol0
00Hco`000`000?ooooooo`0Koooo00?o09Woooooool0Ioooo`00Soooo`030000<ol0<ol000Hco`00
0`000?ooooooo`0Koooo00?o09Woooooool0Ioooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`0Koooo00?o09Woooooool0Ioooo`00Soooo`800006<ol000<0003oooooool07?ooo`03o`2I
oooooooo06Ooool008ooool00`0003?o03?o0005<ol000<0003oooooool07?ooo`03o`2Ioooooooo
06Ooool008ooool00`0003?o03?o0005<ol000<0003oooooool07?ooo`03o`2Ioooooooo06Ooool0
08ooool00`0003?o03?o0005<ol000<0003oooooool07?ooo`03o`2Ioooooooo06Ooool008ooool0
0`0003?o03?o0005<ol000<0003oooooool07?ooo`03o`2Ioooooooo06Ooool008ooool00`0003?o
03?o0005<ol000<0003oooooool07?ooo`03o`2Ioooooooo06Ooool008ooool200001S?o00030000
oooooooo01coool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`001C?o00030000oooooooo
01coool00ol0VOooooooo`1Woooo002?oooo00<0000co`0co`001C?o00030000oooooooo01coool0
0ol0VOooooooo`1Woooo002?oooo00<0000co`0co`0013?o00030000oooooooo01goool00ol0VOoo
ooooo`1Woooo002?oooo00<0000co`0co`0013?o00030000oooooooo01goool00ol0VOooooooo`1W
oooo0029oooo0`0000?oool00`0003?o03?o0004<ol000<0003oooooool07Oooo`03o`2Ioooooooo
06Ooool008[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o00030000oooooooo01goool0
0ol0VOooooooo`1Woooo0027oooo1@0000?oool3000013?o00030000oooooooo01goool00ol0VOoo
ooooo`1Woooo0027oooo00@0003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004
oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_oo
o`00NOooo`030000oooooooo01?oool7<ol03_ooo`030000oooooooo07Woool007Soool00`000?oo
ooooo`08oooo00<0003oooooool02Oooo`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Koool500000S?o008000000c?o0?ooooooo`03
00001Oooo`<00002oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01oooo`030000<ol0<ol000Dco`02oooo00@0003ooooo
ool00005oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0?oooo00<0000co`0co`001C?o00;oool010000?ooooooo`0000;oool500000oooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000<ol0<ol000Dco`02oooo0`00
00?oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00004Oooo`030000<ol0<ol000Dco`03oooo00<0003oooooool00oooo`030000oooo000000?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007<ol00oooo`<00004oooo0P00
00;oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.66) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.59832 .12361 L
.61984 .12361 L
.6298 .12361 L
.64043 .12361 L
.64559 .12361 L
.65045 .12361 L
.65258 .12361 L
.65482 .12361 L
.65599 .12361 L
s
.65599 .12361 m
.65651 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.33304 .12361 L
.33554 .12361 L
.33823 .12361 L
.33953 .12361 L
.34076 .12361 L
.34187 .12361 L
.34309 .12337 L
.34373 .1227 L
.34441 .12201 L
.34564 .12077 L
.3484 .11805 L
.3534 .11336 L
.36276 .10537 L
.38373 .09076 L
.40337 .08058 L
.4217 .07356 L
.43215 .07047 L
.44205 .06807 L
.45087 .06633 L
.46061 .06479 L
.47026 .06362 L
.4752 .06314 L
.48052 .06272 L
.48548 .06241 L
.49002 .06218 L
.49437 .06201 L
.49655 .06195 L
.49894 .06189 L
.50017 .06187 L
.50148 .06184 L
.50291 .0618 L
.50423 .06174 L
.5066 .06163 L
.50922 .06146 L
.51404 .06107 L
.51855 .06062 L
.5395 .05766 L
.57833 .04998 L
.59807 .04564 L
Mistroke
.6196 .04092 L
.62959 .0388 L
.64023 .03663 L
.64541 .03561 L
.65027 .03468 L
.65464 .03388 L
.65584 .03366 L
.6571 .03343 L
.65818 .12361 L
.65936 .12361 L
.69984 .12361 L
.7388 .12361 L
.78021 .12361 L
.82011 .12361 L
.85849 .12361 L
.89933 .12361 L
.93865 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.66) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool08?ooo`H0I_mXoooo002?oooo00<0003oooooool06_ooo`H0I_l5oooo00<0I_oooooo
ool0I_ooo`00Soooo`030000oooooooo01Soool206Ko2oooo`0306Kooooooooo06Koool008ooool0
0`000?ooooooo`0Doooo101Vo`goool00`1Vooooooooo`1Voooo002?oooo0P00013oool506Ko4Ooo
o`0306Kooooooooo06Koool008ooool00`000?ooooooo`0:oooo1@1VoaKoool00`1Vooooooooo`1V
oooo002?oooo00<0003oooooool00_ooo`P0I_lKoooo00<0I_ooooooool0I_ooo`00QOooo`X0I_l0
0`00001Vo`1Vo`0206Ko8oooo`0306Kooooooooo06Koool0083oool506Ko2_ooo`030000oooooooo
02Goool00`1Vooooooooo`1Voooo001moooo0`1Vo`ooool00`000?ooooooo`0Uoooo00<0I_oooooo
ool0I_ooo`00NOooo`@0I_lBoooo0P0002Koool00`1Vooooooooo`1Voooo000Goooo100003Woool5
00007Oooo`<0I_lFoooo00<0003oooooool09Oooo`0306Kooooooooo00ooool50000>?ooo`@0000F
oooo000Goooo00<0003oooooool0??ooo`030000oooooooo01_oool206Ko6Oooo`030000oooooooo
02Goool00`1Vooooooooo`0Aoooo00<0003oooooool0>?ooo`030000oooooooo01Ooool001Soool0
0`000?ooooooo`0koooo00<0003oooooool06Oooo`80I_lKoooo00<0003oooooool09Oooo`0306Ko
oooooooo017oool00`000?ooooooo`0ioooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0
003oooooool0<_ooo`@00004oooo00<0003oooooool06?ooo`0306Kooooooooo01_oool00`000?oo
ooooo`0Uoooo00<0I_ooooooool04Oooo`030000oooooooo03[oool00`000?ooooooo`0Eoooo000G
oooo00@0003oooooool0000koooo00<0003oooooool05oooo`0306Kooooooooo01coool00`000?oo
ooooo`0Uoooo00<0I_ooooooool04Oooo`030000oooooooo03Soool010000?ooooooo`0001Koool0
01Soool20000>oooo`80000Goooo0P1Voaooool200009_ooo`0306Kooooooooo013oool20000>ooo
o`80000Goooo001]oooo00<0I_ooooooool07oooo`030000oooooooo02Goool00`1Vooooooooo`1V
oooo001/oooo00<0I_ooooooool08?ooo`030000oooooooo02Goool00`1Vooooooooo`1Voooo001[
oooo00<0I_ooooooool08Oooo`030000oooooooo02Goool00`1Vooooooooo`1Voooo001Zoooo00<0
I_ooooooool08_ooo`030000oooooooo02Goool00`1Vooooooooo`1Voooo001Yoooo00<0I_oooooo
ool08oooo`030000oooooooo02Goool00`1Vooooooooo`1Voooo000@ooooo`00017oool001Koool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000D0000co`0co`0co`3o09T01c?o00030000<ol0<ol0
00Tco`000`0003?o03?o0006<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`009C?o0003o`2I
<ol0<ol0014co`090000=?ooo`030000oooooooo01Goool008ooool00`0003?o03?o000U<ol000?o
09Tco`0co`002c?o00H0001Eoooo002?oooo00<0000co`0co`009C?o0003o`2I<ol0<ol000Tco`02
0000Foooo`00Soooo`030000<ol0<ol002Dco`000ol0VC?o03?o0007<ol00P0005goool008ooool0
0`0003?o03?o000U<ol000?o09Tco`0co`0013?o00<0001Ooooo002?oooo0P0002Hco`001?l0VC?o
03?o03?o00<0001Roooo002?oooo00<0000co`0co`009C?o0004o`2I<ol000000000IOooo`00Sooo
o`030000<ol0<ol002Dco`000ol0V@000?ooo`1Voooo002?oooo00<0000co`0co`009C?o0003o`2I
oooooooo06Koool008ooool00`0003?o03?o000T<ol000<0003o09Woool0Ioooo`00Soooo`030000
<ol0<ol0028co`02000000?ooooo09Woool0Ioooo`00Soooo`80000R<ol000D0003ooooooooooooo
09T0J?ooo`00Soooo`030000<ol0<ol0020co`000`000?ooooooo`02oooo00?o09Woooooool0I_oo
o`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`03oooo00?o09Woooooool0I_ooo`00Sooo
o`030000<ol0<ol001lco`000`000?ooooooo`03oooo00?o09Woooooool0I_ooo`00Soooo`030000
<ol0<ol001hco`000`000?ooooooo`04oooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol0
01dco`000`000?ooooooo`05oooo00?o09Woooooool0I_ooo`00Soooo`80000M<ol000<0003ooooo
ool01_ooo`03o`2Ioooooooo06Koool008ooool00`0003?o03?o000K<ol000<0003oooooool01ooo
o`03o`2Ioooooooo06Koool008ooool00`0003?o03?o000K<ol000<0003oooooool01oooo`03o`2I
oooooooo06Koool008ooool00`0003?o03?o000J<ol000<0003oooooool02?ooo`03o`2Ioooooooo
06Koool008ooool00`0003?o03?o000J<ol000<0003oooooool02?ooo`03o`2Ioooooooo06Koool0
08ooool00`0003?o03?o000I<ol000<0003oooooool02Oooo`03o`2Ioooooooo06Koool008ooool2
00006S?o00030000oooooooo00Woool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`0063?o
00030000oooooooo00[oool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`0063?o00030000
oooooooo00[oool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`005c?o00030000oooooooo
00_oool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`005c?o00030000oooooooo00_oool0
0ol0VOooooooo`1Voooo0027oooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool03?oo
o`03o`2Ioooooooo06Koool008Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000
oooooooo00coool00ol0VOooooooo`1Voooo0029oooo00<0003oooooool00oooo`<0000E<ol000<0
003oooooool03Oooo`03o`2Ioooooooo06Koool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`005C?o00030000oooooooo00goool00ol0VOooooooo`1Voooo0029oooo00<0003oooooool00ooo
o`030000<ol0<ol001Dco`000`000?ooooooo`0=oooo00?o09Woooooool0I_ooo`00R?ooo`800005
oooo00<0000co`0co`0053?o00030000oooooooo00koool00ol0VOooooooo`1Voooo002?oooo00<0
000co`0co`0053?o00030000oooooooo00koool00ol0VOooooooo`1Voooo002?oooo00<0000co`0c
o`004c?o00030000oooooooo00ooool00ol0VOooooooo`1Voooo002?oooo0P0001@co`000`000?oo
ooooo`0?oooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`0?
oooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0@oooo00?o
09Woooooool0I_ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0@oooo00?o09Wooooo
ool0I_ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0@oooo00?o09Woooooool0I_oo
o`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Aoooo00?o09Woooooool0I_ooo`00Sooo
o`80000B<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Koool008ooool00`0003?o03?o000A
<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Koool008ooool00`0003?o03?o000A<ol000<0
003oooooool04Oooo`03o`2Ioooooooo06Koool008ooool00`0003?o03?o000@<ol000<0003ooooo
ool04_ooo`03o`2Ioooooooo06Koool008ooool00`0003?o03?o000@<ol000<0003oooooool04_oo
o`03o`2Ioooooooo06Koool008ooool00`0003?o03?o000@<ol000<0003oooooool04_ooo`03o`2I
oooooooo06Koool008ooool00`0003?o03?o000@<ol000<0003oooooool04_ooo`03o`2Ioooooooo
06Koool008ooool2000043?o00030000oooooooo01?oool00ol0VOooooooo`1Voooo002?oooo00<0
000co`0co`003c?o00030000oooooooo01?oool00ol0VOooooooo`1Voooo002?oooo00<0000co`0c
o`003c?o00030000oooooooo01?oool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`003c?o
00030000oooooooo01?oool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`003c?o00030000
oooooooo01?oool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`003S?o00030000oooooooo
01Coool00ol0VOooooooo`1Voooo002?oooo0P0000lco`000`000?ooooooo`0Doooo00?o09Wooooo
ool0I_ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Doooo00?o09Woooooool0I_oo
o`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Doooo00?o09Woooooool0I_ooo`00Sooo
o`030000<ol0<ol000dco`000`000?ooooooo`0Eoooo00?o09Woooooool0I_ooo`00Qoooo`@00004
oooo00<0000co`0co`003C?o00030000oooooooo01Goool00ol0VOooooooo`1Voooo0027oooo00<0
003oooooool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`0Eoooo00?o09Woooooool0I_oo
o`00R?ooo`030000oooooooo00Coool300003C?o00030000oooooooo01Goool00ol0VOooooooo`1V
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`0Eoooo00?o
09Woooooool0I_ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?oo
ooooo`0Foooo00?o09Woooooool0I_ooo`00R?ooo`800005oooo00<0000co`0co`0033?o00030000
oooooooo01Koool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`0033?o00030000oooooooo
01Koool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`0033?o00030000oooooooo01Koool0
0ol0VOooooooo`1Voooo002?oooo0P0000dco`000`000?ooooooo`0Foooo00?o09Woooooool0I_oo
o`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0Foooo00?o09Woooooool0I_ooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`0Goooo00?o09Woooooool0I_ooo`00Soooo`030000
<ol0<ol000/co`000`000?ooooooo`0Goooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`0Goooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`0Goooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`0Goooo00?o09Woooooool0I_ooo`00Soooo`80000<<ol000<0003oooooool05oooo`03o`2I
oooooooo06Koool008ooool00`0003?o03?o000;<ol000<0003oooooool05oooo`03o`2Ioooooooo
06Koool008ooool00`0003?o03?o000:<ol000<0003oooooool06?ooo`03o`2Ioooooooo06Koool0
08ooool00`0003?o03?o000:<ol000<0003oooooool06?ooo`03o`2Ioooooooo06Koool008ooool0
0`0003?o03?o000:<ol000<0003oooooool06?ooo`03o`2Ioooooooo06Koool008ooool00`0003?o
03?o000:<ol000<0003oooooool06?ooo`03o`2Ioooooooo06Koool008ooool200002c?o00030000
oooooooo01Soool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`002S?o00030000oooooooo
01Soool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`002S?o00030000oooooooo01Soool0
0ol0VOooooooo`1Voooo002?oooo00<0000co`0co`002C?o00030000oooooooo01Woool00ol0VOoo
ooooo`1Voooo002?oooo00<0000co`0co`002C?o00030000oooooooo01Woool00ol0VOooooooo`1V
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo01Woool00ol0VOooooooo`1Voooo002?
oooo0P0000Xco`000`000?ooooooo`0Ioooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol0
00Tco`000`000?ooooooo`0Ioooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol000Tco`00
0`000?ooooooo`0Ioooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0Joooo00?o09Woooooool0I_ooo`00R?ooo`800005oooo00<0000co`0co`0023?o00030000
oooooooo01[oool00ol0VOooooooo`1Voooo0027oooo00@0003oooooool00004oooo00<0000co`0c
o`0023?o00030000oooooooo01[oool00ol0VOooooooo`1Voooo0029oooo00<0003oooooool00ooo
o`<00008<ol000<0003oooooool06_ooo`03o`2Ioooooooo06Koool008[oool00`000?ooooooo`02
oooo00<0000co`0co`0023?o00030000oooooooo01[oool00ol0VOooooooo`1Voooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo01[oool00ol0VOooooooo`1V
oooo0028oooo0P0000Goool00`0003?o03?o0007<ol000<0003oooooool06oooo`03o`2Ioooooooo
06Koool008ooool00`0003?o03?o0007<ol000<0003oooooool06oooo`03o`2Ioooooooo06Koool0
08ooool00`0003?o03?o0007<ol000<0003oooooool06oooo`03o`2Ioooooooo06Koool008ooool0
0`0003?o03?o0007<ol000<0003oooooool06oooo`03o`2Ioooooooo06Koool008ooool2000023?o
00030000oooooooo01_oool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`001c?o00030000
oooooooo01_oool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`001c?o00030000oooooooo
01_oool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`001c?o00030000oooooooo01_oool0
0ol0VOooooooo`1Voooo002?oooo00<0000co`0co`001S?o00030000oooooooo01coool00ol0VOoo
ooooo`1Voooo002?oooo00<0000co`0co`001S?o00030000oooooooo01coool00ol0VOooooooo`1V
oooo002?oooo0P0000Lco`000`000?ooooooo`0Loooo00?o09Woooooool0I_ooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`0Loooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol0
00Hco`000`000?ooooooo`0Loooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol000Hco`00
0`000?ooooooo`0Loooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`0Loooo00?o09Woooooool0I_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0L
oooo00?o09Woooooool0I_ooo`00Soooo`800006<ol000<0003oooooool07Oooo`03o`2Ioooooooo
06Koool008ooool00`0003?o03?o0005<ol000<0003oooooool07Oooo`03o`2Ioooooooo06Koool0
08ooool00`0003?o03?o0005<ol000<0003oooooool07Oooo`03o`2Ioooooooo06Koool008ooool0
0`0003?o03?o0005<ol000<0003oooooool07Oooo`03o`2Ioooooooo06Koool008ooool00`0003?o
03?o0005<ol000<0003oooooool07Oooo`03o`2Ioooooooo06Koool008ooool00`0003?o03?o0005
<ol000<0003oooooool07Oooo`03o`2Ioooooooo06Koool008ooool200001S?o00030000oooooooo
01goool00ol0VOooooooo`1Voooo002?oooo00<0000co`0co`001C?o00030000oooooooo01goool0
0ol0VOooooooo`1Voooo002?oooo00<0000co`0co`001C?o00030000oooooooo01goool00ol0VOoo
ooooo`1Voooo002?oooo00<0000co`0co`0013?o00030000oooooooo01koool00ol0VOooooooo`1V
oooo002?oooo00<0000co`0co`0013?o00030000oooooooo01koool00ol0VOooooooo`1Voooo0029
oooo0`0000?oool00`0003?o03?o0004<ol000<0003oooooool07_ooo`03o`2Ioooooooo06Koool0
08[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o00030000oooooooo01koool00ol0VOoo
ooooo`1Voooo0027oooo1@0000?oool3000013?o00030000oooooooo01koool00ol0VOooooooo`1V
oooo0027oooo00@0003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o
08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOoo
o`030000oooooooo01?oool7<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool02Oooo`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool500000S?o008000000c?o0?ooooooo`0300000ooo
o`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01oooo`030000<ol0<ol000Dco`02oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool0
0`000?ooooooo`0?oooo00<0000co`0co`001C?o00;oool010000?ooooooo`0000;oool010000?oo
ooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000koool00`0003?o
03?o0005<ol00_ooo`<00003oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000004Oooo`030000<ol0<ol000Dco`03oooo00<0003oooooool00oooo`030000oooooooo
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007<ol00oooo`<00003
oooo0`0000;oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.68) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65045 .12361 L
.65519 .12361 L
.65954 .12361 L
.66069 .12361 L
.66177 .12361 L
s
.66177 .12361 m
.66222 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.32831 .12361 L
.33304 .12361 L
.33443 .12361 L
.33575 .12361 L
.33693 .12361 L
.33823 .12347 L
.33945 .12222 L
.34075 .1209 L
.34309 .11859 L
.36306 .10145 L
.38467 .08749 L
.40553 .07767 L
.41546 .07405 L
.42473 .0712 L
.44356 .0668 L
.45353 .06512 L
.46422 .06375 L
.47439 .06282 L
.48014 .06244 L
.48546 .06217 L
.4901 .062 L
.49274 .06193 L
.49522 .06187 L
.50017 .06181 L
.50087 .06181 L
.50152 .0618 L
.50228 .06178 L
.50297 .06177 L
.50424 .06173 L
.50558 .06168 L
.50804 .06157 L
.5103 .06143 L
.51541 .06104 L
.52576 .05993 L
.54427 .05715 L
.58216 .04966 L
.6225 .04087 L
.64107 .037 L
.65088 .03508 L
Mistroke
.65626 .03408 L
.6589 .0336 L
.66005 .03339 L
.66132 .03316 L
.66202 .12361 L
.66267 .12361 L
.66409 .12361 L
.66709 .12361 L
.67231 .12361 L
.6825 .12361 L
.7026 .12361 L
.74156 .12361 L
.78297 .12361 L
.82287 .12361 L
.86125 .12361 L
.90209 .12361 L
.9414 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.68) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0Voooo00<0I_oooooo
ool0IOooo`00Soooo`030000oooooooo01ooool806KoIoooo`00Soooo`030000oooooooo01_oool4
06Ko1oooo`0306Kooooooooo06Goool008ooool00`000?ooooooo`0Hoooo0`1Vo`_oool00`1Voooo
ooooo`1Uoooo002?oooo00<0003oooooool05?ooo`@0I_l>oooo00<0I_ooooooool0IOooo`00Sooo
o`80000Aoooo101Voa;oool00`1Vooooooooo`1Uoooo002?oooo00<0003oooooool02oooo`D0I_lF
oooo00<0I_ooooooool0IOooo`00Soooo`030000oooooooo00?oool806Ko6oooo`0306Kooooooooo
06Goool008Goool:06Ko00<00000I_l0I_l00`1Vob?oool00`1Vooooooooo`1Uoooo001ooooo1P1V
o`[oool00`000?ooooooo`0Voooo00<0I_ooooooool0IOooo`00O?ooo`<0I_l@oooo00<0003ooooo
ool09_ooo`0306Kooooooooo06Goool007Woool306Ko4oooo`80000Woooo00<0I_ooooooool0IOoo
o`005oooo`@0000ioooo1@0001goool306Ko5_ooo`030000oooooooo02Koool00`1Vooooooooo`0>
oooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?ooooooo`0Koooo0P1V
oaWoool00`000?ooooooo`0Voooo00<0I_ooooooool04?ooo`030000oooooooo03Soool00`000?oo
ooooo`0Goooo000Hoooo00<0003oooooool0>oooo`030000oooooooo01Woool206Ko6oooo`030000
oooooooo02Koool00`1Vooooooooo`0@oooo00<0003oooooool0>Oooo`030000oooooooo01Koool0
017oool400001?ooo`030000oooooooo03;oool400001?ooo`030000oooooooo01Ooool206Ko7Ooo
o`030000oooooooo02Koool00`1Vooooooooo`0@oooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0Foooo00<0I_ooooooool07Ooo
o`030000oooooooo02Koool00`1Vooooooooo`0@oooo00<0003oooooool0>?ooo`040000oooooooo
00005_ooo`006?ooo`80000koooo0P0001Koool206Ko8?ooo`80000Woooo00<0I_ooooooool03ooo
o`80000koooo0P0001Ooool006coool00`1Vooooooooo`0Poooo00<0003oooooool09_ooo`0306Ko
oooooooo06Goool006_oool00`1Vooooooooo`0Qoooo00<0003oooooool09_ooo`0306Kooooooooo
06Goool006Woool206Ko9?ooo`030000oooooooo02Koool00`1Vooooooooo`1Uoooo001Xoooo00<0
I_ooooooool09?ooo`030000oooooooo02Koool00`1Vooooooooo`1Uoooo001Woooo00<0I_oooooo
ool09Oooo`030000oooooooo02Koool00`1Vooooooooo`1Uoooo000@ooooo`00017oool001Koool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`000S?o0003o`2I<ol0<ol000@co`00
0`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0003oooooool02Oooo`030000
oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol0
02Hco`000ol0VC?o03?o000@<ol02@0003Coool00`000?ooooooo`0Eoooo002?oooo00<0000co`0c
o`009S?o0003o`2I<ol0<ol000Xco`060000EOooo`00Soooo`030000<ol0<ol002Hco`000ol0VC?o
03?o0008<ol00P0005_oool008ooool00`0003?o03?o000V<ol000?o09Tco`0co`001S?o0080001M
oooo002?oooo00<0000co`0co`009S?o0003o`2I<ol0<ol000<co`030000Goooo`00Soooo`80000W
<ol000?o09Tco`0co`000`0006;oool008ooool00`0003?o03?o000V<ol000?o09T000000000IOoo
o`00Soooo`030000<ol0<ol002Hco`000ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`009C?o
00030000o`2Ioooo06Koool008ooool00`0003?o03?o000T<ol000<0003ooooo09T0Ioooo`00Sooo
o`030000<ol0<ol0028co`0200000_ooo`03o`2Ioooooooo06Goool008ooool200008S?o00030000
oooooooo00;oool00ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`0083?o00030000oooooooo
00?oool00ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`007c?o00030000oooooooo00Coool0
0ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`007c?o00030000oooooooo00Coool00ol0VOoo
ooooo`1Uoooo002?oooo00<0000co`0co`007S?o00030000oooooooo00Goool00ol0VOooooooo`1U
oooo002?oooo00<0000co`0co`007C?o00030000oooooooo00Koool00ol0VOooooooo`1Uoooo002?
oooo0P0001dco`000`000?ooooooo`07oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol0
01/co`000`000?ooooooo`08oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol001/co`00
0`000?ooooooo`08oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol001Xco`000`000?oo
ooooo`09oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`09
oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`0:oooo00?o
09Woooooool0IOooo`00Soooo`80000J<ol000<0003oooooool02_ooo`03o`2Ioooooooo06Goool0
08ooool00`0003?o03?o000H<ol000<0003oooooool02oooo`03o`2Ioooooooo06Goool008ooool0
0`0003?o03?o000H<ol000<0003oooooool02oooo`03o`2Ioooooooo06Goool008ooool00`0003?o
03?o000G<ol000<0003oooooool03?ooo`03o`2Ioooooooo06Goool008ooool00`0003?o03?o000G
<ol000<0003oooooool03?ooo`03o`2Ioooooooo06Goool008Ooool500000oooo`030000<ol0<ol0
01Hco`000`000?ooooooo`0=oooo00?o09Woooooool0IOooo`00ROooo`030000oooooooo00?oool0
0`0003?o03?o000F<ol000<0003oooooool03Oooo`03o`2Ioooooooo06Goool008Woool00`000?oo
ooooo`03oooo0`0001Dco`000`000?ooooooo`0>oooo00?o09Woooooool0IOooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool03_ooo`03o`2Ioooooooo06Goool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo00koool00ol0VOoo
ooooo`1Uoooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool03oooo`03o`2I
oooooooo06Goool008ooool00`0003?o03?o000D<ol000<0003oooooool03oooo`03o`2Ioooooooo
06Goool008ooool00`0003?o03?o000C<ol000<0003oooooool04?ooo`03o`2Ioooooooo06Goool0
08ooool2000053?o00030000oooooooo013oool00ol0VOooooooo`1Uoooo002?oooo00<0000co`0c
o`004c?o00030000oooooooo013oool00ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`004S?o
00030000oooooooo017oool00ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`004S?o00030000
oooooooo017oool00ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`004S?o00030000oooooooo
017oool00ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`004C?o00030000oooooooo01;oool0
0ol0VOooooooo`1Uoooo002?oooo0P00018co`000`000?ooooooo`0Boooo00?o09Woooooool0IOoo
o`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Boooo00?o09Woooooool0IOooo`00Sooo
o`030000<ol0<ol0014co`000`000?ooooooo`0Boooo00?o09Woooooool0IOooo`00Soooo`030000
<ol0<ol0010co`000`000?ooooooo`0Coooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol0
010co`000`000?ooooooo`0Coooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol0010co`00
0`000?ooooooo`0Coooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol0010co`000`000?oo
ooooo`0Coooo00?o09Woooooool0IOooo`00Soooo`80000@<ol000<0003oooooool05?ooo`03o`2I
oooooooo06Goool008ooool00`0003?o03?o000?<ol000<0003oooooool05?ooo`03o`2Ioooooooo
06Goool008ooool00`0003?o03?o000?<ol000<0003oooooool05?ooo`03o`2Ioooooooo06Goool0
08ooool00`0003?o03?o000?<ol000<0003oooooool05?ooo`03o`2Ioooooooo06Goool008ooool0
0`0003?o03?o000?<ol000<0003oooooool05?ooo`03o`2Ioooooooo06Goool008ooool00`0003?o
03?o000><ol000<0003oooooool05Oooo`03o`2Ioooooooo06Goool008ooool200003c?o00030000
oooooooo01Goool00ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`003S?o00030000oooooooo
01Goool00ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`003S?o00030000oooooooo01Goool0
0ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`003C?o00030000oooooooo01Koool00ol0VOoo
ooooo`1Uoooo0027oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool05_ooo`03o`2I
oooooooo06Goool008Ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo
01Koool00ol0VOooooooo`1Uoooo0028oooo00<0003oooooool01?ooo`<0000=<ol000<0003ooooo
ool05_ooo`03o`2Ioooooooo06Goool008Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o
00030000oooooooo01Koool00ol0VOooooooo`1Uoooo0027oooo00@0003oooooool00004oooo00<0
000co`0co`0033?o00030000oooooooo01Ooool00ol0VOooooooo`1Uoooo0028oooo0P0000Goool0
0`0003?o03?o000<<ol000<0003oooooool05oooo`03o`2Ioooooooo06Goool008ooool00`0003?o
03?o000<<ol000<0003oooooool05oooo`03o`2Ioooooooo06Goool008ooool00`0003?o03?o000<
<ol000<0003oooooool05oooo`03o`2Ioooooooo06Goool008ooool200003C?o00030000oooooooo
01Ooool00ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`0033?o00030000oooooooo01Ooool0
0ol0VOooooooo`1Uoooo002?oooo00<0000co`0co`002c?o00030000oooooooo01Soool00ol0VOoo
ooooo`1Uoooo002?oooo00<0000co`0co`002c?o00030000oooooooo01Soool00ol0VOooooooo`1U
oooo002?oooo00<0000co`0co`002c?o00030000oooooooo01Soool00ol0VOooooooo`1Uoooo002?
oooo00<0000co`0co`002c?o00030000oooooooo01Soool00ol0VOooooooo`1Uoooo002?oooo00<0
000co`0co`002c?o00030000oooooooo01Soool00ol0VOooooooo`1Uoooo002?oooo0P0000`co`00
0`000?ooooooo`0Hoooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`0Hoooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0I
oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Ioooo00?o
09Woooooool0IOooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Ioooo00?o09Wooooo
ool0IOooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Ioooo00?o09Woooooool0IOoo
o`00Soooo`80000;<ol000<0003oooooool06Oooo`03o`2Ioooooooo06Goool008ooool00`0003?o
03?o000:<ol000<0003oooooool06Oooo`03o`2Ioooooooo06Goool008ooool00`0003?o03?o000:
<ol000<0003oooooool06Oooo`03o`2Ioooooooo06Goool008ooool00`0003?o03?o0009<ol000<0
003oooooool06_ooo`03o`2Ioooooooo06Goool008ooool00`0003?o03?o0009<ol000<0003ooooo
ool06_ooo`03o`2Ioooooooo06Goool008ooool00`0003?o03?o0009<ol000<0003oooooool06_oo
o`03o`2Ioooooooo06Goool008ooool200002S?o00030000oooooooo01[oool00ol0VOooooooo`1U
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo01[oool00ol0VOooooooo`1Uoooo002?
oooo00<0000co`0co`002C?o00030000oooooooo01[oool00ol0VOooooooo`1Uoooo002?oooo00<0
000co`0co`0023?o00030000oooooooo01_oool00ol0VOooooooo`1Uoooo0028oooo0P0000Goool0
0`0003?o03?o0008<ol000<0003oooooool06oooo`03o`2Ioooooooo06Goool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool06oooo`03o`2Ioooooooo06Goool0
08Woool00`000?ooooooo`03oooo0`0000Pco`000`000?ooooooo`0Koooo00?o09Woooooool0IOoo
o`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool06oooo`03o`2I
oooooooo06Goool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003ooooo
ool06oooo`03o`2Ioooooooo06Goool008Soool200001Oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0Loooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0L
oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Loooo00?o
09Woooooool0IOooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Loooo00?o09Wooooo
ool0IOooo`00Soooo`800008<ol000<0003oooooool07?ooo`03o`2Ioooooooo06Goool008ooool0
0`0003?o03?o0007<ol000<0003oooooool07?ooo`03o`2Ioooooooo06Goool008ooool00`0003?o
03?o0007<ol000<0003oooooool07?ooo`03o`2Ioooooooo06Goool008ooool00`0003?o03?o0007
<ol000<0003oooooool07?ooo`03o`2Ioooooooo06Goool008ooool00`0003?o03?o0006<ol000<0
003oooooool07Oooo`03o`2Ioooooooo06Goool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool07Oooo`03o`2Ioooooooo06Goool008ooool200001c?o00030000oooooooo01goool00ol0VOoo
ooooo`1Uoooo002?oooo00<0000co`0co`001S?o00030000oooooooo01goool00ol0VOooooooo`1U
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo01goool00ol0VOooooooo`1Uoooo002?
oooo00<0000co`0co`001S?o00030000oooooooo01goool00ol0VOooooooo`1Uoooo002?oooo00<0
000co`0co`001S?o00030000oooooooo01goool00ol0VOooooooo`1Uoooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo01goool00ol0VOooooooo`1Uoooo002?oooo0P0000Hco`000`000?oo
ooooo`0Noooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0N
oooo00?o09Woooooool0IOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Noooo00?o
09Woooooool0IOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Noooo00?o09Wooooo
ool0IOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Noooo00?o09Woooooool0IOoo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Noooo00?o09Woooooool0IOooo`00Sooo
o`800006<ol000<0003oooooool07_ooo`03o`2Ioooooooo06Goool008ooool00`0003?o03?o0005
<ol000<0003oooooool07_ooo`03o`2Ioooooooo06Goool008ooool00`0003?o03?o0005<ol000<0
003oooooool07_ooo`03o`2Ioooooooo06Goool008ooool00`0003?o03?o0004<ol000<0003ooooo
ool07oooo`03o`2Ioooooooo06Goool008ooool00`0003?o03?o0004<ol000<0003oooooool07ooo
o`03o`2Ioooooooo06Goool008Woool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`0O
oooo00?o09Woooooool0IOooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0
003oooooool07oooo`03o`2Ioooooooo06Goool008Ooool500000oooo`<00004<ol000<0003ooooo
ool07oooo`03o`2Ioooooooo06Goool008Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?oo
o`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_oo
o`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>oooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o00ooool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002<ol00P00
0003<ol0oooooooo00<00004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0000co`0co`001C?o
00;oool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001g
oooo00<0003oooooool00_ooo`030000oooooooo00ooool00`0003?o03?o0005<ol00_ooo`040000
oooooooo00000_ooo`040000oooooooo00001?ooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500003_ooo`030000<ol0<ol000Dco`02oooo0`0000Coool200001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`00000Aoooo00<0000co`0co`001C?o00?oool00`000?oo
ooooo`02oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo
017oool200001c?o00?oool300000oooo`800003oooo00<0003oooooool0NOooo`00Soooo`Lco`2:
oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65045 .12361 L
.65954 .12361 L
.66177 .12361 L
.66412 .12361 L
.66534 .12361 L
.66604 .12361 L
s
.66604 .12361 m
.6663 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.32392 .12361 L
.32831 .12361 L
.33073 .12361 L
.33193 .12361 L
.33304 .12361 L
.33433 .12257 L
.33575 .12114 L
.33823 .11868 L
.34309 .11408 L
.36188 .09883 L
.38221 .08624 L
.39337 .08079 L
.40363 .07657 L
.41406 .07296 L
.4238 .07016 L
.44262 .0661 L
.45259 .06458 L
.45815 .0639 L
.46328 .06336 L
.47346 .06256 L
.47882 .06226 L
.48157 .06213 L
.48452 .06202 L
.4871 .06195 L
.48946 .06189 L
.49171 .06185 L
.49285 .06184 L
.49409 .06182 L
.4948 .06182 L
.49547 .06181 L
.49673 .06181 L
.49744 .0618 L
.49809 .0618 L
.4988 .0618 L
.49956 .0618 L
.50081 .06181 L
.50198 .0618 L
.50327 .06178 L
.50399 .06177 L
.50465 .06175 L
Mistroke
.50715 .06167 L
.50943 .06157 L
.51452 .06125 L
.51923 .06085 L
.52367 .0604 L
.54441 .05748 L
.58301 .05001 L
.62406 .04113 L
.64453 .03688 L
.65451 .03494 L
.65924 .03406 L
.6636 .03327 L
.66474 .03306 L
.6658 .03288 L
.66691 .12361 L
.66813 .12361 L
.67304 .12361 L
.68197 .12361 L
.70163 .12361 L
.74037 .12361 L
.78156 .12361 L
.82124 .12361 L
.8594 .12361 L
.90001 .12361 L
.93911 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0Voooo0P1VofKoool0
08ooool00`000?ooooooo`0Poooo1P1Vo`03oooo06Kooooo06Goool008ooool00`000?ooooooo`0K
oooo1@1Vo`Ooool00`1Vooooooooo`1Toooo002?oooo00<0003oooooool06?ooo`<0I_l<oooo00<0
I_ooooooool0I?ooo`00Soooo`030000oooooooo01Coool406Ko3oooo`0306Kooooooooo06Coool0
08ooool200004Oooo`@0I_lCoooo00<0I_ooooooool0I?ooo`00Soooo`030000oooooooo00_oool5
06Ko5oooo`0306Kooooooooo06Coool008ooool00`000?ooooooo`02oooo2@1Voacoool00`1Voooo
ooooo`1Toooo0022oooo3@1Vo`03000006Ko06Ko0080I_lUoooo00<0I_ooooooool0I?ooo`00Oooo
o`<0I_l=oooo00<0003oooooool09oooo`0306Kooooooooo06Coool007_oool406Ko4?ooo`030000
oooooooo02Ooool00`1Vooooooooo`1Toooo001goooo101VoaCoool20000:?ooo`0306Kooooooooo
06Coool001Ooool40000>Oooo`D0000Loooo0P1VoaSoool00`000?ooooooo`0Woooo00<0I_oooooo
ool03Oooo`D0000hoooo100001Koool001Ooool00`000?ooooooo`0loooo00<0003oooooool06_oo
o`80I_lJoooo00<0003oooooool09oooo`0306Kooooooooo00ooool00`000?ooooooo`0hoooo00<0
003oooooool05oooo`006?ooo`030000oooooooo03_oool00`000?ooooooo`0Hoooo0P1Voacoool0
0`000?ooooooo`0Woooo00<0I_ooooooool03oooo`030000oooooooo03Woool00`000?ooooooo`0F
oooo000Aoooo100000Coool00`000?ooooooo`0boooo100000Coool00`000?ooooooo`0Foooo0P1V
oakoool00`000?ooooooo`0Woooo00<0I_ooooooool03oooo`030000oooooooo03[oool00`000?oo
ooooo`0Eoooo000Goooo00@0003oooooool0000koooo00<0003oooooool05?ooo`80I_lPoooo00<0
003oooooool09oooo`0306Kooooooooo00ooool00`000?ooooooo`0hoooo00@0003oooooool0000F
oooo000Hoooo0P0003_oool200005Oooo`0306Kooooooooo023oool20000:?ooo`0306Kooooooooo
00koool20000>oooo`80000Goooo001[oooo00<0I_ooooooool08Oooo`030000oooooooo02Ooool0
0`1Vooooooooo`1Toooo001Yoooo0P1VobCoool00`000?ooooooo`0Woooo00<0I_ooooooool0I?oo
o`00J?ooo`0306Kooooooooo02Coool00`000?ooooooo`0Woooo00<0I_ooooooool0I?ooo`00Iooo
o`0306Kooooooooo02Goool00`000?ooooooo`0Woooo00<0I_ooooooool0I?ooo`00I_ooo`0306Ko
oooooooo02Koool00`000?ooooooo`0Woooo00<0I_ooooooool0I?ooo`004?ooool0000Aoooo000F
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000<co`000ol0VC?o03?o0003
<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000oooooooo00Woool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o
03?o000W<ol000?o09Tco`0co`003c?o00T0000doooo00<0003oooooool05Oooo`00Soooo`030000
<ol0<ol002Lco`000ol0VC?o03?o0009<ol01P0005Goool008ooool00`0003?o03?o000W<ol000?o
09Tco`0co`001c?o0080001Koooo002?oooo00<0000co`0co`009c?o0003o`2I<ol0<ol000Dco`02
0000GOooo`00Soooo`030000<ol0<ol002Lco`000ol0VC?o03?o0002<ol00`0005ooool008ooool2
0000:3?o0003o`2I<ol000000080001Roooo002?oooo00<0000co`0co`009c?o0003o`2I0000oooo
06Coool008ooool00`0003?o03?o000V<ol000<0003o09Woool0IOooo`00Soooo`030000<ol0<ol0
02Dco`000`000?ooool0V@1Voooo002?oooo00<0000co`0co`0093?o00040000ooooooooo`2II_oo
o`00Soooo`030000<ol0<ol0028co`0200000oooo`03o`2Ioooooooo06Coool008ooool200008S?o
00030000oooooooo00?oool00ol0VOooooooo`1Toooo002?oooo00<0000co`0co`0083?o00030000
oooooooo00Coool00ol0VOooooooo`1Toooo002?oooo00<0000co`0co`007c?o00030000oooooooo
00Goool00ol0VOooooooo`1Toooo002?oooo00<0000co`0co`007c?o00030000oooooooo00Goool0
0ol0VOooooooo`1Toooo002?oooo00<0000co`0co`007S?o00030000oooooooo00Koool00ol0VOoo
ooooo`1Toooo002?oooo00<0000co`0co`007C?o00030000oooooooo00Ooool00ol0VOooooooo`1T
oooo002?oooo0P0001dco`000`000?ooooooo`08oooo00?o09Woooooool0I?ooo`00Soooo`030000
<ol0<ol001/co`000`000?ooooooo`09oooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol0
01/co`000`000?ooooooo`09oooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol001Xco`00
0`000?ooooooo`0:oooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol001Xco`000`000?oo
ooooo`0:oooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`0;
oooo00?o09Woooooool0I?ooo`00Soooo`80000J<ol000<0003oooooool02oooo`03o`2Ioooooooo
06Coool008ooool00`0003?o03?o000H<ol000<0003oooooool03?ooo`03o`2Ioooooooo06Coool0
08ooool00`0003?o03?o000H<ol000<0003oooooool03?ooo`03o`2Ioooooooo06Coool008ooool0
0`0003?o03?o000G<ol000<0003oooooool03Oooo`03o`2Ioooooooo06Coool008ooool00`0003?o
03?o000G<ol000<0003oooooool03Oooo`03o`2Ioooooooo06Coool008Ooool500000oooo`030000
<ol0<ol001Hco`000`000?ooooooo`0>oooo00?o09Woooooool0I?ooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000F<ol000<0003oooooool03_ooo`03o`2Ioooooooo06Coool008Woool0
0`000?ooooooo`03oooo0`0001Dco`000`000?ooooooo`0?oooo00?o09Woooooool0I?ooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool03oooo`03o`2Ioooooooo
06Coool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo00ooool0
0ol0VOooooooo`1Toooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool04?oo
o`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000D<ol000<0003oooooool04?ooo`03o`2I
oooooooo06Coool008ooool00`0003?o03?o000C<ol000<0003oooooool04Oooo`03o`2Ioooooooo
06Coool008ooool2000053?o00030000oooooooo017oool00ol0VOooooooo`1Toooo002?oooo00<0
000co`0co`004c?o00030000oooooooo017oool00ol0VOooooooo`1Toooo002?oooo00<0000co`0c
o`004S?o00030000oooooooo01;oool00ol0VOooooooo`1Toooo002?oooo00<0000co`0co`004S?o
00030000oooooooo01;oool00ol0VOooooooo`1Toooo002?oooo00<0000co`0co`004S?o00030000
oooooooo01;oool00ol0VOooooooo`1Toooo002?oooo00<0000co`0co`004C?o00030000oooooooo
01?oool00ol0VOooooooo`1Toooo002?oooo0P00018co`000`000?ooooooo`0Coooo00?o09Wooooo
ool0I?ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Coooo00?o09Woooooool0I?oo
o`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Coooo00?o09Woooooool0I?ooo`00Sooo
o`030000<ol0<ol0010co`000`000?ooooooo`0Doooo00?o09Woooooool0I?ooo`00Soooo`030000
<ol0<ol0010co`000`000?ooooooo`0Doooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol0
010co`000`000?ooooooo`0Doooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol0010co`00
0`000?ooooooo`0Doooo00?o09Woooooool0I?ooo`00Soooo`80000@<ol000<0003oooooool05Ooo
o`03o`2Ioooooooo06Coool008ooool00`0003?o03?o000?<ol000<0003oooooool05Oooo`03o`2I
oooooooo06Coool008ooool00`0003?o03?o000?<ol000<0003oooooool05Oooo`03o`2Ioooooooo
06Coool008ooool00`0003?o03?o000?<ol000<0003oooooool05Oooo`03o`2Ioooooooo06Coool0
08ooool00`0003?o03?o000?<ol000<0003oooooool05Oooo`03o`2Ioooooooo06Coool008ooool0
0`0003?o03?o000><ol000<0003oooooool05_ooo`03o`2Ioooooooo06Coool008ooool200003c?o
00030000oooooooo01Koool00ol0VOooooooo`1Toooo002?oooo00<0000co`0co`003S?o00030000
oooooooo01Koool00ol0VOooooooo`1Toooo002?oooo00<0000co`0co`003S?o00030000oooooooo
01Koool00ol0VOooooooo`1Toooo002?oooo00<0000co`0co`003C?o00030000oooooooo01Ooool0
0ol0VOooooooo`1Toooo0027oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool05ooo
o`03o`2Ioooooooo06Coool008Ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000
oooooooo01Ooool00ol0VOooooooo`1Toooo0028oooo00<0003oooooool01?ooo`<0000=<ol000<0
003oooooool05oooo`03o`2Ioooooooo06Coool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`003C?o00030000oooooooo01Ooool00ol0VOooooooo`1Toooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0033?o00030000oooooooo01Soool00ol0VOooooooo`1Toooo0028oooo0P00
00Goool00`0003?o03?o000<<ol000<0003oooooool06?ooo`03o`2Ioooooooo06Coool008ooool0
0`0003?o03?o000<<ol000<0003oooooool06?ooo`03o`2Ioooooooo06Coool008ooool00`0003?o
03?o000<<ol000<0003oooooool06?ooo`03o`2Ioooooooo06Coool008ooool200003C?o00030000
oooooooo01Soool00ol0VOooooooo`1Toooo002?oooo00<0000co`0co`0033?o00030000oooooooo
01Soool00ol0VOooooooo`1Toooo002?oooo00<0000co`0co`002c?o00030000oooooooo01Woool0
0ol0VOooooooo`1Toooo002?oooo00<0000co`0co`002c?o00030000oooooooo01Woool00ol0VOoo
ooooo`1Toooo002?oooo00<0000co`0co`002c?o00030000oooooooo01Woool00ol0VOooooooo`1T
oooo002?oooo00<0000co`0co`002c?o00030000oooooooo01Woool00ol0VOooooooo`1Toooo002?
oooo00<0000co`0co`002c?o00030000oooooooo01Woool00ol0VOooooooo`1Toooo002?oooo0P00
00`co`000`000?ooooooo`0Ioooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`0Ioooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0Joooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0J
oooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Joooo00?o
09Woooooool0I?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Joooo00?o09Wooooo
ool0I?ooo`00Soooo`80000;<ol000<0003oooooool06_ooo`03o`2Ioooooooo06Coool008ooool0
0`0003?o03?o000:<ol000<0003oooooool06_ooo`03o`2Ioooooooo06Coool008ooool00`0003?o
03?o000:<ol000<0003oooooool06_ooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o0009
<ol000<0003oooooool06oooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o0009<ol000<0
003oooooool06oooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o0009<ol000<0003ooooo
ool06oooo`03o`2Ioooooooo06Coool008ooool200002S?o00030000oooooooo01_oool00ol0VOoo
ooooo`1Toooo002?oooo00<0000co`0co`002C?o00030000oooooooo01_oool00ol0VOooooooo`1T
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo01_oool00ol0VOooooooo`1Toooo002?
oooo00<0000co`0co`0023?o00030000oooooooo01coool00ol0VOooooooo`1Toooo0028oooo0P00
00Goool00`0003?o03?o0008<ol000<0003oooooool07?ooo`03o`2Ioooooooo06Coool008Ooool0
10000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool07?ooo`03o`2Ioooooooo
06Coool008Woool00`000?ooooooo`03oooo0`0000Pco`000`000?ooooooo`0Loooo00?o09Wooooo
ool0I?ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool07?oo
o`03o`2Ioooooooo06Coool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0
003oooooool07?ooo`03o`2Ioooooooo06Coool008Soool200001Oooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0Moooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0Moooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0M
oooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Moooo00?o
09Woooooool0I?ooo`00Soooo`800008<ol000<0003oooooool07Oooo`03o`2Ioooooooo06Coool0
08ooool00`0003?o03?o0007<ol000<0003oooooool07Oooo`03o`2Ioooooooo06Coool008ooool0
0`0003?o03?o0007<ol000<0003oooooool07Oooo`03o`2Ioooooooo06Coool008ooool00`0003?o
03?o0007<ol000<0003oooooool07Oooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o0006
<ol000<0003oooooool07_ooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o0006<ol000<0
003oooooool07_ooo`03o`2Ioooooooo06Coool008ooool200001c?o00030000oooooooo01koool0
0ol0VOooooooo`1Toooo002?oooo00<0000co`0co`001S?o00030000oooooooo01koool00ol0VOoo
ooooo`1Toooo002?oooo00<0000co`0co`001S?o00030000oooooooo01koool00ol0VOooooooo`1T
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo01koool00ol0VOooooooo`1Toooo002?
oooo00<0000co`0co`001S?o00030000oooooooo01koool00ol0VOooooooo`1Toooo002?oooo00<0
000co`0co`001S?o00030000oooooooo01koool00ol0VOooooooo`1Toooo002?oooo0P0000Hco`00
0`000?ooooooo`0Ooooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`0Ooooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0O
oooo00?o09Woooooool0I?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Ooooo00?o
09Woooooool0I?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Ooooo00?o09Wooooo
ool0I?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Ooooo00?o09Woooooool0I?oo
o`00Soooo`800006<ol000<0003oooooool07oooo`03o`2Ioooooooo06Coool008ooool00`0003?o
03?o0005<ol000<0003oooooool07oooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o0005
<ol000<0003oooooool07oooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o0004<ol000<0
003oooooool08?ooo`03o`2Ioooooooo06Coool008ooool00`0003?o03?o0004<ol000<0003ooooo
ool08?ooo`03o`2Ioooooooo06Coool008Woool300000oooo`030000<ol0<ol000@co`000`000?oo
ooooo`0Poooo00?o09Woooooool0I?ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0004
<ol000<0003oooooool08?ooo`03o`2Ioooooooo06Coool008Ooool500000oooo`<00004<ol000<0
003oooooool08?ooo`03o`2Ioooooooo06Coool008Ooool010000?ooooooo`0000Coool7<ol0R_oo
o`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7
<ol0R_ooo`00Soooo`Lco`2:oooo001loooo00<0003oooooool04?ooo`Lco`0;oooo00<0003ooooo
ool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`06oooo1c?o00coool00`000?oo
ooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002
<ol00P0000Goool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Noooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`8co`000`0003?o03?o0002
<ol01oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_oo
o`030000oooooooo00goool2<ol000<0000co`0co`000S?o00Ooool00`000?ooooooo`03oooo00<0
003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<oooo0S?o00030000<ol0<ol0008co`08
oooo00D0003oooooooooool00000OOooo`00Noooo`050000oooooooooooo000000ooool2<ol000<0
000co`0co`000S?o00Goool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0
003oooooool04?ooo`03<ol00000000000@co`05oooo100000;oool00`000?ooooooo`1loooo002?
oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.72) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65045 .12361 L
.65954 .12361 L
.66412 .12361 L
.66652 .12361 L
.66906 .12361 L
.67014 .12361 L
.67129 .12361 L
s
.67129 .12361 m
.67179 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.30316 .12361 L
.31323 .12361 L
.31875 .12361 L
.32392 .12361 L
.32617 .12361 L
.32728 .12361 L
.32831 .12361 L
.32949 .12266 L
.33078 .12135 L
.33304 .1191 L
.34309 .10985 L
.36188 .09554 L
.38221 .0838 L
.39337 .07874 L
.40363 .07484 L
.41406 .07153 L
.4238 .06898 L
.43364 .06687 L
.44262 .06533 L
.45259 .06399 L
.45778 .06343 L
.46328 .06294 L
.468 .0626 L
.4732 .0623 L
.47793 .06209 L
.48237 .06195 L
.48491 .06189 L
.48629 .06186 L
.48758 .06184 L
.48878 .06183 L
.48986 .06182 L
.49107 .06181 L
.49236 .06181 L
.49303 .0618 L
.49374 .0618 L
.49502 .06181 L
.49573 .06181 L
.49639 .06181 L
.49712 .06182 L
.4979 .06182 L
.49931 .06184 L
.50001 .06185 L
Mistroke
.50064 .06185 L
.50184 .06186 L
.50313 .06186 L
.50437 .06184 L
.50568 .06182 L
.50697 .06179 L
.50839 .06174 L
.51091 .06163 L
.51326 .0615 L
.51859 .06112 L
.5243 .06057 L
.54441 .05786 L
.58582 .04998 L
.62572 .0414 L
.64397 .0376 L
.65436 .03554 L
.65944 .03458 L
.6641 .03372 L
.66875 .03289 L
.66988 .03269 L
.67109 .03248 L
.67178 .12361 L
.67241 .12361 L
.67364 .12361 L
.68391 .12361 L
.70493 .12361 L
.74497 .12361 L
.78349 .12361 L
.82446 .12361 L
.86391 .12361 L
.90185 .12361 L
.94224 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.72) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0Xoooo00<0I_oooooo
ool0Hoooo`00Soooo`030000oooooooo02?oool606KoIOooo`00Soooo`030000oooooooo023oool3
06Ko1Oooo`0306Kooooooooo06?oool008ooool00`000?ooooooo`0Koooo1@1Vo`Soool00`1Voooo
ooooo`1Soooo002?oooo00<0003oooooool05_ooo`D0I_l=oooo00<0I_ooooooool0Hoooo`00Sooo
o`80000Boooo1@1Voa;oool00`1Vooooooooo`1Soooo002?oooo00<0003oooooool02oooo`H0I_lG
oooo00<0I_ooooooool0Hoooo`00Soooo`030000oooooooo00?oool806Ko7Oooo`0306Kooooooooo
06?oool008;oool=06Ko00<00000I_l0I_l00`1VobGoool00`1Vooooooooo`1Soooo001noooo101V
o`goool00`000?ooooooo`0Xoooo00<0I_ooooooool0Hoooo`00NOooo`D0I_lAoooo00<0003ooooo
ool0:?ooo`0306Kooooooooo06?oool007Koool306Ko5_ooo`80000Yoooo00<0I_ooooooool0Hooo
o`005oooo`@0000ioooo1@0001[oool306Ko6Oooo`030000oooooooo02Woool00`1Vooooooooo`0;
oooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?ooooooo`0Hoooo0P1V
oacoool00`000?ooooooo`0Yoooo00<0I_ooooooool03Oooo`030000oooooooo03Soool00`000?oo
ooooo`0Goooo000Hoooo00<0003oooooool0>oooo`030000oooooooo01Koool206Ko7_ooo`030000
oooooooo02Woool00`1Vooooooooo`0=oooo00<0003oooooool0>Oooo`030000oooooooo01Koool0
017oool400001?ooo`030000oooooooo03;oool400001?ooo`030000oooooooo01Coool206Ko8?oo
o`030000oooooooo02Woool00`1Vooooooooo`0=oooo00<0003oooooool0>_ooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0Coooo00<0I_ooooooool08?oo
o`030000oooooooo02Woool00`1Vooooooooo`0=oooo00<0003oooooool0>?ooo`040000oooooooo
00005_ooo`006?ooo`80000koooo0P0001Coool00`1Vooooooooo`0Qoooo0P0002[oool00`1Voooo
ooooo`0<oooo0P0003_oool200005oooo`00JOooo`80I_lToooo00<0003oooooool0:Oooo`0306Ko
oooooooo06;oool006Soool00`1Vooooooooo`0Toooo00<0003oooooool0:Oooo`0306Kooooooooo
06;oool006Ooool00`1Vooooooooo`0Uoooo00<0003oooooool0:Oooo`0306Kooooooooo06;oool0
06Koool00`1Vooooooooo`0Voooo00<0003oooooool0:Oooo`0306Kooooooooo06;oool006Goool0
0`1Vooooooooo`0Woooo00<0003oooooool0:Oooo`0306Kooooooooo06;oool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0004<ol000?o09Tco`0c
o`000S?o00030000<ol0<ol000Tco`000`0003?o03?o0006<ol08P0000Koool00`000?ooooooo`09
oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0
000co`0co`00:3?o0003o`2I<ol0<ol000hco`090000=?ooo`030000oooooooo01Goool008ooool0
0`0003?o03?o000X<ol000?o09Tco`0co`0023?o00H0001Eoooo002?oooo00<0000co`0co`00:3?o
0003o`2I<ol0<ol000Hco`020000Foooo`00Soooo`030000<ol0<ol002Pco`000ol0VC?o03?o0004
<ol00P0005goool008ooool00`0003?o03?o000X<ol000Co09Tco`0co`0co`030000Goooo`00Sooo
o`80000Y<ol000Co09T000000000001Roooo002?oooo00<0000co`0co`009c?o00030000o`2Ioooo
06Coool008ooool00`0003?o03?o000V<ol000<0003ooooo09T0IOooo`00Soooo`030000<ol0<ol0
02Dco`0010000?ooooooool0VFGoool008ooool00`0003?o03?o000T<ol000D0003ooooooooooooo
09T0IOooo`00Soooo`030000<ol0<ol0028co`0200001?ooo`03o`2Ioooooooo06?oool008ooool2
00008S?o00030000oooooooo00Coool00ol0VOooooooo`1Soooo002?oooo00<0000co`0co`0083?o
00030000oooooooo00Goool00ol0VOooooooo`1Soooo002?oooo00<0000co`0co`007c?o00030000
oooooooo00Koool00ol0VOooooooo`1Soooo002?oooo00<0000co`0co`007c?o00030000oooooooo
00Koool00ol0VOooooooo`1Soooo002?oooo00<0000co`0co`007S?o00030000oooooooo00Ooool0
0ol0VOooooooo`1Soooo002?oooo00<0000co`0co`007C?o00030000oooooooo00Soool00ol0VOoo
ooooo`1Soooo002?oooo0P0001dco`000`000?ooooooo`09oooo00?o09Woooooool0Hoooo`00Sooo
o`030000<ol0<ol001/co`000`000?ooooooo`0:oooo00?o09Woooooool0Hoooo`00Soooo`030000
<ol0<ol001/co`000`000?ooooooo`0:oooo00?o09Woooooool0Hoooo`00Soooo`030000<ol0<ol0
01Xco`000`000?ooooooo`0;oooo00?o09Woooooool0Hoooo`00Soooo`030000<ol0<ol001Xco`00
0`000?ooooooo`0;oooo00?o09Woooooool0Hoooo`00Soooo`030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo00?o09Woooooool0Hoooo`00Soooo`80000J<ol000<0003oooooool03?ooo`03o`2I
oooooooo06?oool008ooool00`0003?o03?o000H<ol000<0003oooooool03Oooo`03o`2Ioooooooo
06?oool008ooool00`0003?o03?o000H<ol000<0003oooooool03Oooo`03o`2Ioooooooo06?oool0
08ooool00`0003?o03?o000G<ol000<0003oooooool03_ooo`03o`2Ioooooooo06?oool008ooool0
0`0003?o03?o000G<ol000<0003oooooool03_ooo`03o`2Ioooooooo06?oool008Ooool500000ooo
o`030000<ol0<ol001Hco`000`000?ooooooo`0?oooo00?o09Woooooool0Hoooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000F<ol000<0003oooooool03oooo`03o`2Ioooooooo06?oool0
08Woool00`000?ooooooo`03oooo0`0001Dco`000`000?ooooooo`0@oooo00?o09Woooooool0Hooo
o`00ROooo`030000oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool04?ooo`03o`2I
oooooooo06?oool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo
013oool00ol0VOooooooo`1Soooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003ooooo
ool04Oooo`03o`2Ioooooooo06?oool008ooool00`0003?o03?o000D<ol000<0003oooooool04Ooo
o`03o`2Ioooooooo06?oool008ooool00`0003?o03?o000C<ol000<0003oooooool04_ooo`03o`2I
oooooooo06?oool008ooool2000053?o00030000oooooooo01;oool00ol0VOooooooo`1Soooo002?
oooo00<0000co`0co`004c?o00030000oooooooo01;oool00ol0VOooooooo`1Soooo002?oooo00<0
000co`0co`004S?o00030000oooooooo01?oool00ol0VOooooooo`1Soooo002?oooo00<0000co`0c
o`004S?o00030000oooooooo01?oool00ol0VOooooooo`1Soooo002?oooo00<0000co`0co`004S?o
00030000oooooooo01?oool00ol0VOooooooo`1Soooo002?oooo00<0000co`0co`004C?o00030000
oooooooo01Coool00ol0VOooooooo`1Soooo002?oooo0P00018co`000`000?ooooooo`0Doooo00?o
09Woooooool0Hoooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Doooo00?o09Wooooo
ool0Hoooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Doooo00?o09Woooooool0Hooo
o`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Eoooo00?o09Woooooool0Hoooo`00Sooo
o`030000<ol0<ol0010co`000`000?ooooooo`0Eoooo00?o09Woooooool0Hoooo`00Soooo`030000
<ol0<ol0010co`000`000?ooooooo`0Eoooo00?o09Woooooool0Hoooo`00Soooo`030000<ol0<ol0
010co`000`000?ooooooo`0Eoooo00?o09Woooooool0Hoooo`00Soooo`80000@<ol000<0003ooooo
ool05_ooo`03o`2Ioooooooo06?oool008ooool00`0003?o03?o000?<ol000<0003oooooool05_oo
o`03o`2Ioooooooo06?oool008ooool00`0003?o03?o000?<ol000<0003oooooool05_ooo`03o`2I
oooooooo06?oool008ooool00`0003?o03?o000?<ol000<0003oooooool05_ooo`03o`2Ioooooooo
06?oool008ooool00`0003?o03?o000?<ol000<0003oooooool05_ooo`03o`2Ioooooooo06?oool0
08ooool00`0003?o03?o000><ol000<0003oooooool05oooo`03o`2Ioooooooo06?oool008ooool2
00003c?o00030000oooooooo01Ooool00ol0VOooooooo`1Soooo002?oooo00<0000co`0co`003S?o
00030000oooooooo01Ooool00ol0VOooooooo`1Soooo002?oooo00<0000co`0co`003S?o00030000
oooooooo01Ooool00ol0VOooooooo`1Soooo002?oooo00<0000co`0co`003C?o00030000oooooooo
01Soool00ol0VOooooooo`1Soooo0027oooo100000Coool00`0003?o03?o000=<ol000<0003ooooo
ool06?ooo`03o`2Ioooooooo06?oool008Ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o
00030000oooooooo01Soool00ol0VOooooooo`1Soooo0028oooo00<0003oooooool01?ooo`<0000=
<ol000<0003oooooool06?ooo`03o`2Ioooooooo06?oool008Woool00`000?ooooooo`03oooo00<0
000co`0co`003C?o00030000oooooooo01Woool00ol0VOooooooo`1Roooo0027oooo00@0003ooooo
ool00004oooo00<0000co`0co`0033?o00030000oooooooo01[oool00ol0VOooooooo`1Roooo0028
oooo0P0000Goool00`0003?o03?o000<<ol000<0003oooooool06_ooo`03o`2Ioooooooo06;oool0
08ooool00`0003?o03?o000<<ol000<0003oooooool06_ooo`03o`2Ioooooooo06;oool008ooool0
0`0003?o03?o000<<ol000<0003oooooool06_ooo`03o`2Ioooooooo06;oool008ooool200003C?o
00030000oooooooo01[oool00ol0VOooooooo`1Roooo002?oooo00<0000co`0co`0033?o00030000
oooooooo01[oool00ol0VOooooooo`1Roooo002?oooo00<0000co`0co`002c?o00030000oooooooo
01_oool00ol0VOooooooo`1Roooo002?oooo00<0000co`0co`002c?o00030000oooooooo01_oool0
0ol0VOooooooo`1Roooo002?oooo00<0000co`0co`002c?o00030000oooooooo01_oool00ol0VOoo
ooooo`1Roooo002?oooo00<0000co`0co`002c?o00030000oooooooo01_oool00ol0VOooooooo`1R
oooo002?oooo00<0000co`0co`002c?o00030000oooooooo01_oool00ol0VOooooooo`1Roooo002?
oooo0P0000`co`000`000?ooooooo`0Koooo00?o09Woooooool0H_ooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`0Koooo00?o09Woooooool0H_ooo`00Soooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0Loooo00?o09Woooooool0H_ooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0Loooo00?o09Woooooool0H_ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0L
oooo00?o09Woooooool0H_ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Loooo00?o
09Woooooool0H_ooo`00Soooo`80000;<ol000<0003oooooool07?ooo`03o`2Ioooooooo06;oool0
08ooool00`0003?o03?o000:<ol000<0003oooooool07?ooo`03o`2Ioooooooo06;oool008ooool0
0`0003?o03?o000:<ol000<0003oooooool07?ooo`03o`2Ioooooooo06;oool008ooool00`0003?o
03?o0009<ol000<0003oooooool07Oooo`03o`2Ioooooooo06;oool008ooool00`0003?o03?o0009
<ol000<0003oooooool07Oooo`03o`2Ioooooooo06;oool008ooool00`0003?o03?o0009<ol000<0
003oooooool07Oooo`03o`2Ioooooooo06;oool008ooool200002S?o00030000oooooooo01goool0
0ol0VOooooooo`1Roooo002?oooo00<0000co`0co`002C?o00030000oooooooo01goool00ol0VOoo
ooooo`1Roooo002?oooo00<0000co`0co`002C?o00030000oooooooo01goool00ol0VOooooooo`1R
oooo002?oooo00<0000co`0co`0023?o00030000oooooooo01koool00ol0VOooooooo`1Roooo0028
oooo0P0000Goool00`0003?o03?o0008<ol000<0003oooooool07_ooo`03o`2Ioooooooo06;oool0
08Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool07_ooo`03o`2I
oooooooo06;oool008Woool00`000?ooooooo`03oooo0`0000Pco`000`000?ooooooo`0Noooo00?o
09Woooooool0H_ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008<ol000<0003ooooo
ool07_ooo`03o`2Ioooooooo06;oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008
<ol000<0003oooooool07_ooo`03o`2Ioooooooo06;oool008Soool200001Oooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0Ooooo00?o09Woooooool0H_ooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0Ooooo00?o09Woooooool0H_ooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0Ooooo00?o09Woooooool0H_ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0O
oooo00?o09Woooooool0H_ooo`00Soooo`800008<ol000<0003oooooool07oooo`03o`2Ioooooooo
06;oool008ooool00`0003?o03?o0007<ol000<0003oooooool07oooo`03o`2Ioooooooo06;oool0
08ooool00`0003?o03?o0007<ol000<0003oooooool07oooo`03o`2Ioooooooo06;oool008ooool0
0`0003?o03?o0007<ol000<0003oooooool07oooo`03o`2Ioooooooo06;oool008ooool00`0003?o
03?o0006<ol000<0003oooooool08?ooo`03o`2Ioooooooo06;oool008ooool00`0003?o03?o0006
<ol000<0003oooooool08?ooo`03o`2Ioooooooo06;oool008ooool200001c?o00030000oooooooo
023oool00ol0VOooooooo`1Roooo002?oooo00<0000co`0co`001S?o00030000oooooooo023oool0
0ol0VOooooooo`1Roooo002?oooo00<0000co`0co`001S?o00030000oooooooo023oool00ol0VOoo
ooooo`1Roooo002?oooo00<0000co`0co`001S?o00030000oooooooo023oool00ol0VOooooooo`1R
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo023oool00ol0VOooooooo`1Roooo002?
oooo00<0000co`0co`001S?o00030000oooooooo023oool00ol0VOooooooo`1Roooo002?oooo0P00
00Hco`000`000?ooooooo`0Qoooo00?o09Woooooool0H_ooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`0Qoooo00?o09Woooooool0H_ooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`0Qoooo00?o09Woooooool0H_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Q
oooo00?o09Woooooool0H_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Qoooo00?o
09Woooooool0H_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Qoooo00?o09Wooooo
ool0H_ooo`00Soooo`800006<ol000<0003oooooool08Oooo`03o`2Ioooooooo06;oool008ooool0
0`0003?o03?o0005<ol000<0003oooooool08Oooo`03o`2Ioooooooo06;oool008ooool00`0003?o
03?o0005<ol000<0003oooooool08Oooo`03o`2Ioooooooo06;oool008ooool00`0003?o03?o0004
<ol000<0003oooooool08_ooo`03o`2Ioooooooo06;oool008ooool00`0003?o03?o0004<ol000<0
003oooooool08_ooo`03o`2Ioooooooo06;oool008Woool300000oooo`030000<ol0<ol000@co`00
0`000?ooooooo`0Roooo00?o09Woooooool0H_ooo`00R_ooo`030000oooooooo00;oool00`0003?o
03?o0004<ol000<0003oooooool08_ooo`03o`2Ioooooooo06;oool008Ooool500000oooo`<00004
<ol000<0003oooooool08_ooo`03o`2Ioooooooo06;oool008Ooool010000?ooooooo`0000Coool7
<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool0
08ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>oooo00<0
003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o00ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_oo
o`D00002<ol00P000003<ol0oooooooo00;oool010000?ooooooooooo`@00003oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01oooo`030000<ol0<ol000Dco`04oooo00D0003oooooooooool000001_ooo`030000oooooooo
07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000<ol0<ol000Dco`04
oooo00<0003oooooool00_ooo`030000oooooooo00Coool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0000koool00`0003?o03?o0005<ol01Oooo`030000oooooooo00;oool00`000?oo
ooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000017oool00`0003?o
03?o0005<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`02oooo100000?oool200000oooo`030000
oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.74) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65045 .12361 L
.65954 .12361 L
.66412 .12361 L
.66906 .12361 L
.67133 .12361 L
.67373 .12361 L
.67472 .12361 L
.67578 .12361 L
s
.67578 .12361 m
.67625 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.30316 .12361 L
.31304 .12361 L
.31574 .12361 L
.31865 .12361 L
.32006 .12361 L
.3214 .12361 L
.3226 .12361 L
.32392 .1235 L
.32522 .12216 L
.32644 .12092 L
.32873 .11866 L
.33386 .11381 L
.34309 .10588 L
.36146 .09274 L
.38164 .0818 L
.40157 .07392 L
.41247 .07064 L
.42264 .06815 L
.43309 .06611 L
.44299 .06459 L
.45188 .06355 L
.45687 .06308 L
.46155 .06272 L
.46645 .0624 L
.47095 .06218 L
.47594 .062 L
.47856 .06192 L
.48001 .06189 L
.48132 .06187 L
.48253 .06185 L
.48383 .06183 L
.48455 .06182 L
.48522 .06182 L
.48652 .06181 L
.48764 .0618 L
.48887 .0618 L
.49015 .06181 L
.49135 .06181 L
.49203 .06181 L
.49277 .06182 L
.49412 .06183 L
Mistroke
.49665 .06187 L
.49938 .06192 L
.50081 .06195 L
.50154 .06196 L
.50233 .06197 L
.50302 .06197 L
.50377 .06197 L
.50447 .06197 L
.50511 .06196 L
.50642 .06195 L
.50766 .06192 L
.50891 .06189 L
.51006 .06185 L
.51267 .06173 L
.51722 .06146 L
.52204 .06107 L
.53202 .06 L
.54303 .05849 L
.58328 .05109 L
.62202 .04284 L
.64171 .0387 L
.65211 .0366 L
.66321 .03446 L
.66876 .03344 L
.67149 .03296 L
.67268 .03275 L
.674 .03252 L
.67518 .03232 L
.67628 .12361 L
.67745 .12361 L
.67869 .12361 L
.68378 .12361 L
.70289 .12361 L
.74422 .12361 L
.78403 .12361 L
.82233 .12361 L
.86308 .12361 L
.90231 .12361 L
.94003 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.74) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0Xoooo0P1VofCoool0
08ooool00`000?ooooooo`0Soooo1`1VofCoool008ooool00`000?ooooooo`0Ooooo101Vo`Koool0
0`1Vooooooooo`1Roooo002?oooo00<0003oooooool06_ooo`D0I_l:oooo00<0I_ooooooool0H_oo
o`00Soooo`030000oooooooo01Goool506Ko3oooo`0306Kooooooooo06;oool008ooool200004Ooo
o`D0I_lDoooo00<0I_ooooooool0H_ooo`00Soooo`030000oooooooo00_oool506Ko6Oooo`0306Ko
oooooooo06;oool008ooool00`000?ooooooo`05oooo1P1Voakoool00`1Vooooooooo`1Roooo0020
oooo3`1Vo`03000006Ko06Ko00D0I_lToooo00<0I_ooooooool0H_ooo`00Noooo`D0I_l?oooo00<0
003oooooool0:Oooo`0306Kooooooooo06;oool007Soool306Ko5?ooo`030000oooooooo02Woool0
0`1Vooooooooo`1Roooo001eoooo0`1VoaOoool20000:_ooo`0306Kooooooooo06;oool001Ooool4
0000>Oooo`D0000Joooo0P1Voa[oool00`000?ooooooo`0Zoooo00<0I_ooooooool02_ooo`D0000h
oooo100001Koool001Ooool00`000?ooooooo`0loooo00<0003oooooool06?ooo`80I_lLoooo00<0
003oooooool0:_ooo`0306Kooooooooo00coool00`000?ooooooo`0hoooo00<0003oooooool05ooo
o`006?ooo`030000oooooooo03_oool00`000?ooooooo`0Foooo0P1Voakoool00`000?ooooooo`0Z
oooo00<0I_ooooooool03?ooo`030000oooooooo03Woool00`000?ooooooo`0Foooo000Aoooo1000
00Coool00`000?ooooooo`0boooo100000Coool00`000?ooooooo`0Doooo0P1Vob3oool00`000?oo
ooooo`0Zoooo00<0I_ooooooool03?ooo`030000oooooooo03[oool00`000?ooooooo`0Eoooo000G
oooo00@0003oooooool0000koooo00<0003oooooool04oooo`0306Kooooooooo023oool00`000?oo
ooooo`0Zoooo00<0I_ooooooool03?ooo`030000oooooooo03Soool010000?ooooooo`0001Koool0
01Soool20000>oooo`80000Coooo0P1Vob?oool20000:oooo`0306Kooooooooo00_oool20000>ooo
o`80000Goooo001Xoooo0P1VobGoool00`000?ooooooo`0Zoooo00<0I_ooooooool0HOooo`00Iooo
o`0306Kooooooooo02Goool00`000?ooooooo`0Zoooo00<0I_ooooooool0HOooo`00I_ooo`0306Ko
oooooooo02Koool00`000?ooooooo`0Zoooo00<0I_ooooooool0HOooo`00IOooo`0306Kooooooooo
02Ooool00`000?ooooooo`0Zoooo00<0I_ooooooool0HOooo`00I?ooo`0306Kooooooooo02Soool0
0`000?ooooooo`0Zoooo00<0I_ooooooool0HOooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`001?l0VC?o03?o000000/co`000`0003?o
03?o0006<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000
oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`00:S?o0003o`2I<ol0<ol000`co`09
0000=?ooo`030000oooooooo01Goool008ooool00`0003?o03?o000Z<ol000?o09Tco`0co`001S?o
00H0001Eoooo002?oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol000@co`020000Foooo`00Sooo
o`030000<ol0<ol002Xco`000ol0VC?o03?o0002<ol00P0005goool008ooool00`0003?o03?o000Z
<ol000?o09Tco`0000000P0005ooool008ooool20000:S?o00030000o`2I000006;oool008ooool0
0`0003?o03?o000W<ol00P000003ooooo`2Ioooo06;oool008ooool00`0003?o03?o000V<ol000D0
003ooooooooooooo09T0Hoooo`00Soooo`030000<ol0<ol002Dco`000`000?ooooooo`02oooo00?o
09Woooooool0HOooo`00Soooo`030000<ol0<ol002@co`000`000?ooooooo`03oooo00?o09Wooooo
ool0HOooo`00Soooo`030000<ol0<ol0028co`0200001_ooo`03o`2Ioooooooo067oool008ooool2
00008S?o00030000oooooooo00Koool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`0083?o
00030000oooooooo00Ooool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`007c?o00030000
oooooooo00Soool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`007c?o00030000oooooooo
00Soool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`007S?o00030000oooooooo00Woool0
0ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`007C?o00030000oooooooo00[oool00ol0VOoo
ooooo`1Qoooo002?oooo0P0001dco`000`000?ooooooo`0;oooo00?o09Woooooool0HOooo`00Sooo
o`030000<ol0<ol001/co`000`000?ooooooo`0<oooo00?o09Woooooool0HOooo`00Soooo`030000
<ol0<ol001/co`000`000?ooooooo`0<oooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol0
01Xco`000`000?ooooooo`0=oooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol001Xco`00
0`000?ooooooo`0=oooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol001Tco`000`000?oo
ooooo`0>oooo00?o09Woooooool0HOooo`00Soooo`80000J<ol000<0003oooooool03_ooo`03o`2I
oooooooo067oool008ooool00`0003?o03?o000H<ol000<0003oooooool03oooo`03o`2Ioooooooo
067oool008ooool00`0003?o03?o000H<ol000<0003oooooool03oooo`03o`2Ioooooooo067oool0
08ooool00`0003?o03?o000G<ol000<0003oooooool04?ooo`03o`2Ioooooooo067oool008ooool0
0`0003?o03?o000G<ol000<0003oooooool04?ooo`03o`2Ioooooooo067oool008Ooool500000ooo
o`030000<ol0<ol001Hco`000`000?ooooooo`0Aoooo00?o09Woooooool0HOooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000F<ol000<0003oooooool04Oooo`03o`2Ioooooooo067oool0
08Woool00`000?ooooooo`03oooo0`0001Dco`000`000?ooooooo`0Boooo00?o09Woooooool0HOoo
o`00ROooo`030000oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool04_ooo`03o`2I
oooooooo067oool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo
01;oool00ol0VOooooooo`1Qoooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003ooooo
ool04oooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o000D<ol000<0003oooooool04ooo
o`03o`2Ioooooooo067oool008ooool00`0003?o03?o000C<ol000<0003oooooool05?ooo`03o`2I
oooooooo067oool008ooool2000053?o00030000oooooooo01Coool00ol0VOooooooo`1Qoooo002?
oooo00<0000co`0co`004c?o00030000oooooooo01Coool00ol0VOooooooo`1Qoooo002?oooo00<0
000co`0co`004S?o00030000oooooooo01Goool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0c
o`004S?o00030000oooooooo01Goool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`004S?o
00030000oooooooo01Goool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`004C?o00030000
oooooooo01Koool00ol0VOooooooo`1Qoooo002?oooo0P00018co`000`000?ooooooo`0Foooo00?o
09Woooooool0HOooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Foooo00?o09Wooooo
ool0HOooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Foooo00?o09Woooooool0HOoo
o`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Goooo00?o09Woooooool0HOooo`00Sooo
o`030000<ol0<ol0010co`000`000?ooooooo`0Goooo00?o09Woooooool0HOooo`00Soooo`030000
<ol0<ol0010co`000`000?ooooooo`0Goooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol0
010co`000`000?ooooooo`0Goooo00?o09Woooooool0HOooo`00Soooo`80000@<ol000<0003ooooo
ool06?ooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o000?<ol000<0003oooooool06?oo
o`03o`2Ioooooooo067oool008ooool00`0003?o03?o000?<ol000<0003oooooool06?ooo`03o`2I
oooooooo067oool008ooool00`0003?o03?o000?<ol000<0003oooooool06?ooo`03o`2Ioooooooo
067oool008ooool00`0003?o03?o000?<ol000<0003oooooool06?ooo`03o`2Ioooooooo067oool0
08ooool00`0003?o03?o000><ol000<0003oooooool06Oooo`03o`2Ioooooooo067oool008ooool2
00003c?o00030000oooooooo01Woool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`003S?o
00030000oooooooo01Woool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`003S?o00030000
oooooooo01Woool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`003C?o00030000oooooooo
01[oool00ol0VOooooooo`1Qoooo0027oooo100000Coool00`0003?o03?o000=<ol000<0003ooooo
ool06_ooo`03o`2Ioooooooo067oool008Ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o
00030000oooooooo01[oool00ol0VOooooooo`1Qoooo0028oooo00<0003oooooool01?ooo`<0000=
<ol000<0003oooooool06_ooo`03o`2Ioooooooo067oool008Woool00`000?ooooooo`03oooo00<0
000co`0co`003C?o00030000oooooooo01[oool00ol0VOooooooo`1Qoooo0027oooo00@0003ooooo
ool00004oooo00<0000co`0co`0033?o00030000oooooooo01_oool00ol0VOooooooo`1Qoooo0028
oooo0P0000Goool00`0003?o03?o000<<ol000<0003oooooool06oooo`03o`2Ioooooooo067oool0
08ooool00`0003?o03?o000<<ol000<0003oooooool06oooo`03o`2Ioooooooo067oool008ooool0
0`0003?o03?o000<<ol000<0003oooooool06oooo`03o`2Ioooooooo067oool008ooool200003C?o
00030000oooooooo01_oool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`0033?o00030000
oooooooo01_oool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`002c?o00030000oooooooo
01coool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`002c?o00030000oooooooo01coool0
0ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`002c?o00030000oooooooo01coool00ol0VOoo
ooooo`1Qoooo002?oooo00<0000co`0co`002c?o00030000oooooooo01coool00ol0VOooooooo`1Q
oooo002?oooo00<0000co`0co`002c?o00030000oooooooo01coool00ol0VOooooooo`1Qoooo002?
oooo0P0000`co`000`000?ooooooo`0Loooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`0Loooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0Moooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0Moooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0M
oooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Moooo00?o
09Woooooool0HOooo`00Soooo`80000;<ol000<0003oooooool07Oooo`03o`2Ioooooooo067oool0
08ooool00`0003?o03?o000:<ol000<0003oooooool07Oooo`03o`2Ioooooooo067oool008ooool0
0`0003?o03?o000:<ol000<0003oooooool07Oooo`03o`2Ioooooooo067oool008ooool00`0003?o
03?o0009<ol000<0003oooooool07_ooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o0009
<ol000<0003oooooool07_ooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o0009<ol000<0
003oooooool07_ooo`03o`2Ioooooooo067oool008ooool200002S?o00030000oooooooo01koool0
0ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`002C?o00030000oooooooo01koool00ol0VOoo
ooooo`1Qoooo002?oooo00<0000co`0co`002C?o00030000oooooooo01koool00ol0VOooooooo`1Q
oooo002?oooo00<0000co`0co`0023?o00030000oooooooo01ooool00ol0VOooooooo`1Qoooo0028
oooo0P0000Goool00`0003?o03?o0008<ol000<0003oooooool07oooo`03o`2Ioooooooo067oool0
08Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool07oooo`03o`2I
oooooooo067oool008Woool00`000?ooooooo`03oooo0`0000Pco`000`000?ooooooo`0Ooooo00?o
09Woooooool0HOooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008<ol000<0003ooooo
ool07oooo`03o`2Ioooooooo067oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008
<ol000<0003oooooool07oooo`03o`2Ioooooooo067oool008Soool200001Oooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0Poooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0Poooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0Poooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0P
oooo00?o09Woooooool0HOooo`00Soooo`800008<ol000<0003oooooool08?ooo`03o`2Ioooooooo
067oool008ooool00`0003?o03?o0007<ol000<0003oooooool08?ooo`03o`2Ioooooooo067oool0
08ooool00`0003?o03?o0007<ol000<0003oooooool08?ooo`03o`2Ioooooooo067oool008ooool0
0`0003?o03?o0007<ol000<0003oooooool08?ooo`03o`2Ioooooooo067oool008ooool00`0003?o
03?o0006<ol000<0003oooooool08Oooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o0006
<ol000<0003oooooool08Oooo`03o`2Ioooooooo067oool008ooool200001c?o00030000oooooooo
027oool00ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`001S?o00030000oooooooo027oool0
0ol0VOooooooo`1Qoooo002?oooo00<0000co`0co`001S?o00030000oooooooo027oool00ol0VOoo
ooooo`1Qoooo002?oooo00<0000co`0co`001S?o00030000oooooooo027oool00ol0VOooooooo`1Q
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo027oool00ol0VOooooooo`1Qoooo002?
oooo00<0000co`0co`001S?o00030000oooooooo027oool00ol0VOooooooo`1Qoooo002?oooo0P00
00Hco`000`000?ooooooo`0Roooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`0Roooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`0Roooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0R
oooo00?o09Woooooool0HOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Roooo00?o
09Woooooool0HOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Roooo00?o09Wooooo
ool0HOooo`00Soooo`800006<ol000<0003oooooool08_ooo`03o`2Ioooooooo067oool008ooool0
0`0003?o03?o0005<ol000<0003oooooool08_ooo`03o`2Ioooooooo067oool008ooool00`0003?o
03?o0005<ol000<0003oooooool08_ooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o0004
<ol000<0003oooooool08oooo`03o`2Ioooooooo067oool008ooool00`0003?o03?o0004<ol000<0
003oooooool08oooo`03o`2Ioooooooo067oool008Woool300000oooo`030000<ol0<ol000@co`00
0`000?ooooooo`0Soooo00?o09Woooooool0HOooo`00R_ooo`030000oooooooo00;oool00`0003?o
03?o0004<ol000<0003oooooool08oooo`03o`2Ioooooooo067oool008Ooool500000oooo`<00004
<ol000<0003oooooool08oooo`03o`2Ioooooooo067oool008Ooool010000?ooooooo`0000Coool7
<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool0
08ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>oooo00<0
003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o00ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_oo
o`D00002<ol00P000003<ol0oooooooo00;oool00`000?ooooooo`03oooo0`0000;oool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`07oooo00<0000co`0co`001C?o00Coool00`000?ooooooo`04oooo00D0003oooooooooool0
0000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0000co`0co`001C?o
00Coool010000?ooooooooooo`D00003oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo
00D0000>oooo00<0000co`0co`001C?o00Goool010000?ooooooo`0000;oool01@000?oooooooooo
o`00001joooo001hoooo00D0003oooooooooool000004Oooo`030000<ol0<ol000Dco`02oooo00@0
003oooooool00003oooo00<0003oool000000oooo`030000oooooooo07Soool007Woool00`000?oo
ooooo`0Aoooo0P0000Lco`02oooo100000Coool200000_ooo`030000oooooooo07Woool008ooool7
<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.76) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65954 .12361 L
.66906 .12361 L
.67373 .12361 L
.67803 .12361 L
.67928 .12361 L
.68044 .12361 L
s
.68044 .12361 m
.68093 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.30316 .12361 L
.31304 .12361 L
.31574 .12361 L
.31723 .12361 L
.31797 .12361 L
.31865 .12361 L
.31997 .12266 L
.3214 .1212 L
.32392 .1187 L
.34309 .10215 L
.36361 .08861 L
.38221 .07942 L
.40146 .07244 L
.4123 .06945 L
.42228 .06723 L
.43137 .0656 L
.44111 .06422 L
.4467 .06359 L
.45179 .06311 L
.45663 .06273 L
.46177 .0624 L
.46648 .06217 L
.46898 .06207 L
.47168 .06198 L
.47415 .06192 L
.47641 .06187 L
.47858 .06184 L
.47966 .06183 L
.48085 .06181 L
.48153 .06181 L
.48226 .06181 L
.48294 .0618 L
.48358 .0618 L
.48478 .0618 L
.48605 .06181 L
.48671 .06181 L
.48742 .06182 L
.4887 .06183 L
.49022 .06184 L
.49161 .06186 L
.49406 .06191 L
Mistroke
.49674 .06197 L
.49928 .06204 L
.50039 .06207 L
.50161 .0621 L
.50286 .06212 L
.50418 .06214 L
.50487 .06214 L
.50561 .06213 L
.50631 .06213 L
.50694 .06212 L
.50818 .0621 L
.50888 .06209 L
.50952 .06207 L
.51196 .06199 L
.51412 .0619 L
.5165 .06177 L
.52133 .06143 L
.53216 .06035 L
.54231 .05902 L
.58105 .05215 L
.62224 .04347 L
.64281 .03914 L
.66192 .03533 L
.67142 .03355 L
.67609 .03272 L
.67813 .03237 L
.67922 .03218 L
.68038 .03198 L
.68163 .12361 L
.68279 .12361 L
.68534 .12361 L
.69071 .12361 L
.70008 .12361 L
.74141 .12361 L
.78122 .12361 L
.81952 .12361 L
.86027 .12361 L
.8995 .12361 L
.93722 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.76) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0Zoooo0P1Vof;oool0
08ooool00`000?ooooooo`0Toooo1P1Vo`03oooo06Kooooo067oool008ooool00`000?ooooooo`0O
oooo1@1Vo`Ooool00`1Vooooooooo`1Poooo002?oooo00<0003oooooool06_ooo`D0I_l<oooo00<0
I_ooooooool0H?ooo`00Soooo`030000oooooooo01Goool506Ko4Oooo`0306Kooooooooo063oool0
08ooool200004Oooo`D0I_lFoooo00<0I_ooooooool0H?ooo`00Soooo`030000oooooooo00_oool5
06Ko6oooo`0306Kooooooooo063oool008ooool00`000?ooooooo`04oooo1`1Vob3oool00`1Voooo
ooooo`1Poooo0020oooo3`1Vo`03000006Ko06Ko00@0I_lWoooo00<0I_ooooooool0H?ooo`00Nooo
o`D0I_l?oooo00<0003oooooool0:oooo`0306Kooooooooo063oool007Goool606Ko5?ooo`030000
oooooooo02_oool00`1Vooooooooo`1Poooo001coooo0P1Voa[oool20000;?ooo`0306Kooooooooo
063oool001Ooool40000>Oooo`D0000Hoooo0P1Voacoool00`000?ooooooo`0[oooo00<0I_oooooo
ool02Oooo`D0000hoooo100001Koool001Ooool00`000?ooooooo`0loooo00<0003oooooool05_oo
o`80I_lNoooo00<0003oooooool0:oooo`0306Kooooooooo00_oool00`000?ooooooo`0hoooo00<0
003oooooool05oooo`006?ooo`030000oooooooo03_oool00`000?ooooooo`0Doooo0P1Vob3oool0
0`000?ooooooo`0[oooo00<0I_ooooooool02oooo`030000oooooooo03Woool00`000?ooooooo`0F
oooo000Aoooo100000Coool00`000?ooooooo`0boooo100000Coool00`000?ooooooo`0Coooo00<0
I_ooooooool08?ooo`030000oooooooo02_oool00`1Vooooooooo`0;oooo00<0003oooooool0>_oo
o`030000oooooooo01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`0Aoooo0P1V
ob?oool00`000?ooooooo`0[oooo00<0I_ooooooool02oooo`030000oooooooo03Soool010000?oo
ooooo`0001Koool001Soool20000>oooo`80000Aoooo0P1VobGoool20000;?ooo`0306Kooooooooo
00[oool20000>oooo`80000Goooo001Woooo00<0I_ooooooool09Oooo`030000oooooooo02_oool0
0`1Vooooooooo`1Poooo001Voooo00<0I_ooooooool09_ooo`030000oooooooo02_oool00`1Voooo
ooooo`1Poooo001Toooo0P1VobWoool00`000?ooooooo`0[oooo00<0I_ooooooool0H?ooo`00Hooo
o`0306Kooooooooo02Woool00`000?ooooooo`0[oooo00<0I_ooooooool0H?ooo`00H_ooo`0306Ko
oooooooo02[oool00`000?ooooooo`0[oooo00<0I_ooooooool0H?ooo`004?ooool0000Aoooo000F
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Lco`000ol0VC?o0000000;
<ol000<0000co`0co`001S?o02800006oooo00<0003oooooool02Oooo`030000oooooooo01Goool0
01Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol002/co`000ol0VC?o
03?o000;<ol02@0003Coool00`000?ooooooo`0Eoooo002?oooo00<0000co`0co`00:c?o0003o`2I
<ol0<ol000Dco`060000EOooo`00Soooo`030000<ol0<ol002/co`000ol0VC?o03?o0003<ol00P00
05_oool008ooool00`0003?o03?o000[<ol000Co09Tco`0co`0co`020000GOooo`00Soooo`030000
<ol0<ol002/co`001?l0V@000000000005ooool008ooool20000:S?o008000000ol0VOooooooo`1P
oooo002?oooo00<0000co`0co`009c?o00800002oooo00?o09Woooooool0H?ooo`00Soooo`030000
<ol0<ol002Hco`000`000?ooooooo`02oooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol0
02Dco`000`000?ooooooo`03oooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol002@co`00
0`000?ooooooo`04oooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol0028co`0200001ooo
o`03o`2Ioooooooo063oool008ooool200008S?o00030000oooooooo00Ooool00ol0VOooooooo`1P
oooo002?oooo00<0000co`0co`0083?o00030000oooooooo00Soool00ol0VOooooooo`1Poooo002?
oooo00<0000co`0co`007c?o00030000oooooooo00Woool00ol0VOooooooo`1Poooo002?oooo00<0
000co`0co`007c?o00030000oooooooo00Woool00ol0VOooooooo`1Poooo002?oooo00<0000co`0c
o`007S?o00030000oooooooo00[oool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`007C?o
00030000oooooooo00_oool00ol0VOooooooo`1Poooo002?oooo0P0001dco`000`000?ooooooo`0<
oooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0=oooo00?o
09Woooooool0H?ooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0=oooo00?o09Wooooo
ool0H?ooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0>oooo00?o09Woooooool0H?oo
o`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0>oooo00?o09Woooooool0H?ooo`00Sooo
o`030000<ol0<ol001Tco`000`000?ooooooo`0?oooo00?o09Woooooool0H?ooo`00Soooo`80000J
<ol000<0003oooooool03oooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o000H<ol000<0
003oooooool04?ooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o000H<ol000<0003ooooo
ool04?ooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o000G<ol000<0003oooooool04Ooo
o`03o`2Ioooooooo063oool008ooool00`0003?o03?o000G<ol000<0003oooooool04Oooo`03o`2I
oooooooo063oool008Ooool500000oooo`030000<ol0<ol001Hco`000`000?ooooooo`0Boooo00?o
09Woooooool0H?ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000F<ol000<0003ooooo
ool04_ooo`03o`2Ioooooooo063oool008Woool00`000?ooooooo`03oooo0`0001Dco`000`000?oo
ooooo`0Coooo00?o09Woooooool0H?ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E
<ol000<0003oooooool04oooo`03o`2Ioooooooo063oool008Woool00`000?ooooooo`03oooo00<0
000co`0co`005C?o00030000oooooooo01?oool00ol0VOooooooo`1Poooo0028oooo0P0000Goool0
0`0003?o03?o000D<ol000<0003oooooool05?ooo`03o`2Ioooooooo063oool008ooool00`0003?o
03?o000D<ol000<0003oooooool05?ooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o000C
<ol000<0003oooooool05Oooo`03o`2Ioooooooo063oool008ooool2000053?o00030000oooooooo
01Goool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`004c?o00030000oooooooo01Goool0
0ol0VOooooooo`1Poooo002?oooo00<0000co`0co`004S?o00030000oooooooo01Koool00ol0VOoo
ooooo`1Poooo002?oooo00<0000co`0co`004S?o00030000oooooooo01Koool00ol0VOooooooo`1P
oooo002?oooo00<0000co`0co`004S?o00030000oooooooo01Koool00ol0VOooooooo`1Poooo002?
oooo00<0000co`0co`004C?o00030000oooooooo01Ooool00ol0VOooooooo`1Poooo002?oooo0P00
018co`000`000?ooooooo`0Goooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol0014co`00
0`000?ooooooo`0Goooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol0014co`000`000?oo
ooooo`0Goooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0H
oooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Hoooo00?o
09Woooooool0H?ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Hoooo00?o09Wooooo
ool0H?ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Hoooo00?o09Woooooool0H?oo
o`00Soooo`80000@<ol000<0003oooooool06Oooo`03o`2Ioooooooo063oool008ooool00`0003?o
03?o000?<ol000<0003oooooool06Oooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o000?
<ol000<0003oooooool06Oooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o000?<ol000<0
003oooooool06Oooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o000?<ol000<0003ooooo
ool06Oooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o000><ol000<0003oooooool06_oo
o`03o`2Ioooooooo063oool008ooool200003c?o00030000oooooooo01[oool00ol0VOooooooo`1P
oooo002?oooo00<0000co`0co`003S?o00030000oooooooo01[oool00ol0VOooooooo`1Poooo002?
oooo00<0000co`0co`003S?o00030000oooooooo01[oool00ol0VOooooooo`1Poooo002?oooo00<0
000co`0co`003C?o00030000oooooooo01_oool00ol0VOooooooo`1Poooo0027oooo100000Coool0
0`0003?o03?o000=<ol000<0003oooooool06oooo`03o`2Ioooooooo063oool008Ooool00`000?oo
ooooo`05oooo00<0000co`0co`003C?o00030000oooooooo01_oool00ol0VOooooooo`1Poooo0028
oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool06oooo`03o`2Ioooooooo063oool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo01_oool00ol0VOoo
ooooo`1Poooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0033?o00030000oooooooo
01coool00ol0VOooooooo`1Poooo0028oooo0P0000Goool00`0003?o03?o000<<ol000<0003ooooo
ool07?ooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o000<<ol000<0003oooooool07?oo
o`03o`2Ioooooooo063oool008ooool00`0003?o03?o000<<ol000<0003oooooool07?ooo`03o`2I
oooooooo063oool008ooool200003C?o00030000oooooooo01coool00ol0VOooooooo`1Poooo002?
oooo00<0000co`0co`0033?o00030000oooooooo01coool00ol0VOooooooo`1Poooo002?oooo00<0
000co`0co`002c?o00030000oooooooo01goool00ol0VOooooooo`1Poooo002?oooo00<0000co`0c
o`002c?o00030000oooooooo01goool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`002c?o
00030000oooooooo01goool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`002c?o00030000
oooooooo01goool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`002c?o00030000oooooooo
01goool00ol0VOooooooo`1Poooo002?oooo0P0000`co`000`000?ooooooo`0Moooo00?o09Wooooo
ool0H?ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0Moooo00?o09Woooooool0H?oo
o`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Noooo00?o09Woooooool0H?ooo`00Sooo
o`030000<ol0<ol000Xco`000`000?ooooooo`0Noooo00?o09Woooooool0H?ooo`00Soooo`030000
<ol0<ol000Xco`000`000?ooooooo`0Noooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0Noooo00?o09Woooooool0H?ooo`00Soooo`80000;<ol000<0003ooooo
ool07_ooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o000:<ol000<0003oooooool07_oo
o`03o`2Ioooooooo063oool008ooool00`0003?o03?o000:<ol000<0003oooooool07_ooo`03o`2I
oooooooo063oool008ooool00`0003?o03?o0009<ol000<0003oooooool07oooo`03o`2Ioooooooo
063oool008ooool00`0003?o03?o0009<ol000<0003oooooool07oooo`03o`2Ioooooooo063oool0
08ooool00`0003?o03?o0009<ol000<0003oooooool07oooo`03o`2Ioooooooo063oool008ooool2
00002S?o00030000oooooooo01ooool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`002C?o
00030000oooooooo01ooool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`002C?o00030000
oooooooo01ooool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`0023?o00030000oooooooo
023oool00ol0VOooooooo`1Poooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0003ooooo
ool08?ooo`03o`2Ioooooooo063oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008
<ol000<0003oooooool08?ooo`03o`2Ioooooooo063oool008Woool00`000?ooooooo`03oooo0`00
00Pco`000`000?ooooooo`0Poooo00?o09Woooooool0H?ooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o0008<ol000<0003oooooool08?ooo`03o`2Ioooooooo063oool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool08?ooo`03o`2Ioooooooo063oool0
08Soool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`0Qoooo00?o09Woooooool0H?oo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Qoooo00?o09Woooooool0H?ooo`00Sooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0Qoooo00?o09Woooooool0H?ooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`0Qoooo00?o09Woooooool0H?ooo`00Soooo`800008<ol000<0
003oooooool08Oooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool08Oooo`03o`2Ioooooooo063oool008ooool00`0003?o03?o0007<ol000<0003oooooool08Ooo
o`03o`2Ioooooooo063oool008ooool00`0003?o03?o0007<ol000<0003oooooool08Oooo`03o`2I
oooooooo063oool008ooool00`0003?o03?o0006<ol000<0003oooooool08_ooo`03o`2Ioooooooo
063oool008ooool00`0003?o03?o0006<ol000<0003oooooool08_ooo`03o`2Ioooooooo063oool0
08ooool200001c?o00030000oooooooo02;oool00ol0VOooooooo`1Poooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo02;oool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`001S?o
00030000oooooooo02;oool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`001S?o00030000
oooooooo02;oool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`001S?o00030000oooooooo
02;oool00ol0VOooooooo`1Poooo002?oooo00<0000co`0co`001S?o00030000oooooooo02;oool0
0ol0VOooooooo`1Poooo002?oooo0P0000Hco`000`000?ooooooo`0Soooo00?o09Woooooool0H?oo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Soooo00?o09Woooooool0H?ooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`0Soooo00?o09Woooooool0H?ooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`0Soooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`0Soooo00?o09Woooooool0H?ooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`0Soooo00?o09Woooooool0H?ooo`00Soooo`800006<ol000<0003oooooool08ooo
o`03o`2Ioooooooo063oool008ooool00`0003?o03?o0005<ol000<0003oooooool08oooo`03o`2I
oooooooo063oool008ooool00`0003?o03?o0005<ol000<0003oooooool08oooo`03o`2Ioooooooo
063oool008ooool00`0003?o03?o0004<ol000<0003oooooool09?ooo`03o`2Ioooooooo063oool0
08ooool00`0003?o03?o0004<ol000<0003oooooool09?ooo`03o`2Ioooooooo063oool008Woool3
00000oooo`030000<ol0<ol000@co`000`000?ooooooo`0Toooo00?o09Woooooool0H?ooo`00R_oo
o`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool09?ooo`03o`2Ioooooooo
063oool008Ooool500000oooo`<00004<ol000<0003oooooool09?ooo`03o`2Ioooooooo063oool0
08Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_oo
o`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0
003oooooool04oooo`Lco`0>oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool0
0`000?ooooooo`09oooo1c?o00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01_ooo`D00002<ol00P000003<ol0oooooooo00;oool010000?oo
ooooooooo`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01oooo`030000<ol0<ol000Dco`04oooo00D0003ooooo
ooooool000000_ooo`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0
003oooooool03oooo`030000<ol0<ol000Dco`04oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000koool00`0003?o
03?o0005<ol01Oooo`030000oooooooo00<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo0000017oool00`0003?o03?o0005<ol00_ooo`040000oooooooo00000oooo`030000
oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007<ol00_oo
o`@00003oooo0`0000;oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.78) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65954 .12361 L
.66906 .12361 L
.67803 .12361 L
.68044 .12361 L
.683 .12361 L
.68433 .12361 L
.68509 .12361 L
s
.68509 .12361 m
.68537 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.30316 .12361 L
.30791 .12361 L
.31054 .12361 L
.31183 .12361 L
.31304 .12361 L
.31371 .12361 L
.31444 .12345 L
.31524 .12262 L
.31597 .12188 L
.31865 .11919 L
.32392 .11419 L
.34309 .09865 L
.36233 .08669 L
.38315 .07711 L
.40309 .0706 L
.41313 .06815 L
.42415 .06601 L
.43436 .06447 L
.44366 .06342 L
.44881 .06296 L
.4544 .06256 L
.45969 .06226 L
.46224 .06215 L
.46458 .06206 L
.46679 .06198 L
.46921 .06192 L
.47164 .06187 L
.47299 .06185 L
.47421 .06183 L
.47537 .06182 L
.47647 .06181 L
.47763 .06181 L
.47889 .0618 L
.47999 .0618 L
.48115 .06181 L
.48215 .06181 L
.48324 .06182 L
.48462 .06183 L
.48592 .06185 L
.48837 .06189 L
.49101 .06195 L
Mistroke
.49389 .06202 L
.49867 .06218 L
.50119 .06227 L
.50246 .06231 L
.50318 .06232 L
.50385 .06233 L
.50455 .06234 L
.50519 .06235 L
.50592 .06235 L
.50662 .06235 L
.50785 .06234 L
.50854 .06233 L
.50918 .06232 L
.51033 .0623 L
.51161 .06227 L
.51419 .06217 L
.51652 .06206 L
.51902 .06192 L
.52356 .06158 L
.53451 .06048 L
.54454 .05916 L
.58422 .05214 L
.62238 .04414 L
.64367 .03965 L
.66299 .03577 L
.67266 .03395 L
.67774 .03303 L
.68052 .03254 L
.68312 .03209 L
.68428 .0319 L
.68539 .03171 L
.68666 .12361 L
.68782 .12361 L
.693 .12361 L
.70209 .12361 L
.74039 .12361 L
.78114 .12361 L
.82037 .12361 L
.85809 .12361 L
.89826 .12361 L
.93692 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.78) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0Zoooo0`1Vof7oool0
08ooool00`000?ooooooo`0Toooo1P1Vo`;oool00`1Vooooooooo`1Ooooo002?oooo00<0003ooooo
ool07oooo`D0I_l8oooo00<0I_ooooooool0Goooo`00Soooo`030000oooooooo01[oool506Ko3Ooo
o`0306Kooooooooo05ooool008ooool00`000?ooooooo`0Eoooo1@1Voa;oool00`1Vooooooooo`1O
oooo002?oooo0P00017oool506Ko5oooo`0306Kooooooooo05ooool008ooool00`000?ooooooo`0;
oooo1@1Voacoool00`1Vooooooooo`1Ooooo002?oooo00<0003oooooool01Oooo`H0I_lQoooo00<0
I_ooooooool0Goooo`00O_oooa40I_l00`00001Vo`1Vo`0506Ko9oooo`0306Kooooooooo05ooool0
07Soool606Ko4Oooo`030000oooooooo02coool00`1Vooooooooo`1Ooooo001eoooo0`1VoaOoool0
0`000?ooooooo`0/oooo00<0I_ooooooool0Goooo`00Loooo`80I_lJoooo0P0002goool00`1Voooo
ooooo`1Ooooo000Goooo100003Woool500005oooo`<0I_lLoooo00<0003oooooool0;?ooo`0306Ko
oooooooo00Soool50000>?ooo`@0000Foooo000Goooo00<0003oooooool0??ooo`030000oooooooo
01Goool206Ko7oooo`030000oooooooo02coool00`1Vooooooooo`0:oooo00<0003oooooool0>?oo
o`030000oooooooo01Ooool001Soool00`000?ooooooo`0koooo00<0003oooooool04oooo`80I_lQ
oooo00<0003oooooool0;?ooo`0306Kooooooooo00[oool00`000?ooooooo`0ioooo00<0003ooooo
ool05_ooo`004Oooo`@00004oooo00<0003oooooool0<_ooo`@00004oooo00<0003oooooool04Ooo
o`80I_lSoooo00<0003oooooool0;?ooo`0306Kooooooooo00[oool00`000?ooooooo`0joooo00<0
003oooooool05Oooo`005oooo`040000oooooooo0000>oooo`030000oooooooo00ooool206Ko9Ooo
o`030000oooooooo02coool00`1Vooooooooo`0:oooo00<0003oooooool0>?ooo`040000oooooooo
00005_ooo`006?ooo`80000koooo0P00013oool00`1Vooooooooo`0Uoooo0P0002goool00`1Voooo
ooooo`09oooo0P0003_oool200005oooo`00I_ooo`0306Kooooooooo02Koool00`000?ooooooo`0/
oooo00<0I_ooooooool0Goooo`00I?ooo`80I_lYoooo00<0003oooooool0;?ooo`0306Kooooooooo
05ooool006?oool00`1Vooooooooo`0Yoooo00<0003oooooool0;?ooo`0306Kooooooooo05ooool0
06;oool00`1Vooooooooo`0Zoooo00<0003oooooool0;?ooo`0306Kooooooooo05ooool0067oool0
0`1Vooooooooo`0[oooo00<0003oooooool0;?ooo`0306Kooooooooo05ooool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0008<ol000?o09T0000c
o`002S?o00030000<ol0<ol000Hco`0R00001_ooo`030000oooooooo00Woool00`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000/<ol000?o
09Tco`0co`002S?o00T0000doooo00<0003oooooool05Oooo`00Soooo`030000<ol0<ol002`co`00
0ol0VC?o03?o0004<ol01P0005Goool008ooool00`0003?o03?o000/<ol000?o09Tco`0co`000S?o
0080001Koooo002?oooo00<0000co`0co`00;3?o0003o`2I<ol0<ol00080001Moooo002?oooo00<0
000co`0co`00;3?o0003o`2I0000000005ooool008ooool20000:S?o00<000000ol0VOooooooo`1O
oooo002?oooo00<0000co`0co`009c?o00800003oooo00?o09Woooooool0Goooo`00Soooo`030000
<ol0<ol002Hco`000`000?ooooooo`03oooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol0
02Dco`000`000?ooooooo`04oooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol002@co`00
0`000?ooooooo`05oooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol0028co`0200002?oo
o`03o`2Ioooooooo05ooool008ooool200008S?o00030000oooooooo00Soool00ol0VOooooooo`1O
oooo002?oooo00<0000co`0co`0083?o00030000oooooooo00Woool00ol0VOooooooo`1Ooooo002?
oooo00<0000co`0co`007c?o00030000oooooooo00[oool00ol0VOooooooo`1Ooooo002?oooo00<0
000co`0co`007c?o00030000oooooooo00[oool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0c
o`007S?o00030000oooooooo00_oool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`007C?o
00030000oooooooo00coool00ol0VOooooooo`1Ooooo002?oooo0P0001dco`000`000?ooooooo`0=
oooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0>oooo00?o
09Woooooool0Goooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0>oooo00?o09Wooooo
ool0Goooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0?oooo00?o09Woooooool0Gooo
o`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0?oooo00?o09Woooooool0Goooo`00Sooo
o`030000<ol0<ol001Tco`000`000?ooooooo`0@oooo00?o09Woooooool0Goooo`00Soooo`80000J
<ol000<0003oooooool04?ooo`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000H<ol000<0
003oooooool04Oooo`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000H<ol000<0003ooooo
ool04Oooo`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000G<ol000<0003oooooool04_oo
o`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000G<ol000<0003oooooool04_ooo`03o`2I
oooooooo05ooool008Ooool500000oooo`030000<ol0<ol001Hco`000`000?ooooooo`0Coooo00?o
09Woooooool0Goooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000F<ol000<0003ooooo
ool04oooo`03o`2Ioooooooo05ooool008Woool00`000?ooooooo`03oooo0`0001Dco`000`000?oo
ooooo`0Doooo00?o09Woooooool0Goooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E
<ol000<0003oooooool05?ooo`03o`2Ioooooooo05ooool008Woool00`000?ooooooo`03oooo00<0
000co`0co`005C?o00030000oooooooo01Coool00ol0VOooooooo`1Ooooo0028oooo0P0000Goool0
0`0003?o03?o000D<ol000<0003oooooool05Oooo`03o`2Ioooooooo05ooool008ooool00`0003?o
03?o000D<ol000<0003oooooool05Oooo`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000C
<ol000<0003oooooool05_ooo`03o`2Ioooooooo05ooool008ooool2000053?o00030000oooooooo
01Koool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`004c?o00030000oooooooo01Koool0
0ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`004S?o00030000oooooooo01Ooool00ol0VOoo
ooooo`1Ooooo002?oooo00<0000co`0co`004S?o00030000oooooooo01Ooool00ol0VOooooooo`1O
oooo002?oooo00<0000co`0co`004S?o00030000oooooooo01Ooool00ol0VOooooooo`1Ooooo002?
oooo00<0000co`0co`004C?o00030000oooooooo01Soool00ol0VOooooooo`1Ooooo002?oooo0P00
018co`000`000?ooooooo`0Hoooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol0014co`00
0`000?ooooooo`0Hoooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol0014co`000`000?oo
ooooo`0Hoooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0I
oooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Ioooo00?o
09Woooooool0Goooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Ioooo00?o09Wooooo
ool0Goooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Ioooo00?o09Woooooool0Gooo
o`00Soooo`80000@<ol000<0003oooooool06_ooo`03o`2Ioooooooo05ooool008ooool00`0003?o
03?o000?<ol000<0003oooooool06_ooo`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000?
<ol000<0003oooooool06_ooo`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000?<ol000<0
003oooooool06_ooo`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000?<ol000<0003ooooo
ool06_ooo`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000><ol000<0003oooooool06ooo
o`03o`2Ioooooooo05ooool008ooool200003c?o00030000oooooooo01_oool00ol0VOooooooo`1O
oooo002?oooo00<0000co`0co`003S?o00030000oooooooo01_oool00ol0VOooooooo`1Ooooo002?
oooo00<0000co`0co`003S?o00030000oooooooo01_oool00ol0VOooooooo`1Ooooo002?oooo00<0
000co`0co`003C?o00030000oooooooo01coool00ol0VOooooooo`1Ooooo0027oooo100000Coool0
0`0003?o03?o000=<ol000<0003oooooool07?ooo`03o`2Ioooooooo05ooool008Ooool00`000?oo
ooooo`05oooo00<0000co`0co`003C?o00030000oooooooo01coool00ol0VOooooooo`1Ooooo0028
oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool07?ooo`03o`2Ioooooooo05ooool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo01coool00ol0VOoo
ooooo`1Ooooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0033?o00030000oooooooo
01goool00ol0VOooooooo`1Ooooo0028oooo0P0000Goool00`0003?o03?o000<<ol000<0003ooooo
ool07Oooo`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000<<ol000<0003oooooool07Ooo
o`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000<<ol000<0003oooooool07Oooo`03o`2I
oooooooo05ooool008ooool200003C?o00030000oooooooo01goool00ol0VOooooooo`1Ooooo002?
oooo00<0000co`0co`0033?o00030000oooooooo01goool00ol0VOooooooo`1Ooooo002?oooo00<0
000co`0co`002c?o00030000oooooooo01koool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0c
o`002c?o00030000oooooooo01koool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`002c?o
00030000oooooooo01koool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`002c?o00030000
oooooooo01koool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`002c?o00030000oooooooo
01koool00ol0VOooooooo`1Ooooo002?oooo0P0000`co`000`000?ooooooo`0Noooo00?o09Wooooo
ool0Goooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0Noooo00?o09Woooooool0Gooo
o`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Ooooo00?o09Woooooool0Goooo`00Sooo
o`030000<ol0<ol000Xco`000`000?ooooooo`0Ooooo00?o09Woooooool0Goooo`00Soooo`030000
<ol0<ol000Xco`000`000?ooooooo`0Ooooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0Ooooo00?o09Woooooool0Goooo`00Soooo`80000;<ol000<0003ooooo
ool07oooo`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000:<ol000<0003oooooool07ooo
o`03o`2Ioooooooo05ooool008ooool00`0003?o03?o000:<ol000<0003oooooool07oooo`03o`2I
oooooooo05ooool008ooool00`0003?o03?o0009<ol000<0003oooooool08?ooo`03o`2Ioooooooo
05ooool008ooool00`0003?o03?o0009<ol000<0003oooooool08?ooo`03o`2Ioooooooo05ooool0
08ooool00`0003?o03?o0009<ol000<0003oooooool08?ooo`03o`2Ioooooooo05ooool008ooool2
00002S?o00030000oooooooo023oool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`002C?o
00030000oooooooo023oool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`002C?o00030000
oooooooo023oool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`0023?o00030000oooooooo
027oool00ol0VOooooooo`1Ooooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0003ooooo
ool08Oooo`03o`2Ioooooooo05ooool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008
<ol000<0003oooooool08Oooo`03o`2Ioooooooo05ooool008Woool00`000?ooooooo`03oooo0`00
00Pco`000`000?ooooooo`0Qoooo00?o09Woooooool0Goooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o0008<ol000<0003oooooool08Oooo`03o`2Ioooooooo05ooool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool08Oooo`03o`2Ioooooooo05ooool0
08Soool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`0Roooo00?o09Woooooool0Gooo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Roooo00?o09Woooooool0Goooo`00Sooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0Roooo00?o09Woooooool0Goooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`0Roooo00?o09Woooooool0Goooo`00Soooo`800008<ol000<0
003oooooool08_ooo`03o`2Ioooooooo05ooool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool08_ooo`03o`2Ioooooooo05ooool008ooool00`0003?o03?o0007<ol000<0003oooooool08_oo
o`03o`2Ioooooooo05ooool008ooool00`0003?o03?o0007<ol000<0003oooooool08_ooo`03o`2I
oooooooo05ooool008ooool00`0003?o03?o0006<ol000<0003oooooool08oooo`03o`2Ioooooooo
05ooool008ooool00`0003?o03?o0006<ol000<0003oooooool08oooo`03o`2Ioooooooo05ooool0
08ooool200001c?o00030000oooooooo02?oool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo02?oool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`001S?o
00030000oooooooo02?oool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`001S?o00030000
oooooooo02?oool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`001S?o00030000oooooooo
02?oool00ol0VOooooooo`1Ooooo002?oooo00<0000co`0co`001S?o00030000oooooooo02?oool0
0ol0VOooooooo`1Ooooo002?oooo0P0000Hco`000`000?ooooooo`0Toooo00?o09Woooooool0Gooo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Toooo00?o09Woooooool0Goooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`0Toooo00?o09Woooooool0Goooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`0Toooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`0Toooo00?o09Woooooool0Goooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`0Toooo00?o09Woooooool0Goooo`00Soooo`800006<ol000<0003oooooool09?oo
o`03o`2Ioooooooo05ooool008ooool00`0003?o03?o0005<ol000<0003oooooool09?ooo`03o`2I
oooooooo05ooool008ooool00`0003?o03?o0005<ol000<0003oooooool09?ooo`03o`2Ioooooooo
05ooool008ooool00`0003?o03?o0004<ol000<0003oooooool09Oooo`03o`2Ioooooooo05ooool0
08ooool00`0003?o03?o0004<ol000<0003oooooool09Oooo`03o`2Ioooooooo05ooool008Woool3
00000oooo`030000<ol0<ol000@co`000`000?ooooooo`0Uoooo00?o09Woooooool0Goooo`00R_oo
o`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool09Oooo`03o`2Ioooooooo
05ooool008Ooool500000oooo`<00004<ol000<0003oooooool09Oooo`03o`2Ioooooooo05ooool0
08Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_oo
o`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0
003oooooool04oooo`Lco`0>oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool0
0`000?ooooooo`09oooo1c?o00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01_ooo`D00002<ol00P000003<ol0oooooooo00;oool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`07oooo00<0000co`0co`001C?o00Coool01@000?oo
ooooooooo`000002oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool0
0`000?ooooooo`0?oooo00<0000co`0co`001C?o00Coool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000
<ol0<ol000Dco`05oooo00@0003oooooooooool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000Aoooo00<0000co`0co`001C?o00;oool010000?ooooooo`0000;oool0
10000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007
<ol00_ooo`@00003oooo0P0000?oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7
<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65954 .12361 L
.67803 .12361 L
.68335 .12361 L
.68596 .12361 L
.68711 .12361 L
.68837 .12361 L
.6895 .12361 L
s
.6895 .12361 m
.68992 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.29779 .12361 L
.30316 .12361 L
.3056 .12361 L
.30791 .12361 L
.30919 .12361 L
.30992 .1232 L
.31059 .12251 L
.31304 .12004 L
.32392 .10996 L
.34309 .09538 L
.36361 .08358 L
.38221 .07568 L
.40146 .06978 L
.4123 .06732 L
.42228 .06553 L
.43202 .06417 L
.44111 .06321 L
.44623 .06279 L
.45108 .06247 L
.45667 .06218 L
.4593 .06207 L
.46177 .06199 L
.46416 .06193 L
.46636 .06188 L
.46879 .06184 L
.47007 .06183 L
.47078 .06182 L
.47142 .06181 L
.47265 .06181 L
.47396 .0618 L
.47517 .0618 L
.47632 .06181 L
.47697 .06181 L
.47766 .06181 L
.47889 .06182 L
.48022 .06184 L
.48168 .06186 L
.48408 .0619 L
.48627 .06195 L
.49119 .06208 L
.49576 .06225 L
Mistroke
.5001 .06244 L
.50135 .0625 L
.5027 .06254 L
.50397 .06257 L
.50514 .06259 L
.5062 .0626 L
.50737 .06261 L
.50858 .0626 L
.50971 .06259 L
.51035 .06258 L
.51104 .06257 L
.5123 .06254 L
.51465 .06247 L
.5174 .06234 L
.51994 .0622 L
.52887 .0615 L
.53834 .06046 L
.55785 .05762 L
.57615 .05436 L
.61489 .04646 L
.63457 .04228 L
.65608 .03783 L
.66603 .03586 L
.67664 .03386 L
.6818 .03293 L
.68433 .03249 L
.68666 .03208 L
.68879 .03172 L
.68985 .03155 L
.69103 .12361 L
.69221 .12361 L
.69347 .12361 L
.69575 .12361 L
.73708 .12361 L
.7769 .12361 L
.81519 .12361 L
.85594 .12361 L
.89518 .12361 L
.9329 .12361 L
.97307 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0[oooo0`1Vof3oool0
08ooool00`000?ooooooo`0Woooo101Vo`;oool00`1Vooooooooo`1Noooo002?oooo00<0003ooooo
ool08oooo`@0I_l6oooo00<0I_ooooooool0G_ooo`00Soooo`030000oooooooo01goool606Ko2_oo
o`0306Kooooooooo05koool008ooool00`000?ooooooo`0Hoooo1@1Voa3oool00`1Vooooooooo`1N
oooo002?oooo0P0001Coool506Ko5Oooo`0306Kooooooooo05koool008ooool00`000?ooooooo`0?
oooo101Voa[oool00`1Vooooooooo`1Noooo002?oooo00<0003oooooool01_ooo`T0I_lNoooo00<0
I_ooooooool0G_ooo`00OOoooa80I_l00`00001Vo`1Vo`0606Ko9oooo`0306Kooooooooo05koool0
07Soool506Ko4_ooo`030000oooooooo02goool00`1Vooooooooo`1Noooo001doooo101VoaOoool0
0`000?ooooooo`0]oooo00<0I_ooooooool0G_ooo`00L?ooo`@0I_lKoooo0P0002koool00`1Voooo
ooooo`1Noooo000Goooo100003Woool500005Oooo`80I_lOoooo00<0003oooooool0;Oooo`0306Ko
oooooooo00Ooool50000>?ooo`@0000Foooo000Goooo00<0003oooooool0??ooo`030000oooooooo
01?oool206Ko8Oooo`030000oooooooo02goool00`1Vooooooooo`09oooo00<0003oooooool0>?oo
o`030000oooooooo01Ooool001Soool00`000?ooooooo`0koooo00<0003oooooool04Oooo`80I_lS
oooo00<0003oooooool0;Oooo`0306Kooooooooo00Woool00`000?ooooooo`0ioooo00<0003ooooo
ool05_ooo`004Oooo`@00004oooo00<0003oooooool0<_ooo`@00004oooo00<0003oooooool03ooo
o`80I_lUoooo00<0003oooooool0;Oooo`0306Kooooooooo00Woool00`000?ooooooo`0joooo00<0
003oooooool05Oooo`005oooo`040000oooooooo0000>oooo`030000oooooooo00koool00`1Voooo
ooooo`0Uoooo00<0003oooooool0;Oooo`0306Kooooooooo00Woool00`000?ooooooo`0hoooo00@0
003oooooool0000Foooo000Hoooo0P0003_oool200003oooo`0306Kooooooooo02Koool20000;_oo
o`0306Kooooooooo00Soool20000>oooo`80000Goooo001Toooo0P1VobWoool00`000?ooooooo`0]
oooo00<0I_ooooooool0G_ooo`00Hoooo`0306Kooooooooo02Woool00`000?ooooooo`0]oooo00<0
I_ooooooool0G_ooo`00H_ooo`0306Kooooooooo02[oool00`000?ooooooo`0]oooo00<0I_oooooo
ool0G_ooo`00HOooo`0306Kooooooooo02_oool00`000?ooooooo`0]oooo00<0I_ooooooool0G_oo
o`00H?ooo`0306Kooooooooo02coool00`000?ooooooo`0]oooo00<0I_ooooooool0G_ooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0003oooooool02Oooo`030000
oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol0
02dco`000ol0VC?o03?o0009<ol02@0003Coool00`000?ooooooo`0Eoooo002?oooo00<0000co`0c
o`00;C?o0003o`2I<ol0<ol000<co`060000EOooo`00Soooo`030000<ol0<ol002dco`001?l0VC?o
03?o03?o0080001Koooo002?oooo00<0000co`0co`00;C?o0004o`2I<ol000000000GOooo`00Sooo
o`030000<ol0<ol002`co`000`000?l0V@00001Ooooo002?oooo0P0002Xco`03000000?ooooo09Wo
ool0Goooo`00Soooo`030000<ol0<ol002Lco`0200001?ooo`03o`2Ioooooooo05koool008ooool0
0`0003?o03?o000V<ol000<0003oooooool01?ooo`03o`2Ioooooooo05koool008ooool00`0003?o
03?o000U<ol000<0003oooooool01Oooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000T
<ol000<0003oooooool01_ooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000R<ol00P00
00Woool00ol0VOooooooo`1Noooo002?oooo0P00028co`000`000?ooooooo`09oooo00?o09Wooooo
ool0G_ooo`00Soooo`030000<ol0<ol0020co`000`000?ooooooo`0:oooo00?o09Woooooool0G_oo
o`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0;oooo00?o09Woooooool0G_ooo`00Sooo
o`030000<ol0<ol001lco`000`000?ooooooo`0;oooo00?o09Woooooool0G_ooo`00Soooo`030000
<ol0<ol001hco`000`000?ooooooo`0<oooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol0
01dco`000`000?ooooooo`0=oooo00?o09Woooooool0G_ooo`00Soooo`80000M<ol000<0003ooooo
ool03_ooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000K<ol000<0003oooooool03ooo
o`03o`2Ioooooooo05koool008ooool00`0003?o03?o000K<ol000<0003oooooool03oooo`03o`2I
oooooooo05koool008ooool00`0003?o03?o000J<ol000<0003oooooool04?ooo`03o`2Ioooooooo
05koool008ooool00`0003?o03?o000J<ol000<0003oooooool04?ooo`03o`2Ioooooooo05koool0
08ooool00`0003?o03?o000I<ol000<0003oooooool04Oooo`03o`2Ioooooooo05koool008ooool2
00006S?o00030000oooooooo017oool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`0063?o
00030000oooooooo01;oool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`0063?o00030000
oooooooo01;oool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`005c?o00030000oooooooo
01?oool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`005c?o00030000oooooooo01?oool0
0ol0VOooooooo`1Noooo0027oooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool05?oo
o`03o`2Ioooooooo05koool008Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000
oooooooo01Coool00ol0VOooooooo`1Noooo0029oooo00<0003oooooool00oooo`<0000E<ol000<0
003oooooool05Oooo`03o`2Ioooooooo05koool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`005C?o00030000oooooooo01Goool00ol0VOooooooo`1Noooo0029oooo00<0003oooooool00ooo
o`030000<ol0<ol001Dco`000`000?ooooooo`0Eoooo00?o09Woooooool0G_ooo`00R?ooo`800005
oooo00<0000co`0co`0053?o00030000oooooooo01Koool00ol0VOooooooo`1Noooo002?oooo00<0
000co`0co`0053?o00030000oooooooo01Koool00ol0VOooooooo`1Noooo002?oooo00<0000co`0c
o`004c?o00030000oooooooo01Ooool00ol0VOooooooo`1Noooo002?oooo0P0001@co`000`000?oo
ooooo`0Goooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`0G
oooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Hoooo00?o
09Woooooool0G_ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Hoooo00?o09Wooooo
ool0G_ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Hoooo00?o09Woooooool0G_oo
o`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Ioooo00?o09Woooooool0G_ooo`00Sooo
o`80000B<ol000<0003oooooool06Oooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000A
<ol000<0003oooooool06Oooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000A<ol000<0
003oooooool06Oooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000@<ol000<0003ooooo
ool06_ooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o000@<ol000<0003oooooool06_oo
o`03o`2Ioooooooo05koool008ooool00`0003?o03?o000@<ol000<0003oooooool06_ooo`03o`2I
oooooooo05koool008ooool00`0003?o03?o000@<ol000<0003oooooool06_ooo`03o`2Ioooooooo
05koool008ooool2000043?o00030000oooooooo01_oool00ol0VOooooooo`1Noooo002?oooo00<0
000co`0co`003c?o00030000oooooooo01_oool00ol0VOooooooo`1Noooo002?oooo00<0000co`0c
o`003c?o00030000oooooooo01_oool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`003c?o
00030000oooooooo01_oool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`003c?o00030000
oooooooo01_oool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`003S?o00030000oooooooo
01coool00ol0VOooooooo`1Noooo002?oooo0P0000lco`000`000?ooooooo`0Loooo00?o09Wooooo
ool0G_ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Loooo00?o09Woooooool0G_oo
o`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Loooo00?o09Woooooool0G_ooo`00Sooo
o`030000<ol0<ol000dco`000`000?ooooooo`0Moooo00?o09Woooooool0G_ooo`00Qoooo`@00004
oooo00<0000co`0co`003C?o00030000oooooooo01goool00ol0VOooooooo`1Noooo0027oooo00<0
003oooooool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`0Moooo00?o09Woooooool0G_oo
o`00R?ooo`030000oooooooo00Coool300003C?o00030000oooooooo01goool00ol0VOooooooo`1N
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`0Moooo00?o
09Woooooool0G_ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?oo
ooooo`0Noooo00?o09Woooooool0G_ooo`00R?ooo`800005oooo00<0000co`0co`0033?o00030000
oooooooo01koool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`0033?o00030000oooooooo
01koool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`0033?o00030000oooooooo01koool0
0ol0VOooooooo`1Noooo002?oooo0P0000dco`000`000?ooooooo`0Noooo00?o09Woooooool0G_oo
o`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0Noooo00?o09Woooooool0G_ooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`0Ooooo00?o09Woooooool0G_ooo`00Soooo`030000
<ol0<ol000/co`000`000?ooooooo`0Ooooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`0Ooooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`0Ooooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`0Ooooo00?o09Woooooool0G_ooo`00Soooo`80000<<ol000<0003oooooool07oooo`03o`2I
oooooooo05koool008ooool00`0003?o03?o000;<ol000<0003oooooool07oooo`03o`2Ioooooooo
05koool008ooool00`0003?o03?o000:<ol000<0003oooooool08?ooo`03o`2Ioooooooo05koool0
08ooool00`0003?o03?o000:<ol000<0003oooooool08?ooo`03o`2Ioooooooo05koool008ooool0
0`0003?o03?o000:<ol000<0003oooooool08?ooo`03o`2Ioooooooo05koool008ooool00`0003?o
03?o000:<ol000<0003oooooool08?ooo`03o`2Ioooooooo05koool008ooool200002c?o00030000
oooooooo023oool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`002S?o00030000oooooooo
023oool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`002S?o00030000oooooooo023oool0
0ol0VOooooooo`1Noooo002?oooo00<0000co`0co`002C?o00030000oooooooo027oool00ol0VOoo
ooooo`1Noooo002?oooo00<0000co`0co`002C?o00030000oooooooo027oool00ol0VOooooooo`1N
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo027oool00ol0VOooooooo`1Noooo002?
oooo0P0000Xco`000`000?ooooooo`0Qoooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol0
00Tco`000`000?ooooooo`0Qoooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol000Tco`00
0`000?ooooooo`0Qoooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0Roooo00?o09Woooooool0G_ooo`00R?ooo`800005oooo00<0000co`0co`0023?o00030000
oooooooo02;oool00ol0VOooooooo`1Noooo0027oooo00@0003oooooool00004oooo00<0000co`0c
o`0023?o00030000oooooooo02;oool00ol0VOooooooo`1Noooo0029oooo00<0003oooooool00ooo
o`<00008<ol000<0003oooooool08_ooo`03o`2Ioooooooo05koool008[oool00`000?ooooooo`02
oooo00<0000co`0co`0023?o00030000oooooooo02;oool00ol0VOooooooo`1Noooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo02;oool00ol0VOooooooo`1N
oooo0028oooo0P0000Goool00`0003?o03?o0007<ol000<0003oooooool08oooo`03o`2Ioooooooo
05koool008ooool00`0003?o03?o0007<ol000<0003oooooool08oooo`03o`2Ioooooooo05koool0
08ooool00`0003?o03?o0007<ol000<0003oooooool08oooo`03o`2Ioooooooo05koool008ooool0
0`0003?o03?o0007<ol000<0003oooooool08oooo`03o`2Ioooooooo05koool008ooool2000023?o
00030000oooooooo02?oool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`001c?o00030000
oooooooo02?oool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`001c?o00030000oooooooo
02?oool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`001c?o00030000oooooooo02?oool0
0ol0VOooooooo`1Noooo002?oooo00<0000co`0co`001S?o00030000oooooooo02Coool00ol0VOoo
ooooo`1Noooo002?oooo00<0000co`0co`001S?o00030000oooooooo02Coool00ol0VOooooooo`1N
oooo002?oooo0P0000Lco`000`000?ooooooo`0Toooo00?o09Woooooool0G_ooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`0Toooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol0
00Hco`000`000?ooooooo`0Toooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol000Hco`00
0`000?ooooooo`0Toooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`0Toooo00?o09Woooooool0G_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0T
oooo00?o09Woooooool0G_ooo`00Soooo`800006<ol000<0003oooooool09Oooo`03o`2Ioooooooo
05koool008ooool00`0003?o03?o0005<ol000<0003oooooool09Oooo`03o`2Ioooooooo05koool0
08ooool00`0003?o03?o0005<ol000<0003oooooool09Oooo`03o`2Ioooooooo05koool008ooool0
0`0003?o03?o0005<ol000<0003oooooool09Oooo`03o`2Ioooooooo05koool008ooool00`0003?o
03?o0005<ol000<0003oooooool09Oooo`03o`2Ioooooooo05koool008ooool00`0003?o03?o0005
<ol000<0003oooooool09Oooo`03o`2Ioooooooo05koool008ooool200001S?o00030000oooooooo
02Goool00ol0VOooooooo`1Noooo002?oooo00<0000co`0co`001C?o00030000oooooooo02Goool0
0ol0VOooooooo`1Noooo002?oooo00<0000co`0co`001C?o00030000oooooooo02Goool00ol0VOoo
ooooo`1Noooo002?oooo00<0000co`0co`0013?o00030000oooooooo02Koool00ol0VOooooooo`1N
oooo002?oooo00<0000co`0co`0013?o00030000oooooooo02Koool00ol0VOooooooo`1Noooo0029
oooo0`0000?oool00`0003?o03?o0004<ol000<0003oooooool09_ooo`03o`2Ioooooooo05koool0
08[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o00030000oooooooo02Koool00ol0VOoo
ooooo`1Noooo0027oooo1@0000?oool3000013?o00030000oooooooo02Koool00ol0VOooooooo`1N
oooo0027oooo00@0003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o
08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00O?oo
o`030000oooooooo013oool7<ol02oooo`030000oooooooo07coool007_oool00`000?ooooooo`08
oooo00<0003oooooool01_ooo`Lco`0<oooo00<0003oooooool0Noooo`00Noooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool500000S?o00800004oooo0P0000Coool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo0S?o00030000<ol0<ol0008co`05oooo00@0003oooooool00003oooo00<0003ooooo
ool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0=oooo0S?o00030000<ol0<ol0
008co`05oooo00@0003oooooool00004oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000<oooo0S?o00030000<ol0<ol0008co`06oooo0P0000Coool00`000?ooooooo`1koooo001k
oooo00D0003oooooooooool000003oooo`8co`000`0003?o03?o0002<ol01Oooo`040000oooooooo
00000oooo`030000oooooooo07_oool007coool00`000?ooooooo`0@oooo00<co`000000000013?o
00Koool200000oooo`030000oooooooo07coool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.82) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.64043 .12361 L
.65954 .12361 L
.67803 .12361 L
.68335 .12361 L
.68837 .12361 L
.69055 .12361 L
.69287 .12361 L
.69408 .12361 L
.69476 .12361 L
s
.69476 .12361 m
.69502 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.28158 .12361 L
.29205 .12361 L
.29779 .12361 L
.30059 .12361 L
.30182 .12361 L
.30316 .12361 L
.30442 .12361 L
.3056 .12275 L
.30791 .1204 L
.31304 .11545 L
.32392 .10597 L
.34309 .09232 L
.36361 .08133 L
.38221 .07402 L
.40146 .06863 L
.4123 .06641 L
.42228 .06482 L
.43202 .06363 L
.44111 .06282 L
.44632 .06247 L
.45108 .06222 L
.45371 .06211 L
.45657 .06201 L
.45907 .06193 L
.46177 .06188 L
.463 .06186 L
.4643 .06184 L
.46541 .06182 L
.46662 .06181 L
.46776 .06181 L
.46897 .0618 L
.47012 .0618 L
.47117 .06181 L
.47182 .06181 L
.4725 .06181 L
.47373 .06182 L
.47505 .06183 L
.4765 .06185 L
.47911 .06189 L
.48154 .06195 L
.48684 .0621 L
.49167 .06228 L
.49694 .06252 L
Mistroke
.49983 .06267 L
.50125 .06274 L
.50255 .0628 L
.50376 .06284 L
.50504 .06287 L
.50632 .06289 L
.50705 .0629 L
.50773 .0629 L
.50892 .06291 L
.51 .0629 L
.51124 .06289 L
.51242 .06287 L
.51353 .06284 L
.5147 .06281 L
.51681 .06273 L
.52157 .06248 L
.52667 .06211 L
.53144 .06169 L
.54231 .06045 L
.56253 .05742 L
.58105 .05407 L
.62073 .04595 L
.65889 .03798 L
.67854 .03417 L
.68419 .03315 L
.68953 .03221 L
.69186 .03181 L
.69313 .0316 L
.69432 .0314 L
.6956 .12361 L
.69628 .12361 L
.69702 .12361 L
.6995 .12361 L
.74083 .12361 L
.78064 .12361 L
.81894 .12361 L
.85969 .12361 L
.89892 .12361 L
.93664 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.82) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0/oooo0`1Voeooool0
08ooool00`000?ooooooo`0Xoooo101Vo`;oool00`1Vooooooooo`1Moooo002?oooo00<0003ooooo
ool08oooo`D0I_l6oooo00<0I_ooooooool0GOooo`00Soooo`030000oooooooo01ooool406Ko2ooo
o`0306Kooooooooo05goool008ooool00`000?ooooooo`0Joooo1@1Vo`ooool00`1Vooooooooo`1M
oooo002?oooo0P0001Koool506Ko5?ooo`0306Kooooooooo05goool008ooool00`000?ooooooo`0@
oooo1@1VoaWoool00`1Vooooooooo`1Moooo002?oooo00<0003oooooool01oooo`T0I_lNoooo00<0
I_ooooooool0GOooo`00Nooooa@0I_l00`00001Vo`1Vo`0706Ko9oooo`0306Kooooooooo05goool0
07Goool606Ko5?ooo`030000oooooooo02koool00`1Vooooooooo`1Moooo001coooo0P1Voa[oool0
0`000?ooooooo`0^oooo00<0I_ooooooool0GOooo`00L?ooo`<0I_lLoooo0P0002ooool00`1Voooo
ooooo`1Moooo000Goooo100003Woool500005Oooo`80I_lOoooo00<0003oooooool0;oooo`0306Ko
oooooooo00Goool50000>?ooo`@0000Foooo000Goooo00<0003oooooool0??ooo`030000oooooooo
01;oool306Ko8Oooo`030000oooooooo02ooool00`1Vooooooooo`07oooo00<0003oooooool0>?oo
o`030000oooooooo01Ooool001Soool00`000?ooooooo`0koooo00<0003oooooool04?ooo`80I_lT
oooo00<0003oooooool0;oooo`0306Kooooooooo00Ooool00`000?ooooooo`0ioooo00<0003ooooo
ool05_ooo`004Oooo`@00004oooo00<0003oooooool0<_ooo`@00004oooo00<0003oooooool03_oo
o`80I_lVoooo00<0003oooooool0;oooo`0306Kooooooooo00Ooool00`000?ooooooo`0joooo00<0
003oooooool05Oooo`005oooo`040000oooooooo0000>oooo`030000oooooooo00goool00`1Voooo
ooooo`0Voooo00<0003oooooool0;oooo`0306Kooooooooo00Ooool00`000?ooooooo`0hoooo00@0
003oooooool0000Foooo000Hoooo0P0003_oool200003Oooo`80I_lYoooo0P00033oool00`1Voooo
ooooo`06oooo0P0003_oool200005oooo`00Hoooo`0306Kooooooooo02Woool00`000?ooooooo`0_
oooo00<0I_ooooooool0G?ooo`00H_ooo`0306Kooooooooo02[oool00`000?ooooooo`0_oooo00<0
I_ooooooool0G?ooo`00HOooo`0306Kooooooooo02_oool00`000?ooooooo`0_oooo00<0I_oooooo
ool0G?ooo`00H?ooo`0306Kooooooooo02coool00`000?ooooooo`0_oooo00<0I_ooooooool0G?oo
o`00Goooo`0306Kooooooooo02goool00`000?ooooooo`0_oooo00<0I_ooooooool0G?ooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`000?l0VC?o0009<ol000<0000co`0co`001S?o02800006oooo00<0003oooooool02Oooo`030000
oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol0
02hco`000ol0VC?o03?o0008<ol02@0003Coool00`000?ooooooo`0Eoooo002?oooo00<0000co`0c
o`00;S?o0003o`2I<ol0<ol0008co`060000EOooo`00Soooo`030000<ol0<ol002hco`000ol0VC?o
03?o00020000Foooo`00Soooo`030000<ol0<ol002hco`000ol0V@000000001Moooo002?oooo00<0
000co`0co`00;3?o008000000ol0VOooooooo`1Moooo002?oooo0P0002Xco`0300000_ooo`03o`2I
oooooooo05goool008ooool00`0003?o03?o000W<ol00P0000Goool00ol0VOooooooo`1Moooo002?
oooo00<0000co`0co`009S?o00030000oooooooo00Goool00ol0VOooooooo`1Moooo002?oooo00<0
000co`0co`009C?o00030000oooooooo00Koool00ol0VOooooooo`1Moooo002?oooo00<0000co`0c
o`0093?o00030000oooooooo00Ooool00ol0VOooooooo`1Moooo002?oooo00<0000co`0co`008S?o
0080000:oooo00?o09Woooooool0GOooo`00Soooo`80000R<ol000<0003oooooool02_ooo`03o`2I
oooooooo05goool008ooool00`0003?o03?o000P<ol000<0003oooooool02oooo`03o`2Ioooooooo
05goool008ooool00`0003?o03?o000O<ol000<0003oooooool03?ooo`03o`2Ioooooooo05goool0
08ooool00`0003?o03?o000O<ol000<0003oooooool03?ooo`03o`2Ioooooooo05goool008ooool0
0`0003?o03?o000N<ol000<0003oooooool03Oooo`03o`2Ioooooooo05goool008ooool00`0003?o
03?o000M<ol000<0003oooooool03_ooo`03o`2Ioooooooo05goool008ooool200007C?o00030000
oooooooo00ooool00ol0VOooooooo`1Moooo002?oooo00<0000co`0co`006c?o00030000oooooooo
013oool00ol0VOooooooo`1Moooo002?oooo00<0000co`0co`006c?o00030000oooooooo013oool0
0ol0VOooooooo`1Moooo002?oooo00<0000co`0co`006S?o00030000oooooooo017oool00ol0VOoo
ooooo`1Moooo002?oooo00<0000co`0co`006S?o00030000oooooooo017oool00ol0VOooooooo`1M
oooo002?oooo00<0000co`0co`006C?o00030000oooooooo01;oool00ol0VOooooooo`1Moooo002?
oooo0P0001Xco`000`000?ooooooo`0Boooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol0
01Pco`000`000?ooooooo`0Coooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol001Pco`00
0`000?ooooooo`0Coooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol001Lco`000`000?oo
ooooo`0Doooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0D
oooo00?o09Woooooool0GOooo`00Qoooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo
01Goool00ol0VOooooooo`1Moooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`00
0`000?ooooooo`0Eoooo00?o09Woooooool0GOooo`00ROooo`030000oooooooo00?oool300005C?o
00030000oooooooo01Koool00ol0VOooooooo`1Moooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol001Dco`000`000?ooooooo`0Foooo00?o09Woooooool0GOooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000E<ol000<0003oooooool05_ooo`03o`2Ioooooooo05goool008Soool2
00001Oooo`030000<ol0<ol001@co`000`000?ooooooo`0Goooo00?o09Woooooool0GOooo`00Sooo
o`030000<ol0<ol001@co`000`000?ooooooo`0Goooo00?o09Woooooool0GOooo`00Soooo`030000
<ol0<ol001<co`000`000?ooooooo`0Hoooo00?o09Woooooool0GOooo`00Soooo`80000D<ol000<0
003oooooool06?ooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o000C<ol000<0003ooooo
ool06?ooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o000B<ol000<0003oooooool06Ooo
o`03o`2Ioooooooo05goool008ooool00`0003?o03?o000B<ol000<0003oooooool06Oooo`03o`2I
oooooooo05goool008ooool00`0003?o03?o000B<ol000<0003oooooool06Oooo`03o`2Ioooooooo
05goool008ooool00`0003?o03?o000A<ol000<0003oooooool06_ooo`03o`2Ioooooooo05goool0
08ooool200004S?o00030000oooooooo01[oool00ol0VOooooooo`1Moooo002?oooo00<0000co`0c
o`004C?o00030000oooooooo01[oool00ol0VOooooooo`1Moooo002?oooo00<0000co`0co`004C?o
00030000oooooooo01[oool00ol0VOooooooo`1Moooo002?oooo00<0000co`0co`0043?o00030000
oooooooo01_oool00ol0VOooooooo`1Moooo002?oooo00<0000co`0co`0043?o00030000oooooooo
01_oool00ol0VOooooooo`1Moooo002?oooo00<0000co`0co`0043?o00030000oooooooo01_oool0
0ol0VOooooooo`1Moooo002?oooo00<0000co`0co`0043?o00030000oooooooo01_oool00ol0VOoo
ooooo`1Moooo002?oooo0P00010co`000`000?ooooooo`0Loooo00?o09Woooooool0GOooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`0Loooo00?o09Woooooool0GOooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`0Loooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol0
00lco`000`000?ooooooo`0Loooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol000lco`00
0`000?ooooooo`0Loooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol000hco`000`000?oo
ooooo`0Moooo00?o09Woooooool0GOooo`00Soooo`80000?<ol000<0003oooooool07Oooo`03o`2I
oooooooo05goool008ooool00`0003?o03?o000><ol000<0003oooooool07Oooo`03o`2Ioooooooo
05goool008ooool00`0003?o03?o000><ol000<0003oooooool07Oooo`03o`2Ioooooooo05goool0
08ooool00`0003?o03?o000=<ol000<0003oooooool07_ooo`03o`2Ioooooooo05goool008Ooool4
00001?ooo`030000<ol0<ol000dco`000`000?ooooooo`0Noooo00?o09Woooooool0GOooo`00Qooo
o`030000oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool07_ooo`03o`2Ioooooooo
05goool008Soool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`0Noooo00?o09Wooooo
ool0GOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool07_oo
o`03o`2Ioooooooo05goool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0
003oooooool07oooo`03o`2Ioooooooo05goool008Soool200001Oooo`030000<ol0<ol000`co`00
0`000?ooooooo`0Ooooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol000`co`000`000?oo
ooooo`0Ooooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0O
oooo00?o09Woooooool0GOooo`00Soooo`80000=<ol000<0003oooooool07oooo`03o`2Ioooooooo
05goool008ooool00`0003?o03?o000<<ol000<0003oooooool07oooo`03o`2Ioooooooo05goool0
08ooool00`0003?o03?o000;<ol000<0003oooooool08?ooo`03o`2Ioooooooo05goool008ooool0
0`0003?o03?o000;<ol000<0003oooooool08?ooo`03o`2Ioooooooo05goool008ooool00`0003?o
03?o000;<ol000<0003oooooool08?ooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o000;
<ol000<0003oooooool08?ooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o000;<ol000<0
003oooooool08?ooo`03o`2Ioooooooo05goool008ooool2000033?o00030000oooooooo023oool0
0ol0VOooooooo`1Moooo002?oooo00<0000co`0co`002c?o00030000oooooooo023oool00ol0VOoo
ooooo`1Moooo002?oooo00<0000co`0co`002S?o00030000oooooooo027oool00ol0VOooooooo`1M
oooo002?oooo00<0000co`0co`002S?o00030000oooooooo027oool00ol0VOooooooo`1Moooo002?
oooo00<0000co`0co`002S?o00030000oooooooo027oool00ol0VOooooooo`1Moooo002?oooo00<0
000co`0co`002S?o00030000oooooooo027oool00ol0VOooooooo`1Moooo002?oooo0P0000/co`00
0`000?ooooooo`0Qoooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0Qoooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Q
oooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0Roooo00?o
09Woooooool0GOooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0Roooo00?o09Wooooo
ool0GOooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0Roooo00?o09Woooooool0GOoo
o`00Soooo`80000:<ol000<0003oooooool08_ooo`03o`2Ioooooooo05goool008ooool00`0003?o
03?o0009<ol000<0003oooooool08_ooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o0009
<ol000<0003oooooool08_ooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o0008<ol000<0
003oooooool08oooo`03o`2Ioooooooo05goool008Soool200001Oooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0Soooo00?o09Woooooool0GOooo`00Qoooo`040000oooooooo00001?ooo`030000
<ol0<ol000Pco`000`000?ooooooo`0Soooo00?o09Woooooool0GOooo`00ROooo`030000oooooooo
00?oool3000023?o00030000oooooooo02?oool00ol0VOooooooo`1Moooo002:oooo00<0003ooooo
ool00_ooo`030000<ol0<ol000Pco`000`000?ooooooo`0Soooo00?o09Woooooool0GOooo`00Qooo
o`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0Soooo00?o09Wooooo
ool0GOooo`00R?ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo02Coool00ol0VOoo
ooooo`1Moooo002?oooo00<0000co`0co`001c?o00030000oooooooo02Coool00ol0VOooooooo`1M
oooo002?oooo00<0000co`0co`001c?o00030000oooooooo02Coool00ol0VOooooooo`1Moooo002?
oooo00<0000co`0co`001c?o00030000oooooooo02Coool00ol0VOooooooo`1Moooo002?oooo0P00
00Pco`000`000?ooooooo`0Toooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0Toooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0Toooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0T
oooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0Uoooo00?o
09Woooooool0GOooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0Uoooo00?o09Wooooo
ool0GOooo`00Soooo`800007<ol000<0003oooooool09Oooo`03o`2Ioooooooo05goool008ooool0
0`0003?o03?o0006<ol000<0003oooooool09Oooo`03o`2Ioooooooo05goool008ooool00`0003?o
03?o0006<ol000<0003oooooool09Oooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o0006
<ol000<0003oooooool09Oooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o0006<ol000<0
003oooooool09Oooo`03o`2Ioooooooo05goool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool09Oooo`03o`2Ioooooooo05goool008ooool200001S?o00030000oooooooo02Koool00ol0VOoo
ooooo`1Moooo002?oooo00<0000co`0co`001C?o00030000oooooooo02Koool00ol0VOooooooo`1M
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo02Koool00ol0VOooooooo`1Moooo002?
oooo00<0000co`0co`001C?o00030000oooooooo02Koool00ol0VOooooooo`1Moooo002?oooo00<0
000co`0co`001C?o00030000oooooooo02Koool00ol0VOooooooo`1Moooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo02Koool00ol0VOooooooo`1Moooo002?oooo0P0000Hco`000`000?oo
ooooo`0Voooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0V
oooo00?o09Woooooool0GOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Voooo00?o
09Woooooool0GOooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0Woooo00?o09Wooooo
ool0GOooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0Woooo00?o09Woooooool0GOoo
o`00ROooo`<00003oooo00<0000co`0co`0013?o00030000oooooooo02Ooool00ol0VOooooooo`1M
oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`0Woooo00?o
09Woooooool0GOooo`00Qoooo`D00003oooo0`0000@co`000`000?ooooooo`0Woooo00?o09Wooooo
ool0GOooo`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?oo
o`Lco`2:oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool0
07Woool00`000?ooooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@00008co`02000000@co`3oooooooooool2
00000oooo`@00003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01oooo`030000<ol0<ol000Dco`02oooo00@0003ooooo
ool00002oooo00<0003oooooool01?ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool03oooo`030000<ol0<ol000Dco`02oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000
<ol0<ol000Dco`03oooo0P0000Goool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo0000017oool00`0003?o03?o0005<ol00_ooo`040000oooooooo00000_oo
o`040000oooooooo00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P00
00Lco`03oooo0P0000Coool200000oooo`030000oooooooo07Woool008ooool7<ol0R_ooo`00Sooo
o`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.84) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.67958 .12361 L
.6883 .12361 L
.69289 .12361 L
.6954 .12361 L
.69774 .12361 L
.69895 .12361 L
s
.69895 .12361 m
.69947 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.28302 .12361 L
.2881 .12361 L
.29349 .12361 L
.2957 .12361 L
.29809 .12361 L
.29879 .12361 L
.29945 .12361 L
.3007 .12288 L
.30188 .12168 L
.30316 .1204 L
.32447 .10182 L
.3438 .08905 L
.36395 .07909 L
.38293 .07228 L
.39269 .06959 L
.40301 .06728 L
.41267 .06554 L
.42148 .06429 L
.43096 .06327 L
.43618 .06283 L
.44112 .06249 L
.44538 .06226 L
.4499 .06207 L
.45226 .06199 L
.45486 .06192 L
.45723 .06187 L
.45945 .06184 L
.46063 .06182 L
.46189 .06181 L
.46307 .06181 L
.46415 .0618 L
.46542 .0618 L
.46613 .0618 L
.46679 .06181 L
.468 .06181 L
.46928 .06182 L
.47051 .06184 L
.47183 .06185 L
.47421 .06189 L
.47705 .06195 L
.47964 .06202 L
.48913 .06238 L
Mistroke
.49814 .06284 L
.50052 .06299 L
.50177 .06305 L
.50309 .06311 L
.50425 .06315 L
.50552 .06319 L
.50668 .06321 L
.50775 .06323 L
.50845 .06324 L
.50911 .06324 L
.51035 .06324 L
.51104 .06324 L
.51168 .06323 L
.51238 .06322 L
.51312 .06321 L
.51432 .06318 L
.51544 .06315 L
.51799 .06306 L
.52024 .06296 L
.52261 .06283 L
.52685 .06254 L
.53639 .06165 L
.54596 .0605 L
.55617 .05904 L
.57455 .05594 L
.6161 .04768 L
.65613 .03929 L
.67448 .03564 L
.68491 .03368 L
.69 .03277 L
.69465 .03196 L
.69701 .03156 L
.69826 .03136 L
.69894 .03124 L
.69958 .03114 L
.70073 .12361 L
.70201 .12361 L
.70426 .12361 L
.71456 .12361 L
.73562 .12361 L
.77427 .12361 L
.81538 .12361 L
.85497 .12361 L
.89305 .12361 L
.93358 .12361 L
.97259 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.84) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0]oooo101Voegoool0
08ooool00`000?ooooooo`0Xoooo1@1Vo`?oool00`1Vooooooooo`1Koooo002?oooo00<0003ooooo
ool08oooo`D0I_l8oooo00<0I_ooooooool0Foooo`00Soooo`030000oooooooo01goool606Ko3Ooo
o`0306Kooooooooo05_oool008ooool00`000?ooooooo`0Hoooo1@1Voa?oool00`1Vooooooooo`1K
oooo002?oooo0P0001Coool506Ko6?ooo`0306Kooooooooo05_oool008ooool00`000?ooooooo`0>
oooo1@1Voagoool00`1Vooooooooo`1Koooo002?oooo00<0003oooooool02?ooo`H0I_lRoooo00<0
I_ooooooool0Foooo`00Nooooa@0I_l00`00001Vo`1Vo`0806Ko:?ooo`0306Kooooooooo05_oool0
07Koool506Ko5?ooo`030000oooooooo033oool00`1Vooooooooo`1Koooo001`oooo1P1VoaWoool0
0`000?ooooooo`0`oooo00<0I_ooooooool0Foooo`00K_ooo`80I_lOoooo0P00037oool00`1Voooo
ooooo`1Koooo000Goooo100003Woool500004oooo`80I_lQoooo00<0003oooooool0<?ooo`0306Ko
oooooooo00Coool50000>?ooo`@0000Foooo000Goooo00<0003oooooool0??ooo`030000oooooooo
017oool206Ko8oooo`030000oooooooo033oool00`1Vooooooooo`06oooo00<0003oooooool0>?oo
o`030000oooooooo01Ooool001Soool00`000?ooooooo`0koooo00<0003oooooool03oooo`80I_lU
oooo00<0003oooooool0<?ooo`0306Kooooooooo00Koool00`000?ooooooo`0ioooo00<0003ooooo
ool05_ooo`004Oooo`@00004oooo00<0003oooooool0<_ooo`@00004oooo00<0003oooooool03_oo
o`0306Kooooooooo02Goool00`000?ooooooo`0`oooo00<0I_ooooooool01_ooo`030000oooooooo
03[oool00`000?ooooooo`0Eoooo000Goooo00@0003oooooool0000koooo00<0003oooooool03?oo
o`80I_lXoooo00<0003oooooool0<?ooo`0306Kooooooooo00Koool00`000?ooooooo`0hoooo00@0
003oooooool0000Foooo000Hoooo0P0003_oool200003?ooo`80I_lZoooo0P00037oool00`1Voooo
ooooo`05oooo0P0003_oool200005oooo`00H_ooo`0306Kooooooooo02[oool00`000?ooooooo`0`
oooo00<0I_ooooooool0Foooo`00HOooo`0306Kooooooooo02_oool00`000?ooooooo`0`oooo00<0
I_ooooooool0Foooo`00H?ooo`0306Kooooooooo02coool00`000?ooooooo`0`oooo00<0I_oooooo
ool0Foooo`00Goooo`0306Kooooooooo02goool00`000?ooooooo`0`oooo00<0I_ooooooool0Fooo
o`00G_ooo`0306Kooooooooo02koool00`000?ooooooo`0`oooo00<0I_ooooooool0Foooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o0?l0V@09<ol000<0000co`0co`001S?o02800006oooo00<0003oooooool02Oooo`030000
oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol0
02lco`000ol0VC?o03?o0007<ol02@0003Coool00`000?ooooooo`0Eoooo002?oooo00<0000co`0c
o`00;c?o0004o`2I<ol0<ol0<ol01P0005Goool008ooool00`0003?o03?o000_<ol000Co09Tco`00
0000001Koooo002?oooo00<0000co`0co`00;c?o0003o`2I0000oooo05coool008ooool00`0003?o
03?o000/<ol00`000003o`2Ioooooooo05coool008ooool20000:S?o00<00003oooo00?o09Wooooo
ool0G?ooo`00Soooo`030000<ol0<ol002Lco`0200001_ooo`03o`2Ioooooooo05coool008ooool0
0`0003?o03?o000V<ol000<0003oooooool01_ooo`03o`2Ioooooooo05coool008ooool00`0003?o
03?o000U<ol000<0003oooooool01oooo`03o`2Ioooooooo05coool008ooool00`0003?o03?o000T
<ol000<0003oooooool02?ooo`03o`2Ioooooooo05coool008ooool00`0003?o03?o000R<ol00P00
00_oool00ol0VOooooooo`1Loooo002?oooo0P00028co`000`000?ooooooo`0;oooo00?o09Wooooo
ool0G?ooo`00Soooo`030000<ol0<ol0020co`000`000?ooooooo`0<oooo00?o09Woooooool0G?oo
o`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0=oooo00?o09Woooooool0G?ooo`00Sooo
o`030000<ol0<ol001lco`000`000?ooooooo`0=oooo00?o09Woooooool0G?ooo`00Soooo`030000
<ol0<ol001hco`000`000?ooooooo`0>oooo00?o09Woooooool0G?ooo`00Soooo`030000<ol0<ol0
01dco`000`000?ooooooo`0?oooo00?o09Woooooool0G?ooo`00Soooo`80000M<ol000<0003ooooo
ool04?ooo`03o`2Ioooooooo05coool008ooool00`0003?o03?o000K<ol000<0003oooooool04Ooo
o`03o`2Ioooooooo05coool008ooool00`0003?o03?o000K<ol000<0003oooooool04Oooo`03o`2I
oooooooo05coool008ooool00`0003?o03?o000J<ol000<0003oooooool04_ooo`03o`2Ioooooooo
05coool008ooool00`0003?o03?o000J<ol000<0003oooooool04_ooo`03o`2Ioooooooo05coool0
08ooool00`0003?o03?o000I<ol000<0003oooooool04oooo`03o`2Ioooooooo05coool008ooool2
00006S?o00030000oooooooo01?oool00ol0VOooooooo`1Loooo002?oooo00<0000co`0co`0063?o
00030000oooooooo01Coool00ol0VOooooooo`1Loooo002?oooo00<0000co`0co`0063?o00030000
oooooooo01Coool00ol0VOooooooo`1Loooo002?oooo00<0000co`0co`005c?o00030000oooooooo
01Goool00ol0VOooooooo`1Loooo002?oooo00<0000co`0co`005c?o00030000oooooooo01Goool0
0ol0VOooooooo`1Loooo0027oooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool05_oo
o`03o`2Ioooooooo05coool008Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000
oooooooo01Koool00ol0VOooooooo`1Loooo0029oooo00<0003oooooool00oooo`<0000E<ol000<0
003oooooool05oooo`03o`2Ioooooooo05coool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`005C?o00030000oooooooo01Ooool00ol0VOooooooo`1Loooo0029oooo00<0003oooooool00ooo
o`030000<ol0<ol001Dco`000`000?ooooooo`0Goooo00?o09Woooooool0G?ooo`00R?ooo`800005
oooo00<0000co`0co`0053?o00030000oooooooo01Soool00ol0VOooooooo`1Loooo002?oooo00<0
000co`0co`0053?o00030000oooooooo01Soool00ol0VOooooooo`1Loooo002?oooo00<0000co`0c
o`004c?o00030000oooooooo01Woool00ol0VOooooooo`1Loooo002?oooo0P0001@co`000`000?oo
ooooo`0Ioooo00?o09Woooooool0G?ooo`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`0I
oooo00?o09Woooooool0G?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Joooo00?o
09Woooooool0G?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Joooo00?o09Wooooo
ool0G?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Joooo00?o09Woooooool0G?oo
o`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Koooo00?o09Woooooool0G?ooo`00Sooo
o`80000B<ol000<0003oooooool06oooo`03o`2Ioooooooo05coool008ooool00`0003?o03?o000A
<ol000<0003oooooool06oooo`03o`2Ioooooooo05coool008ooool00`0003?o03?o000A<ol000<0
003oooooool06oooo`03o`2Ioooooooo05coool008ooool00`0003?o03?o000@<ol000<0003ooooo
ool07?ooo`03o`2Ioooooooo05coool008ooool00`0003?o03?o000@<ol000<0003oooooool07?oo
o`03o`2Ioooooooo05coool008ooool00`0003?o03?o000@<ol000<0003oooooool07?ooo`03o`2I
oooooooo05coool008ooool00`0003?o03?o000@<ol000<0003oooooool07?ooo`03o`2Ioooooooo
05coool008ooool2000043?o00030000oooooooo01goool00ol0VOooooooo`1Loooo002?oooo00<0
000co`0co`003c?o00030000oooooooo01goool00ol0VOooooooo`1Loooo002?oooo00<0000co`0c
o`003c?o00030000oooooooo01goool00ol0VOooooooo`1Loooo002?oooo00<0000co`0co`003c?o
00030000oooooooo01goool00ol0VOooooooo`1Loooo002?oooo00<0000co`0co`003c?o00030000
oooooooo01goool00ol0VOooooooo`1Loooo002?oooo00<0000co`0co`003S?o00030000oooooooo
01koool00ol0VOooooooo`1Loooo002?oooo0P0000lco`000`000?ooooooo`0Noooo00?o09Wooooo
ool0G?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Noooo00?o09Woooooool0G?oo
o`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Noooo00?o09Woooooool0G?ooo`00Sooo
o`030000<ol0<ol000dco`000`000?ooooooo`0Ooooo00?o09Woooooool0G?ooo`00Qoooo`@00004
oooo00<0000co`0co`003C?o00030000oooooooo01ooool00ol0VOooooooo`1Loooo0027oooo00<0
003oooooool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`0Ooooo00?o09Woooooool0G?oo
o`00R?ooo`030000oooooooo00Coool300003C?o00030000oooooooo01ooool00ol0VOooooooo`1L
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`0Poooo00?o
09Woooooool0Foooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?oo
ooooo`0Qoooo00?o09Woooooool0Foooo`00R?ooo`800005oooo00<0000co`0co`0033?o00030000
oooooooo027oool00ol0VOooooooo`1Koooo002?oooo00<0000co`0co`0033?o00030000oooooooo
027oool00ol0VOooooooo`1Koooo002?oooo00<0000co`0co`0033?o00030000oooooooo027oool0
0ol0VOooooooo`1Koooo002?oooo0P0000dco`000`000?ooooooo`0Qoooo00?o09Woooooool0Fooo
o`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0Qoooo00?o09Woooooool0Foooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`0Roooo00?o09Woooooool0Foooo`00Soooo`030000
<ol0<ol000/co`000`000?ooooooo`0Roooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`0Roooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`0Roooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`0Roooo00?o09Woooooool0Foooo`00Soooo`80000<<ol000<0003oooooool08_ooo`03o`2I
oooooooo05_oool008ooool00`0003?o03?o000;<ol000<0003oooooool08_ooo`03o`2Ioooooooo
05_oool008ooool00`0003?o03?o000:<ol000<0003oooooool08oooo`03o`2Ioooooooo05_oool0
08ooool00`0003?o03?o000:<ol000<0003oooooool08oooo`03o`2Ioooooooo05_oool008ooool0
0`0003?o03?o000:<ol000<0003oooooool08oooo`03o`2Ioooooooo05_oool008ooool00`0003?o
03?o000:<ol000<0003oooooool08oooo`03o`2Ioooooooo05_oool008ooool200002c?o00030000
oooooooo02?oool00ol0VOooooooo`1Koooo002?oooo00<0000co`0co`002S?o00030000oooooooo
02?oool00ol0VOooooooo`1Koooo002?oooo00<0000co`0co`002S?o00030000oooooooo02?oool0
0ol0VOooooooo`1Koooo002?oooo00<0000co`0co`002C?o00030000oooooooo02Coool00ol0VOoo
ooooo`1Koooo002?oooo00<0000co`0co`002C?o00030000oooooooo02Coool00ol0VOooooooo`1K
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo02Coool00ol0VOooooooo`1Koooo002?
oooo0P0000Xco`000`000?ooooooo`0Toooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol0
00Tco`000`000?ooooooo`0Toooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol000Tco`00
0`000?ooooooo`0Toooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0Uoooo00?o09Woooooool0Foooo`00R?ooo`800005oooo00<0000co`0co`0023?o00030000
oooooooo02Goool00ol0VOooooooo`1Koooo0027oooo00@0003oooooool00004oooo00<0000co`0c
o`0023?o00030000oooooooo02Goool00ol0VOooooooo`1Koooo0029oooo00<0003oooooool00ooo
o`<00008<ol000<0003oooooool09Oooo`03o`2Ioooooooo05_oool008[oool00`000?ooooooo`02
oooo00<0000co`0co`0023?o00030000oooooooo02Goool00ol0VOooooooo`1Koooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo02Goool00ol0VOooooooo`1K
oooo0028oooo0P0000Goool00`0003?o03?o0007<ol000<0003oooooool09_ooo`03o`2Ioooooooo
05_oool008ooool00`0003?o03?o0007<ol000<0003oooooool09_ooo`03o`2Ioooooooo05_oool0
08ooool00`0003?o03?o0007<ol000<0003oooooool09_ooo`03o`2Ioooooooo05_oool008ooool0
0`0003?o03?o0007<ol000<0003oooooool09_ooo`03o`2Ioooooooo05_oool008ooool2000023?o
00030000oooooooo02Koool00ol0VOooooooo`1Koooo002?oooo00<0000co`0co`001c?o00030000
oooooooo02Koool00ol0VOooooooo`1Koooo002?oooo00<0000co`0co`001c?o00030000oooooooo
02Koool00ol0VOooooooo`1Koooo002?oooo00<0000co`0co`001c?o00030000oooooooo02Koool0
0ol0VOooooooo`1Koooo002?oooo00<0000co`0co`001S?o00030000oooooooo02Ooool00ol0VOoo
ooooo`1Koooo002?oooo00<0000co`0co`001S?o00030000oooooooo02Ooool00ol0VOooooooo`1K
oooo002?oooo0P0000Lco`000`000?ooooooo`0Woooo00?o09Woooooool0Foooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`0Woooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol0
00Hco`000`000?ooooooo`0Woooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol000Hco`00
0`000?ooooooo`0Woooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`0Woooo00?o09Woooooool0Foooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0W
oooo00?o09Woooooool0Foooo`00Soooo`800006<ol000<0003oooooool0:?ooo`03o`2Ioooooooo
05_oool008ooool00`0003?o03?o0005<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05_oool0
08ooool00`0003?o03?o0005<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05_oool008ooool0
0`0003?o03?o0005<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05_oool008ooool00`0003?o
03?o0005<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05_oool008ooool00`0003?o03?o0005
<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05_oool008ooool200001S?o00030000oooooooo
02Soool00ol0VOooooooo`1Koooo002?oooo00<0000co`0co`001C?o00030000oooooooo02Soool0
0ol0VOooooooo`1Koooo002?oooo00<0000co`0co`001C?o00030000oooooooo02Soool00ol0VOoo
ooooo`1Koooo002?oooo00<0000co`0co`0013?o00030000oooooooo02Woool00ol0VOooooooo`1K
oooo002?oooo00<0000co`0co`0013?o00030000oooooooo02Woool00ol0VOooooooo`1Koooo0029
oooo0`0000?oool00`0003?o03?o0004<ol000<0003oooooool0:Oooo`03o`2Ioooooooo05_oool0
08[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o00030000oooooooo02Woool00ol0VOoo
ooooo`1Koooo0027oooo1@0000?oool3000013?o00030000oooooooo02Woool00ol0VOooooooo`1K
oooo0027oooo00@0003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o
08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOoo
o`030000oooooooo01?oool7<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool02Oooo`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool500000S?o0080000013?o0?ooooooooooo`800005
oooo0`0000;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`07oooo00<0000co`0co`001C?o00;oool010000?ooooooo`00
00Goool01@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo
00ooool00`0003?o03?o0005<ol00_ooo`040000oooooooo00000_ooo`D00003oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0000co`0co`001C?o00?oool200000ooo
o`040000oooooooo00000oooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000A
oooo00<0000co`0co`001C?o00;oool010000?ooooooo`0000?oool00`000?ooo`000003oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo017oool200001c?o00?oool200001Oooo`800002
oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.86) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.67958 .12361 L
.6883 .12361 L
.69774 .12361 L
.7003 .12361 L
.7017 .12361 L
.70301 .12361 L
.70413 .12361 L
s
.70413 .12361 m
.70461 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.28302 .12361 L
.2881 .12361 L
.29088 .12361 L
.29224 .12361 L
.29349 .12361 L
.29462 .12361 L
.2957 .12312 L
.29684 .12196 L
.29809 .1207 L
.30316 .11579 L
.32447 .09834 L
.3438 .08641 L
.36395 .07717 L
.38293 .07091 L
.39269 .06846 L
.40301 .06637 L
.41267 .06483 L
.42148 .06374 L
.43096 .06286 L
.43618 .0625 L
.44112 .06224 L
.44568 .06205 L
.4499 .06193 L
.4521 .06188 L
.45453 .06184 L
.45575 .06183 L
.45707 .06181 L
.45831 .06181 L
.45945 .0618 L
.46073 .0618 L
.46194 .06181 L
.46302 .06181 L
.46419 .06182 L
.46547 .06183 L
.46683 .06185 L
.46926 .06189 L
.4736 .06199 L
.47838 .06213 L
.48907 .06261 L
.49908 .0632 L
.50149 .06336 L
.50406 .06348 L
Mistroke
.50553 .06353 L
.50687 .06357 L
.50752 .06358 L
.50822 .06359 L
.50948 .0636 L
.51068 .06361 L
.51199 .06361 L
.51265 .0636 L
.51336 .06359 L
.51463 .06357 L
.51591 .06354 L
.51711 .06351 L
.51936 .06342 L
.52398 .06319 L
.52825 .06289 L
.5379 .062 L
.5566 .05957 L
.57722 .05613 L
.61748 .04816 L
.65621 .04004 L
.6759 .03609 L
.68631 .03412 L
.69202 .03308 L
.69741 .03214 L
.69992 .03171 L
.70258 .03126 L
.70325 .03115 L
.70397 .03104 L
.70476 .12361 L
.7055 .12361 L
.70819 .12361 L
.71797 .12361 L
.73708 .12361 L
.77841 .12361 L
.81822 .12361 L
.85652 .12361 L
.89727 .12361 L
.93651 .12361 L
.97422 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.86) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0^oooo101Voecoool0
08ooool00`000?ooooooo`0Xoooo1P1Vo`?oool00`1Vooooooooo`1Joooo002?oooo00<0003ooooo
ool08oooo`D0I_l9oooo00<0I_ooooooool0F_ooo`00Soooo`030000oooooooo01koool506Ko3_oo
o`0306Kooooooooo05[oool008ooool00`000?ooooooo`0Ioooo1@1Voa?oool00`1Vooooooooo`1J
oooo002?oooo0P0001Goool506Ko6?ooo`0306Kooooooooo05[oool008ooool00`000?ooooooo`0?
oooo1@1Voagoool00`1Vooooooooo`1Joooo002?oooo00<0003oooooool02_ooo`D0I_lRoooo00<0
I_ooooooool0F_ooo`00N?oooaL0I_l00`00001Vo`1Vo`0:06Ko9oooo`0306Kooooooooo05[oool0
07?oool506Ko5oooo`030000oooooooo037oool00`1Vooooooooo`1Joooo001`oooo0`1Voacoool0
0`000?ooooooo`0aoooo00<0I_ooooooool0F_ooo`00K_ooo`80I_lOoooo0P0003;oool00`1Voooo
ooooo`1Joooo000Goooo100003Woool500004_ooo`<0I_lQoooo00<0003oooooool0<Oooo`0306Ko
oooooooo00?oool50000>?ooo`@0000Foooo000Goooo00<0003oooooool0??ooo`030000oooooooo
013oool206Ko9?ooo`030000oooooooo037oool00`1Vooooooooo`05oooo00<0003oooooool0>?oo
o`030000oooooooo01Ooool001Soool00`000?ooooooo`0koooo00<0003oooooool03_ooo`80I_lV
oooo00<0003oooooool0<Oooo`0306Kooooooooo00Goool00`000?ooooooo`0ioooo00<0003ooooo
ool05_ooo`004Oooo`@00004oooo00<0003oooooool0<_ooo`@00004oooo00<0003oooooool03?oo
o`80I_lXoooo00<0003oooooool0<Oooo`0306Kooooooooo00Goool00`000?ooooooo`0joooo00<0
003oooooool05Oooo`005oooo`040000oooooooo0000>oooo`030000oooooooo00[oool206Ko:_oo
o`030000oooooooo037oool00`1Vooooooooo`05oooo00<0003oooooool0>?ooo`040000oooooooo
00005_ooo`006?ooo`80000koooo0P0000_oool00`1Vooooooooo`0Zoooo0P0003;oool00`1Voooo
ooooo`04oooo0P0003_oool200005oooo`00HOooo`0306Kooooooooo02_oool00`000?ooooooo`0a
oooo00<0I_ooooooool0F_ooo`00Goooo`80I_l^oooo00<0003oooooool0<Oooo`0306Kooooooooo
05[oool005koool00`1Vooooooooo`0^oooo00<0003oooooool0<Oooo`0306Kooooooooo05[oool0
05goool00`1Vooooooooo`0_oooo00<0003oooooool0<Oooo`0306Kooooooooo05[oool005coool0
0`1Vooooooooo`0`oooo00<0003oooooool0<Oooo`0306Kooooooooo05[oool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000D0000co`0c
o`0co`3o09T01c?o00030000<ol0<ol000Hco`0R00001_ooo`030000oooooooo00Woool00`000?oo
ooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000a
<ol000?o09Tco`0co`001C?o00T0000doooo00<0003oooooool05Oooo`00Soooo`030000<ol0<ol0
034co`000ol0VC?o000000050000EOooo`00Soooo`030000<ol0<ol0034co`000ol0V@000?ooo`1J
oooo002?oooo00<0000co`0co`00;c?o008000000ol0VOooooooo`1Joooo002?oooo00<0000co`0c
o`00;3?o00<00002oooo00?o09Woooooool0F_ooo`00Soooo`80000Z<ol00`0000Goool00ol0VOoo
ooooo`1Joooo002?oooo00<0000co`0co`009c?o00800008oooo00?o09Woooooool0F_ooo`00Sooo
o`030000<ol0<ol002Hco`000`000?ooooooo`08oooo00?o09Woooooool0F_ooo`00Soooo`030000
<ol0<ol002Dco`000`000?ooooooo`09oooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol0
02@co`000`000?ooooooo`0:oooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol0028co`02
00003Oooo`03o`2Ioooooooo05[oool008ooool200008S?o00030000oooooooo00goool00ol0VOoo
ooooo`1Joooo002?oooo00<0000co`0co`0083?o00030000oooooooo00koool00ol0VOooooooo`1J
oooo002?oooo00<0000co`0co`007c?o00030000oooooooo00ooool00ol0VOooooooo`1Joooo002?
oooo00<0000co`0co`007c?o00030000oooooooo00ooool00ol0VOooooooo`1Joooo002?oooo00<0
000co`0co`007S?o00030000oooooooo013oool00ol0VOooooooo`1Joooo002?oooo00<0000co`0c
o`007C?o00030000oooooooo017oool00ol0VOooooooo`1Joooo002?oooo0P0001dco`000`000?oo
ooooo`0Boooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0C
oooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0Coooo00?o
09Woooooool0F_ooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0Doooo00?o09Wooooo
ool0F_ooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0Doooo00?o09Woooooool0F_oo
o`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`0Eoooo00?o09Woooooool0F_ooo`00Sooo
o`80000J<ol000<0003oooooool05Oooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000H
<ol000<0003oooooool05_ooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000H<ol000<0
003oooooool05_ooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000G<ol000<0003ooooo
ool05oooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000G<ol000<0003oooooool05ooo
o`03o`2Ioooooooo05[oool008Ooool500000oooo`030000<ol0<ol001Hco`000`000?ooooooo`0H
oooo00?o09Woooooool0F_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000F<ol000<0
003oooooool06?ooo`03o`2Ioooooooo05[oool008Woool00`000?ooooooo`03oooo0`0001Dco`00
0`000?ooooooo`0Ioooo00?o09Woooooool0F_ooo`00ROooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool06Oooo`03o`2Ioooooooo05[oool008Woool00`000?ooooooo`03
oooo00<0000co`0co`005C?o00030000oooooooo01Woool00ol0VOooooooo`1Joooo0028oooo0P00
00Goool00`0003?o03?o000D<ol000<0003oooooool06_ooo`03o`2Ioooooooo05[oool008ooool0
0`0003?o03?o000D<ol000<0003oooooool06_ooo`03o`2Ioooooooo05[oool008ooool00`0003?o
03?o000C<ol000<0003oooooool06oooo`03o`2Ioooooooo05[oool008ooool2000053?o00030000
oooooooo01_oool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`004c?o00030000oooooooo
01_oool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`004S?o00030000oooooooo01coool0
0ol0VOooooooo`1Joooo002?oooo00<0000co`0co`004S?o00030000oooooooo01coool00ol0VOoo
ooooo`1Joooo002?oooo00<0000co`0co`004S?o00030000oooooooo01coool00ol0VOooooooo`1J
oooo002?oooo00<0000co`0co`004C?o00030000oooooooo01goool00ol0VOooooooo`1Joooo002?
oooo0P00018co`000`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol0
014co`000`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol0014co`00
0`000?ooooooo`0Moooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol0010co`000`000?oo
ooooo`0Noooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0N
oooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Noooo00?o
09Woooooool0F_ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Noooo00?o09Wooooo
ool0F_ooo`00Soooo`80000@<ol000<0003oooooool07oooo`03o`2Ioooooooo05[oool008ooool0
0`0003?o03?o000?<ol000<0003oooooool07oooo`03o`2Ioooooooo05[oool008ooool00`0003?o
03?o000?<ol000<0003oooooool07oooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000?
<ol000<0003oooooool07oooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000?<ol000<0
003oooooool07oooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000><ol000<0003ooooo
ool08?ooo`03o`2Ioooooooo05[oool008ooool200003c?o00030000oooooooo023oool00ol0VOoo
ooooo`1Joooo002?oooo00<0000co`0co`003S?o00030000oooooooo023oool00ol0VOooooooo`1J
oooo002?oooo00<0000co`0co`003S?o00030000oooooooo023oool00ol0VOooooooo`1Joooo002?
oooo00<0000co`0co`003C?o00030000oooooooo027oool00ol0VOooooooo`1Joooo0027oooo1000
00Coool00`0003?o03?o000=<ol000<0003oooooool08Oooo`03o`2Ioooooooo05[oool008Ooool0
0`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo027oool00ol0VOooooooo`1J
oooo0028oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool08Oooo`03o`2Ioooooooo
05[oool008Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo027oool0
0ol0VOooooooo`1Joooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0033?o00030000
oooooooo02;oool00ol0VOooooooo`1Joooo0028oooo0P0000Goool00`0003?o03?o000<<ol000<0
003oooooool08_ooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000<<ol000<0003ooooo
ool08_ooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000<<ol000<0003oooooool08_oo
o`03o`2Ioooooooo05[oool008ooool200003C?o00030000oooooooo02;oool00ol0VOooooooo`1J
oooo002?oooo00<0000co`0co`0033?o00030000oooooooo02;oool00ol0VOooooooo`1Joooo002?
oooo00<0000co`0co`002c?o00030000oooooooo02?oool00ol0VOooooooo`1Joooo002?oooo00<0
000co`0co`002c?o00030000oooooooo02?oool00ol0VOooooooo`1Joooo002?oooo00<0000co`0c
o`002c?o00030000oooooooo02?oool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`002c?o
00030000oooooooo02?oool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`002c?o00030000
oooooooo02?oool00ol0VOooooooo`1Joooo002?oooo0P0000`co`000`000?ooooooo`0Soooo00?o
09Woooooool0F_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0Soooo00?o09Wooooo
ool0F_ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Toooo00?o09Woooooool0F_oo
o`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Toooo00?o09Woooooool0F_ooo`00Sooo
o`030000<ol0<ol000Xco`000`000?ooooooo`0Toooo00?o09Woooooool0F_ooo`00Soooo`030000
<ol0<ol000Xco`000`000?ooooooo`0Toooo00?o09Woooooool0F_ooo`00Soooo`80000;<ol000<0
003oooooool09?ooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000:<ol000<0003ooooo
ool09?ooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o000:<ol000<0003oooooool09?oo
o`03o`2Ioooooooo05[oool008ooool00`0003?o03?o0009<ol000<0003oooooool09Oooo`03o`2I
oooooooo05[oool008ooool00`0003?o03?o0009<ol000<0003oooooool09Oooo`03o`2Ioooooooo
05[oool008ooool00`0003?o03?o0009<ol000<0003oooooool09Oooo`03o`2Ioooooooo05[oool0
08ooool200002S?o00030000oooooooo02Goool00ol0VOooooooo`1Joooo002?oooo00<0000co`0c
o`002C?o00030000oooooooo02Goool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`002C?o
00030000oooooooo02Goool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`0023?o00030000
oooooooo02Koool00ol0VOooooooo`1Joooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0
003oooooool09_ooo`03o`2Ioooooooo05[oool008Ooool010000?ooooooo`0000Coool00`0003?o
03?o0008<ol000<0003oooooool09_ooo`03o`2Ioooooooo05[oool008Woool00`000?ooooooo`03
oooo0`0000Pco`000`000?ooooooo`0Voooo00?o09Woooooool0F_ooo`00R_ooo`030000oooooooo
00;oool00`0003?o03?o0008<ol000<0003oooooool09_ooo`03o`2Ioooooooo05[oool008Ooool0
10000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool09_ooo`03o`2Ioooooooo
05[oool008Soool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`0Woooo00?o09Wooooo
ool0F_ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Woooo00?o09Woooooool0F_oo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Woooo00?o09Woooooool0F_ooo`00Sooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0Woooo00?o09Woooooool0F_ooo`00Soooo`800008
<ol000<0003oooooool09oooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o0007<ol000<0
003oooooool09oooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool09oooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o0007<ol000<0003oooooool09ooo
o`03o`2Ioooooooo05[oool008ooool00`0003?o03?o0006<ol000<0003oooooool0:?ooo`03o`2I
oooooooo05[oool008ooool00`0003?o03?o0006<ol000<0003oooooool0:?ooo`03o`2Ioooooooo
05[oool008ooool200001c?o00030000oooooooo02Soool00ol0VOooooooo`1Joooo002?oooo00<0
000co`0co`001S?o00030000oooooooo02Soool00ol0VOooooooo`1Joooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo02Soool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`001S?o
00030000oooooooo02Soool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`001S?o00030000
oooooooo02Soool00ol0VOooooooo`1Joooo002?oooo00<0000co`0co`001S?o00030000oooooooo
02Soool00ol0VOooooooo`1Joooo002?oooo0P0000Hco`000`000?ooooooo`0Yoooo00?o09Wooooo
ool0F_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Yoooo00?o09Woooooool0F_oo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0Yoooo00?o09Woooooool0F_ooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`0Yoooo00?o09Woooooool0F_ooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`0Yoooo00?o09Woooooool0F_ooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`0Yoooo00?o09Woooooool0F_ooo`00Soooo`800006<ol000<0003ooooo
ool0:Oooo`03o`2Ioooooooo05[oool008ooool00`0003?o03?o0005<ol000<0003oooooool0:Ooo
o`03o`2Ioooooooo05[oool008ooool00`0003?o03?o0005<ol000<0003oooooool0:Oooo`03o`2I
oooooooo05[oool008ooool00`0003?o03?o0004<ol000<0003oooooool0:_ooo`03o`2Ioooooooo
05[oool008ooool00`0003?o03?o0004<ol000<0003oooooool0:_ooo`03o`2Ioooooooo05[oool0
08Woool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`0Zoooo00?o09Woooooool0F_oo
o`00R_ooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0:_ooo`03o`2I
oooooooo05[oool008Ooool500000oooo`<00004<ol000<0003oooooool0:_ooo`03o`2Ioooooooo
05[oool008Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7
<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001i
oooo00<0003oooooool04oooo`Lco`0>oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo
00Soool00`000?ooooooo`09oooo1c?o00ooool00`000?ooooooo`1hoooo001hoooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool01_ooo`D00002<ol00P000004<ol0oooooooooooo0P00
00?oool300001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Ooool00`0003?o03?o0005<ol00_ooo`040000oooooooo
00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool03oooo`030000<ol0<ol000Dco`02oooo00@0003oooooool00002oooo00@0
003oooooool00004oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0
000co`0co`001C?o00?oool200000oooo`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo0000017oool00`0003?o03?o0005<ol00_ooo`040000oooooooo00000oooo`030000
oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007<ol00ooo
o`800004oooo0`0000;oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.88) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.67958 .12361 L
.69774 .12361 L
.7026 .12361 L
.70516 .12361 L
.70656 .12361 L
.70787 .12361 L
.70901 .12361 L
s
.70901 .12361 m
.7095 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.27731 .12361 L
.28302 .12361 L
.28542 .12361 L
.288 .12361 L
.28876 .12361 L
.28948 .12361 L
.29013 .12361 L
.29083 .12324 L
.2915 .12255 L
.29221 .12183 L
.29349 .12054 L
.30316 .11145 L
.32313 .09598 L
.34474 .08349 L
.35488 .0789 L
.3656 .07481 L
.3848 .06919 L
.39428 .06712 L
.40444 .06534 L
.41403 .06404 L
.42278 .06315 L
.42758 .06276 L
.43269 .06243 L
.43705 .06221 L
.44186 .06202 L
.44455 .06194 L
.44701 .06188 L
.44972 .06184 L
.45108 .06183 L
.45185 .06182 L
.45257 .06181 L
.45389 .06181 L
.45509 .0618 L
.45638 .0618 L
.4571 .06181 L
.45778 .06181 L
.4589 .06182 L
.46013 .06183 L
.46142 .06184 L
.46262 .06186 L
.4652 .0619 L
.4676 .06195 L
Mistroke
.47303 .06211 L
.47781 .0623 L
.48291 .06253 L
.49257 .06309 L
.4968 .06337 L
.50145 .0637 L
.5027 .06377 L
.50404 .06384 L
.5052 .06389 L
.50646 .06393 L
.5072 .06395 L
.50789 .06397 L
.50853 .06398 L
.50923 .06399 L
.51046 .064 L
.51176 .06401 L
.51246 .06401 L
.5132 .064 L
.51383 .064 L
.51453 .06399 L
.51527 .06398 L
.51607 .06396 L
.51751 .06393 L
.52033 .06383 L
.5229 .06371 L
.52789 .06341 L
.53329 .06298 L
.54308 .06197 L
.56299 .05921 L
.58405 .05558 L
.62199 .048 L
.66238 .03956 L
.68099 .03585 L
.69082 .034 L
.70126 .03214 L
.70649 .03126 L
.70793 .03102 L
.70868 .0309 L
.70947 .03077 L
.71017 .12361 L
.71093 .12361 L
.71227 .12361 L
.72247 .12361 L
.74259 .12361 L
.78312 .12361 L
.82213 .12361 L
.86359 .12361 L
.90354 .12361 L
.94198 .12361 L
.97619 .12361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.88) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0_oooo101Voe_oool0
08ooool00`000?ooooooo`0Yoooo1P1Vo`?oool00`1Vooooooooo`1Ioooo002?oooo00<0003ooooo
ool09?ooo`D0I_l9oooo00<0I_ooooooool0FOooo`00Soooo`030000oooooooo01ooool506Ko3_oo
o`0306Kooooooooo05Woool008ooool00`000?ooooooo`0Joooo1@1Voa?oool00`1Vooooooooo`1I
oooo002?oooo0P0001Koool506Ko6?ooo`0306Kooooooooo05Woool008ooool00`000?ooooooo`0@
oooo1@1Voagoool00`1Vooooooooo`1Ioooo002?oooo00<0003oooooool02oooo`D0I_lRoooo00<0
I_ooooooool0FOooo`00NOoooaH0I_l00`00001Vo`1Vo`0;06Ko9oooo`0306Kooooooooo05Woool0
07Coool506Ko5_ooo`030000oooooooo03;oool00`1Vooooooooo`1Ioooo001`oooo101Voa_oool0
0`000?ooooooo`0boooo00<0I_ooooooool0FOooo`00K?ooo`@0I_lOoooo0P0003?oool00`1Voooo
ooooo`1Ioooo000Goooo100003Woool500004Oooo`80I_lSoooo00<0003oooooool0<_ooo`0306Ko
oooooooo00;oool50000>?ooo`@0000Foooo000Goooo00<0003oooooool0??ooo`030000oooooooo
00ooool206Ko9Oooo`030000oooooooo03;oool00`1Vooooooooo`04oooo00<0003oooooool0>?oo
o`030000oooooooo01Ooool001Soool00`000?ooooooo`0koooo00<0003oooooool03Oooo`80I_lW
oooo00<0003oooooool0<_ooo`0306Kooooooooo00Coool00`000?ooooooo`0ioooo00<0003ooooo
ool05_ooo`004Oooo`@00004oooo00<0003oooooool0<_ooo`@00004oooo00<0003oooooool02ooo
o`80I_lYoooo00<0003oooooool0<_ooo`0306Kooooooooo00Coool00`000?ooooooo`0joooo00<0
003oooooool05Oooo`005oooo`040000oooooooo0000>oooo`030000oooooooo00Woool206Ko:ooo
o`030000oooooooo03;oool00`1Vooooooooo`04oooo00<0003oooooool0>?ooo`040000oooooooo
00005_ooo`006?ooo`80000koooo0P0000[oool00`1Vooooooooo`0[oooo0P0003?oool00`1Voooo
ooooo`03oooo0P0003_oool200005oooo`00Goooo`80I_l^oooo00<0003oooooool0<_ooo`0306Ko
oooooooo05Woool005koool00`1Vooooooooo`0^oooo00<0003oooooool0<_ooo`0306Kooooooooo
05Woool005goool00`1Vooooooooo`0_oooo00<0003oooooool0<_ooo`0306Kooooooooo05Woool0
05coool00`1Vooooooooo`0`oooo00<0003oooooool0<_ooo`0306Kooooooooo05Woool005coool0
0`1Vooooooooo`0`oooo00<0003oooooool0<_ooo`0306Kooooooooo05Woool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0c
o`000S?o0003o`2I<ol0<ol000@co`000`0003?o03?o0006<ol08P0000Koool00`000?ooooooo`09
oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0
000co`0co`00<S?o0003o`2I<ol0<ol000@co`090000=?ooo`030000oooooooo01Goool008ooool0
0`0003?o03?o000b<ol000?o09T000000000100005Goool008ooool00`0003?o03?o000a<ol000<0
003o09Woool0F_ooo`00Soooo`030000<ol0<ol002lco`02000000?ooooo09Woool0F_ooo`00Sooo
o`030000<ol0<ol002`co`0300000oooo`03o`2Ioooooooo05Woool008ooool20000:S?o00<00006
oooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol002Lco`0200002Oooo`03o`2Ioooooooo
05Woool008ooool00`0003?o03?o000V<ol000<0003oooooool02Oooo`03o`2Ioooooooo05Woool0
08ooool00`0003?o03?o000U<ol000<0003oooooool02_ooo`03o`2Ioooooooo05Woool008ooool0
0`0003?o03?o000T<ol000<0003oooooool02oooo`03o`2Ioooooooo05Woool008ooool00`0003?o
03?o000R<ol00P0000koool00ol0VOooooooo`1Ioooo002?oooo0P00028co`000`000?ooooooo`0>
oooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol0020co`000`000?ooooooo`0?oooo00?o
09Woooooool0FOooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0@oooo00?o09Wooooo
ool0FOooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0@oooo00?o09Woooooool0FOoo
o`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`0Aoooo00?o09Woooooool0FOooo`00Sooo
o`030000<ol0<ol001dco`000`000?ooooooo`0Boooo00?o09Woooooool0FOooo`00Soooo`80000M
<ol000<0003oooooool04oooo`03o`2Ioooooooo05Woool008ooool00`0003?o03?o000K<ol000<0
003oooooool05?ooo`03o`2Ioooooooo05Woool008ooool00`0003?o03?o000K<ol000<0003ooooo
ool05?ooo`03o`2Ioooooooo05Woool008ooool00`0003?o03?o000J<ol000<0003oooooool05Ooo
o`03o`2Ioooooooo05Woool008ooool00`0003?o03?o000J<ol000<0003oooooool05Oooo`03o`2I
oooooooo05Woool008ooool00`0003?o03?o000I<ol000<0003oooooool05_ooo`03o`2Ioooooooo
05Woool008ooool200006S?o00030000oooooooo01Koool00ol0VOooooooo`1Ioooo002?oooo00<0
000co`0co`0063?o00030000oooooooo01Ooool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0c
o`0063?o00030000oooooooo01Ooool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`005c?o
00030000oooooooo01Soool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`005c?o00030000
oooooooo01Soool00ol0VOooooooo`1Ioooo0027oooo1@0000?oool00`0003?o03?o000F<ol000<0
003oooooool06Oooo`03o`2Ioooooooo05Woool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`005S?o00030000oooooooo01Woool00ol0VOooooooo`1Ioooo0029oooo00<0003oooooool00ooo
o`<0000E<ol000<0003oooooool06_ooo`03o`2Ioooooooo05Woool008Woool00`000?ooooooo`03
oooo00<0000co`0co`005C?o00030000oooooooo01[oool00ol0VOooooooo`1Ioooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`0Joooo00?o09Woooooool0FOoo
o`00R?ooo`800005oooo00<0000co`0co`0053?o00030000oooooooo01_oool00ol0VOooooooo`1I
oooo002?oooo00<0000co`0co`0053?o00030000oooooooo01_oool00ol0VOooooooo`1Ioooo002?
oooo00<0000co`0co`004c?o00030000oooooooo01coool00ol0VOooooooo`1Ioooo002?oooo0P00
01@co`000`000?ooooooo`0Loooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol001<co`00
0`000?ooooooo`0Loooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol0018co`000`000?oo
ooooo`0Moooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0M
oooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Moooo00?o
09Woooooool0FOooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Noooo00?o09Wooooo
ool0FOooo`00Soooo`80000B<ol000<0003oooooool07_ooo`03o`2Ioooooooo05Woool008ooool0
0`0003?o03?o000A<ol000<0003oooooool07_ooo`03o`2Ioooooooo05Woool008ooool00`0003?o
03?o000A<ol000<0003oooooool07_ooo`03o`2Ioooooooo05Woool008ooool00`0003?o03?o000@
<ol000<0003oooooool07oooo`03o`2Ioooooooo05Woool008ooool00`0003?o03?o000@<ol000<0
003oooooool07oooo`03o`2Ioooooooo05Woool008ooool00`0003?o03?o000@<ol000<0003ooooo
ool07oooo`03o`2Ioooooooo05Woool008ooool00`0003?o03?o000@<ol000<0003oooooool07ooo
o`03o`2Ioooooooo05Woool008ooool2000043?o00030000oooooooo023oool00ol0VOooooooo`1I
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo023oool00ol0VOooooooo`1Ioooo002?
oooo00<0000co`0co`003c?o00030000oooooooo023oool00ol0VOooooooo`1Ioooo002?oooo00<0
000co`0co`003c?o00030000oooooooo023oool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0c
o`003c?o00030000oooooooo023oool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`003S?o
00030000oooooooo027oool00ol0VOooooooo`1Ioooo002?oooo0P0000lco`000`000?ooooooo`0Q
oooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Qoooo00?o
09Woooooool0FOooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Qoooo00?o09Wooooo
ool0FOooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`0Roooo00?o09Woooooool0FOoo
o`00Qoooo`@00004oooo00<0000co`0co`003C?o00030000oooooooo02;oool00ol0VOooooooo`1I
oooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`0Roooo00?o
09Woooooool0FOooo`00R?ooo`030000oooooooo00Coool300003C?o00030000oooooooo02;oool0
0ol0VOooooooo`1Ioooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000dco`000`000?oo
ooooo`0Roooo00?o09Woooooool0FOooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol0
00`co`000`000?ooooooo`0Soooo00?o09Woooooool0FOooo`00R?ooo`800005oooo00<0000co`0c
o`0033?o00030000oooooooo02?oool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`0033?o
00030000oooooooo02?oool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`0033?o00030000
oooooooo02?oool00ol0VOooooooo`1Ioooo002?oooo0P0000dco`000`000?ooooooo`0Soooo00?o
09Woooooool0FOooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0Soooo00?o09Wooooo
ool0FOooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0Toooo00?o09Woooooool0FOoo
o`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0Toooo00?o09Woooooool0FOooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`0Toooo00?o09Woooooool0FOooo`00Soooo`030000
<ol0<ol000/co`000`000?ooooooo`0Toooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`0Toooo00?o09Woooooool0FOooo`00Soooo`80000<<ol000<0003ooooo
ool09?ooo`03o`2Ioooooooo05Woool008ooool00`0003?o03?o000;<ol000<0003oooooool09?oo
o`03o`2Ioooooooo05Woool008ooool00`0003?o03?o000:<ol000<0003oooooool09Oooo`03o`2I
oooooooo05Woool008ooool00`0003?o03?o000:<ol000<0003oooooool09Oooo`03o`2Ioooooooo
05Woool008ooool00`0003?o03?o000:<ol000<0003oooooool09Oooo`03o`2Ioooooooo05Woool0
08ooool00`0003?o03?o000:<ol000<0003oooooool09Oooo`03o`2Ioooooooo05Woool008ooool2
00002c?o00030000oooooooo02Goool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`002S?o
00030000oooooooo02Goool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`002S?o00030000
oooooooo02Goool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`002C?o00030000oooooooo
02Koool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`002C?o00030000oooooooo02Koool0
0ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`002C?o00030000oooooooo02Koool00ol0VOoo
ooooo`1Ioooo002?oooo0P0000Xco`000`000?ooooooo`0Voooo00?o09Woooooool0FOooo`00Sooo
o`030000<ol0<ol000Tco`000`000?ooooooo`0Voooo00?o09Woooooool0FOooo`00Soooo`030000
<ol0<ol000Tco`000`000?ooooooo`0Voooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol0
00Pco`000`000?ooooooo`0Woooo00?o09Woooooool0FOooo`00R?ooo`800005oooo00<0000co`0c
o`0023?o00030000oooooooo02Ooool00ol0VOooooooo`1Ioooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0023?o00030000oooooooo02Ooool00ol0VOooooooo`1Ioooo0029oooo00<0
003oooooool00oooo`<00008<ol000<0003oooooool09oooo`03o`2Ioooooooo05Woool008[oool0
0`000?ooooooo`02oooo00<0000co`0co`0023?o00030000oooooooo02Ooool00ol0VOooooooo`1I
oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo02Ooool0
0ol0VOooooooo`1Ioooo0028oooo0P0000Goool00`0003?o03?o0007<ol000<0003oooooool0:?oo
o`03o`2Ioooooooo05Woool008ooool00`0003?o03?o0007<ol000<0003oooooool0:?ooo`03o`2I
oooooooo05Woool008ooool00`0003?o03?o0007<ol000<0003oooooool0:?ooo`03o`2Ioooooooo
05Woool008ooool00`0003?o03?o0007<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05Woool0
08ooool2000023?o00030000oooooooo02Soool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo02Soool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`001c?o
00030000oooooooo02Soool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`001c?o00030000
oooooooo02Soool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`001S?o00030000oooooooo
02Woool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`001S?o00030000oooooooo02Woool0
0ol0VOooooooo`1Ioooo002?oooo0P0000Lco`000`000?ooooooo`0Yoooo00?o09Woooooool0FOoo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0Yoooo00?o09Woooooool0FOooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`0Yoooo00?o09Woooooool0FOooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`0Yoooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol0
00Hco`000`000?ooooooo`0Yoooo00?o09Woooooool0FOooo`00Soooo`030000<ol0<ol000Hco`00
0`000?ooooooo`0Yoooo00?o09Woooooool0FOooo`00Soooo`800006<ol000<0003oooooool0:_oo
o`03o`2Ioooooooo05Woool008ooool00`0003?o03?o0005<ol000<0003oooooool0:_ooo`03o`2I
oooooooo05Woool008ooool00`0003?o03?o0005<ol000<0003oooooool0:_ooo`03o`2Ioooooooo
05Woool008ooool00`0003?o03?o0005<ol000<0003oooooool0:_ooo`03o`2Ioooooooo05Woool0
08ooool00`0003?o03?o0005<ol000<0003oooooool0:_ooo`03o`2Ioooooooo05Woool008ooool0
0`0003?o03?o0005<ol000<0003oooooool0:_ooo`03o`2Ioooooooo05Woool008ooool200001S?o
00030000oooooooo02[oool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`001C?o00030000
oooooooo02[oool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`001C?o00030000oooooooo
02[oool00ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`0013?o00030000oooooooo02_oool0
0ol0VOooooooo`1Ioooo002?oooo00<0000co`0co`0013?o00030000oooooooo02_oool00ol0VOoo
ooooo`1Ioooo0029oooo0`0000?oool00`0003?o03?o0004<ol000<0003oooooool0:oooo`03o`2I
oooooooo05Woool008[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o00030000oooooooo
02_oool00ol0VOooooooo`1Ioooo0027oooo1@0000?oool3000013?o00030000oooooooo02_oool0
0ol0VOooooooo`1Ioooo0027oooo00@0003oooooool00004oooo1c?o08[oool008Soool00`000?oo
o`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7
<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_ooo`030000oooooooo07Woool007Soool0
0`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?oooo00<0003oooooool0N?ooo`00N?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000S?o0080000013?o0?oo
ooooooooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0000co`0co`001C?o00;oool0
10000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0
003oooooool00_ooo`030000oooooooo00ooool00`0003?o03?o0005<ol00_ooo`040000oooooooo
00000_ooo`040000oooooooo00001?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00003_ooo`030000<ol0<ol000Dco`03oooo0P0000Coool200001?ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`00000Aoooo00<0000co`0co`001C?o00;oool010000?ooooooo`00
00;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Ooo
o`800007<ol00oooo`800004oooo0P0000?oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool0
08ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.67958 .12361 L
.69774 .12361 L
.7026 .12361 L
.70787 .12361 L
.71028 .12361 L
.7116 .12361 L
.71284 .12361 L
.71389 .12361 L
s
.71389 .12361 m
.71434 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.27193 .12361 L
.27731 .12361 L
.28025 .12361 L
.28302 .12361 L
.28425 .12361 L
.28542 .12361 L
.28606 .12325 L
.28676 .12252 L
.288 .12127 L
.29349 .11592 L
.30316 .10738 L
.32447 .09205 L
.3438 .08167 L
.35348 .07754 L
.36395 .07376 L
.38293 .06852 L
.39244 .06656 L
.40287 .06487 L
.40813 .06418 L
.41376 .06355 L
.42393 .06268 L
.42922 .06236 L
.43411 .06213 L
.43687 .06203 L
.43947 .06195 L
.44218 .06189 L
.44362 .06186 L
.44517 .06184 L
.44644 .06182 L
.44762 .06181 L
.44891 .06181 L
.44963 .0618 L
.45029 .0618 L
.45098 .0618 L
.45162 .0618 L
.45232 .06181 L
.45306 .06181 L
.4543 .06182 L
.45501 .06182 L
.45567 .06183 L
.45809 .06186 L
.46031 .0619 L
.46529 .06202 L
Mistroke
.47008 .06218 L
.47517 .06239 L
.48432 .06287 L
.49513 .06359 L
.49986 .06395 L
.50255 .06414 L
.50386 .06421 L
.50506 .06427 L
.50622 .06432 L
.50748 .06436 L
.50881 .06439 L
.51007 .06442 L
.51071 .06443 L
.51141 .06443 L
.51214 .06444 L
.51282 .06444 L
.51405 .06443 L
.51537 .06442 L
.51607 .06441 L
.51672 .0644 L
.5182 .06436 L
.51964 .06432 L
.52118 .06427 L
.52651 .064 L
.53195 .06362 L
.53709 .06317 L
.54669 .06212 L
.56674 .05927 L
.58521 .05608 L
.62466 .04825 L
.6626 .04032 L
.68372 .03609 L
.703 .03252 L
.70763 .03172 L
.71016 .0313 L
.71255 .0309 L
.71378 .0307 L
.71448 .12361 L
.71512 .12361 L
.71795 .12361 L
.72295 .12361 L
.74187 .12361 L
.78146 .12361 L
.81954 .12361 L
.86007 .12361 L
.89908 .12361 L
.94055 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0_oooo1@1Voe[oool0
08ooool00`000?ooooooo`0Zoooo1@1Vo`Coool00`1Vooooooooo`1Hoooo002?oooo00<0003ooooo
ool09?ooo`H0I_l9oooo00<0I_ooooooool0F?ooo`00Soooo`030000oooooooo023oool406Ko3ooo
o`0306Kooooooooo05Soool008ooool00`000?ooooooo`0Koooo1@1Voa?oool00`1Vooooooooo`1H
oooo002?oooo0P0001Ooool506Ko6?ooo`0306Kooooooooo05Soool008ooool00`000?ooooooo`0A
oooo1@1Voagoool00`1Vooooooooo`1Hoooo002?oooo00<0003oooooool03?ooo`D0I_lRoooo00<0
I_ooooooool0F?ooo`00N?oooaL0I_l00`00001Vo`1Vo`0<06Ko9oooo`0306Kooooooooo05Soool0
073oool806Ko5oooo`030000oooooooo03?oool00`1Vooooooooo`1Hoooo001^oooo0P1Voaooool0
0`000?ooooooo`0coooo00<0I_ooooooool0F?ooo`00K?ooo`80I_lQoooo0P0003Coool00`1Voooo
ooooo`1Hoooo000Goooo100003Woool500004?ooo`<0I_lSoooo00<0003oooooool0<oooo`0406Ko
oooooooooooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?ooooooo`0=
oooo0`1VobKoool00`000?ooooooo`0coooo00<0I_ooooooool00oooo`030000oooooooo03Soool0
0`000?ooooooo`0Goooo000Hoooo00<0003oooooool0>oooo`030000oooooooo00_oool206Ko:Ooo
o`030000oooooooo03?oool00`1Vooooooooo`03oooo00<0003oooooool0>Oooo`030000oooooooo
01Koool0017oool400001?ooo`030000oooooooo03;oool400001?ooo`030000oooooooo00Woool2
06Ko:oooo`030000oooooooo03?oool00`1Vooooooooo`03oooo00<0003oooooool0>_ooo`030000
oooooooo01Goool001Ooool010000?ooooooo`0003_oool00`000?ooooooo`08oooo00<0I_oooooo
ool0:oooo`030000oooooooo03?oool00`1Vooooooooo`03oooo00<0003oooooool0>?ooo`040000
oooooooo00005_ooo`006?ooo`80000koooo0P0000Soool206Ko;_ooo`80000doooo00<0I_oooooo
ool00_ooo`80000koooo0P0001Ooool005koool00`1Vooooooooo`0^oooo00<0003oooooool0<ooo
o`0306Kooooooooo05Soool005goool00`1Vooooooooo`0_oooo00<0003oooooool0<oooo`0306Ko
oooooooo05Soool005coool00`1Vooooooooo`0`oooo00<0003oooooool0<oooo`0306Kooooooooo
05Soool005_oool00`1Vooooooooo`0aoooo00<0003oooooool0<oooo`0306Kooooooooo05Soool0
05[oool00`1Vooooooooo`0boooo00<0003oooooool0<oooo`0306Kooooooooo05Soool0013ooooo
00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o
03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0
000co`0co`000c?o0003o`2I<ol0<ol000<co`000`0003?o03?o0006<ol08P0000Koool00`000?oo
ooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0i
oooo00<0000co`0co`00<c?o0003o`2I<ol0<ol000<co`090000=?ooo`030000oooooooo01Goool0
08ooool00`0003?o03?o000c<ol000?o09T0000000000`0005Goool008ooool00`0003?o03?o000a
<ol00P000003o`2Ioooooooo05Soool008ooool00`0003?o03?o000_<ol00P0000;oool00ol0VOoo
ooooo`1Hoooo002?oooo00<0000co`0co`00;3?o00<00004oooo00?o09Woooooool0F?ooo`00Sooo
o`80000Z<ol00`0000Ooool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`009c?o0080000:
oooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol002Hco`000`000?ooooooo`0:oooo00?o
09Woooooool0F?ooo`00Soooo`030000<ol0<ol002Dco`000`000?ooooooo`0;oooo00?o09Wooooo
ool0F?ooo`00Soooo`030000<ol0<ol002@co`000`000?ooooooo`0<oooo00?o09Woooooool0F?oo
o`00Soooo`030000<ol0<ol0028co`0200003oooo`03o`2Ioooooooo05Soool008ooool200008S?o
00030000oooooooo00ooool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`0083?o00030000
oooooooo013oool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`007c?o00030000oooooooo
017oool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`007c?o00030000oooooooo017oool0
0ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`007S?o00030000oooooooo01;oool00ol0VOoo
ooooo`1Hoooo002?oooo00<0000co`0co`007C?o00030000oooooooo01?oool00ol0VOooooooo`1H
oooo002?oooo0P0001dco`000`000?ooooooo`0Doooo00?o09Woooooool0F?ooo`00Soooo`030000
<ol0<ol001/co`000`000?ooooooo`0Eoooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol0
01/co`000`000?ooooooo`0Eoooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol001Xco`00
0`000?ooooooo`0Foooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol001Xco`000`000?oo
ooooo`0Foooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`0G
oooo00?o09Woooooool0F?ooo`00Soooo`80000J<ol000<0003oooooool05oooo`03o`2Ioooooooo
05Soool008ooool00`0003?o03?o000H<ol000<0003oooooool06?ooo`03o`2Ioooooooo05Soool0
08ooool00`0003?o03?o000H<ol000<0003oooooool06?ooo`03o`2Ioooooooo05Soool008ooool0
0`0003?o03?o000G<ol000<0003oooooool06Oooo`03o`2Ioooooooo05Soool008ooool00`0003?o
03?o000G<ol000<0003oooooool06Oooo`03o`2Ioooooooo05Soool008Ooool500000oooo`030000
<ol0<ol001Hco`000`000?ooooooo`0Joooo00?o09Woooooool0F?ooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000F<ol000<0003oooooool06_ooo`03o`2Ioooooooo05Soool008Woool0
0`000?ooooooo`03oooo0`0001Dco`000`000?ooooooo`0Koooo00?o09Woooooool0F?ooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool06oooo`03o`2Ioooooooo
05Soool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo01_oool0
0ol0VOooooooo`1Hoooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool07?oo
o`03o`2Ioooooooo05Soool008ooool00`0003?o03?o000D<ol000<0003oooooool07?ooo`03o`2I
oooooooo05Soool008ooool00`0003?o03?o000C<ol000<0003oooooool07Oooo`03o`2Ioooooooo
05Soool008ooool2000053?o00030000oooooooo01goool00ol0VOooooooo`1Hoooo002?oooo00<0
000co`0co`004c?o00030000oooooooo01goool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0c
o`004S?o00030000oooooooo01koool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`004S?o
00030000oooooooo01koool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`004S?o00030000
oooooooo01koool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`004C?o00030000oooooooo
01ooool00ol0VOooooooo`1Hoooo002?oooo0P00018co`000`000?ooooooo`0Ooooo00?o09Wooooo
ool0F?ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Ooooo00?o09Woooooool0F?oo
o`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Ooooo00?o09Woooooool0F?ooo`00Sooo
o`030000<ol0<ol0010co`000`000?ooooooo`0Poooo00?o09Woooooool0F?ooo`00Soooo`030000
<ol0<ol0010co`000`000?ooooooo`0Poooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol0
010co`000`000?ooooooo`0Poooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol0010co`00
0`000?ooooooo`0Poooo00?o09Woooooool0F?ooo`00Soooo`80000@<ol000<0003oooooool08Ooo
o`03o`2Ioooooooo05Soool008ooool00`0003?o03?o000?<ol000<0003oooooool08Oooo`03o`2I
oooooooo05Soool008ooool00`0003?o03?o000?<ol000<0003oooooool08Oooo`03o`2Ioooooooo
05Soool008ooool00`0003?o03?o000?<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Soool0
08ooool00`0003?o03?o000?<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Soool008ooool0
0`0003?o03?o000><ol000<0003oooooool08_ooo`03o`2Ioooooooo05Soool008ooool200003c?o
00030000oooooooo02;oool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`003S?o00030000
oooooooo02;oool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`003S?o00030000oooooooo
02;oool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`003C?o00030000oooooooo02?oool0
0ol0VOooooooo`1Hoooo0027oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool08ooo
o`03o`2Ioooooooo05Soool008Ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000
oooooooo02?oool00ol0VOooooooo`1Hoooo0028oooo00<0003oooooool01?ooo`<0000=<ol000<0
003oooooool08oooo`03o`2Ioooooooo05Soool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`003C?o00030000oooooooo02?oool00ol0VOooooooo`1Hoooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0033?o00030000oooooooo02Coool00ol0VOooooooo`1Hoooo0028oooo0P00
00Goool00`0003?o03?o000<<ol000<0003oooooool09?ooo`03o`2Ioooooooo05Soool008ooool0
0`0003?o03?o000<<ol000<0003oooooool09?ooo`03o`2Ioooooooo05Soool008ooool00`0003?o
03?o000<<ol000<0003oooooool09?ooo`03o`2Ioooooooo05Soool008ooool200003C?o00030000
oooooooo02Coool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`0033?o00030000oooooooo
02Coool00ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`002c?o00030000oooooooo02Goool0
0ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`002c?o00030000oooooooo02Goool00ol0VOoo
ooooo`1Hoooo002?oooo00<0000co`0co`002c?o00030000oooooooo02Goool00ol0VOooooooo`1H
oooo002?oooo00<0000co`0co`002c?o00030000oooooooo02Goool00ol0VOooooooo`1Hoooo002?
oooo00<0000co`0co`002c?o00030000oooooooo02Goool00ol0VOooooooo`1Hoooo002?oooo0P00
00`co`000`000?ooooooo`0Uoooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`0Uoooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0Voooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0V
oooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Voooo00?o
09Woooooool0F?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Voooo00?o09Wooooo
ool0F?ooo`00Soooo`80000;<ol000<0003oooooool09_ooo`03o`2Ioooooooo05Soool008ooool0
0`0003?o03?o000:<ol000<0003oooooool09_ooo`03o`2Ioooooooo05Soool008ooool00`0003?o
03?o000:<ol000<0003oooooool09_ooo`03o`2Ioooooooo05Soool008ooool00`0003?o03?o0009
<ol000<0003oooooool09oooo`03o`2Ioooooooo05Soool008ooool00`0003?o03?o0009<ol000<0
003oooooool09oooo`03o`2Ioooooooo05Soool008ooool00`0003?o03?o0009<ol000<0003ooooo
ool09oooo`03o`2Ioooooooo05Soool008ooool200002S?o00030000oooooooo02Ooool00ol0VOoo
ooooo`1Hoooo002?oooo00<0000co`0co`002C?o00030000oooooooo02Ooool00ol0VOooooooo`1H
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo02Ooool00ol0VOooooooo`1Hoooo002?
oooo00<0000co`0co`0023?o00030000oooooooo02Soool00ol0VOooooooo`1Hoooo0028oooo0P00
00Goool00`0003?o03?o0008<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05Soool008Ooool0
10000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0:?ooo`03o`2Ioooooooo
05Soool008Woool00`000?ooooooo`03oooo0`0000Pco`000`000?ooooooo`0Xoooo00?o09Wooooo
ool0F?ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0:?oo
o`03o`2Ioooooooo05Soool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0
003oooooool0:?ooo`03o`2Ioooooooo05Soool008Soool200001Oooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0Yoooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0Yoooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Y
oooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0Yoooo00?o
09Woooooool0F?ooo`00Soooo`800008<ol000<0003oooooool0:Oooo`03o`2Ioooooooo05Soool0
08ooool00`0003?o03?o0007<ol000<0003oooooool0:Oooo`03o`2Ioooooooo05Soool008ooool0
0`0003?o03?o0007<ol000<0003oooooool0:Oooo`03o`2Ioooooooo05Soool008ooool00`0003?o
03?o0007<ol000<0003oooooool0:Oooo`03o`2Ioooooooo05Soool008ooool00`0003?o03?o0006
<ol000<0003oooooool0:_ooo`03o`2Ioooooooo05Soool008ooool00`0003?o03?o0006<ol000<0
003oooooool0:_ooo`03o`2Ioooooooo05Soool008ooool200001c?o00030000oooooooo02[oool0
0ol0VOooooooo`1Hoooo002?oooo00<0000co`0co`001S?o00030000oooooooo02[oool00ol0VOoo
ooooo`1Hoooo002?oooo00<0000co`0co`001S?o00030000oooooooo02[oool00ol0VOooooooo`1H
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo02[oool00ol0VOooooooo`1Hoooo002?
oooo00<0000co`0co`001S?o00030000oooooooo02[oool00ol0VOooooooo`1Hoooo002?oooo00<0
000co`0co`001S?o00030000oooooooo02[oool00ol0VOooooooo`1Hoooo002?oooo0P0000Hco`00
0`000?ooooooo`0[oooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`0[oooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0[
oooo00?o09Woooooool0F?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0[oooo00?o
09Woooooool0F?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0[oooo00?o09Wooooo
ool0F?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0[oooo00?o09Woooooool0F?oo
o`00Soooo`800006<ol000<0003oooooool0:oooo`03o`2Ioooooooo05Soool008ooool00`0003?o
03?o0005<ol000<0003oooooool0:oooo`03o`2Ioooooooo05Soool008ooool00`0003?o03?o0005
<ol000<0003oooooool0:oooo`03o`2Ioooooooo05Soool008ooool00`0003?o03?o0004<ol000<0
003oooooool0;?ooo`03o`2Ioooooooo05Soool008ooool00`0003?o03?o0004<ol000<0003ooooo
ool0;?ooo`03o`2Ioooooooo05Soool008Woool300000oooo`030000<ol0<ol000@co`000`000?oo
ooooo`0/oooo00?o09Woooooool0F?ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0004
<ol000<0003oooooool0;?ooo`03o`2Ioooooooo05Soool008Ooool500000oooo`<00004<ol000<0
003oooooool0;?ooo`03o`2Ioooooooo05Soool008Ooool010000?ooooooo`0000Coool7<ol0R_oo
o`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7
<ol0R_ooo`00Soooo`Lco`2:oooo001loooo00<0003oooooool04?ooo`Lco`0;oooo00<0003ooooo
ool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`06oooo1c?o00coool00`000?oo
ooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002
<ol00P0000?oool300001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Goool2<ol000<0000co`0co`000S?o00Ooool0
0`000?ooooooo`02oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?oo
ooooo`0=oooo0S?o00030000<ol0<ol0008co`06oooo0`0000Coool00`000?ooooooo`1joooo001k
oooo00<0003oooooool01@0000coool2<ol000<0000co`0co`000S?o00Goool010000?ooooooo`00
00?oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000003oooo`8co`000`0003?o
03?o0002<ol01Oooo`040000oooooooo00000oooo`030000oooooooo07_oool007coool00`000?oo
ooooo`0@oooo00<co`000000000013?o00Koool300000_ooo`030000oooooooo07coool008ooool7
<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.92) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.70787 .12361 L
.71284 .12361 L
.71502 .12361 L
.71741 .12361 L
.71805 .12361 L
.71874 .12361 L
s
.71874 .12361 m
.71924 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.26171 .12361 L
.26709 .12361 L
.27279 .12361 L
.27765 .12361 L
.27899 .12361 L
.27972 .12361 L
.28042 .12361 L
.28107 .12349 L
.28178 .12276 L
.28302 .12149 L
.30316 .10356 L
.32283 .09017 L
.3438 .07956 L
.35409 .07552 L
.36521 .07189 L
.37483 .0693 L
.38538 .067 L
.39569 .06522 L
.40532 .06395 L
.41549 .06296 L
.42119 .06255 L
.42639 .06226 L
.43119 .06206 L
.43362 .06198 L
.4363 .06191 L
.43858 .06187 L
.43977 .06185 L
.44103 .06183 L
.44214 .06182 L
.44335 .06181 L
.44445 .06181 L
.44547 .0618 L
.44677 .0618 L
.4475 .06181 L
.44818 .06181 L
.44942 .06182 L
.45073 .06183 L
.45191 .06184 L
.45301 .06186 L
.45551 .0619 L
.45821 .06196 L
.46068 .06202 L
.46623 .06221 L
Mistroke
.4761 .06268 L
.48525 .06323 L
.49594 .06402 L
.50118 .06444 L
.50347 .0646 L
.50469 .06467 L
.50599 .06473 L
.5073 .06478 L
.50848 .06482 L
.50967 .06485 L
.5108 .06487 L
.51207 .06488 L
.51323 .06489 L
.51452 .06489 L
.51516 .06489 L
.51588 .06488 L
.51655 .06487 L
.51726 .06486 L
.51853 .06483 L
.5199 .0648 L
.52139 .06475 L
.52655 .06451 L
.53122 .06421 L
.53621 .06381 L
.54517 .0629 L
.56656 .05998 L
.58672 .05654 L
.62524 .04894 L
.66621 .04039 L
.68661 .0363 L
.69658 .03441 L
.70567 .03276 L
.71017 .03197 L
.71254 .03157 L
.71506 .03115 L
.71726 .03079 L
.71851 .03059 L
.71969 .12361 L
.72076 .12361 L
.72175 .12361 L
.72397 .12361 L
.74361 .12361 L
.7832 .12361 L
.82128 .12361 L
.86181 .12361 L
.90082 .12361 L
.94228 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.92) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0aoooo101VoeWoool0
08ooool00`000?ooooooo`0Zoooo1`1Vo`?oool00`1Vooooooooo`1Goooo002?oooo00<0003ooooo
ool09Oooo`D0I_l:oooo00<0I_ooooooool0Eoooo`00Soooo`030000oooooooo023oool506Ko3ooo
o`0306Kooooooooo05Ooool008ooool00`000?ooooooo`0Koooo1@1VoaCoool00`1Vooooooooo`1G
oooo002?oooo0P0001Ooool506Ko6Oooo`0306Kooooooooo05Ooool008ooool00`000?ooooooo`0A
oooo1@1Voakoool00`1Vooooooooo`1Goooo002?oooo00<0003oooooool03?ooo`D0I_lSoooo00<0
I_ooooooool0Eoooo`00MooooaP0I_l00`00001Vo`1Vo`02oooo2P1VobSoool00`1Vooooooooo`1G
oooo001aoooo1P1VoaSoool00`000?ooo`1Vo`0206Ko<_ooo`0306Kooooooooo05Ooool006coool5
06Ko7_ooo`030000oooooooo03Coool00`1Vooooooooo`1Goooo001Yoooo0`1Vob?oool20000=Ooo
o`0306Kooooooooo05Ooool001Ooool40000>Oooo`D0000>oooo0P1VobKoool00`000?ooooooo`0e
oooo00<0I_ooool00000100003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0<oooo0P1VobSoool00`000?ooooooo`0eoooo00D0I_ooooooooooool00000>_ooo`030000
oooooooo01Ooool001Soool00`000?ooooooo`0koooo00<0003oooooool02_ooo`80I_lZoooo00<0
003oooooool0=Oooo`0506Kooooooooooooo000003_oool00`000?ooooooo`0Foooo000Aoooo1000
00Coool00`000?ooooooo`0boooo100000Coool00`000?ooooooo`09oooo00<0I_ooooooool0:_oo
o`030000oooooooo03Goool01@1Vooooooooooooo`00000loooo00<0003oooooool05Oooo`005ooo
o`040000oooooooo0000>oooo`030000oooooooo00Ooool206Ko;Oooo`030000oooooooo03Goool0
1@1Vooooooooooooo`00000joooo00@0003oooooool0000Foooo000Hoooo0P0003_oool200001ooo
o`80I_l_oooo0P0003Koool00`1Vooooooooo`020000>oooo`80000Goooo001Moooo00<0I_oooooo
ool0;oooo`030000oooooooo03Goool00`1Vooooooooo`1Foooo001Loooo00<0I_ooooooool0<?oo
o`030000oooooooo03Goool00`1Vooooooooo`1Foooo001Koooo00<0I_ooooooool0<Oooo`030000
oooooooo03Goool00`1Vooooooooo`1Foooo001Joooo00<0I_ooooooool0<_ooo`030000oooooooo
03Goool00`1Vooooooooo`1Foooo001Ioooo00<0I_ooooooool0<oooo`030000oooooooo03Goool0
0`1Vooooooooo`1Foooo000@ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000@co`000ol0VC?o03?o0002<ol000<0000co`0c
o`001S?o02800006oooo00<0003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol003@co`000ol0VC?o03?o0002<ol02@00
03Coool00`000?ooooooo`0Eoooo002?oooo00<0000co`0co`00<c?o00030000o`2I000000<0001E
oooo002?oooo00<0000co`0co`00<C?o008000000oooool0VOooo`1Hoooo002?oooo00<0000co`0c
o`00;c?o00800003oooo00?o09Woooooool0Eoooo`00Soooo`030000<ol0<ol002`co`0300001Ooo
o`03o`2Ioooooooo05Ooool008ooool20000:S?o00<00008oooo00?o09Woooooool0Eoooo`00Sooo
o`030000<ol0<ol002Lco`0200002oooo`03o`2Ioooooooo05Ooool008ooool00`0003?o03?o000V
<ol000<0003oooooool02oooo`03o`2Ioooooooo05Ooool008ooool00`0003?o03?o000U<ol000<0
003oooooool03?ooo`03o`2Ioooooooo05Ooool008ooool00`0003?o03?o000T<ol000<0003ooooo
ool03Oooo`03o`2Ioooooooo05Ooool008ooool00`0003?o03?o000R<ol00P00013oool00ol0VOoo
ooooo`1Goooo002?oooo0P00028co`000`000?ooooooo`0@oooo00?o09Woooooool0Eoooo`00Sooo
o`030000<ol0<ol0020co`000`000?ooooooo`0Aoooo00?o09Woooooool0Eoooo`00Soooo`030000
<ol0<ol001lco`000`000?ooooooo`0Boooo00?o09Woooooool0Eoooo`00Soooo`030000<ol0<ol0
01lco`000`000?ooooooo`0Boooo00?o09Woooooool0Eoooo`00Soooo`030000<ol0<ol001hco`00
0`000?ooooooo`0Coooo00?o09Woooooool0Eoooo`00Soooo`030000<ol0<ol001dco`000`000?oo
ooooo`0Doooo00?o09Woooooool0Eoooo`00Soooo`80000M<ol000<0003oooooool05Oooo`03o`2I
oooooooo05Ooool008ooool00`0003?o03?o000K<ol000<0003oooooool05_ooo`03o`2Ioooooooo
05Ooool008ooool00`0003?o03?o000K<ol000<0003oooooool05_ooo`03o`2Ioooooooo05Ooool0
08ooool00`0003?o03?o000J<ol000<0003oooooool05oooo`03o`2Ioooooooo05Ooool008ooool0
0`0003?o03?o000J<ol000<0003oooooool05oooo`03o`2Ioooooooo05Ooool008ooool00`0003?o
03?o000I<ol000<0003oooooool06?ooo`03o`2Ioooooooo05Ooool008ooool200006S?o00030000
oooooooo01Soool00ol0VOooooooo`1Goooo002?oooo00<0000co`0co`0063?o00030000oooooooo
01Woool00ol0VOooooooo`1Goooo002?oooo00<0000co`0co`0063?o00030000oooooooo01Woool0
0ol0VOooooooo`1Goooo002?oooo00<0000co`0co`005c?o00030000oooooooo01[oool00ol0VOoo
ooooo`1Goooo002?oooo00<0000co`0co`005c?o00030000oooooooo01[oool00ol0VOooooooo`1G
oooo0027oooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool06oooo`03o`2Ioooooooo
05Ooool008Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo01_oool0
0ol0VOooooooo`1Goooo0029oooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool07?oo
o`03o`2Ioooooooo05Ooool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000
oooooooo01coool00ol0VOooooooo`1Goooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`0Loooo00?o09Woooooool0Eoooo`00R?ooo`800005oooo00<0000co`0c
o`0053?o00030000oooooooo01goool00ol0VOooooooo`1Goooo002?oooo00<0000co`0co`0053?o
00030000oooooooo01goool00ol0VOooooooo`1Goooo002?oooo00<0000co`0co`004c?o00030000
oooooooo01koool00ol0VOooooooo`1Goooo002?oooo0P0001@co`000`000?ooooooo`0Noooo00?o
09Woooooool0Eoooo`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`0Noooo00?o09Wooooo
ool0Eoooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Ooooo00?o09Woooooool0Eooo
o`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0Ooooo00?o09Woooooool0Eoooo`00Sooo
o`030000<ol0<ol0018co`000`000?ooooooo`0Ooooo00?o09Woooooool0Eoooo`00Soooo`030000
<ol0<ol0014co`000`000?ooooooo`0Poooo00?o09Woooooool0Eoooo`00Soooo`80000B<ol000<0
003oooooool08?ooo`03o`2Ioooooooo05Ooool008ooool00`0003?o03?o000A<ol000<0003ooooo
ool08?ooo`03o`2Ioooooooo05Ooool008ooool00`0003?o03?o000A<ol000<0003oooooool08?oo
o`03o`2Ioooooooo05Ooool008ooool00`0003?o03?o000@<ol000<0003oooooool08Oooo`03o`2I
oooooooo05Ooool008ooool00`0003?o03?o000@<ol000<0003oooooool08Oooo`03o`2Ioooooooo
05Ooool008ooool00`0003?o03?o000@<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Ooool0
08ooool00`0003?o03?o000@<ol000<0003oooooool08Oooo`03o`2Ioooooooo05Ooool008ooool2
000043?o00030000oooooooo02;oool00ol0VOooooooo`1Goooo002?oooo00<0000co`0co`003c?o
00030000oooooooo02;oool00ol0VOooooooo`1Goooo002?oooo00<0000co`0co`003c?o00030000
oooooooo02;oool00ol0VOooooooo`1Goooo002?oooo00<0000co`0co`003c?o00030000oooooooo
02;oool00ol0VOooooooo`1Goooo002?oooo00<0000co`0co`003c?o00030000oooooooo02;oool0
0ol0VOooooooo`1Goooo002?oooo00<0000co`0co`003S?o00030000oooooooo02?oool00ol0VOoo
ooooo`1Goooo002?oooo0P0000lco`000`000?ooooooo`0Soooo00?o09Woooooool0Eoooo`00Sooo
o`030000<ol0<ol000hco`000`000?ooooooo`0Soooo00?o09Woooooool0Eoooo`00Soooo`030000
<ol0<ol000hco`000`000?ooooooo`0Soooo00?o09Woooooool0Eoooo`00Soooo`030000<ol0<ol0
00dco`000`000?ooooooo`0Toooo00?o09Woooooool0Eoooo`00Qoooo`@00004oooo00<0000co`0c
o`003C?o00030000oooooooo02Coool00ol0VOooooooo`1Goooo0027oooo00<0003oooooool01Ooo
o`030000<ol0<ol000dco`000`000?ooooooo`0Toooo00?o09Woooooool0Eoooo`00R?ooo`030000
oooooooo00Coool300003C?o00030000oooooooo02Coool00ol0VOooooooo`1Goooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`0Uoooo00?o09Woooooool0E_oo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`0Voooo00?o
09Woooooool0E_ooo`00R?ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo02Koool0
0ol0VOooooooo`1Foooo002?oooo00<0000co`0co`0033?o00030000oooooooo02Koool00ol0VOoo
ooooo`1Foooo002?oooo00<0000co`0co`0033?o00030000oooooooo02Koool00ol0VOooooooo`1F
oooo002?oooo0P0000dco`000`000?ooooooo`0Voooo00?o09Woooooool0E_ooo`00Soooo`030000
<ol0<ol000`co`000`000?ooooooo`0Voooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`0Woooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`0Woooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`0Woooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0W
oooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0Woooo00?o
09Woooooool0E_ooo`00Soooo`80000<<ol000<0003oooooool09oooo`03o`2Ioooooooo05Koool0
08ooool00`0003?o03?o000;<ol000<0003oooooool09oooo`03o`2Ioooooooo05Koool008ooool0
0`0003?o03?o000:<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05Koool008ooool00`0003?o
03?o000:<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o000:
<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o000:<ol000<0
003oooooool0:?ooo`03o`2Ioooooooo05Koool008ooool200002c?o00030000oooooooo02Soool0
0ol0VOooooooo`1Foooo002?oooo00<0000co`0co`002S?o00030000oooooooo02Soool00ol0VOoo
ooooo`1Foooo002?oooo00<0000co`0co`002S?o00030000oooooooo02Soool00ol0VOooooooo`1F
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo02Woool00ol0VOooooooo`1Foooo002?
oooo00<0000co`0co`002C?o00030000oooooooo02Woool00ol0VOooooooo`1Foooo002?oooo00<0
000co`0co`002C?o00030000oooooooo02Woool00ol0VOooooooo`1Foooo002?oooo0P0000Xco`00
0`000?ooooooo`0Yoooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol000Tco`000`000?oo
ooooo`0Yoooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0Y
oooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol000Pco`000`000?ooooooo`0Zoooo00?o
09Woooooool0E_ooo`00R?ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo02[oool0
0ol0VOooooooo`1Foooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000
oooooooo02[oool00ol0VOooooooo`1Foooo0029oooo00<0003oooooool00oooo`<00008<ol000<0
003oooooool0:_ooo`03o`2Ioooooooo05Koool008[oool00`000?ooooooo`02oooo00<0000co`0c
o`0023?o00030000oooooooo02[oool00ol0VOooooooo`1Foooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0023?o00030000oooooooo02[oool00ol0VOooooooo`1Foooo0028oooo0P00
00Goool00`0003?o03?o0007<ol000<0003oooooool0:oooo`03o`2Ioooooooo05Koool008ooool0
0`0003?o03?o0007<ol000<0003oooooool0:oooo`03o`2Ioooooooo05Koool008ooool00`0003?o
03?o0007<ol000<0003oooooool0:oooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o0007
<ol000<0003oooooool0:oooo`03o`2Ioooooooo05Koool008ooool2000023?o00030000oooooooo
02_oool00ol0VOooooooo`1Foooo002?oooo00<0000co`0co`001c?o00030000oooooooo02_oool0
0ol0VOooooooo`1Foooo002?oooo00<0000co`0co`001c?o00030000oooooooo02_oool00ol0VOoo
ooooo`1Foooo002?oooo00<0000co`0co`001c?o00030000oooooooo02_oool00ol0VOooooooo`1F
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo02coool00ol0VOooooooo`1Foooo002?
oooo00<0000co`0co`001S?o00030000oooooooo02coool00ol0VOooooooo`1Foooo002?oooo0P00
00Lco`000`000?ooooooo`0/oooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol000Hco`00
0`000?ooooooo`0/oooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`0/oooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0/
oooo00?o09Woooooool0E_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0/oooo00?o
09Woooooool0E_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0/oooo00?o09Wooooo
ool0E_ooo`00Soooo`800006<ol000<0003oooooool0;Oooo`03o`2Ioooooooo05Koool008ooool0
0`0003?o03?o0005<ol000<0003oooooool0;Oooo`03o`2Ioooooooo05Koool008ooool00`0003?o
03?o0005<ol000<0003oooooool0;Oooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o0005
<ol000<0003oooooool0;Oooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o0005<ol000<0
003oooooool0;Oooo`03o`2Ioooooooo05Koool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool0;Oooo`03o`2Ioooooooo05Koool008ooool200001S?o00030000oooooooo02goool00ol0VOoo
ooooo`1Foooo002?oooo00<0000co`0co`001C?o00030000oooooooo02goool00ol0VOooooooo`1F
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo02goool00ol0VOooooooo`1Foooo002?
oooo00<0000co`0co`0013?o00030000oooooooo02koool00ol0VOooooooo`1Foooo002?oooo00<0
000co`0co`0013?o00030000oooooooo02koool00ol0VOooooooo`1Foooo0029oooo0`0000?oool0
0`0003?o03?o0004<ol000<0003oooooool0;_ooo`03o`2Ioooooooo05Koool008[oool00`000?oo
ooooo`02oooo00<0000co`0co`0013?o00030000oooooooo02koool00ol0VOooooooo`1Foooo0027
oooo1@0000?oool3000013?o00030000oooooooo02koool00ol0VOooooooo`1Foooo0027oooo00@0
003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool2
00001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo
01?oool7<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool02Oooo`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool500000S?o008000000c?o0?ooooooo`0300000oooo`@00003oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01oooo`030000<ol0<ol000Dco`04oooo00D0003oooooooooool000001_ooo`030000
oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000<ol0<ol0
00Dco`03oooo0`0000?oool00`000?ooooooo`04oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000>oooo00<0000co`0co`001C?o00;oool010000?ooooooo`0000Coool00`000?oo
ooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000017oool00`0003?o
03?o0005<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`03oooo0`0000?oool200000oooo`030000
oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.94) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.70787 .12361 L
.71741 .12361 L
.71998 .12361 L
.72138 .12361 L
.72269 .12361 L
.72338 .12361 L
s
.72338 .12361 m
.72367 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.26171 .12361 L
.26709 .12361 L
.27003 .12361 L
.27279 .12361 L
.27399 .12361 L
.27513 .12361 L
.27645 .12334 L
.27765 .1221 L
.28302 .11682 L
.30316 .09997 L
.32296 .08738 L
.34135 .07859 L
.35192 .07461 L
.36187 .07147 L
.38048 .06702 L
.39024 .06533 L
.40056 .06395 L
.40936 .06307 L
.41436 .06269 L
.41903 .06239 L
.42403 .06215 L
.42667 .06205 L
.42948 .06196 L
.43192 .0619 L
.43322 .06188 L
.43462 .06185 L
.4359 .06183 L
.43708 .06182 L
.4382 .06181 L
.43938 .06181 L
.44054 .0618 L
.4416 .0618 L
.44282 .06181 L
.44397 .06181 L
.44504 .06182 L
.44602 .06183 L
.44824 .06186 L
.45049 .06189 L
.45295 .06195 L
.45794 .06209 L
.46315 .06228 L
.4681 .06251 L
.47738 .06303 L
Mistroke
.4875 .06373 L
.49828 .06461 L
.50086 .06483 L
.50364 .06504 L
.50627 .06518 L
.50753 .06523 L
.50869 .06528 L
.50984 .06531 L
.51088 .06533 L
.51204 .06535 L
.51328 .06536 L
.51447 .06537 L
.51577 .06536 L
.51699 .06535 L
.51812 .06534 L
.51918 .06532 L
.52031 .06529 L
.52237 .06523 L
.52481 .06513 L
.52705 .06502 L
.53652 .06435 L
.54635 .06337 L
.55548 .06225 L
.5762 .05912 L
.6153 .0518 L
.65685 .04317 L
.67769 .03888 L
.69688 .03511 L
.70656 .03332 L
.7156 .03174 L
.72015 .03098 L
.72146 .03076 L
.72271 .03056 L
.72382 .12361 L
.72504 .12361 L
.7354 .12361 L
.77615 .12361 L
.81538 .12361 L
.8531 .12361 L
.89327 .12361 L
.93193 .12361 L
.97303 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.94) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0coooo0`1VoeSoool0
08ooool00`000?ooooooo`0]oooo1P1Vo`;oool00`1Vooooooooo`1Foooo002?oooo00<0003ooooo
ool0:?ooo`D0I_l8oooo00<0I_ooooooool0E_ooo`00Soooo`030000oooooooo02?oool506Ko3Ooo
o`0306Kooooooooo05Koool008ooool00`000?ooooooo`0Moooo1P1Voa;oool00`1Vooooooooo`1F
oooo002?oooo0P0001Woool506Ko6?ooo`0306Kooooooooo05Koool008ooool00`000?ooooooo`0C
oooo1@1Voagoool00`1Vooooooooo`1Foooo002?oooo00<0003oooooool03_ooo`D0I_lRoooo00<0
I_ooooooool0E_ooo`00MOoooaX0I_l00`000?ooooooo`06oooo201VobOoool00`1Vooooooooo`1F
oooo001_oooo1P1Voa[oool00`00001Vo`1Vo`0606Ko;oooo`0306Kooooooooo05Koool006_oool4
06Ko8?ooo`030000oooooooo03Goool00`1Vooooooooo`1Foooo001Yoooo0P1VobCoool20000=_oo
o`0306Kooooooooo05Koool001Ooool40000>Oooo`D0000=oooo0`1VobKoool00`000?ooooooo`0f
oooo00<0I_l0000000000`0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?oo
ooooo`0;oooo0P1VobWoool00`000?ooooooo`0foooo00@0I_ooooooool0000joooo00<0003ooooo
ool05oooo`006?ooo`030000oooooooo03_oool00`000?ooooooo`09oooo0P1Vob_oool00`000?oo
ooooo`0foooo00@0I_ooooooool0000koooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0
003oooooool0<_ooo`@00004oooo00<0003oooooool01oooo`80I_l]oooo00<0003oooooool0=_oo
o`0406Kooooooooo0000??ooo`030000oooooooo01Goool001Ooool010000?ooooooo`0003_oool0
0`000?ooooooo`05oooo0P1Vobooool00`000?ooooooo`0foooo00@0I_ooooooool0000joooo00@0
003oooooool0000Foooo000Hoooo0P0003_oool200001_ooo`0306Kooooooooo02ooool20000=ooo
o`0406Kooooo00000000>oooo`80000Goooo001Loooo00<0I_ooooooool0<?ooo`030000oooooooo
03Koool00`1Vooooooooo`1Eoooo001Koooo00<0I_ooooooool0<Oooo`030000oooooooo03Koool0
0`1Vooooooooo`1Eoooo001Joooo00<0I_ooooooool0<_ooo`030000oooooooo03Koool00`1Voooo
ooooo`1Eoooo001Ioooo00<0I_ooooooool0<oooo`030000oooooooo03Koool00`1Vooooooooo`1E
oooo001Hoooo00<0I_ooooooool0=?ooo`030000oooooooo03Koool00`1Vooooooooo`1Eoooo000@
ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Hco`001?l0VC?o03?o000000Pco`0R00001_ooo`030000oooooooo00Woool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o
03?o000f<ol000?o09Tco`0co`002@0003Coool00`000?ooooooo`0Eoooo002?oooo00<0000co`0c
o`00<c?o00<000000ol0V@000000001Eoooo002?oooo00<0000co`0co`00<C?o00800003oooo00?o
09Woooooool0EOooo`00Soooo`030000<ol0<ol002lco`0200001Oooo`03o`2Ioooooooo05Goool0
08ooool00`0003?o03?o000/<ol00`0000Ooool00ol0VOooooooo`1Eoooo002?oooo0P0002Xco`03
00002_ooo`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000W<ol00P0000goool00ol0VOoo
ooooo`1Eoooo002?oooo00<0000co`0co`009S?o00030000oooooooo00goool00ol0VOooooooo`1E
oooo002?oooo00<0000co`0co`009C?o00030000oooooooo00koool00ol0VOooooooo`1Eoooo002?
oooo00<0000co`0co`0093?o00030000oooooooo00ooool00ol0VOooooooo`1Eoooo002?oooo00<0
000co`0co`008S?o0080000Boooo00?o09Woooooool0EOooo`00Soooo`80000R<ol000<0003ooooo
ool04_ooo`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000P<ol000<0003oooooool04ooo
o`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000O<ol000<0003oooooool05?ooo`03o`2I
oooooooo05Goool008ooool00`0003?o03?o000O<ol000<0003oooooool05?ooo`03o`2Ioooooooo
05Goool008ooool00`0003?o03?o000N<ol000<0003oooooool05Oooo`03o`2Ioooooooo05Goool0
08ooool00`0003?o03?o000M<ol000<0003oooooool05_ooo`03o`2Ioooooooo05Goool008ooool2
00007C?o00030000oooooooo01Ooool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`006c?o
00030000oooooooo01Soool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`006c?o00030000
oooooooo01Soool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`006S?o00030000oooooooo
01Woool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`006S?o00030000oooooooo01Woool0
0ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`006C?o00030000oooooooo01[oool00ol0VOoo
ooooo`1Eoooo002?oooo0P0001Xco`000`000?ooooooo`0Joooo00?o09Woooooool0EOooo`00Sooo
o`030000<ol0<ol001Pco`000`000?ooooooo`0Koooo00?o09Woooooool0EOooo`00Soooo`030000
<ol0<ol001Pco`000`000?ooooooo`0Koooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol0
01Lco`000`000?ooooooo`0Loooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol001Lco`00
0`000?ooooooo`0Loooo00?o09Woooooool0EOooo`00Qoooo`D00003oooo00<0000co`0co`005S?o
00030000oooooooo01goool00ol0VOooooooo`1Eoooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol001Hco`000`000?ooooooo`0Moooo00?o09Woooooool0EOooo`00ROooo`030000oooooooo
00?oool300005C?o00030000oooooooo01koool00ol0VOooooooo`1Eoooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`0Noooo00?o09Woooooool0EOooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool07_ooo`03o`2Ioooooooo
05Goool008Soool200001Oooo`030000<ol0<ol001@co`000`000?ooooooo`0Ooooo00?o09Wooooo
ool0EOooo`00Soooo`030000<ol0<ol001@co`000`000?ooooooo`0Ooooo00?o09Woooooool0EOoo
o`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`0Poooo00?o09Woooooool0EOooo`00Sooo
o`80000D<ol000<0003oooooool08?ooo`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000C
<ol000<0003oooooool08?ooo`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000B<ol000<0
003oooooool08Oooo`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000B<ol000<0003ooooo
ool08Oooo`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000B<ol000<0003oooooool08Ooo
o`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000A<ol000<0003oooooool08_ooo`03o`2I
oooooooo05Goool008ooool200004S?o00030000oooooooo02;oool00ol0VOooooooo`1Eoooo002?
oooo00<0000co`0co`004C?o00030000oooooooo02;oool00ol0VOooooooo`1Eoooo002?oooo00<0
000co`0co`004C?o00030000oooooooo02;oool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0c
o`0043?o00030000oooooooo02?oool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`0043?o
00030000oooooooo02?oool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`0043?o00030000
oooooooo02?oool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`0043?o00030000oooooooo
02?oool00ol0VOooooooo`1Eoooo002?oooo0P00010co`000`000?ooooooo`0Toooo00?o09Wooooo
ool0EOooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0Toooo00?o09Woooooool0EOoo
o`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0Toooo00?o09Woooooool0EOooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`0Toooo00?o09Woooooool0EOooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`0Toooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol0
00hco`000`000?ooooooo`0Uoooo00?o09Woooooool0EOooo`00Soooo`80000?<ol000<0003ooooo
ool09Oooo`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000><ol000<0003oooooool09Ooo
o`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000><ol000<0003oooooool09Oooo`03o`2I
oooooooo05Goool008ooool00`0003?o03?o000=<ol000<0003oooooool09_ooo`03o`2Ioooooooo
05Goool008Ooool400001?ooo`030000<ol0<ol000dco`000`000?ooooooo`0Voooo00?o09Wooooo
ool0EOooo`00Qoooo`030000oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool09_oo
o`03o`2Ioooooooo05Goool008Soool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`0V
oooo00?o09Woooooool0EOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0
003oooooool09_ooo`03o`2Ioooooooo05Goool008Ooool010000?ooooooo`0000Coool00`0003?o
03?o000<<ol000<0003oooooool09oooo`03o`2Ioooooooo05Goool008Soool200001Oooo`030000
<ol0<ol000`co`000`000?ooooooo`0Woooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol0
00`co`000`000?ooooooo`0Woooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol000`co`00
0`000?ooooooo`0Woooo00?o09Woooooool0EOooo`00Soooo`80000=<ol000<0003oooooool09ooo
o`03o`2Ioooooooo05Goool008ooool00`0003?o03?o000<<ol000<0003oooooool09oooo`03o`2I
oooooooo05Goool008ooool00`0003?o03?o000;<ol000<0003oooooool0:?ooo`03o`2Ioooooooo
05Goool008ooool00`0003?o03?o000;<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05Goool0
08ooool00`0003?o03?o000;<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05Goool008ooool0
0`0003?o03?o000;<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05Goool008ooool00`0003?o
03?o000;<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05Goool008ooool2000033?o00030000
oooooooo02Soool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`002c?o00030000oooooooo
02Soool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`002S?o00030000oooooooo02Woool0
0ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`002S?o00030000oooooooo02Woool00ol0VOoo
ooooo`1Eoooo002?oooo00<0000co`0co`002S?o00030000oooooooo02Woool00ol0VOooooooo`1E
oooo002?oooo00<0000co`0co`002S?o00030000oooooooo02Woool00ol0VOooooooo`1Eoooo002?
oooo0P0000/co`000`000?ooooooo`0Yoooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0Yoooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0Yoooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol000Tco`000`000?oo
ooooo`0Zoooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0Z
oooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0Zoooo00?o
09Woooooool0EOooo`00Soooo`80000:<ol000<0003oooooool0:_ooo`03o`2Ioooooooo05Goool0
08ooool00`0003?o03?o0009<ol000<0003oooooool0:_ooo`03o`2Ioooooooo05Goool008ooool0
0`0003?o03?o0009<ol000<0003oooooool0:_ooo`03o`2Ioooooooo05Goool008ooool00`0003?o
03?o0008<ol000<0003oooooool0:oooo`03o`2Ioooooooo05Goool008Soool200001Oooo`030000
<ol0<ol000Pco`000`000?ooooooo`0[oooo00?o09Woooooool0EOooo`00Qoooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0[oooo00?o09Woooooool0EOooo`00ROoo
o`030000oooooooo00?oool3000023?o00030000oooooooo02_oool00ol0VOooooooo`1Eoooo002:
oooo00<0003oooooool00_ooo`030000<ol0<ol000Pco`000`000?ooooooo`0[oooo00?o09Wooooo
ool0EOooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0[
oooo00?o09Woooooool0EOooo`00R?ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo
02coool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`001c?o00030000oooooooo02coool0
0ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`001c?o00030000oooooooo02coool00ol0VOoo
ooooo`1Eoooo002?oooo00<0000co`0co`001c?o00030000oooooooo02coool00ol0VOooooooo`1E
oooo002?oooo0P0000Pco`000`000?ooooooo`0/oooo00?o09Woooooool0EOooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`0/oooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0/oooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0/oooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`0]oooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0]
oooo00?o09Woooooool0EOooo`00Soooo`800007<ol000<0003oooooool0;Oooo`03o`2Ioooooooo
05Goool008ooool00`0003?o03?o0006<ol000<0003oooooool0;Oooo`03o`2Ioooooooo05Goool0
08ooool00`0003?o03?o0006<ol000<0003oooooool0;Oooo`03o`2Ioooooooo05Goool008ooool0
0`0003?o03?o0006<ol000<0003oooooool0;Oooo`03o`2Ioooooooo05Goool008ooool00`0003?o
03?o0006<ol000<0003oooooool0;Oooo`03o`2Ioooooooo05Goool008ooool00`0003?o03?o0006
<ol000<0003oooooool0;Oooo`03o`2Ioooooooo05Goool008ooool200001S?o00030000oooooooo
02koool00ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`001C?o00030000oooooooo02koool0
0ol0VOooooooo`1Eoooo002?oooo00<0000co`0co`001C?o00030000oooooooo02koool00ol0VOoo
ooooo`1Eoooo002?oooo00<0000co`0co`001C?o00030000oooooooo02koool00ol0VOooooooo`1E
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo02koool00ol0VOooooooo`1Eoooo002?
oooo00<0000co`0co`001C?o00030000oooooooo02koool00ol0VOooooooo`1Eoooo002?oooo0P00
00Hco`000`000?ooooooo`0^oooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`0^oooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`0^oooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0_
oooo00?o09Woooooool0EOooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0_oooo00?o
09Woooooool0EOooo`00ROooo`<00003oooo00<0000co`0co`0013?o00030000oooooooo02ooool0
0ol0VOooooooo`1Eoooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?oo
ooooo`0_oooo00?o09Woooooool0EOooo`00Qoooo`D00003oooo0`0000@co`000`000?ooooooo`0_
oooo00?o09Woooooool0EOooo`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0
003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?
oooo1c?o08[oool007Woool00`000?ooooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo00Woool7<ol03oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@00008co`02000000<c
o`3oooooool00`0000Goool300000_ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`0003?o03?o0005<ol01?oo
o`030000oooooooo00Coool01@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_oo
o`030000oooooooo00ooool00`0003?o03?o0005<ol00oooo`<00002oooo1@0000?oool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0000koool00`0003?o03?o0005<ol00_ooo`040000
oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`00000Aoooo00<0000co`0co`001C?o00;oool010000?ooooooo`0000?oool00`000?oo
o`000003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200001c?o00?oool3
00001?ooo`800002oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.96) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71741 .12361 L
.72307 .12361 L
.72585 .12361 L
.72707 .12361 L
.72772 .12361 L
.72841 .12361 L
s
.72841 .12361 m
.72889 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.25127 .12361 L
.26171 .12361 L
.26698 .12361 L
.26843 .12361 L
.26922 .12361 L
.26998 .12361 L
.27068 .12361 L
.27145 .12359 L
.27214 .12287 L
.27279 .12221 L
.28302 .11242 L
.30316 .09661 L
.32368 .08449 L
.34228 .07635 L
.36153 .07026 L
.37238 .0677 L
.38235 .06583 L
.39209 .0644 L
.40118 .06338 L
.41115 .06258 L
.41674 .06226 L
.41916 .06215 L
.42184 .06205 L
.42415 .06198 L
.42665 .06191 L
.42802 .06188 L
.42928 .06186 L
.43056 .06184 L
.43175 .06183 L
.43278 .06182 L
.43389 .06181 L
.43511 .06181 L
.43622 .0618 L
.43738 .0618 L
.43864 .06181 L
.43983 .06182 L
.44092 .06182 L
.44212 .06184 L
.4434 .06185 L
.44573 .06189 L
.44849 .06195 L
.45101 .06202 L
.45648 .06221 L
Mistroke
.46168 .06243 L
.4713 .06295 L
.48153 .06364 L
.49112 .0644 L
.49993 .06519 L
.50253 .06541 L
.50495 .06557 L
.50747 .0657 L
.50881 .06575 L
.51024 .0658 L
.51168 .06583 L
.51249 .06584 L
.51324 .06585 L
.51389 .06586 L
.51461 .06586 L
.51537 .06587 L
.51607 .06586 L
.51672 .06586 L
.51741 .06586 L
.51863 .06584 L
.51994 .06582 L
.52138 .06578 L
.52403 .0657 L
.52644 .06559 L
.53184 .06528 L
.53685 .06491 L
.54156 .06449 L
.56162 .06208 L
.58008 .0592 L
.61954 .05176 L
.65748 .04389 L
.6786 .03953 L
.69787 .03571 L
.70742 .03392 L
.71783 .03206 L
.72259 .03126 L
.7252 .03083 L
.72648 .03062 L
.72765 .03043 L
.72866 .12361 L
.72973 .12361 L
.73197 .12361 L
.73675 .12361 L
.77482 .12361 L
.81535 .12361 L
.85436 .12361 L
.89583 .12361 L
.93578 .12361 L
.97421 .12361 L
.97619 .12361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.96) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0doooo101VoeKoool0
08ooool00`000?ooooooo`0]oooo1`1Vo`?oool00`1Vooooooooo`1Doooo002?oooo00<0003ooooo
ool0:?ooo`D0I_l:oooo00<0I_ooooooool0E?ooo`00Soooo`030000oooooooo02?oool506Ko3ooo
o`0306Kooooooooo05Coool008ooool00`000?ooooooo`0Noooo1@1VoaCoool00`1Vooooooooo`1D
oooo002?oooo0P0001[oool506Ko6Oooo`0306Kooooooooo05Coool008ooool00`000?ooooooo`0D
oooo1@1Voakoool00`1Vooooooooo`1Doooo002?oooo00<0003oooooool04?ooo`@0I_lSoooo00<0
I_ooooooool0E?ooo`00Looooa/0I_l00oooo`000?ooo`09oooo201VobOoool00`1Vooooooooo`1D
oooo001^oooo1@1Voa_oool00`1Vo`00001Vo`0906Ko;oooo`0306Kooooooooo05Coool006[oool4
06Ko8Oooo`030000oooooooo03Ooool00`1Vooooooooo`1Doooo001Voooo101VobGoool20000>?oo
o`0306Kooooooooo05Coool001Ooool40000>Oooo`D0000;oooo0P1VobWoool00`000?ooooooo`0g
oooo1@0003Soool400005_ooo`005oooo`030000oooooooo03coool00`000?ooooooo`09oooo0P1V
ob_oool00`000?ooooooo`0goooo00<0I_ooool00000>_ooo`030000oooooooo01Ooool001Soool0
0`000?ooooooo`0koooo00<0003oooooool02?ooo`0306Kooooooooo02_oool00`000?ooooooo`0g
oooo00<0I_ooool00000>oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo
03;oool400001?ooo`030000oooooooo00Koool206Ko;_ooo`030000oooooooo03Ooool00`1Voooo
o`00000loooo00<0003oooooool05Oooo`005oooo`040000oooooooo0000>oooo`030000oooooooo
00Goool00`1Vooooooooo`0^oooo00<0003oooooool0=oooo`0306Kooooo000003[oool010000?oo
ooooo`0001Koool001Soool20000>oooo`800006oooo00<0I_ooooooool0;oooo`80000hoooo00<0
I_l000000000>oooo`80000Goooo001Loooo00<0I_ooooooool0<?ooo`030000oooooooo03Ooool0
0`1Vooooooooo`1Doooo001Joooo0P1Voc?oool00`000?ooooooo`0goooo00<0I_ooooooool0E?oo
o`00FOooo`0306Kooooooooo03?oool00`000?ooooooo`0goooo00<0I_ooooooool0E?ooo`00F?oo
o`0306Kooooooooo03Coool00`000?ooooooo`0goooo00<0I_ooooooool0E?ooo`00E_ooo`80I_lg
oooo00<0003oooooool0=oooo`0306Kooooooooo05Coool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001c?o0003o`2I
<ol0000000Pco`0R00001_ooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000g<ol000?o09Tco`0000002000
03Coool00`000?ooooooo`0Eoooo002?oooo00<0000co`0co`00<c?o00@000000ol0V@000?ooo`1D
oooo002?oooo00<0000co`0co`00<C?o00800004oooo00?o09Woooooool0E?ooo`00Soooo`030000
<ol0<ol002lco`0200001_ooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o000/<ol00`00
00Soool00ol0VOooooooo`1Doooo002?oooo0P0002Xco`0300002oooo`03o`2Ioooooooo05Coool0
08ooool00`0003?o03?o000W<ol00P0000koool00ol0VOooooooo`1Doooo002?oooo00<0000co`0c
o`009S?o00030000oooooooo00koool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`009C?o
00030000oooooooo00ooool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`0093?o00030000
oooooooo013oool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`008S?o0080000Coooo00?o
09Woooooool0E?ooo`00Soooo`80000R<ol000<0003oooooool04oooo`03o`2Ioooooooo05Coool0
08ooool00`0003?o03?o000P<ol000<0003oooooool05?ooo`03o`2Ioooooooo05Coool008ooool0
0`0003?o03?o000O<ol000<0003oooooool05Oooo`03o`2Ioooooooo05Coool008ooool00`0003?o
03?o000O<ol000<0003oooooool05Oooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o000N
<ol000<0003oooooool05_ooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o000M<ol000<0
003oooooool05oooo`03o`2Ioooooooo05Coool008ooool200007C?o00030000oooooooo01Soool0
0ol0VOooooooo`1Doooo002?oooo00<0000co`0co`006c?o00030000oooooooo01Woool00ol0VOoo
ooooo`1Doooo002?oooo00<0000co`0co`006c?o00030000oooooooo01Woool00ol0VOooooooo`1D
oooo002?oooo00<0000co`0co`006S?o00030000oooooooo01[oool00ol0VOooooooo`1Doooo002?
oooo00<0000co`0co`006S?o00030000oooooooo01[oool00ol0VOooooooo`1Doooo002?oooo00<0
000co`0co`006C?o00030000oooooooo01_oool00ol0VOooooooo`1Doooo002?oooo0P0001Xco`00
0`000?ooooooo`0Koooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol001Pco`000`000?oo
ooooo`0Loooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0L
oooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0Moooo00?o
09Woooooool0E?ooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0Moooo00?o09Wooooo
ool0E?ooo`00Qoooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo01koool00ol0VOoo
ooooo`1Doooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`0N
oooo00?o09Woooooool0E?ooo`00ROooo`030000oooooooo00?oool300005C?o00030000oooooooo
01ooool00ol0VOooooooo`1Doooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`0Ooooo00?o09Woooooool0E?ooo`00ROooo`030000oooooooo00?oool00`0003?o
03?o000E<ol000<0003oooooool07oooo`03o`2Ioooooooo05Coool008Soool200001Oooo`030000
<ol0<ol001@co`000`000?ooooooo`0Poooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol0
01@co`000`000?ooooooo`0Poooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol001<co`00
0`000?ooooooo`0Qoooo00?o09Woooooool0E?ooo`00Soooo`80000D<ol000<0003oooooool08Ooo
o`03o`2Ioooooooo05Coool008ooool00`0003?o03?o000C<ol000<0003oooooool08Oooo`03o`2I
oooooooo05Coool008ooool00`0003?o03?o000B<ol000<0003oooooool08_ooo`03o`2Ioooooooo
05Coool008ooool00`0003?o03?o000B<ol000<0003oooooool08_ooo`03o`2Ioooooooo05Coool0
08ooool00`0003?o03?o000B<ol000<0003oooooool08_ooo`03o`2Ioooooooo05Coool008ooool0
0`0003?o03?o000A<ol000<0003oooooool08oooo`03o`2Ioooooooo05Coool008ooool200004S?o
00030000oooooooo02?oool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`004C?o00030000
oooooooo02?oool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`004C?o00030000oooooooo
02?oool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`0043?o00030000oooooooo02Coool0
0ol0VOooooooo`1Doooo002?oooo00<0000co`0co`0043?o00030000oooooooo02Coool00ol0VOoo
ooooo`1Doooo002?oooo00<0000co`0co`0043?o00030000oooooooo02Coool00ol0VOooooooo`1D
oooo002?oooo00<0000co`0co`0043?o00030000oooooooo02Coool00ol0VOooooooo`1Doooo002?
oooo0P00010co`000`000?ooooooo`0Uoooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol0
00lco`000`000?ooooooo`0Uoooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol000lco`00
0`000?ooooooo`0Uoooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol000lco`000`000?oo
ooooo`0Uoooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0U
oooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Voooo00?o
09Woooooool0E?ooo`00Soooo`80000?<ol000<0003oooooool09_ooo`03o`2Ioooooooo05Coool0
08ooool00`0003?o03?o000><ol000<0003oooooool09_ooo`03o`2Ioooooooo05Coool008ooool0
0`0003?o03?o000><ol000<0003oooooool09_ooo`03o`2Ioooooooo05Coool008ooool00`0003?o
03?o000=<ol000<0003oooooool09oooo`03o`2Ioooooooo05Coool008Ooool400001?ooo`030000
<ol0<ol000dco`000`000?ooooooo`0Woooo00?o09Woooooool0E?ooo`00Qoooo`030000oooooooo
00Goool00`0003?o03?o000=<ol000<0003oooooool09oooo`03o`2Ioooooooo05Coool008Soool0
0`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`0Woooo00?o09Woooooool0E?ooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool09oooo`03o`2Ioooooooo
05Coool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0:?oo
o`03o`2Ioooooooo05Coool008Soool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`0X
oooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0Xoooo00?o
09Woooooool0E?ooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0Xoooo00?o09Wooooo
ool0E?ooo`00Soooo`80000=<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05Coool008ooool0
0`0003?o03?o000<<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05Coool008ooool00`0003?o
03?o000;<ol000<0003oooooool0:Oooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o000;
<ol000<0003oooooool0:Oooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o000;<ol000<0
003oooooool0:Oooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o000;<ol000<0003ooooo
ool0:Oooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o000;<ol000<0003oooooool0:Ooo
o`03o`2Ioooooooo05Coool008ooool2000033?o00030000oooooooo02Woool00ol0VOooooooo`1D
oooo002?oooo00<0000co`0co`002c?o00030000oooooooo02Woool00ol0VOooooooo`1Doooo002?
oooo00<0000co`0co`002S?o00030000oooooooo02[oool00ol0VOooooooo`1Doooo002?oooo00<0
000co`0co`002S?o00030000oooooooo02[oool00ol0VOooooooo`1Doooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo02[oool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`002S?o
00030000oooooooo02[oool00ol0VOooooooo`1Doooo002?oooo0P0000/co`000`000?ooooooo`0Z
oooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Zoooo00?o
09Woooooool0E?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0Zoooo00?o09Wooooo
ool0E?ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0[oooo00?o09Woooooool0E?oo
o`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0[oooo00?o09Woooooool0E?ooo`00Sooo
o`030000<ol0<ol000Tco`000`000?ooooooo`0[oooo00?o09Woooooool0E?ooo`00Soooo`80000:
<ol000<0003oooooool0:oooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o0009<ol000<0
003oooooool0:oooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o0009<ol000<0003ooooo
ool0:oooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o0008<ol000<0003oooooool0;?oo
o`03o`2Ioooooooo05Coool008Soool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`0/
oooo00?o09Woooooool0E?ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0/oooo00?o09Woooooool0E?ooo`00ROooo`030000oooooooo00?oool3000023?o
00030000oooooooo02coool00ol0VOooooooo`1Doooo002:oooo00<0003oooooool00_ooo`030000
<ol0<ol000Pco`000`000?ooooooo`0/oooo00?o09Woooooool0E?ooo`00Qoooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0/oooo00?o09Woooooool0E?ooo`00R?oo
o`800005oooo00<0000co`0co`001c?o00030000oooooooo02goool00ol0VOooooooo`1Doooo002?
oooo00<0000co`0co`001c?o00030000oooooooo02goool00ol0VOooooooo`1Doooo002?oooo00<0
000co`0co`001c?o00030000oooooooo02goool00ol0VOooooooo`1Doooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo02goool00ol0VOooooooo`1Doooo002?oooo0P0000Pco`000`000?oo
ooooo`0]oooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0]
oooo00?o09Woooooool0E?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0]oooo00?o
09Woooooool0E?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0]oooo00?o09Wooooo
ool0E?ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0^oooo00?o09Woooooool0E?oo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0^oooo00?o09Woooooool0E?ooo`00Sooo
o`800007<ol000<0003oooooool0;_ooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o0006
<ol000<0003oooooool0;_ooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o0006<ol000<0
003oooooool0;_ooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool0;_ooo`03o`2Ioooooooo05Coool008ooool00`0003?o03?o0006<ol000<0003oooooool0;_oo
o`03o`2Ioooooooo05Coool008ooool00`0003?o03?o0006<ol000<0003oooooool0;_ooo`03o`2I
oooooooo05Coool008ooool200001S?o00030000oooooooo02ooool00ol0VOooooooo`1Doooo002?
oooo00<0000co`0co`001C?o00030000oooooooo02ooool00ol0VOooooooo`1Doooo002?oooo00<0
000co`0co`001C?o00030000oooooooo02ooool00ol0VOooooooo`1Doooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo02ooool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`001C?o
00030000oooooooo02ooool00ol0VOooooooo`1Doooo002?oooo00<0000co`0co`001C?o00030000
oooooooo02ooool00ol0VOooooooo`1Doooo002?oooo0P0000Hco`000`000?ooooooo`0_oooo00?o
09Woooooool0E?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0_oooo00?o09Wooooo
ool0E?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0_oooo00?o09Woooooool0E?oo
o`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0`oooo00?o09Woooooool0E?ooo`00Sooo
o`030000<ol0<ol000@co`000`000?ooooooo`0`oooo00?o09Woooooool0E?ooo`00ROooo`<00003
oooo00<0000co`0co`0013?o00030000oooooooo033oool00ol0VOooooooo`1Doooo002:oooo00<0
003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`0`oooo00?o09Woooooool0E?oo
o`00Qoooo`D00003oooo0`0000@co`000`000?ooooooo`0`oooo00?o09Woooooool0E?ooo`00Qooo
o`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029
oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?oo
ooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo1@00008co`02000000<co`3oooooool00`0000?oool300001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Ooool00`0003?o03?o0005<ol01?ooo`050000oooooooooooo000000;oool0
1@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo00ooool0
0`0003?o03?o0005<ol00oooo`<00002oooo00@0003oooooool00004oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000>oooo00<0000co`0co`001C?o00;oool010000?ooooooo`00
00;oool300001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Aoooo00<0
000co`0co`001C?o00;oool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo017oool200001c?o00?oool300000oooo`<00002oooo00<0
003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.98) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71741 .12361 L
.72307 .12361 L
.72841 .12361 L
.73074 .12361 L
.73201 .12361 L
.7332 .12361 L
s
.7332 .12361 m
.73371 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.25127 .12361 L
.25666 .12361 L
.26171 .12361 L
.26425 .12361 L
.26498 .12361 L
.26568 .12361 L
.26698 .12328 L
.26768 .12256 L
.26842 .12181 L
.26976 .12046 L
.27279 .11749 L
.28302 .10829 L
.30316 .09347 L
.32457 .08176 L
.33438 .07756 L
.34474 .07382 L
.35431 .07092 L
.36482 .06831 L
.3743 .0664 L
.38329 .06495 L
.39349 .06368 L
.4028 .06283 L
.408 .06248 L
.41282 .06222 L
.4181 .06202 L
.42077 .06194 L
.42371 .06188 L
.42606 .06184 L
.42739 .06182 L
.42863 .06181 L
.42994 .06181 L
.43113 .0618 L
.43179 .0618 L
.43251 .0618 L
.43381 .06181 L
.43492 .06181 L
.43614 .06182 L
.43742 .06184 L
.43862 .06185 L
.44306 .06194 L
.44575 .06201 L
.44831 .06208 L
.45311 .06226 L
Mistroke
.46392 .06279 L
.47353 .06341 L
.48376 .06419 L
.49335 .06502 L
.49755 .06541 L
.50216 .06584 L
.50476 .06603 L
.50718 .06617 L
.50974 .06627 L
.51117 .06632 L
.51247 .06635 L
.51316 .06636 L
.5139 .06637 L
.51522 .06638 L
.51595 .06638 L
.51663 .06638 L
.51739 .06638 L
.5182 .06637 L
.51886 .06637 L
.51958 .06636 L
.52102 .06633 L
.52237 .0663 L
.52361 .06626 L
.52873 .06604 L
.53338 .06576 L
.5438 .06489 L
.5538 .06378 L
.56302 .06257 L
.58383 .05931 L
.62328 .05184 L
.66122 .04397 L
.68234 .03961 L
.70162 .03579 L
.71117 .03399 L
.72157 .03214 L
.72633 .03133 L
.72894 .03089 L
.73022 .03069 L
.7314 .0305 L
.73241 .03034 L
.73347 .12361 L
.73455 .12361 L
.73572 .12361 L
.74049 .12361 L
.78102 .12361 L
.82003 .12361 L
.8615 .12361 L
.90145 .12361 L
.93988 .12361 L
.97619 .12361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.98) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0eoooo101VoeGoool0
08ooool00`000?ooooooo`0^oooo1`1Vo`?oool00`1Vooooooooo`1Coooo002?oooo00<0003ooooo
ool0:Oooo`D0I_l:oooo00<0I_ooooooool0Doooo`00Soooo`030000oooooooo02Coool506Ko3ooo
o`0306Kooooooooo05?oool008ooool00`000?ooooooo`0Ooooo1@1VoaCoool00`1Vooooooooo`1C
oooo002?oooo0P0001_oool506Ko6Oooo`0306Kooooooooo05?oool008ooool00`000?ooooooo`0E
oooo1@1Voakoool00`1Vooooooooo`1Coooo002?oooo00<0003oooooool04?ooo`D0I_lSoooo00<0
I_ooooooool0Doooo`00LooooaT0I_l3oooo00<0003oooooool02_ooo`H0I_lXoooo00<0I_oooooo
ool0Doooo`00K?ooo`L0I_lIoooo0`1Vo`03000006Ko06Ko00X0I_l^oooo00<0I_ooooooool0Dooo
o`00J_ooo`80I_lSoooo00<0003oooooool0>?ooo`0306Kooooooooo05?oool006Ooool306Ko9Ooo
o`80000ioooo00<0I_ooooooool0Doooo`005oooo`@0000ioooo1@0000_oool306Ko:?ooo`030000
oooooooo03Ooool50000>?ooo`@0000Foooo000Goooo00<0003oooooool0??ooo`030000oooooooo
00Woool206Ko:oooo`030000oooooooo03Soool00`1Vo`000?ooo`0ioooo00<0003oooooool05ooo
o`006?ooo`030000oooooooo03_oool00`000?ooooooo`07oooo0P1Vobgoool00`000?ooooooo`0h
oooo00<0I_l0003oool0>_ooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo
03;oool400001?ooo`030000oooooooo00Goool206Ko;oooo`030000oooooooo03Soool00`1Vo`00
0?ooo`0koooo00<0003oooooool05Oooo`005oooo`040000oooooooo0000>oooo`030000oooooooo
00Coool00`1Vooooooooo`0_oooo00<0003oooooool0>?ooo`0306Ko0000oooo03Woool010000?oo
ooooo`0001Koool001Soool20000>oooo`800005oooo00<0I_ooooooool0<?ooo`80000ioooo0P00
03_oool200005oooo`00F_ooo`80I_lcoooo00<0003oooooool0>?ooo`0306Kooooooooo05?oool0
05Woool00`1Vooooooooo`0coooo00<0003oooooool0>?ooo`0306Kooooooooo05?oool005Soool0
0`1Vooooooooo`0doooo00<0003oooooool0>?ooo`0306Kooooooooo05?oool005Koool206Ko=ooo
o`030000oooooooo03Soool00`1Vooooooooo`1Coooo001Eoooo00<0I_ooooooool0=oooo`030000
oooooooo03Soool00`1Vooooooooo`1Coooo000@ooooo`00017oool001Koool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Pco`000ol0V@0003?o0007
<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo
03[oool00`000?ooooooo`0ioooo00<0000co`0co`00>3?o0003o`2I0000000000L0000doooo00<0
003oooooool05Oooo`00Soooo`030000<ol0<ol003<co`05000000?o09Woooooool0Doooo`00Sooo
o`030000<ol0<ol0034co`0200001Oooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000_
<ol00P0000Ooool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`00;3?o00<00009oooo00?o
09Woooooool0Doooo`00Soooo`80000Z<ol00`0000coool00ol0VOooooooo`1Coooo002?oooo00<0
000co`0co`009c?o0080000?oooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol002Hco`00
0`000?ooooooo`0?oooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol002Dco`000`000?oo
ooooo`0@oooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol002@co`000`000?ooooooo`0A
oooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol0028co`0200005?ooo`03o`2Ioooooooo
05?oool008ooool200008S?o00030000oooooooo01Coool00ol0VOooooooo`1Coooo002?oooo00<0
000co`0co`0083?o00030000oooooooo01Goool00ol0VOooooooo`1Coooo002?oooo00<0000co`0c
o`007c?o00030000oooooooo01Koool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`007c?o
00030000oooooooo01Koool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`007S?o00030000
oooooooo01Ooool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`007C?o00030000oooooooo
01Soool00ol0VOooooooo`1Coooo002?oooo0P0001dco`000`000?ooooooo`0Ioooo00?o09Wooooo
ool0Doooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0Joooo00?o09Woooooool0Dooo
o`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0Joooo00?o09Woooooool0Doooo`00Sooo
o`030000<ol0<ol001Xco`000`000?ooooooo`0Koooo00?o09Woooooool0Doooo`00Soooo`030000
<ol0<ol001Xco`000`000?ooooooo`0Koooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol0
01Tco`000`000?ooooooo`0Loooo00?o09Woooooool0Doooo`00Soooo`80000J<ol000<0003ooooo
ool07?ooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000H<ol000<0003oooooool07Ooo
o`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000H<ol000<0003oooooool07Oooo`03o`2I
oooooooo05?oool008ooool00`0003?o03?o000G<ol000<0003oooooool07_ooo`03o`2Ioooooooo
05?oool008ooool00`0003?o03?o000G<ol000<0003oooooool07_ooo`03o`2Ioooooooo05?oool0
08Ooool500000oooo`030000<ol0<ol001Hco`000`000?ooooooo`0Ooooo00?o09Woooooool0Dooo
o`00ROooo`030000oooooooo00?oool00`0003?o03?o000F<ol000<0003oooooool07oooo`03o`2I
oooooooo05?oool008Woool00`000?ooooooo`03oooo0`0001Dco`000`000?ooooooo`0Poooo00?o
09Woooooool0Doooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E<ol000<0003ooooo
ool08?ooo`03o`2Ioooooooo05?oool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o
00030000oooooooo023oool00ol0VOooooooo`1Coooo0028oooo0P0000Goool00`0003?o03?o000D
<ol000<0003oooooool08Oooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000D<ol000<0
003oooooool08Oooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000C<ol000<0003ooooo
ool08_ooo`03o`2Ioooooooo05?oool008ooool2000053?o00030000oooooooo02;oool00ol0VOoo
ooooo`1Coooo002?oooo00<0000co`0co`004c?o00030000oooooooo02;oool00ol0VOooooooo`1C
oooo002?oooo00<0000co`0co`004S?o00030000oooooooo02?oool00ol0VOooooooo`1Coooo002?
oooo00<0000co`0co`004S?o00030000oooooooo02?oool00ol0VOooooooo`1Coooo002?oooo00<0
000co`0co`004S?o00030000oooooooo02?oool00ol0VOooooooo`1Coooo002?oooo00<0000co`0c
o`004C?o00030000oooooooo02Coool00ol0VOooooooo`1Coooo002?oooo0P00018co`000`000?oo
ooooo`0Toooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0T
oooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Toooo00?o
09Woooooool0Doooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Uoooo00?o09Wooooo
ool0Doooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Uoooo00?o09Woooooool0Dooo
o`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0Uoooo00?o09Woooooool0Doooo`00Sooo
o`030000<ol0<ol0010co`000`000?ooooooo`0Uoooo00?o09Woooooool0Doooo`00Soooo`80000@
<ol000<0003oooooool09_ooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000?<ol000<0
003oooooool09_ooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000?<ol000<0003ooooo
ool09_ooo`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000?<ol000<0003oooooool09_oo
o`03o`2Ioooooooo05?oool008ooool00`0003?o03?o000?<ol000<0003oooooool09_ooo`03o`2I
oooooooo05?oool008ooool00`0003?o03?o000><ol000<0003oooooool09oooo`03o`2Ioooooooo
05?oool008ooool200003c?o00030000oooooooo02Ooool00ol0VOooooooo`1Coooo002?oooo00<0
000co`0co`003S?o00030000oooooooo02Ooool00ol0VOooooooo`1Coooo002?oooo00<0000co`0c
o`003S?o00030000oooooooo02Ooool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`003C?o
00030000oooooooo02Soool00ol0VOooooooo`1Coooo0027oooo100000Coool00`0003?o03?o000=
<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05?oool008Ooool00`000?ooooooo`05oooo00<0
000co`0co`003C?o00030000oooooooo02Soool00ol0VOooooooo`1Coooo0028oooo00<0003ooooo
ool01?ooo`<0000=<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05?oool008Woool00`000?oo
ooooo`03oooo00<0000co`0co`003C?o00030000oooooooo02Soool00ol0VOooooooo`1Coooo0027
oooo00@0003oooooool00004oooo00<0000co`0co`0033?o00030000oooooooo02Woool00ol0VOoo
ooooo`1Coooo0028oooo0P0000Goool00`0003?o03?o000<<ol000<0003oooooool0:Oooo`03o`2I
oooooooo05?oool008ooool00`0003?o03?o000<<ol000<0003oooooool0:Oooo`03o`2Ioooooooo
05?oool008ooool00`0003?o03?o000<<ol000<0003oooooool0:Oooo`03o`2Ioooooooo05?oool0
08ooool200003C?o00030000oooooooo02Woool00ol0VOooooooo`1Coooo002?oooo00<0000co`0c
o`0033?o00030000oooooooo02Woool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`002c?o
00030000oooooooo02[oool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`002c?o00030000
oooooooo02[oool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`002c?o00030000oooooooo
02[oool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`002c?o00030000oooooooo02[oool0
0ol0VOooooooo`1Coooo002?oooo00<0000co`0co`002c?o00030000oooooooo02[oool00ol0VOoo
ooooo`1Coooo002?oooo0P0000`co`000`000?ooooooo`0Zoooo00?o09Woooooool0Doooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`0Zoooo00?o09Woooooool0Doooo`00Soooo`030000
<ol0<ol000Xco`000`000?ooooooo`0[oooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0[oooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0[oooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0[oooo00?o09Woooooool0Doooo`00Soooo`80000;<ol000<0003oooooool0:oooo`03o`2I
oooooooo05?oool008ooool00`0003?o03?o000:<ol000<0003oooooool0:oooo`03o`2Ioooooooo
05?oool008ooool00`0003?o03?o000:<ol000<0003oooooool0:oooo`03o`2Ioooooooo05?oool0
08ooool00`0003?o03?o0009<ol000<0003oooooool0;?ooo`03o`2Ioooooooo05?oool008ooool0
0`0003?o03?o0009<ol000<0003oooooool0;?ooo`03o`2Ioooooooo05?oool008ooool00`0003?o
03?o0009<ol000<0003oooooool0;?ooo`03o`2Ioooooooo05?oool008ooool200002S?o00030000
oooooooo02coool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`002C?o00030000oooooooo
02coool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`002C?o00030000oooooooo02coool0
0ol0VOooooooo`1Coooo002?oooo00<0000co`0co`0023?o00030000oooooooo02goool00ol0VOoo
ooooo`1Coooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0003oooooool0;Oooo`03o`2I
oooooooo05?oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003ooooo
ool0;Oooo`03o`2Ioooooooo05?oool008Woool00`000?ooooooo`03oooo0`0000Pco`000`000?oo
ooooo`0]oooo00?o09Woooooool0Doooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008
<ol000<0003oooooool0;Oooo`03o`2Ioooooooo05?oool008Ooool010000?ooooooo`0000Coool0
0`0003?o03?o0008<ol000<0003oooooool0;Oooo`03o`2Ioooooooo05?oool008Soool200001Ooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0^oooo00?o09Woooooool0Doooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`0^oooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0^oooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0^oooo00?o09Woooooool0Doooo`00Soooo`800008<ol000<0003oooooool0;_oo
o`03o`2Ioooooooo05?oool008ooool00`0003?o03?o0007<ol000<0003oooooool0;_ooo`03o`2I
oooooooo05?oool008ooool00`0003?o03?o0007<ol000<0003oooooool0;_ooo`03o`2Ioooooooo
05?oool008ooool00`0003?o03?o0007<ol000<0003oooooool0;_ooo`03o`2Ioooooooo05?oool0
08ooool00`0003?o03?o0006<ol000<0003oooooool0;oooo`03o`2Ioooooooo05?oool008ooool0
0`0003?o03?o0006<ol000<0003oooooool0;oooo`03o`2Ioooooooo05?oool008ooool200001c?o
00030000oooooooo02ooool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`001S?o00030000
oooooooo02ooool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`001S?o00030000oooooooo
02ooool00ol0VOooooooo`1Coooo002?oooo00<0000co`0co`001S?o00030000oooooooo02ooool0
0ol0VOooooooo`1Coooo002?oooo00<0000co`0co`001S?o00030000oooooooo02ooool00ol0VOoo
ooooo`1Coooo002?oooo00<0000co`0co`001S?o00030000oooooooo02ooool00ol0VOooooooo`1C
oooo002?oooo0P0000Hco`000`000?ooooooo`0`oooo00?o09Woooooool0Doooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`0`oooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`0`oooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`0`oooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`0`oooo00?o09Woooooool0Doooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0`
oooo00?o09Woooooool0Doooo`00Soooo`800006<ol000<0003oooooool0<?ooo`03o`2Ioooooooo
05?oool008ooool00`0003?o03?o0005<ol000<0003oooooool0<?ooo`03o`2Ioooooooo05?oool0
08ooool00`0003?o03?o0005<ol000<0003oooooool0<?ooo`03o`2Ioooooooo05?oool008ooool0
0`0003?o03?o0004<ol000<0003oooooool0<Oooo`03o`2Ioooooooo05?oool008ooool00`0003?o
03?o0004<ol000<0003oooooool0<Oooo`03o`2Ioooooooo05?oool008Woool300000oooo`030000
<ol0<ol000@co`000`000?ooooooo`0aoooo00?o09Woooooool0Doooo`00R_ooo`030000oooooooo
00;oool00`0003?o03?o0004<ol000<0003oooooool0<Oooo`03o`2Ioooooooo05?oool008Ooool5
00000oooo`<00004<ol000<0003oooooool0<Oooo`03o`2Ioooooooo05?oool008Ooool010000?oo
ooooo`0000Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004
oooo1c?o08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04ooo
o`Lco`0>oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09
oooo1c?o00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01_ooo`D00002<ol00P000003<ol0oooooooo00<00004oooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`07oooo00<0000co`0co`001C?o00Coool01@000?ooooooooooo`000002oooo00D0003ooooo
ooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0000co`0c
o`001C?o00?oool300000_ooo`040000oooooooo00001?ooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500003_ooo`030000<ol0<ol000Dco`02oooo00@0003oooooool00003oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000004Oooo`030000<ol0<ol0
00Dco`02oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo017oool200001c?o00?oool300000oooo`800003oooo00<0003ooooo
ool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71741 .12361 L
.72307 .12361 L
.72841 .12361 L
.7332 .12361 L
.73451 .12361 L
.7359 .12361 L
.73708 .12361 L
s
.73708 .12361 m
.7376 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.24141 .12361 L
.25127 .12361 L
.25666 .12361 L
.2593 .12361 L
.26045 .12361 L
.26171 .12361 L
.26301 .12247 L
.26425 .12121 L
.26698 .1185 L
.27279 .11305 L
.28302 .10441 L
.30316 .09054 L
.32283 .0804 L
.3438 .0726 L
.35409 .06972 L
.36521 .06722 L
.37572 .06536 L
.38538 .06405 L
.39008 .06354 L
.39512 .06307 L
.39947 .06273 L
.40421 .06242 L
.40976 .06215 L
.41231 .06205 L
.41502 .06197 L
.41745 .06191 L
.41874 .06188 L
.42013 .06186 L
.42141 .06184 L
.42258 .06182 L
.42369 .06182 L
.42487 .06181 L
.4261 .0618 L
.4268 .0618 L
.42744 .0618 L
.42862 .06181 L
.42987 .06181 L
.43099 .06182 L
.43203 .06183 L
.43442 .06186 L
.43698 .06191 L
.43933 .06196 L
.44461 .06212 L
.45403 .06252 L
Mistroke
.46298 .06302 L
.48282 .06451 L
.49167 .06531 L
.50122 .06624 L
.50391 .06646 L
.50675 .06664 L
.50917 .06676 L
.51054 .06681 L
.51182 .06685 L
.51311 .06688 L
.51434 .0669 L
.51544 .06691 L
.51663 .06692 L
.51793 .06691 L
.51859 .06691 L
.51931 .0669 L
.52059 .06689 L
.52179 .06687 L
.52407 .06681 L
.52647 .06672 L
.53075 .06652 L
.53537 .06622 L
.54041 .06583 L
.56006 .06366 L
.58102 .06053 L
.62257 .05284 L
.6626 .04456 L
.70112 .0367 L
.72104 .03297 L
.73107 .03124 L
.73382 .03079 L
.73533 .03054 L
.73608 .03042 L
.73677 .03031 L
.73741 .03021 L
.7381 .12361 L
.73879 .12361 L
.73955 .12361 L
.74209 .12361 L
.78226 .12361 L
.82092 .12361 L
.86203 .12361 L
.90162 .12361 L
.93969 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0coooo1`1VoeCoool0
08ooool00`000?ooooooo`0^oooo1@1Vo`Koool00`1Vooooooooo`1Boooo002?oooo00<0003ooooo
ool0:Oooo`D0I_l;oooo00<0I_ooooooool0D_ooo`00Soooo`030000oooooooo02Coool506Ko4?oo
o`0306Kooooooooo05;oool008ooool00`000?ooooooo`0Ooooo1@1VoaGoool00`1Vooooooooo`1B
oooo002?oooo0P0001_oool506Ko6_ooo`0306Kooooooooo05;oool008ooool00`000?ooooooo`0E
oooo1@1Voaooool00`1Vooooooooo`1Boooo002?oooo00<0003oooooool04?ooo`D0I_lToooo00<0
I_ooooooool0D_ooo`00LOoooa/0I_l3oooo00<0003oooooool02_ooo`H0I_lYoooo00<0I_oooooo
ool0D_ooo`00K?ooo`D0I_lKoooo0`1Vo`03000006Ko06Ko00X0I_l_oooo00<0I_ooooooool0D_oo
o`00I_ooo`H0I_lSoooo00<0003oooooool0>Oooo`0306Kooooooooo05;oool006Coool206Ko:Ooo
o`80000joooo00<0I_ooooooool0D_ooo`005oooo`@0000ioooo1@0000Woool206Ko:oooo`030000
oooooooo03Ooool50000>?ooo`@0000Foooo000Goooo00<0003oooooool0??ooo`030000oooooooo
00Ooool206Ko;Oooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00<0003oooooool05ooo
o`006?ooo`030000oooooooo03_oool00`000?ooooooo`05oooo0P1Vobooool00`000?ooooooo`0i
oooo00<0003oooooool0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo
03;oool400001?ooo`030000oooooooo00Coool00`1Vooooooooo`0_oooo00<0003oooooool0>Ooo
o`030000oooooooo03[oool00`000?ooooooo`0Eoooo000Goooo00@0003oooooool0000koooo00<0
003oooooool00oooo`0306Kooooooooo033oool00`000?ooooooo`0ioooo00<0003oooooool0>?oo
o`040000oooooooo00005_ooo`006?ooo`80000koooo0P0000?oool206Ko<oooo`80000ioooo0P00
03_oool200005oooo`00FOooo`0306Kooooooooo03?oool00`000?ooooooo`0ioooo00<0I_oooooo
ool0D_ooo`00F?ooo`0306Kooooooooo03Coool00`000?ooooooo`0ioooo00<0I_ooooooool0D_oo
o`00E_ooo`80I_lgoooo00<0003oooooool0>Oooo`0306Kooooooooo05;oool005Goool00`1Voooo
ooooo`0goooo00<0003oooooool0>Oooo`0306Kooooooooo05;oool005Coool00`1Vooooooooo`0h
oooo00<0003oooooool0>Oooo`0306Kooooooooo05;oool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Hco`0R00001_ooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0
003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000i<ol02@0003Coool00`000?oo
ooooo`0Eoooo002?oooo00<0000co`0co`00<c?o00H000000ol0VOooooooo`1Boooo002?oooo00<0
000co`0co`00<C?o00800006oooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol002lco`02
00002?ooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000/<ol00`0000[oool00ol0VOoo
ooooo`1Boooo002?oooo0P0002Xco`0300003Oooo`03o`2Ioooooooo05;oool008ooool00`0003?o
03?o000W<ol00P00013oool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`009S?o00030000
oooooooo013oool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`009C?o00030000oooooooo
017oool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`0093?o00030000oooooooo01;oool0
0ol0VOooooooo`1Boooo002?oooo00<0000co`0co`008S?o0080000Eoooo00?o09Woooooool0D_oo
o`00Soooo`80000R<ol000<0003oooooool05Oooo`03o`2Ioooooooo05;oool008ooool00`0003?o
03?o000P<ol000<0003oooooool05_ooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000O
<ol000<0003oooooool05oooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000O<ol000<0
003oooooool05oooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000N<ol000<0003ooooo
ool06?ooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000M<ol000<0003oooooool06Ooo
o`03o`2Ioooooooo05;oool008ooool200007C?o00030000oooooooo01[oool00ol0VOooooooo`1B
oooo002?oooo00<0000co`0co`006c?o00030000oooooooo01_oool00ol0VOooooooo`1Boooo002?
oooo00<0000co`0co`006c?o00030000oooooooo01_oool00ol0VOooooooo`1Boooo002?oooo00<0
000co`0co`006S?o00030000oooooooo01coool00ol0VOooooooo`1Boooo002?oooo00<0000co`0c
o`006S?o00030000oooooooo01coool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`006C?o
00030000oooooooo01goool00ol0VOooooooo`1Boooo002?oooo0P0001Xco`000`000?ooooooo`0M
oooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0Noooo00?o
09Woooooool0D_ooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0Noooo00?o09Wooooo
ool0D_ooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0Ooooo00?o09Woooooool0D_oo
o`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0Ooooo00?o09Woooooool0D_ooo`00Qooo
o`D00003oooo00<0000co`0co`005S?o00030000oooooooo023oool00ol0VOooooooo`1Boooo0029
oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`0Poooo00?o09Wooooo
ool0D_ooo`00ROooo`030000oooooooo00?oool300005C?o00030000oooooooo027oool00ol0VOoo
ooooo`1Boooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`0Q
oooo00?o09Woooooool0D_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E<ol000<0
003oooooool08Oooo`03o`2Ioooooooo05;oool008Soool200001Oooo`030000<ol0<ol001@co`00
0`000?ooooooo`0Roooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol001@co`000`000?oo
ooooo`0Roooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`0S
oooo00?o09Woooooool0D_ooo`00Soooo`80000D<ol000<0003oooooool08oooo`03o`2Ioooooooo
05;oool008ooool00`0003?o03?o000C<ol000<0003oooooool08oooo`03o`2Ioooooooo05;oool0
08ooool00`0003?o03?o000B<ol000<0003oooooool09?ooo`03o`2Ioooooooo05;oool008ooool0
0`0003?o03?o000B<ol000<0003oooooool09?ooo`03o`2Ioooooooo05;oool008ooool00`0003?o
03?o000B<ol000<0003oooooool09?ooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000A
<ol000<0003oooooool09Oooo`03o`2Ioooooooo05;oool008ooool200004S?o00030000oooooooo
02Goool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`004C?o00030000oooooooo02Goool0
0ol0VOooooooo`1Boooo002?oooo00<0000co`0co`004C?o00030000oooooooo02Goool00ol0VOoo
ooooo`1Boooo002?oooo00<0000co`0co`0043?o00030000oooooooo02Koool00ol0VOooooooo`1B
oooo002?oooo00<0000co`0co`0043?o00030000oooooooo02Koool00ol0VOooooooo`1Boooo002?
oooo00<0000co`0co`0043?o00030000oooooooo02Koool00ol0VOooooooo`1Boooo002?oooo00<0
000co`0co`0043?o00030000oooooooo02Koool00ol0VOooooooo`1Boooo002?oooo0P00010co`00
0`000?ooooooo`0Woooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol000lco`000`000?oo
ooooo`0Woooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0W
oooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0Woooo00?o
09Woooooool0D_ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0Woooo00?o09Wooooo
ool0D_ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0Xoooo00?o09Woooooool0D_oo
o`00Soooo`80000?<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05;oool008ooool00`0003?o
03?o000><ol000<0003oooooool0:?ooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000>
<ol000<0003oooooool0:?ooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000=<ol000<0
003oooooool0:Oooo`03o`2Ioooooooo05;oool008Ooool400001?ooo`030000<ol0<ol000dco`00
0`000?ooooooo`0Yoooo00?o09Woooooool0D_ooo`00Qoooo`030000oooooooo00Goool00`0003?o
03?o000=<ol000<0003oooooool0:Oooo`03o`2Ioooooooo05;oool008Soool00`000?ooooooo`04
oooo0`0000dco`000`000?ooooooo`0Yoooo00?o09Woooooool0D_ooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000=<ol000<0003oooooool0:Oooo`03o`2Ioooooooo05;oool008Ooool0
10000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0:_ooo`03o`2Ioooooooo
05;oool008Soool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`0Zoooo00?o09Wooooo
ool0D_ooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0Zoooo00?o09Woooooool0D_oo
o`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0Zoooo00?o09Woooooool0D_ooo`00Sooo
o`80000=<ol000<0003oooooool0:_ooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000<
<ol000<0003oooooool0:_ooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000;<ol000<0
003oooooool0:oooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000;<ol000<0003ooooo
ool0:oooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000;<ol000<0003oooooool0:ooo
o`03o`2Ioooooooo05;oool008ooool00`0003?o03?o000;<ol000<0003oooooool0:oooo`03o`2I
oooooooo05;oool008ooool00`0003?o03?o000;<ol000<0003oooooool0:oooo`03o`2Ioooooooo
05;oool008ooool2000033?o00030000oooooooo02_oool00ol0VOooooooo`1Boooo002?oooo00<0
000co`0co`002c?o00030000oooooooo02_oool00ol0VOooooooo`1Boooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo02coool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`002S?o
00030000oooooooo02coool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`002S?o00030000
oooooooo02coool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`002S?o00030000oooooooo
02coool00ol0VOooooooo`1Boooo002?oooo0P0000/co`000`000?ooooooo`0/oooo00?o09Wooooo
ool0D_ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0/oooo00?o09Woooooool0D_oo
o`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0/oooo00?o09Woooooool0D_ooo`00Sooo
o`030000<ol0<ol000Tco`000`000?ooooooo`0]oooo00?o09Woooooool0D_ooo`00Soooo`030000
<ol0<ol000Tco`000`000?ooooooo`0]oooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol0
00Tco`000`000?ooooooo`0]oooo00?o09Woooooool0D_ooo`00Soooo`80000:<ol000<0003ooooo
ool0;Oooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o0009<ol000<0003oooooool0;Ooo
o`03o`2Ioooooooo05;oool008ooool00`0003?o03?o0009<ol000<0003oooooool0;Oooo`03o`2I
oooooooo05;oool008ooool00`0003?o03?o0008<ol000<0003oooooool0;_ooo`03o`2Ioooooooo
05;oool008Soool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`0^oooo00?o09Wooooo
ool0D_ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0^
oooo00?o09Woooooool0D_ooo`00ROooo`030000oooooooo00?oool3000023?o00030000oooooooo
02koool00ol0VOooooooo`1Boooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0^oooo00?o09Woooooool0D_ooo`00Qoooo`040000oooooooo00001?ooo`030000
<ol0<ol000Pco`000`000?ooooooo`0^oooo00?o09Woooooool0D_ooo`00R?ooo`800005oooo00<0
000co`0co`001c?o00030000oooooooo02ooool00ol0VOooooooo`1Boooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo02ooool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`001c?o
00030000oooooooo02ooool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`001c?o00030000
oooooooo02ooool00ol0VOooooooo`1Boooo002?oooo0P0000Pco`000`000?ooooooo`0_oooo00?o
09Woooooool0D_ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0_oooo00?o09Wooooo
ool0D_ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0_oooo00?o09Woooooool0D_oo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0_oooo00?o09Woooooool0D_ooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`0`oooo00?o09Woooooool0D_ooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`0`oooo00?o09Woooooool0D_ooo`00Soooo`800007<ol000<0
003oooooool0<?ooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool0<?ooo`03o`2Ioooooooo05;oool008ooool00`0003?o03?o0006<ol000<0003oooooool0<?oo
o`03o`2Ioooooooo05;oool008ooool00`0003?o03?o0006<ol000<0003oooooool0<?ooo`03o`2I
oooooooo05;oool008ooool00`0003?o03?o0006<ol000<0003oooooool0<?ooo`03o`2Ioooooooo
05;oool008ooool00`0003?o03?o0006<ol000<0003oooooool0<?ooo`03o`2Ioooooooo05;oool0
08ooool200001S?o00030000oooooooo037oool00ol0VOooooooo`1Boooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo037oool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`001C?o
00030000oooooooo037oool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`001C?o00030000
oooooooo037oool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`001C?o00030000oooooooo
037oool00ol0VOooooooo`1Boooo002?oooo00<0000co`0co`001C?o00030000oooooooo037oool0
0ol0VOooooooo`1Boooo002?oooo0P0000Hco`000`000?ooooooo`0aoooo00?o09Woooooool0D_oo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0aoooo00?o09Woooooool0D_ooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`0aoooo00?o09Woooooool0D_ooo`00Soooo`030000
<ol0<ol000@co`000`000?ooooooo`0boooo00?o09Woooooool0D_ooo`00Soooo`030000<ol0<ol0
00@co`000`000?ooooooo`0boooo00?o09Woooooool0D_ooo`00ROooo`<00003oooo00<0000co`0c
o`0013?o00030000oooooooo03;oool00ol0VOooooooo`1Boooo002:oooo00<0003oooooool00_oo
o`030000<ol0<ol000@co`000`000?ooooooo`0boooo00?o09Woooooool0D_ooo`00Qoooo`D00003
oooo0`0000@co`000`000?ooooooo`0boooo00?o09Woooooool0D_ooo`00Qoooo`040000oooooooo
00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7
<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007ooool00`000?ooooooo`0=oooo1c?o
00Soool00`000?ooooooo`1ooooo001noooo00<0003oooooool02?ooo`030000oooooooo00?oool7
<ol02Oooo`030000oooooooo07koool007koool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`03oooo0c?o00@00003oooo0P0000Coool00`000?ooooooo`1noooo001noooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`02oooo0c?o00040000<ol0<ol0
<ol02Oooo`030000oooooooo07koool007goool00`000?ooooooo`02oooo00<0003oooooool02_oo
o`@co`000`0003?o03?o000:oooo00<0003oooooool0OOooo`00O_ooo`030000oooooooo00D00009
oooo1C?o00030000<ol0oooo00Soool00`000?ooooooo`1noooo001noooo00D0003oooooooooool0
00003?ooo`<co`00100003?o03?o000000Woool00`000?ooooooo`1noooo001ooooo00<0003ooooo
ool03Oooo`@co`02000000<co`3oooooool01_ooo`030000oooooooo07ooool008ooool7<ol0R_oo
o`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.72912 .12361 L
.73354 .12361 L
.73604 .12361 L
.73838 .12361 L
.74065 .12361 L
.74193 .12361 L
s
.74193 .12361 m
.74239 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.24276 .12361 L
.24754 .12361 L
.25261 .12361 L
.2547 .12361 L
.25585 .12361 L
.25694 .12361 L
.25823 .12249 L
.2594 .12129 L
.26171 .119 L
.28174 .10172 L
.2999 .08965 L
.31958 .07974 L
.3305 .07544 L
.34055 .07214 L
.35979 .06735 L
.36992 .06553 L
.38061 .06405 L
.39009 .06309 L
.39541 .06268 L
.40025 .06238 L
.40476 .06216 L
.40714 .06207 L
.40967 .06198 L
.41187 .06192 L
.4143 .06187 L
.41536 .06186 L
.41651 .06184 L
.41758 .06183 L
.41859 .06182 L
.41984 .06181 L
.42098 .0618 L
.42221 .0618 L
.42291 .0618 L
.42354 .06181 L
.42461 .06181 L
.42579 .06182 L
.42701 .06183 L
.42816 .06184 L
.43079 .06188 L
.4332 .06193 L
.43863 .06208 L
.44381 .06227 L
Mistroke
.44945 .06253 L
.45973 .06312 L
.47944 .06463 L
.49037 .06564 L
.50042 .06665 L
.50544 .06707 L
.50797 .06722 L
.51074 .06734 L
.51219 .06739 L
.51352 .06742 L
.51425 .06744 L
.51505 .06745 L
.5158 .06746 L
.5165 .06746 L
.51774 .06747 L
.51845 .06747 L
.51911 .06746 L
.5198 .06746 L
.52044 .06745 L
.52114 .06744 L
.52188 .06743 L
.52429 .06737 L
.52565 .06733 L
.52688 .06729 L
.53152 .06707 L
.53694 .06673 L
.54206 .06632 L
.56211 .06409 L
.58058 .06136 L
.62003 .05419 L
.65797 .04642 L
.69836 .03809 L
.71698 .03449 L
.7268 .03271 L
.73724 .03093 L
.73976 .03052 L
.74108 .0303 L
.7418 .03019 L
.74247 .03008 L
.74322 .12361 L
.74403 .12361 L
.74545 .12361 L
.74826 .12361 L
.75845 .12361 L
.77857 .12361 L
.81758 .12361 L
.85905 .12361 L
.899 .12361 L
.93743 .12361 L
.97619 .12361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0foooo1@1Voe?oool0
08ooool00`000?ooooooo`0boooo101Vo`Coool00`1Vooooooooo`1Aoooo002?oooo00<0003ooooo
ool0;Oooo`D0I_l8oooo00<0I_ooooooool0DOooo`00Soooo`030000oooooooo02Soool506Ko3Ooo
o`0306Kooooooooo057oool008ooool00`000?ooooooo`0Soooo1@1Voa;oool00`1Vooooooooo`1A
oooo002?oooo0P0001ooool506Ko5oooo`0306Kooooooooo057oool008ooool00`000?ooooooo`0I
oooo1@1Voacoool00`1Vooooooooo`1Aoooo002?oooo00<0003oooooool05?ooo`D0I_lQoooo00<0
I_ooooooool0DOooo`00L?oooa`0I_l3oooo00<0003oooooool02oooo`T0I_lVoooo00<0I_oooooo
ool0DOooo`00J_ooo`H0I_lLoooo0`1Vo`03000006Ko06Ko00/0I_l_oooo00<0I_ooooooool0DOoo
o`00I_ooo`@0I_lUoooo00<0003oooooool0>_ooo`0306Kooooooooo057oool006?oool306Ko:Ooo
o`80000koooo00<0I_ooooooool0DOooo`005oooo`@0000ioooo1@0000Soool206Ko;?ooo`030000
oooooooo03Ooool50000>?ooo`@0000Foooo000Goooo00<0003oooooool0??ooo`030000oooooooo
00Koool206Ko;_ooo`030000oooooooo03Woool00`000?ooo`1Vo`0hoooo00<0003oooooool05ooo
o`006?ooo`030000oooooooo03_oool00`000?ooooooo`04oooo0P1Voc3oool00`000?ooooooo`0i
oooo00<0003oool0I_l0>Oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo
03;oool400001?ooo`030000oooooooo00?oool00`1Vooooooooo`0`oooo00<0003oooooool0>Ooo
o`030000oooo06Ko03[oool00`000?ooooooo`0Eoooo000Goooo00@0003oooooool0000koooo00<0
003oooooool00_ooo`0306Kooooooooo037oool00`000?ooooooo`0ioooo00<0003oool0I_l0>?oo
o`040000oooooooo00005_ooo`006?ooo`80000koooo0P0000;oool206Ko=?ooo`80000ioooo0P00
0003oooo06Kooooo03Soool200005oooo`00F?ooo`0306Kooooooooo03Coool00`000?ooooooo`0k
oooo00<0I_ooooooool0D?ooo`00Eoooo`0306Kooooooooo03Goool00`000?ooooooo`0koooo00<0
I_ooooooool0D?ooo`00EOooo`80I_lhoooo00<0003oooooool0>oooo`0306Kooooooooo053oool0
05Coool00`1Vooooooooo`0hoooo00<0003oooooool0>oooo`0306Kooooooooo053oool005?oool0
0`1Vooooooooo`0ioooo00<0003oooooool0>oooo`0306Kooooooooo053oool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000o`2I<ol000Hco`0R00001_ooo`030000oooooooo00Woool00`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000i<ol000<0
003o09T000001P0003Coool00`000?ooooooo`0Eoooo002?oooo00<0000co`0co`00<c?o00H00000
0oooool0VOooo`1Boooo002?oooo00<0000co`0co`00<C?o00800007oooo00?o09Woooooool0DOoo
o`00Soooo`030000<ol0<ol002lco`0200002Oooo`03o`2Ioooooooo057oool008ooool00`0003?o
03?o000/<ol00`0000_oool00ol0VOooooooo`1Aoooo002?oooo0P0002Xco`0300003_ooo`03o`2I
oooooooo057oool008ooool00`0003?o03?o000W<ol00P00017oool00ol0VOooooooo`1Aoooo002?
oooo00<0000co`0co`009S?o00030000oooooooo017oool00ol0VOooooooo`1Aoooo002?oooo00<0
000co`0co`009C?o00030000oooooooo01;oool00ol0VOooooooo`1Aoooo002?oooo00<0000co`0c
o`0093?o00030000oooooooo01?oool00ol0VOooooooo`1Aoooo002?oooo00<0000co`0co`008S?o
0080000Foooo00?o09Woooooool0DOooo`00Soooo`80000R<ol000<0003oooooool05_ooo`03o`2I
oooooooo057oool008ooool00`0003?o03?o000P<ol000<0003oooooool05oooo`03o`2Ioooooooo
057oool008ooool00`0003?o03?o000O<ol000<0003oooooool06?ooo`03o`2Ioooooooo057oool0
08ooool00`0003?o03?o000O<ol000<0003oooooool06?ooo`03o`2Ioooooooo057oool008ooool0
0`0003?o03?o000N<ol000<0003oooooool06Oooo`03o`2Ioooooooo057oool008ooool00`0003?o
03?o000M<ol000<0003oooooool06_ooo`03o`2Ioooooooo057oool008ooool200007C?o00030000
oooooooo01_oool00ol0VOooooooo`1Aoooo002?oooo00<0000co`0co`006c?o00030000oooooooo
01coool00ol0VOooooooo`1Aoooo002?oooo00<0000co`0co`006c?o00030000oooooooo01coool0
0ol0VOooooooo`1Aoooo002?oooo00<0000co`0co`006S?o00030000oooooooo01goool00ol0VOoo
ooooo`1Aoooo002?oooo00<0000co`0co`006S?o00030000oooooooo01goool00ol0VOooooooo`1A
oooo002?oooo00<0000co`0co`006C?o00030000oooooooo01koool00ol0VOooooooo`1Aoooo002?
oooo0P0001Xco`000`000?ooooooo`0Noooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol0
01Pco`000`000?ooooooo`0Ooooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol001Pco`00
0`000?ooooooo`0Ooooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol001Lco`000`000?oo
ooooo`0Poooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0P
oooo00?o09Woooooool0DOooo`00Qoooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo
027oool00ol0VOooooooo`1Aoooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`00
0`000?ooooooo`0Qoooo00?o09Woooooool0DOooo`00ROooo`030000oooooooo00?oool300005C?o
00030000oooooooo02;oool00ol0VOooooooo`1Aoooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol001Dco`000`000?ooooooo`0Roooo00?o09Woooooool0DOooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000E<ol000<0003oooooool08_ooo`03o`2Ioooooooo057oool008Soool2
00001Oooo`030000<ol0<ol001@co`000`000?ooooooo`0Soooo00?o09Woooooool0DOooo`00Sooo
o`030000<ol0<ol001@co`000`000?ooooooo`0Soooo00?o09Woooooool0DOooo`00Soooo`030000
<ol0<ol001<co`000`000?ooooooo`0Toooo00?o09Woooooool0DOooo`00Soooo`80000D<ol000<0
003oooooool09?ooo`03o`2Ioooooooo057oool008ooool00`0003?o03?o000C<ol000<0003ooooo
ool09?ooo`03o`2Ioooooooo057oool008ooool00`0003?o03?o000B<ol000<0003oooooool09Ooo
o`03o`2Ioooooooo057oool008ooool00`0003?o03?o000B<ol000<0003oooooool09Oooo`03o`2I
oooooooo057oool008ooool00`0003?o03?o000B<ol000<0003oooooool09Oooo`03o`2Ioooooooo
057oool008ooool00`0003?o03?o000A<ol000<0003oooooool09_ooo`03o`2Ioooooooo057oool0
08ooool200004S?o00030000oooooooo02Koool00ol0VOooooooo`1Aoooo002?oooo00<0000co`0c
o`004C?o00030000oooooooo02Koool00ol0VOooooooo`1Aoooo002?oooo00<0000co`0co`004C?o
00030000oooooooo02Koool00ol0VOooooooo`1Aoooo002?oooo00<0000co`0co`0043?o00030000
oooooooo02Ooool00ol0VOooooooo`1Aoooo002?oooo00<0000co`0co`0043?o00030000oooooooo
02Ooool00ol0VOooooooo`1Aoooo002?oooo00<0000co`0co`0043?o00030000oooooooo02Ooool0
0ol0VOooooooo`1Aoooo002?oooo00<0000co`0co`0043?o00030000oooooooo02Ooool00ol0VOoo
ooooo`1Aoooo002?oooo0P00010co`000`000?ooooooo`0Xoooo00?o09Woooooool0DOooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`0Xoooo00?o09Woooooool0DOooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`0Xoooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol0
00lco`000`000?ooooooo`0Xoooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol000lco`00
0`000?ooooooo`0Xoooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol000hco`000`000?oo
ooooo`0Yoooo00?o09Woooooool0DOooo`00Soooo`80000?<ol000<0003oooooool0:Oooo`03o`2I
oooooooo057oool008ooool00`0003?o03?o000><ol000<0003oooooool0:Oooo`03o`2Ioooooooo
057oool008ooool00`0003?o03?o000><ol000<0003oooooool0:Oooo`03o`2Ioooooooo057oool0
08ooool00`0003?o03?o000=<ol000<0003oooooool0:_ooo`03o`2Ioooooooo057oool008Ooool4
00001?ooo`030000<ol0<ol000dco`000`000?ooooooo`0Zoooo00?o09Woooooool0DOooo`00Qooo
o`030000oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool0:_ooo`03o`2Ioooooooo
057oool008Soool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`0Zoooo00?o09Wooooo
ool0DOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0:_oo
o`03o`2Ioooooooo057oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0
003oooooool0:oooo`03o`2Ioooooooo057oool008Soool200001Oooo`030000<ol0<ol000`co`00
0`000?ooooooo`0[oooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol000`co`000`000?oo
ooooo`0[oooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0[
oooo00?o09Woooooool0DOooo`00Soooo`80000=<ol000<0003oooooool0:oooo`03o`2Ioooooooo
057oool008ooool00`0003?o03?o000<<ol000<0003oooooool0:oooo`03o`2Ioooooooo057oool0
08ooool00`0003?o03?o000;<ol000<0003oooooool0;?ooo`03o`2Ioooooooo057oool008ooool0
0`0003?o03?o000;<ol000<0003oooooool0;?ooo`03o`2Ioooooooo057oool008ooool00`0003?o
03?o000;<ol000<0003oooooool0;?ooo`03o`2Ioooooooo057oool008ooool00`0003?o03?o000;
<ol000<0003oooooool0;?ooo`03o`2Ioooooooo057oool008ooool00`0003?o03?o000;<ol000<0
003oooooool0;?ooo`03o`2Ioooooooo057oool008ooool2000033?o00030000oooooooo02coool0
0ol0VOooooooo`1Aoooo002?oooo00<0000co`0co`002c?o00030000oooooooo02coool00ol0VOoo
ooooo`1Aoooo002?oooo00<0000co`0co`002S?o00030000oooooooo02goool00ol0VOooooooo`1A
oooo002?oooo00<0000co`0co`002S?o00030000oooooooo02goool00ol0VOooooooo`1Aoooo002?
oooo00<0000co`0co`002S?o00030000oooooooo02goool00ol0VOooooooo`1Aoooo002?oooo00<0
000co`0co`002S?o00030000oooooooo02goool00ol0VOooooooo`1Aoooo002?oooo0P0000/co`00
0`000?ooooooo`0]oooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0]oooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0]
oooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0^oooo00?o
09Woooooool0DOooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0^oooo00?o09Wooooo
ool0DOooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0^oooo00?o09Woooooool0DOoo
o`00Soooo`80000:<ol000<0003oooooool0;_ooo`03o`2Ioooooooo057oool008ooool00`0003?o
03?o0009<ol000<0003oooooool0;_ooo`03o`2Ioooooooo057oool008ooool00`0003?o03?o0009
<ol000<0003oooooool0;_ooo`03o`2Ioooooooo057oool008ooool00`0003?o03?o0008<ol000<0
003oooooool0;oooo`03o`2Ioooooooo057oool008Soool200001Oooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0_oooo00?o09Woooooool0DOooo`00Qoooo`040000oooooooo00001?ooo`030000
<ol0<ol000Pco`000`000?ooooooo`0_oooo00?o09Woooooool0DOooo`00ROooo`030000oooooooo
00?oool3000023?o00030000oooooooo02ooool00ol0VOooooooo`1Aoooo002:oooo00<0003ooooo
ool00_ooo`030000<ol0<ol000Pco`000`000?ooooooo`0_oooo00?o09Woooooool0DOooo`00Qooo
o`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0_oooo00?o09Wooooo
ool0DOooo`00R?ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo033oool00ol0VOoo
ooooo`1Aoooo002?oooo00<0000co`0co`001c?o00030000oooooooo033oool00ol0VOooooooo`1A
oooo002?oooo00<0000co`0co`001c?o00030000oooooooo033oool00ol0VOooooooo`1Aoooo002?
oooo00<0000co`0co`001c?o00030000oooooooo033oool00ol0VOooooooo`1Aoooo002?oooo0P00
00Pco`000`000?ooooooo`0`oooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0`oooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0`oooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0`
oooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0aoooo00?o
09Woooooool0DOooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0aoooo00?o09Wooooo
ool0DOooo`00Soooo`800007<ol000<0003oooooool0<Oooo`03o`2Ioooooooo057oool008ooool0
0`0003?o03?o0006<ol000<0003oooooool0<Oooo`03o`2Ioooooooo057oool008ooool00`0003?o
03?o0006<ol000<0003oooooool0<Oooo`03o`2Ioooooooo057oool008ooool00`0003?o03?o0006
<ol000<0003oooooool0<Oooo`03o`2Ioooooooo057oool008ooool00`0003?o03?o0006<ol000<0
003oooooool0<Oooo`03o`2Ioooooooo057oool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool0<Oooo`03o`2Ioooooooo057oool008ooool200001S?o00030000oooooooo03;oool00ol0VOoo
ooooo`1Aoooo002?oooo00<0000co`0co`001C?o00030000oooooooo03;oool00ol0VOooooooo`1A
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo03;oool00ol0VOooooooo`1Aoooo002?
oooo00<0000co`0co`001C?o00030000oooooooo03;oool00ol0VOooooooo`1Aoooo002?oooo00<0
000co`0co`001C?o00030000oooooooo03;oool00ol0VOooooooo`1Aoooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo03;oool00ol0VOooooooo`1Aoooo002?oooo0P0000Hco`000`000?oo
ooooo`0boooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0b
oooo00?o09Woooooool0DOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0boooo00?o
09Woooooool0DOooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0coooo00?o09Wooooo
ool0DOooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0coooo00?o09Woooooool0DOoo
o`00ROooo`<00003oooo00<0000co`0co`0013?o00030000oooooooo03?oool00ol0VOooooooo`1A
oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`0coooo00?o
09Woooooool0DOooo`00Qoooo`D00003oooo0`0000@co`000`000?ooooooo`0coooo00?o09Wooooo
ool0DOooo`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?oo
o`Lco`2:oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool0
07Woool00`000?ooooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000<co`02000000@co`3oooooooooool2
00000oooo`@00003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00Lco`02oooo00@0003ooooo
ool00002oooo00<0003oooooool01?ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool03_ooo`030000oooo<ol000Hco`02oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000
<ol0<ol000Dco`02oooo00@0003oooooool00004oooo00<0003oooooool00_ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00006<ol00_ooo`040000
oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Woool00`000?oo
ooooo`0Aoooo0P0000Lco`03oooo0P0000Coool200000oooo`030000oooooooo07Woool008ooool7
<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.72912 .12361 L
.73838 .12361 L
.74309 .12361 L
.74546 .12361 L
.74611 .12361 L
.7468 .12361 L
s
.7468 .12361 m
.74731 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.23739 .12361 L
.24276 .12361 L
.24745 .12361 L
.24873 .12361 L
.25012 .12361 L
.25142 .12361 L
.25261 .12337 L
.25377 .12218 L
.25484 .12109 L
.25728 .11868 L
.26171 .11447 L
.28051 .09913 L
.30084 .08647 L
.31199 .08098 L
.32225 .07673 L
.33268 .07309 L
.34242 .07027 L
.36125 .06618 L
.37122 .06464 L
.37677 .06394 L
.38191 .0634 L
.39208 .06258 L
.39745 .06228 L
.40019 .06215 L
.40315 .06204 L
.40572 .06196 L
.40808 .0619 L
.41034 .06186 L
.41158 .06184 L
.41271 .06183 L
.41398 .06182 L
.41467 .06181 L
.41533 .06181 L
.41649 .0618 L
.41776 .0618 L
.41842 .0618 L
.41915 .06181 L
.41991 .06181 L
.42062 .06181 L
.4219 .06182 L
.42327 .06184 L
.42582 .06188 L
Mistroke
.42853 .06193 L
.4334 .06206 L
.4392 .06228 L
.44444 .06252 L
.46455 .0638 L
.48383 .06547 L
.49377 .06646 L
.49903 .06701 L
.50193 .06731 L
.50467 .06754 L
.50726 .06771 L
.50863 .06779 L
.51008 .06786 L
.51129 .0679 L
.51264 .06795 L
.51386 .06798 L
.515 .068 L
.51619 .06802 L
.51743 .06803 L
.51849 .06803 L
.51965 .06803 L
.5209 .06802 L
.5216 .06801 L
.52224 .068 L
.52464 .06795 L
.52596 .06791 L
.52736 .06786 L
.52985 .06776 L
.53549 .06745 L
.54037 .0671 L
.54572 .06664 L
.56521 .06439 L
.58611 .06123 L
.62744 .05358 L
.66725 .04537 L
.70555 .03752 L
.72491 .03382 L
.7352 .03199 L
.74061 .03108 L
.74356 .0306 L
.74499 .03037 L
.7463 .03016 L
.74755 .02996 L
.74874 .12361 L
.74998 .12361 L
.75134 .12361 L
.75685 .12361 L
.76653 .12361 L
.78554 .12361 L
.82642 .12361 L
Mistroke
.86579 .12361 L
.90365 .12361 L
.94396 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0hoooo1@1Voe7oool0
08ooool00`000?ooooooo`0doooo101Vo`Coool00`1Vooooooooo`1?oooo002?oooo00<0003ooooo
ool0;oooo`D0I_l8oooo00<0I_ooooooool0Coooo`00Soooo`030000oooooooo02[oool506Ko3Ooo
o`0306Kooooooooo04ooool008ooool00`000?ooooooo`0Uoooo1@1Voa;oool00`1Vooooooooo`1?
oooo002?oooo0P00027oool506Ko5oooo`0306Kooooooooo04ooool008ooool00`000?ooooooo`0K
oooo1@1Voacoool00`1Vooooooooo`1?oooo002?oooo00<0003oooooool05_ooo`D0I_lQoooo00<0
I_ooooooool0Coooo`00K_oooa/0I_l6oooo00<0003oooooool03?ooo`X0I_lVoooo00<0I_oooooo
ool0Coooo`00J_ooo`@0I_lKoooo1P1Vo`03000006Ko06Ko00`0I_l`oooo00<0I_ooooooool0Cooo
o`00Ioooo`<0I_lUoooo00<0003oooooool0??ooo`0306Kooooooooo04ooool006Coool306Ko:?oo
o`80000moooo00<0I_ooooooool0Coooo`005oooo`@0000ioooo1@0000Soool306Ko:oooo`030000
oooooooo03Ooool5000000<0I_ooooooool0=Oooo`@0000Foooo000Goooo00<0003oooooool0??oo
o`030000oooooooo00Goool306Ko;_ooo`030000oooooooo03Woool010000?ooooooo`1VocOoool0
0`000?ooooooo`0Goooo000Hoooo00<0003oooooool0>oooo`030000oooooooo00?oool206Ko<Ooo
o`030000oooooooo03Woool010000?ooooooo`1VocSoool00`000?ooooooo`0Foooo000Aoooo1000
00Coool00`000?ooooooo`0boooo100000Coool010000?ooooooooooo`80I_lcoooo00<0003ooooo
ool0>Oooo`040000oooooooo06Ko>Oooo`030000oooooooo01Goool001Ooool010000?ooooooo`00
03_oool010000?ooo`1Vo`1VocGoool00`000?ooooooo`0ioooo00@0003oooooool0I_lgoooo00@0
003oooooool0000Foooo000Hoooo0P0003_oool2000000<0I_ooooooool0=Oooo`80000ioooo0P00
00;oool00`1Vooooooooo`0foooo0P0001Ooool005Koool00`1Vooooooooo`0foooo00<0003ooooo
ool0??ooo`0306Kooooooooo04ooool005Goool00`1Vooooooooo`0goooo00<0003oooooool0??oo
o`0306Kooooooooo04ooool005Coool00`1Vooooooooo`0hoooo00<0003oooooool0??ooo`0306Ko
oooooooo04ooool005?oool00`1Vooooooooo`0ioooo00<0003oooooool0??ooo`0306Kooooooooo
04ooool0057oool206Ko??ooo`030000oooooooo03coool00`1Vooooooooo`1?oooo000@ooooo`00
017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`00100003?o03?o0?l0V@Dco`0R00001_ooo`030000oooooooo00Woool00`000?oo
ooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000i
<ol00`000003o`2I0000000000<0000doooo00<0003oooooool05Oooo`00Soooo`030000<ol0<ol0
03<co`0600000oooo`03o`2Ioooooooo04ooool008ooool00`0003?o03?o000a<ol00P0000Woool0
0ol0VOooooooo`1?oooo002?oooo00<0000co`0co`00;c?o0080000;oooo00?o09Woooooool0Cooo
o`00Soooo`030000<ol0<ol002`co`0300003Oooo`03o`2Ioooooooo04ooool008ooool20000:S?o
00<0000@oooo00?o09Woooooool0Coooo`00Soooo`030000<ol0<ol002Lco`0200004oooo`03o`2I
oooooooo04ooool008ooool00`0003?o03?o000V<ol000<0003oooooool04oooo`03o`2Ioooooooo
04ooool008ooool00`0003?o03?o000U<ol000<0003oooooool05?ooo`03o`2Ioooooooo04ooool0
08ooool00`0003?o03?o000T<ol000<0003oooooool05Oooo`03o`2Ioooooooo04ooool008ooool0
0`0003?o03?o000R<ol00P0001Soool00ol0VOooooooo`1?oooo002?oooo0P00028co`000`000?oo
ooooo`0Hoooo00?o09Woooooool0Coooo`00Soooo`030000<ol0<ol0020co`000`000?ooooooo`0I
oooo00?o09Woooooool0Coooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0Joooo00?o
09Woooooool0Coooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0Joooo00?o09Wooooo
ool0Coooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`0Koooo00?o09Woooooool0Cooo
o`00Soooo`030000<ol0<ol001dco`000`000?ooooooo`0Loooo00?o09Woooooool0Coooo`00Sooo
o`80000M<ol000<0003oooooool07Oooo`03o`2Ioooooooo04ooool008ooool00`0003?o03?o000K
<ol000<0003oooooool07_ooo`03o`2Ioooooooo04ooool008ooool00`0003?o03?o000K<ol000<0
003oooooool07_ooo`03o`2Ioooooooo04ooool008ooool00`0003?o03?o000J<ol000<0003ooooo
ool07oooo`03o`2Ioooooooo04ooool008ooool00`0003?o03?o000J<ol000<0003oooooool07ooo
o`03o`2Ioooooooo04ooool008ooool00`0003?o03?o000I<ol000<0003oooooool08?ooo`03o`2I
oooooooo04ooool008ooool200006S?o00030000oooooooo023oool00ol0VOooooooo`1?oooo002?
oooo00<0000co`0co`0063?o00030000oooooooo027oool00ol0VOooooooo`1?oooo002?oooo00<0
000co`0co`0063?o00030000oooooooo027oool00ol0VOooooooo`1?oooo002?oooo00<0000co`0c
o`005c?o00030000oooooooo02;oool00ol0VOooooooo`1?oooo002?oooo00<0000co`0co`005c?o
00030000oooooooo02;oool00ol0VOooooooo`1?oooo0027oooo1@0000?oool00`0003?o03?o000F
<ol000<0003oooooool08oooo`03o`2Ioooooooo04ooool008Woool00`000?ooooooo`03oooo00<0
000co`0co`005S?o00030000oooooooo02?oool00ol0VOooooooo`1?oooo0029oooo00<0003ooooo
ool00oooo`<0000E<ol000<0003oooooool09?ooo`03o`2Ioooooooo04ooool008Woool00`000?oo
ooooo`03oooo00<0000co`0co`005C?o00030000oooooooo02Coool00ol0VOooooooo`1?oooo0029
oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`0Toooo00?o09Wooooo
ool0Coooo`00R?ooo`800005oooo00<0000co`0co`0053?o00030000oooooooo02Goool00ol0VOoo
ooooo`1?oooo002?oooo00<0000co`0co`0053?o00030000oooooooo02Goool00ol0VOooooooo`1?
oooo002?oooo00<0000co`0co`004c?o00030000oooooooo02Koool00ol0VOooooooo`1?oooo002?
oooo0P0001@co`000`000?ooooooo`0Voooo00?o09Woooooool0Coooo`00Soooo`030000<ol0<ol0
01<co`000`000?ooooooo`0Voooo00?o09Woooooool0Coooo`00Soooo`030000<ol0<ol0018co`00
0`000?ooooooo`0Woooo00?o09Woooooool0Coooo`00Soooo`030000<ol0<ol0018co`000`000?oo
ooooo`0Woooo00?o09Woooooool0Coooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0W
oooo00?o09Woooooool0Coooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Xoooo00?o
09Woooooool0Coooo`00Soooo`80000B<ol000<0003oooooool0:?ooo`03o`2Ioooooooo04ooool0
08ooool00`0003?o03?o000A<ol000<0003oooooool0:?ooo`03o`2Ioooooooo04ooool008ooool0
0`0003?o03?o000A<ol000<0003oooooool0:?ooo`03o`2Ioooooooo04ooool008ooool00`0003?o
03?o000@<ol000<0003oooooool0:Oooo`03o`2Ioooooooo04ooool008ooool00`0003?o03?o000@
<ol000<0003oooooool0:Oooo`03o`2Ioooooooo04ooool008ooool00`0003?o03?o000@<ol000<0
003oooooool0:Oooo`03o`2Ioooooooo04ooool008ooool00`0003?o03?o000@<ol000<0003ooooo
ool0:Oooo`03o`2Ioooooooo04ooool008ooool2000043?o00030000oooooooo02[oool00ol0VOoo
ooooo`1?oooo002?oooo00<0000co`0co`003c?o00030000oooooooo02[oool00ol0VOooooooo`1?
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo02[oool00ol0VOooooooo`1?oooo002?
oooo00<0000co`0co`003c?o00030000oooooooo02[oool00ol0VOooooooo`1?oooo002?oooo00<0
000co`0co`003c?o00030000oooooooo02[oool00ol0VOooooooo`1?oooo002?oooo00<0000co`0c
o`003S?o00030000oooooooo02_oool00ol0VOooooooo`1?oooo002?oooo0P0000lco`000`000?oo
ooooo`0[oooo00?o09Woooooool0Coooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0[
oooo00?o09Woooooool0Coooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0[oooo00?o
09Woooooool0Coooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`0/oooo00?o09Wooooo
ool0Coooo`00Qoooo`@00004oooo00<0000co`0co`003C?o00030000oooooooo02coool00ol0VOoo
ooooo`1?oooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`0/
oooo00?o09Woooooool0Coooo`00R?ooo`030000oooooooo00Coool300003C?o00030000oooooooo
02coool00ol0VOooooooo`1?oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000dco`00
0`000?ooooooo`0/oooo00?o09Woooooool0Coooo`00Qoooo`040000oooooooo00001?ooo`030000
<ol0<ol000`co`000`000?ooooooo`0]oooo00?o09Woooooool0Coooo`00R?ooo`800005oooo00<0
000co`0co`0033?o00030000oooooooo02goool00ol0VOooooooo`1?oooo002?oooo00<0000co`0c
o`0033?o00030000oooooooo02goool00ol0VOooooooo`1?oooo002?oooo00<0000co`0co`0033?o
00030000oooooooo02goool00ol0VOooooooo`1?oooo002?oooo0P0000dco`000`000?ooooooo`0]
oooo00?o09Woooooool0Coooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0]oooo00?o
09Woooooool0Coooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0^oooo00?o09Wooooo
ool0Coooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0^oooo00?o09Woooooool0Cooo
o`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0^oooo00?o09Woooooool0Coooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`0^oooo00?o09Woooooool0Coooo`00Soooo`030000
<ol0<ol000/co`000`000?ooooooo`0^oooo00?o09Woooooool0Coooo`00Soooo`80000<<ol000<0
003oooooool0;_ooo`03o`2Ioooooooo04ooool008ooool00`0003?o03?o000;<ol000<0003ooooo
ool0;_ooo`03o`2Ioooooooo04ooool008ooool00`0003?o03?o000:<ol000<0003oooooool0;ooo
o`03o`2Ioooooooo04ooool008ooool00`0003?o03?o000:<ol000<0003oooooool0;oooo`03o`2I
oooooooo04ooool008ooool00`0003?o03?o000:<ol000<0003oooooool0;oooo`03o`2Ioooooooo
04ooool008ooool00`0003?o03?o000:<ol000<0003oooooool0;oooo`03o`2Ioooooooo04ooool0
08ooool200002c?o00030000oooooooo02ooool00ol0VOooooooo`1?oooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo02ooool00ol0VOooooooo`1?oooo002?oooo00<0000co`0co`002S?o
00030000oooooooo02ooool00ol0VOooooooo`1?oooo002?oooo00<0000co`0co`002C?o00030000
oooooooo033oool00ol0VOooooooo`1?oooo002?oooo00<0000co`0co`002C?o00030000oooooooo
033oool00ol0VOooooooo`1?oooo002?oooo00<0000co`0co`002C?o00030000oooooooo033oool0
0ol0VOooooooo`1?oooo002?oooo0P0000Xco`000`000?ooooooo`0`oooo00?o09Woooooool0Cooo
o`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0`oooo00?o09Woooooool0Coooo`00Sooo
o`030000<ol0<ol000Tco`000`000?ooooooo`0`oooo00?o09Woooooool0Coooo`00Soooo`030000
<ol0<ol000Pco`000`000?ooooooo`0aoooo00?o09Woooooool0Coooo`00R?ooo`800005oooo00<0
000co`0co`0023?o00030000oooooooo037oool00ol0VOooooooo`1?oooo0027oooo00@0003ooooo
ool00004oooo00<0000co`0co`0023?o00030000oooooooo037oool00ol0VOooooooo`1?oooo0029
oooo00<0003oooooool00oooo`<00008<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04ooool0
08[oool00`000?ooooooo`02oooo00<0000co`0co`0023?o00030000oooooooo037oool00ol0VOoo
ooooo`1?oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo
037oool00ol0VOooooooo`1?oooo0028oooo0P0000Goool00`0003?o03?o0007<ol000<0003ooooo
ool0<_ooo`03o`2Ioooooooo04ooool008ooool00`0003?o03?o0007<ol000<0003oooooool0<_oo
o`03o`2Ioooooooo04ooool008ooool00`0003?o03?o0007<ol000<0003oooooool0<_ooo`03o`2I
oooooooo04ooool008ooool00`0003?o03?o0007<ol000<0003oooooool0<_ooo`03o`2Ioooooooo
04ooool008ooool2000023?o00030000oooooooo03;oool00ol0VOooooooo`1?oooo002?oooo00<0
000co`0co`001c?o00030000oooooooo03;oool00ol0VOooooooo`1?oooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo03;oool00ol0VOooooooo`1?oooo002?oooo00<0000co`0co`001c?o
00030000oooooooo03;oool00ol0VOooooooo`1?oooo002?oooo00<0000co`0co`001S?o00030000
oooooooo03?oool00ol0VOooooooo`1?oooo002?oooo00<0000co`0co`001S?o00030000oooooooo
03?oool00ol0VOooooooo`1?oooo002?oooo0P0000Lco`000`000?ooooooo`0coooo00?o09Wooooo
ool0Coooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0coooo00?o09Woooooool0Cooo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0coooo00?o09Woooooool0Coooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`0coooo00?o09Woooooool0Coooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`0coooo00?o09Woooooool0Coooo`00Soooo`030000<ol0<ol0
00Hco`000`000?ooooooo`0coooo00?o09Woooooool0Coooo`00Soooo`800006<ol000<0003ooooo
ool0=?ooo`03o`2Ioooooooo04ooool008ooool00`0003?o03?o0005<ol000<0003oooooool0=?oo
o`03o`2Ioooooooo04ooool008ooool00`0003?o03?o0005<ol000<0003oooooool0=?ooo`03o`2I
oooooooo04ooool008ooool00`0003?o03?o0005<ol000<0003oooooool0=?ooo`03o`2Ioooooooo
04ooool008ooool00`0003?o03?o0005<ol000<0003oooooool0=?ooo`03o`2Ioooooooo04ooool0
08ooool00`0003?o03?o0005<ol000<0003oooooool0=?ooo`03o`2Ioooooooo04ooool008ooool2
00001S?o00030000oooooooo03Coool00ol0VOooooooo`1?oooo002?oooo00<0000co`0co`001C?o
00030000oooooooo03Coool00ol0VOooooooo`1?oooo002?oooo00<0000co`0co`001C?o00030000
oooooooo03Coool00ol0VOooooooo`1?oooo002?oooo00<0000co`0co`0013?o00030000oooooooo
03Goool00ol0VOooooooo`1?oooo002?oooo00<0000co`0co`0013?o00030000oooooooo03Goool0
0ol0VOooooooo`1?oooo0029oooo0`0000?oool00`0003?o03?o0004<ol000<0003oooooool0=Ooo
o`03o`2Ioooooooo04ooool008[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o00030000
oooooooo03Goool00ol0VOooooooo`1?oooo0027oooo1@0000?oool3000013?o00030000oooooooo
03Goool00ol0VOooooooo`1?oooo0027oooo00@0003oooooool00004oooo1c?o08[oool008Soool0
0`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o08[oool0
08ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?oooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000c?o00800000
13?o0?ooooooooooo`800005oooo0`0000;oool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool01c?o
00;oool010000?ooooooo`0000Goool01@000?ooooooooooo`00001joooo001goooo00<0003ooooo
ool00_ooo`030000oooooooo00koool00`000?oooc?o0006<ol00_ooo`040000oooooooo00000_oo
o`D00003oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0000co`0c
o`001C?o00;oool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00001S?o00;oool010000?oo
ooooo`0000?oool00`000?ooo`000003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo
017oool200001c?o00?oool200001Oooo`800002oooo00<0003oooooool0NOooo`00Soooo`Lco`2:
oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.73838 .12361 L
.74309 .12361 L
.74806 .12361 L
.75066 .12361 L
.75137 .12361 L
.75214 .12361 L
s
.75214 .12361 m
.75242 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.23739 .12361 L
.24276 .12361 L
.24502 .12361 L
.24627 .12361 L
.24745 .12361 L
.24812 .12309 L
.24884 .12235 L
.25012 .12105 L
.25261 .11858 L
.26171 .11022 L
.28303 .09417 L
.30236 .08326 L
.3225 .0749 L
.34148 .0693 L
.35125 .06715 L
.36156 .06534 L
.37037 .06414 L
.38004 .06314 L
.38528 .06272 L
.39024 .06241 L
.3947 .06218 L
.39955 .062 L
.40205 .06193 L
.40481 .06187 L
.4062 .06185 L
.4077 .06183 L
.40839 .06182 L
.40911 .06182 L
.41041 .06181 L
.41161 .0618 L
.4129 .0618 L
.41411 .06181 L
.41521 .06181 L
.41651 .06182 L
.41791 .06183 L
.42046 .06187 L
.42282 .06191 L
.42535 .06197 L
.42992 .06211 L
.43536 .06231 L
.44034 .06255 L
.46138 .06392 L
Mistroke
.4804 .06559 L
.49128 .06669 L
.50114 .06775 L
.50602 .06817 L
.50877 .06834 L
.5113 .06846 L
.51351 .06853 L
.51477 .06856 L
.51595 .06858 L
.51719 .0686 L
.51831 .06861 L
.51962 .06861 L
.52085 .0686 L
.52206 .06859 L
.52274 .06858 L
.52339 .06857 L
.52608 .06851 L
.52841 .06843 L
.53091 .06833 L
.53661 .06801 L
.54184 .06763 L
.55167 .06672 L
.5608 .06567 L
.58151 .06274 L
.62061 .05578 L
.66216 .04734 L
.7022 .03905 L
.72055 .03545 L
.73097 .03351 L
.74071 .03179 L
.74565 .03097 L
.74807 .03057 L
.75032 .03021 L
.75157 .03001 L
.7522 .02991 L
.7529 .12361 L
.7536 .12361 L
.75435 .12361 L
.75571 .12361 L
.76063 .12361 L
.78168 .12361 L
.82279 .12361 L
.86238 .12361 L
.90046 .12361 L
.94099 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0joooo101Voe3oool0
08ooool00`000?ooooooo`0coooo1`1Vo`?oool00`1Vooooooooo`1>oooo002?oooo00<0003ooooo
ool0;_ooo`D0I_l:oooo00<0I_ooooooool0C_ooo`00Soooo`030000oooooooo02Woool506Ko3ooo
o`0306Kooooooooo04koool008ooool00`000?ooooooo`0Toooo1@1VoaCoool00`1Vooooooooo`1>
oooo002?oooo0P00023oool506Ko6Oooo`0306Kooooooooo04koool008ooool00`000?ooooooo`0J
oooo1@1Voakoool00`1Vooooooooo`1>oooo002?oooo00<0003oooooool05Oooo`D0I_lSoooo00<0
I_ooooooool0C_ooo`00K_oooaX0I_l7oooo00<0003oooooool04?ooo`D0I_lXoooo00<0I_oooooo
ool0C_ooo`00JOooo`D0I_lJoooo1`1Vo`03000006Ko06Ko0100I_l]oooo00<0I_ooooooool0C_oo
o`00IOooo`@0I_lVoooo00<0003oooooool0?Oooo`0306Kooooooooo04koool0067oool406Ko:_oo
o`80000noooo00<0I_ooooooool0C_ooo`005oooo`@0000ioooo1@0000Koool206Ko;_ooo`030000
oooooooo03Ooool5000000?oool0I_ooool0=Oooo`@0000Foooo000Goooo00<0003oooooool0??oo
o`030000oooooooo00Coool206Ko<?ooo`030000oooooooo03Woool01@000?ooooooooooo`1Vo`0f
oooo00<0003oooooool05oooo`006?ooo`030000oooooooo03_oool00`000?ooooooo`02oooo0P1V
oc;oool00`000?ooooooo`0ioooo00D0003oooooooooool0I_l0=oooo`030000oooooooo01Koool0
017oool400001?ooo`030000oooooooo03;oool400001?ooo`030000oooooooo0080I_ldoooo00<0
003oooooool0>Oooo`050000oooooooooooo06Ko03Soool00`000?ooooooo`0Eoooo000Goooo00@0
003oooooool0000koooo00<0003oool0I_l0=_ooo`030000oooooooo03Woool01@000?oooooooooo
o`1Vo`0foooo00@0003oooooool0000Foooo000Hoooo0P0003_oool2000000<0I_ooooooool0=Ooo
o`80000ioooo0P0000?oool00`1Vooooooooo`0eoooo0P0001Ooool005Goool206Ko>?ooo`030000
oooooooo03goool00`1Vooooooooo`1>oooo001Doooo00<0I_ooooooool0>?ooo`030000oooooooo
03goool00`1Vooooooooo`1>oooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo03goool0
0`1Vooooooooo`1>oooo001Aoooo0P1Voccoool00`000?ooooooo`0moooo00<0I_ooooooool0C_oo
o`00D?ooo`0306Kooooooooo03coool00`000?ooooooo`0moooo00<0I_ooooooool0C_ooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000D0000co`0co`0co`3o09T013?o02800006oooo00<0003oooooool02Ooo
o`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000
<ol0<ol003Tco`04000000?o09T0000000000P0003Coool00`000?ooooooo`0Eoooo002?oooo00<0
000co`0co`00<c?o00H00004oooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol0034co`02
00002_ooo`03o`2Ioooooooo04koool008ooool00`0003?o03?o000_<ol00P0000coool00ol0VOoo
ooooo`1>oooo002?oooo00<0000co`0co`00;3?o00<0000>oooo00?o09Woooooool0C_ooo`00Sooo
o`80000Z<ol00`00017oool00ol0VOooooooo`1>oooo002?oooo00<0000co`0co`009c?o0080000D
oooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol002Hco`000`000?ooooooo`0Doooo00?o
09Woooooool0C_ooo`00Soooo`030000<ol0<ol002Dco`000`000?ooooooo`0Eoooo00?o09Wooooo
ool0C_ooo`00Soooo`030000<ol0<ol002@co`000`000?ooooooo`0Foooo00?o09Woooooool0C_oo
o`00Soooo`030000<ol0<ol0028co`0200006Oooo`03o`2Ioooooooo04koool008ooool200008S?o
00030000oooooooo01Woool00ol0VOooooooo`1>oooo002?oooo00<0000co`0co`0083?o00030000
oooooooo01[oool00ol0VOooooooo`1>oooo002?oooo00<0000co`0co`007c?o00030000oooooooo
01_oool00ol0VOooooooo`1>oooo002?oooo00<0000co`0co`007c?o00030000oooooooo01_oool0
0ol0VOooooooo`1>oooo002?oooo00<0000co`0co`007S?o00030000oooooooo01coool00ol0VOoo
ooooo`1>oooo002?oooo00<0000co`0co`007C?o00030000oooooooo01goool00ol0VOooooooo`1>
oooo002?oooo0P0001dco`000`000?ooooooo`0Noooo00?o09Woooooool0C_ooo`00Soooo`030000
<ol0<ol001/co`000`000?ooooooo`0Ooooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol0
01/co`000`000?ooooooo`0Ooooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol001Xco`00
0`000?ooooooo`0Poooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol001Xco`000`000?oo
ooooo`0Poooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`0Q
oooo00?o09Woooooool0C_ooo`00Soooo`80000J<ol000<0003oooooool08Oooo`03o`2Ioooooooo
04koool008ooool00`0003?o03?o000H<ol000<0003oooooool08_ooo`03o`2Ioooooooo04koool0
08ooool00`0003?o03?o000H<ol000<0003oooooool08_ooo`03o`2Ioooooooo04koool008ooool0
0`0003?o03?o000G<ol000<0003oooooool08oooo`03o`2Ioooooooo04koool008ooool00`0003?o
03?o000G<ol000<0003oooooool08oooo`03o`2Ioooooooo04koool008Ooool500000oooo`030000
<ol0<ol001Hco`000`000?ooooooo`0Toooo00?o09Woooooool0C_ooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000F<ol000<0003oooooool09?ooo`03o`2Ioooooooo04koool008Woool0
0`000?ooooooo`03oooo0`0001Dco`000`000?ooooooo`0Uoooo00?o09Woooooool0C_ooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool09Oooo`03o`2Ioooooooo
04koool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo02Goool0
0ol0VOooooooo`1>oooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool09_oo
o`03o`2Ioooooooo04koool008ooool00`0003?o03?o000D<ol000<0003oooooool09_ooo`03o`2I
oooooooo04koool008ooool00`0003?o03?o000C<ol000<0003oooooool09oooo`03o`2Ioooooooo
04koool008ooool2000053?o00030000oooooooo02Ooool00ol0VOooooooo`1>oooo002?oooo00<0
000co`0co`004c?o00030000oooooooo02Ooool00ol0VOooooooo`1>oooo002?oooo00<0000co`0c
o`004S?o00030000oooooooo02Soool00ol0VOooooooo`1>oooo002?oooo00<0000co`0co`004S?o
00030000oooooooo02Soool00ol0VOooooooo`1>oooo002?oooo00<0000co`0co`004S?o00030000
oooooooo02Soool00ol0VOooooooo`1>oooo002?oooo00<0000co`0co`004C?o00030000oooooooo
02Woool00ol0VOooooooo`1>oooo002?oooo0P00018co`000`000?ooooooo`0Yoooo00?o09Wooooo
ool0C_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Yoooo00?o09Woooooool0C_oo
o`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0Yoooo00?o09Woooooool0C_ooo`00Sooo
o`030000<ol0<ol0010co`000`000?ooooooo`0Zoooo00?o09Woooooool0C_ooo`00Soooo`030000
<ol0<ol0010co`000`000?ooooooo`0Zoooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol0
010co`000`000?ooooooo`0Zoooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol0010co`00
0`000?ooooooo`0Zoooo00?o09Woooooool0C_ooo`00Soooo`80000@<ol000<0003oooooool0:ooo
o`03o`2Ioooooooo04koool008ooool00`0003?o03?o000?<ol000<0003oooooool0:oooo`03o`2I
oooooooo04koool008ooool00`0003?o03?o000?<ol000<0003oooooool0:oooo`03o`2Ioooooooo
04koool008ooool00`0003?o03?o000?<ol000<0003oooooool0:oooo`03o`2Ioooooooo04koool0
08ooool00`0003?o03?o000?<ol000<0003oooooool0:oooo`03o`2Ioooooooo04koool008ooool0
0`0003?o03?o000><ol000<0003oooooool0;?ooo`03o`2Ioooooooo04koool008ooool200003c?o
00030000oooooooo02coool00ol0VOooooooo`1>oooo002?oooo00<0000co`0co`003S?o00030000
oooooooo02coool00ol0VOooooooo`1>oooo002?oooo00<0000co`0co`003S?o00030000oooooooo
02coool00ol0VOooooooo`1>oooo002?oooo00<0000co`0co`003C?o00030000oooooooo02goool0
0ol0VOooooooo`1>oooo0027oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool0;Ooo
o`03o`2Ioooooooo04koool008Ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000
oooooooo02goool00ol0VOooooooo`1>oooo0028oooo00<0003oooooool01?ooo`<0000=<ol000<0
003oooooool0;Oooo`03o`2Ioooooooo04koool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`003C?o00030000oooooooo02goool00ol0VOooooooo`1>oooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0033?o00030000oooooooo02koool00ol0VOooooooo`1>oooo0028oooo0P00
00Goool00`0003?o03?o000<<ol000<0003oooooool0;_ooo`03o`2Ioooooooo04koool008ooool0
0`0003?o03?o000<<ol000<0003oooooool0;_ooo`03o`2Ioooooooo04koool008ooool00`0003?o
03?o000<<ol000<0003oooooool0;_ooo`03o`2Ioooooooo04koool008ooool200003C?o00030000
oooooooo02koool00ol0VOooooooo`1>oooo002?oooo00<0000co`0co`0033?o00030000oooooooo
02koool00ol0VOooooooo`1>oooo002?oooo00<0000co`0co`002c?o00030000oooooooo02ooool0
0ol0VOooooooo`1>oooo002?oooo00<0000co`0co`002c?o00030000oooooooo02ooool00ol0VOoo
ooooo`1>oooo002?oooo00<0000co`0co`002c?o00030000oooooooo02ooool00ol0VOooooooo`1>
oooo002?oooo00<0000co`0co`002c?o00030000oooooooo02ooool00ol0VOooooooo`1>oooo002?
oooo00<0000co`0co`002c?o00030000oooooooo02ooool00ol0VOooooooo`1>oooo002?oooo0P00
00`co`000`000?ooooooo`0_oooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`0_oooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`0`oooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0`
oooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0`oooo00?o
09Woooooool0C_ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0`oooo00?o09Wooooo
ool0C_ooo`00Soooo`80000;<ol000<0003oooooool0<?ooo`03o`2Ioooooooo04koool008ooool0
0`0003?o03?o000:<ol000<0003oooooool0<?ooo`03o`2Ioooooooo04koool008ooool00`0003?o
03?o000:<ol000<0003oooooool0<?ooo`03o`2Ioooooooo04koool008ooool00`0003?o03?o0009
<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04koool008ooool00`0003?o03?o0009<ol000<0
003oooooool0<Oooo`03o`2Ioooooooo04koool008ooool00`0003?o03?o0009<ol000<0003ooooo
ool0<Oooo`03o`2Ioooooooo04koool008ooool200002S?o00030000oooooooo037oool00ol0VOoo
ooooo`1>oooo002?oooo00<0000co`0co`002C?o00030000oooooooo037oool00ol0VOooooooo`1>
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo037oool00ol0VOooooooo`1>oooo002?
oooo00<0000co`0co`0023?o00030000oooooooo03;oool00ol0VOooooooo`1>oooo0028oooo0P00
00Goool00`0003?o03?o0008<ol000<0003oooooool0<_ooo`03o`2Ioooooooo04koool008Ooool0
10000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0<_ooo`03o`2Ioooooooo
04koool008Woool00`000?ooooooo`03oooo0`0000Pco`000`000?ooooooo`0boooo00?o09Wooooo
ool0C_ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0<_oo
o`03o`2Ioooooooo04koool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0
003oooooool0<_ooo`03o`2Ioooooooo04koool008Soool200001Oooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0coooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0coooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0c
oooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0coooo00?o
09Woooooool0C_ooo`00Soooo`800008<ol000<0003oooooool0<oooo`03o`2Ioooooooo04koool0
08ooool00`0003?o03?o0007<ol000<0003oooooool0<oooo`03o`2Ioooooooo04koool008ooool0
0`0003?o03?o0007<ol000<0003oooooool0<oooo`03o`2Ioooooooo04koool008ooool00`0003?o
03?o0007<ol000<0003oooooool0<oooo`03o`2Ioooooooo04koool008ooool00`0003?o03?o0006
<ol000<0003oooooool0=?ooo`03o`2Ioooooooo04koool008ooool00`0003?o03?o0006<ol000<0
003oooooool0=?ooo`03o`2Ioooooooo04koool008ooool200001c?o00030000oooooooo03Coool0
0ol0VOooooooo`1>oooo002?oooo00<0000co`0co`001S?o00030000oooooooo03Coool00ol0VOoo
ooooo`1>oooo002?oooo00<0000co`0co`001S?o00030000oooooooo03Coool00ol0VOooooooo`1>
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo03Coool00ol0VOooooooo`1>oooo002?
oooo00<0000co`0co`001S?o00030000oooooooo03Coool00ol0VOooooooo`1>oooo002?oooo00<0
000co`0co`001S?o00030000oooooooo03Coool00ol0VOooooooo`1>oooo002?oooo0P0000Hco`00
0`000?ooooooo`0eoooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`0eoooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0e
oooo00?o09Woooooool0C_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0eoooo00?o
09Woooooool0C_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0eoooo00?o09Wooooo
ool0C_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0eoooo00?o09Woooooool0C_oo
o`00Soooo`800006<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04koool008ooool00`0003?o
03?o0005<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04koool008ooool00`0003?o03?o0005
<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04koool008ooool00`0003?o03?o0004<ol000<0
003oooooool0=_ooo`03o`2Ioooooooo04koool008ooool00`0003?o03?o0004<ol000<0003ooooo
ool0=_ooo`03o`2Ioooooooo04koool008Woool300000oooo`030000<ol0<ol000@co`000`000?oo
ooooo`0foooo00?o09Woooooool0C_ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0004
<ol000<0003oooooool0=_ooo`03o`2Ioooooooo04koool008Ooool500000oooo`<00004<ol000<0
003oooooool0=_ooo`03o`2Ioooooooo04koool008Ooool010000?ooooooo`0000Coool7<ol0R_oo
o`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7
<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>oooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o00ooool00`000?oo
ooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003
<ol00P000004<ol0oooooooooooo0P0000?oool300001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?oo
ooooo`07<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooo<ol000Hco`02
oooo00@0003oooooool00002oooo00@0003oooooool00004oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000>oooo00<0000co`0co`001C?o00;oool010000?ooooooo`0000;oool3
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00006<ol00_ooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool04Oooo`800007<ol00oooo`800004oooo0`0000;oool00`000?oo
ooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.73838 .12361 L
.74806 .12361 L
.75071 .12361 L
.75351 .12361 L
.75467 .12361 L
.75591 .12361 L
.75662 .12361 L
s
.75662 .12361 m
.75687 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.23739 .12361 L
.24016 .12361 L
.24152 .12361 L
.24276 .12361 L
.24392 .12251 L
.24502 .12139 L
.24745 .11897 L
.25261 .11408 L
.26171 .10622 L
.28174 .09197 L
.2999 .08216 L
.31958 .07427 L
.33037 .07096 L
.34055 .06841 L
.35031 .06643 L
.36063 .06478 L
.36943 .0637 L
.3791 .06282 L
.38434 .06247 L
.3893 .06221 L
.39376 .06203 L
.39628 .06196 L
.39861 .0619 L
.3998 .06188 L
.40109 .06186 L
.40221 .06184 L
.40343 .06183 L
.40478 .06181 L
.40552 .06181 L
.4062 .06181 L
.40744 .0618 L
.40875 .0618 L
.40947 .06181 L
.41014 .06181 L
.41088 .06181 L
.41165 .06182 L
.41296 .06183 L
.41439 .06185 L
.41704 .06189 L
.41952 .06194 L
.4245 .06208 L
.42993 .06229 L
Mistroke
.43981 .06278 L
.45835 .06406 L
.47806 .06583 L
.49904 .06806 L
.50406 .06857 L
.50659 .06876 L
.50936 .06893 L
.51081 .069 L
.51236 .06906 L
.5138 .06911 L
.51516 .06914 L
.5165 .06917 L
.51726 .06918 L
.51795 .06919 L
.51919 .06919 L
.5205 .06919 L
.52174 .06919 L
.52288 .06918 L
.52413 .06916 L
.52545 .06913 L
.52767 .06907 L
.5301 .06898 L
.53558 .06871 L
.54068 .06837 L
.55123 .06745 L
.56118 .06634 L
.57978 .06378 L
.6183 .05709 L
.65927 .04885 L
.69872 .04065 L
.73666 .03328 L
.74666 .03153 L
.75159 .03071 L
.75375 .03036 L
.7549 .03018 L
.75615 .02998 L
.75745 .12361 L
.75868 .12361 L
.76138 .12361 L
.76708 .12361 L
.77705 .12361 L
.81816 .12361 L
.85775 .12361 L
.89583 .12361 L
.93636 .12361 L
.97537 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0goooo201Vodooool0
08ooool00`000?ooooooo`0boooo1@1Vo`Ooool00`1Vooooooooo`1=oooo002?oooo00<0003ooooo
ool0;Oooo`D0I_l<oooo00<0I_ooooooool0COooo`00Soooo`030000oooooooo02Soool506Ko4Ooo
o`0306Kooooooooo04goool008ooool00`000?ooooooo`0Toooo101VoaKoool00`1Vooooooooo`1=
oooo002?oooo0P0002;oool306Ko6_ooo`0306Kooooooooo04goool008ooool00`000?ooooooo`0M
oooo101Voagoool00`1Vooooooooo`1=oooo002?oooo00<0003oooooool05oooo`H0I_lQoooo00<0
I_ooooooool0COooo`00Jooooa`0I_l8oooo00<0003oooooool03oooo`P0I_lWoooo00<0I_oooooo
ool0COooo`00I_ooo`D0I_lLoooo201Vo`03000006Ko06Ko00Koool906Ko;oooo`0306Kooooooooo
04goool006?oool306Ko:Oooo`030000oooo06Ko00H0I_lhoooo00<0I_ooooooool0COooo`00H?oo
o`<0I_l/oooo0P0003ooool00`1Vooooooooo`1=oooo000Goooo100003Woool500001Oooo`80I_l_
oooo00<0003oooooool0=oooo`D00002oooo00<0I_ooooooool0<oooo`@0000Foooo000Goooo00<0
003oooooool0??ooo`030000oooooooo00?oool206Ko<Oooo`030000oooooooo03Woool00`000?oo
ooooo`02oooo00<0I_ooooooool0<oooo`030000oooooooo01Ooool001Soool00`000?ooooooo`0k
oooo00@0003oooooooooool206Ko<oooo`030000oooooooo03Woool00`000?ooooooo`02oooo00<0
I_ooooooool0=?ooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool4
00001?ooo`040000oooo06Ko06Ko=Oooo`030000oooooooo03Woool00`000?ooooooo`02oooo00<0
I_ooooooool0=Oooo`030000oooooooo01Goool001Ooool010000?ooooooo`0003_oool00`00001V
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo00;oool00`1Vooooooooo`0coooo00@0
003oooooool0000Foooo000Hoooo0P0003_oool20000>?ooo`80000ioooo0P0000Coool00`1Voooo
ooooo`0doooo0P0001Ooool005Coool00`1Vooooooooo`0hoooo00<0003oooooool0?_ooo`0306Ko
oooooooo04goool005?oool00`1Vooooooooo`0ioooo00<0003oooooool0?_ooo`0306Kooooooooo
04goool0057oool206Ko??ooo`030000oooooooo03koool00`1Vooooooooo`1=oooo001@oooo00<0
I_ooooooool0??ooo`030000oooooooo03koool00`1Vooooooooo`1=oooo001?oooo00<0I_oooooo
ool0?Oooo`030000oooooooo03koool00`1Vooooooooo`1=oooo000@ooooo`00017oool001Koool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0002<ol000Co09Tco`0co`0co`0R00001_ooo`030000oooooooo00Woool00`000?oo
ooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000i
<ol01@000004o`2I000000000000=?ooo`030000oooooooo01Goool008ooool00`0003?o03?o000c
<ol01P0000Goool00ol0VOooooooo`1=oooo002?oooo00<0000co`0co`00<C?o0080000;oooo00?o
09Woooooool0COooo`00Soooo`030000<ol0<ol002lco`0200003Oooo`03o`2Ioooooooo04goool0
08ooool00`0003?o03?o000/<ol00`0000ooool00ol0VOooooooo`1=oooo002?oooo0P0002Xco`03
00004_ooo`03o`2Ioooooooo04goool008ooool00`0003?o03?o000W<ol00P0001Goool00ol0VOoo
ooooo`1=oooo002?oooo00<0000co`0co`009S?o00030000oooooooo01Goool00ol0VOooooooo`1=
oooo002?oooo00<0000co`0co`009C?o00030000oooooooo01Koool00ol0VOooooooo`1=oooo002?
oooo00<0000co`0co`0093?o00030000oooooooo01Ooool00ol0VOooooooo`1=oooo002?oooo00<0
000co`0co`008S?o0080000Joooo00?o09Woooooool0COooo`00Soooo`80000R<ol000<0003ooooo
ool06_ooo`03o`2Ioooooooo04goool008ooool00`0003?o03?o000P<ol000<0003oooooool06ooo
o`03o`2Ioooooooo04goool008ooool00`0003?o03?o000O<ol000<0003oooooool07?ooo`03o`2I
oooooooo04goool008ooool00`0003?o03?o000O<ol000<0003oooooool07?ooo`03o`2Ioooooooo
04goool008ooool00`0003?o03?o000N<ol000<0003oooooool07Oooo`03o`2Ioooooooo04goool0
08ooool00`0003?o03?o000M<ol000<0003oooooool07_ooo`03o`2Ioooooooo04goool008ooool2
00007C?o00030000oooooooo01ooool00ol0VOooooooo`1=oooo002?oooo00<0000co`0co`006c?o
00030000oooooooo023oool00ol0VOooooooo`1=oooo002?oooo00<0000co`0co`006c?o00030000
oooooooo023oool00ol0VOooooooo`1=oooo002?oooo00<0000co`0co`006S?o00030000oooooooo
027oool00ol0VOooooooo`1=oooo002?oooo00<0000co`0co`006S?o00030000oooooooo027oool0
0ol0VOooooooo`1=oooo002?oooo00<0000co`0co`006C?o00030000oooooooo02;oool00ol0VOoo
ooooo`1=oooo002?oooo0P0001Xco`000`000?ooooooo`0Roooo00?o09Woooooool0COooo`00Sooo
o`030000<ol0<ol001Pco`000`000?ooooooo`0Soooo00?o09Woooooool0COooo`00Soooo`030000
<ol0<ol001Pco`000`000?ooooooo`0Soooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol0
01Lco`000`000?ooooooo`0Toooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol001Lco`00
0`000?ooooooo`0Toooo00?o09Woooooool0COooo`00Qoooo`D00003oooo00<0000co`0co`005S?o
00030000oooooooo02Goool00ol0VOooooooo`1=oooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol001Hco`000`000?ooooooo`0Uoooo00?o09Woooooool0COooo`00ROooo`030000oooooooo
00?oool300005C?o00030000oooooooo02Koool00ol0VOooooooo`1=oooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`0Voooo00?o09Woooooool0COooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool09_ooo`03o`2Ioooooooo
04goool008Soool200001Oooo`030000<ol0<ol001@co`000`000?ooooooo`0Woooo00?o09Wooooo
ool0COooo`00Soooo`030000<ol0<ol001@co`000`000?ooooooo`0Woooo00?o09Woooooool0COoo
o`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`0Xoooo00?o09Woooooool0COooo`00Sooo
o`80000D<ol000<0003oooooool0:?ooo`03o`2Ioooooooo04goool008ooool00`0003?o03?o000C
<ol000<0003oooooool0:?ooo`03o`2Ioooooooo04goool008ooool00`0003?o03?o000B<ol000<0
003oooooool0:Oooo`03o`2Ioooooooo04goool008ooool00`0003?o03?o000B<ol000<0003ooooo
ool0:Oooo`03o`2Ioooooooo04goool008ooool00`0003?o03?o000B<ol000<0003oooooool0:Ooo
o`03o`2Ioooooooo04goool008ooool00`0003?o03?o000A<ol000<0003oooooool0:_ooo`03o`2I
oooooooo04goool008ooool200004S?o00030000oooooooo02[oool00ol0VOooooooo`1=oooo002?
oooo00<0000co`0co`004C?o00030000oooooooo02[oool00ol0VOooooooo`1=oooo002?oooo00<0
000co`0co`004C?o00030000oooooooo02[oool00ol0VOooooooo`1=oooo002?oooo00<0000co`0c
o`0043?o00030000oooooooo02_oool00ol0VOooooooo`1=oooo002?oooo00<0000co`0co`0043?o
00030000oooooooo02_oool00ol0VOooooooo`1=oooo002?oooo00<0000co`0co`0043?o00030000
oooooooo02_oool00ol0VOooooooo`1=oooo002?oooo00<0000co`0co`0043?o00030000oooooooo
02_oool00ol0VOooooooo`1=oooo002?oooo0P00010co`000`000?ooooooo`0/oooo00?o09Wooooo
ool0COooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0/oooo00?o09Woooooool0COoo
o`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0/oooo00?o09Woooooool0COooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`0/oooo00?o09Woooooool0COooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`0/oooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol0
00hco`000`000?ooooooo`0]oooo00?o09Woooooool0COooo`00Soooo`80000?<ol000<0003ooooo
ool0;Oooo`03o`2Ioooooooo04goool008ooool00`0003?o03?o000><ol000<0003oooooool0;Ooo
o`03o`2Ioooooooo04goool008ooool00`0003?o03?o000><ol000<0003oooooool0;Oooo`03o`2I
oooooooo04goool008ooool00`0003?o03?o000=<ol000<0003oooooool0;_ooo`03o`2Ioooooooo
04goool008Ooool400001?ooo`030000<ol0<ol000dco`000`000?ooooooo`0^oooo00?o09Wooooo
ool0COooo`00Qoooo`030000oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool0;_oo
o`03o`2Ioooooooo04goool008Soool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`0^
oooo00?o09Woooooool0COooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0
003oooooool0;_ooo`03o`2Ioooooooo04goool008Ooool010000?ooooooo`0000Coool00`0003?o
03?o000<<ol000<0003oooooool0;oooo`03o`2Ioooooooo04goool008Soool200001Oooo`030000
<ol0<ol000`co`000`000?ooooooo`0_oooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol0
00`co`000`000?ooooooo`0_oooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol000`co`00
0`000?ooooooo`0_oooo00?o09Woooooool0COooo`00Soooo`80000=<ol000<0003oooooool0;ooo
o`03o`2Ioooooooo04goool008ooool00`0003?o03?o000<<ol000<0003oooooool0;oooo`03o`2I
oooooooo04goool008ooool00`0003?o03?o000;<ol000<0003oooooool0<?ooo`03o`2Ioooooooo
04goool008ooool00`0003?o03?o000;<ol000<0003oooooool0<?ooo`03o`2Ioooooooo04goool0
08ooool00`0003?o03?o000;<ol000<0003oooooool0<?ooo`03o`2Ioooooooo04goool008ooool0
0`0003?o03?o000;<ol000<0003oooooool0<?ooo`03o`2Ioooooooo04goool008ooool00`0003?o
03?o000;<ol000<0003oooooool0<?ooo`03o`2Ioooooooo04goool008ooool2000033?o00030000
oooooooo033oool00ol0VOooooooo`1=oooo002?oooo00<0000co`0co`002c?o00030000oooooooo
033oool00ol0VOooooooo`1=oooo002?oooo00<0000co`0co`002S?o00030000oooooooo037oool0
0ol0VOooooooo`1=oooo002?oooo00<0000co`0co`002S?o00030000oooooooo037oool00ol0VOoo
ooooo`1=oooo002?oooo00<0000co`0co`002S?o00030000oooooooo037oool00ol0VOooooooo`1=
oooo002?oooo00<0000co`0co`002S?o00030000oooooooo037oool00ol0VOooooooo`1=oooo002?
oooo0P0000/co`000`000?ooooooo`0aoooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0aoooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0aoooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol000Tco`000`000?oo
ooooo`0boooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0b
oooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0boooo00?o
09Woooooool0COooo`00Soooo`80000:<ol000<0003oooooool0<_ooo`03o`2Ioooooooo04goool0
08ooool00`0003?o03?o0009<ol000<0003oooooool0<_ooo`03o`2Ioooooooo04goool008ooool0
0`0003?o03?o0009<ol000<0003oooooool0<_ooo`03o`2Ioooooooo04goool008ooool00`0003?o
03?o0008<ol000<0003oooooool0<oooo`03o`2Ioooooooo04goool008Soool200001Oooo`030000
<ol0<ol000Pco`000`000?ooooooo`0coooo00?o09Woooooool0COooo`00Qoooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0coooo00?o09Woooooool0COooo`00ROoo
o`030000oooooooo00?oool3000023?o00030000oooooooo03?oool00ol0VOooooooo`1=oooo002:
oooo00<0003oooooool00_ooo`030000<ol0<ol000Pco`000`000?ooooooo`0coooo00?o09Wooooo
ool0COooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0c
oooo00?o09Woooooool0COooo`00R?ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo
03Coool00ol0VOooooooo`1=oooo002?oooo00<0000co`0co`001c?o00030000oooooooo03Coool0
0ol0VOooooooo`1=oooo002?oooo00<0000co`0co`001c?o00030000oooooooo03Coool00ol0VOoo
ooooo`1=oooo002?oooo00<0000co`0co`001c?o00030000oooooooo03Coool00ol0VOooooooo`1=
oooo002?oooo0P0000Pco`000`000?ooooooo`0doooo00?o09Woooooool0COooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`0doooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0doooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0doooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`0eoooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0e
oooo00?o09Woooooool0COooo`00Soooo`800007<ol000<0003oooooool0=Oooo`03o`2Ioooooooo
04goool008ooool00`0003?o03?o0006<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04goool0
08ooool00`0003?o03?o0006<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04goool008ooool0
0`0003?o03?o0006<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04goool008ooool00`0003?o
03?o0006<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04goool008ooool00`0003?o03?o0006
<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04goool008ooool200001S?o00030000oooooooo
03Koool00ol0VOooooooo`1=oooo002?oooo00<0000co`0co`001C?o00030000oooooooo03Koool0
0ol0VOooooooo`1=oooo002?oooo00<0000co`0co`001C?o00030000oooooooo03Koool00ol0VOoo
ooooo`1=oooo002?oooo00<0000co`0co`001C?o00030000oooooooo03Koool00ol0VOooooooo`1=
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo03Koool00ol0VOooooooo`1=oooo002?
oooo00<0000co`0co`001C?o00030000oooooooo03Koool00ol0VOooooooo`1=oooo002?oooo0P00
00Hco`000`000?ooooooo`0foooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`0foooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`0foooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0g
oooo00?o09Woooooool0COooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0goooo00?o
09Woooooool0COooo`00ROooo`<00003oooo00<0000co`0co`0013?o00030000oooooooo03Ooool0
0ol0VOooooooo`1=oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?oo
ooooo`0goooo00?o09Woooooool0COooo`00Qoooo`D00003oooo0`0000@co`000`000?ooooooo`0g
oooo00?o09Woooooool0COooo`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0
003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?
oooo1c?o08[oool007Woool00`000?ooooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo00Woool7<ol03oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000<co`02000000@c
o`3oooooooooool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00Lco`02
oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Mooo
o`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0003ooolco`001S?o00;oool010000?oo
ooooo`0000;oool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0000koool00`0003?o03?o0005<ol00_ooo`040000oooooooo00000oooo`800004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Hco`02
oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo017oool200001c?o00?oool200001?ooo`800003oooo00<0003oooooool0NOoo
o`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.73838 .12361 L
.74806 .12361 L
.75315 .12361 L
.75593 .12361 L
.75853 .12361 L
.7597 .12361 L
.76081 .12361 L
s
.76081 .12361 m
.76132 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.23233 .12361 L
.23496 .12361 L
.2364 .12361 L
.23711 .12361 L
.23775 .12361 L
.2389 .12277 L
.24014 .12151 L
.24276 .1189 L
.26171 .10247 L
.2807 .08974 L
.30142 .07936 L
.32109 .07226 L
.33209 .06927 L
.34206 .06709 L
.35142 .06544 L
.36131 .06408 L
.36648 .06351 L
.37215 .063 L
.37693 .06264 L
.38213 .06233 L
.38485 .0622 L
.38737 .06209 L
.38973 .06201 L
.39234 .06194 L
.39466 .06188 L
.39685 .06185 L
.39805 .06183 L
.39915 .06182 L
.40036 .06181 L
.40164 .06181 L
.40295 .0618 L
.40414 .0618 L
.4048 .06181 L
.40552 .06181 L
.40681 .06182 L
.40803 .06183 L
.40932 .06184 L
.41163 .06188 L
.41432 .06193 L
.41683 .062 L
.42255 .06218 L
.43296 .06266 L
.44284 .06326 L
Mistroke
.46138 .06471 L
.48145 .06666 L
.49962 .06867 L
.50451 .06916 L
.50725 .06937 L
.50978 .06952 L
.512 .06962 L
.51443 .06971 L
.51566 .06974 L
.51697 .06976 L
.51821 .06978 L
.51934 .06979 L
.52064 .06979 L
.5213 .06979 L
.52202 .06979 L
.5233 .06978 L
.5245 .06976 L
.52592 .06973 L
.52721 .0697 L
.53012 .06961 L
.5325 .06951 L
.53509 .06938 L
.54032 .06905 L
.55062 .06819 L
.55997 .0672 L
.58093 .06437 L
.62097 .05744 L
.65949 .04972 L
.70046 .04119 L
.72086 .03709 L
.73991 .03349 L
.74931 .03183 L
.75393 .03105 L
.75822 .03035 L
.7606 .02997 L
.7618 .02979 L
.76249 .12361 L
.76313 .12361 L
.76848 .12361 L
.77785 .12361 L
.81651 .12361 L
.85762 .12361 L
.89721 .12361 L
.93528 .12361 L
.97581 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0loooo101Vodkoool0
08ooool00`000?ooooooo`0doooo201Vo`?oool00`1Vooooooooo`1<oooo002?oooo00<0003ooooo
ool0<_ooo`80I_l;oooo00<0I_ooooooool0C?ooo`00Soooo`030000oooooooo02koool406Ko3Ooo
o`0306Kooooooooo04coool008ooool00`000?ooooooo`0Xoooo1P1Voa7oool00`1Vooooooooo`1<
oooo002?oooo0P0002Coool506Ko5oooo`0306Kooooooooo04coool008ooool00`000?ooooooo`0O
oooo101Voacoool00`1Vooooooooo`1<oooo002?oooo00<0003oooooool05oooo`P0I_lPoooo00<0
I_ooooooool0C?ooo`00Jooooad0I_l7oooo00<0003oooooool03oooo`P0I_lXoooo00<0I_oooooo
ool0C?ooo`00I_ooo`D0I_lMoooo1`1Vo`030000oooooooo00Woool606Ko<?ooo`0306Kooooooooo
04coool0067oool506Ko:Oooo`03000006Ko06Ko00T0I_lfoooo00<0I_ooooooool0C?ooo`00Gooo
o`80I_l^oooo0P00043oool00`1Vooooooooo`1<oooo000Goooo100003Woool500001?ooo`80I_l`
oooo00<0003oooooool0=oooo`D00004oooo00<0I_ooooooool0<Oooo`@0000Foooo000Goooo00<0
003oooooool0??ooo`030000oooooooo00;oool206Ko<_ooo`030000oooooooo03Woool00`000?oo
ooooo`04oooo00<0I_ooooooool0<Oooo`030000oooooooo01Ooool001Soool00`000?ooooooo`0k
oooo00<0003oooooool00P1VocCoool00`000?ooooooo`0ioooo00<0003oooooool01?ooo`0306Ko
oooooooo03;oool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0boooo1000
00Coool00`00001Vo`1Vo`0foooo00<0003oooooool0>Oooo`030000oooooooo00Coool00`1Voooo
ooooo`0coooo00<0003oooooool05Oooo`005oooo`040000oooooooo0000>oooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool01?ooo`0306Kooooooooo037oool010000?oo
ooooo`0001Koool001Soool20000>_ooo`0306Ko0000000003Soool20000>Oooo`800006oooo00<0
I_ooooooool0<_ooo`80000Goooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo043oool0
0`1Vooooooooo`1;oooo001Boooo00<0I_ooooooool0>_ooo`030000oooooooo043oool00`1Voooo
ooooo`1;oooo001@oooo0P1Vocgoool00`000?ooooooo`10oooo00<0I_ooooooool0Boooo`00Cooo
o`0306Kooooooooo03goool00`000?ooooooo`10oooo00<0I_ooooooool0Boooo`00C_ooo`0306Ko
oooooooo03koool00`000?ooooooo`10oooo00<0I_ooooooool0Boooo`004?ooool0000Aoooo000F
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`000c?o0003o`2I<ol0<ol002800006oooo00<0003oooooool02Oooo`030000
oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol0
03Tco`06000000?o09T000000000=?ooo`030000oooooooo01Goool008ooool00`0003?o03?o000c
<ol01P0000Koool00ol0VOooooooo`1<oooo002?oooo00<0000co`0co`00<C?o0080000<oooo00?o
09Woooooool0C?ooo`00Soooo`030000<ol0<ol002lco`0200003_ooo`03o`2Ioooooooo04coool0
08ooool00`0003?o03?o000/<ol00`00013oool00ol0VOooooooo`1<oooo002?oooo0P0002Xco`03
00004oooo`03o`2Ioooooooo04coool008ooool00`0003?o03?o000W<ol00P0001Koool00ol0VOoo
ooooo`1<oooo002?oooo00<0000co`0co`009S?o00030000oooooooo01Koool00ol0VOooooooo`1<
oooo002?oooo00<0000co`0co`009C?o00030000oooooooo01Ooool00ol0VOooooooo`1<oooo002?
oooo00<0000co`0co`0093?o00030000oooooooo01Soool00ol0VOooooooo`1<oooo002?oooo00<0
000co`0co`008S?o0080000Koooo00?o09Woooooool0C?ooo`00Soooo`80000R<ol000<0003ooooo
ool06oooo`03o`2Ioooooooo04coool008ooool00`0003?o03?o000P<ol000<0003oooooool07?oo
o`03o`2Ioooooooo04coool008ooool00`0003?o03?o000O<ol000<0003oooooool07Oooo`03o`2I
oooooooo04coool008ooool00`0003?o03?o000O<ol000<0003oooooool07Oooo`03o`2Ioooooooo
04coool008ooool00`0003?o03?o000N<ol000<0003oooooool07_ooo`03o`2Ioooooooo04coool0
08ooool00`0003?o03?o000M<ol000<0003oooooool07oooo`03o`2Ioooooooo04coool008ooool2
00007C?o00030000oooooooo023oool00ol0VOooooooo`1<oooo002?oooo00<0000co`0co`006c?o
00030000oooooooo027oool00ol0VOooooooo`1<oooo002?oooo00<0000co`0co`006c?o00030000
oooooooo027oool00ol0VOooooooo`1<oooo002?oooo00<0000co`0co`006S?o00030000oooooooo
02;oool00ol0VOooooooo`1<oooo002?oooo00<0000co`0co`006S?o00030000oooooooo02;oool0
0ol0VOooooooo`1<oooo002?oooo00<0000co`0co`006C?o00030000oooooooo02?oool00ol0VOoo
ooooo`1<oooo002?oooo0P0001Xco`000`000?ooooooo`0Soooo00?o09Woooooool0C?ooo`00Sooo
o`030000<ol0<ol001Pco`000`000?ooooooo`0Toooo00?o09Woooooool0C?ooo`00Soooo`030000
<ol0<ol001Pco`000`000?ooooooo`0Toooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol0
01Lco`000`000?ooooooo`0Uoooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol001Lco`00
0`000?ooooooo`0Uoooo00?o09Woooooool0C?ooo`00Qoooo`D00003oooo00<0000co`0co`005S?o
00030000oooooooo02Koool00ol0VOooooooo`1<oooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol001Hco`000`000?ooooooo`0Voooo00?o09Woooooool0C?ooo`00ROooo`030000oooooooo
00?oool300005C?o00030000oooooooo02Ooool00ol0VOooooooo`1<oooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`0Woooo00?o09Woooooool0C?ooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool09oooo`03o`2Ioooooooo
04coool008Soool200001Oooo`030000<ol0<ol001@co`000`000?ooooooo`0Xoooo00?o09Wooooo
ool0C?ooo`00Soooo`030000<ol0<ol001@co`000`000?ooooooo`0Xoooo00?o09Woooooool0C?oo
o`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`0Yoooo00?o09Woooooool0C?ooo`00Sooo
o`80000D<ol000<0003oooooool0:Oooo`03o`2Ioooooooo04coool008ooool00`0003?o03?o000C
<ol000<0003oooooool0:Oooo`03o`2Ioooooooo04coool008ooool00`0003?o03?o000B<ol000<0
003oooooool0:_ooo`03o`2Ioooooooo04coool008ooool00`0003?o03?o000B<ol000<0003ooooo
ool0:_ooo`03o`2Ioooooooo04coool008ooool00`0003?o03?o000B<ol000<0003oooooool0:_oo
o`03o`2Ioooooooo04coool008ooool00`0003?o03?o000A<ol000<0003oooooool0:oooo`03o`2I
oooooooo04coool008ooool200004S?o00030000oooooooo02_oool00ol0VOooooooo`1<oooo002?
oooo00<0000co`0co`004C?o00030000oooooooo02_oool00ol0VOooooooo`1<oooo002?oooo00<0
000co`0co`004C?o00030000oooooooo02_oool00ol0VOooooooo`1<oooo002?oooo00<0000co`0c
o`0043?o00030000oooooooo02coool00ol0VOooooooo`1<oooo002?oooo00<0000co`0co`0043?o
00030000oooooooo02coool00ol0VOooooooo`1<oooo002?oooo00<0000co`0co`0043?o00030000
oooooooo02coool00ol0VOooooooo`1<oooo002?oooo00<0000co`0co`0043?o00030000oooooooo
02coool00ol0VOooooooo`1<oooo002?oooo0P00010co`000`000?ooooooo`0]oooo00?o09Wooooo
ool0C?ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0]oooo00?o09Woooooool0C?oo
o`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0]oooo00?o09Woooooool0C?ooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`0]oooo00?o09Woooooool0C?ooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`0]oooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol0
00hco`000`000?ooooooo`0^oooo00?o09Woooooool0C?ooo`00Soooo`80000?<ol000<0003ooooo
ool0;_ooo`03o`2Ioooooooo04coool008ooool00`0003?o03?o000><ol000<0003oooooool0;_oo
o`03o`2Ioooooooo04coool008ooool00`0003?o03?o000><ol000<0003oooooool0;_ooo`03o`2I
oooooooo04coool008ooool00`0003?o03?o000=<ol000<0003oooooool0;oooo`03o`2Ioooooooo
04coool008Ooool400001?ooo`030000<ol0<ol000dco`000`000?ooooooo`0_oooo00?o09Wooooo
ool0C?ooo`00Qoooo`030000oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool0;ooo
o`03o`2Ioooooooo04coool008Soool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`0_
oooo00?o09Woooooool0C?ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0
003oooooool0;oooo`03o`2Ioooooooo04coool008Ooool010000?ooooooo`0000Coool00`0003?o
03?o000<<ol000<0003oooooool0<?ooo`03o`2Ioooooooo04coool008Soool200001Oooo`030000
<ol0<ol000`co`000`000?ooooooo`0`oooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol0
00`co`000`000?ooooooo`0`oooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol000`co`00
0`000?ooooooo`0`oooo00?o09Woooooool0C?ooo`00Soooo`80000=<ol000<0003oooooool0<?oo
o`03o`2Ioooooooo04coool008ooool00`0003?o03?o000<<ol000<0003oooooool0<?ooo`03o`2I
oooooooo04coool008ooool00`0003?o03?o000;<ol000<0003oooooool0<Oooo`03o`2Ioooooooo
04coool008ooool00`0003?o03?o000;<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04coool0
08ooool00`0003?o03?o000;<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04coool008ooool0
0`0003?o03?o000;<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04coool008ooool00`0003?o
03?o000;<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04coool008ooool2000033?o00030000
oooooooo037oool00ol0VOooooooo`1<oooo002?oooo00<0000co`0co`002c?o00030000oooooooo
037oool00ol0VOooooooo`1<oooo002?oooo00<0000co`0co`002S?o00030000oooooooo03;oool0
0ol0VOooooooo`1<oooo002?oooo00<0000co`0co`002S?o00030000oooooooo03;oool00ol0VOoo
ooooo`1<oooo002?oooo00<0000co`0co`002S?o00030000oooooooo03;oool00ol0VOooooooo`1<
oooo002?oooo00<0000co`0co`002S?o00030000oooooooo03;oool00ol0VOooooooo`1<oooo002?
oooo0P0000/co`000`000?ooooooo`0boooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0boooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0boooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol000Tco`000`000?oo
ooooo`0coooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0c
oooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0coooo00?o
09Woooooool0C?ooo`00Soooo`80000:<ol000<0003oooooool0<oooo`03o`2Ioooooooo04coool0
08ooool00`0003?o03?o0009<ol000<0003oooooool0<oooo`03o`2Ioooooooo04coool008ooool0
0`0003?o03?o0009<ol000<0003oooooool0<oooo`03o`2Ioooooooo04coool008ooool00`0003?o
03?o0008<ol000<0003oooooool0=?ooo`03o`2Ioooooooo04coool008Soool200001Oooo`030000
<ol0<ol000Pco`000`000?ooooooo`0doooo00?o09Woooooool0C?ooo`00Qoooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0doooo00?o09Woooooool0C?ooo`00ROoo
o`030000oooooooo00?oool3000023?o00030000oooooooo03Coool00ol0VOooooooo`1<oooo002:
oooo00<0003oooooool00_ooo`030000<ol0<ol000Pco`000`000?ooooooo`0doooo00?o09Wooooo
ool0C?ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0d
oooo00?o09Woooooool0C?ooo`00R?ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo
03Goool00ol0VOooooooo`1<oooo002?oooo00<0000co`0co`001c?o00030000oooooooo03Goool0
0ol0VOooooooo`1<oooo002?oooo00<0000co`0co`001c?o00030000oooooooo03Goool00ol0VOoo
ooooo`1<oooo002?oooo00<0000co`0co`001c?o00030000oooooooo03Goool00ol0VOooooooo`1<
oooo002?oooo0P0000Pco`000`000?ooooooo`0eoooo00?o09Woooooool0C?ooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`0eoooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0eoooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0eoooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`0foooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0f
oooo00?o09Woooooool0C?ooo`00Soooo`800007<ol000<0003oooooool0=_ooo`03o`2Ioooooooo
04coool008ooool00`0003?o03?o0006<ol000<0003oooooool0=_ooo`03o`2Ioooooooo04coool0
08ooool00`0003?o03?o0006<ol000<0003oooooool0=_ooo`03o`2Ioooooooo04coool008ooool0
0`0003?o03?o0006<ol000<0003oooooool0=_ooo`03o`2Ioooooooo04coool008ooool00`0003?o
03?o0006<ol000<0003oooooool0=_ooo`03o`2Ioooooooo04coool008ooool00`0003?o03?o0006
<ol000<0003oooooool0=_ooo`03o`2Ioooooooo04coool008ooool200001S?o00030000oooooooo
03Ooool00ol0VOooooooo`1<oooo002?oooo00<0000co`0co`001C?o00030000oooooooo03Ooool0
0ol0VOooooooo`1<oooo002?oooo00<0000co`0co`001C?o00030000oooooooo03Ooool00ol0VOoo
ooooo`1<oooo002?oooo00<0000co`0co`001C?o00030000oooooooo03Ooool00ol0VOooooooo`1<
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo03Ooool00ol0VOooooooo`1<oooo002?
oooo00<0000co`0co`001C?o00030000oooooooo03Ooool00ol0VOooooooo`1<oooo002?oooo0P00
00Hco`000`000?ooooooo`0goooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`0goooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`0goooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0h
oooo00?o09Woooooool0C?ooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0hoooo00?o
09Woooooool0C?ooo`00ROooo`<00003oooo00<0000co`0co`0013?o00030000oooooooo03Soool0
0ol0VOooooooo`1<oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?oo
ooooo`0hoooo00?o09Woooooool0C?ooo`00Qoooo`D00003oooo0`0000@co`000`000?ooooooo`0h
oooo00?o09Woooooool0C?ooo`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0
003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?
oooo1c?o08[oool007coool00`000?ooooooo`0@oooo1c?o00_oool00`000?ooooooo`1loooo001k
oooo00<0003oooooool02?ooo`030000oooooooo00Koool7<ol03?ooo`030000oooooooo07_oool0
07_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000<co`0200000ooo
o`D00002oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`030000<ol0<ol000@co`07oooo00<0003oooooool00_oo
o`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`03<ol0
0000<ol000@co`07oooo00<0003oooooool00oooo`030000oooooooo07[oool007_oool00`000?oo
ooooo`0500003?ooo`8co`000`0003?o03?o0002<ol01oooo`030000oooooooo00;oool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000003oooo`040000<ol0<ol000000c?o00Ooool0
0`000?ooooooo`02oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo013oool00c?o0000
00000004<ol01_ooo`800003oooo00<0003oooooool0O?ooo`00Soooo`Lco`2:oooo002?oooo1c?o
08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.73838 .12361 L
.74806 .12361 L
.75315 .12361 L
.75853 .12361 L
.76324 .12361 L
.76453 .12361 L
.76525 .12361 L
.76592 .12361 L
s
.76592 .12361 m
.76644 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.22272 .12361 L
.22738 .12361 L
.22994 .12361 L
.23119 .12361 L
.23233 .12361 L
.23357 .12336 L
.23426 .12265 L
.23491 .12199 L
.23775 .11914 L
.24276 .11438 L
.26171 .09895 L
.28152 .08661 L
.2999 .07802 L
.31047 .07413 L
.32042 .07107 L
.33903 .06675 L
.3488 .06511 L
.35911 .06379 L
.36792 .06295 L
.37292 .06259 L
.37758 .06232 L
.38259 .06209 L
.38542 .062 L
.38803 .06193 L
.39032 .06188 L
.39284 .06184 L
.3941 .06182 L
.39477 .06182 L
.39547 .06181 L
.39675 .06181 L
.39794 .0618 L
.3991 .0618 L
.40015 .06181 L
.40137 .06181 L
.40253 .06182 L
.40359 .06183 L
.40458 .06184 L
.4068 .06188 L
.40904 .06192 L
.41151 .06198 L
.41649 .06214 L
.42665 .06258 L
.43594 .06312 L
.45683 .06473 L
Mistroke
.47746 .06674 L
.49659 .06887 L
.50118 .0694 L
.50359 .06964 L
.50614 .06986 L
.50837 .07001 L
.51082 .07015 L
.51304 .07025 L
.51512 .07032 L
.51646 .07035 L
.51773 .07037 L
.51887 .07039 L
.52011 .0704 L
.52076 .0704 L
.52146 .0704 L
.5222 .0704 L
.5229 .07039 L
.52413 .07038 L
.52483 .07037 L
.52547 .07036 L
.52765 .07031 L
.53003 .07024 L
.53484 .07004 L
.54014 .06972 L
.54514 .06936 L
.55449 .0685 L
.57545 .06593 L
.61397 .0596 L
.65494 .05157 L
.6944 .04336 L
.73233 .03573 L
.75182 .03216 L
.75743 .03121 L
.76019 .03075 L
.76275 .03034 L
.76507 .02997 L
.76624 .02979 L
.76753 .12361 L
.76882 .12361 L
.77021 .12361 L
.77273 .12361 L
.81383 .12361 L
.85343 .12361 L
.8915 .12361 L
.93203 .12361 L
.97104 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0koooo1P1Vodgoool0
08ooool00`000?ooooooo`0foooo1@1Vo`Goool00`1Vooooooooo`1;oooo002?oooo00<0003ooooo
ool0<Oooo`D0I_l:oooo00<0I_ooooooool0Boooo`00Soooo`030000oooooooo02coool506Ko3ooo
o`0306Kooooooooo04_oool008ooool00`000?ooooooo`0Woooo1@1VoaCoool00`1Vooooooooo`1;
oooo002?oooo0P0002?oool506Ko6Oooo`0306Kooooooooo04_oool008ooool00`000?ooooooo`0M
oooo1@1Voakoool00`1Vooooooooo`1;oooo002?oooo00<0003oooooool06?ooo`D0I_lSoooo00<0
I_ooooooool0Boooo`00Jooooa`0I_l8oooo00<0003oooooool04oooo`D0I_lXoooo00<0I_oooooo
ool0Boooo`00I?ooo`L0I_lLoooo1@1Vo`?oool00`000?ooooooo`0:oooo2@1Vobgoool00`1Voooo
ooooo`1;oooo001Qoooo0`1VobSoool306Ko00<00000I_l0I_l02P1VocKoool00`1Vooooooooo`1;
oooo001Noooo0`1Vobkoool20000@Oooo`0306Kooooooooo04_oool001Ooool40000>Oooo`D00003
oooo0P1Voc7oool00`000?ooooooo`0goooo1@0000Goool00`1Vooooooooo`0`oooo100001Koool0
01Ooool00`000?ooooooo`0loooo00@0003oooooooooool206Ko<oooo`030000oooooooo03Woool0
0`000?ooooooo`05oooo00<0I_ooooooool0<?ooo`030000oooooooo01Ooool001Soool00`000?oo
ooooo`0koooo00@0003oool0I_l0I_leoooo00<0003oooooool0>Oooo`030000oooooooo00Goool0
0`1Vooooooooo`0aoooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool0<_oo
o`@00004oooo00<00000I_ooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`05oooo00<0
I_ooooooool0<_ooo`030000oooooooo01Goool001Ooool010000?ooooooo`0003Woool206Ko00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`05oooo00<0I_ooooooool0<?oo
o`040000oooooooo00005_ooo`006?ooo`80000ioooo00@0I_ooool00000000hoooo0P0003Woool2
00001oooo`0306Kooooooooo037oool200005oooo`00D_ooo`0306Kooooooooo03[oool00`000?oo
ooooo`11oooo00<0I_ooooooool0B_ooo`00D?ooo`80I_lmoooo00<0003oooooool0@Oooo`0306Ko
oooooooo04[oool004ooool00`1Vooooooooo`0moooo00<0003oooooool0@Oooo`0306Kooooooooo
04[oool004koool00`1Vooooooooo`0noooo00<0003oooooool0@Oooo`0306Kooooooooo04[oool0
04coool206Ko@Oooo`030000oooooooo047oool00`1Vooooooooo`1:oooo000@ooooo`00017oool0
01Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0004<ol000?o09Tco`0000008@0000Koool00`000?ooooooo`09oooo00<0
003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0c
o`00>C?o00L000000ol0V@000?ooo`0coooo00<0003oooooool05Oooo`00Soooo`030000<ol0<ol0
03<co`0600001oooo`03o`2Ioooooooo04_oool008ooool00`0003?o03?o000a<ol00P0000goool0
0ol0VOooooooo`1;oooo002?oooo00<0000co`0co`00;c?o0080000?oooo00?o09Woooooool0Booo
o`00Soooo`030000<ol0<ol002`co`0300004Oooo`03o`2Ioooooooo04_oool008ooool20000:S?o
00<0000Doooo00?o09Woooooool0Boooo`00Soooo`030000<ol0<ol002Lco`0200005oooo`03o`2I
oooooooo04_oool008ooool00`0003?o03?o000V<ol000<0003oooooool05oooo`03o`2Ioooooooo
04_oool008ooool00`0003?o03?o000U<ol000<0003oooooool06?ooo`03o`2Ioooooooo04_oool0
08ooool00`0003?o03?o000T<ol000<0003oooooool06Oooo`03o`2Ioooooooo04_oool008ooool0
0`0003?o03?o000R<ol00P0001coool00ol0VOooooooo`1;oooo002?oooo0P00028co`000`000?oo
ooooo`0Loooo00?o09Woooooool0Boooo`00Soooo`030000<ol0<ol0020co`000`000?ooooooo`0M
oooo00?o09Woooooool0Boooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0Noooo00?o
09Woooooool0Boooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0Noooo00?o09Wooooo
ool0Boooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`0Ooooo00?o09Woooooool0Booo
o`00Soooo`030000<ol0<ol001dco`000`000?ooooooo`0Poooo00?o09Woooooool0Boooo`00Sooo
o`80000M<ol000<0003oooooool08Oooo`03o`2Ioooooooo04_oool008ooool00`0003?o03?o000K
<ol000<0003oooooool08_ooo`03o`2Ioooooooo04_oool008ooool00`0003?o03?o000K<ol000<0
003oooooool08_ooo`03o`2Ioooooooo04_oool008ooool00`0003?o03?o000J<ol000<0003ooooo
ool08oooo`03o`2Ioooooooo04_oool008ooool00`0003?o03?o000J<ol000<0003oooooool08ooo
o`03o`2Ioooooooo04_oool008ooool00`0003?o03?o000I<ol000<0003oooooool09?ooo`03o`2I
oooooooo04_oool008ooool200006S?o00030000oooooooo02Coool00ol0VOooooooo`1;oooo002?
oooo00<0000co`0co`0063?o00030000oooooooo02Goool00ol0VOooooooo`1;oooo002?oooo00<0
000co`0co`0063?o00030000oooooooo02Goool00ol0VOooooooo`1;oooo002?oooo00<0000co`0c
o`005c?o00030000oooooooo02Koool00ol0VOooooooo`1;oooo002?oooo00<0000co`0co`005c?o
00030000oooooooo02Koool00ol0VOooooooo`1;oooo0027oooo1@0000?oool00`0003?o03?o000F
<ol000<0003oooooool09oooo`03o`2Ioooooooo04_oool008Woool00`000?ooooooo`03oooo00<0
000co`0co`005S?o00030000oooooooo02Ooool00ol0VOooooooo`1;oooo0029oooo00<0003ooooo
ool00oooo`<0000E<ol000<0003oooooool0:?ooo`03o`2Ioooooooo04_oool008Woool00`000?oo
ooooo`03oooo00<0000co`0co`005C?o00030000oooooooo02Soool00ol0VOooooooo`1;oooo0029
oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`0Xoooo00?o09Wooooo
ool0Boooo`00R?ooo`800005oooo00<0000co`0co`0053?o00030000oooooooo02Woool00ol0VOoo
ooooo`1;oooo002?oooo00<0000co`0co`0053?o00030000oooooooo02Woool00ol0VOooooooo`1;
oooo002?oooo00<0000co`0co`004c?o00030000oooooooo02[oool00ol0VOooooooo`1;oooo002?
oooo0P0001@co`000`000?ooooooo`0Zoooo00?o09Woooooool0Boooo`00Soooo`030000<ol0<ol0
01<co`000`000?ooooooo`0Zoooo00?o09Woooooool0Boooo`00Soooo`030000<ol0<ol0018co`00
0`000?ooooooo`0[oooo00?o09Woooooool0Boooo`00Soooo`030000<ol0<ol0018co`000`000?oo
ooooo`0[oooo00?o09Woooooool0Boooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0[
oooo00?o09Woooooool0Boooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0/oooo00?o
09Woooooool0Boooo`00Soooo`80000B<ol000<0003oooooool0;?ooo`03o`2Ioooooooo04_oool0
08ooool00`0003?o03?o000A<ol000<0003oooooool0;?ooo`03o`2Ioooooooo04_oool008ooool0
0`0003?o03?o000A<ol000<0003oooooool0;?ooo`03o`2Ioooooooo04_oool008ooool00`0003?o
03?o000@<ol000<0003oooooool0;Oooo`03o`2Ioooooooo04_oool008ooool00`0003?o03?o000@
<ol000<0003oooooool0;Oooo`03o`2Ioooooooo04_oool008ooool00`0003?o03?o000@<ol000<0
003oooooool0;Oooo`03o`2Ioooooooo04_oool008ooool00`0003?o03?o000@<ol000<0003ooooo
ool0;Oooo`03o`2Ioooooooo04_oool008ooool2000043?o00030000oooooooo02koool00ol0VOoo
ooooo`1;oooo002?oooo00<0000co`0co`003c?o00030000oooooooo02koool00ol0VOooooooo`1;
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo02koool00ol0VOooooooo`1;oooo002?
oooo00<0000co`0co`003c?o00030000oooooooo02koool00ol0VOooooooo`1;oooo002?oooo00<0
000co`0co`003c?o00030000oooooooo02koool00ol0VOooooooo`1;oooo002?oooo00<0000co`0c
o`003S?o00030000oooooooo02ooool00ol0VOooooooo`1;oooo002?oooo0P0000lco`000`000?oo
ooooo`0_oooo00?o09Woooooool0Boooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0_
oooo00?o09Woooooool0Boooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0_oooo00?o
09Woooooool0Boooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`0`oooo00?o09Wooooo
ool0Boooo`00Qoooo`@00004oooo00<0000co`0co`003C?o00030000oooooooo033oool00ol0VOoo
ooooo`1;oooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`0`
oooo00?o09Woooooool0Boooo`00R?ooo`030000oooooooo00Coool300003C?o00030000oooooooo
033oool00ol0VOooooooo`1;oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000dco`00
0`000?ooooooo`0aoooo00?o09Woooooool0B_ooo`00Qoooo`040000oooooooo00001?ooo`030000
<ol0<ol000`co`000`000?ooooooo`0boooo00?o09Woooooool0B_ooo`00R?ooo`800005oooo00<0
000co`0co`0033?o00030000oooooooo03;oool00ol0VOooooooo`1:oooo002?oooo00<0000co`0c
o`0033?o00030000oooooooo03;oool00ol0VOooooooo`1:oooo002?oooo00<0000co`0co`0033?o
00030000oooooooo03;oool00ol0VOooooooo`1:oooo002?oooo0P0000dco`000`000?ooooooo`0b
oooo00?o09Woooooool0B_ooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0boooo00?o
09Woooooool0B_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0coooo00?o09Wooooo
ool0B_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0coooo00?o09Woooooool0B_oo
o`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0coooo00?o09Woooooool0B_ooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`0coooo00?o09Woooooool0B_ooo`00Soooo`030000
<ol0<ol000/co`000`000?ooooooo`0coooo00?o09Woooooool0B_ooo`00Soooo`80000<<ol000<0
003oooooool0<oooo`03o`2Ioooooooo04[oool008ooool00`0003?o03?o000;<ol000<0003ooooo
ool0<oooo`03o`2Ioooooooo04[oool008ooool00`0003?o03?o000:<ol000<0003oooooool0=?oo
o`03o`2Ioooooooo04[oool008ooool00`0003?o03?o000:<ol000<0003oooooool0=?ooo`03o`2I
oooooooo04[oool008ooool00`0003?o03?o000:<ol000<0003oooooool0=?ooo`03o`2Ioooooooo
04[oool008ooool00`0003?o03?o000:<ol000<0003oooooool0=?ooo`03o`2Ioooooooo04[oool0
08ooool200002c?o00030000oooooooo03Coool00ol0VOooooooo`1:oooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo03Coool00ol0VOooooooo`1:oooo002?oooo00<0000co`0co`002S?o
00030000oooooooo03Coool00ol0VOooooooo`1:oooo002?oooo00<0000co`0co`002C?o00030000
oooooooo03Goool00ol0VOooooooo`1:oooo002?oooo00<0000co`0co`002C?o00030000oooooooo
03Goool00ol0VOooooooo`1:oooo002?oooo00<0000co`0co`002C?o00030000oooooooo03Goool0
0ol0VOooooooo`1:oooo002?oooo0P0000Xco`000`000?ooooooo`0eoooo00?o09Woooooool0B_oo
o`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0eoooo00?o09Woooooool0B_ooo`00Sooo
o`030000<ol0<ol000Tco`000`000?ooooooo`0eoooo00?o09Woooooool0B_ooo`00Soooo`030000
<ol0<ol000Pco`000`000?ooooooo`0foooo00?o09Woooooool0B_ooo`00R?ooo`800005oooo00<0
000co`0co`0023?o00030000oooooooo03Koool00ol0VOooooooo`1:oooo0027oooo00@0003ooooo
ool00004oooo00<0000co`0co`0023?o00030000oooooooo03Koool00ol0VOooooooo`1:oooo0029
oooo00<0003oooooool00oooo`<00008<ol000<0003oooooool0=_ooo`03o`2Ioooooooo04[oool0
08[oool00`000?ooooooo`02oooo00<0000co`0co`0023?o00030000oooooooo03Koool00ol0VOoo
ooooo`1:oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo
03Koool00ol0VOooooooo`1:oooo0028oooo0P0000Goool00`0003?o03?o0007<ol000<0003ooooo
ool0=oooo`03o`2Ioooooooo04[oool008ooool00`0003?o03?o0007<ol000<0003oooooool0=ooo
o`03o`2Ioooooooo04[oool008ooool00`0003?o03?o0007<ol000<0003oooooool0=oooo`03o`2I
oooooooo04[oool008ooool00`0003?o03?o0007<ol000<0003oooooool0=oooo`03o`2Ioooooooo
04[oool008ooool2000023?o00030000oooooooo03Ooool00ol0VOooooooo`1:oooo002?oooo00<0
000co`0co`001c?o00030000oooooooo03Ooool00ol0VOooooooo`1:oooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo03Ooool00ol0VOooooooo`1:oooo002?oooo00<0000co`0co`001c?o
00030000oooooooo03Ooool00ol0VOooooooo`1:oooo002?oooo00<0000co`0co`001S?o00030000
oooooooo03Soool00ol0VOooooooo`1:oooo002?oooo00<0000co`0co`001S?o00030000oooooooo
03Soool00ol0VOooooooo`1:oooo002?oooo0P0000Lco`000`000?ooooooo`0hoooo00?o09Wooooo
ool0B_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0hoooo00?o09Woooooool0B_oo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0hoooo00?o09Woooooool0B_ooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`0hoooo00?o09Woooooool0B_ooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`0hoooo00?o09Woooooool0B_ooo`00Soooo`030000<ol0<ol0
00Hco`000`000?ooooooo`0hoooo00?o09Woooooool0B_ooo`00Soooo`800006<ol000<0003ooooo
ool0>Oooo`03o`2Ioooooooo04[oool008ooool00`0003?o03?o0005<ol000<0003oooooool0>Ooo
o`03o`2Ioooooooo04[oool008ooool00`0003?o03?o0005<ol000<0003oooooool0>Oooo`03o`2I
oooooooo04[oool008ooool00`0003?o03?o0005<ol000<0003oooooool0>Oooo`03o`2Ioooooooo
04[oool008ooool00`0003?o03?o0005<ol000<0003oooooool0>Oooo`03o`2Ioooooooo04[oool0
08ooool00`0003?o03?o0005<ol000<0003oooooool0>Oooo`03o`2Ioooooooo04[oool008ooool2
00001S?o00030000oooooooo03Woool00ol0VOooooooo`1:oooo002?oooo00<0000co`0co`001C?o
00030000oooooooo03Woool00ol0VOooooooo`1:oooo002?oooo00<0000co`0co`001C?o00030000
oooooooo03Woool00ol0VOooooooo`1:oooo002?oooo00<0000co`0co`0013?o00030000oooooooo
03[oool00ol0VOooooooo`1:oooo002?oooo00<0000co`0co`0013?o00030000oooooooo03[oool0
0ol0VOooooooo`1:oooo0029oooo0`0000?oool00`0003?o03?o0004<ol000<0003oooooool0>_oo
o`03o`2Ioooooooo04[oool008[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o00030000
oooooooo03[oool00ol0VOooooooo`1:oooo0027oooo1@0000?oool3000013?o00030000oooooooo
03[oool00ol0VOooooooo`1:oooo0027oooo00@0003oooooool00004oooo1c?o08[oool008Soool0
0`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o08[oool0
08ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?oooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000c?o00800000
0c?o0?ooooooo`05000000?oool0000000000P0000?oool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003ooooo
ool01c?o00Coool01@000?ooooooooooo`000006oooo00<0003oooooool0N?ooo`00Moooo`030000
oooooooo00;oool00`000?ooooooo`0>oooo00<0003ooolco`001S?o00Coool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_oo
o`030000<ol0<ol000Dco`04oooo00<0003oooooool00oooo`030000oooooooo00;oool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00001S?o00Coool0
1@000?ooooooooooo`000002oooo00D0003oooooooooool00000N_ooo`00NOooo`030000oooooooo
017oool200001c?o00?oool200001?ooo`800003oooo00<0003oooooool0NOooo`00Soooo`Lco`2:
oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.73838 .12361 L
.74806 .12361 L
.75853 .12361 L
.76334 .12361 L
.76596 .12361 L
.76842 .12361 L
.76949 .12361 L
.77051 .12361 L
s
.77051 .12361 m
.77098 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.21345 .12361 L
.22272 .12361 L
.22513 .12361 L
.22738 .12361 L
.22852 .12361 L
.22974 .12241 L
.23233 .1198 L
.24276 .11013 L
.26171 .09566 L
.28284 .08349 L
.30293 .07508 L
.31252 .07198 L
.32274 .06923 L
.33232 .06713 L
.34113 .06556 L
.35141 .06413 L
.35672 .06354 L
.36254 .063 L
.36727 .06265 L
.37235 .06234 L
.37515 .0622 L
.37771 .0621 L
.38008 .06201 L
.38271 .06194 L
.38519 .06188 L
.38752 .06184 L
.3888 .06183 L
.38997 .06182 L
.39126 .06181 L
.39191 .06181 L
.39262 .0618 L
.39383 .0618 L
.39492 .06181 L
.39618 .06181 L
.39737 .06182 L
.39848 .06183 L
.39949 .06184 L
.40179 .06187 L
.40428 .06192 L
.4066 .06198 L
.41188 .06214 L
.41703 .06235 L
.42255 .06261 L
.44373 .06403 L
Mistroke
.46383 .06584 L
.4839 .06796 L
.49264 .06896 L
.50208 .07006 L
.50465 .07031 L
.50737 .07053 L
.50989 .07069 L
.51223 .07081 L
.51443 .07089 L
.51556 .07093 L
.51679 .07096 L
.51749 .07097 L
.51813 .07098 L
.51941 .071 L
.52056 .07101 L
.52179 .07101 L
.52308 .07101 L
.52427 .071 L
.52557 .07098 L
.52694 .07096 L
.52925 .0709 L
.53177 .07081 L
.53747 .07055 L
.54277 .07021 L
.55332 .06932 L
.56327 .06825 L
.58187 .06577 L
.62039 .05927 L
.66136 .05117 L
.70082 .04295 L
.73876 .03535 L
.75824 .03183 L
.76385 .03088 L
.76661 .03043 L
.76783 .03024 L
.76917 .03002 L
.77037 .02984 L
.77149 .12361 L
.77267 .12361 L
.77395 .12361 L
.77915 .12361 L
.82026 .12361 L
.85985 .12361 L
.89792 .12361 L
.93845 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0moooo1P1Vod_oool0
08ooool00`000?ooooooo`0hoooo1@1Vo`Goool00`1Vooooooooo`19oooo002?oooo00<0003ooooo
ool0<oooo`D0I_l:oooo00<0I_ooooooool0BOooo`00Soooo`030000oooooooo02koool506Ko3ooo
o`0306Kooooooooo04Woool008ooool00`000?ooooooo`0Yoooo1@1VoaCoool00`1Vooooooooo`19
oooo002?oooo0P0002Goool506Ko6Oooo`0306Kooooooooo04Woool008ooool00`000?ooooooo`0N
oooo1P1Voakoool00`1Vooooooooo`19oooo002?oooo00<0003oooooool06Oooo`D0I_lToooo00<0
I_ooooooool0BOooo`00JOoooa/0I_l;oooo00<0003oooooool05Oooo`@0I_lYoooo00<0I_oooooo
ool0BOooo`00I?ooo`D0I_lKoooo201Vo`?oool00`000?ooooooo`0<oooo2@1Vobgoool00`1Voooo
ooooo`19oooo001Ooooo1@1VobSoool306Ko00<00000I_l0I_l0301VocKoool00`1Vooooooooo`19
oooo001Loooo0`1Voc3oool20000@oooo`0306Kooooooooo04Woool001Ooool40000>Oooo`D00000
0oooo`1Vo`1Vo`0coooo00<0003oooooool0=oooo`D00006oooo00<0I_ooooooool0;oooo`@0000F
oooo000Goooo00<0003oooooool0??ooo`040000oooo06Ko06Ko=Oooo`030000oooooooo03Woool0
0`000?ooooooo`06oooo00<0I_ooooooool0;oooo`030000oooooooo01Ooool001Soool00`000?oo
ooooo`0koooo00<00000I_ooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`06oooo00<0
I_ooooooool0<?ooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool4
00000_ooo`80I_l00`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo00Koool0
0`1Vooooooooo`0aoooo00<0003oooooool05Oooo`005oooo`040000oooooooo0000>?ooo`0406Ko
oooooooo0000>?ooo`030000oooooooo03Woool00`000?ooooooo`06oooo00<0I_ooooooool0;ooo
o`040000oooooooo00005_ooo`006?ooo`80000hoooo00<0I_ooooooool00P0003Soool20000>Ooo
o`800008oooo00<0I_ooooooool0<?ooo`80000Goooo001@oooo0P1Vocgoool00`000?ooooooo`12
oooo00<0I_ooooooool0BOooo`00Coooo`0306Kooooooooo03goool00`000?ooooooo`12oooo00<0
I_ooooooool0BOooo`00C_ooo`0306Kooooooooo03koool00`000?ooooooo`12oooo00<0I_oooooo
ool0BOooo`00C?ooo`80I_m1oooo00<0003oooooool0@_ooo`0306Kooooooooo04Woool004_oool0
0`1Vooooooooo`11oooo00<0003oooooool0@_ooo`0306Kooooooooo04Woool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Hco`000ol0V@000000000O00001_ooo`030000oooooooo00Woool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o
03?o000i<ol02@000003o`2Ioooooooo037oool00`000?ooooooo`0Eoooo002?oooo00<0000co`0c
o`00<c?o00H00009oooo00?o09Woooooool0BOooo`00Soooo`030000<ol0<ol0034co`0200003ooo
o`03o`2Ioooooooo04Woool008ooool00`0003?o03?o000_<ol00P00017oool00ol0VOooooooo`19
oooo002?oooo00<0000co`0co`00;3?o00<0000Coooo00?o09Woooooool0BOooo`00Soooo`80000Z
<ol00`0001Koool00ol0VOooooooo`19oooo002?oooo00<0000co`0co`009c?o0080000Ioooo00?o
09Woooooool0BOooo`00Soooo`030000<ol0<ol002Hco`000`000?ooooooo`0Ioooo00?o09Wooooo
ool0BOooo`00Soooo`030000<ol0<ol002Dco`000`000?ooooooo`0Joooo00?o09Woooooool0BOoo
o`00Soooo`030000<ol0<ol002@co`000`000?ooooooo`0Koooo00?o09Woooooool0BOooo`00Sooo
o`030000<ol0<ol0028co`0200007_ooo`03o`2Ioooooooo04Woool008ooool200008S?o00030000
oooooooo01koool00ol0VOooooooo`19oooo002?oooo00<0000co`0co`0083?o00030000oooooooo
01ooool00ol0VOooooooo`19oooo002?oooo00<0000co`0co`007c?o00030000oooooooo023oool0
0ol0VOooooooo`19oooo002?oooo00<0000co`0co`007c?o00030000oooooooo023oool00ol0VOoo
ooooo`19oooo002?oooo00<0000co`0co`007S?o00030000oooooooo027oool00ol0VOooooooo`19
oooo002?oooo00<0000co`0co`007C?o00030000oooooooo02;oool00ol0VOooooooo`19oooo002?
oooo0P0001dco`000`000?ooooooo`0Soooo00?o09Woooooool0BOooo`00Soooo`030000<ol0<ol0
01/co`000`000?ooooooo`0Toooo00?o09Woooooool0BOooo`00Soooo`030000<ol0<ol001/co`00
0`000?ooooooo`0Toooo00?o09Woooooool0BOooo`00Soooo`030000<ol0<ol001Xco`000`000?oo
ooooo`0Uoooo00?o09Woooooool0BOooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0U
oooo00?o09Woooooool0BOooo`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`0Voooo00?o
09Woooooool0BOooo`00Soooo`80000J<ol000<0003oooooool09_ooo`03o`2Ioooooooo04Woool0
08ooool00`0003?o03?o000H<ol000<0003oooooool09oooo`03o`2Ioooooooo04Woool008ooool0
0`0003?o03?o000H<ol000<0003oooooool09oooo`03o`2Ioooooooo04Woool008ooool00`0003?o
03?o000G<ol000<0003oooooool0:?ooo`03o`2Ioooooooo04Woool008ooool00`0003?o03?o000G
<ol000<0003oooooool0:?ooo`03o`2Ioooooooo04Woool008Ooool500000oooo`030000<ol0<ol0
01Hco`000`000?ooooooo`0Yoooo00?o09Woooooool0BOooo`00ROooo`030000oooooooo00?oool0
0`0003?o03?o000F<ol000<0003oooooool0:Oooo`03o`2Ioooooooo04Woool008Woool00`000?oo
ooooo`03oooo0`0001Dco`000`000?ooooooo`0Zoooo00?o09Woooooool0BOooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool0:_ooo`03o`2Ioooooooo04Woool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo02[oool00ol0VOoo
ooooo`19oooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool0:oooo`03o`2I
oooooooo04Woool008ooool00`0003?o03?o000D<ol000<0003oooooool0:oooo`03o`2Ioooooooo
04Woool008ooool00`0003?o03?o000C<ol000<0003oooooool0;?ooo`03o`2Ioooooooo04Woool0
08ooool2000053?o00030000oooooooo02coool00ol0VOooooooo`19oooo002?oooo00<0000co`0c
o`004c?o00030000oooooooo02coool00ol0VOooooooo`19oooo002?oooo00<0000co`0co`004S?o
00030000oooooooo02goool00ol0VOooooooo`19oooo002?oooo00<0000co`0co`004S?o00030000
oooooooo02goool00ol0VOooooooo`19oooo002?oooo00<0000co`0co`004S?o00030000oooooooo
02goool00ol0VOooooooo`19oooo002?oooo00<0000co`0co`004C?o00030000oooooooo02koool0
0ol0VOooooooo`19oooo002?oooo0P00018co`000`000?ooooooo`0^oooo00?o09Woooooool0BOoo
o`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0^oooo00?o09Woooooool0BOooo`00Sooo
o`030000<ol0<ol0014co`000`000?ooooooo`0^oooo00?o09Woooooool0BOooo`00Soooo`030000
<ol0<ol0010co`000`000?ooooooo`0_oooo00?o09Woooooool0BOooo`00Soooo`030000<ol0<ol0
010co`000`000?ooooooo`0_oooo00?o09Woooooool0BOooo`00Soooo`030000<ol0<ol0010co`00
0`000?ooooooo`0_oooo00?o09Woooooool0BOooo`00Soooo`030000<ol0<ol0010co`000`000?oo
ooooo`0_oooo00?o09Woooooool0BOooo`00Soooo`80000@<ol000<0003oooooool0<?ooo`03o`2I
oooooooo04Woool008ooool00`0003?o03?o000?<ol000<0003oooooool0<?ooo`03o`2Ioooooooo
04Woool008ooool00`0003?o03?o000?<ol000<0003oooooool0<?ooo`03o`2Ioooooooo04Woool0
08ooool00`0003?o03?o000?<ol000<0003oooooool0<?ooo`03o`2Ioooooooo04Woool008ooool0
0`0003?o03?o000?<ol000<0003oooooool0<?ooo`03o`2Ioooooooo04Woool008ooool00`0003?o
03?o000><ol000<0003oooooool0<Oooo`03o`2Ioooooooo04Woool008ooool200003c?o00030000
oooooooo037oool00ol0VOooooooo`19oooo002?oooo00<0000co`0co`003S?o00030000oooooooo
037oool00ol0VOooooooo`19oooo002?oooo00<0000co`0co`003S?o00030000oooooooo037oool0
0ol0VOooooooo`19oooo002?oooo00<0000co`0co`003C?o00030000oooooooo03;oool00ol0VOoo
ooooo`19oooo0027oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool0<_ooo`03o`2I
oooooooo04Woool008Ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo
03;oool00ol0VOooooooo`19oooo0028oooo00<0003oooooool01?ooo`<0000=<ol000<0003ooooo
ool0<_ooo`03o`2Ioooooooo04Woool008Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o
00030000oooooooo03;oool00ol0VOooooooo`19oooo0027oooo00@0003oooooool00004oooo00<0
000co`0co`0033?o00030000oooooooo03?oool00ol0VOooooooo`19oooo0028oooo0P0000Goool0
0`0003?o03?o000<<ol000<0003oooooool0<oooo`03o`2Ioooooooo04Woool008ooool00`0003?o
03?o000<<ol000<0003oooooool0<oooo`03o`2Ioooooooo04Woool008ooool00`0003?o03?o000<
<ol000<0003oooooool0<oooo`03o`2Ioooooooo04Woool008ooool200003C?o00030000oooooooo
03?oool00ol0VOooooooo`19oooo002?oooo00<0000co`0co`0033?o00030000oooooooo03?oool0
0ol0VOooooooo`19oooo002?oooo00<0000co`0co`002c?o00030000oooooooo03Coool00ol0VOoo
ooooo`19oooo002?oooo00<0000co`0co`002c?o00030000oooooooo03Coool00ol0VOooooooo`19
oooo002?oooo00<0000co`0co`002c?o00030000oooooooo03Coool00ol0VOooooooo`19oooo002?
oooo00<0000co`0co`002c?o00030000oooooooo03Coool00ol0VOooooooo`19oooo002?oooo00<0
000co`0co`002c?o00030000oooooooo03Coool00ol0VOooooooo`19oooo002?oooo0P0000`co`00
0`000?ooooooo`0doooo00?o09Woooooool0BOooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`0doooo00?o09Woooooool0BOooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0e
oooo00?o09Woooooool0BOooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0eoooo00?o
09Woooooool0BOooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0eoooo00?o09Wooooo
ool0BOooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0eoooo00?o09Woooooool0BOoo
o`00Soooo`80000;<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04Woool008ooool00`0003?o
03?o000:<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04Woool008ooool00`0003?o03?o000:
<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04Woool008ooool00`0003?o03?o0009<ol000<0
003oooooool0=_ooo`03o`2Ioooooooo04Woool008ooool00`0003?o03?o0009<ol000<0003ooooo
ool0=_ooo`03o`2Ioooooooo04Woool008ooool00`0003?o03?o0009<ol000<0003oooooool0=_oo
o`03o`2Ioooooooo04Woool008ooool200002S?o00030000oooooooo03Koool00ol0VOooooooo`19
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo03Koool00ol0VOooooooo`19oooo002?
oooo00<0000co`0co`002C?o00030000oooooooo03Koool00ol0VOooooooo`19oooo002?oooo00<0
000co`0co`0023?o00030000oooooooo03Ooool00ol0VOooooooo`19oooo0028oooo0P0000Goool0
0`0003?o03?o0008<ol000<0003oooooool0=oooo`03o`2Ioooooooo04Woool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0=oooo`03o`2Ioooooooo04Woool0
08Woool00`000?ooooooo`03oooo0`0000Pco`000`000?ooooooo`0goooo00?o09Woooooool0BOoo
o`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0=oooo`03o`2I
oooooooo04Woool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003ooooo
ool0=oooo`03o`2Ioooooooo04Woool008Soool200001Oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0hoooo00?o09Woooooool0BOooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0h
oooo00?o09Woooooool0BOooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0hoooo00?o
09Woooooool0BOooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0hoooo00?o09Wooooo
ool0BOooo`00Soooo`800008<ol000<0003oooooool0>?ooo`03o`2Ioooooooo04Woool008ooool0
0`0003?o03?o0007<ol000<0003oooooool0>?ooo`03o`2Ioooooooo04Woool008ooool00`0003?o
03?o0007<ol000<0003oooooool0>?ooo`03o`2Ioooooooo04Woool008ooool00`0003?o03?o0007
<ol000<0003oooooool0>?ooo`03o`2Ioooooooo04Woool008ooool00`0003?o03?o0006<ol000<0
003oooooool0>Oooo`03o`2Ioooooooo04Woool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool0>Oooo`03o`2Ioooooooo04Woool008ooool200001c?o00030000oooooooo03Woool00ol0VOoo
ooooo`19oooo002?oooo00<0000co`0co`001S?o00030000oooooooo03Woool00ol0VOooooooo`19
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo03Woool00ol0VOooooooo`19oooo002?
oooo00<0000co`0co`001S?o00030000oooooooo03Woool00ol0VOooooooo`19oooo002?oooo00<0
000co`0co`001S?o00030000oooooooo03Woool00ol0VOooooooo`19oooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo03Woool00ol0VOooooooo`19oooo002?oooo0P0000Hco`000`000?oo
ooooo`0joooo00?o09Woooooool0BOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0j
oooo00?o09Woooooool0BOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0joooo00?o
09Woooooool0BOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0joooo00?o09Wooooo
ool0BOooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0joooo00?o09Woooooool0BOoo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0joooo00?o09Woooooool0BOooo`00Sooo
o`800006<ol000<0003oooooool0>_ooo`03o`2Ioooooooo04Woool008ooool00`0003?o03?o0005
<ol000<0003oooooool0>_ooo`03o`2Ioooooooo04Woool008ooool00`0003?o03?o0005<ol000<0
003oooooool0>_ooo`03o`2Ioooooooo04Woool008ooool00`0003?o03?o0004<ol000<0003ooooo
ool0>oooo`03o`2Ioooooooo04Woool008ooool00`0003?o03?o0004<ol000<0003oooooool0>ooo
o`03o`2Ioooooooo04Woool008Woool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`0k
oooo00?o09Woooooool0BOooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0
003oooooool0>oooo`03o`2Ioooooooo04Woool008Ooool500000oooo`<00004<ol000<0003ooooo
ool0>oooo`03o`2Ioooooooo04Woool008Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?oo
o`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_oo
o`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>oooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o00ooool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003<ol00P00
0003<ol0oooooooo00D00003oooo0`0000;oool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool01c?o
00Coool00`000?ooooooo`04oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0>oooo00<0003ooolco`001S?o00Coool010000?ooooooooooo`D00003
oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0000co`0co`001C?o
00Coool01@000?ooooooooooo`000002oooo00D0003oooooooooool00000N_ooo`00N?ooo`050000
oooooooooooo000000ooool010000?ooooooo`0000Hco`04oooo00<0003oooooool00_ooo`030000
oooo000000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007<ol00ooo
o`800005oooo0P0000;oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.71905 .12361 L
.73838 .12361 L
.74806 .12361 L
.75853 .12361 L
.76334 .12361 L
.76842 .12361 L
.77275 .12361 L
.77394 .12361 L
.77521 .12361 L
s
.77521 .12361 m
.77569 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20342 .12361 L
.21345 .12361 L
.21786 .12361 L
.22037 .12361 L
.22159 .12361 L
.22272 .12361 L
.22387 .12354 L
.22496 .12242 L
.22738 .11998 L
.23233 .11522 L
.24276 .10614 L
.26171 .09258 L
.28152 .08185 L
.2999 .07448 L
.31047 .07119 L
.32042 .06865 L
.3293 .06679 L
.33903 .06515 L
.3488 .06388 L
.35377 .06336 L
.35911 .0629 L
.36411 .06254 L
.36866 .06229 L
.37324 .06209 L
.37758 .06195 L
.37995 .06189 L
.38217 .06185 L
.38344 .06184 L
.38461 .06182 L
.38589 .06181 L
.38653 .06181 L
.38724 .06181 L
.38793 .0618 L
.38858 .0618 L
.38981 .0618 L
.39112 .06181 L
.39186 .06181 L
.39255 .06182 L
.39369 .06183 L
.39495 .06184 L
.39749 .06188 L
.39989 .06193 L
.40208 .06198 L
.40701 .06214 L
.41591 .06252 L
Mistroke
.42578 .06308 L
.43494 .06372 L
.45567 .06551 L
.49486 .06978 L
.49987 .07039 L
.50517 .07094 L
.50794 .07116 L
.51097 .07134 L
.51373 .07147 L
.51631 .07155 L
.51756 .07158 L
.51823 .0716 L
.51893 .07161 L
.52022 .07162 L
.52141 .07163 L
.52255 .07163 L
.52362 .07163 L
.52479 .07162 L
.52605 .0716 L
.52732 .07158 L
.52871 .07155 L
.5315 .07147 L
.53409 .07137 L
.53649 .07126 L
.54704 .07056 L
.55699 .06966 L
.57559 .06743 L
.61411 .06128 L
.65508 .05338 L
.69453 .04519 L
.73247 .03744 L
.75359 .03344 L
.7636 .03168 L
.768 .03094 L
.77051 .03053 L
.77286 .03015 L
.77395 .02998 L
.77509 .0298 L
.77634 .12361 L
.77749 .12361 L
.78242 .12361 L
.79282 .12361 L
.81174 .12361 L
.84982 .12361 L
.89034 .12361 L
.92936 .12361 L
.97082 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0ooooo1@1Vod[oool0
08ooool00`000?ooooooo`0koooo101Vo`Coool00`1Vooooooooo`18oooo002?oooo00<0003ooooo
ool0=_ooo`D0I_l8oooo00<0I_ooooooool0B?ooo`00Soooo`030000oooooooo037oool506Ko3Ooo
o`0306Kooooooooo04Soool008ooool00`000?ooooooo`0/oooo1@1Voa;oool00`1Vooooooooo`18
oooo002?oooo0P0002Soool506Ko5oooo`0306Kooooooooo04Soool008ooool00`000?ooooooo`0R
oooo1@1Voacoool00`1Vooooooooo`18oooo002?oooo00<0003oooooool07Oooo`D0I_lQoooo00<0
I_ooooooool0B?ooo`00J?oooaT0I_l>oooo00<0003oooooool05_ooo`L0I_lVoooo00<0I_oooooo
ool0B?ooo`00HOooo`L0I_lIoooo201Vo`Koool00`000?ooooooo`0>oooo201Vobgoool00`1Voooo
ooooo`18oooo001Noooo0`1VobSoool606Ko00<00000I_l0I_l03P1VocGoool00`1Vooooooooo`18
oooo001Loooo0P1Voc7oool20000A?ooo`0306Kooooooooo04Soool001Ooool40000>Oooo`D00000
0oooo`1Vo`1Vo`0coooo00<0003oooooool0=oooo`D00007oooo00<0I_ooooooool0;_ooo`@0000F
oooo000Goooo00<0003oooooool0??ooo`040000oooo06Ko06Ko=Oooo`030000oooooooo03Woool0
0`000?ooooooo`07oooo00<0I_ooooooool0;_ooo`030000oooooooo01Ooool001Soool00`000?oo
ooooo`0koooo00<00000I_ooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`07oooo00<0
I_ooooooool0;oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo03;oool4
00000_ooo`80I_l00`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo00Ooool0
0`1Vooooooooo`0`oooo00<0003oooooool05Oooo`005oooo`040000oooooooo0000>?ooo`0406Ko
oooooooo0000>?ooo`030000oooooooo03Woool00`000?ooooooo`07oooo00<0I_ooooooool0;_oo
o`040000oooooooo00005_ooo`006?ooo`80000goooo0P1Vo`;oool20000>?ooo`80000ioooo0P00
00Woool00`1Vooooooooo`0_oooo0P0001Ooool004ooool206Ko?_ooo`030000oooooooo04?oool0
0`1Vooooooooo`18oooo001>oooo00<0I_ooooooool0?_ooo`030000oooooooo04?oool00`1Voooo
ooooo`18oooo001<oooo0P1Vod7oool00`000?ooooooo`13oooo00<0I_ooooooool0B?ooo`00Booo
o`0306Kooooooooo047oool00`000?ooooooo`13oooo00<0I_ooooooool0B?ooo`00B_ooo`0306Ko
oooooooo04;oool00`000?ooooooo`13oooo00<0I_ooooooool0B?ooo`004?ooool0000Aoooo000F
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`001S?o00030000o`2I000001l00006oooo00<0003oooooool02Oooo`030000
oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol0
03Tco`09000000?ooooo09Woool0<Oooo`030000oooooooo01Goool008ooool00`0003?o03?o000c
<ol01P0000[oool00ol0VOooooooo`18oooo002?oooo00<0000co`0co`00<C?o0080000@oooo00?o
09Woooooool0B?ooo`00Soooo`030000<ol0<ol002lco`0200004_ooo`03o`2Ioooooooo04Soool0
08ooool00`0003?o03?o000/<ol00`0001Coool00ol0VOooooooo`18oooo002?oooo0P0002Xco`03
00005oooo`03o`2Ioooooooo04Soool008ooool00`0003?o03?o000W<ol00P0001[oool00ol0VOoo
ooooo`18oooo002?oooo00<0000co`0co`009S?o00030000oooooooo01[oool00ol0VOooooooo`18
oooo002?oooo00<0000co`0co`009C?o00030000oooooooo01_oool00ol0VOooooooo`18oooo002?
oooo00<0000co`0co`0093?o00030000oooooooo01coool00ol0VOooooooo`18oooo002?oooo00<0
000co`0co`008S?o0080000Ooooo00?o09Woooooool0B?ooo`00Soooo`80000R<ol000<0003ooooo
ool07oooo`03o`2Ioooooooo04Soool008ooool00`0003?o03?o000P<ol000<0003oooooool08?oo
o`03o`2Ioooooooo04Soool008ooool00`0003?o03?o000O<ol000<0003oooooool08Oooo`03o`2I
oooooooo04Soool008ooool00`0003?o03?o000O<ol000<0003oooooool08Oooo`03o`2Ioooooooo
04Soool008ooool00`0003?o03?o000N<ol000<0003oooooool08_ooo`03o`2Ioooooooo04Soool0
08ooool00`0003?o03?o000M<ol000<0003oooooool08oooo`03o`2Ioooooooo04Soool008ooool2
00007C?o00030000oooooooo02Coool00ol0VOooooooo`18oooo002?oooo00<0000co`0co`006c?o
00030000oooooooo02Goool00ol0VOooooooo`18oooo002?oooo00<0000co`0co`006c?o00030000
oooooooo02Goool00ol0VOooooooo`18oooo002?oooo00<0000co`0co`006S?o00030000oooooooo
02Koool00ol0VOooooooo`18oooo002?oooo00<0000co`0co`006S?o00030000oooooooo02Koool0
0ol0VOooooooo`18oooo002?oooo00<0000co`0co`006C?o00030000oooooooo02Ooool00ol0VOoo
ooooo`18oooo002?oooo0P0001Xco`000`000?ooooooo`0Woooo00?o09Woooooool0B?ooo`00Sooo
o`030000<ol0<ol001Pco`000`000?ooooooo`0Xoooo00?o09Woooooool0B?ooo`00Soooo`030000
<ol0<ol001Pco`000`000?ooooooo`0Xoooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol0
01Lco`000`000?ooooooo`0Yoooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol001Lco`00
0`000?ooooooo`0Yoooo00?o09Woooooool0B?ooo`00Qoooo`D00003oooo00<0000co`0co`005S?o
00030000oooooooo02[oool00ol0VOooooooo`18oooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol001Hco`000`000?ooooooo`0Zoooo00?o09Woooooool0B?ooo`00ROooo`030000oooooooo
00?oool300005C?o00030000oooooooo02_oool00ol0VOooooooo`18oooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`0[oooo00?o09Woooooool0B?ooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool0:oooo`03o`2Ioooooooo
04Soool008Soool200001Oooo`030000<ol0<ol001@co`000`000?ooooooo`0/oooo00?o09Wooooo
ool0B?ooo`00Soooo`030000<ol0<ol001@co`000`000?ooooooo`0/oooo00?o09Woooooool0B?oo
o`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`0]oooo00?o09Woooooool0B?ooo`00Sooo
o`80000D<ol000<0003oooooool0;Oooo`03o`2Ioooooooo04Soool008ooool00`0003?o03?o000C
<ol000<0003oooooool0;Oooo`03o`2Ioooooooo04Soool008ooool00`0003?o03?o000B<ol000<0
003oooooool0;_ooo`03o`2Ioooooooo04Soool008ooool00`0003?o03?o000B<ol000<0003ooooo
ool0;_ooo`03o`2Ioooooooo04Soool008ooool00`0003?o03?o000B<ol000<0003oooooool0;_oo
o`03o`2Ioooooooo04Soool008ooool00`0003?o03?o000A<ol000<0003oooooool0;oooo`03o`2I
oooooooo04Soool008ooool200004S?o00030000oooooooo02ooool00ol0VOooooooo`18oooo002?
oooo00<0000co`0co`004C?o00030000oooooooo02ooool00ol0VOooooooo`18oooo002?oooo00<0
000co`0co`004C?o00030000oooooooo02ooool00ol0VOooooooo`18oooo002?oooo00<0000co`0c
o`0043?o00030000oooooooo033oool00ol0VOooooooo`18oooo002?oooo00<0000co`0co`0043?o
00030000oooooooo033oool00ol0VOooooooo`18oooo002?oooo00<0000co`0co`0043?o00030000
oooooooo033oool00ol0VOooooooo`18oooo002?oooo00<0000co`0co`0043?o00030000oooooooo
033oool00ol0VOooooooo`18oooo002?oooo0P00010co`000`000?ooooooo`0aoooo00?o09Wooooo
ool0B?ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0aoooo00?o09Woooooool0B?oo
o`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0aoooo00?o09Woooooool0B?ooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`0aoooo00?o09Woooooool0B?ooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`0aoooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol0
00hco`000`000?ooooooo`0boooo00?o09Woooooool0B?ooo`00Soooo`80000?<ol000<0003ooooo
ool0<_ooo`03o`2Ioooooooo04Soool008ooool00`0003?o03?o000><ol000<0003oooooool0<_oo
o`03o`2Ioooooooo04Soool008ooool00`0003?o03?o000><ol000<0003oooooool0<_ooo`03o`2I
oooooooo04Soool008ooool00`0003?o03?o000=<ol000<0003oooooool0<oooo`03o`2Ioooooooo
04Soool008Ooool400001?ooo`030000<ol0<ol000dco`000`000?ooooooo`0coooo00?o09Wooooo
ool0B?ooo`00Qoooo`030000oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool0<ooo
o`03o`2Ioooooooo04Soool008Soool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`0c
oooo00?o09Woooooool0B?ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0
003oooooool0<oooo`03o`2Ioooooooo04Soool008Ooool010000?ooooooo`0000Coool00`0003?o
03?o000<<ol000<0003oooooool0=?ooo`03o`2Ioooooooo04Soool008Soool200001Oooo`030000
<ol0<ol000`co`000`000?ooooooo`0doooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol0
00`co`000`000?ooooooo`0doooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol000`co`00
0`000?ooooooo`0doooo00?o09Woooooool0B?ooo`00Soooo`80000=<ol000<0003oooooool0=?oo
o`03o`2Ioooooooo04Soool008ooool00`0003?o03?o000<<ol000<0003oooooool0=?ooo`03o`2I
oooooooo04Soool008ooool00`0003?o03?o000;<ol000<0003oooooool0=Oooo`03o`2Ioooooooo
04Soool008ooool00`0003?o03?o000;<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04Soool0
08ooool00`0003?o03?o000;<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04Soool008ooool0
0`0003?o03?o000;<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04Soool008ooool00`0003?o
03?o000;<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04Soool008ooool2000033?o00030000
oooooooo03Goool00ol0VOooooooo`18oooo002?oooo00<0000co`0co`002c?o00030000oooooooo
03Goool00ol0VOooooooo`18oooo002?oooo00<0000co`0co`002S?o00030000oooooooo03Koool0
0ol0VOooooooo`18oooo002?oooo00<0000co`0co`002S?o00030000oooooooo03Koool00ol0VOoo
ooooo`18oooo002?oooo00<0000co`0co`002S?o00030000oooooooo03Koool00ol0VOooooooo`18
oooo002?oooo00<0000co`0co`002S?o00030000oooooooo03Koool00ol0VOooooooo`18oooo002?
oooo0P0000/co`000`000?ooooooo`0foooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0foooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0foooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol000Tco`000`000?oo
ooooo`0goooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0g
oooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0goooo00?o
09Woooooool0B?ooo`00Soooo`80000:<ol000<0003oooooool0=oooo`03o`2Ioooooooo04Soool0
08ooool00`0003?o03?o0009<ol000<0003oooooool0=oooo`03o`2Ioooooooo04Soool008ooool0
0`0003?o03?o0009<ol000<0003oooooool0=oooo`03o`2Ioooooooo04Soool008ooool00`0003?o
03?o0008<ol000<0003oooooool0>?ooo`03o`2Ioooooooo04Soool008Soool200001Oooo`030000
<ol0<ol000Pco`000`000?ooooooo`0hoooo00?o09Woooooool0B?ooo`00Qoooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0hoooo00?o09Woooooool0B?ooo`00ROoo
o`030000oooooooo00?oool3000023?o00030000oooooooo03Soool00ol0VOooooooo`18oooo002:
oooo00<0003oooooool00_ooo`030000<ol0<ol000Pco`000`000?ooooooo`0hoooo00?o09Wooooo
ool0B?ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0h
oooo00?o09Woooooool0B?ooo`00R?ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo
03Woool00ol0VOooooooo`18oooo002?oooo00<0000co`0co`001c?o00030000oooooooo03Woool0
0ol0VOooooooo`18oooo002?oooo00<0000co`0co`001c?o00030000oooooooo03Woool00ol0VOoo
ooooo`18oooo002?oooo00<0000co`0co`001c?o00030000oooooooo03Woool00ol0VOooooooo`18
oooo002?oooo0P0000Pco`000`000?ooooooo`0ioooo00?o09Woooooool0B?ooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`0ioooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol0
00Lco`000`000?ooooooo`0ioooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`0ioooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`0joooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0j
oooo00?o09Woooooool0B?ooo`00Soooo`800007<ol000<0003oooooool0>_ooo`03o`2Ioooooooo
04Soool008ooool00`0003?o03?o0006<ol000<0003oooooool0>_ooo`03o`2Ioooooooo04Soool0
08ooool00`0003?o03?o0006<ol000<0003oooooool0>_ooo`03o`2Ioooooooo04Soool008ooool0
0`0003?o03?o0006<ol000<0003oooooool0>_ooo`03o`2Ioooooooo04Soool008ooool00`0003?o
03?o0006<ol000<0003oooooool0>_ooo`03o`2Ioooooooo04Soool008ooool00`0003?o03?o0006
<ol000<0003oooooool0>_ooo`03o`2Ioooooooo04Soool008ooool200001S?o00030000oooooooo
03_oool00ol0VOooooooo`18oooo002?oooo00<0000co`0co`001C?o00030000oooooooo03_oool0
0ol0VOooooooo`18oooo002?oooo00<0000co`0co`001C?o00030000oooooooo03_oool00ol0VOoo
ooooo`18oooo002?oooo00<0000co`0co`001C?o00030000oooooooo03_oool00ol0VOooooooo`18
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo03_oool00ol0VOooooooo`18oooo002?
oooo00<0000co`0co`001C?o00030000oooooooo03_oool00ol0VOooooooo`18oooo002?oooo0P00
00Hco`000`000?ooooooo`0koooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`0koooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`0koooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0l
oooo00?o09Woooooool0B?ooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0loooo00?o
09Woooooool0B?ooo`00ROooo`<00003oooo00<0000co`0co`0013?o00030000oooooooo03coool0
0ol0VOooooooo`18oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?oo
ooooo`0loooo00?o09Woooooool0B?ooo`00Qoooo`D00003oooo0`0000@co`000`000?ooooooo`0l
oooo00?o09Woooooool0B?ooo`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0
003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?
oooo1c?o08[oool007Woool00`000?ooooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo00Woool7<ol03oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000<co`02000000<c
o`3oooooool01@000004oooo0000000000001?ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`07
<ol01?ooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00001joooo001goooo00<0
003oooooool00_ooo`030000oooooooo00koool00`000?oooc?o0006<ol01?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo
00D0000>oooo00<0000co`0co`001C?o00Coool010000?ooooooooooo`<00004oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Hco`04oooo00<0
003oooooool00_ooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003ooooo
ool04Oooo`800007<ol00oooo`800004oooo0`0000;oool00`000?ooooooo`1ioooo002?oooo1c?o
08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.75718 .12361 L
.76707 .12361 L
.77247 .12361 L
.77751 .12361 L
.77883 .12361 L
.78008 .12361 L
.78077 .12361 L
s
.78077 .12361 m
.78107 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20178 .12361 L
.20742 .12361 L
.21274 .12361 L
.21506 .12361 L
.21753 .12361 L
.21881 .12361 L
.21954 .1231 L
.22022 .12239 L
.22272 .11988 L
.24125 .10355 L
.26149 .08983 L
.28262 .07925 L
.29316 .07517 L
.30271 .07206 L
.32239 .06721 L
.33319 .06531 L
.34336 .06395 L
.35312 .063 L
.35804 .06263 L
.36344 .06231 L
.36805 .0621 L
.37059 .06201 L
.37299 .06194 L
.37522 .06189 L
.3764 .06187 L
.37766 .06185 L
.37871 .06184 L
.37986 .06182 L
.38092 .06181 L
.38191 .06181 L
.38309 .0618 L
.38434 .0618 L
.38553 .06181 L
.3866 .06181 L
.38787 .06182 L
.38925 .06183 L
.39174 .06187 L
.39436 .06191 L
.39713 .06198 L
.40209 .06213 L
.4109 .0625 L
.4206 .06305 L
.44004 .06451 L
.46094 .06651 L
.48068 .06868 L
Mistroke
.49111 .06991 L
.49683 .0706 L
.50221 .07124 L
.50742 .07171 L
.51035 .07191 L
.51304 .07205 L
.51532 .07214 L
.51661 .07218 L
.51781 .0722 L
.51908 .07223 L
.52024 .07224 L
.52088 .07225 L
.52158 .07225 L
.52284 .07226 L
.52403 .07225 L
.52514 .07225 L
.52636 .07223 L
.52767 .07221 L
.52897 .07218 L
.53034 .07215 L
.53279 .07207 L
.53718 .07188 L
.54197 .07161 L
.55228 .07081 L
.56162 .06988 L
.58259 .06722 L
.62262 .06059 L
.66114 .05306 L
.70211 .04455 L
.74157 .03654 L
.7614 .03285 L
.77007 .03135 L
.77464 .03059 L
.77715 .03019 L
.77951 .02982 L
.78069 .02963 L
.78197 .12361 L
.78267 .12361 L
.78339 .12361 L
.7847 .12361 L
.78951 .12361 L
.79899 .12361 L
.8199 .12361 L
.85797 .12361 L
.8985 .12361 L
.93752 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`0moooo201VodWoool0
08ooool00`000?ooooooo`0hoooo1@1Vo`Ooool00`1Vooooooooo`17oooo002?oooo00<0003ooooo
ool0<oooo`D0I_l<oooo00<0I_ooooooool0Aoooo`00Soooo`030000oooooooo02ooool406Ko4Ooo
o`0306Kooooooooo04Ooool008ooool00`000?ooooooo`0/oooo0`1VoaGoool00`1Vooooooooo`17
oooo002?oooo0P0002Woool406Ko6?ooo`0306Kooooooooo04Ooool008ooool00`000?ooooooo`0R
oooo1P1Voacoool00`1Vooooooooo`17oooo002?oooo00<0003oooooool06_ooo`P0I_lRoooo00<0
I_ooooooool0Aoooo`00Iooooa`0I_l<oooo00<0003oooooool05Oooo`D0I_lZoooo00<0I_oooooo
ool0Aoooo`00H?ooo`L0I_lLoooo2@1Vo`?oool00`000?ooooooo`0@oooo1@1Vobooool00`1Voooo
ooooo`17oooo001Moooo0`1Vobcoool306Ko00<00000I_l0I_l0401VocCoool00`1Vooooooooo`17
oooo001Joooo0`1Voc;oool20000AOooo`0306Kooooooooo04Ooool001Ooool40000>Oooo`D00000
0`1Vooooooooo`0coooo00<0003oooooool0=oooo`D00008oooo00<0I_ooooooool0;Oooo`@0000F
oooo000Goooo00<0003oooooool0??ooo`03000006Kooooo03Koool00`000?ooooooo`0ioooo00<0
003oooooool02?ooo`0306Kooooooooo02goool00`000?ooooooo`0Goooo000Hoooo00<0003ooooo
ool0>Oooo`80I_l00`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo00Soool0
0`1Vooooooooo`0^oooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool0<_oo
o`@0000206Ko0_ooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool02?oo
o`0306Kooooooooo02ooool00`000?ooooooo`0Eoooo000Goooo00@0003oooooool0000eoooo0P1V
o`Coool00`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo00Soool00`1Voooo
ooooo`0]oooo00@0003oooooool0000Foooo000Hoooo0P0003Coool206Ko1Oooo`80000hoooo0P00
03Woool200002_ooo`0306Kooooooooo02koool200005oooo`00COooo`0306Kooooooooo03ooool0
0`000?ooooooo`14oooo00<0I_ooooooool0Aoooo`00C?ooo`0306Kooooooooo043oool00`000?oo
ooooo`14oooo00<0I_ooooooool0Aoooo`00Boooo`0306Kooooooooo047oool00`000?ooooooo`14
oooo00<0I_ooooooool0Aoooo`00B_ooo`0306Kooooooooo04;oool00`000?ooooooo`14oooo00<0
I_ooooooool0Aoooo`00BOooo`0306Kooooooooo04?oool00`000?ooooooo`14oooo00<0I_oooooo
ool0Aoooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o008000000ol0V@000000000M
00001_ooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_oo
o`030000oooooooo03Woool00`0003?o03?o000i<ol02@0000;oool00ol0VOooooooo`0_oooo00<0
003oooooool05Oooo`00Soooo`030000<ol0<ol003<co`0600002oooo`03o`2Ioooooooo04Ooool0
08ooool00`0003?o03?o000a<ol00P00017oool00ol0VOooooooo`17oooo002?oooo00<0000co`0c
o`00;c?o0080000Coooo00?o09Woooooool0Aoooo`00Soooo`030000<ol0<ol002`co`0300005Ooo
o`03o`2Ioooooooo04Ooool008ooool20000:S?o00<0000Hoooo00?o09Woooooool0Aoooo`00Sooo
o`030000<ol0<ol002Lco`0200006oooo`03o`2Ioooooooo04Ooool008ooool00`0003?o03?o000V
<ol000<0003oooooool06oooo`03o`2Ioooooooo04Ooool008ooool00`0003?o03?o000U<ol000<0
003oooooool07?ooo`03o`2Ioooooooo04Ooool008ooool00`0003?o03?o000T<ol000<0003ooooo
ool07Oooo`03o`2Ioooooooo04Ooool008ooool00`0003?o03?o000R<ol00P00023oool00ol0VOoo
ooooo`17oooo002?oooo0P00028co`000`000?ooooooo`0Poooo00?o09Woooooool0Aoooo`00Sooo
o`030000<ol0<ol0020co`000`000?ooooooo`0Qoooo00?o09Woooooool0Aoooo`00Soooo`030000
<ol0<ol001lco`000`000?ooooooo`0Roooo00?o09Woooooool0Aoooo`00Soooo`030000<ol0<ol0
01lco`000`000?ooooooo`0Roooo00?o09Woooooool0Aoooo`00Soooo`030000<ol0<ol001hco`00
0`000?ooooooo`0Soooo00?o09Woooooool0Aoooo`00Soooo`030000<ol0<ol001dco`000`000?oo
ooooo`0Toooo00?o09Woooooool0Aoooo`00Soooo`80000M<ol000<0003oooooool09Oooo`03o`2I
oooooooo04Ooool008ooool00`0003?o03?o000K<ol000<0003oooooool09_ooo`03o`2Ioooooooo
04Ooool008ooool00`0003?o03?o000K<ol000<0003oooooool09_ooo`03o`2Ioooooooo04Ooool0
08ooool00`0003?o03?o000J<ol000<0003oooooool09oooo`03o`2Ioooooooo04Ooool008ooool0
0`0003?o03?o000J<ol000<0003oooooool09oooo`03o`2Ioooooooo04Ooool008ooool00`0003?o
03?o000I<ol000<0003oooooool0:?ooo`03o`2Ioooooooo04Ooool008ooool200006S?o00030000
oooooooo02Soool00ol0VOooooooo`17oooo002?oooo00<0000co`0co`0063?o00030000oooooooo
02Woool00ol0VOooooooo`17oooo002?oooo00<0000co`0co`0063?o00030000oooooooo02Woool0
0ol0VOooooooo`17oooo002?oooo00<0000co`0co`005c?o00030000oooooooo02[oool00ol0VOoo
ooooo`17oooo002?oooo00<0000co`0co`005c?o00030000oooooooo02[oool00ol0VOooooooo`17
oooo0027oooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool0:oooo`03o`2Ioooooooo
04Ooool008Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo02_oool0
0ol0VOooooooo`17oooo0029oooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0;?oo
o`03o`2Ioooooooo04Ooool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000
oooooooo02coool00ol0VOooooooo`17oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`0/oooo00?o09Woooooool0Aoooo`00R?ooo`800005oooo00<0000co`0c
o`0053?o00030000oooooooo02goool00ol0VOooooooo`17oooo002?oooo00<0000co`0co`0053?o
00030000oooooooo02goool00ol0VOooooooo`17oooo002?oooo00<0000co`0co`004c?o00030000
oooooooo02koool00ol0VOooooooo`17oooo002?oooo0P0001@co`000`000?ooooooo`0^oooo00?o
09Woooooool0Aoooo`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`0^oooo00?o09Wooooo
ool0Aoooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0_oooo00?o09Woooooool0Aooo
o`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0_oooo00?o09Woooooool0Aoooo`00Sooo
o`030000<ol0<ol0018co`000`000?ooooooo`0_oooo00?o09Woooooool0Aoooo`00Soooo`030000
<ol0<ol0014co`000`000?ooooooo`0`oooo00?o09Woooooool0Aoooo`00Soooo`80000B<ol000<0
003oooooool0<?ooo`03o`2Ioooooooo04Ooool008ooool00`0003?o03?o000A<ol000<0003ooooo
ool0<?ooo`03o`2Ioooooooo04Ooool008ooool00`0003?o03?o000A<ol000<0003oooooool0<?oo
o`03o`2Ioooooooo04Ooool008ooool00`0003?o03?o000@<ol000<0003oooooool0<Oooo`03o`2I
oooooooo04Ooool008ooool00`0003?o03?o000@<ol000<0003oooooool0<Oooo`03o`2Ioooooooo
04Ooool008ooool00`0003?o03?o000@<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04Ooool0
08ooool00`0003?o03?o000@<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04Ooool008ooool2
000043?o00030000oooooooo03;oool00ol0VOooooooo`17oooo002?oooo00<0000co`0co`003c?o
00030000oooooooo03;oool00ol0VOooooooo`17oooo002?oooo00<0000co`0co`003c?o00030000
oooooooo03;oool00ol0VOooooooo`17oooo002?oooo00<0000co`0co`003c?o00030000oooooooo
03;oool00ol0VOooooooo`17oooo002?oooo00<0000co`0co`003c?o00030000oooooooo03;oool0
0ol0VOooooooo`17oooo002?oooo00<0000co`0co`003S?o00030000oooooooo03?oool00ol0VOoo
ooooo`17oooo002?oooo0P0000lco`000`000?ooooooo`0coooo00?o09Woooooool0Aoooo`00Sooo
o`030000<ol0<ol000hco`000`000?ooooooo`0coooo00?o09Woooooool0Aoooo`00Soooo`030000
<ol0<ol000hco`000`000?ooooooo`0coooo00?o09Woooooool0Aoooo`00Soooo`030000<ol0<ol0
00dco`000`000?ooooooo`0doooo00?o09Woooooool0Aoooo`00Qoooo`@00004oooo00<0000co`0c
o`003C?o00030000oooooooo03Coool00ol0VOooooooo`17oooo0027oooo00<0003oooooool01Ooo
o`030000<ol0<ol000dco`000`000?ooooooo`0doooo00?o09Woooooool0Aoooo`00R?ooo`030000
oooooooo00Coool300003C?o00030000oooooooo03Coool00ol0VOooooooo`17oooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`0doooo00?o09Woooooool0Aooo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`0eoooo00?o
09Woooooool0Aoooo`00R?ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo03Goool0
0ol0VOooooooo`17oooo002?oooo00<0000co`0co`0033?o00030000oooooooo03Goool00ol0VOoo
ooooo`17oooo002?oooo00<0000co`0co`0033?o00030000oooooooo03Goool00ol0VOooooooo`17
oooo002?oooo0P0000dco`000`000?ooooooo`0eoooo00?o09Woooooool0Aoooo`00Soooo`030000
<ol0<ol000`co`000`000?ooooooo`0eoooo00?o09Woooooool0Aoooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`0foooo00?o09Woooooool0Aoooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`0foooo00?o09Woooooool0Aoooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`0foooo00?o09Woooooool0Aoooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0f
oooo00?o09Woooooool0Aoooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0foooo00?o
09Woooooool0Aoooo`00Soooo`80000<<ol000<0003oooooool0=_ooo`03o`2Ioooooooo04Ooool0
08ooool00`0003?o03?o000;<ol000<0003oooooool0=_ooo`03o`2Ioooooooo04Ooool008ooool0
0`0003?o03?o000:<ol000<0003oooooool0=oooo`03o`2Ioooooooo04Ooool008ooool00`0003?o
03?o000:<ol000<0003oooooool0=oooo`03o`2Ioooooooo04Ooool008ooool00`0003?o03?o000:
<ol000<0003oooooool0=oooo`03o`2Ioooooooo04Ooool008ooool00`0003?o03?o000:<ol000<0
003oooooool0=oooo`03o`2Ioooooooo04Ooool008ooool200002c?o00030000oooooooo03Ooool0
0ol0VOooooooo`17oooo002?oooo00<0000co`0co`002S?o00030000oooooooo03Ooool00ol0VOoo
ooooo`17oooo002?oooo00<0000co`0co`002S?o00030000oooooooo03Ooool00ol0VOooooooo`17
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo03Soool00ol0VOooooooo`17oooo002?
oooo00<0000co`0co`002C?o00030000oooooooo03Soool00ol0VOooooooo`17oooo002?oooo00<0
000co`0co`002C?o00030000oooooooo03Soool00ol0VOooooooo`17oooo002?oooo0P0000Xco`00
0`000?ooooooo`0hoooo00?o09Woooooool0Aoooo`00Soooo`030000<ol0<ol000Tco`000`000?oo
ooooo`0hoooo00?o09Woooooool0Aoooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0h
oooo00?o09Woooooool0Aoooo`00Soooo`030000<ol0<ol000Pco`000`000?ooooooo`0ioooo00?o
09Woooooool0Aoooo`00R?ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo03Woool0
0ol0VOooooooo`17oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000
oooooooo03Woool00ol0VOooooooo`17oooo0029oooo00<0003oooooool00oooo`<00008<ol000<0
003oooooool0>Oooo`03o`2Ioooooooo04Ooool008[oool00`000?ooooooo`02oooo00<0000co`0c
o`0023?o00030000oooooooo03Woool00ol0VOooooooo`17oooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0023?o00030000oooooooo03Woool00ol0VOooooooo`17oooo0028oooo0P00
00Goool00`0003?o03?o0007<ol000<0003oooooool0>_ooo`03o`2Ioooooooo04Ooool008ooool0
0`0003?o03?o0007<ol000<0003oooooool0>_ooo`03o`2Ioooooooo04Ooool008ooool00`0003?o
03?o0007<ol000<0003oooooool0>_ooo`03o`2Ioooooooo04Ooool008ooool00`0003?o03?o0007
<ol000<0003oooooool0>_ooo`03o`2Ioooooooo04Ooool008ooool2000023?o00030000oooooooo
03[oool00ol0VOooooooo`17oooo002?oooo00<0000co`0co`001c?o00030000oooooooo03[oool0
0ol0VOooooooo`17oooo002?oooo00<0000co`0co`001c?o00030000oooooooo03[oool00ol0VOoo
ooooo`17oooo002?oooo00<0000co`0co`001c?o00030000oooooooo03[oool00ol0VOooooooo`17
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo03_oool00ol0VOooooooo`17oooo002?
oooo00<0000co`0co`001S?o00030000oooooooo03_oool00ol0VOooooooo`17oooo002?oooo0P00
00Lco`000`000?ooooooo`0koooo00?o09Woooooool0Aoooo`00Soooo`030000<ol0<ol000Hco`00
0`000?ooooooo`0koooo00?o09Woooooool0Aoooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`0koooo00?o09Woooooool0Aoooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0k
oooo00?o09Woooooool0Aoooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0koooo00?o
09Woooooool0Aoooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0koooo00?o09Wooooo
ool0Aoooo`00Soooo`800006<ol000<0003oooooool0??ooo`03o`2Ioooooooo04Ooool008ooool0
0`0003?o03?o0005<ol000<0003oooooool0??ooo`03o`2Ioooooooo04Ooool008ooool00`0003?o
03?o0005<ol000<0003oooooool0??ooo`03o`2Ioooooooo04Ooool008ooool00`0003?o03?o0005
<ol000<0003oooooool0??ooo`03o`2Ioooooooo04Ooool008ooool00`0003?o03?o0005<ol000<0
003oooooool0??ooo`03o`2Ioooooooo04Ooool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool0??ooo`03o`2Ioooooooo04Ooool008ooool200001S?o00030000oooooooo03coool00ol0VOoo
ooooo`17oooo002?oooo00<0000co`0co`001C?o00030000oooooooo03coool00ol0VOooooooo`17
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo03coool00ol0VOooooooo`17oooo002?
oooo00<0000co`0co`0013?o00030000oooooooo03goool00ol0VOooooooo`17oooo002?oooo00<0
000co`0co`0013?o00030000oooooooo03goool00ol0VOooooooo`17oooo0029oooo0`0000?oool0
0`0003?o03?o0004<ol000<0003oooooool0?Oooo`03o`2Ioooooooo04Ooool008[oool00`000?oo
ooooo`02oooo00<0000co`0co`0013?o00030000oooooooo03goool00ol0VOooooooo`17oooo0027
oooo1@0000?oool3000013?o00030000oooooooo03goool00ol0VOooooooo`17oooo0027oooo00@0
003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool2
00001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo
01?oool7<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool02Oooo`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool400000c?o008000000c?o0?ooooooo`0500000_ooo`800004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`030000oooooooo00Lco`04oooo00D0003oooooooooool000000_ooo`050000
oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000
oooo<ol000Hco`04oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0000koool00`0003?o03?o0005<ol01?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?
oooo00@0003oooooool00006<ol01?ooo`050000oooooooooooo000000;oool01@000?oooooooooo
o`00001joooo001ioooo00<0003oooooool04Oooo`800007<ol00oooo`800004oooo0P0000?oool0
0`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.75718 .12361 L
.76707 .12361 L
.77751 .12361 L
.78008 .12361 L
.78283 .12361 L
.78364 .12361 L
.78441 .12361 L
.7851 .12361 L
s
.7851 .12361 m
.7854 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.20178 .12361 L
.20742 .12361 L
.21019 .12361 L
.2114 .12361 L
.21274 .12361 L
.21394 .12361 L
.21506 .1228 L
.21753 .12031 L
.22272 .11531 L
.24125 .09997 L
.26149 .08714 L
.28262 .07732 L
.29316 .07355 L
.30271 .07071 L
.31216 .06837 L
.32239 .06631 L
.33319 .06463 L
.34336 .06345 L
.35286 .06266 L
.35826 .06233 L
.3633 .0621 L
.36603 .06201 L
.36861 .06193 L
.37094 .06188 L
.37346 .06184 L
.37477 .06183 L
.37621 .06181 L
.37693 .06181 L
.37771 .06181 L
.37845 .0618 L
.37912 .0618 L
.38034 .0618 L
.38103 .06181 L
.38168 .06181 L
.38297 .06182 L
.3837 .06182 L
.38436 .06183 L
.38667 .06186 L
.38921 .06191 L
.39434 .06203 L
.3991 .0622 L
.40355 .06238 L
.41357 .06291 L
.42434 .06364 L
.46562 .06752 L
Mistroke
.48625 .06989 L
.49629 .07111 L
.50103 .0717 L
.50538 .07215 L
.50997 .07249 L
.51238 .07263 L
.51493 .07274 L
.516 .07277 L
.51714 .07281 L
.51813 .07283 L
.51921 .07285 L
.52047 .07287 L
.52167 .07288 L
.52283 .07289 L
.5239 .07289 L
.52504 .07288 L
.52625 .07287 L
.5274 .07286 L
.52846 .07284 L
.5309 .07278 L
.53347 .0727 L
.53833 .07248 L
.54363 .07217 L
.55393 .07136 L
.56328 .07042 L
.58424 .06776 L
.62427 .06115 L
.66279 .05366 L
.70376 .04515 L
.74322 .03711 L
.76306 .03336 L
.77172 .03184 L
.7763 .03107 L
.78116 .03027 L
.78363 .02988 L
.7843 .02978 L
.78503 .02966 L
.78635 .12361 L
.78757 .12361 L
.78886 .12361 L
.79116 .12361 L
.80064 .12361 L
.82155 .12361 L
.85963 .12361 L
.90015 .12361 L
.93917 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`12oooo101VodSoool0
08ooool00`000?ooooooo`0joooo201Vo`?oool00`1Vooooooooo`16oooo002?oooo00<0003ooooo
ool0=oooo`<0I_l;oooo00<0I_ooooooool0A_ooo`00Soooo`030000oooooooo03?oool406Ko3_oo
o`0306Kooooooooo04Koool008ooool00`000?ooooooo`0_oooo101Voa;oool00`1Vooooooooo`16
oooo002?oooo0P0002[oool606Ko5_ooo`0306Kooooooooo04Koool008ooool00`000?ooooooo`0T
oooo1@1Voacoool00`1Vooooooooo`16oooo002?oooo00<0003oooooool07oooo`D0I_lQoooo00<0
I_ooooooool0A_ooo`00I?oooad0I_l>oooo00<0003oooooool06?ooo`L0I_lVoooo00<0I_oooooo
ool0A_ooo`00Goooo`D0I_lMoooo201Vo`Koool00`000?ooooooo`0@oooo201Vobgoool00`1Voooo
ooooo`16oooo001Moooo0P1Vob[oool606Ko00@00000I_l0I_l0I_l4oooo2`1VocGoool00`1Voooo
ooooo`16oooo001Joooo0`1Voc;oool200000_ooo`D0I_looooo00<0I_ooooooool0A_ooo`005ooo
o`@0000ioooo1@00000306Kooooooooo03?oool00`000?ooooooo`0goooo1@0000[oool00`1Voooo
ooooo`0[oooo100001Koool001Ooool00`000?ooooooo`0joooo0P1Vo`030000oooooooo03Koool0
0`000?ooooooo`0ioooo00<0003oooooool02_ooo`0306Kooooooooo02_oool00`000?ooooooo`0G
oooo000Hoooo00<0003oooooool0=oooo`80I_l2oooo00<0003oooooool0=_ooo`030000oooooooo
03Woool00`000?ooooooo`0:oooo00<0I_ooooooool0;?ooo`030000oooooooo01Koool0017oool4
00001?ooo`030000oooooooo03;oool400001?ooo`030000oooooooo03Koool00`000?ooooooo`0i
oooo00<0003oooooool02_ooo`0306Kooooooooo02goool00`000?ooooooo`0Eoooo000Goooo00@0
003oooooool0000coooo0P1Vo`Koool00`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000
oooooooo00[oool00`1Vooooooooo`0[oooo00@0003oooooool0000Foooo000Hoooo0P0003?oool0
0`1Vooooooooo`05oooo0P0003Soool20000>Oooo`80000<oooo00<0I_ooooooool0;?ooo`80000G
oooo001<oooo00<0I_ooooooool0@?ooo`030000oooooooo04Koool00`1Vooooooooo`15oooo001;
oooo00<0I_ooooooool0@Oooo`030000oooooooo04Koool00`1Vooooooooo`15oooo001:oooo00<0
I_ooooooool0@_ooo`030000oooooooo04Koool00`1Vooooooooo`15oooo0019oooo00<0I_oooooo
ool0@oooo`030000oooooooo04Koool00`1Vooooooooo`15oooo0018oooo00<0I_ooooooool0A?oo
o`030000oooooooo04Koool00`1Vooooooooo`15oooo000@ooooo`00017oool001Koool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol0
00Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o
03?o0006<ol08P0000Koool00`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000
oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`00>C?o00T00003oooo00?o09Wooooo
ool0;_ooo`030000oooooooo01Goool008ooool00`0003?o03?o000c<ol01P0000coool00ol0VOoo
ooooo`16oooo002?oooo00<0000co`0co`00<C?o0080000Boooo00?o09Woooooool0A_ooo`00Sooo
o`030000<ol0<ol002lco`0200005?ooo`03o`2Ioooooooo04Koool008ooool00`0003?o03?o000/
<ol00`0001Koool00ol0VOooooooo`16oooo002?oooo0P0002Xco`0300006Oooo`03o`2Ioooooooo
04Koool008ooool00`0003?o03?o000W<ol00P0001coool00ol0VOooooooo`16oooo002?oooo00<0
000co`0co`009S?o00030000oooooooo01coool00ol0VOooooooo`16oooo002?oooo00<0000co`0c
o`009C?o00030000oooooooo01goool00ol0VOooooooo`16oooo002?oooo00<0000co`0co`0093?o
00030000oooooooo01koool00ol0VOooooooo`16oooo002?oooo00<0000co`0co`008S?o0080000Q
oooo00?o09Woooooool0A_ooo`00Soooo`80000R<ol000<0003oooooool08Oooo`03o`2Ioooooooo
04Koool008ooool00`0003?o03?o000P<ol000<0003oooooool08_ooo`03o`2Ioooooooo04Koool0
08ooool00`0003?o03?o000O<ol000<0003oooooool08oooo`03o`2Ioooooooo04Koool008ooool0
0`0003?o03?o000O<ol000<0003oooooool08oooo`03o`2Ioooooooo04Koool008ooool00`0003?o
03?o000N<ol000<0003oooooool09?ooo`03o`2Ioooooooo04Koool008ooool00`0003?o03?o000M
<ol000<0003oooooool09Oooo`03o`2Ioooooooo04Koool008ooool200007C?o00030000oooooooo
02Koool00ol0VOooooooo`16oooo002?oooo00<0000co`0co`006c?o00030000oooooooo02Ooool0
0ol0VOooooooo`16oooo002?oooo00<0000co`0co`006c?o00030000oooooooo02Ooool00ol0VOoo
ooooo`16oooo002?oooo00<0000co`0co`006S?o00030000oooooooo02Soool00ol0VOooooooo`16
oooo002?oooo00<0000co`0co`006S?o00030000oooooooo02Soool00ol0VOooooooo`16oooo002?
oooo00<0000co`0co`006C?o00030000oooooooo02Woool00ol0VOooooooo`16oooo002?oooo0P00
01Xco`000`000?ooooooo`0Yoooo00?o09Woooooool0A_ooo`00Soooo`030000<ol0<ol001Pco`00
0`000?ooooooo`0Zoooo00?o09Woooooool0A_ooo`00Soooo`030000<ol0<ol001Pco`000`000?oo
ooooo`0Zoooo00?o09Woooooool0A_ooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0[
oooo00?o09Woooooool0A_ooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0[oooo00?o
09Woooooool0A_ooo`00Qoooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo02coool0
0ol0VOooooooo`16oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`0/oooo00?o09Woooooool0A_ooo`00ROooo`030000oooooooo00?oool300005C?o00030000
oooooooo02goool00ol0VOooooooo`16oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`0]oooo00?o09Woooooool0A_ooo`00ROooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0;Oooo`03o`2Ioooooooo04Koool008Soool200001Ooo
o`030000<ol0<ol001@co`000`000?ooooooo`0^oooo00?o09Woooooool0A_ooo`00Soooo`030000
<ol0<ol001@co`000`000?ooooooo`0^oooo00?o09Woooooool0A_ooo`00Soooo`030000<ol0<ol0
01<co`000`000?ooooooo`0_oooo00?o09Woooooool0A_ooo`00Soooo`80000D<ol000<0003ooooo
ool0;oooo`03o`2Ioooooooo04Koool008ooool00`0003?o03?o000C<ol000<0003oooooool0;ooo
o`03o`2Ioooooooo04Koool008ooool00`0003?o03?o000B<ol000<0003oooooool0<?ooo`03o`2I
oooooooo04Koool008ooool00`0003?o03?o000B<ol000<0003oooooool0<?ooo`03o`2Ioooooooo
04Koool008ooool00`0003?o03?o000B<ol000<0003oooooool0<?ooo`03o`2Ioooooooo04Koool0
08ooool00`0003?o03?o000A<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04Koool008ooool2
00004S?o00030000oooooooo037oool00ol0VOooooooo`16oooo002?oooo00<0000co`0co`004C?o
00030000oooooooo037oool00ol0VOooooooo`16oooo002?oooo00<0000co`0co`004C?o00030000
oooooooo037oool00ol0VOooooooo`16oooo002?oooo00<0000co`0co`0043?o00030000oooooooo
03;oool00ol0VOooooooo`16oooo002?oooo00<0000co`0co`0043?o00030000oooooooo03;oool0
0ol0VOooooooo`16oooo002?oooo00<0000co`0co`0043?o00030000oooooooo03;oool00ol0VOoo
ooooo`16oooo002?oooo00<0000co`0co`0043?o00030000oooooooo03;oool00ol0VOooooooo`16
oooo002?oooo0P00010co`000`000?ooooooo`0coooo00?o09Woooooool0A_ooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`0coooo00?o09Woooooool0A_ooo`00Soooo`030000<ol0<ol0
00lco`000`000?ooooooo`0coooo00?o09Woooooool0A_ooo`00Soooo`030000<ol0<ol000lco`00
0`000?ooooooo`0coooo00?o09Woooooool0A_ooo`00Soooo`030000<ol0<ol000lco`000`000?oo
ooooo`0coooo00?o09Woooooool0A_ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0d
oooo00?o09Woooooool0A_ooo`00Soooo`80000?<ol000<0003oooooool0=?ooo`03o`2Ioooooooo
04Koool008ooool00`0003?o03?o000><ol000<0003oooooool0=?ooo`03o`2Ioooooooo04Koool0
08ooool00`0003?o03?o000><ol000<0003oooooool0=?ooo`03o`2Ioooooooo04Koool008ooool0
0`0003?o03?o000=<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04Koool008Ooool400001?oo
o`030000<ol0<ol000dco`000`000?ooooooo`0eoooo00?o09Woooooool0A_ooo`00Qoooo`030000
oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool0=Oooo`03o`2Ioooooooo04Koool0
08Soool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`0eoooo00?o09Woooooool0A_oo
o`00ROooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0=Oooo`03o`2I
oooooooo04Koool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003ooooo
ool0=_ooo`03o`2Ioooooooo04Koool008Soool200001Oooo`030000<ol0<ol000`co`000`000?oo
ooooo`0foooo00?o09Woooooool0A_ooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0f
oooo00?o09Woooooool0A_ooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0foooo00?o
09Woooooool0A_ooo`00Soooo`80000=<ol000<0003oooooool0=_ooo`03o`2Ioooooooo04Koool0
08ooool00`0003?o03?o000<<ol000<0003oooooool0=_ooo`03o`2Ioooooooo04Koool008ooool0
0`0003?o03?o000;<ol000<0003oooooool0=oooo`03o`2Ioooooooo04Koool008ooool00`0003?o
03?o000;<ol000<0003oooooool0=oooo`03o`2Ioooooooo04Koool008ooool00`0003?o03?o000;
<ol000<0003oooooool0=oooo`03o`2Ioooooooo04Koool008ooool00`0003?o03?o000;<ol000<0
003oooooool0=oooo`03o`2Ioooooooo04Koool008ooool00`0003?o03?o000;<ol000<0003ooooo
ool0=oooo`03o`2Ioooooooo04Koool008ooool2000033?o00030000oooooooo03Ooool00ol0VOoo
ooooo`16oooo002?oooo00<0000co`0co`002c?o00030000oooooooo03Ooool00ol0VOooooooo`16
oooo002?oooo00<0000co`0co`002S?o00030000oooooooo03Soool00ol0VOooooooo`16oooo002?
oooo00<0000co`0co`002S?o00030000oooooooo03Soool00ol0VOooooooo`16oooo002?oooo00<0
000co`0co`002S?o00030000oooooooo03Soool00ol0VOooooooo`16oooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo03Soool00ol0VOooooooo`16oooo002?oooo0P0000/co`000`000?oo
ooooo`0hoooo00?o09Woooooool0A_ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0h
oooo00?o09Woooooool0A_ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0hoooo00?o
09Woooooool0A_ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0ioooo00?o09Wooooo
ool0A_ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0ioooo00?o09Woooooool0A_oo
o`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0ioooo00?o09Woooooool0A_ooo`00Sooo
o`80000:<ol000<0003oooooool0>Oooo`03o`2Ioooooooo04Koool008ooool00`0003?o03?o0009
<ol000<0003oooooool0>Oooo`03o`2Ioooooooo04Koool008ooool00`0003?o03?o0009<ol000<0
003oooooool0>Oooo`03o`2Ioooooooo04Koool008ooool00`0003?o03?o0008<ol000<0003ooooo
ool0>_ooo`03o`2Ioooooooo04Koool008Soool200001Oooo`030000<ol0<ol000Pco`000`000?oo
ooooo`0joooo00?o09Woooooool0A_ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol0
00Pco`000`000?ooooooo`0joooo00?o09Woooooool0A_ooo`00ROooo`030000oooooooo00?oool3
000023?o00030000oooooooo03[oool00ol0VOooooooo`16oooo002:oooo00<0003oooooool00_oo
o`030000<ol0<ol000Pco`000`000?ooooooo`0joooo00?o09Woooooool0A_ooo`00Qoooo`040000
oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0joooo00?o09Woooooool0A_oo
o`00R?ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo03_oool00ol0VOooooooo`16
oooo002?oooo00<0000co`0co`001c?o00030000oooooooo03_oool00ol0VOooooooo`16oooo002?
oooo00<0000co`0co`001c?o00030000oooooooo03_oool00ol0VOooooooo`16oooo002?oooo00<0
000co`0co`001c?o00030000oooooooo03_oool00ol0VOooooooo`16oooo002?oooo0P0000Pco`00
0`000?ooooooo`0koooo00?o09Woooooool0A_ooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ooooo`0koooo00?o09Woooooool0A_ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0k
oooo00?o09Woooooool0A_ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0koooo00?o
09Woooooool0A_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0loooo00?o09Wooooo
ool0A_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`0loooo00?o09Woooooool0A_oo
o`00Soooo`800007<ol000<0003oooooool0??ooo`03o`2Ioooooooo04Koool008ooool00`0003?o
03?o0006<ol000<0003oooooool0??ooo`03o`2Ioooooooo04Koool008ooool00`0003?o03?o0006
<ol000<0003oooooool0??ooo`03o`2Ioooooooo04Koool008ooool00`0003?o03?o0006<ol000<0
003oooooool0??ooo`03o`2Ioooooooo04Koool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool0??ooo`03o`2Ioooooooo04Koool008ooool00`0003?o03?o0006<ol000<0003oooooool0??oo
o`03o`2Ioooooooo04Koool008ooool200001S?o00030000oooooooo03goool00ol0VOooooooo`16
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo03goool00ol0VOooooooo`16oooo002?
oooo00<0000co`0co`001C?o00030000oooooooo03goool00ol0VOooooooo`16oooo002?oooo00<0
000co`0co`001C?o00030000oooooooo03goool00ol0VOooooooo`16oooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo03goool00ol0VOooooooo`16oooo002?oooo00<0000co`0co`001C?o
00030000oooooooo03goool00ol0VOooooooo`16oooo002?oooo0P0000Hco`000`000?ooooooo`0m
oooo00?o09Woooooool0A_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0moooo00?o
09Woooooool0A_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0moooo00?o09Wooooo
ool0A_ooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0noooo00?o09Woooooool0A_oo
o`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`0noooo00?o09Woooooool0A_ooo`00ROoo
o`<00003oooo00<0000co`0co`0013?o00030000oooooooo03koool00ol0VOooooooo`16oooo002:
oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`0noooo00?o09Wooooo
ool0A_ooo`00Qoooo`D00003oooo0`0000@co`000`000?ooooooo`0noooo00?o09Woooooool0A_oo
o`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:
oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007coool0
0`000?ooooooo`0@oooo1c?o00_oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?oo
o`030000oooooooo00Koool7<ol03?ooo`030000oooooooo07_oool007_oool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`06oooo100000<co`0200000oooo`@00003oooo00<0003ooooo
ool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01Oooo`030000<ol0<ol000@co`05oooo00<0003oooooool01?ooo`030000oooooooo07_oool0
07[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`03<ol00000<ol000@co`06oooo00<0
003oooooool01?ooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003?ooo`8co`00
0`0003?o03?o0002<ol01oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001koooo00D0
003oooooooooool000003oooo`040000<ol0<ol000000c?o00Goool010000?ooooooo`0000?oool0
0`000?ooooooo`1koooo001loooo00<0003oooooool04?ooo`03<ol00000000000@co`06oooo0P00
00?oool00`000?ooooooo`1loooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.75718 .12361 L
.77751 .12361 L
.78293 .12361 L
.7859 .12361 L
.78734 .12361 L
.78866 .12361 L
.78988 .12361 L
s
.78988 .12361 m
.79034 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.19227 .12361 L
.20178 .12361 L
.20433 .12361 L
.20704 .12361 L
.20845 .12361 L
.20925 .12361 L
.21 .12311 L
.21132 .12176 L
.21274 .12033 L
.22272 .111 L
.24243 .09582 L
.26394 .08342 L
.28453 .07485 L
.30365 .06924 L
.31422 .06695 L
.32417 .06524 L
.33311 .06404 L
.33811 .06349 L
.34278 .06306 L
.34775 .06268 L
.35228 .0624 L
.35732 .06215 L
.36012 .06204 L
.36272 .06196 L
.36523 .0619 L
.3679 .06185 L
.36928 .06183 L
.37058 .06182 L
.37132 .06181 L
.372 .06181 L
.37275 .06181 L
.37354 .0618 L
.37476 .0618 L
.37607 .06181 L
.37731 .06181 L
.37843 .06182 L
.37975 .06183 L
.38118 .06185 L
.38378 .06189 L
.38614 .06194 L
.38867 .06201 L
.39325 .06216 L
.40366 .06262 L
.41465 .06329 L
.4247 .06403 L
Mistroke
.46446 .06792 L
.48453 .07026 L
.49327 .07133 L
.50271 .07248 L
.50528 .07274 L
.508 .07296 L
.51052 .07314 L
.51286 .07326 L
.51507 .07336 L
.51742 .07344 L
.51877 .07347 L
.52004 .07349 L
.52118 .07351 L
.52242 .07352 L
.52372 .07352 L
.52494 .07352 L
.52563 .07351 L
.52627 .07351 L
.52697 .0735 L
.52771 .07349 L
.5291 .07347 L
.5304 .07344 L
.53333 .07336 L
.53588 .07326 L
.5382 .07316 L
.54341 .07286 L
.55341 .07211 L
.56263 .07122 L
.58344 .06864 L
.62289 .06226 L
.66083 .05498 L
.70123 .04663 L
.7401 .03862 L
.75989 .03478 L
.77033 .03288 L
.77605 .03188 L
.78143 .03097 L
.78616 .0302 L
.78745 .03 L
.78881 .02978 L
.78998 .0296 L
.79125 .12361 L
.79198 .12361 L
.79267 .12361 L
.79397 .12361 L
.79687 .12361 L
.8021 .12361 L
.82124 .12361 L
.85968 .12361 L
.90056 .12361 L
Mistroke
.93994 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`11oooo1P1VodOoool0
08ooool00`000?ooooooo`0moooo101Vo`Goool00`1Vooooooooo`15oooo002?oooo00<0003ooooo
ool0>?ooo`D0I_l9oooo00<0I_ooooooool0AOooo`00Soooo`030000oooooooo03?oool506Ko3_oo
o`0306Kooooooooo04Goool008ooool00`000?ooooooo`0^oooo1@1Voa?oool00`1Vooooooooo`15
oooo002?oooo0P0002[oool506Ko6?ooo`0306Kooooooooo04Goool008ooool00`000?ooooooo`0T
oooo1@1Voagoool00`1Vooooooooo`15oooo002?oooo00<0003oooooool07oooo`D0I_lRoooo00<0
I_ooooooool0AOooo`00I?oooad0I_l>oooo00<0003oooooool06?ooo`L0I_lWoooo00<0I_oooooo
ool0AOooo`00Goooo`D0I_lMoooo201Vo`Koool00`000?ooooooo`0@oooo201Vobkoool00`1Voooo
ooooo`15oooo001Koooo101Vob[oool606Ko00<00000I_ooool02_ooo`H0I_lfoooo00<0I_oooooo
ool0AOooo`00Eoooo`@0I_ldoooo0P0000/0I_lloooo00<0I_ooooooool0AOooo`005oooo`@0000i
oooo1@0003Koool00`000?ooooooo`0goooo1@0000_oool00`1Vooooooooo`0Zoooo100001Koool0
01Ooool00`000?ooooooo`0ioooo0P1Vo`03oooo0000oooo03Ooool00`000?ooooooo`0ioooo00<0
003oooooool02oooo`0306Kooooooooo02[oool00`000?ooooooo`0Goooo000Hoooo00<0003ooooo
ool0=_ooo`80I_l3oooo00<0003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0;
oooo00<0I_ooooooool0:oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo
03;oool400001?ooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool02ooo
o`0306Kooooooooo02coool00`000?ooooooo`0Eoooo000Goooo00@0003oooooool0000coooo00<0
I_ooooooool01Oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool02ooo
o`0306Kooooooooo02[oool010000?ooooooo`0001Koool001Soool20000<oooo`0306Kooooooooo
00Goool20000>?ooo`80000ioooo0P0000goool00`1Vooooooooo`0[oooo0P0001Ooool004_oool2
06Ko@_ooo`030000oooooooo04Ooool00`1Vooooooooo`14oooo001:oooo00<0I_ooooooool0@_oo
o`030000oooooooo04Ooool00`1Vooooooooo`14oooo0019oooo00<0I_ooooooool0@oooo`030000
oooooooo04Ooool00`1Vooooooooo`14oooo0018oooo00<0I_ooooooool0A?ooo`030000oooooooo
04Ooool00`1Vooooooooo`14oooo0017oooo00<0I_ooooooool0AOooo`030000oooooooo04Ooool0
0`1Vooooooooo`14oooo000@ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006<ol010000003o`2I
0000000001/00006oooo00<0003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol003Tco`0900001?ooo`03o`2Ioooooooo
02goool00`000?ooooooo`0Eoooo002?oooo00<0000co`0co`00<c?o00H0000=oooo00?o09Wooooo
ool0AOooo`00Soooo`030000<ol0<ol0034co`0200004oooo`03o`2Ioooooooo04Goool008ooool0
0`0003?o03?o000_<ol00P0001Goool00ol0VOooooooo`15oooo002?oooo00<0000co`0co`00;3?o
00<0000Goooo00?o09Woooooool0AOooo`00Soooo`80000Z<ol00`0001[oool00ol0VOooooooo`15
oooo002?oooo00<0000co`0co`009c?o0080000Moooo00?o09Woooooool0AOooo`00Soooo`030000
<ol0<ol002Hco`000`000?ooooooo`0Moooo00?o09Woooooool0AOooo`00Soooo`030000<ol0<ol0
02Dco`000`000?ooooooo`0Noooo00?o09Woooooool0AOooo`00Soooo`030000<ol0<ol002@co`00
0`000?ooooooo`0Ooooo00?o09Woooooool0AOooo`00Soooo`030000<ol0<ol0028co`0200008_oo
o`03o`2Ioooooooo04Goool008ooool200008S?o00030000oooooooo02;oool00ol0VOooooooo`15
oooo002?oooo00<0000co`0co`0083?o00030000oooooooo02?oool00ol0VOooooooo`15oooo002?
oooo00<0000co`0co`007c?o00030000oooooooo02Coool00ol0VOooooooo`15oooo002?oooo00<0
000co`0co`007c?o00030000oooooooo02Coool00ol0VOooooooo`15oooo002?oooo00<0000co`0c
o`007S?o00030000oooooooo02Goool00ol0VOooooooo`15oooo002?oooo00<0000co`0co`007C?o
00030000oooooooo02Koool00ol0VOooooooo`15oooo002?oooo0P0001dco`000`000?ooooooo`0W
oooo00?o09Woooooool0AOooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0Xoooo00?o
09Woooooool0AOooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0Xoooo00?o09Wooooo
ool0AOooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0Yoooo00?o09Woooooool0AOoo
o`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0Yoooo00?o09Woooooool0AOooo`00Sooo
o`030000<ol0<ol001Tco`000`000?ooooooo`0Zoooo00?o09Woooooool0AOooo`00Soooo`80000J
<ol000<0003oooooool0:_ooo`03o`2Ioooooooo04Goool008ooool00`0003?o03?o000H<ol000<0
003oooooool0:oooo`03o`2Ioooooooo04Goool008ooool00`0003?o03?o000H<ol000<0003ooooo
ool0:oooo`03o`2Ioooooooo04Goool008ooool00`0003?o03?o000G<ol000<0003oooooool0;?oo
o`03o`2Ioooooooo04Goool008ooool00`0003?o03?o000G<ol000<0003oooooool0;?ooo`03o`2I
oooooooo04Goool008Ooool500000oooo`030000<ol0<ol001Hco`000`000?ooooooo`0]oooo00?o
09Woooooool0AOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000F<ol000<0003ooooo
ool0;Oooo`03o`2Ioooooooo04Goool008Woool00`000?ooooooo`03oooo0`0001Dco`000`000?oo
ooooo`0^oooo00?o09Woooooool0AOooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E
<ol000<0003oooooool0;_ooo`03o`2Ioooooooo04Goool008Woool00`000?ooooooo`03oooo00<0
000co`0co`005C?o00030000oooooooo02koool00ol0VOooooooo`15oooo0028oooo0P0000Goool0
0`0003?o03?o000D<ol000<0003oooooool0;oooo`03o`2Ioooooooo04Goool008ooool00`0003?o
03?o000D<ol000<0003oooooool0;oooo`03o`2Ioooooooo04Goool008ooool00`0003?o03?o000C
<ol000<0003oooooool0<?ooo`03o`2Ioooooooo04Goool008ooool2000053?o00030000oooooooo
033oool00ol0VOooooooo`15oooo002?oooo00<0000co`0co`004c?o00030000oooooooo033oool0
0ol0VOooooooo`15oooo002?oooo00<0000co`0co`004S?o00030000oooooooo037oool00ol0VOoo
ooooo`15oooo002?oooo00<0000co`0co`004S?o00030000oooooooo037oool00ol0VOooooooo`15
oooo002?oooo00<0000co`0co`004S?o00030000oooooooo037oool00ol0VOooooooo`15oooo002?
oooo00<0000co`0co`004C?o00030000oooooooo03;oool00ol0VOooooooo`15oooo002?oooo0P00
018co`000`000?ooooooo`0boooo00?o09Woooooool0AOooo`00Soooo`030000<ol0<ol0014co`00
0`000?ooooooo`0boooo00?o09Woooooool0AOooo`00Soooo`030000<ol0<ol0014co`000`000?oo
ooooo`0boooo00?o09Woooooool0AOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0c
oooo00?o09Woooooool0AOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0coooo00?o
09Woooooool0AOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0coooo00?o09Wooooo
ool0AOooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0coooo00?o09Woooooool0AOoo
o`00Soooo`80000@<ol000<0003oooooool0=?ooo`03o`2Ioooooooo04Goool008ooool00`0003?o
03?o000?<ol000<0003oooooool0=?ooo`03o`2Ioooooooo04Goool008ooool00`0003?o03?o000?
<ol000<0003oooooool0=?ooo`03o`2Ioooooooo04Goool008ooool00`0003?o03?o000?<ol000<0
003oooooool0=?ooo`03o`2Ioooooooo04Goool008ooool00`0003?o03?o000?<ol000<0003ooooo
ool0=?ooo`03o`2Ioooooooo04Goool008ooool00`0003?o03?o000><ol000<0003oooooool0=Ooo
o`03o`2Ioooooooo04Goool008ooool200003c?o00030000oooooooo03Goool00ol0VOooooooo`15
oooo002?oooo00<0000co`0co`003S?o00030000oooooooo03Goool00ol0VOooooooo`15oooo002?
oooo00<0000co`0co`003S?o00030000oooooooo03Goool00ol0VOooooooo`15oooo002?oooo00<0
000co`0co`003C?o00030000oooooooo03Koool00ol0VOooooooo`15oooo0027oooo100000Coool0
0`0003?o03?o000=<ol000<0003oooooool0=_ooo`03o`2Ioooooooo04Goool008Ooool00`000?oo
ooooo`05oooo00<0000co`0co`003C?o00030000oooooooo03Koool00ol0VOooooooo`15oooo0028
oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0=_ooo`03o`2Ioooooooo04Goool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo03Ooool00ol0VOoo
ooooo`14oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0033?o00030000oooooooo
03Soool00ol0VOooooooo`14oooo0028oooo0P0000Goool00`0003?o03?o000<<ol000<0003ooooo
ool0>?ooo`03o`2Ioooooooo04Coool008ooool00`0003?o03?o000<<ol000<0003oooooool0>?oo
o`03o`2Ioooooooo04Coool008ooool00`0003?o03?o000<<ol000<0003oooooool0>?ooo`03o`2I
oooooooo04Coool008ooool200003C?o00030000oooooooo03Soool00ol0VOooooooo`14oooo002?
oooo00<0000co`0co`0033?o00030000oooooooo03Soool00ol0VOooooooo`14oooo002?oooo00<0
000co`0co`002c?o00030000oooooooo03Woool00ol0VOooooooo`14oooo002?oooo00<0000co`0c
o`002c?o00030000oooooooo03Woool00ol0VOooooooo`14oooo002?oooo00<0000co`0co`002c?o
00030000oooooooo03Woool00ol0VOooooooo`14oooo002?oooo00<0000co`0co`002c?o00030000
oooooooo03Woool00ol0VOooooooo`14oooo002?oooo00<0000co`0co`002c?o00030000oooooooo
03Woool00ol0VOooooooo`14oooo002?oooo0P0000`co`000`000?ooooooo`0ioooo00?o09Wooooo
ool0A?ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0ioooo00?o09Woooooool0A?oo
o`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0joooo00?o09Woooooool0A?ooo`00Sooo
o`030000<ol0<ol000Xco`000`000?ooooooo`0joooo00?o09Woooooool0A?ooo`00Soooo`030000
<ol0<ol000Xco`000`000?ooooooo`0joooo00?o09Woooooool0A?ooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0joooo00?o09Woooooool0A?ooo`00Soooo`80000;<ol000<0003ooooo
ool0>_ooo`03o`2Ioooooooo04Coool008ooool00`0003?o03?o000:<ol000<0003oooooool0>_oo
o`03o`2Ioooooooo04Coool008ooool00`0003?o03?o000:<ol000<0003oooooool0>_ooo`03o`2I
oooooooo04Coool008ooool00`0003?o03?o0009<ol000<0003oooooool0>oooo`03o`2Ioooooooo
04Coool008ooool00`0003?o03?o0009<ol000<0003oooooool0>oooo`03o`2Ioooooooo04Coool0
08ooool00`0003?o03?o0009<ol000<0003oooooool0>oooo`03o`2Ioooooooo04Coool008ooool2
00002S?o00030000oooooooo03_oool00ol0VOooooooo`14oooo002?oooo00<0000co`0co`002C?o
00030000oooooooo03_oool00ol0VOooooooo`14oooo002?oooo00<0000co`0co`002C?o00030000
oooooooo03_oool00ol0VOooooooo`14oooo002?oooo00<0000co`0co`0023?o00030000oooooooo
03coool00ol0VOooooooo`14oooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0003ooooo
ool0??ooo`03o`2Ioooooooo04Coool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008
<ol000<0003oooooool0??ooo`03o`2Ioooooooo04Coool008Woool00`000?ooooooo`03oooo0`00
00Pco`000`000?ooooooo`0loooo00?o09Woooooool0A?ooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o0008<ol000<0003oooooool0??ooo`03o`2Ioooooooo04Coool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0??ooo`03o`2Ioooooooo04Coool0
08Soool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`0moooo00?o09Woooooool0A?oo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0moooo00?o09Woooooool0A?ooo`00Sooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0moooo00?o09Woooooool0A?ooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`0moooo00?o09Woooooool0A?ooo`00Soooo`800008<ol000<0
003oooooool0?Oooo`03o`2Ioooooooo04Coool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool0?Oooo`03o`2Ioooooooo04Coool008ooool00`0003?o03?o0007<ol000<0003oooooool0?Ooo
o`03o`2Ioooooooo04Coool008ooool00`0003?o03?o0007<ol000<0003oooooool0?Oooo`03o`2I
oooooooo04Coool008ooool00`0003?o03?o0006<ol000<0003oooooool0?_ooo`03o`2Ioooooooo
04Coool008ooool00`0003?o03?o0006<ol000<0003oooooool0?_ooo`03o`2Ioooooooo04Coool0
08ooool200001c?o00030000oooooooo03koool00ol0VOooooooo`14oooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo03koool00ol0VOooooooo`14oooo002?oooo00<0000co`0co`001S?o
00030000oooooooo03koool00ol0VOooooooo`14oooo002?oooo00<0000co`0co`001S?o00030000
oooooooo03koool00ol0VOooooooo`14oooo002?oooo00<0000co`0co`001S?o00030000oooooooo
03koool00ol0VOooooooo`14oooo002?oooo00<0000co`0co`001S?o00030000oooooooo03koool0
0ol0VOooooooo`14oooo002?oooo0P0000Hco`000`000?ooooooo`0ooooo00?o09Woooooool0A?oo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`0ooooo00?o09Woooooool0A?ooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`0ooooo00?o09Woooooool0A?ooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`0ooooo00?o09Woooooool0A?ooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`0ooooo00?o09Woooooool0A?ooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`0ooooo00?o09Woooooool0A?ooo`00Soooo`800006<ol000<0003oooooool0?ooo
o`03o`2Ioooooooo04Coool008ooool00`0003?o03?o0005<ol000<0003oooooool0?oooo`03o`2I
oooooooo04Coool008ooool00`0003?o03?o0005<ol000<0003oooooool0?oooo`03o`2Ioooooooo
04Coool008ooool00`0003?o03?o0004<ol000<0003oooooool0@?ooo`03o`2Ioooooooo04Coool0
08ooool00`0003?o03?o0004<ol000<0003oooooool0@?ooo`03o`2Ioooooooo04Coool008Woool3
00000oooo`030000<ol0<ol000@co`000`000?ooooooo`10oooo00?o09Woooooool0A?ooo`00R_oo
o`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0@?ooo`03o`2Ioooooooo
04Coool008Ooool500000oooo`<00004<ol000<0003oooooool0@?ooo`03o`2Ioooooooo04Coool0
08Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_oo
o`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0
003oooooool04oooo`Lco`0>oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool0
0`000?ooooooo`09oooo1c?o00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01_ooo`@00003<ol00P000003<ol0oooooooo00@00002oooo1000
00?oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo00<0003oooooool01c?o00;oool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003ooooo
ool03_ooo`030000oooo<ol000Hco`03oooo00<0003oooooool00oooo`030000oooooooo00Coool0
0`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000koool00`0003?o03?o0005<ol01?oo
o`030000oooooooo00?oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000ooool010000?ooooooo`0000Hco`02oooo00@0003oooooool00002oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200001c?o
00?oool200001?ooo`800003oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o
08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.75718 .12361 L
.77751 .12361 L
.78293 .12361 L
.78866 .12361 L
.79102 .12361 L
.79355 .12361 L
.7943 .12361 L
.79501 .12361 L
s
.79501 .12361 m
.79526 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.19227 .12361 L
.19721 .12361 L
.20178 .12361 L
.2031 .12361 L
.20433 .12361 L
.20562 .12272 L
.2063 .12202 L
.20704 .12128 L
.21274 .11573 L
.22272 .10695 L
.24243 .09273 L
.26394 .08118 L
.27391 .077 L
.28453 .07326 L
.30365 .06814 L
.31394 .06612 L
.32506 .06444 L
.33017 .06383 L
.33557 .06328 L
.34062 .06285 L
.34523 .06253 L
.34977 .06228 L
.35471 .06207 L
.35742 .06198 L
.35993 .06191 L
.36232 .06187 L
.36365 .06185 L
.36487 .06183 L
.36592 .06182 L
.36703 .06181 L
.36815 .06181 L
.36936 .0618 L
.37042 .0618 L
.37155 .06181 L
.37262 .06181 L
.37358 .06182 L
.37482 .06183 L
.37596 .06184 L
.37853 .06188 L
.3808 .06193 L
.3832 .06199 L
.38813 .06214 L
.39264 .06232 L
.40278 .06284 L
.42109 .06412 L
Mistroke
.46085 .06805 L
.48092 .0704 L
.4991 .07266 L
.50398 .07322 L
.50655 .07346 L
.50925 .07367 L
.51163 .07381 L
.51423 .07395 L
.5166 .07404 L
.51881 .0741 L
.52012 .07412 L
.5208 .07413 L
.52153 .07414 L
.52217 .07415 L
.52288 .07415 L
.52411 .07416 L
.52531 .07416 L
.52661 .07415 L
.52783 .07413 L
.52894 .07412 L
.53147 .07406 L
.53423 .07398 L
.53712 .07387 L
.53979 .07374 L
.55034 .07306 L
.56029 .07217 L
.57889 .07002 L
.61741 .06409 L
.65838 .0564 L
.69784 .0483 L
.73578 .04042 L
.7569 .03622 L
.77617 .03265 L
.78572 .03102 L
.78834 .03059 L
.79112 .03014 L
.7935 .02976 L
.79415 .02966 L
.79485 .02955 L
.79612 .12361 L
.79731 .12361 L
.79842 .12361 L
.80093 .12361 L
.80599 .12361 L
.81504 .12361 L
.85406 .12361 L
.89552 .12361 L
.93547 .12361 L
.97391 .12361 L
.97619 .12361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`11oooo201VodGoool0
08ooool00`000?ooooooo`0loooo1@1Vo`Ooool00`1Vooooooooo`13oooo002?oooo00<0003ooooo
ool0=oooo`D0I_l<oooo00<0I_ooooooool0@oooo`00Soooo`030000oooooooo03;oool506Ko4Ooo
o`0306Kooooooooo04?oool008ooool00`000?ooooooo`0]oooo1@1VoaKoool00`1Vooooooooo`13
oooo002?oooo0P0002Woool506Ko6oooo`0306Kooooooooo04?oool008ooool00`000?ooooooo`0S
oooo1@1Vob3oool00`1Vooooooooo`13oooo002?oooo00<0003oooooool07_ooo`D0I_lUoooo00<0
I_ooooooool0@oooo`00H_oooah0I_l?oooo00<0003oooooool06Oooo`D0I_lZoooo00<0I_oooooo
ool0@oooo`00G?ooo`H0I_lNoooo201Vo`Ooool00`000?ooooooo`0Doooo1@1Vobooool00`1Voooo
ooooo`13oooo001Joooo0P1Vobcoool706Ko00<0003oooooool03?ooo`P0I_ldoooo00<0I_oooooo
ool0@oooo`00F?ooo`80I_leoooo0P0000d0I_lloooo00<0I_ooooooool0@oooo`005oooo`@0000i
oooo1@0003Koool00`000?ooooooo`0goooo1@0000coool00`1Vooooooooo`0Yoooo100001Koool0
01Ooool00`000?ooooooo`0ioooo0P1Vo`03oooo0000oooo03Ooool00`000?ooooooo`0ioooo00<0
003oooooool03?ooo`0306Kooooooooo02Woool00`000?ooooooo`0Goooo000Hoooo00<0003ooooo
ool0=_ooo`80I_l3oooo00<0003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0<
oooo00<0I_ooooooool0:_ooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo
03;oool400001?ooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool03?oo
o`0306Kooooooooo02_oool00`000?ooooooo`0Eoooo000Goooo00@0003oooooool0000coooo00<0
I_ooooooool01Oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool03?oo
o`0306Kooooooooo02Woool010000?ooooooo`0001Koool001Soool20000<_ooo`80I_l7oooo0P00
03Soool20000>Oooo`80000>oooo00<0I_ooooooool0:_ooo`80000Goooo001:oooo0P1Vod?oool0
0`000?ooooooo`18oooo00<0I_ooooooool0@oooo`00BOooo`0306Kooooooooo04?oool00`000?oo
ooooo`18oooo00<0I_ooooooool0@oooo`00Aoooo`80I_m6oooo00<0003oooooool0B?ooo`0306Ko
oooooooo04?oool004Koool00`1Vooooooooo`16oooo00<0003oooooool0B?ooo`0306Kooooooooo
04?oool004Goool00`1Vooooooooo`17oooo00<0003oooooool0B?ooo`0306Kooooooooo04?oool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`06000000?o09T0000000006@0000Koool0
0`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?oo
ooooo`0ioooo00<0000co`0co`00>C?o00T00006oooo00?o09Woooooool0:oooo`030000oooooooo
01Goool008ooool00`0003?o03?o000c<ol01P0000ooool00ol0VOooooooo`13oooo002?oooo00<0
000co`0co`00<C?o0080000Eoooo00?o09Woooooool0@oooo`00Soooo`030000<ol0<ol002lco`02
00005oooo`03o`2Ioooooooo04?oool008ooool00`0003?o03?o000/<ol00`0001Woool00ol0VOoo
ooooo`13oooo002?oooo0P0002Xco`0300007?ooo`03o`2Ioooooooo04?oool008ooool00`0003?o
03?o000W<ol00P0001ooool00ol0VOooooooo`13oooo002?oooo00<0000co`0co`009S?o00030000
oooooooo01ooool00ol0VOooooooo`13oooo002?oooo00<0000co`0co`009C?o00030000oooooooo
023oool00ol0VOooooooo`13oooo002?oooo00<0000co`0co`0093?o00030000oooooooo027oool0
0ol0VOooooooo`13oooo002?oooo00<0000co`0co`008S?o0080000Toooo00?o09Woooooool0@ooo
o`00Soooo`80000R<ol000<0003oooooool09?ooo`03o`2Ioooooooo04?oool008ooool00`0003?o
03?o000P<ol000<0003oooooool09Oooo`03o`2Ioooooooo04?oool008ooool00`0003?o03?o000O
<ol000<0003oooooool09_ooo`03o`2Ioooooooo04?oool008ooool00`0003?o03?o000O<ol000<0
003oooooool09_ooo`03o`2Ioooooooo04?oool008ooool00`0003?o03?o000N<ol000<0003ooooo
ool09oooo`03o`2Ioooooooo04?oool008ooool00`0003?o03?o000M<ol000<0003oooooool0:?oo
o`03o`2Ioooooooo04?oool008ooool200007C?o00030000oooooooo02Woool00ol0VOooooooo`13
oooo002?oooo00<0000co`0co`006c?o00030000oooooooo02[oool00ol0VOooooooo`13oooo002?
oooo00<0000co`0co`006c?o00030000oooooooo02[oool00ol0VOooooooo`13oooo002?oooo00<0
000co`0co`006S?o00030000oooooooo02_oool00ol0VOooooooo`13oooo002?oooo00<0000co`0c
o`006S?o00030000oooooooo02_oool00ol0VOooooooo`13oooo002?oooo00<0000co`0co`006C?o
00030000oooooooo02coool00ol0VOooooooo`13oooo002?oooo0P0001Xco`000`000?ooooooo`0/
oooo00?o09Woooooool0@oooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0]oooo00?o
09Woooooool0@oooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0]oooo00?o09Wooooo
ool0@oooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0^oooo00?o09Woooooool0@ooo
o`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0^oooo00?o09Woooooool0@oooo`00Qooo
o`D00003oooo00<0000co`0co`005S?o00030000oooooooo02ooool00ol0VOooooooo`13oooo0029
oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`0_oooo00?o09Wooooo
ool0@oooo`00ROooo`030000oooooooo00?oool300005C?o00030000oooooooo033oool00ol0VOoo
ooooo`13oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`0`
oooo00?o09Woooooool0@oooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E<ol000<0
003oooooool0<?ooo`03o`2Ioooooooo04?oool008Soool200001Oooo`030000<ol0<ol001@co`00
0`000?ooooooo`0aoooo00?o09Woooooool0@oooo`00Soooo`030000<ol0<ol001@co`000`000?oo
ooooo`0aoooo00?o09Woooooool0@oooo`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`0b
oooo00?o09Woooooool0@oooo`00Soooo`80000D<ol000<0003oooooool0<_ooo`03o`2Ioooooooo
04?oool008ooool00`0003?o03?o000C<ol000<0003oooooool0<_ooo`03o`2Ioooooooo04?oool0
08ooool00`0003?o03?o000B<ol000<0003oooooool0<oooo`03o`2Ioooooooo04?oool008ooool0
0`0003?o03?o000B<ol000<0003oooooool0<oooo`03o`2Ioooooooo04?oool008ooool00`0003?o
03?o000B<ol000<0003oooooool0<oooo`03o`2Ioooooooo04?oool008ooool00`0003?o03?o000A
<ol000<0003oooooool0=?ooo`03o`2Ioooooooo04?oool008ooool200004S?o00030000oooooooo
03Coool00ol0VOooooooo`13oooo002?oooo00<0000co`0co`004C?o00030000oooooooo03Coool0
0ol0VOooooooo`13oooo002?oooo00<0000co`0co`004C?o00030000oooooooo03Coool00ol0VOoo
ooooo`13oooo002?oooo00<0000co`0co`0043?o00030000oooooooo03Goool00ol0VOooooooo`13
oooo002?oooo00<0000co`0co`0043?o00030000oooooooo03Goool00ol0VOooooooo`13oooo002?
oooo00<0000co`0co`0043?o00030000oooooooo03Goool00ol0VOooooooo`13oooo002?oooo00<0
000co`0co`0043?o00030000oooooooo03Goool00ol0VOooooooo`13oooo002?oooo0P00010co`00
0`000?ooooooo`0foooo00?o09Woooooool0@oooo`00Soooo`030000<ol0<ol000lco`000`000?oo
ooooo`0foooo00?o09Woooooool0@oooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0f
oooo00?o09Woooooool0@oooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0foooo00?o
09Woooooool0@oooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0foooo00?o09Wooooo
ool0@oooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0goooo00?o09Woooooool0@ooo
o`00Soooo`80000?<ol000<0003oooooool0=oooo`03o`2Ioooooooo04?oool008ooool00`0003?o
03?o000><ol000<0003oooooool0=oooo`03o`2Ioooooooo04?oool008ooool00`0003?o03?o000>
<ol000<0003oooooool0=oooo`03o`2Ioooooooo04?oool008ooool00`0003?o03?o000=<ol000<0
003oooooool0>?ooo`03o`2Ioooooooo04?oool008Ooool400001?ooo`030000<ol0<ol000dco`00
0`000?ooooooo`0hoooo00?o09Woooooool0@oooo`00Qoooo`030000oooooooo00Goool00`0003?o
03?o000=<ol000<0003oooooool0>?ooo`03o`2Ioooooooo04?oool008Soool00`000?ooooooo`04
oooo0`0000dco`000`000?ooooooo`0hoooo00?o09Woooooool0@oooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000=<ol000<0003oooooool0>?ooo`03o`2Ioooooooo04?oool008Ooool0
10000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0>Oooo`03o`2Ioooooooo
04?oool008Soool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`0ioooo00?o09Wooooo
ool0@oooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0ioooo00?o09Woooooool0@ooo
o`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0ioooo00?o09Woooooool0@oooo`00Sooo
o`80000=<ol000<0003oooooool0>Oooo`03o`2Ioooooooo04?oool008ooool00`0003?o03?o000<
<ol000<0003oooooool0>Oooo`03o`2Ioooooooo04?oool008ooool00`0003?o03?o000;<ol000<0
003oooooool0>_ooo`03o`2Ioooooooo04?oool008ooool00`0003?o03?o000;<ol000<0003ooooo
ool0>_ooo`03o`2Ioooooooo04?oool008ooool00`0003?o03?o000;<ol000<0003oooooool0>_oo
o`03o`2Ioooooooo04?oool008ooool00`0003?o03?o000;<ol000<0003oooooool0>_ooo`03o`2I
oooooooo04?oool008ooool00`0003?o03?o000;<ol000<0003oooooool0>_ooo`03o`2Ioooooooo
04?oool008ooool2000033?o00030000oooooooo03[oool00ol0VOooooooo`13oooo002?oooo00<0
000co`0co`002c?o00030000oooooooo03[oool00ol0VOooooooo`13oooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo03_oool00ol0VOooooooo`13oooo002?oooo00<0000co`0co`002S?o
00030000oooooooo03_oool00ol0VOooooooo`13oooo002?oooo00<0000co`0co`002S?o00030000
oooooooo03_oool00ol0VOooooooo`13oooo002?oooo00<0000co`0co`002S?o00030000oooooooo
03_oool00ol0VOooooooo`13oooo002?oooo0P0000/co`000`000?ooooooo`0koooo00?o09Wooooo
ool0@oooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0koooo00?o09Woooooool0@ooo
o`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0koooo00?o09Woooooool0@oooo`00Sooo
o`030000<ol0<ol000Tco`000`000?ooooooo`0loooo00?o09Woooooool0@oooo`00Soooo`030000
<ol0<ol000Tco`000`000?ooooooo`0loooo00?o09Woooooool0@oooo`00Soooo`030000<ol0<ol0
00Tco`000`000?ooooooo`0loooo00?o09Woooooool0@oooo`00Soooo`80000:<ol000<0003ooooo
ool0??ooo`03o`2Ioooooooo04?oool008ooool00`0003?o03?o0009<ol000<0003oooooool0??oo
o`03o`2Ioooooooo04?oool008ooool00`0003?o03?o0009<ol000<0003oooooool0??ooo`03o`2I
oooooooo04?oool008ooool00`0003?o03?o0008<ol000<0003oooooool0?Oooo`03o`2Ioooooooo
04?oool008Soool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`0moooo00?o09Wooooo
ool0@oooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0m
oooo00?o09Woooooool0@oooo`00ROooo`030000oooooooo00?oool3000023?o00030000oooooooo
03goool00ol0VOooooooo`13oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`0moooo00?o09Woooooool0@oooo`00Qoooo`040000oooooooo00001?ooo`030000
<ol0<ol000Pco`000`000?ooooooo`0moooo00?o09Woooooool0@oooo`00R?ooo`800005oooo00<0
000co`0co`001c?o00030000oooooooo03koool00ol0VOooooooo`13oooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo03koool00ol0VOooooooo`13oooo002?oooo00<0000co`0co`001c?o
00030000oooooooo03koool00ol0VOooooooo`13oooo002?oooo00<0000co`0co`001c?o00030000
oooooooo03koool00ol0VOooooooo`13oooo002?oooo0P0000Pco`000`000?ooooooo`0noooo00?o
09Woooooool0@oooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0noooo00?o09Wooooo
ool0@oooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0noooo00?o09Woooooool0@ooo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0noooo00?o09Woooooool0@oooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`0ooooo00?o09Woooooool0@oooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`0ooooo00?o09Woooooool0@oooo`00Soooo`800007<ol000<0
003oooooool0?oooo`03o`2Ioooooooo04?oool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool0?oooo`03o`2Ioooooooo04?oool008ooool00`0003?o03?o0006<ol000<0003oooooool0?ooo
o`03o`2Ioooooooo04?oool008ooool00`0003?o03?o0006<ol000<0003oooooool0?oooo`03o`2I
oooooooo04?oool008ooool00`0003?o03?o0006<ol000<0003oooooool0?oooo`03o`2Ioooooooo
04?oool008ooool00`0003?o03?o0006<ol000<0003oooooool0?oooo`03o`2Ioooooooo04?oool0
08ooool200001S?o00030000oooooooo043oool00ol0VOooooooo`13oooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo043oool00ol0VOooooooo`13oooo002?oooo00<0000co`0co`001C?o
00030000oooooooo043oool00ol0VOooooooo`13oooo002?oooo00<0000co`0co`001C?o00030000
oooooooo043oool00ol0VOooooooo`13oooo002?oooo00<0000co`0co`001C?o00030000oooooooo
043oool00ol0VOooooooo`13oooo002?oooo00<0000co`0co`001C?o00030000oooooooo043oool0
0ol0VOooooooo`13oooo002?oooo0P0000Hco`000`000?ooooooo`10oooo00?o09Woooooool0@ooo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`10oooo00?o09Woooooool0@oooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`10oooo00?o09Woooooool0@oooo`00Soooo`030000
<ol0<ol000@co`000`000?ooooooo`11oooo00?o09Woooooool0@oooo`00Soooo`030000<ol0<ol0
00@co`000`000?ooooooo`11oooo00?o09Woooooool0@oooo`00ROooo`<00003oooo00<0000co`0c
o`0013?o00030000oooooooo047oool00ol0VOooooooo`13oooo002:oooo00<0003oooooool00_oo
o`030000<ol0<ol000@co`000`000?ooooooo`11oooo00?o09Woooooool0@oooo`00Qoooo`D00003
oooo0`0000@co`000`000?ooooooo`11oooo00?o09Woooooool0@oooo`00Qoooo`040000oooooooo
00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7
<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?ooooooo`0Coooo1c?o
00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo00Woool7
<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`06oooo100000<co`02000000<co`3oooooool0100000Coool300000_ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Goool00`000?ooooooo`07<ol00_ooo`030000oooooooo00Koool01@000?ooooooooooo`00001j
oooo001goooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?oooc?o0006<ol00ooo
o`030000oooooooo00;oool500000oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00003_ooo`030000<ol0<ol000Dco`04oooo00D0003oooooooooool000000_ooo`050000oooooooo
oooo000007[oool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00006<ol00_oo
o`040000oooooooo00000oooo`030000oooo000000?oool00`000?ooooooo`1hoooo001ioooo00<0
003oooooool04Oooo`800007<ol00oooo`800005oooo0P0000;oool00`000?ooooooo`1ioooo002?
oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.7878 .12361 L
.79321 .12361 L
.79616 .12361 L
.79761 .12361 L
.79892 .12361 L
s
.79892 .12361 m
.79942 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.16408 .12361 L
.18221 .12361 L
.18703 .12361 L
.19227 .12361 L
.19467 .12361 L
.19721 .12361 L
.19826 .12361 L
.19939 .12361 L
.20062 .12296 L
.20178 .12178 L
.22272 .10316 L
.24385 .08902 L
.26394 .0791 L
.27353 .07538 L
.28375 .07204 L
.30213 .06745 L
.31242 .06558 L
.32355 .06404 L
.32865 .06349 L
.33405 .063 L
.33911 .06262 L
.34372 .06235 L
.34858 .06212 L
.35319 .06196 L
.35572 .0619 L
.35806 .06186 L
.35928 .06184 L
.36063 .06182 L
.3613 .06182 L
.36203 .06181 L
.36335 .06181 L
.36451 .0618 L
.36558 .0618 L
.36676 .06181 L
.36801 .06181 L
.36934 .06182 L
.37058 .06184 L
.37292 .06187 L
.37511 .06191 L
.37713 .06195 L
.38169 .06209 L
.38636 .06226 L
.39138 .06248 L
.40045 .06298 L
.42109 .06452 L
.46237 .06876 L
Mistroke
.483 .07124 L
.49304 .07249 L
.50213 .07363 L
.50672 .07408 L
.50913 .07427 L
.51167 .07444 L
.51391 .07455 L
.51635 .07465 L
.51743 .07469 L
.51858 .07472 L
.51958 .07474 L
.52065 .07476 L
.52197 .07478 L
.52319 .07479 L
.52451 .0748 L
.52526 .0748 L
.52596 .07479 L
.52722 .07479 L
.52837 .07477 L
.52964 .07475 L
.53097 .07473 L
.5333 .07467 L
.53547 .0746 L
.54037 .07438 L
.54544 .07409 L
.55092 .07371 L
.56087 .07283 L
.57947 .07071 L
.62044 .06441 L
.6599 .05702 L
.69784 .04926 L
.73823 .04085 L
.7771 .03331 L
.78726 .03153 L
.79262 .03064 L
.79556 .03016 L
.797 .02993 L
.79832 .02973 L
.79948 .02955 L
.80071 .12361 L
.80194 .12361 L
.80328 .12361 L
.80876 .12361 L
.81843 .12361 L
.85896 .12361 L
.89798 .12361 L
.93944 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`15oooo1@1VodCoool0
08ooool00`000?ooooooo`0ooooo1P1Vo`Coool00`1Vooooooooo`12oooo002?oooo00<0003ooooo
ool0>?ooo`L0I_l:oooo00<0I_ooooooool0@_ooo`00Soooo`030000oooooooo03Goool306Ko4Ooo
o`0306Kooooooooo04;oool008ooool00`000?ooooooo`0aoooo101VoaCoool00`1Vooooooooo`12
oooo002?oooo0P0002koool406Ko6?ooo`0306Kooooooooo04;oool008ooool00`000?ooooooo`0Y
oooo101Voacoool00`1Vooooooooo`12oooo002?oooo00<0003oooooool08_ooo`L0I_lPoooo00<0
I_ooooooool0@_ooo`00HOoooal0I_l?oooo00<0003oooooool06_ooo`P0I_lWoooo00<0I_oooooo
ool0@_ooo`00Foooo`H0I_lOoooo201Vo`Ooool00`000?ooooooo`0Doooo1P1Vobooool00`1Voooo
ooooo`12oooo001Hoooo0`1Vobgoool706Ko00<0003oooooool03oooo`D0I_leoooo00<0I_oooooo
ool0@_ooo`00EOooo`<0I_lgoooo0P000100I_ljoooo00<0I_ooooooool0@_ooo`005oooo`@0000h
oooo00<0I_l0000000000`0003Koool00`000?ooooooo`0goooo1@0000goool00`1Vooooooooo`0X
oooo100001Koool001Ooool00`000?ooooooo`0goooo0P1Vo`?oool00`000?ooooooo`0foooo00<0
003oooooool0>Oooo`030000oooooooo00goool00`1Vooooooooo`0Xoooo00<0003oooooool05ooo
o`006?ooo`030000oooooooo03Coool206Ko1Oooo`030000oooooooo03Koool00`000?ooooooo`0i
oooo00<0003oooooool03Oooo`0306Kooooooooo02Woool00`000?ooooooo`0Foooo000Aoooo1000
00Coool00`000?ooooooo`0boooo100000Coool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo00goool00`1Vooooooooo`0Zoooo00<0003oooooool05Oooo`005oooo`040000
oooooooo0000<Oooo`80I_l8oooo00<0003oooooool0=_ooo`030000oooooooo03Woool00`000?oo
ooooo`0=oooo00<0I_ooooooool0:?ooo`040000oooooooo00005_ooo`006?ooo`80000`oooo0P1V
o`Woool20000>?ooo`80000ioooo0P0000ooool00`1Vooooooooo`0Yoooo0P0001Ooool004Woool0
0`1Vooooooooo`13oooo00<0003oooooool0BOooo`0306Kooooooooo04;oool004Soool00`1Voooo
ooooo`14oooo00<0003oooooool0BOooo`0306Kooooooooo04;oool004Ooool00`1Vooooooooo`15
oooo00<0003oooooool0BOooo`0306Kooooooooo04;oool004Goool206KoB?ooo`030000oooooooo
04Woool00`1Vooooooooo`12oooo0014oooo00<0I_ooooooool0B?ooo`030000oooooooo04Woool0
0`1Vooooooooo`12oooo000@ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006<ol01`000003o`2I
0000000001P00006oooo00<0003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol003Tco`0900001oooo`03o`2Ioooooooo
02[oool00`000?ooooooo`0Eoooo002?oooo00<0000co`0co`00<c?o00H0000@oooo00?o09Wooooo
ool0@_ooo`00Soooo`030000<ol0<ol0034co`0200005_ooo`03o`2Ioooooooo04;oool008ooool0
0`0003?o03?o000_<ol00P0001Soool00ol0VOooooooo`12oooo002?oooo00<0000co`0co`00;3?o
00<0000Joooo00?o09Woooooool0@_ooo`00Soooo`80000Z<ol00`0001goool00ol0VOooooooo`12
oooo002?oooo00<0000co`0co`009c?o0080000Poooo00?o09Woooooool0@_ooo`00Soooo`030000
<ol0<ol002Hco`000`000?ooooooo`0Poooo00?o09Woooooool0@_ooo`00Soooo`030000<ol0<ol0
02Dco`000`000?ooooooo`0Qoooo00?o09Woooooool0@_ooo`00Soooo`030000<ol0<ol002@co`00
0`000?ooooooo`0Roooo00?o09Woooooool0@_ooo`00Soooo`030000<ol0<ol0028co`0200009Ooo
o`03o`2Ioooooooo04;oool008ooool200008S?o00030000oooooooo02Goool00ol0VOooooooo`12
oooo002?oooo00<0000co`0co`0083?o00030000oooooooo02Koool00ol0VOooooooo`12oooo002?
oooo00<0000co`0co`007c?o00030000oooooooo02Ooool00ol0VOooooooo`12oooo002?oooo00<0
000co`0co`007c?o00030000oooooooo02Ooool00ol0VOooooooo`12oooo002?oooo00<0000co`0c
o`007S?o00030000oooooooo02Soool00ol0VOooooooo`12oooo002?oooo00<0000co`0co`007C?o
00030000oooooooo02Woool00ol0VOooooooo`12oooo002?oooo0P0001dco`000`000?ooooooo`0Z
oooo00?o09Woooooool0@_ooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0[oooo00?o
09Woooooool0@_ooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0[oooo00?o09Wooooo
ool0@_ooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0/oooo00?o09Woooooool0@_oo
o`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0/oooo00?o09Woooooool0@_ooo`00Sooo
o`030000<ol0<ol001Tco`000`000?ooooooo`0]oooo00?o09Woooooool0@_ooo`00Soooo`80000J
<ol000<0003oooooool0;Oooo`03o`2Ioooooooo04;oool008ooool00`0003?o03?o000H<ol000<0
003oooooool0;_ooo`03o`2Ioooooooo04;oool008ooool00`0003?o03?o000H<ol000<0003ooooo
ool0;_ooo`03o`2Ioooooooo04;oool008ooool00`0003?o03?o000G<ol000<0003oooooool0;ooo
o`03o`2Ioooooooo04;oool008ooool00`0003?o03?o000G<ol000<0003oooooool0;oooo`03o`2I
oooooooo04;oool008Ooool500000oooo`030000<ol0<ol001Hco`000`000?ooooooo`0`oooo00?o
09Woooooool0@_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000F<ol000<0003ooooo
ool0<?ooo`03o`2Ioooooooo04;oool008Woool00`000?ooooooo`03oooo0`0001Dco`000`000?oo
ooooo`0aoooo00?o09Woooooool0@_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E
<ol000<0003oooooool0<Oooo`03o`2Ioooooooo04;oool008Woool00`000?ooooooo`03oooo00<0
000co`0co`005C?o00030000oooooooo037oool00ol0VOooooooo`12oooo0028oooo0P0000Goool0
0`0003?o03?o000D<ol000<0003oooooool0<_ooo`03o`2Ioooooooo04;oool008ooool00`0003?o
03?o000D<ol000<0003oooooool0<_ooo`03o`2Ioooooooo04;oool008ooool00`0003?o03?o000C
<ol000<0003oooooool0<oooo`03o`2Ioooooooo04;oool008ooool2000053?o00030000oooooooo
03?oool00ol0VOooooooo`12oooo002?oooo00<0000co`0co`004c?o00030000oooooooo03?oool0
0ol0VOooooooo`12oooo002?oooo00<0000co`0co`004S?o00030000oooooooo03Coool00ol0VOoo
ooooo`12oooo002?oooo00<0000co`0co`004S?o00030000oooooooo03Coool00ol0VOooooooo`12
oooo002?oooo00<0000co`0co`004S?o00030000oooooooo03Coool00ol0VOooooooo`12oooo002?
oooo00<0000co`0co`004C?o00030000oooooooo03Goool00ol0VOooooooo`12oooo002?oooo0P00
018co`000`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00Soooo`030000<ol0<ol0014co`00
0`000?ooooooo`0eoooo00?o09Woooooool0@_ooo`00Soooo`030000<ol0<ol0014co`000`000?oo
ooooo`0eoooo00?o09Woooooool0@_ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0f
oooo00?o09Woooooool0@_ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0foooo00?o
09Woooooool0@_ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0foooo00?o09Wooooo
ool0@_ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0foooo00?o09Woooooool0@_oo
o`00Soooo`80000@<ol000<0003oooooool0=oooo`03o`2Ioooooooo04;oool008ooool00`0003?o
03?o000?<ol000<0003oooooool0=oooo`03o`2Ioooooooo04;oool008ooool00`0003?o03?o000?
<ol000<0003oooooool0=oooo`03o`2Ioooooooo04;oool008ooool00`0003?o03?o000?<ol000<0
003oooooool0=oooo`03o`2Ioooooooo04;oool008ooool00`0003?o03?o000?<ol000<0003ooooo
ool0=oooo`03o`2Ioooooooo04;oool008ooool00`0003?o03?o000><ol000<0003oooooool0>?oo
o`03o`2Ioooooooo04;oool008ooool200003c?o00030000oooooooo03Soool00ol0VOooooooo`12
oooo002?oooo00<0000co`0co`003S?o00030000oooooooo03Soool00ol0VOooooooo`12oooo002?
oooo00<0000co`0co`003S?o00030000oooooooo03Soool00ol0VOooooooo`12oooo002?oooo00<0
000co`0co`003C?o00030000oooooooo03Woool00ol0VOooooooo`12oooo0027oooo100000Coool0
0`0003?o03?o000=<ol000<0003oooooool0>Oooo`03o`2Ioooooooo04;oool008Ooool00`000?oo
ooooo`05oooo00<0000co`0co`003C?o00030000oooooooo03Woool00ol0VOooooooo`12oooo0028
oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0>Oooo`03o`2Ioooooooo04;oool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo03Woool00ol0VOoo
ooooo`12oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0033?o00030000oooooooo
03[oool00ol0VOooooooo`12oooo0028oooo0P0000Goool00`0003?o03?o000<<ol000<0003ooooo
ool0>_ooo`03o`2Ioooooooo04;oool008ooool00`0003?o03?o000<<ol000<0003oooooool0>_oo
o`03o`2Ioooooooo04;oool008ooool00`0003?o03?o000<<ol000<0003oooooool0>_ooo`03o`2I
oooooooo04;oool008ooool200003C?o00030000oooooooo03[oool00ol0VOooooooo`12oooo002?
oooo00<0000co`0co`0033?o00030000oooooooo03[oool00ol0VOooooooo`12oooo002?oooo00<0
000co`0co`002c?o00030000oooooooo03_oool00ol0VOooooooo`12oooo002?oooo00<0000co`0c
o`002c?o00030000oooooooo03_oool00ol0VOooooooo`12oooo002?oooo00<0000co`0co`002c?o
00030000oooooooo03_oool00ol0VOooooooo`12oooo002?oooo00<0000co`0co`002c?o00030000
oooooooo03_oool00ol0VOooooooo`12oooo002?oooo00<0000co`0co`002c?o00030000oooooooo
03_oool00ol0VOooooooo`12oooo002?oooo0P0000`co`000`000?ooooooo`0koooo00?o09Wooooo
ool0@_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0koooo00?o09Woooooool0@_oo
o`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`0loooo00?o09Woooooool0@_ooo`00Sooo
o`030000<ol0<ol000Xco`000`000?ooooooo`0loooo00?o09Woooooool0@_ooo`00Soooo`030000
<ol0<ol000Xco`000`000?ooooooo`0loooo00?o09Woooooool0@_ooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0loooo00?o09Woooooool0@_ooo`00Soooo`80000;<ol000<0003ooooo
ool0??ooo`03o`2Ioooooooo04;oool008ooool00`0003?o03?o000:<ol000<0003oooooool0??oo
o`03o`2Ioooooooo04;oool008ooool00`0003?o03?o000:<ol000<0003oooooool0??ooo`03o`2I
oooooooo04;oool008ooool00`0003?o03?o0009<ol000<0003oooooool0?Oooo`03o`2Ioooooooo
04;oool008ooool00`0003?o03?o0009<ol000<0003oooooool0?Oooo`03o`2Ioooooooo04;oool0
08ooool00`0003?o03?o0009<ol000<0003oooooool0?Oooo`03o`2Ioooooooo04;oool008ooool2
00002S?o00030000oooooooo03goool00ol0VOooooooo`12oooo002?oooo00<0000co`0co`002C?o
00030000oooooooo03goool00ol0VOooooooo`12oooo002?oooo00<0000co`0co`002C?o00030000
oooooooo03goool00ol0VOooooooo`12oooo002?oooo00<0000co`0co`0023?o00030000oooooooo
03koool00ol0VOooooooo`12oooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0003ooooo
ool0?_ooo`03o`2Ioooooooo04;oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008
<ol000<0003oooooool0?_ooo`03o`2Ioooooooo04;oool008Woool00`000?ooooooo`03oooo0`00
00Pco`000`000?ooooooo`0noooo00?o09Woooooool0@_ooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o0008<ol000<0003oooooool0?_ooo`03o`2Ioooooooo04;oool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0?_ooo`03o`2Ioooooooo04;oool0
08Soool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`0ooooo00?o09Woooooool0@_oo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`0ooooo00?o09Woooooool0@_ooo`00Sooo
o`030000<ol0<ol000Lco`000`000?ooooooo`0ooooo00?o09Woooooool0@_ooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`0ooooo00?o09Woooooool0@_ooo`00Soooo`800008<ol000<0
003oooooool0?oooo`03o`2Ioooooooo04;oool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool0?oooo`03o`2Ioooooooo04;oool008ooool00`0003?o03?o0007<ol000<0003oooooool0?ooo
o`03o`2Ioooooooo04;oool008ooool00`0003?o03?o0007<ol000<0003oooooool0?oooo`03o`2I
oooooooo04;oool008ooool00`0003?o03?o0006<ol000<0003oooooool0@?ooo`03o`2Ioooooooo
04;oool008ooool00`0003?o03?o0006<ol000<0003oooooool0@?ooo`03o`2Ioooooooo04;oool0
08ooool200001c?o00030000oooooooo043oool00ol0VOooooooo`12oooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo043oool00ol0VOooooooo`12oooo002?oooo00<0000co`0co`001S?o
00030000oooooooo043oool00ol0VOooooooo`12oooo002?oooo00<0000co`0co`001S?o00030000
oooooooo043oool00ol0VOooooooo`12oooo002?oooo00<0000co`0co`001S?o00030000oooooooo
043oool00ol0VOooooooo`12oooo002?oooo00<0000co`0co`001S?o00030000oooooooo043oool0
0ol0VOooooooo`12oooo002?oooo0P0000Hco`000`000?ooooooo`11oooo00?o09Woooooool0@_oo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`11oooo00?o09Woooooool0@_ooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`11oooo00?o09Woooooool0@_ooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`11oooo00?o09Woooooool0@_ooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`11oooo00?o09Woooooool0@_ooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`11oooo00?o09Woooooool0@_ooo`00Soooo`800006<ol000<0003oooooool0@Ooo
o`03o`2Ioooooooo04;oool008ooool00`0003?o03?o0005<ol000<0003oooooool0@Oooo`03o`2I
oooooooo04;oool008ooool00`0003?o03?o0005<ol000<0003oooooool0@Oooo`03o`2Ioooooooo
04;oool008ooool00`0003?o03?o0004<ol000<0003oooooool0@_ooo`03o`2Ioooooooo04;oool0
08ooool00`0003?o03?o0004<ol000<0003oooooool0@_ooo`03o`2Ioooooooo04;oool008Woool3
00000oooo`030000<ol0<ol000@co`000`000?ooooooo`12oooo00?o09Woooooool0@_ooo`00R_oo
o`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0@_ooo`03o`2Ioooooooo
04;oool008Ooool500000oooo`<00004<ol000<0003oooooool0@_ooo`03o`2Ioooooooo04;oool0
08Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_oo
o`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0
003oooooool04oooo`Lco`0>oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool0
0`000?ooooooo`09oooo1c?o00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01_ooo`@00003<ol00P000003<ol0oooooooo00@00002oooo0`00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo00<0003oooooool01c?o00;oool00`000?ooooooo`03oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0>oooo00<0003ooolco`001S?o00?oool00`000?ooooooo`02oooo00@0003oooooool00004
oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0000co`0co`001C?o
00Coool010000?ooooooooooo`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Hco`02oooo00@0003oooooool00003oooo00<0003ooooo
ool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`03oooo0P00
00Coool300000_ooo`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.7878 .12361 L
.79321 .12361 L
.79892 .12361 L
.80134 .12361 L
.80267 .12361 L
.80393 .12361 L
.80464 .12361 L
s
.80464 .12361 m
.80495 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.16408 .12361 L
.18221 .12361 L
.18703 .12361 L
.18957 .12361 L
.19227 .12361 L
.1934 .12361 L
.19462 .12361 L
.19532 .12352 L
.19596 .12286 L
.19721 .12158 L
.20178 .11709 L
.22272 .0996 L
.2417 .08755 L
.26243 .07777 L
.2821 .07114 L
.2931 .06837 L
.30307 .06636 L
.31309 .06477 L
.32232 .06365 L
.33244 .06275 L
.33754 .06242 L
.34022 .06228 L
.34314 .06215 L
.34586 .06204 L
.34838 .06197 L
.35078 .06191 L
.35202 .06188 L
.35334 .06186 L
.35453 .06184 L
.35562 .06183 L
.35667 .06182 L
.35777 .06181 L
.35897 .06181 L
.3601 .0618 L
.36133 .0618 L
.36265 .06181 L
.36333 .06181 L
.36405 .06182 L
.36535 .06183 L
.36675 .06185 L
.36828 .06187 L
.37103 .06192 L
.3736 .06199 L
.3784 .06214 L
.38356 .06234 L
.39369 .06286 L
Mistroke
.40474 .0636 L
.42484 .06529 L
.46554 .06969 L
.48437 .072 L
.49427 .07325 L
.49968 .07394 L
.50472 .07451 L
.51005 .07495 L
.51287 .07512 L
.5159 .07526 L
.51722 .07531 L
.51866 .07535 L
.51993 .07538 L
.52127 .07541 L
.52248 .07542 L
.52317 .07543 L
.52382 .07543 L
.52495 .07544 L
.52617 .07544 L
.52744 .07543 L
.52862 .07542 L
.52992 .0754 L
.53131 .07537 L
.53414 .0753 L
.53671 .07521 L
.54167 .07499 L
.54635 .07471 L
.5561 .07398 L
.56641 .07299 L
.58487 .07076 L
.62281 .06485 L
.6632 .05728 L
.70208 .04933 L
.74341 .04074 L
.76408 .03661 L
.78322 .03303 L
.79279 .03137 L
.79748 .03059 L
.80178 .02991 L
.80292 .02973 L
.80398 .02956 L
.80508 .12361 L
.80629 .12361 L
.81116 .12361 L
.82152 .12361 L
.86053 .12361 L
.902 .12361 L
.94195 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`13oooo201Vod?oool0
08ooool00`000?ooooooo`0noooo1@1Vo`Ooool00`1Vooooooooo`11oooo002?oooo00<0003ooooo
ool0>_ooo`@0I_l<oooo00<0I_ooooooool0@Oooo`00Soooo`030000oooooooo03Koool406Ko4?oo
o`0306Kooooooooo047oool008ooool00`000?ooooooo`0boooo101VoaCoool00`1Vooooooooo`11
oooo002?oooo0P0002ooool406Ko6?ooo`0306Kooooooooo047oool008ooool00`000?ooooooo`0Y
oooo1@1Voacoool00`1Vooooooooo`11oooo002?oooo00<0003oooooool09?ooo`D0I_lQoooo00<0
I_ooooooool0@Oooo`00Gooooa/0I_lEoooo00<0003oooooool07oooo`D0I_lVoooo00<0I_oooooo
ool0@Oooo`00F_ooo`D0I_lKoooo1`1Vo`koool00`000?ooooooo`0Hoooo1`1Vob_oool00`1Voooo
ooooo`11oooo001Goooo0`1VobOoool<06Ko0_ooo`030000oooooooo017oool706Ko<_ooo`0306Ko
oooooooo047oool005Goool206Ko=_ooo`80I_l200004P1VocWoool00`1Vooooooooo`11oooo000G
oooo100003Ooool206Ko1@0003Koool00`000?ooooooo`0goooo1@0000koool00`1Vooooooooo`0W
oooo100001Koool001Ooool00`000?ooooooo`0eoooo0`1Vo`Coool00`000?ooooooo`0foooo00<0
003oooooool0>Oooo`030000oooooooo00koool00`1Vooooooooo`0Woooo00<0003oooooool05ooo
o`006?ooo`030000oooooooo03;oool206Ko1oooo`030000oooooooo03Koool00`000?ooooooo`0i
oooo00<0003oooooool03_ooo`0306Kooooooooo02Soool00`000?ooooooo`0Foooo000Aoooo1000
00Coool00`000?ooooooo`0`oooo00<0I_ooool000000`0000Coool00`000?ooooooo`0foooo00<0
003oooooool0>Oooo`030000oooooooo00koool00`1Vooooooooo`0Yoooo00<0003oooooool05Ooo
o`005oooo`040000oooooooo0000;oooo`80I_l:oooo00<0003oooooool0=_ooo`030000oooooooo
03Woool00`000?ooooooo`0>oooo00<0I_ooooooool09oooo`040000oooooooo00005_ooo`006?oo
o`80000_oooo00<0I_ooooooool02Oooo`80000hoooo0P0003Woool200004?ooo`0306Kooooooooo
02Soool200005oooo`00B?ooo`0306Kooooooooo04Coool00`000?ooooooo`1:oooo00<0I_oooooo
ool0@Oooo`00Aoooo`0306Kooooooooo04Goool00`000?ooooooo`1:oooo00<0I_ooooooool0@Ooo
o`00AOooo`80I_m8oooo00<0003oooooool0B_ooo`0306Kooooooooo047oool004Coool00`1Voooo
ooooo`18oooo00<0003oooooool0B_ooo`0306Kooooooooo047oool004?oool00`1Vooooooooo`19
oooo00<0003oooooool0B_ooo`0306Kooooooooo047oool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Hco`08000000?o09T0000000005`0000Koool00`000?ooooooo`09oooo00<0003ooooo
ool05Oooo`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`00>C?o
00T00008oooo00?o09Woooooool0:Oooo`030000oooooooo01Goool008ooool00`0003?o03?o000c
<ol01P00017oool00ol0VOooooooo`11oooo002?oooo00<0000co`0co`00<C?o0080000Goooo00?o
09Woooooool0@Oooo`00Soooo`030000<ol0<ol002lco`0200006Oooo`03o`2Ioooooooo047oool0
08ooool00`0003?o03?o000/<ol00`0001_oool00ol0VOooooooo`11oooo002?oooo0P0002Xco`03
00007_ooo`03o`2Ioooooooo047oool008ooool00`0003?o03?o000W<ol00P00027oool00ol0VOoo
ooooo`11oooo002?oooo00<0000co`0co`009S?o00030000oooooooo027oool00ol0VOooooooo`11
oooo002?oooo00<0000co`0co`009C?o00030000oooooooo02;oool00ol0VOooooooo`11oooo002?
oooo00<0000co`0co`0093?o00030000oooooooo02?oool00ol0VOooooooo`11oooo002?oooo00<0
000co`0co`008S?o0080000Voooo00?o09Woooooool0@Oooo`00Soooo`80000R<ol000<0003ooooo
ool09_ooo`03o`2Ioooooooo047oool008ooool00`0003?o03?o000P<ol000<0003oooooool09ooo
o`03o`2Ioooooooo047oool008ooool00`0003?o03?o000O<ol000<0003oooooool0:?ooo`03o`2I
oooooooo047oool008ooool00`0003?o03?o000O<ol000<0003oooooool0:?ooo`03o`2Ioooooooo
047oool008ooool00`0003?o03?o000N<ol000<0003oooooool0:Oooo`03o`2Ioooooooo047oool0
08ooool00`0003?o03?o000M<ol000<0003oooooool0:_ooo`03o`2Ioooooooo047oool008ooool2
00007C?o00030000oooooooo02_oool00ol0VOooooooo`11oooo002?oooo00<0000co`0co`006c?o
00030000oooooooo02coool00ol0VOooooooo`11oooo002?oooo00<0000co`0co`006c?o00030000
oooooooo02coool00ol0VOooooooo`11oooo002?oooo00<0000co`0co`006S?o00030000oooooooo
02goool00ol0VOooooooo`11oooo002?oooo00<0000co`0co`006S?o00030000oooooooo02goool0
0ol0VOooooooo`11oooo002?oooo00<0000co`0co`006C?o00030000oooooooo02koool00ol0VOoo
ooooo`11oooo002?oooo0P0001Xco`000`000?ooooooo`0^oooo00?o09Woooooool0@Oooo`00Sooo
o`030000<ol0<ol001Pco`000`000?ooooooo`0_oooo00?o09Woooooool0@Oooo`00Soooo`030000
<ol0<ol001Pco`000`000?ooooooo`0_oooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol0
01Lco`000`000?ooooooo`0`oooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol001Lco`00
0`000?ooooooo`0`oooo00?o09Woooooool0@Oooo`00Qoooo`D00003oooo00<0000co`0co`005S?o
00030000oooooooo037oool00ol0VOooooooo`11oooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol001Hco`000`000?ooooooo`0aoooo00?o09Woooooool0@Oooo`00ROooo`030000oooooooo
00?oool300005C?o00030000oooooooo03;oool00ol0VOooooooo`11oooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`0boooo00?o09Woooooool0@Oooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool0<_ooo`03o`2Ioooooooo
047oool008Soool200001Oooo`030000<ol0<ol001@co`000`000?ooooooo`0coooo00?o09Wooooo
ool0@Oooo`00Soooo`030000<ol0<ol001@co`000`000?ooooooo`0coooo00?o09Woooooool0@Ooo
o`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`0doooo00?o09Woooooool0@Oooo`00Sooo
o`80000D<ol000<0003oooooool0=?ooo`03o`2Ioooooooo047oool008ooool00`0003?o03?o000C
<ol000<0003oooooool0=?ooo`03o`2Ioooooooo047oool008ooool00`0003?o03?o000B<ol000<0
003oooooool0=Oooo`03o`2Ioooooooo047oool008ooool00`0003?o03?o000B<ol000<0003ooooo
ool0=Oooo`03o`2Ioooooooo047oool008ooool00`0003?o03?o000B<ol000<0003oooooool0=Ooo
o`03o`2Ioooooooo047oool008ooool00`0003?o03?o000A<ol000<0003oooooool0=_ooo`03o`2I
oooooooo047oool008ooool200004S?o00030000oooooooo03Koool00ol0VOooooooo`11oooo002?
oooo00<0000co`0co`004C?o00030000oooooooo03Koool00ol0VOooooooo`11oooo002?oooo00<0
000co`0co`004C?o00030000oooooooo03Koool00ol0VOooooooo`11oooo002?oooo00<0000co`0c
o`0043?o00030000oooooooo03Ooool00ol0VOooooooo`11oooo002?oooo00<0000co`0co`0043?o
00030000oooooooo03Ooool00ol0VOooooooo`11oooo002?oooo00<0000co`0co`0043?o00030000
oooooooo03Ooool00ol0VOooooooo`11oooo002?oooo00<0000co`0co`0043?o00030000oooooooo
03Ooool00ol0VOooooooo`11oooo002?oooo0P00010co`000`000?ooooooo`0hoooo00?o09Wooooo
ool0@Oooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0hoooo00?o09Woooooool0@Ooo
o`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`0hoooo00?o09Woooooool0@Oooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`0hoooo00?o09Woooooool0@Oooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`0hoooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol0
00hco`000`000?ooooooo`0ioooo00?o09Woooooool0@Oooo`00Soooo`80000?<ol000<0003ooooo
ool0>Oooo`03o`2Ioooooooo047oool008ooool00`0003?o03?o000><ol000<0003oooooool0>Ooo
o`03o`2Ioooooooo047oool008ooool00`0003?o03?o000><ol000<0003oooooool0>Oooo`03o`2I
oooooooo047oool008ooool00`0003?o03?o000=<ol000<0003oooooool0>_ooo`03o`2Ioooooooo
047oool008Ooool400001?ooo`030000<ol0<ol000dco`000`000?ooooooo`0joooo00?o09Wooooo
ool0@Oooo`00Qoooo`030000oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool0>_oo
o`03o`2Ioooooooo047oool008Soool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`0j
oooo00?o09Woooooool0@Oooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0
003oooooool0>_ooo`03o`2Ioooooooo047oool008Ooool010000?ooooooo`0000Coool00`0003?o
03?o000<<ol000<0003oooooool0>oooo`03o`2Ioooooooo047oool008Soool200001Oooo`030000
<ol0<ol000`co`000`000?ooooooo`0koooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol0
00`co`000`000?ooooooo`0koooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol000`co`00
0`000?ooooooo`0koooo00?o09Woooooool0@Oooo`00Soooo`80000=<ol000<0003oooooool0>ooo
o`03o`2Ioooooooo047oool008ooool00`0003?o03?o000<<ol000<0003oooooool0>oooo`03o`2I
oooooooo047oool008ooool00`0003?o03?o000;<ol000<0003oooooool0??ooo`03o`2Ioooooooo
047oool008ooool00`0003?o03?o000;<ol000<0003oooooool0??ooo`03o`2Ioooooooo047oool0
08ooool00`0003?o03?o000;<ol000<0003oooooool0??ooo`03o`2Ioooooooo047oool008ooool0
0`0003?o03?o000;<ol000<0003oooooool0??ooo`03o`2Ioooooooo047oool008ooool00`0003?o
03?o000;<ol000<0003oooooool0??ooo`03o`2Ioooooooo047oool008ooool2000033?o00030000
oooooooo03coool00ol0VOooooooo`11oooo002?oooo00<0000co`0co`002c?o00030000oooooooo
03coool00ol0VOooooooo`11oooo002?oooo00<0000co`0co`002S?o00030000oooooooo03goool0
0ol0VOooooooo`11oooo002?oooo00<0000co`0co`002S?o00030000oooooooo03goool00ol0VOoo
ooooo`11oooo002?oooo00<0000co`0co`002S?o00030000oooooooo03goool00ol0VOooooooo`11
oooo002?oooo00<0000co`0co`002S?o00030000oooooooo03goool00ol0VOooooooo`11oooo002?
oooo0P0000/co`000`000?ooooooo`0moooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`0moooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol000Xco`00
0`000?ooooooo`0moooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol000Tco`000`000?oo
ooooo`0noooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0n
oooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`0noooo00?o
09Woooooool0@Oooo`00Soooo`80000:<ol000<0003oooooool0?_ooo`03o`2Ioooooooo047oool0
08ooool00`0003?o03?o0009<ol000<0003oooooool0?_ooo`03o`2Ioooooooo047oool008ooool0
0`0003?o03?o0009<ol000<0003oooooool0?_ooo`03o`2Ioooooooo047oool008ooool00`0003?o
03?o0008<ol000<0003oooooool0?oooo`03o`2Ioooooooo047oool008Soool200001Oooo`030000
<ol0<ol000Pco`000`000?ooooooo`0ooooo00?o09Woooooool0@Oooo`00Qoooo`040000oooooooo
00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0ooooo00?o09Woooooool0@Oooo`00ROoo
o`030000oooooooo00?oool3000023?o00030000oooooooo03ooool00ol0VOooooooo`11oooo002:
oooo00<0003oooooool00_ooo`030000<ol0<ol000Pco`000`000?ooooooo`0ooooo00?o09Wooooo
ool0@Oooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`0o
oooo00?o09Woooooool0@Oooo`00R?ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo
043oool00ol0VOooooooo`11oooo002?oooo00<0000co`0co`001c?o00030000oooooooo043oool0
0ol0VOooooooo`11oooo002?oooo00<0000co`0co`001c?o00030000oooooooo043oool00ol0VOoo
ooooo`11oooo002?oooo00<0000co`0co`001c?o00030000oooooooo043oool00ol0VOooooooo`11
oooo002?oooo0P0000Pco`000`000?ooooooo`10oooo00?o09Woooooool0@Oooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`10oooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol0
00Lco`000`000?ooooooo`10oooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`10oooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`11oooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`11
oooo00?o09Woooooool0@Oooo`00Soooo`800007<ol000<0003oooooool0@Oooo`03o`2Ioooooooo
047oool008ooool00`0003?o03?o0006<ol000<0003oooooool0@Oooo`03o`2Ioooooooo047oool0
08ooool00`0003?o03?o0006<ol000<0003oooooool0@Oooo`03o`2Ioooooooo047oool008ooool0
0`0003?o03?o0006<ol000<0003oooooool0@Oooo`03o`2Ioooooooo047oool008ooool00`0003?o
03?o0006<ol000<0003oooooool0@Oooo`03o`2Ioooooooo047oool008ooool00`0003?o03?o0006
<ol000<0003oooooool0@Oooo`03o`2Ioooooooo047oool008ooool200001S?o00030000oooooooo
04;oool00ol0VOooooooo`11oooo002?oooo00<0000co`0co`001C?o00030000oooooooo04;oool0
0ol0VOooooooo`11oooo002?oooo00<0000co`0co`001C?o00030000oooooooo04;oool00ol0VOoo
ooooo`11oooo002?oooo00<0000co`0co`001C?o00030000oooooooo04;oool00ol0VOooooooo`11
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo04;oool00ol0VOooooooo`11oooo002?
oooo00<0000co`0co`001C?o00030000oooooooo04;oool00ol0VOooooooo`11oooo002?oooo0P00
00Hco`000`000?ooooooo`12oooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`12oooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`12oooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`13
oooo00?o09Woooooool0@Oooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`13oooo00?o
09Woooooool0@Oooo`00ROooo`<00003oooo00<0000co`0co`0013?o00030000oooooooo04?oool0
0ol0VOooooooo`11oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?oo
ooooo`13oooo00?o09Woooooool0@Oooo`00Qoooo`D00003oooo0`0000@co`000`000?ooooooo`13
oooo00?o09Woooooool0@Oooo`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0
003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?
oooo1c?o08[oool007Woool00`000?ooooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo00Woool7<ol03oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000<co`02000000<c
o`3oooooool0100000?oool200001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`07<ol00_oo
o`030000oooooooo00?oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0
003oooooool00_ooo`030000oooooooo00koool00`000?oooc?o0006<ol00oooo`030000oooooooo
00;oool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
00koool00`0003?o03?o0005<ol01?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00006<ol00_ooo`040000
oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Woool00`000?oo
ooooo`0Aoooo0P0000Lco`03oooo0P0000Coool200000oooo`030000oooooooo07Woool008ooool7
<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.7878 .12361 L
.79892 .12361 L
.80403 .12361 L
.80682 .12361 L
.80819 .12361 L
.80943 .12361 L
s
.80943 .12361 m
.80989 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.16408 .12361 L
.17277 .12361 L
.18221 .12361 L
.18475 .12361 L
.18744 .12361 L
.18855 .12361 L
.18974 .12361 L
.19104 .12302 L
.19227 .12177 L
.20178 .11268 L
.22272 .09626 L
.24385 .08393 L
.26394 .0754 L
.27353 .07225 L
.28375 .06945 L
.29332 .06731 L
.30213 .06571 L
.31242 .06424 L
.31772 .06363 L
.32355 .06308 L
.32828 .06271 L
.33335 .06239 L
.33871 .06213 L
.34372 .06196 L
.34628 .0619 L
.34768 .06187 L
.349 .06185 L
.35021 .06183 L
.35132 .06182 L
.35256 .06181 L
.35321 .06181 L
.35389 .06181 L
.35458 .0618 L
.35521 .0618 L
.35594 .0618 L
.35663 .0618 L
.35785 .06181 L
.35854 .06181 L
.35917 .06182 L
.36051 .06183 L
.36198 .06185 L
.36496 .0619 L
.36757 .06195 L
.36997 .06202 L
.37535 .0622 L
.38508 .06265 L
Mistroke
.39495 .06324 L
.4041 .06391 L
.42484 .06575 L
.46402 .07008 L
.48403 .07256 L
.49455 .0739 L
.5003 .07463 L
.50565 .07522 L
.51047 .0756 L
.51317 .07576 L
.51563 .07588 L
.51832 .07597 L
.51984 .07601 L
.52125 .07604 L
.52247 .07606 L
.52317 .07607 L
.52383 .07607 L
.52514 .07608 L
.52588 .07608 L
.52656 .07608 L
.52768 .07607 L
.52888 .07606 L
.53001 .07604 L
.53104 .07603 L
.53355 .07597 L
.53593 .0759 L
.54065 .07571 L
.54577 .07543 L
.55526 .07475 L
.56569 .07378 L
.58674 .07127 L
.62714 .06495 L
.66601 .05765 L
.70734 .0492 L
.74715 .04091 L
.78545 .03346 L
.79563 .03167 L
.80062 .03084 L
.8052 .03009 L
.80754 .02973 L
.80871 .02954 L
.81 .12361 L
.8113 .12361 L
.81268 .12361 L
.81518 .12361 L
.8262 .12361 L
.86767 .12361 L
.90762 .12361 L
.94605 .12361 L
.97619 .12361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`17oooo1@1Vod;oool0
08ooool00`000?ooooooo`11oooo1P1Vo`Coool00`1Vooooooooo`10oooo002?oooo00<0003ooooo
ool0>oooo`H0I_l:oooo00<0I_ooooooool0@?ooo`00Soooo`030000oooooooo03Soool306Ko4?oo
o`0306Kooooooooo043oool008ooool00`000?ooooooo`0doooo101Voa?oool00`1Vooooooooo`10
oooo002?oooo0P00037oool406Ko5oooo`0306Kooooooooo043oool008ooool00`000?ooooooo`0Z
oooo1P1Voa_oool00`1Vooooooooo`10oooo002?oooo00<0003oooooool09Oooo`D0I_lQoooo00<0
I_ooooooool0@?ooo`00Gooooa/0I_lEoooo00<0003oooooool08?ooo`D0I_lVoooo00<0I_oooooo
ool0@?ooo`00F_ooo`D0I_lKoooo1`1Vo`koool00`000?ooooooo`0Ioooo1`1Vob_oool00`1Voooo
ooooo`10oooo001Eoooo1@1VobOoool<06Ko0_ooo`030000oooooooo017oool806Ko<_ooo`0306Ko
oooooooo043oool005;oool306Ko>?ooo`80I_l200004P1Voc[oool00`1Vooooooooo`10oooo000G
oooo100003Goool206Ko0_ooo`D0000foooo00<0003oooooool0=oooo`D0000@oooo00<0I_oooooo
ool09Oooo`@0000Foooo000Goooo00<0003oooooool0=?ooo`80I_l6oooo00<0003oooooool0=_oo
o`030000oooooooo03Woool00`000?ooooooo`0@oooo00<0I_ooooooool09Oooo`030000oooooooo
01Ooool001Soool00`000?ooooooo`0aoooo0P1Vo`Soool00`000?ooooooo`0foooo00<0003ooooo
ool0>Oooo`030000oooooooo013oool00`1Vooooooooo`0Voooo00<0003oooooool05_ooo`004Ooo
o`@00004oooo00<0003oooooool0;_ooo`80I_l2oooo100000Coool00`000?ooooooo`0foooo00<0
003oooooool0>Oooo`030000oooooooo013oool00`1Vooooooooo`0Woooo00<0003oooooool05Ooo
o`005oooo`040000oooooooo0000;_ooo`0306Kooooooooo00[oool00`000?ooooooo`0foooo00<0
003oooooool0>Oooo`030000oooooooo013oool00`1Vooooooooo`0Uoooo00@0003oooooool0000F
oooo000Hoooo0P0002koool00`1Vooooooooo`0:oooo0P0003Soool20000>Oooo`80000Boooo00<0
I_ooooooool09_ooo`80000Goooo0017oooo00<0I_ooooooool0AOooo`030000oooooooo04coool0
0`1Vooooooooo`0ooooo0015oooo0P1VodSoool00`000?ooooooo`1<oooo00<0I_ooooooool0?ooo
o`00A?ooo`0306Kooooooooo04Soool00`000?ooooooo`1<oooo00<0I_ooooooool0?oooo`00@ooo
o`0306Kooooooooo04Woool00`000?ooooooo`1<oooo00<0I_ooooooool0?oooo`00@_ooo`0306Ko
oooooooo04[oool00`000?ooooooo`1<oooo00<0I_ooooooool0?oooo`004?ooool0000Aoooo000F
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`001S?o00T000000ol0V@000000000F00001_ooo`030000oooooooo00Woool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o
03?o000i<ol02@0000Woool00ol0VOooooooo`0Xoooo00<0003oooooool05Oooo`00Soooo`030000
<ol0<ol003<co`0600004_ooo`03o`2Ioooooooo043oool008ooool00`0003?o03?o000a<ol00P00
01Soool00ol0VOooooooo`10oooo002?oooo00<0000co`0co`00;c?o0080000Joooo00?o09Wooooo
ool0@?ooo`00Soooo`030000<ol0<ol002`co`0300007?ooo`03o`2Ioooooooo043oool008ooool2
0000:S?o00<0000Ooooo00?o09Woooooool0@?ooo`00Soooo`030000<ol0<ol002Lco`0200008_oo
o`03o`2Ioooooooo043oool008ooool00`0003?o03?o000V<ol000<0003oooooool08_ooo`03o`2I
oooooooo043oool008ooool00`0003?o03?o000U<ol000<0003oooooool08oooo`03o`2Ioooooooo
043oool008ooool00`0003?o03?o000T<ol000<0003oooooool09?ooo`03o`2Ioooooooo043oool0
08ooool00`0003?o03?o000R<ol00P0002Ooool00ol0VOooooooo`10oooo002?oooo0P00028co`00
0`000?ooooooo`0Woooo00?o09Woooooool0@?ooo`00Soooo`030000<ol0<ol0020co`000`000?oo
ooooo`0Xoooo00?o09Woooooool0@?ooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0Y
oooo00?o09Woooooool0@?ooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0Yoooo00?o
09Woooooool0@?ooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`0Zoooo00?o09Wooooo
ool0@?ooo`00Soooo`030000<ol0<ol001dco`000`000?ooooooo`0[oooo00?o09Woooooool0@?oo
o`00Soooo`80000M<ol000<0003oooooool0;?ooo`03o`2Ioooooooo043oool008ooool00`0003?o
03?o000K<ol000<0003oooooool0;Oooo`03o`2Ioooooooo043oool008ooool00`0003?o03?o000K
<ol000<0003oooooool0;Oooo`03o`2Ioooooooo043oool008ooool00`0003?o03?o000J<ol000<0
003oooooool0;_ooo`03o`2Ioooooooo043oool008ooool00`0003?o03?o000J<ol000<0003ooooo
ool0;_ooo`03o`2Ioooooooo043oool008ooool00`0003?o03?o000I<ol000<0003oooooool0;ooo
o`03o`2Ioooooooo043oool008ooool200006S?o00030000oooooooo02ooool00ol0VOooooooo`10
oooo002?oooo00<0000co`0co`0063?o00030000oooooooo033oool00ol0VOooooooo`10oooo002?
oooo00<0000co`0co`0063?o00030000oooooooo033oool00ol0VOooooooo`10oooo002?oooo00<0
000co`0co`005c?o00030000oooooooo037oool00ol0VOooooooo`10oooo002?oooo00<0000co`0c
o`005c?o00030000oooooooo037oool00ol0VOooooooo`10oooo0027oooo1@0000?oool00`0003?o
03?o000F<ol000<0003oooooool0<_ooo`03o`2Ioooooooo043oool008Woool00`000?ooooooo`03
oooo00<0000co`0co`005S?o00030000oooooooo03;oool00ol0VOooooooo`10oooo0029oooo00<0
003oooooool00oooo`<0000E<ol000<0003oooooool0<oooo`03o`2Ioooooooo043oool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo03?oool00ol0VOooooooo`10
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`0coooo00?o
09Woooooool0@?ooo`00R?ooo`800005oooo00<0000co`0co`0053?o00030000oooooooo03Coool0
0ol0VOooooooo`10oooo002?oooo00<0000co`0co`0053?o00030000oooooooo03Coool00ol0VOoo
ooooo`10oooo002?oooo00<0000co`0co`004c?o00030000oooooooo03Goool00ol0VOooooooo`10
oooo002?oooo0P0001@co`000`000?ooooooo`0eoooo00?o09Woooooool0@?ooo`00Soooo`030000
<ol0<ol001<co`000`000?ooooooo`0eoooo00?o09Woooooool0@?ooo`00Soooo`030000<ol0<ol0
018co`000`000?ooooooo`0foooo00?o09Woooooool0@?ooo`00Soooo`030000<ol0<ol0018co`00
0`000?ooooooo`0foooo00?o09Woooooool0@?ooo`00Soooo`030000<ol0<ol0018co`000`000?oo
ooooo`0foooo00?o09Woooooool0@?ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0g
oooo00?o09Woooooool0@?ooo`00Soooo`80000B<ol000<0003oooooool0=oooo`03o`2Ioooooooo
043oool008ooool00`0003?o03?o000A<ol000<0003oooooool0=oooo`03o`2Ioooooooo043oool0
08ooool00`0003?o03?o000A<ol000<0003oooooool0=oooo`03o`2Ioooooooo043oool008ooool0
0`0003?o03?o000@<ol000<0003oooooool0>?ooo`03o`2Ioooooooo043oool008ooool00`0003?o
03?o000@<ol000<0003oooooool0>?ooo`03o`2Ioooooooo043oool008ooool00`0003?o03?o000@
<ol000<0003oooooool0>?ooo`03o`2Ioooooooo043oool008ooool00`0003?o03?o000@<ol000<0
003oooooool0>?ooo`03o`2Ioooooooo043oool008ooool2000043?o00030000oooooooo03Woool0
0ol0VOooooooo`10oooo002?oooo00<0000co`0co`003c?o00030000oooooooo03Woool00ol0VOoo
ooooo`10oooo002?oooo00<0000co`0co`003c?o00030000oooooooo03Woool00ol0VOooooooo`10
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo03Woool00ol0VOooooooo`10oooo002?
oooo00<0000co`0co`003c?o00030000oooooooo03Woool00ol0VOooooooo`10oooo002?oooo00<0
000co`0co`003S?o00030000oooooooo03[oool00ol0VOooooooo`10oooo002?oooo0P0000lco`00
0`000?ooooooo`0joooo00?o09Woooooool0@?ooo`00Soooo`030000<ol0<ol000hco`000`000?oo
ooooo`0joooo00?o09Woooooool0@?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0j
oooo00?o09Woooooool0@?ooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`0koooo00?o
09Woooooool0@?ooo`00Qoooo`@00004oooo00<0000co`0co`003C?o00030000oooooooo03_oool0
0ol0VOooooooo`10oooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol000dco`000`000?oo
ooooo`0koooo00?o09Woooooool0@?ooo`00R?ooo`030000oooooooo00Coool300003C?o00030000
oooooooo03_oool00ol0VOooooooo`10oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
00dco`000`000?ooooooo`0loooo00?o09Woooooool0?oooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol000`co`000`000?ooooooo`0moooo00?o09Woooooool0?oooo`00R?ooo`800005
oooo00<0000co`0co`0033?o00030000oooooooo03goool00ol0VOooooooo`0ooooo002?oooo00<0
000co`0co`0033?o00030000oooooooo03goool00ol0VOooooooo`0ooooo002?oooo00<0000co`0c
o`0033?o00030000oooooooo03goool00ol0VOooooooo`0ooooo002?oooo0P0000dco`000`000?oo
ooooo`0moooo00?o09Woooooool0?oooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`0m
oooo00?o09Woooooool0?oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0noooo00?o
09Woooooool0?oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0noooo00?o09Wooooo
ool0?oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0noooo00?o09Woooooool0?ooo
o`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`0noooo00?o09Woooooool0?oooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`0noooo00?o09Woooooool0?oooo`00Soooo`80000<
<ol000<0003oooooool0?_ooo`03o`2Ioooooooo03ooool008ooool00`0003?o03?o000;<ol000<0
003oooooool0?_ooo`03o`2Ioooooooo03ooool008ooool00`0003?o03?o000:<ol000<0003ooooo
ool0?oooo`03o`2Ioooooooo03ooool008ooool00`0003?o03?o000:<ol000<0003oooooool0?ooo
o`03o`2Ioooooooo03ooool008ooool00`0003?o03?o000:<ol000<0003oooooool0?oooo`03o`2I
oooooooo03ooool008ooool00`0003?o03?o000:<ol000<0003oooooool0?oooo`03o`2Ioooooooo
03ooool008ooool200002c?o00030000oooooooo03ooool00ol0VOooooooo`0ooooo002?oooo00<0
000co`0co`002S?o00030000oooooooo03ooool00ol0VOooooooo`0ooooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo03ooool00ol0VOooooooo`0ooooo002?oooo00<0000co`0co`002C?o
00030000oooooooo043oool00ol0VOooooooo`0ooooo002?oooo00<0000co`0co`002C?o00030000
oooooooo043oool00ol0VOooooooo`0ooooo002?oooo00<0000co`0co`002C?o00030000oooooooo
043oool00ol0VOooooooo`0ooooo002?oooo0P0000Xco`000`000?ooooooo`10oooo00?o09Wooooo
ool0?oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`10oooo00?o09Woooooool0?ooo
o`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`10oooo00?o09Woooooool0?oooo`00Sooo
o`030000<ol0<ol000Pco`000`000?ooooooo`11oooo00?o09Woooooool0?oooo`00R?ooo`800005
oooo00<0000co`0co`0023?o00030000oooooooo047oool00ol0VOooooooo`0ooooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo047oool00ol0VOooooooo`0o
oooo0029oooo00<0003oooooool00oooo`<00008<ol000<0003oooooool0@Oooo`03o`2Ioooooooo
03ooool008[oool00`000?ooooooo`02oooo00<0000co`0co`0023?o00030000oooooooo047oool0
0ol0VOooooooo`0ooooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000
oooooooo047oool00ol0VOooooooo`0ooooo0028oooo0P0000Goool00`0003?o03?o0007<ol000<0
003oooooool0@_ooo`03o`2Ioooooooo03ooool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool0@_ooo`03o`2Ioooooooo03ooool008ooool00`0003?o03?o0007<ol000<0003oooooool0@_oo
o`03o`2Ioooooooo03ooool008ooool00`0003?o03?o0007<ol000<0003oooooool0@_ooo`03o`2I
oooooooo03ooool008ooool2000023?o00030000oooooooo04;oool00ol0VOooooooo`0ooooo002?
oooo00<0000co`0co`001c?o00030000oooooooo04;oool00ol0VOooooooo`0ooooo002?oooo00<0
000co`0co`001c?o00030000oooooooo04;oool00ol0VOooooooo`0ooooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo04;oool00ol0VOooooooo`0ooooo002?oooo00<0000co`0co`001S?o
00030000oooooooo04?oool00ol0VOooooooo`0ooooo002?oooo00<0000co`0co`001S?o00030000
oooooooo04?oool00ol0VOooooooo`0ooooo002?oooo0P0000Lco`000`000?ooooooo`13oooo00?o
09Woooooool0?oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`13oooo00?o09Wooooo
ool0?oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`13oooo00?o09Woooooool0?ooo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`13oooo00?o09Woooooool0?oooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`13oooo00?o09Woooooool0?oooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`13oooo00?o09Woooooool0?oooo`00Soooo`800006<ol000<0
003oooooool0A?ooo`03o`2Ioooooooo03ooool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool0A?ooo`03o`2Ioooooooo03ooool008ooool00`0003?o03?o0005<ol000<0003oooooool0A?oo
o`03o`2Ioooooooo03ooool008ooool00`0003?o03?o0005<ol000<0003oooooool0A?ooo`03o`2I
oooooooo03ooool008ooool00`0003?o03?o0005<ol000<0003oooooool0A?ooo`03o`2Ioooooooo
03ooool008ooool00`0003?o03?o0005<ol000<0003oooooool0A?ooo`03o`2Ioooooooo03ooool0
08ooool200001S?o00030000oooooooo04Coool00ol0VOooooooo`0ooooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo04Coool00ol0VOooooooo`0ooooo002?oooo00<0000co`0co`001C?o
00030000oooooooo04Coool00ol0VOooooooo`0ooooo002?oooo00<0000co`0co`0013?o00030000
oooooooo04Goool00ol0VOooooooo`0ooooo002?oooo00<0000co`0co`0013?o00030000oooooooo
04Goool00ol0VOooooooo`0ooooo0029oooo0`0000?oool00`0003?o03?o0004<ol000<0003ooooo
ool0AOooo`03o`2Ioooooooo03ooool008[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o
00030000oooooooo04Goool00ol0VOooooooo`0ooooo0027oooo1@0000?oool3000013?o00030000
oooooooo04Goool00ol0VOooooooo`0ooooo0027oooo00@0003oooooool00004oooo1c?o08[oool0
08Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o
08[oool008ooool7<ol0R_ooo`00O?ooo`030000oooooooo013oool7<ol02oooo`030000oooooooo
07coool007_oool00`000?ooooooo`08oooo00<0003oooooool01_ooo`Lco`0<oooo00<0003ooooo
ool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000c?o
00800004oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`05oooo00<0000co`0co`0013?o00Goool010000?oo
ooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo
00goool00c?o000003?o0004<ol01oooo`030000oooooooo00?oool00`000?ooooooo`1joooo001k
oooo00<0003oooooool01@0000coool2<ol000<0000co`0co`000S?o00Soool01@000?oooooooooo
o`00001moooo001koooo00D0003oooooooooool000003oooo`040000<ol0<ol000000c?o00Goool0
10000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04?ooo`03<ol0
0000000000@co`06oooo0P0000?oool00`000?ooooooo`1loooo002?oooo1c?o08[oool008ooool7
<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.7878 .12361 L
.79892 .12361 L
.80403 .12361 L
.80943 .12361 L
.81165 .12361 L
.81288 .12361 L
.81404 .12361 L
s
.81404 .12361 m
.8143 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.16408 .12361 L
.17277 .12361 L
.17735 .12361 L
.18221 .12361 L
.18341 .12361 L
.1847 .12361 L
.18544 .12361 L
.18611 .12319 L
.18679 .12249 L
.18744 .12183 L
.19227 .11708 L
.20178 .10853 L
.22272 .09315 L
.24252 .08227 L
.26091 .07479 L
.27148 .07145 L
.28143 .06886 L
.2903 .06697 L
.30004 .06529 L
.3098 .06398 L
.31478 .06345 L
.32012 .06297 L
.32511 .0626 L
.32967 .06233 L
.33425 .06212 L
.33859 .06197 L
.34096 .06191 L
.34318 .06187 L
.34437 .06185 L
.34562 .06183 L
.34627 .06183 L
.34699 .06182 L
.34824 .06181 L
.34894 .06181 L
.34959 .0618 L
.35081 .0618 L
.35213 .06181 L
.35287 .06181 L
.35356 .06181 L
.3547 .06182 L
.35596 .06183 L
.3585 .06187 L
.3609 .06191 L
.36309 .06196 L
.36802 .06211 L
.37692 .06247 L
Mistroke
.38679 .06302 L
.39594 .06365 L
.41668 .06542 L
.45586 .06968 L
.47588 .07213 L
.4864 .07346 L
.4975 .07489 L
.50231 .07549 L
.50747 .076 L
.51043 .07622 L
.51313 .07638 L
.51584 .07651 L
.5184 .07661 L
.52073 .07667 L
.5219 .07669 L
.52319 .0767 L
.52429 .07671 L
.52547 .07672 L
.52659 .07672 L
.52761 .07672 L
.52882 .07671 L
.52994 .07669 L
.53117 .07667 L
.53249 .07665 L
.53518 .07658 L
.53762 .0765 L
.54248 .07629 L
.54762 .07599 L
.55684 .07532 L
.57765 .07318 L
.61559 .06775 L
.65598 .06053 L
.69486 .05275 L
.73619 .04413 L
.75686 .03988 L
.776 .0361 L
.79456 .03266 L
.80394 .03105 L
.80651 .03063 L
.80928 .03018 L
.81055 .02998 L
.8119 .02977 L
.81304 .02959 L
.8143 .12361 L
.81561 .12361 L
.81683 .12361 L
.81957 .12361 L
.82455 .12361 L
.83388 .12361 L
.85483 .12361 L
Mistroke
.8942 .12361 L
.93205 .12361 L
.97236 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.32) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`16oooo1`1Vod7oool0
08ooool00`000?ooooooo`11oooo1@1Vo`Koool00`1Vooooooooo`0ooooo002?oooo00<0003ooooo
ool0??ooo`D0I_l;oooo00<0I_ooooooool0?oooo`00Soooo`030000oooooooo03Ooool506Ko4?oo
o`0306Kooooooooo03ooool008ooool00`000?ooooooo`0aoooo1P1VoaGoool00`1Vooooooooo`0o
oooo002?oooo0P0002goool506Ko6oooo`0306Kooooooooo03ooool008ooool00`000?ooooooo`0X
oooo101Vob3oool00`1Vooooooooo`0ooooo002?oooo00<0003oooooool08oooo`D0I_lToooo00<0
I_ooooooool0?oooo`00G_oooaX0I_lGoooo00<0003oooooool07Oooo`H0I_lYoooo00<0I_oooooo
ool0?oooo`00F_ooo`@0I_lJoooo1`1Voa3oool00`000?ooooooo`0Hoooo1@1Vobooool00`1Voooo
ooooo`0ooooo001Doooo1P1VobGoool<06Ko1?ooo`030000oooooooo01Coool406Ko=?ooo`0306Ko
oooooooo03ooool005;oool206Ko=oooo`@0I_l20000101Vo`;oool?06Ko>?ooo`0306Kooooooooo
03ooool001Ooool40000=Oooo`80I_l2oooo1@0003Koool00`000?ooooooo`02oooo101Voc7oool5
00004Oooo`0306Kooooooooo02Coool400005_ooo`005oooo`030000oooooooo03Coool206Ko1_oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool04Oooo`0306Kooooooooo
02Coool00`000?ooooooo`0Goooo000Hoooo00<0003oooooool0<Oooo`80I_l8oooo00<0003ooooo
ool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0Aoooo00<0I_ooooooool09Oooo`030000
oooooooo01Koool0017oool400001?ooo`030000oooooooo02koool206Ko0_ooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0Aoooo00<0I_ooooooool09_oo
o`030000oooooooo01Goool001Ooool010000?ooooooo`0002koool00`1Vooooooooo`0:oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0Aoooo00<0I_ooooooool09?oo
o`040000oooooooo00005_ooo`006?ooo`80000]oooo0P1Vo`coool20000>?ooo`80000ioooo0P00
01?oool00`1Vooooooooo`0Uoooo0P0001Ooool004Koool00`1Vooooooooo`16oooo00<0003ooooo
ool0COooo`0306Kooooooooo03koool004Coool206KoBOooo`030000oooooooo04goool00`1Voooo
ooooo`0noooo0013oooo00<0I_ooooooool0BOooo`030000oooooooo04goool00`1Vooooooooo`0n
oooo0012oooo00<0I_ooooooool0B_ooo`030000oooooooo04goool00`1Vooooooooo`0noooo0011
oooo00<0I_ooooooool0Boooo`030000oooooooo04goool00`1Vooooooooo`0noooo000@ooooo`00
017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0006<ol02`000003o`2I0000000001@00006oooo00<0003ooooo
ool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Ooo
o`030000<ol0<ol003Tco`0900002oooo`03o`2Ioooooooo02Koool00`000?ooooooo`0Eoooo002?
oooo00<0000co`0co`00<c?o00H0000Doooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol0
034co`0200006_ooo`03o`2Ioooooooo03koool008ooool00`0003?o03?o000_<ol00P0001coool0
0ol0VOooooooo`0noooo002?oooo00<0000co`0co`00;3?o00<0000Noooo00?o09Woooooool0?_oo
o`00Soooo`80000Z<ol00`00027oool00ol0VOooooooo`0noooo002?oooo00<0000co`0co`009c?o
0080000Toooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol002Hco`000`000?ooooooo`0T
oooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol002Dco`000`000?ooooooo`0Uoooo00?o
09Woooooool0?_ooo`00Soooo`030000<ol0<ol002@co`000`000?ooooooo`0Voooo00?o09Wooooo
ool0?_ooo`00Soooo`030000<ol0<ol0028co`020000:Oooo`03o`2Ioooooooo03koool008ooool2
00008S?o00030000oooooooo02Woool00ol0VOooooooo`0noooo002?oooo00<0000co`0co`0083?o
00030000oooooooo02[oool00ol0VOooooooo`0noooo002?oooo00<0000co`0co`007c?o00030000
oooooooo02_oool00ol0VOooooooo`0noooo002?oooo00<0000co`0co`007c?o00030000oooooooo
02_oool00ol0VOooooooo`0noooo002?oooo00<0000co`0co`007S?o00030000oooooooo02coool0
0ol0VOooooooo`0noooo002?oooo00<0000co`0co`007C?o00030000oooooooo02goool00ol0VOoo
ooooo`0noooo002?oooo0P0001dco`000`000?ooooooo`0^oooo00?o09Woooooool0?_ooo`00Sooo
o`030000<ol0<ol001/co`000`000?ooooooo`0_oooo00?o09Woooooool0?_ooo`00Soooo`030000
<ol0<ol001/co`000`000?ooooooo`0_oooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol0
01Xco`000`000?ooooooo`0`oooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol001Xco`00
0`000?ooooooo`0`oooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol001Tco`000`000?oo
ooooo`0aoooo00?o09Woooooool0?_ooo`00Soooo`80000J<ol000<0003oooooool0<Oooo`03o`2I
oooooooo03koool008ooool00`0003?o03?o000H<ol000<0003oooooool0<_ooo`03o`2Ioooooooo
03koool008ooool00`0003?o03?o000H<ol000<0003oooooool0<_ooo`03o`2Ioooooooo03koool0
08ooool00`0003?o03?o000G<ol000<0003oooooool0<oooo`03o`2Ioooooooo03koool008ooool0
0`0003?o03?o000G<ol000<0003oooooool0<oooo`03o`2Ioooooooo03koool008Ooool500000ooo
o`030000<ol0<ol001Hco`000`000?ooooooo`0doooo00?o09Woooooool0?_ooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000F<ol000<0003oooooool0=?ooo`03o`2Ioooooooo03koool0
08Woool00`000?ooooooo`03oooo0`0001Dco`000`000?ooooooo`0eoooo00?o09Woooooool0?_oo
o`00ROooo`030000oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool0=Oooo`03o`2I
oooooooo03koool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo
03Goool00ol0VOooooooo`0noooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003ooooo
ool0=_ooo`03o`2Ioooooooo03koool008ooool00`0003?o03?o000D<ol000<0003oooooool0=_oo
o`03o`2Ioooooooo03koool008ooool00`0003?o03?o000C<ol000<0003oooooool0=oooo`03o`2I
oooooooo03koool008ooool2000053?o00030000oooooooo03Ooool00ol0VOooooooo`0noooo002?
oooo00<0000co`0co`004c?o00030000oooooooo03Ooool00ol0VOooooooo`0noooo002?oooo00<0
000co`0co`004S?o00030000oooooooo03Soool00ol0VOooooooo`0noooo002?oooo00<0000co`0c
o`004S?o00030000oooooooo03Soool00ol0VOooooooo`0noooo002?oooo00<0000co`0co`004S?o
00030000oooooooo03Soool00ol0VOooooooo`0noooo002?oooo00<0000co`0co`004C?o00030000
oooooooo03Woool00ol0VOooooooo`0noooo002?oooo0P00018co`000`000?ooooooo`0ioooo00?o
09Woooooool0?_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0ioooo00?o09Wooooo
ool0?_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0ioooo00?o09Woooooool0?_oo
o`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0joooo00?o09Woooooool0?_ooo`00Sooo
o`030000<ol0<ol0010co`000`000?ooooooo`0joooo00?o09Woooooool0?_ooo`00Soooo`030000
<ol0<ol0010co`000`000?ooooooo`0joooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol0
010co`000`000?ooooooo`0joooo00?o09Woooooool0?_ooo`00Soooo`80000@<ol000<0003ooooo
ool0>oooo`03o`2Ioooooooo03koool008ooool00`0003?o03?o000?<ol000<0003oooooool0>ooo
o`03o`2Ioooooooo03koool008ooool00`0003?o03?o000?<ol000<0003oooooool0>oooo`03o`2I
oooooooo03koool008ooool00`0003?o03?o000?<ol000<0003oooooool0>oooo`03o`2Ioooooooo
03koool008ooool00`0003?o03?o000?<ol000<0003oooooool0>oooo`03o`2Ioooooooo03koool0
08ooool00`0003?o03?o000><ol000<0003oooooool0??ooo`03o`2Ioooooooo03koool008ooool2
00003c?o00030000oooooooo03coool00ol0VOooooooo`0noooo002?oooo00<0000co`0co`003S?o
00030000oooooooo03coool00ol0VOooooooo`0noooo002?oooo00<0000co`0co`003S?o00030000
oooooooo03coool00ol0VOooooooo`0noooo002?oooo00<0000co`0co`003C?o00030000oooooooo
03goool00ol0VOooooooo`0noooo0027oooo100000Coool00`0003?o03?o000=<ol000<0003ooooo
ool0?Oooo`03o`2Ioooooooo03koool008Ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o
00030000oooooooo03goool00ol0VOooooooo`0noooo0028oooo00<0003oooooool01?ooo`<0000=
<ol000<0003oooooool0?Oooo`03o`2Ioooooooo03koool008Woool00`000?ooooooo`03oooo00<0
000co`0co`003C?o00030000oooooooo03goool00ol0VOooooooo`0noooo0027oooo00@0003ooooo
ool00004oooo00<0000co`0co`0033?o00030000oooooooo03koool00ol0VOooooooo`0noooo0028
oooo0P0000Goool00`0003?o03?o000<<ol000<0003oooooool0?_ooo`03o`2Ioooooooo03koool0
08ooool00`0003?o03?o000<<ol000<0003oooooool0?_ooo`03o`2Ioooooooo03koool008ooool0
0`0003?o03?o000<<ol000<0003oooooool0?_ooo`03o`2Ioooooooo03koool008ooool200003C?o
00030000oooooooo03koool00ol0VOooooooo`0noooo002?oooo00<0000co`0co`0033?o00030000
oooooooo03koool00ol0VOooooooo`0noooo002?oooo00<0000co`0co`002c?o00030000oooooooo
03ooool00ol0VOooooooo`0noooo002?oooo00<0000co`0co`002c?o00030000oooooooo03ooool0
0ol0VOooooooo`0noooo002?oooo00<0000co`0co`002c?o00030000oooooooo03ooool00ol0VOoo
ooooo`0noooo002?oooo00<0000co`0co`002c?o00030000oooooooo03ooool00ol0VOooooooo`0n
oooo002?oooo00<0000co`0co`002c?o00030000oooooooo03ooool00ol0VOooooooo`0noooo002?
oooo0P0000`co`000`000?ooooooo`0ooooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`0ooooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol000Xco`00
0`000?ooooooo`10oooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`10oooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`10
oooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`10oooo00?o
09Woooooool0?_ooo`00Soooo`80000;<ol000<0003oooooool0@?ooo`03o`2Ioooooooo03koool0
08ooool00`0003?o03?o000:<ol000<0003oooooool0@?ooo`03o`2Ioooooooo03koool008ooool0
0`0003?o03?o000:<ol000<0003oooooool0@?ooo`03o`2Ioooooooo03koool008ooool00`0003?o
03?o0009<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03koool008ooool00`0003?o03?o0009
<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03koool008ooool00`0003?o03?o0009<ol000<0
003oooooool0@Oooo`03o`2Ioooooooo03koool008ooool200002S?o00030000oooooooo047oool0
0ol0VOooooooo`0noooo002?oooo00<0000co`0co`002C?o00030000oooooooo047oool00ol0VOoo
ooooo`0noooo002?oooo00<0000co`0co`002C?o00030000oooooooo047oool00ol0VOooooooo`0n
oooo002?oooo00<0000co`0co`0023?o00030000oooooooo04;oool00ol0VOooooooo`0noooo0028
oooo0P0000Goool00`0003?o03?o0008<ol000<0003oooooool0@_ooo`03o`2Ioooooooo03koool0
08Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0@_ooo`03o`2I
oooooooo03koool008Woool00`000?ooooooo`03oooo0`0000Pco`000`000?ooooooo`12oooo00?o
09Woooooool0?_ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008<ol000<0003ooooo
ool0@_ooo`03o`2Ioooooooo03koool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008
<ol000<0003oooooool0@_ooo`03o`2Ioooooooo03koool008Soool200001Oooo`030000<ol0<ol0
00Lco`000`000?ooooooo`13oooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`13oooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ooooo`13oooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`13
oooo00?o09Woooooool0?_ooo`00Soooo`800008<ol000<0003oooooool0@oooo`03o`2Ioooooooo
03koool008ooool00`0003?o03?o0007<ol000<0003oooooool0@oooo`03o`2Ioooooooo03koool0
08ooool00`0003?o03?o0007<ol000<0003oooooool0@oooo`03o`2Ioooooooo03koool008ooool0
0`0003?o03?o0007<ol000<0003oooooool0@oooo`03o`2Ioooooooo03koool008ooool00`0003?o
03?o0006<ol000<0003oooooool0A?ooo`03o`2Ioooooooo03koool008ooool00`0003?o03?o0006
<ol000<0003oooooool0A?ooo`03o`2Ioooooooo03koool008ooool200001c?o00030000oooooooo
04Coool00ol0VOooooooo`0noooo002?oooo00<0000co`0co`001S?o00030000oooooooo04Coool0
0ol0VOooooooo`0noooo002?oooo00<0000co`0co`001S?o00030000oooooooo04Coool00ol0VOoo
ooooo`0noooo002?oooo00<0000co`0co`001S?o00030000oooooooo04Coool00ol0VOooooooo`0n
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo04Coool00ol0VOooooooo`0noooo002?
oooo00<0000co`0co`001S?o00030000oooooooo04Coool00ol0VOooooooo`0noooo002?oooo0P00
00Hco`000`000?ooooooo`15oooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`15oooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`15oooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`15
oooo00?o09Woooooool0?_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`15oooo00?o
09Woooooool0?_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`15oooo00?o09Wooooo
ool0?_ooo`00Soooo`800006<ol000<0003oooooool0AOooo`03o`2Ioooooooo03koool008ooool0
0`0003?o03?o0005<ol000<0003oooooool0AOooo`03o`2Ioooooooo03koool008ooool00`0003?o
03?o0005<ol000<0003oooooool0AOooo`03o`2Ioooooooo03koool008ooool00`0003?o03?o0004
<ol000<0003oooooool0A_ooo`03o`2Ioooooooo03koool008ooool00`0003?o03?o0004<ol000<0
003oooooool0A_ooo`03o`2Ioooooooo03koool008Woool300000oooo`030000<ol0<ol000@co`00
0`000?ooooooo`16oooo00?o09Woooooool0?_ooo`00R_ooo`030000oooooooo00;oool00`0003?o
03?o0004<ol000<0003oooooool0A_ooo`03o`2Ioooooooo03koool008Ooool500000oooo`<00004
<ol000<0003oooooool0A_ooo`03o`2Ioooooooo03koool008Ooool010000?ooooooo`0000Coool7
<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool0
08ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>oooo00<0
003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o00ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_oo
o`@00003<ol00P000004<ol0oooooooooooo0P0000?oool400000oooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
0`000?ooooooo`07<ol00_ooo`040000oooooooo00000_ooo`030000oooooooo00Coool00`000?oo
ooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?oooc?o0006
<ol01?ooo`030000oooooooo00;oool00`000?ooooooo`04oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000>oooo00<0000co`0co`001C?o00Goool00`000?ooooooo`02oooo00<0
003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0
003oooooool00006<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`03oooo0P0000Coool200000ooo
o`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.7878 .12361 L
.79892 .12361 L
.80403 .12361 L
.80943 .12361 L
.81404 .12361 L
.8153 .12361 L
.81665 .12361 L
.81793 .12361 L
s
.81793 .12361 m
.8184 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.14415 .12361 L
.16254 .12361 L
.16783 .12361 L
.17284 .12361 L
.17733 .12361 L
.17856 .12361 L
.17987 .12361 L
.18098 .12358 L
.18221 .12231 L
.20325 .10348 L
.2225 .09036 L
.24237 .08018 L
.26127 .07309 L
.27085 .07031 L
.28107 .06787 L
.29065 .06603 L
.29946 .06468 L
.30975 .06347 L
.31516 .06298 L
.32087 .06257 L
.32584 .06229 L
.33049 .06208 L
.3331 .06199 L
.33558 .06193 L
.33695 .0619 L
.33844 .06187 L
.3398 .06185 L
.34104 .06183 L
.34218 .06182 L
.34338 .06181 L
.34458 .06181 L
.34589 .0618 L
.34703 .0618 L
.34825 .06181 L
.3494 .06182 L
.35044 .06182 L
.35177 .06184 L
.353 .06186 L
.35578 .0619 L
.35823 .06196 L
.36082 .06203 L
.37082 .06241 L
.37651 .0627 L
.38182 .06301 L
.40211 .06453 L
.42065 .06628 L
Mistroke
.46041 .0708 L
.48048 .07331 L
.49865 .07565 L
.50354 .07624 L
.5061 .0765 L
.50881 .07673 L
.51119 .07689 L
.51379 .07705 L
.51614 .07715 L
.51837 .07724 L
.51968 .07727 L
.52111 .07731 L
.52241 .07733 L
.52361 .07735 L
.52491 .07736 L
.52564 .07736 L
.52634 .07736 L
.52706 .07736 L
.52773 .07736 L
.52846 .07735 L
.52923 .07735 L
.53044 .07733 L
.53174 .07731 L
.53407 .07726 L
.53684 .07718 L
.53935 .07709 L
.54422 .07687 L
.54936 .07656 L
.55858 .07587 L
.57939 .07372 L
.61733 .06829 L
.65772 .0611 L
.69659 .05335 L
.73792 .04474 L
.77774 .03666 L
.79593 .03325 L
.8063 .03144 L
.81137 .03059 L
.8136 .03023 L
.81603 .02985 L
.81719 .02967 L
.81843 .02948 L
.8196 .12361 L
.82066 .12361 L
.82553 .12361 L
.83578 .12361 L
.85678 .12361 L
.89673 .12361 L
.93517 .12361 L
.97605 .12361 L
Mistroke
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.34) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`16oooo2@1Vocooool0
08ooool00`000?ooooooo`11oooo1@1Vo`Soool00`1Vooooooooo`0moooo002?oooo00<0003ooooo
ool0??ooo`D0I_l=oooo00<0I_ooooooool0?Oooo`00Soooo`030000oooooooo03Soool406Ko4_oo
o`0306Kooooooooo03goool008ooool00`000?ooooooo`0eoooo0`1VoaKoool00`1Vooooooooo`0m
oooo002?oooo0P0003;oool406Ko6Oooo`0306Kooooooooo03goool008ooool00`000?ooooooo`0]
oooo101Voagoool00`1Vooooooooo`0moooo002?oooo00<0003oooooool0:?ooo`D0I_lQoooo00<0
I_ooooooool0?Oooo`00G?oooad0I_lFoooo00<0003oooooool08Oooo`L0I_lVoooo00<0I_oooooo
ool0?Oooo`00Eoooo`D0I_lMoooo1`1Vo`ooool00`000?ooooooo`0Ioooo201Vobgoool00`1Voooo
ooooo`0moooo001Doooo0`1VobWoool806Ko1oooo`030000oooooooo01Coool506Ko=Oooo`0306Ko
oooooooo03goool0057oool306Ko=?ooo`L0I_l2000000<0I_ooooooool01oooo`/0I_ljoooo00<0
I_ooooooool0?Oooo`005oooo`@0000coooo0`1Vo`?oool50000=_ooo`030000oooo06Ko00T0I_l^
oooo1@0001;oool00`1Vooooooooo`0Soooo100001Koool001Ooool00`000?ooooooo`0boooo0P1V
o`Soool00`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo01;oool00`1Voooo
ooooo`0Soooo00<0003oooooool05oooo`006?ooo`030000oooooooo02ooool206Ko2_ooo`030000
oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool04_ooo`0306Kooooooooo02Coool0
0`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0]oooo00<0I_ooooooool00_oo
o`@00004oooo00<0003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0Boooo00<0
I_ooooooool09Oooo`030000oooooooo01Goool001Ooool010000?ooooooo`0002coool206Ko3Ooo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool04_ooo`0306Kooooooooo
02?oool010000?ooooooo`0001Koool001Soool20000:oooo`80I_l>oooo0P0003Soool20000>Ooo
o`80000Doooo00<0I_ooooooool09?ooo`80000Goooo0014oooo00<0I_ooooooool0B?ooo`030000
oooooooo04koool00`1Vooooooooo`0moooo0013oooo00<0I_ooooooool0BOooo`030000oooooooo
04koool00`1Vooooooooo`0moooo0012oooo00<0I_ooooooool0B_ooo`030000oooooooo04koool0
0`1Vooooooooo`0moooo0010oooo0P1Vodgoool00`000?ooooooo`1>oooo00<0I_ooooooool0?Ooo
o`00?oooo`0306Kooooooooo04goool00`000?ooooooo`1>oooo00<0I_ooooooool0?Oooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`001S?o00`000000ol0V@000000000C00001_ooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
03Woool00`0003?o03?o000i<ol02@0000coool00ol0VOooooooo`0Uoooo00<0003oooooool05Ooo
o`00Soooo`030000<ol0<ol003<co`0600005Oooo`03o`2Ioooooooo03goool008ooool00`0003?o
03?o000a<ol00P0001_oool00ol0VOooooooo`0moooo002?oooo00<0000co`0co`00;c?o0080000M
oooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol002`co`0300007oooo`03o`2Ioooooooo
03goool008ooool20000:S?o00<0000Roooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol0
02Lco`0200009Oooo`03o`2Ioooooooo03goool008ooool00`0003?o03?o000V<ol000<0003ooooo
ool09Oooo`03o`2Ioooooooo03goool008ooool00`0003?o03?o000U<ol000<0003oooooool09_oo
o`03o`2Ioooooooo03goool008ooool00`0003?o03?o000T<ol000<0003oooooool09oooo`03o`2I
oooooooo03goool008ooool00`0003?o03?o000R<ol00P0002[oool00ol0VOooooooo`0moooo002?
oooo0P00028co`000`000?ooooooo`0Zoooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol0
020co`000`000?ooooooo`0[oooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol001lco`00
0`000?ooooooo`0/oooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol001lco`000`000?oo
ooooo`0/oooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`0]
oooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol001dco`000`000?ooooooo`0^oooo00?o
09Woooooool0?Oooo`00Soooo`80000M<ol000<0003oooooool0;oooo`03o`2Ioooooooo03goool0
08ooool00`0003?o03?o000K<ol000<0003oooooool0<?ooo`03o`2Ioooooooo03goool008ooool0
0`0003?o03?o000K<ol000<0003oooooool0<?ooo`03o`2Ioooooooo03goool008ooool00`0003?o
03?o000J<ol000<0003oooooool0<Oooo`03o`2Ioooooooo03goool008ooool00`0003?o03?o000J
<ol000<0003oooooool0<Oooo`03o`2Ioooooooo03goool008ooool00`0003?o03?o000I<ol000<0
003oooooool0<_ooo`03o`2Ioooooooo03goool008ooool200006S?o00030000oooooooo03;oool0
0ol0VOooooooo`0moooo002?oooo00<0000co`0co`0063?o00030000oooooooo03?oool00ol0VOoo
ooooo`0moooo002?oooo00<0000co`0co`0063?o00030000oooooooo03?oool00ol0VOooooooo`0m
oooo002?oooo00<0000co`0co`005c?o00030000oooooooo03Coool00ol0VOooooooo`0moooo002?
oooo00<0000co`0co`005c?o00030000oooooooo03Coool00ol0VOooooooo`0moooo0027oooo1@00
00?oool00`0003?o03?o000F<ol000<0003oooooool0=Oooo`03o`2Ioooooooo03goool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo03Goool00ol0VOooooooo`0m
oooo0029oooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0=_ooo`03o`2Ioooooooo
03goool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo03Koool0
0ol0VOooooooo`0moooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?oo
ooooo`0foooo00?o09Woooooool0?Oooo`00R?ooo`800005oooo00<0000co`0co`0053?o00030000
oooooooo03Ooool00ol0VOooooooo`0moooo002?oooo00<0000co`0co`0053?o00030000oooooooo
03Ooool00ol0VOooooooo`0moooo002?oooo00<0000co`0co`004c?o00030000oooooooo03Soool0
0ol0VOooooooo`0moooo002?oooo0P0001@co`000`000?ooooooo`0hoooo00?o09Woooooool0?Ooo
o`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`0hoooo00?o09Woooooool0?Oooo`00Sooo
o`030000<ol0<ol0018co`000`000?ooooooo`0ioooo00?o09Woooooool0?Oooo`00Soooo`030000
<ol0<ol0018co`000`000?ooooooo`0ioooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol0
018co`000`000?ooooooo`0ioooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol0014co`00
0`000?ooooooo`0joooo00?o09Woooooool0?Oooo`00Soooo`80000B<ol000<0003oooooool0>_oo
o`03o`2Ioooooooo03goool008ooool00`0003?o03?o000A<ol000<0003oooooool0>_ooo`03o`2I
oooooooo03goool008ooool00`0003?o03?o000A<ol000<0003oooooool0>_ooo`03o`2Ioooooooo
03goool008ooool00`0003?o03?o000@<ol000<0003oooooool0>oooo`03o`2Ioooooooo03goool0
08ooool00`0003?o03?o000@<ol000<0003oooooool0>oooo`03o`2Ioooooooo03goool008ooool0
0`0003?o03?o000@<ol000<0003oooooool0>oooo`03o`2Ioooooooo03goool008ooool00`0003?o
03?o000@<ol000<0003oooooool0>oooo`03o`2Ioooooooo03goool008ooool2000043?o00030000
oooooooo03coool00ol0VOooooooo`0moooo002?oooo00<0000co`0co`003c?o00030000oooooooo
03coool00ol0VOooooooo`0moooo002?oooo00<0000co`0co`003c?o00030000oooooooo03coool0
0ol0VOooooooo`0moooo002?oooo00<0000co`0co`003c?o00030000oooooooo03coool00ol0VOoo
ooooo`0moooo002?oooo00<0000co`0co`003c?o00030000oooooooo03coool00ol0VOooooooo`0m
oooo002?oooo00<0000co`0co`003S?o00030000oooooooo03goool00ol0VOooooooo`0moooo002?
oooo0P0000lco`000`000?ooooooo`0moooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol0
00hco`000`000?ooooooo`0moooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol000hco`00
0`000?ooooooo`0moooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol000dco`000`000?oo
ooooo`0noooo00?o09Woooooool0?Oooo`00Qoooo`@00004oooo00<0000co`0co`003C?o00030000
oooooooo03koool00ol0VOooooooo`0moooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol0
00dco`000`000?ooooooo`0noooo00?o09Woooooool0?Oooo`00R?ooo`030000oooooooo00Coool3
00003C?o00030000oooooooo03koool00ol0VOooooooo`0moooo0029oooo00<0003oooooool00ooo
o`030000<ol0<ol000dco`000`000?ooooooo`0noooo00?o09Woooooool0?Oooo`00Qoooo`040000
oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`0ooooo00?o09Woooooool0?Ooo
o`00R?ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo03ooool00ol0VOooooooo`0m
oooo002?oooo00<0000co`0co`0033?o00030000oooooooo03ooool00ol0VOooooooo`0moooo002?
oooo00<0000co`0co`0033?o00030000oooooooo03ooool00ol0VOooooooo`0moooo002?oooo0P00
00dco`000`000?ooooooo`0ooooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol000`co`00
0`000?ooooooo`0ooooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`10oooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`10
oooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`10oooo00?o
09Woooooool0?Oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`10oooo00?o09Wooooo
ool0?Oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`10oooo00?o09Woooooool0?Ooo
o`00Soooo`80000<<ol000<0003oooooool0@?ooo`03o`2Ioooooooo03goool008ooool00`0003?o
03?o000;<ol000<0003oooooool0@?ooo`03o`2Ioooooooo03goool008ooool00`0003?o03?o000:
<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03goool008ooool00`0003?o03?o000:<ol000<0
003oooooool0@Oooo`03o`2Ioooooooo03goool008ooool00`0003?o03?o000:<ol000<0003ooooo
ool0@Oooo`03o`2Ioooooooo03goool008ooool00`0003?o03?o000:<ol000<0003oooooool0@Ooo
o`03o`2Ioooooooo03goool008ooool200002c?o00030000oooooooo047oool00ol0VOooooooo`0m
oooo002?oooo00<0000co`0co`002S?o00030000oooooooo047oool00ol0VOooooooo`0moooo002?
oooo00<0000co`0co`002S?o00030000oooooooo047oool00ol0VOooooooo`0moooo002?oooo00<0
000co`0co`002C?o00030000oooooooo04;oool00ol0VOooooooo`0moooo002?oooo00<0000co`0c
o`002C?o00030000oooooooo04;oool00ol0VOooooooo`0moooo002?oooo00<0000co`0co`002C?o
00030000oooooooo04;oool00ol0VOooooooo`0moooo002?oooo0P0000Xco`000`000?ooooooo`12
oooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`12oooo00?o
09Woooooool0?Oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`12oooo00?o09Wooooo
ool0?Oooo`00Soooo`030000<ol0<ol000Pco`000`000?ooooooo`13oooo00?o09Woooooool0?Ooo
o`00R?ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo04?oool00ol0VOooooooo`0m
oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo04?oool0
0ol0VOooooooo`0moooo0029oooo00<0003oooooool00oooo`<00008<ol000<0003oooooool0@ooo
o`03o`2Ioooooooo03goool008[oool00`000?ooooooo`02oooo00<0000co`0co`0023?o00030000
oooooooo04?oool00ol0VOooooooo`0moooo0027oooo00@0003oooooool00004oooo00<0000co`0c
o`0023?o00030000oooooooo04?oool00ol0VOooooooo`0moooo0028oooo0P0000Goool00`0003?o
03?o0007<ol000<0003oooooool0A?ooo`03o`2Ioooooooo03goool008ooool00`0003?o03?o0007
<ol000<0003oooooool0A?ooo`03o`2Ioooooooo03goool008ooool00`0003?o03?o0007<ol000<0
003oooooool0A?ooo`03o`2Ioooooooo03goool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool0A?ooo`03o`2Ioooooooo03goool008ooool2000023?o00030000oooooooo04Coool00ol0VOoo
ooooo`0moooo002?oooo00<0000co`0co`001c?o00030000oooooooo04Coool00ol0VOooooooo`0m
oooo002?oooo00<0000co`0co`001c?o00030000oooooooo04Coool00ol0VOooooooo`0moooo002?
oooo00<0000co`0co`001c?o00030000oooooooo04Coool00ol0VOooooooo`0moooo002?oooo00<0
000co`0co`001S?o00030000oooooooo04Goool00ol0VOooooooo`0moooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo04Goool00ol0VOooooooo`0moooo002?oooo0P0000Lco`000`000?oo
ooooo`15oooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`15
oooo00?o09Woooooool0?Oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`15oooo00?o
09Woooooool0?Oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`15oooo00?o09Wooooo
ool0?Oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`15oooo00?o09Woooooool0?Ooo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`15oooo00?o09Woooooool0?Oooo`00Sooo
o`800006<ol000<0003oooooool0A_ooo`03o`2Ioooooooo03goool008ooool00`0003?o03?o0005
<ol000<0003oooooool0A_ooo`03o`2Ioooooooo03goool008ooool00`0003?o03?o0005<ol000<0
003oooooool0A_ooo`03o`2Ioooooooo03goool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool0A_ooo`03o`2Ioooooooo03goool008ooool00`0003?o03?o0005<ol000<0003oooooool0A_oo
o`03o`2Ioooooooo03goool008ooool00`0003?o03?o0005<ol000<0003oooooool0A_ooo`03o`2I
oooooooo03goool008ooool200001S?o00030000oooooooo04Koool00ol0VOooooooo`0moooo002?
oooo00<0000co`0co`001C?o00030000oooooooo04Koool00ol0VOooooooo`0moooo002?oooo00<0
000co`0co`001C?o00030000oooooooo04Koool00ol0VOooooooo`0moooo002?oooo00<0000co`0c
o`0013?o00030000oooooooo04Ooool00ol0VOooooooo`0moooo002?oooo00<0000co`0co`0013?o
00030000oooooooo04Ooool00ol0VOooooooo`0moooo0029oooo0`0000?oool00`0003?o03?o0004
<ol000<0003oooooool0Aoooo`03o`2Ioooooooo03goool008[oool00`000?ooooooo`02oooo00<0
000co`0co`0013?o00030000oooooooo04Ooool00ol0VOooooooo`0moooo0027oooo1@0000?oool3
000013?o00030000oooooooo04Ooool00ol0VOooooooo`0moooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Koool400000c?o0080000013?o0?ooooooooooo`800005oooo0`0000;oool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05
oooo00<0003oooooool01c?o00;oool010000?ooooooo`0000Goool01@000?ooooooooooo`00001j
oooo001goooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?oooc?o0006<ol01?oo
o`040000oooooooooooo1@0000?oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
00koool00`0003?o03?o0005<ol01Oooo`040000oooooooo00000_ooo`050000oooooooooooo0000
07[oool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00006<ol00_ooo`040000
oooooooo00000oooo`030000oooo000000?oool00`000?ooooooo`1hoooo001ioooo00<0003ooooo
ool04Oooo`800007<ol00oooo`800005oooo0P0000;oool00`000?ooooooo`1ioooo002?oooo1c?o
08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.80799 .12361 L
.81373 .12361 L
.81654 .12361 L
.81909 .12361 L
.82028 .12361 L
.82156 .12361 L
.82277 .12361 L
s
.82277 .12361 m
.82322 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.14415 .12361 L
.16254 .12361 L
.16783 .12361 L
.17044 .12361 L
.17284 .12361 L
.17502 .12361 L
.17612 .12361 L
.17733 .12243 L
.18221 .11759 L
.20325 .0999 L
.2225 .08764 L
.24237 .07817 L
.26127 .07165 L
.27085 .06911 L
.28107 .06691 L
.29065 .06527 L
.29946 .06408 L
.30975 .06304 L
.31516 .06263 L
.32087 .0623 L
.32584 .06208 L
.32823 .062 L
.33049 .06193 L
.33315 .06188 L
.33558 .06184 L
.33694 .06182 L
.3382 .06181 L
.33885 .06181 L
.33958 .06181 L
.34033 .0618 L
.34104 .0618 L
.34222 .0618 L
.34347 .06181 L
.34466 .06182 L
.34574 .06183 L
.34701 .06184 L
.34838 .06186 L
.35087 .0619 L
.35349 .06196 L
.35626 .06203 L
.36123 .0622 L
.37004 .06261 L
.37973 .06318 L
.39918 .06469 L
.42007 .06671 L
.46135 .0715 L
Mistroke
.48198 .07411 L
.49202 .07541 L
.50111 .07658 L
.5057 .07708 L
.50811 .07729 L
.51065 .07748 L
.51288 .07762 L
.51533 .07775 L
.51754 .07784 L
.51963 .0779 L
.52087 .07793 L
.52221 .07796 L
.52343 .07798 L
.52456 .07799 L
.52578 .078 L
.52647 .078 L
.52712 .078 L
.52843 .078 L
.52916 .07799 L
.52984 .07799 L
.53099 .07797 L
.53205 .07796 L
.53448 .07791 L
.53683 .07784 L
.53935 .07775 L
.5447 .07751 L
.54962 .07722 L
.56074 .07638 L
.5809 .07428 L
.62036 .06862 L
.6583 .06189 L
.69869 .05388 L
.73757 .04578 L
.77889 .03734 L
.79957 .03343 L
.80866 .03183 L
.81349 .03101 L
.81871 .03016 L
.82114 .02978 L
.82246 .02957 L
.8237 .02938 L
.82475 .12361 L
.82588 .12361 L
.82828 .12361 L
.83727 .12361 L
.857 .12361 L
.89847 .12361 L
.93842 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.36) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`1;oooo1@1Vockoool0
08ooool00`000?ooooooo`17oooo101Vo`Coool00`1Vooooooooo`0loooo002?oooo00<0003ooooo
ool0@_ooo`D0I_l8oooo00<0I_ooooooool0??ooo`00Soooo`030000oooooooo03coool606Ko3Ooo
o`0306Kooooooooo03coool008ooool00`000?ooooooo`0goooo1@1Voa?oool00`1Vooooooooo`0l
oooo002?oooo0P0003?oool506Ko6?ooo`0306Kooooooooo03coool008ooool00`000?ooooooo`0]
oooo1@1Voagoool00`1Vooooooooo`0loooo002?oooo00<0003oooooool0:?ooo`D0I_lRoooo00<0
I_ooooooool0??ooo`00G?oooa`0I_lGoooo00<0003oooooool08Oooo`L0I_lWoooo00<0I_oooooo
ool0??ooo`00Eoooo`D0I_lLoooo201Vo`ooool00`000?ooooooo`0Ioooo201Vobkoool00`1Voooo
ooooo`0loooo001Boooo1@1VobWoool806Ko1oooo`030000oooooooo01Coool506Ko=_ooo`0306Ko
oooooooo03coool0053oool206Ko=_ooo`L0I_l200003Oooo`P0I_lkoooo00<0I_ooooooool0??oo
o`005oooo`@0000boooo0`1Vo`Coool50000=_ooo`03000006Ko06Ko00`0I_l[oooo1@0001?oool0
0`1Vooooooooo`0Roooo100001Koool001Ooool00`000?ooooooo`0aoooo0P1Vo`Woool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo01?oool00`1Vooooooooo`0Roooo00<0
003oooooool05oooo`006?ooo`030000oooooooo02koool206Ko2oooo`030000oooooooo03Koool0
0`000?ooooooo`0ioooo00<0003oooooool04oooo`0306Kooooooooo02?oool00`000?ooooooo`0F
oooo000Aoooo100000Coool00`000?ooooooo`0[oooo0P1Vo`Goool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool04oooo`0306Kooooooooo02Coool00`000?oo
ooooo`0Eoooo000Goooo00@0003oooooool0000Zoooo0P1Vo`ooool00`000?ooooooo`0foooo00<0
003oooooool0>Oooo`030000oooooooo01?oool00`1Vooooooooo`0Roooo00@0003oooooool0000F
oooo000Hoooo0P0002[oool00`1Vooooooooo`0>oooo0P0003Soool20000>Oooo`80000Eoooo00<0
I_ooooooool08oooo`80000Goooo0013oooo00<0I_ooooooool0BOooo`030000oooooooo04ooool0
0`1Vooooooooo`0loooo0012oooo00<0I_ooooooool0B_ooo`030000oooooooo04ooool00`1Voooo
ooooo`0loooo0010oooo0P1Vodgoool00`000?ooooooo`1?oooo00<0I_ooooooool0??ooo`00?ooo
o`0306Kooooooooo04goool00`000?ooooooo`1?oooo00<0I_ooooooool0??ooo`00?_ooo`0306Ko
oooooooo04koool00`000?ooooooo`1?oooo00<0I_ooooooool0??ooo`004?ooool0000Aoooo000F
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`001S?o00d000000ol0V@000000000B00001_ooo`030000oooooooo00Woool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o
03?o000i<ol02@0000goool00ol0VOooooooo`0Toooo00<0003oooooool05Oooo`00Soooo`030000
<ol0<ol003<co`0600005_ooo`03o`2Ioooooooo03coool008ooool00`0003?o03?o000a<ol00P00
01coool00ol0VOooooooo`0loooo002?oooo00<0000co`0co`00;c?o0080000Noooo00?o09Wooooo
ool0??ooo`00Soooo`030000<ol0<ol002`co`0300008?ooo`03o`2Ioooooooo03coool008ooool2
0000:S?o00<0000Soooo00?o09Woooooool0??ooo`00Soooo`030000<ol0<ol002Lco`0200009_oo
o`03o`2Ioooooooo03coool008ooool00`0003?o03?o000V<ol000<0003oooooool09_ooo`03o`2I
oooooooo03coool008ooool00`0003?o03?o000U<ol000<0003oooooool09oooo`03o`2Ioooooooo
03coool008ooool00`0003?o03?o000T<ol000<0003oooooool0:?ooo`03o`2Ioooooooo03coool0
08ooool00`0003?o03?o000R<ol00P0002_oool00ol0VOooooooo`0loooo002?oooo0P00028co`00
0`000?ooooooo`0[oooo00?o09Woooooool0??ooo`00Soooo`030000<ol0<ol0020co`000`000?oo
ooooo`0/oooo00?o09Woooooool0??ooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0]
oooo00?o09Woooooool0??ooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0]oooo00?o
09Woooooool0??ooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`0^oooo00?o09Wooooo
ool0??ooo`00Soooo`030000<ol0<ol001dco`000`000?ooooooo`0_oooo00?o09Woooooool0??oo
o`00Soooo`80000M<ol000<0003oooooool0<?ooo`03o`2Ioooooooo03coool008ooool00`0003?o
03?o000K<ol000<0003oooooool0<Oooo`03o`2Ioooooooo03coool008ooool00`0003?o03?o000K
<ol000<0003oooooool0<Oooo`03o`2Ioooooooo03coool008ooool00`0003?o03?o000J<ol000<0
003oooooool0<_ooo`03o`2Ioooooooo03coool008ooool00`0003?o03?o000J<ol000<0003ooooo
ool0<_ooo`03o`2Ioooooooo03coool008ooool00`0003?o03?o000I<ol000<0003oooooool0<ooo
o`03o`2Ioooooooo03coool008ooool200006S?o00030000oooooooo03?oool00ol0VOooooooo`0l
oooo002?oooo00<0000co`0co`0063?o00030000oooooooo03Coool00ol0VOooooooo`0loooo002?
oooo00<0000co`0co`0063?o00030000oooooooo03Coool00ol0VOooooooo`0loooo002?oooo00<0
000co`0co`005c?o00030000oooooooo03Goool00ol0VOooooooo`0loooo002?oooo00<0000co`0c
o`005c?o00030000oooooooo03Goool00ol0VOooooooo`0loooo0027oooo1@0000?oool00`0003?o
03?o000F<ol000<0003oooooool0=_ooo`03o`2Ioooooooo03coool008Woool00`000?ooooooo`03
oooo00<0000co`0co`005S?o00030000oooooooo03Koool00ol0VOooooooo`0loooo0029oooo00<0
003oooooool00oooo`<0000E<ol000<0003oooooool0=oooo`03o`2Ioooooooo03coool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo03Ooool00ol0VOooooooo`0l
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`0goooo00?o
09Woooooool0??ooo`00R?ooo`800005oooo00<0000co`0co`0053?o00030000oooooooo03Soool0
0ol0VOooooooo`0loooo002?oooo00<0000co`0co`0053?o00030000oooooooo03Soool00ol0VOoo
ooooo`0loooo002?oooo00<0000co`0co`004c?o00030000oooooooo03Woool00ol0VOooooooo`0l
oooo002?oooo0P0001@co`000`000?ooooooo`0ioooo00?o09Woooooool0??ooo`00Soooo`030000
<ol0<ol001<co`000`000?ooooooo`0ioooo00?o09Woooooool0??ooo`00Soooo`030000<ol0<ol0
018co`000`000?ooooooo`0joooo00?o09Woooooool0??ooo`00Soooo`030000<ol0<ol0018co`00
0`000?ooooooo`0joooo00?o09Woooooool0??ooo`00Soooo`030000<ol0<ol0018co`000`000?oo
ooooo`0joooo00?o09Woooooool0??ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0k
oooo00?o09Woooooool0??ooo`00Soooo`80000B<ol000<0003oooooool0>oooo`03o`2Ioooooooo
03coool008ooool00`0003?o03?o000A<ol000<0003oooooool0>oooo`03o`2Ioooooooo03coool0
08ooool00`0003?o03?o000A<ol000<0003oooooool0>oooo`03o`2Ioooooooo03coool008ooool0
0`0003?o03?o000@<ol000<0003oooooool0??ooo`03o`2Ioooooooo03coool008ooool00`0003?o
03?o000@<ol000<0003oooooool0??ooo`03o`2Ioooooooo03coool008ooool00`0003?o03?o000@
<ol000<0003oooooool0??ooo`03o`2Ioooooooo03coool008ooool00`0003?o03?o000@<ol000<0
003oooooool0??ooo`03o`2Ioooooooo03coool008ooool2000043?o00030000oooooooo03goool0
0ol0VOooooooo`0loooo002?oooo00<0000co`0co`003c?o00030000oooooooo03goool00ol0VOoo
ooooo`0loooo002?oooo00<0000co`0co`003c?o00030000oooooooo03goool00ol0VOooooooo`0l
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo03goool00ol0VOooooooo`0loooo002?
oooo00<0000co`0co`003c?o00030000oooooooo03goool00ol0VOooooooo`0loooo002?oooo00<0
000co`0co`003S?o00030000oooooooo03koool00ol0VOooooooo`0loooo002?oooo0P0000lco`00
0`000?ooooooo`0noooo00?o09Woooooool0??ooo`00Soooo`030000<ol0<ol000hco`000`000?oo
ooooo`0noooo00?o09Woooooool0??ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`0n
oooo00?o09Woooooool0??ooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`0ooooo00?o
09Woooooool0??ooo`00Qoooo`@00004oooo00<0000co`0co`003C?o00030000oooooooo03ooool0
0ol0VOooooooo`0loooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol000dco`000`000?oo
ooooo`0ooooo00?o09Woooooool0??ooo`00R?ooo`030000oooooooo00Coool300003C?o00030000
oooooooo03ooool00ol0VOooooooo`0loooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
00dco`000`000?ooooooo`0ooooo00?o09Woooooool0??ooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol000`co`000`000?ooooooo`10oooo00?o09Woooooool0??ooo`00R?ooo`800005
oooo00<0000co`0co`0033?o00030000oooooooo043oool00ol0VOooooooo`0loooo002?oooo00<0
000co`0co`0033?o00030000oooooooo043oool00ol0VOooooooo`0loooo002?oooo00<0000co`0c
o`0033?o00030000oooooooo043oool00ol0VOooooooo`0loooo002?oooo0P0000dco`000`000?oo
ooooo`10oooo00?o09Woooooool0??ooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`10
oooo00?o09Woooooool0??ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`11oooo00?o
09Woooooool0??ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`11oooo00?o09Wooooo
ool0??ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`11oooo00?o09Woooooool0??oo
o`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`11oooo00?o09Woooooool0??ooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`11oooo00?o09Woooooool0??ooo`00Soooo`80000<
<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03coool008ooool00`0003?o03?o000;<ol000<0
003oooooool0@Oooo`03o`2Ioooooooo03coool008ooool00`0003?o03?o000:<ol000<0003ooooo
ool0@_ooo`03o`2Ioooooooo03coool008ooool00`0003?o03?o000:<ol000<0003oooooool0@_oo
o`03o`2Ioooooooo03coool008ooool00`0003?o03?o000:<ol000<0003oooooool0@_ooo`03o`2I
oooooooo03coool008ooool00`0003?o03?o000:<ol000<0003oooooool0@_ooo`03o`2Ioooooooo
03coool008ooool200002c?o00030000oooooooo04;oool00ol0VOooooooo`0loooo002?oooo00<0
000co`0co`002S?o00030000oooooooo04;oool00ol0VOooooooo`0loooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo04;oool00ol0VOooooooo`0loooo002?oooo00<0000co`0co`002C?o
00030000oooooooo04?oool00ol0VOooooooo`0loooo002?oooo00<0000co`0co`002C?o00030000
oooooooo04?oool00ol0VOooooooo`0loooo002?oooo00<0000co`0co`002C?o00030000oooooooo
04?oool00ol0VOooooooo`0loooo002?oooo0P0000Xco`000`000?ooooooo`13oooo00?o09Wooooo
ool0??ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`13oooo00?o09Woooooool0??oo
o`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`13oooo00?o09Woooooool0??ooo`00Sooo
o`030000<ol0<ol000Pco`000`000?ooooooo`14oooo00?o09Woooooool0??ooo`00R?ooo`800005
oooo00<0000co`0co`0023?o00030000oooooooo04Coool00ol0VOooooooo`0loooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo04Coool00ol0VOooooooo`0l
oooo0029oooo00<0003oooooool00oooo`<00008<ol000<0003oooooool0A?ooo`03o`2Ioooooooo
03coool008[oool00`000?ooooooo`02oooo00<0000co`0co`0023?o00030000oooooooo04Coool0
0ol0VOooooooo`0loooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000
oooooooo04Coool00ol0VOooooooo`0loooo0028oooo0P0000Goool00`0003?o03?o0007<ol000<0
003oooooool0AOooo`03o`2Ioooooooo03coool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool0AOooo`03o`2Ioooooooo03coool008ooool00`0003?o03?o0007<ol000<0003oooooool0AOoo
o`03o`2Ioooooooo03coool008ooool00`0003?o03?o0007<ol000<0003oooooool0AOooo`03o`2I
oooooooo03coool008ooool2000023?o00030000oooooooo04Goool00ol0VOooooooo`0loooo002?
oooo00<0000co`0co`001c?o00030000oooooooo04Goool00ol0VOooooooo`0loooo002?oooo00<0
000co`0co`001c?o00030000oooooooo04Goool00ol0VOooooooo`0loooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo04Goool00ol0VOooooooo`0loooo002?oooo00<0000co`0co`001S?o
00030000oooooooo04Koool00ol0VOooooooo`0loooo002?oooo00<0000co`0co`001S?o00030000
oooooooo04Koool00ol0VOooooooo`0loooo002?oooo0P0000Lco`000`000?ooooooo`16oooo00?o
09Woooooool0??ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`16oooo00?o09Wooooo
ool0??ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`16oooo00?o09Woooooool0??oo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`16oooo00?o09Woooooool0??ooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`16oooo00?o09Woooooool0??ooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`16oooo00?o09Woooooool0??ooo`00Soooo`800006<ol000<0
003oooooool0Aoooo`03o`2Ioooooooo03coool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool0Aoooo`03o`2Ioooooooo03coool008ooool00`0003?o03?o0005<ol000<0003oooooool0Aooo
o`03o`2Ioooooooo03coool008ooool00`0003?o03?o0005<ol000<0003oooooool0Aoooo`03o`2I
oooooooo03coool008ooool00`0003?o03?o0005<ol000<0003oooooool0Aoooo`03o`2Ioooooooo
03coool008ooool00`0003?o03?o0005<ol000<0003oooooool0Aoooo`03o`2Ioooooooo03coool0
08ooool200001S?o00030000oooooooo04Ooool00ol0VOooooooo`0loooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo04Ooool00ol0VOooooooo`0loooo002?oooo00<0000co`0co`001C?o
00030000oooooooo04Ooool00ol0VOooooooo`0loooo002?oooo00<0000co`0co`0013?o00030000
oooooooo04Soool00ol0VOooooooo`0loooo002?oooo00<0000co`0co`0013?o00030000oooooooo
04Soool00ol0VOooooooo`0loooo0029oooo0`0000?oool00`0003?o03?o0004<ol000<0003ooooo
ool0B?ooo`03o`2Ioooooooo03coool008[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o
00030000oooooooo04Soool00ol0VOooooooo`0loooo0027oooo1@0000?oool3000013?o00030000
oooooooo04Soool00ol0VOooooooo`0loooo0027oooo00@0003oooooool00004oooo1c?o08[oool0
08Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o
08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?oooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000c?o
0080000013?o0?ooooooooooo`800003oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003ooooo
ool01c?o00;oool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1h
oooo001goooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?oooc?o0006<ol01?oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000>oooo00<0000co`0co`001C?o00Goool00`000?ooooooo`0300001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00006
<ol00_ooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool04Oooo`800007<ol00oooo`800004oooo0`0000;oool00`000?ooooooo`1i
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.80799 .12361 L
.81373 .12361 L
.81909 .12361 L
.8239 .12361 L
.82528 .12361 L
.82659 .12361 L
.82776 .12361 L
s
.82776 .12361 m
.82827 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.14415 .12361 L
.1536 .12361 L
.16254 .12361 L
.16748 .12361 L
.16883 .12361 L
.16957 .12361 L
.17026 .12361 L
.17149 .12354 L
.17214 .12287 L
.17284 .12216 L
.18221 .11315 L
.20192 .09746 L
.22343 .08462 L
.24402 .07571 L
.26314 .06984 L
.27371 .06742 L
.28366 .06561 L
.2926 .06433 L
.30227 .06328 L
.31178 .06254 L
.31717 .06224 L
.32221 .06204 L
.32494 .06196 L
.32753 .06189 L
.32985 .06185 L
.33116 .06183 L
.33238 .06182 L
.33367 .06181 L
.33489 .06181 L
.33558 .0618 L
.33622 .0618 L
.33692 .0618 L
.33766 .0618 L
.33833 .06181 L
.33905 .06181 L
.34034 .06182 L
.34113 .06183 L
.34188 .06183 L
.34327 .06185 L
.34567 .06189 L
.3479 .06194 L
.353 .06208 L
.35796 .06226 L
.36329 .0625 L
.38174 .06366 L
.40291 .06547 L
Mistroke
.42302 .06754 L
.46126 .07209 L
.48262 .07481 L
.4927 .07611 L
.50196 .0773 L
.50668 .07779 L
.51166 .07817 L
.51425 .07832 L
.51667 .07843 L
.51931 .07852 L
.5208 .07856 L
.52215 .07859 L
.52333 .07861 L
.52458 .07863 L
.52565 .07863 L
.52683 .07864 L
.52809 .07864 L
.5288 .07864 L
.52945 .07863 L
.53065 .07862 L
.53191 .0786 L
.5342 .07856 L
.53632 .07851 L
.54114 .07834 L
.54621 .07809 L
.55169 .07776 L
.56164 .077 L
.58024 .07509 L
.62121 .06931 L
.66067 .06235 L
.6986 .05486 L
.739 .04646 L
.77787 .03846 L
.79766 .03464 L
.8081 .03274 L
.81382 .03174 L
.8192 .03084 L
.82393 .03007 L
.82522 .02987 L
.82658 .02965 L
.82775 .02947 L
.82902 .12361 L
.82975 .12361 L
.83045 .12361 L
.83174 .12361 L
.83464 .12361 L
.83987 .12361 L
.85901 .12361 L
.89745 .12361 L
.93834 .12361 L
Mistroke
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.38) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`1:oooo1`1Vocgoool0
08ooool00`000?ooooooo`16oooo101Vo`Koool00`1Vooooooooo`0koooo002?oooo00<0003ooooo
ool0@Oooo`D0I_l:oooo00<0I_ooooooool0>oooo`00Soooo`030000oooooooo03goool406Ko3ooo
o`0306Kooooooooo03_oool008ooool00`000?ooooooo`0hoooo1@1Voa?oool00`1Vooooooooo`0k
oooo002?oooo0P0003?oool606Ko6?ooo`0306Kooooooooo03_oool008ooool00`000?ooooooo`0]
oooo1@1Voakoool00`1Vooooooooo`0koooo002?oooo00<0003oooooool0:Oooo`@0I_lSoooo00<0
I_ooooooool0>oooo`00F_oooaX0I_lKoooo00<0003oooooool09?ooo`D0I_lWoooo00<0I_oooooo
ool0>oooo`00EOooo`D0I_lJoooo301Vo`ooool00`000?ooooooo`0Ooooo1@1Vobcoool00`1Voooo
ooooo`0koooo001Aoooo101Vob_oool806Ko1oooo`030000oooooooo01Ooool806Ko<Oooo`0306Ko
oooooooo03_oool004koool306Ko=oooo`H0I_l00oooo`000000000Aoooo1`1VocWoool00`1Voooo
ooooo`0koooo000Goooo1000037oool206Ko1_ooo`D0000eoooo00<0I_l00000I_l04@1VobOoool5
00005?ooo`0306Kooooooooo027oool400005_ooo`005oooo`030000oooooooo033oool206Ko2_oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool05?ooo`0306Kooooooooo
027oool00`000?ooooooo`0Goooo000Hoooo00<0003oooooool0;_ooo`0306Kooooooooo00[oool0
0`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo01Coool00`1Vooooooooo`0R
oooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool0:oooo`80I_l5oooo1000
00Coool00`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo01Coool00`1Voooo
ooooo`0Soooo00<0003oooooool05Oooo`005oooo`040000oooooooo0000:_ooo`80I_l?oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0Doooo00<0I_ooooooool08Ooo
o`040000oooooooo00005_ooo`006?ooo`80000Yoooo0P1Voa3oool20000>?ooo`80000ioooo0P00
01Koool00`1Vooooooooo`0Roooo0P0001Ooool004;oool00`1Vooooooooo`1:oooo00<0003ooooo
ool0D?ooo`0306Kooooooooo03_oool0043oool206KoCOooo`030000oooooooo053oool00`1Voooo
ooooo`0koooo000ooooo00<0I_ooooooool0COooo`030000oooooooo053oool00`1Vooooooooo`0k
oooo000noooo00<0I_ooooooool0C_ooo`030000oooooooo053oool00`1Vooooooooo`0koooo000m
oooo00<0I_ooooooool0Coooo`030000oooooooo053oool00`1Vooooooooo`0koooo000@ooooo`00
017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0c
o`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0006<ol03P000003o`2I0000000001400006oooo00<0003ooooo
ool02Oooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Ooo
o`030000<ol0<ol003Tco`0900003_ooo`03o`2Ioooooooo02?oool00`000?ooooooo`0Eoooo002?
oooo00<0000co`0co`00<c?o00H0000Goooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol0
034co`0200007Oooo`03o`2Ioooooooo03_oool008ooool00`0003?o03?o000_<ol00P0001ooool0
0ol0VOooooooo`0koooo002?oooo00<0000co`0co`00;3?o00<0000Qoooo00?o09Woooooool0>ooo
o`00Soooo`80000Z<ol00`0002Coool00ol0VOooooooo`0koooo002?oooo00<0000co`0co`009c?o
0080000Woooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol002Hco`000`000?ooooooo`0W
oooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol002Dco`000`000?ooooooo`0Xoooo00?o
09Woooooool0>oooo`00Soooo`030000<ol0<ol002@co`000`000?ooooooo`0Yoooo00?o09Wooooo
ool0>oooo`00Soooo`030000<ol0<ol0028co`020000;?ooo`03o`2Ioooooooo03_oool008ooool2
00008S?o00030000oooooooo02coool00ol0VOooooooo`0koooo002?oooo00<0000co`0co`0083?o
00030000oooooooo02goool00ol0VOooooooo`0koooo002?oooo00<0000co`0co`007c?o00030000
oooooooo02koool00ol0VOooooooo`0koooo002?oooo00<0000co`0co`007c?o00030000oooooooo
02koool00ol0VOooooooo`0koooo002?oooo00<0000co`0co`007S?o00030000oooooooo02ooool0
0ol0VOooooooo`0koooo002?oooo00<0000co`0co`007C?o00030000oooooooo033oool00ol0VOoo
ooooo`0koooo002?oooo0P0001dco`000`000?ooooooo`0aoooo00?o09Woooooool0>oooo`00Sooo
o`030000<ol0<ol001/co`000`000?ooooooo`0boooo00?o09Woooooool0>oooo`00Soooo`030000
<ol0<ol001/co`000`000?ooooooo`0boooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol0
01Xco`000`000?ooooooo`0coooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol001Xco`00
0`000?ooooooo`0coooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol001Tco`000`000?oo
ooooo`0doooo00?o09Woooooool0>oooo`00Soooo`80000J<ol000<0003oooooool0=?ooo`03o`2I
oooooooo03_oool008ooool00`0003?o03?o000H<ol000<0003oooooool0=Oooo`03o`2Ioooooooo
03_oool008ooool00`0003?o03?o000H<ol000<0003oooooool0=Oooo`03o`2Ioooooooo03_oool0
08ooool00`0003?o03?o000G<ol000<0003oooooool0=_ooo`03o`2Ioooooooo03_oool008ooool0
0`0003?o03?o000G<ol000<0003oooooool0=_ooo`03o`2Ioooooooo03_oool008Ooool500000ooo
o`030000<ol0<ol001Hco`000`000?ooooooo`0goooo00?o09Woooooool0>oooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000F<ol000<0003oooooool0=oooo`03o`2Ioooooooo03_oool0
08Woool00`000?ooooooo`03oooo0`0001Dco`000`000?ooooooo`0hoooo00?o09Woooooool0>ooo
o`00ROooo`030000oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool0>?ooo`03o`2I
oooooooo03_oool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo
03Soool00ol0VOooooooo`0koooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003ooooo
ool0>Oooo`03o`2Ioooooooo03_oool008ooool00`0003?o03?o000D<ol000<0003oooooool0>Ooo
o`03o`2Ioooooooo03_oool008ooool00`0003?o03?o000C<ol000<0003oooooool0>_ooo`03o`2I
oooooooo03_oool008ooool2000053?o00030000oooooooo03[oool00ol0VOooooooo`0koooo002?
oooo00<0000co`0co`004c?o00030000oooooooo03[oool00ol0VOooooooo`0koooo002?oooo00<0
000co`0co`004S?o00030000oooooooo03_oool00ol0VOooooooo`0koooo002?oooo00<0000co`0c
o`004S?o00030000oooooooo03_oool00ol0VOooooooo`0koooo002?oooo00<0000co`0co`004S?o
00030000oooooooo03_oool00ol0VOooooooo`0koooo002?oooo00<0000co`0co`004C?o00030000
oooooooo03coool00ol0VOooooooo`0koooo002?oooo0P00018co`000`000?ooooooo`0loooo00?o
09Woooooool0>oooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0loooo00?o09Wooooo
ool0>oooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0loooo00?o09Woooooool0>ooo
o`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`0moooo00?o09Woooooool0>oooo`00Sooo
o`030000<ol0<ol0010co`000`000?ooooooo`0moooo00?o09Woooooool0>oooo`00Soooo`030000
<ol0<ol0010co`000`000?ooooooo`0moooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol0
010co`000`000?ooooooo`0moooo00?o09Woooooool0>oooo`00Soooo`80000@<ol000<0003ooooo
ool0?_ooo`03o`2Ioooooooo03_oool008ooool00`0003?o03?o000?<ol000<0003oooooool0?_oo
o`03o`2Ioooooooo03_oool008ooool00`0003?o03?o000?<ol000<0003oooooool0?_ooo`03o`2I
oooooooo03_oool008ooool00`0003?o03?o000?<ol000<0003oooooool0?_ooo`03o`2Ioooooooo
03_oool008ooool00`0003?o03?o000?<ol000<0003oooooool0?_ooo`03o`2Ioooooooo03_oool0
08ooool00`0003?o03?o000><ol000<0003oooooool0?oooo`03o`2Ioooooooo03_oool008ooool2
00003c?o00030000oooooooo03ooool00ol0VOooooooo`0koooo002?oooo00<0000co`0co`003S?o
00030000oooooooo03ooool00ol0VOooooooo`0koooo002?oooo00<0000co`0co`003S?o00030000
oooooooo03ooool00ol0VOooooooo`0koooo002?oooo00<0000co`0co`003C?o00030000oooooooo
043oool00ol0VOooooooo`0koooo0027oooo100000Coool00`0003?o03?o000=<ol000<0003ooooo
ool0@?ooo`03o`2Ioooooooo03_oool008Ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o
00030000oooooooo043oool00ol0VOooooooo`0koooo0028oooo00<0003oooooool01?ooo`<0000=
<ol000<0003oooooool0@?ooo`03o`2Ioooooooo03_oool008Woool00`000?ooooooo`03oooo00<0
000co`0co`003C?o00030000oooooooo043oool00ol0VOooooooo`0koooo0027oooo00@0003ooooo
ool00004oooo00<0000co`0co`0033?o00030000oooooooo047oool00ol0VOooooooo`0koooo0028
oooo0P0000Goool00`0003?o03?o000<<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03_oool0
08ooool00`0003?o03?o000<<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03_oool008ooool0
0`0003?o03?o000<<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03_oool008ooool200003C?o
00030000oooooooo047oool00ol0VOooooooo`0koooo002?oooo00<0000co`0co`0033?o00030000
oooooooo047oool00ol0VOooooooo`0koooo002?oooo00<0000co`0co`002c?o00030000oooooooo
04;oool00ol0VOooooooo`0koooo002?oooo00<0000co`0co`002c?o00030000oooooooo04;oool0
0ol0VOooooooo`0koooo002?oooo00<0000co`0co`002c?o00030000oooooooo04;oool00ol0VOoo
ooooo`0koooo002?oooo00<0000co`0co`002c?o00030000oooooooo04;oool00ol0VOooooooo`0k
oooo002?oooo00<0000co`0co`002c?o00030000oooooooo04;oool00ol0VOooooooo`0koooo002?
oooo0P0000`co`000`000?ooooooo`12oooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`12oooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol000Xco`00
0`000?ooooooo`13oooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`13oooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`13
oooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`13oooo00?o
09Woooooool0>oooo`00Soooo`80000;<ol000<0003oooooool0@oooo`03o`2Ioooooooo03_oool0
08ooool00`0003?o03?o000:<ol000<0003oooooool0@oooo`03o`2Ioooooooo03_oool008ooool0
0`0003?o03?o000:<ol000<0003oooooool0@oooo`03o`2Ioooooooo03_oool008ooool00`0003?o
03?o0009<ol000<0003oooooool0A?ooo`03o`2Ioooooooo03_oool008ooool00`0003?o03?o0009
<ol000<0003oooooool0A?ooo`03o`2Ioooooooo03_oool008ooool00`0003?o03?o0009<ol000<0
003oooooool0A?ooo`03o`2Ioooooooo03_oool008ooool200002S?o00030000oooooooo04Coool0
0ol0VOooooooo`0koooo002?oooo00<0000co`0co`002C?o00030000oooooooo04Coool00ol0VOoo
ooooo`0koooo002?oooo00<0000co`0co`002C?o00030000oooooooo04Coool00ol0VOooooooo`0k
oooo002?oooo00<0000co`0co`0023?o00030000oooooooo04Goool00ol0VOooooooo`0koooo0028
oooo0P0000Goool00`0003?o03?o0008<ol000<0003oooooool0AOooo`03o`2Ioooooooo03_oool0
08Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0AOooo`03o`2I
oooooooo03_oool008Woool00`000?ooooooo`03oooo0`0000Pco`000`000?ooooooo`15oooo00?o
09Woooooool0>oooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008<ol000<0003ooooo
ool0AOooo`03o`2Ioooooooo03_oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008
<ol000<0003oooooool0AOooo`03o`2Ioooooooo03_oool008Soool200001Oooo`030000<ol0<ol0
00Lco`000`000?ooooooo`16oooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`16oooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ooooo`16oooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`16
oooo00?o09Woooooool0>oooo`00Soooo`800008<ol000<0003oooooool0A_ooo`03o`2Ioooooooo
03_oool008ooool00`0003?o03?o0007<ol000<0003oooooool0A_ooo`03o`2Ioooooooo03_oool0
08ooool00`0003?o03?o0007<ol000<0003oooooool0A_ooo`03o`2Ioooooooo03_oool008ooool0
0`0003?o03?o0007<ol000<0003oooooool0A_ooo`03o`2Ioooooooo03_oool008ooool00`0003?o
03?o0006<ol000<0003oooooool0Aoooo`03o`2Ioooooooo03_oool008ooool00`0003?o03?o0006
<ol000<0003oooooool0Aoooo`03o`2Ioooooooo03_oool008ooool200001c?o00030000oooooooo
04Ooool00ol0VOooooooo`0koooo002?oooo00<0000co`0co`001S?o00030000oooooooo04Ooool0
0ol0VOooooooo`0koooo002?oooo00<0000co`0co`001S?o00030000oooooooo04Ooool00ol0VOoo
ooooo`0koooo002?oooo00<0000co`0co`001S?o00030000oooooooo04Ooool00ol0VOooooooo`0k
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo04Ooool00ol0VOooooooo`0koooo002?
oooo00<0000co`0co`001S?o00030000oooooooo04Ooool00ol0VOooooooo`0koooo002?oooo0P00
00Hco`000`000?ooooooo`18oooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`18oooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`18oooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`18
oooo00?o09Woooooool0>oooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`18oooo00?o
09Woooooool0>oooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`18oooo00?o09Wooooo
ool0>oooo`00Soooo`800006<ol000<0003oooooool0B?ooo`03o`2Ioooooooo03_oool008ooool0
0`0003?o03?o0005<ol000<0003oooooool0B?ooo`03o`2Ioooooooo03_oool008ooool00`0003?o
03?o0005<ol000<0003oooooool0B?ooo`03o`2Ioooooooo03_oool008ooool00`0003?o03?o0004
<ol000<0003oooooool0BOooo`03o`2Ioooooooo03_oool008ooool00`0003?o03?o0004<ol000<0
003oooooool0BOooo`03o`2Ioooooooo03_oool008Woool300000oooo`030000<ol0<ol000@co`00
0`000?ooooooo`19oooo00?o09Woooooool0>oooo`00R_ooo`030000oooooooo00;oool00`0003?o
03?o0004<ol000<0003oooooool0BOooo`03o`2Ioooooooo03_oool008Ooool500000oooo`<00004
<ol000<0003oooooool0BOooo`03o`2Ioooooooo03_oool008Ooool010000?ooooooo`0000Coool7
<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool0
08ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>oooo00<0
003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o00ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_oo
o`@00003<ol00P000004<ol0oooooooooooo0P0000Coool200001?ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
0`000?ooooooo`07<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooo<ol0
00Hco`04oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`1g
oooo001hoooo00<0003oooooool01@0000koool00`0003?o03?o0005<ol01Oooo`040000oooooooo
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000
oooooooo00001S?o00;oool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007<ol00oooo`800004oooo0P0000?oool0
0`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.80799 .12361 L
.81909 .12361 L
.8239 .12361 L
.82904 .12361 L
.83056 .12361 L
.832 .12361 L
.83329 .12361 L
s
.83329 .12361 m
.83358 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.14415 .12361 L
.1536 .12361 L
.15825 .12361 L
.16254 .12361 L
.16494 .12361 L
.16615 .12361 L
.16683 .12343 L
.16748 .12277 L
.17284 .11744 L
.18221 .10897 L
.20075 .09504 L
.22098 .08347 L
.23194 .07854 L
.24211 .0747 L
.2622 .0689 L
.27277 .06668 L
.28273 .06503 L
.29166 .06388 L
.29667 .06336 L
.30133 .06295 L
.30631 .06259 L
.31084 .06232 L
.31587 .0621 L
.31865 .062 L
.32127 .06193 L
.32381 .06187 L
.3251 .06185 L
.32651 .06183 L
.32772 .06182 L
.32901 .06181 L
.33024 .06181 L
.33136 .0618 L
.33268 .0618 L
.33392 .06181 L
.33462 .06181 L
.33527 .06182 L
.33671 .06183 L
.3381 .06185 L
.3396 .06187 L
.34234 .06192 L
.34723 .06205 L
.3518 .06221 L
.36221 .0627 L
.37236 .06333 L
.38326 .06415 L
.42453 .06825 L
Mistroke
.46429 .07307 L
.48436 .07565 L
.4931 .07678 L
.50254 .07799 L
.50783 .07851 L
.51015 .07869 L
.51269 .07886 L
.51494 .07898 L
.51734 .07908 L
.51988 .07917 L
.52103 .0792 L
.52225 .07923 L
.52292 .07924 L
.52366 .07925 L
.52496 .07926 L
.52569 .07927 L
.52647 .07927 L
.52721 .07928 L
.52789 .07928 L
.52914 .07927 L
.52984 .07927 L
.5305 .07926 L
.53182 .07925 L
.53323 .07923 L
.53593 .07917 L
.53848 .07909 L
.54324 .07891 L
.54788 .07867 L
.55298 .07835 L
.56329 .07755 L
.58175 .07565 L
.62215 .06998 L
.66102 .06318 L
.70235 .05505 L
.74216 .04677 L
.78046 .03888 L
.79982 .03511 L
.81011 .03321 L
.82121 .03128 L
.82635 .03043 L
.82915 .02998 L
.83052 .02977 L
.83176 .02958 L
.83291 .0294 L
.83399 .12361 L
.83514 .12361 L
.83638 .12361 L
.84144 .12361 L
.86045 .12361 L
.90133 .12361 L
Mistroke
.9407 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`1;oooo1`1Voccoool0
08ooool00`000?ooooooo`17oooo101Vo`Koool00`1Vooooooooo`0joooo002?oooo00<0003ooooo
ool0@_ooo`D0I_l:oooo00<0I_ooooooool0>_ooo`00Soooo`030000oooooooo03goool506Ko3ooo
o`0306Kooooooooo03[oool008ooool00`000?ooooooo`0hoooo1@1VoaCoool00`1Vooooooooo`0j
oooo002?oooo0P0003Coool506Ko6Oooo`0306Kooooooooo03[oool008ooool00`000?ooooooo`0^
oooo1@1Voakoool00`1Vooooooooo`0joooo002?oooo00<0003oooooool0:Oooo`D0I_lSoooo00<0
I_ooooooool0>_ooo`00F_oooad0I_lHoooo00<0003oooooool09?ooo`D0I_lXoooo00<0I_oooooo
ool0>_ooo`00EOooo`D0I_lMoooo201Voa3oool00`000?ooooooo`0Ooooo1@1Vobgoool00`1Voooo
ooooo`0joooo001Aoooo101Vob[oool506Ko2oooo`030000oooooooo01Soool706Ko<_ooo`0306Ko
oooooooo03[oool004goool406Ko<oooo`P0I_l3oooo0P00017oool806Ko>Oooo`0306Kooooooooo
03[oool001Ooool40000;oooo`<0I_l7oooo1@0003?oool306Ko00<00000I_l0I_l0401VobOoool5
00005_ooo`0306Kooooooooo01ooool400005_ooo`005oooo`030000oooooooo02koool206Ko3?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool05_ooo`0306Kooooooooo
01ooool00`000?ooooooo`0Goooo000Hoooo00<0003oooooool0:oooo`80I_l>oooo00<0003ooooo
ool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0Foooo00<0I_ooooooool08?ooo`030000
oooooooo01Koool0017oool400001?ooo`030000oooooooo02Soool206Ko2?ooo`@00004oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0Foooo00<0I_ooooooool08Ooo
o`030000oooooooo01Goool001Ooool010000?ooooooo`0002Soool00`1Vooooooooo`0@oooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0Foooo00<0I_ooooooool07ooo
o`040000oooooooo00005_ooo`006?ooo`80000Xoooo00<0I_ooooooool04?ooo`80000hoooo0P00
03Woool200006?ooo`0306Kooooooooo023oool200005oooo`00@?ooo`80I_m=oooo00<0003ooooo
ool0D_ooo`0306Kooooooooo03Woool003ooool00`1Vooooooooo`1=oooo00<0003oooooool0D_oo
o`0306Kooooooooo03Woool003koool00`1Vooooooooo`1>oooo00<0003oooooool0D_ooo`0306Ko
oooooooo03Woool003goool00`1Vooooooooo`1?oooo00<0003oooooool0D_ooo`0306Kooooooooo
03Woool003coool00`1Vooooooooo`1@oooo00<0003oooooool0D_ooo`0306Kooooooooo03Woool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`030000oooooooo00Woool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o
03?o000i<ol02@0000ooool00ol0VOooooooo`0Roooo00<0003oooooool05Oooo`00Soooo`030000
<ol0<ol003<co`0600006?ooo`03o`2Ioooooooo03[oool008ooool00`0003?o03?o000a<ol00P00
01koool00ol0VOooooooo`0joooo002?oooo00<0000co`0co`00;c?o0080000Poooo00?o09Wooooo
ool0>_ooo`00Soooo`030000<ol0<ol002`co`0300008_ooo`03o`2Ioooooooo03[oool008ooool2
0000:S?o00<0000Uoooo00?o09Woooooool0>_ooo`00Soooo`030000<ol0<ol002Lco`020000:?oo
o`03o`2Ioooooooo03[oool008ooool00`0003?o03?o000V<ol000<0003oooooool0:?ooo`03o`2I
oooooooo03[oool008ooool00`0003?o03?o000U<ol000<0003oooooool0:Oooo`03o`2Ioooooooo
03[oool008ooool00`0003?o03?o000T<ol000<0003oooooool0:_ooo`03o`2Ioooooooo03[oool0
08ooool00`0003?o03?o000R<ol00P0002goool00ol0VOooooooo`0joooo002?oooo0P00028co`00
0`000?ooooooo`0]oooo00?o09Woooooool0>_ooo`00Soooo`030000<ol0<ol0020co`000`000?oo
ooooo`0^oooo00?o09Woooooool0>_ooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0_
oooo00?o09Woooooool0>_ooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0_oooo00?o
09Woooooool0>_ooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`0`oooo00?o09Wooooo
ool0>_ooo`00Soooo`030000<ol0<ol001dco`000`000?ooooooo`0aoooo00?o09Woooooool0>_oo
o`00Soooo`80000M<ol000<0003oooooool0<_ooo`03o`2Ioooooooo03[oool008ooool00`0003?o
03?o000K<ol000<0003oooooool0<oooo`03o`2Ioooooooo03[oool008ooool00`0003?o03?o000K
<ol000<0003oooooool0<oooo`03o`2Ioooooooo03[oool008ooool00`0003?o03?o000J<ol000<0
003oooooool0=?ooo`03o`2Ioooooooo03[oool008ooool00`0003?o03?o000J<ol000<0003ooooo
ool0=?ooo`03o`2Ioooooooo03[oool008ooool00`0003?o03?o000I<ol000<0003oooooool0=Ooo
o`03o`2Ioooooooo03[oool008ooool200006S?o00030000oooooooo03Goool00ol0VOooooooo`0j
oooo002?oooo00<0000co`0co`0063?o00030000oooooooo03Koool00ol0VOooooooo`0joooo002?
oooo00<0000co`0co`0063?o00030000oooooooo03Koool00ol0VOooooooo`0joooo002?oooo00<0
000co`0co`005c?o00030000oooooooo03Ooool00ol0VOooooooo`0joooo002?oooo00<0000co`0c
o`005c?o00030000oooooooo03Ooool00ol0VOooooooo`0joooo0027oooo1@0000?oool00`0003?o
03?o000F<ol000<0003oooooool0>?ooo`03o`2Ioooooooo03[oool008Woool00`000?ooooooo`03
oooo00<0000co`0co`005S?o00030000oooooooo03Soool00ol0VOooooooo`0joooo0029oooo00<0
003oooooool00oooo`<0000E<ol000<0003oooooool0>Oooo`03o`2Ioooooooo03[oool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo03Woool00ol0VOooooooo`0j
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`0ioooo00?o
09Woooooool0>_ooo`00R?ooo`800005oooo00<0000co`0co`0053?o00030000oooooooo03[oool0
0ol0VOooooooo`0joooo002?oooo00<0000co`0co`0053?o00030000oooooooo03[oool00ol0VOoo
ooooo`0joooo002?oooo00<0000co`0co`004c?o00030000oooooooo03_oool00ol0VOooooooo`0j
oooo002?oooo0P0001@co`000`000?ooooooo`0koooo00?o09Woooooool0>_ooo`00Soooo`030000
<ol0<ol001<co`000`000?ooooooo`0koooo00?o09Woooooool0>_ooo`00Soooo`030000<ol0<ol0
018co`000`000?ooooooo`0loooo00?o09Woooooool0>_ooo`00Soooo`030000<ol0<ol0018co`00
0`000?ooooooo`0loooo00?o09Woooooool0>_ooo`00Soooo`030000<ol0<ol0018co`000`000?oo
ooooo`0loooo00?o09Woooooool0>_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`0m
oooo00?o09Woooooool0>_ooo`00Soooo`80000B<ol000<0003oooooool0?Oooo`03o`2Ioooooooo
03[oool008ooool00`0003?o03?o000A<ol000<0003oooooool0?Oooo`03o`2Ioooooooo03[oool0
08ooool00`0003?o03?o000A<ol000<0003oooooool0?Oooo`03o`2Ioooooooo03[oool008ooool0
0`0003?o03?o000@<ol000<0003oooooool0?_ooo`03o`2Ioooooooo03[oool008ooool00`0003?o
03?o000@<ol000<0003oooooool0?_ooo`03o`2Ioooooooo03[oool008ooool00`0003?o03?o000@
<ol000<0003oooooool0?_ooo`03o`2Ioooooooo03[oool008ooool00`0003?o03?o000@<ol000<0
003oooooool0?_ooo`03o`2Ioooooooo03[oool008ooool2000043?o00030000oooooooo03ooool0
0ol0VOooooooo`0joooo002?oooo00<0000co`0co`003c?o00030000oooooooo03ooool00ol0VOoo
ooooo`0joooo002?oooo00<0000co`0co`003c?o00030000oooooooo03ooool00ol0VOooooooo`0j
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo03ooool00ol0VOooooooo`0joooo002?
oooo00<0000co`0co`003c?o00030000oooooooo03ooool00ol0VOooooooo`0joooo002?oooo00<0
000co`0co`003S?o00030000oooooooo043oool00ol0VOooooooo`0joooo002?oooo0P0000lco`00
0`000?ooooooo`10oooo00?o09Woooooool0>_ooo`00Soooo`030000<ol0<ol000hco`000`000?oo
ooooo`10oooo00?o09Woooooool0>_ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`10
oooo00?o09Woooooool0>_ooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`11oooo00?o
09Woooooool0>_ooo`00Qoooo`@00004oooo00<0000co`0co`003C?o00030000oooooooo047oool0
0ol0VOooooooo`0joooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol000dco`000`000?oo
ooooo`11oooo00?o09Woooooool0>_ooo`00R?ooo`030000oooooooo00Coool300003C?o00030000
oooooooo047oool00ol0VOooooooo`0joooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
00dco`000`000?ooooooo`12oooo00?o09Woooooool0>Oooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol000`co`000`000?ooooooo`13oooo00?o09Woooooool0>Oooo`00R?ooo`800005
oooo00<0000co`0co`0033?o00030000oooooooo04?oool00ol0VOooooooo`0ioooo002?oooo00<0
000co`0co`0033?o00030000oooooooo04?oool00ol0VOooooooo`0ioooo002?oooo00<0000co`0c
o`0033?o00030000oooooooo04?oool00ol0VOooooooo`0ioooo002?oooo0P0000dco`000`000?oo
ooooo`13oooo00?o09Woooooool0>Oooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`13
oooo00?o09Woooooool0>Oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`14oooo00?o
09Woooooool0>Oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`14oooo00?o09Wooooo
ool0>Oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`14oooo00?o09Woooooool0>Ooo
o`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`14oooo00?o09Woooooool0>Oooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`14oooo00?o09Woooooool0>Oooo`00Soooo`80000<
<ol000<0003oooooool0A?ooo`03o`2Ioooooooo03Woool008ooool00`0003?o03?o000;<ol000<0
003oooooool0A?ooo`03o`2Ioooooooo03Woool008ooool00`0003?o03?o000:<ol000<0003ooooo
ool0AOooo`03o`2Ioooooooo03Woool008ooool00`0003?o03?o000:<ol000<0003oooooool0AOoo
o`03o`2Ioooooooo03Woool008ooool00`0003?o03?o000:<ol000<0003oooooool0AOooo`03o`2I
oooooooo03Woool008ooool00`0003?o03?o000:<ol000<0003oooooool0AOooo`03o`2Ioooooooo
03Woool008ooool200002c?o00030000oooooooo04Goool00ol0VOooooooo`0ioooo002?oooo00<0
000co`0co`002S?o00030000oooooooo04Goool00ol0VOooooooo`0ioooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo04Goool00ol0VOooooooo`0ioooo002?oooo00<0000co`0co`002C?o
00030000oooooooo04Koool00ol0VOooooooo`0ioooo002?oooo00<0000co`0co`002C?o00030000
oooooooo04Koool00ol0VOooooooo`0ioooo002?oooo00<0000co`0co`002C?o00030000oooooooo
04Koool00ol0VOooooooo`0ioooo002?oooo0P0000Xco`000`000?ooooooo`16oooo00?o09Wooooo
ool0>Oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`16oooo00?o09Woooooool0>Ooo
o`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`16oooo00?o09Woooooool0>Oooo`00Sooo
o`030000<ol0<ol000Pco`000`000?ooooooo`17oooo00?o09Woooooool0>Oooo`00R?ooo`800005
oooo00<0000co`0co`0023?o00030000oooooooo04Ooool00ol0VOooooooo`0ioooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo04Ooool00ol0VOooooooo`0i
oooo0029oooo00<0003oooooool00oooo`<00008<ol000<0003oooooool0Aoooo`03o`2Ioooooooo
03Woool008[oool00`000?ooooooo`02oooo00<0000co`0co`0023?o00030000oooooooo04Ooool0
0ol0VOooooooo`0ioooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000
oooooooo04Ooool00ol0VOooooooo`0ioooo0028oooo0P0000Goool00`0003?o03?o0007<ol000<0
003oooooool0B?ooo`03o`2Ioooooooo03Woool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool0B?ooo`03o`2Ioooooooo03Woool008ooool00`0003?o03?o0007<ol000<0003oooooool0B?oo
o`03o`2Ioooooooo03Woool008ooool00`0003?o03?o0007<ol000<0003oooooool0B?ooo`03o`2I
oooooooo03Woool008ooool2000023?o00030000oooooooo04Soool00ol0VOooooooo`0ioooo002?
oooo00<0000co`0co`001c?o00030000oooooooo04Soool00ol0VOooooooo`0ioooo002?oooo00<0
000co`0co`001c?o00030000oooooooo04Soool00ol0VOooooooo`0ioooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo04Soool00ol0VOooooooo`0ioooo002?oooo00<0000co`0co`001S?o
00030000oooooooo04Woool00ol0VOooooooo`0ioooo002?oooo00<0000co`0co`001S?o00030000
oooooooo04Woool00ol0VOooooooo`0ioooo002?oooo0P0000Lco`000`000?ooooooo`19oooo00?o
09Woooooool0>Oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`19oooo00?o09Wooooo
ool0>Oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`19oooo00?o09Woooooool0>Ooo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`19oooo00?o09Woooooool0>Oooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`19oooo00?o09Woooooool0>Oooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`19oooo00?o09Woooooool0>Oooo`00Soooo`800006<ol000<0
003oooooool0B_ooo`03o`2Ioooooooo03Woool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool0B_ooo`03o`2Ioooooooo03Woool008ooool00`0003?o03?o0005<ol000<0003oooooool0B_oo
o`03o`2Ioooooooo03Woool008ooool00`0003?o03?o0005<ol000<0003oooooool0B_ooo`03o`2I
oooooooo03Woool008ooool00`0003?o03?o0005<ol000<0003oooooool0B_ooo`03o`2Ioooooooo
03Woool008ooool00`0003?o03?o0005<ol000<0003oooooool0B_ooo`03o`2Ioooooooo03Woool0
08ooool200001S?o00030000oooooooo04[oool00ol0VOooooooo`0ioooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo04[oool00ol0VOooooooo`0ioooo002?oooo00<0000co`0co`001C?o
00030000oooooooo04[oool00ol0VOooooooo`0ioooo002?oooo00<0000co`0co`0013?o00030000
oooooooo04_oool00ol0VOooooooo`0ioooo002?oooo00<0000co`0co`0013?o00030000oooooooo
04_oool00ol0VOooooooo`0ioooo0029oooo0`0000?oool00`0003?o03?o0004<ol000<0003ooooo
ool0Boooo`03o`2Ioooooooo03Woool008[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o
00030000oooooooo04_oool00ol0VOooooooo`0ioooo0027oooo1@0000?oool3000013?o00030000
oooooooo04_oool00ol0VOooooooo`0ioooo0027oooo00@0003oooooool00004oooo1c?o08[oool0
08Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o
08[oool008ooool7<ol0R_ooo`00O?ooo`030000oooooooo013oool7<ol02oooo`030000oooooooo
07coool007_oool00`000?ooooooo`08oooo00<0003oooooool01_ooo`Lco`0<oooo00<0003ooooo
ool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000c?o
00800005oooo0`0000;oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`05oooo00<0000co`0co`0013?o00Soool01@000?oo
ooooooooo`00001moooo001joooo00<0003oooooool00_ooo`030000oooooooo00goool00c?o0000
03?o0004<ol01Oooo`D00003oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<
oooo0S?o00030000<ol0<ol0008co`05oooo00@0003oooooool00003oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo000000ooool0100003?o03?o000000<co`06oooo00<0003oool0
00000oooo`030000oooooooo07_oool007coool00`000?ooooooo`0@oooo00<co`000000000013?o
00Ooool200000_ooo`030000oooooooo07coool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.80799 .12361 L
.81909 .12361 L
.82904 .12361 L
.83177 .12361 L
.83469 .12361 L
.83611 .12361 L
.8368 .12361 L
.83745 .12361 L
s
.83745 .12361 m
.83793 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.13506 .12361 L
.14415 .12361 L
.14868 .12361 L
.1536 .12361 L
.15586 .12361 L
.15825 .12361 L
.16029 .12361 L
.16145 .12361 L
.16254 .12295 L
.16375 .12171 L
.16508 .12038 L
.16749 .11801 L
.17201 .11376 L
.18221 .10505 L
.20353 .09032 L
.22285 .08038 L
.23253 .07644 L
.243 .07284 L
.26198 .06788 L
.27149 .06605 L
.28192 .06448 L
.28718 .06384 L
.29282 .06327 L
.29775 .06285 L
.30299 .0625 L
.30827 .06221 L
.31316 .06202 L
.31587 .06194 L
.31842 .06189 L
.31978 .06186 L
.32121 .06184 L
.32196 .06183 L
.32279 .06182 L
.32348 .06182 L
.32423 .06181 L
.32493 .06181 L
.32558 .06181 L
.32687 .0618 L
.32803 .0618 L
.32927 .06181 L
.3299 .06181 L
.33059 .06182 L
.33183 .06183 L
.3333 .06185 L
.33465 .06187 L
.33703 .06191 L
Mistroke
.33962 .06197 L
.34435 .06211 L
.34968 .06232 L
.35469 .06255 L
.36406 .06309 L
.38505 .0647 L
.42365 .06869 L
.4647 .07373 L
.48517 .07637 L
.49515 .07767 L
.50424 .07879 L
.50877 .0792 L
.51115 .07938 L
.51368 .07953 L
.51589 .07965 L
.51832 .07974 L
.52053 .07981 L
.52261 .07986 L
.52376 .07988 L
.52502 .0799 L
.52633 .07991 L
.52755 .07991 L
.5287 .07991 L
.52974 .07991 L
.53094 .0799 L
.53207 .07988 L
.53331 .07987 L
.53462 .07984 L
.53697 .07978 L
.53949 .07971 L
.54227 .0796 L
.55246 .07906 L
.56175 .07837 L
.58266 .07627 L
.62247 .07074 L
.66077 .06412 L
.70152 .05618 L
.74075 .04805 L
.77847 .04022 L
.79942 .03607 L
.81864 .03253 L
.82839 .03086 L
.83314 .03009 L
.83522 .02976 L
.83631 .0296 L
.83746 .02942 L
.83869 .12361 L
.83982 .12361 L
.84204 .12361 L
.84693 .12361 L
Mistroke
.8573 .12361 L
.89515 .12361 L
.93546 .12361 L
.97425 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.42) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`1<oooo201Voc[oool0
08ooool00`000?ooooooo`17oooo1@1Vo`Ooool00`1Vooooooooo`0hoooo002?oooo00<0003ooooo
ool0@_ooo`D0I_l<oooo00<0I_ooooooool0>?ooo`00Soooo`030000oooooooo03goool506Ko4Ooo
o`0306Kooooooooo03Soool008ooool00`000?ooooooo`0hoooo1@1VoaKoool00`1Vooooooooo`0h
oooo002?oooo0P0003Coool506Ko6oooo`0306Kooooooooo03Soool008ooool00`000?ooooooo`0^
oooo1@1Vob3oool00`1Vooooooooo`0hoooo002?oooo00<0003oooooool0:Oooo`D0I_lUoooo00<0
I_ooooooool0>?ooo`00Eoooob00I_lHoooo00<0003oooooool09?ooo`D0I_lZoooo00<0I_oooooo
ool0>?ooo`00D_ooo`D0I_lPoooo201Voa3oool00`000?ooooooo`0Ooooo1@1Vobooool00`1Voooo
ooooo`0hoooo001@oooo0P1Vobgoool506Ko2oooo`030000oooooooo01Soool706Ko=?ooo`0306Ko
oooooooo03Soool004_oool506Ko=?ooo`T0I_l2oooo0P00017oool806Ko>oooo`0306Kooooooooo
03Soool001Ooool40000;_ooo`80I_l9oooo1@0003Coool206Ko00<00000I_l0I_l0401VobOoool5
00005oooo`0306Kooooooooo01koool400005_ooo`005oooo`030000oooooooo02goool206Ko3Ooo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool05oooo`0306Kooooooooo
01koool00`000?ooooooo`0Goooo000Hoooo00<0003oooooool0:_ooo`80I_l?oooo00<0003ooooo
ool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0Goooo00<0I_ooooooool07oooo`030000
oooooooo01Koool0017oool400001?ooo`030000oooooooo02Soool00`1Vooooooooo`07oooo1000
00Coool00`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo01Ooool00`1Voooo
ooooo`0Poooo00<0003oooooool05Oooo`005oooo`040000oooooooo00009oooo`80I_lBoooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0Goooo00<0I_ooooooool07_oo
o`040000oooooooo00005_ooo`006?ooo`80000Woooo00<0I_ooooooool04Oooo`80000hoooo0P00
03Woool200006Oooo`0306Kooooooooo01ooool200005oooo`00?oooo`80I_m>oooo00<0003ooooo
ool0Doooo`0306Kooooooooo03Soool003koool00`1Vooooooooo`1>oooo00<0003oooooool0Dooo
o`0306Kooooooooo03Soool003goool00`1Vooooooooo`1?oooo00<0003oooooool0Doooo`0306Ko
oooooooo03Soool003coool00`1Vooooooooo`1@oooo00<0003oooooool0Doooo`0306Kooooooooo
03Soool003_oool00`1Vooooooooo`1Aoooo00<0003oooooool0Doooo`0306Kooooooooo03Soool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0A000000?o09T0000000003P0000Koool0
0`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?oo
ooooo`0ioooo00<0000co`0co`00>C?o00T0000Aoooo00?o09Woooooool08?ooo`030000oooooooo
01Goool008ooool00`0003?o03?o000c<ol01P0001[oool00ol0VOooooooo`0hoooo002?oooo00<0
000co`0co`00<C?o0080000Poooo00?o09Woooooool0>?ooo`00Soooo`030000<ol0<ol002lco`02
00008_ooo`03o`2Ioooooooo03Soool008ooool00`0003?o03?o000/<ol00`0002Coool00ol0VOoo
ooooo`0hoooo002?oooo0P0002Xco`0300009oooo`03o`2Ioooooooo03Soool008ooool00`0003?o
03?o000W<ol00P0002[oool00ol0VOooooooo`0hoooo002?oooo00<0000co`0co`009S?o00030000
oooooooo02[oool00ol0VOooooooo`0hoooo002?oooo00<0000co`0co`009C?o00030000oooooooo
02_oool00ol0VOooooooo`0hoooo002?oooo00<0000co`0co`0093?o00030000oooooooo02coool0
0ol0VOooooooo`0hoooo002?oooo00<0000co`0co`008S?o0080000_oooo00?o09Woooooool0>?oo
o`00Soooo`80000R<ol000<0003oooooool0;oooo`03o`2Ioooooooo03Soool008ooool00`0003?o
03?o000P<ol000<0003oooooool0<?ooo`03o`2Ioooooooo03Soool008ooool00`0003?o03?o000O
<ol000<0003oooooool0<Oooo`03o`2Ioooooooo03Soool008ooool00`0003?o03?o000O<ol000<0
003oooooool0<Oooo`03o`2Ioooooooo03Soool008ooool00`0003?o03?o000N<ol000<0003ooooo
ool0<_ooo`03o`2Ioooooooo03Soool008ooool00`0003?o03?o000M<ol000<0003oooooool0<ooo
o`03o`2Ioooooooo03Soool008ooool200007C?o00030000oooooooo03Coool00ol0VOooooooo`0h
oooo002?oooo00<0000co`0co`006c?o00030000oooooooo03Goool00ol0VOooooooo`0hoooo002?
oooo00<0000co`0co`006c?o00030000oooooooo03Goool00ol0VOooooooo`0hoooo002?oooo00<0
000co`0co`006S?o00030000oooooooo03Koool00ol0VOooooooo`0hoooo002?oooo00<0000co`0c
o`006S?o00030000oooooooo03Koool00ol0VOooooooo`0hoooo002?oooo00<0000co`0co`006C?o
00030000oooooooo03Ooool00ol0VOooooooo`0hoooo002?oooo0P0001Xco`000`000?ooooooo`0g
oooo00?o09Woooooool0>?ooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0hoooo00?o
09Woooooool0>?ooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0hoooo00?o09Wooooo
ool0>?ooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0ioooo00?o09Woooooool0>?oo
o`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0ioooo00?o09Woooooool0>?ooo`00Qooo
o`D00003oooo00<0000co`0co`005S?o00030000oooooooo03[oool00ol0VOooooooo`0hoooo0029
oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`0joooo00?o09Wooooo
ool0>?ooo`00ROooo`030000oooooooo00?oool300005C?o00030000oooooooo03_oool00ol0VOoo
ooooo`0hoooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`0k
oooo00?o09Woooooool0>?ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E<ol000<0
003oooooool0>oooo`03o`2Ioooooooo03Soool008Soool200001Oooo`030000<ol0<ol001@co`00
0`000?ooooooo`0loooo00?o09Woooooool0>?ooo`00Soooo`030000<ol0<ol001@co`000`000?oo
ooooo`0loooo00?o09Woooooool0>?ooo`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`0m
oooo00?o09Woooooool0>?ooo`00Soooo`80000D<ol000<0003oooooool0?Oooo`03o`2Ioooooooo
03Soool008ooool00`0003?o03?o000C<ol000<0003oooooool0?Oooo`03o`2Ioooooooo03Soool0
08ooool00`0003?o03?o000B<ol000<0003oooooool0?_ooo`03o`2Ioooooooo03Soool008ooool0
0`0003?o03?o000B<ol000<0003oooooool0?_ooo`03o`2Ioooooooo03Soool008ooool00`0003?o
03?o000B<ol000<0003oooooool0?_ooo`03o`2Ioooooooo03Soool008ooool00`0003?o03?o000A
<ol000<0003oooooool0?oooo`03o`2Ioooooooo03Soool008ooool200004S?o00030000oooooooo
03ooool00ol0VOooooooo`0hoooo002?oooo00<0000co`0co`004C?o00030000oooooooo03ooool0
0ol0VOooooooo`0hoooo002?oooo00<0000co`0co`004C?o00030000oooooooo03ooool00ol0VOoo
ooooo`0hoooo002?oooo00<0000co`0co`0043?o00030000oooooooo043oool00ol0VOooooooo`0h
oooo002?oooo00<0000co`0co`0043?o00030000oooooooo043oool00ol0VOooooooo`0hoooo002?
oooo00<0000co`0co`0043?o00030000oooooooo043oool00ol0VOooooooo`0hoooo002?oooo00<0
000co`0co`0043?o00030000oooooooo043oool00ol0VOooooooo`0hoooo002?oooo0P00010co`00
0`000?ooooooo`11oooo00?o09Woooooool0>?ooo`00Soooo`030000<ol0<ol000lco`000`000?oo
ooooo`11oooo00?o09Woooooool0>?ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`11
oooo00?o09Woooooool0>?ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`11oooo00?o
09Woooooool0>?ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`11oooo00?o09Wooooo
ool0>?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`12oooo00?o09Woooooool0>?oo
o`00Soooo`80000?<ol000<0003oooooool0@_ooo`03o`2Ioooooooo03Soool008ooool00`0003?o
03?o000><ol000<0003oooooool0@_ooo`03o`2Ioooooooo03Soool008ooool00`0003?o03?o000>
<ol000<0003oooooool0@_ooo`03o`2Ioooooooo03Soool008ooool00`0003?o03?o000=<ol000<0
003oooooool0@oooo`03o`2Ioooooooo03Soool008Ooool400001?ooo`030000<ol0<ol000dco`00
0`000?ooooooo`13oooo00?o09Woooooool0>?ooo`00Qoooo`030000oooooooo00Goool00`0003?o
03?o000=<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Soool008Soool00`000?ooooooo`04
oooo0`0000dco`000`000?ooooooo`13oooo00?o09Woooooool0>?ooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000=<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Soool008Ooool0
10000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0A?ooo`03o`2Ioooooooo
03Soool008Soool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`14oooo00?o09Wooooo
ool0>?ooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`14oooo00?o09Woooooool0>?oo
o`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`14oooo00?o09Woooooool0>?ooo`00Sooo
o`80000=<ol000<0003oooooool0A?ooo`03o`2Ioooooooo03Soool008ooool00`0003?o03?o000<
<ol000<0003oooooool0A?ooo`03o`2Ioooooooo03Soool008ooool00`0003?o03?o000;<ol000<0
003oooooool0AOooo`03o`2Ioooooooo03Soool008ooool00`0003?o03?o000;<ol000<0003ooooo
ool0AOooo`03o`2Ioooooooo03Soool008ooool00`0003?o03?o000;<ol000<0003oooooool0AOoo
o`03o`2Ioooooooo03Soool008ooool00`0003?o03?o000;<ol000<0003oooooool0AOooo`03o`2I
oooooooo03Soool008ooool00`0003?o03?o000;<ol000<0003oooooool0AOooo`03o`2Ioooooooo
03Soool008ooool2000033?o00030000oooooooo04Goool00ol0VOooooooo`0hoooo002?oooo00<0
000co`0co`002c?o00030000oooooooo04Goool00ol0VOooooooo`0hoooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo04Koool00ol0VOooooooo`0hoooo002?oooo00<0000co`0co`002S?o
00030000oooooooo04Koool00ol0VOooooooo`0hoooo002?oooo00<0000co`0co`002S?o00030000
oooooooo04Koool00ol0VOooooooo`0hoooo002?oooo00<0000co`0co`002S?o00030000oooooooo
04Koool00ol0VOooooooo`0hoooo002?oooo0P0000/co`000`000?ooooooo`16oooo00?o09Wooooo
ool0>?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`16oooo00?o09Woooooool0>?oo
o`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`16oooo00?o09Woooooool0>?ooo`00Sooo
o`030000<ol0<ol000Tco`000`000?ooooooo`17oooo00?o09Woooooool0>?ooo`00Soooo`030000
<ol0<ol000Tco`000`000?ooooooo`17oooo00?o09Woooooool0>?ooo`00Soooo`030000<ol0<ol0
00Tco`000`000?ooooooo`17oooo00?o09Woooooool0>?ooo`00Soooo`80000:<ol000<0003ooooo
ool0Aoooo`03o`2Ioooooooo03Soool008ooool00`0003?o03?o0009<ol000<0003oooooool0Aooo
o`03o`2Ioooooooo03Soool008ooool00`0003?o03?o0009<ol000<0003oooooool0Aoooo`03o`2I
oooooooo03Soool008ooool00`0003?o03?o0008<ol000<0003oooooool0B?ooo`03o`2Ioooooooo
03Soool008Soool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`18oooo00?o09Wooooo
ool0>?ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`18
oooo00?o09Woooooool0>?ooo`00ROooo`030000oooooooo00?oool3000023?o00030000oooooooo
04Soool00ol0VOooooooo`0hoooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`18oooo00?o09Woooooool0>?ooo`00Qoooo`040000oooooooo00001?ooo`030000
<ol0<ol000Pco`000`000?ooooooo`18oooo00?o09Woooooool0>?ooo`00R?ooo`800005oooo00<0
000co`0co`001c?o00030000oooooooo04Woool00ol0VOooooooo`0hoooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo04Woool00ol0VOooooooo`0hoooo002?oooo00<0000co`0co`001c?o
00030000oooooooo04Woool00ol0VOooooooo`0hoooo002?oooo00<0000co`0co`001c?o00030000
oooooooo04Woool00ol0VOooooooo`0hoooo002?oooo0P0000Pco`000`000?ooooooo`19oooo00?o
09Woooooool0>?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`19oooo00?o09Wooooo
ool0>?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`19oooo00?o09Woooooool0>?oo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`19oooo00?o09Woooooool0>?ooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`1:oooo00?o09Woooooool0>?ooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`1:oooo00?o09Woooooool0>?ooo`00Soooo`800007<ol000<0
003oooooool0B_ooo`03o`2Ioooooooo03Soool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool0B_ooo`03o`2Ioooooooo03Soool008ooool00`0003?o03?o0006<ol000<0003oooooool0B_oo
o`03o`2Ioooooooo03Soool008ooool00`0003?o03?o0006<ol000<0003oooooool0B_ooo`03o`2I
oooooooo03Soool008ooool00`0003?o03?o0006<ol000<0003oooooool0B_ooo`03o`2Ioooooooo
03Soool008ooool00`0003?o03?o0006<ol000<0003oooooool0B_ooo`03o`2Ioooooooo03Soool0
08ooool200001S?o00030000oooooooo04_oool00ol0VOooooooo`0hoooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo04_oool00ol0VOooooooo`0hoooo002?oooo00<0000co`0co`001C?o
00030000oooooooo04_oool00ol0VOooooooo`0hoooo002?oooo00<0000co`0co`001C?o00030000
oooooooo04_oool00ol0VOooooooo`0hoooo002?oooo00<0000co`0co`001C?o00030000oooooooo
04_oool00ol0VOooooooo`0hoooo002?oooo00<0000co`0co`001C?o00030000oooooooo04_oool0
0ol0VOooooooo`0hoooo002?oooo0P0000Hco`000`000?ooooooo`1;oooo00?o09Woooooool0>?oo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1;oooo00?o09Woooooool0>?ooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`1;oooo00?o09Woooooool0>?ooo`00Soooo`030000
<ol0<ol000@co`000`000?ooooooo`1<oooo00?o09Woooooool0>?ooo`00Soooo`030000<ol0<ol0
00@co`000`000?ooooooo`1<oooo00?o09Woooooool0>?ooo`00ROooo`<00003oooo00<0000co`0c
o`0013?o00030000oooooooo04coool00ol0VOooooooo`0hoooo002:oooo00<0003oooooool00_oo
o`030000<ol0<ol000@co`000`000?ooooooo`1<oooo00?o09Woooooool0>?ooo`00Qoooo`D00003
oooo0`0000@co`000`000?ooooooo`1<oooo00?o09Woooooool0>?ooo`00Qoooo`040000oooooooo
00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7
<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?ooooooo`0Coooo1c?o
00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo00Woool7
<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`06oooo100000<co`02000000<co`3oooooool00_ooo`<000000oooo`000000000200000ooo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool00`000?ooooooo`07<ol01Oooo`040000oooooooo00001_ooo`030000
oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooo<ol0
00Hco`02oooo1@0000;oool00`000?ooooooo`04oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000>oooo00<0000co`0co`001C?o00;oool010000?ooooooo`0000Coool00`000?oo
ooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Hco`03oooo00<0003oool000000_ooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`04oooo0P0000?oool200000oooo`030000
oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.81909 .12361 L
.82924 .12361 L
.83479 .12361 L
.83749 .12361 L
.83996 .12361 L
.84105 .12361 L
.84223 .12361 L
s
.84223 .12361 m
.84268 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.13506 .12361 L
.14415 .12361 L
.14868 .12361 L
.15107 .12361 L
.1536 .12361 L
.15581 .12361 L
.15707 .12361 L
.15825 .12247 L
.16254 .11819 L
.18221 .10137 L
.20246 .08819 L
.22098 .07914 L
.23997 .07231 L
.25071 .06938 L
.26069 .06717 L
.27126 .06532 L
.28121 .06398 L
.29015 .06308 L
.29518 .06269 L
.29982 .0624 L
.30452 .06217 L
.3071 .06207 L
.30955 .06199 L
.31183 .06193 L
.31431 .06187 L
.3154 .06185 L
.31656 .06184 L
.31757 .06183 L
.31864 .06182 L
.31991 .06181 L
.32108 .0618 L
.32234 .0618 L
.32305 .0618 L
.32371 .06181 L
.32491 .06181 L
.32601 .06182 L
.32727 .06183 L
.32846 .06185 L
.33117 .06189 L
.33367 .06194 L
.33931 .0621 L
.34398 .06228 L
.349 .0625 L
.35807 .06301 L
.37871 .06456 L
.41999 .06882 L
Mistroke
.45975 .07371 L
.47982 .07629 L
.49799 .07865 L
.50287 .07926 L
.50815 .07977 L
.51057 .07996 L
.51313 .08012 L
.51552 .08025 L
.5177 .08034 L
.52021 .08043 L
.52158 .08046 L
.52288 .08049 L
.52409 .08051 L
.5252 .08053 L
.52642 .08054 L
.52771 .08054 L
.52901 .08054 L
.52974 .08054 L
.53041 .08054 L
.53164 .08053 L
.53293 .08051 L
.53436 .08049 L
.53568 .08046 L
.53869 .08038 L
.54375 .08019 L
.54924 .07992 L
.55919 .07925 L
.57779 .07753 L
.5977 .07514 L
.61876 .07213 L
.6567 .06575 L
.69709 .05802 L
.73597 .05003 L
.77729 .04142 L
.79797 .03726 L
.81711 .03364 L
.82668 .03194 L
.83567 .03044 L
.84018 .02972 L
.84141 .02953 L
.84272 .02933 L
.84383 .12361 L
.84505 .12361 L
.8554 .12361 L
.89593 .12361 L
.93495 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.44) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo05Coool00`1Vooooooooo`0goooo002?oooo00<0003ooooo
ool0Coooo`H0I_lioooo002?oooo00<0003oooooool0C?ooo`<0I_l5oooo00<0I_ooooooool0=ooo
o`00Soooo`030000oooooooo04Ooool506Ko2?ooo`0306Kooooooooo03Ooool008ooool00`000?oo
ooooo`11oooo1P1Vo`goool00`1Vooooooooo`0goooo002?oooo00<0003oooooool0??ooo`D0I_lC
oooo00<0I_ooooooool0=oooo`00Soooo`80000hoooo1@1VoaSoool00`1Vooooooooo`0goooo002?
oooo00<0003oooooool0<_ooo`D0I_lMoooo00<0I_ooooooool0=oooo`00Soooo`030000oooooooo
02goool506Ko8_ooo`0306Kooooooooo03Ooool005OooolL06Ko7?ooo`030000oooooooo02Soool5
06Ko9oooo`0306Kooooooooo03Ooool005;oool506Ko7?ooo`H0I_lFoooo00<0003oooooool08Ooo
o`L0I_l/oooo00<0I_ooooooool0=oooo`00C?ooo`H0I_lWoooo1`1Vo`ooool00`000?ooooooo`0I
oooo201Voc?oool00`1Vooooooooo`0goooo001:oooo0P1VocCoool<06Ko0oooo`80000Eoooo1@1V
oc_oool00`1Vooooooooo`0goooo000Goooo100002goool206Ko2_ooo`D0000coooo0`1Vo`030000
06Ko06Ko01@0I_lSoooo1@0001Soool00`1Vooooooooo`0Moooo100001Koool001Ooool00`000?oo
ooooo`0/oooo0P1Vo`koool00`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo
01Soool00`1Vooooooooo`0Moooo00<0003oooooool05oooo`006?ooo`030000oooooooo02Woool2
06Ko4?ooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool06?ooo`0306Ko
oooooooo01koool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Voooo0P1V
o`[oool400001?ooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool06?oo
o`0306Kooooooooo01ooool00`000?ooooooo`0Eoooo000Goooo00@0003oooooool0000Voooo00<0
I_ooooooool04_ooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool06?oo
o`0306Kooooooooo01goool010000?ooooooo`0001Koool001Soool200009Oooo`80I_lDoooo0P00
03Soool20000>Oooo`80000Joooo00<0I_ooooooool07_ooo`80000Goooo000noooo00<0I_oooooo
ool0C_ooo`030000oooooooo05Coool00`1Vooooooooo`0goooo000moooo00<0I_ooooooool0Cooo
o`030000oooooooo05Coool00`1Vooooooooo`0goooo000koooo0P1Voe;oool00`000?ooooooo`1D
oooo00<0I_ooooooool0=oooo`00>_ooo`0306Kooooooooo05;oool00`000?ooooooo`1Doooo00<0
I_ooooooool0=oooo`00>Oooo`0306Kooooooooo05?oool00`000?ooooooo`1Doooo00<0I_oooooo
ool0=oooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o018000000ol0V@000000000=
00001_ooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_oo
o`030000oooooooo03Woool00`0003?o03?o000i<ol02@0001;oool00ol0VOooooooo`0Ooooo00<0
003oooooool05Oooo`00Soooo`030000<ol0<ol003<co`0600006oooo`03o`2Ioooooooo03Ooool0
08ooool00`0003?o03?o000a<ol00P00027oool00ol0VOooooooo`0goooo002?oooo00<0000co`0c
o`00;c?o0080000Soooo00?o09Woooooool0=oooo`00Soooo`030000<ol0<ol002`co`0300009Ooo
o`03o`2Ioooooooo03Ooool008ooool20000:S?o00<0000Xoooo00?o09Woooooool0=oooo`00Sooo
o`030000<ol0<ol002Lco`020000:oooo`03o`2Ioooooooo03Ooool008ooool00`0003?o03?o000V
<ol000<0003oooooool0:oooo`03o`2Ioooooooo03Ooool008ooool00`0003?o03?o000U<ol000<0
003oooooool0;?ooo`03o`2Ioooooooo03Ooool008ooool00`0003?o03?o000T<ol000<0003ooooo
ool0;Oooo`03o`2Ioooooooo03Ooool008ooool00`0003?o03?o000R<ol00P00033oool00ol0VOoo
ooooo`0goooo002?oooo0P00028co`000`000?ooooooo`0`oooo00?o09Woooooool0=oooo`00Sooo
o`030000<ol0<ol0020co`000`000?ooooooo`0aoooo00?o09Woooooool0=oooo`00Soooo`030000
<ol0<ol001lco`000`000?ooooooo`0boooo00?o09Woooooool0=oooo`00Soooo`030000<ol0<ol0
01lco`000`000?ooooooo`0boooo00?o09Woooooool0=oooo`00Soooo`030000<ol0<ol001hco`00
0`000?ooooooo`0coooo00?o09Woooooool0=oooo`00Soooo`030000<ol0<ol001dco`000`000?oo
ooooo`0doooo00?o09Woooooool0=oooo`00Soooo`80000M<ol000<0003oooooool0=Oooo`03o`2I
oooooooo03Ooool008ooool00`0003?o03?o000K<ol000<0003oooooool0=_ooo`03o`2Ioooooooo
03Ooool008ooool00`0003?o03?o000K<ol000<0003oooooool0=_ooo`03o`2Ioooooooo03Ooool0
08ooool00`0003?o03?o000J<ol000<0003oooooool0=oooo`03o`2Ioooooooo03Ooool008ooool0
0`0003?o03?o000J<ol000<0003oooooool0=oooo`03o`2Ioooooooo03Ooool008ooool00`0003?o
03?o000I<ol000<0003oooooool0>?ooo`03o`2Ioooooooo03Ooool008ooool200006S?o00030000
oooooooo03Soool00ol0VOooooooo`0goooo002?oooo00<0000co`0co`0063?o00030000oooooooo
03Woool00ol0VOooooooo`0goooo002?oooo00<0000co`0co`0063?o00030000oooooooo03Woool0
0ol0VOooooooo`0goooo002?oooo00<0000co`0co`005c?o00030000oooooooo03[oool00ol0VOoo
ooooo`0goooo002?oooo00<0000co`0co`005c?o00030000oooooooo03[oool00ol0VOooooooo`0g
oooo0027oooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool0>oooo`03o`2Ioooooooo
03Ooool008Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo03_oool0
0ol0VOooooooo`0goooo0029oooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0??oo
o`03o`2Ioooooooo03Ooool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000
oooooooo03coool00ol0VOooooooo`0goooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`0loooo00?o09Woooooool0=oooo`00R?ooo`800005oooo00<0000co`0c
o`0053?o00030000oooooooo03goool00ol0VOooooooo`0goooo002?oooo00<0000co`0co`0053?o
00030000oooooooo03goool00ol0VOooooooo`0goooo002?oooo00<0000co`0co`004c?o00030000
oooooooo03koool00ol0VOooooooo`0goooo002?oooo0P0001@co`000`000?ooooooo`0noooo00?o
09Woooooool0=oooo`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`0noooo00?o09Wooooo
ool0=oooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0ooooo00?o09Woooooool0=ooo
o`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`0ooooo00?o09Woooooool0=oooo`00Sooo
o`030000<ol0<ol0018co`000`000?ooooooo`0ooooo00?o09Woooooool0=oooo`00Soooo`030000
<ol0<ol0014co`000`000?ooooooo`10oooo00?o09Woooooool0=oooo`00Soooo`80000B<ol000<0
003oooooool0@?ooo`03o`2Ioooooooo03Ooool008ooool00`0003?o03?o000A<ol000<0003ooooo
ool0@?ooo`03o`2Ioooooooo03Ooool008ooool00`0003?o03?o000A<ol000<0003oooooool0@?oo
o`03o`2Ioooooooo03Ooool008ooool00`0003?o03?o000@<ol000<0003oooooool0@Oooo`03o`2I
oooooooo03Ooool008ooool00`0003?o03?o000@<ol000<0003oooooool0@Oooo`03o`2Ioooooooo
03Ooool008ooool00`0003?o03?o000@<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Ooool0
08ooool00`0003?o03?o000@<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Ooool008ooool2
000043?o00030000oooooooo04;oool00ol0VOooooooo`0goooo002?oooo00<0000co`0co`003c?o
00030000oooooooo04;oool00ol0VOooooooo`0goooo002?oooo00<0000co`0co`003c?o00030000
oooooooo04;oool00ol0VOooooooo`0goooo002?oooo00<0000co`0co`003c?o00030000oooooooo
04;oool00ol0VOooooooo`0goooo002?oooo00<0000co`0co`003c?o00030000oooooooo04;oool0
0ol0VOooooooo`0goooo002?oooo00<0000co`0co`003S?o00030000oooooooo04?oool00ol0VOoo
ooooo`0goooo002?oooo0P0000lco`000`000?ooooooo`13oooo00?o09Woooooool0=oooo`00Sooo
o`030000<ol0<ol000hco`000`000?ooooooo`13oooo00?o09Woooooool0=oooo`00Soooo`030000
<ol0<ol000hco`000`000?ooooooo`13oooo00?o09Woooooool0=oooo`00Soooo`030000<ol0<ol0
00dco`000`000?ooooooo`14oooo00?o09Woooooool0=oooo`00Qoooo`@00004oooo00<0000co`0c
o`003C?o00030000oooooooo04Coool00ol0VOooooooo`0goooo0027oooo00<0003oooooool01Ooo
o`030000<ol0<ol000dco`000`000?ooooooo`14oooo00?o09Woooooool0=oooo`00R?ooo`030000
oooooooo00Coool300003C?o00030000oooooooo04Coool00ol0VOooooooo`0goooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`14oooo00?o09Woooooool0=ooo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`15oooo00?o
09Woooooool0=oooo`00R?ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo04Goool0
0ol0VOooooooo`0goooo002?oooo00<0000co`0co`0033?o00030000oooooooo04Goool00ol0VOoo
ooooo`0goooo002?oooo00<0000co`0co`0033?o00030000oooooooo04Goool00ol0VOooooooo`0g
oooo002?oooo0P0000dco`000`000?ooooooo`15oooo00?o09Woooooool0=oooo`00Soooo`030000
<ol0<ol000`co`000`000?ooooooo`15oooo00?o09Woooooool0=oooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`16oooo00?o09Woooooool0=oooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`16oooo00?o09Woooooool0=oooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`16oooo00?o09Woooooool0=oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`16
oooo00?o09Woooooool0=oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`16oooo00?o
09Woooooool0=oooo`00Soooo`80000<<ol000<0003oooooool0A_ooo`03o`2Ioooooooo03Ooool0
08ooool00`0003?o03?o000;<ol000<0003oooooool0A_ooo`03o`2Ioooooooo03Ooool008ooool0
0`0003?o03?o000:<ol000<0003oooooool0Aoooo`03o`2Ioooooooo03Ooool008ooool00`0003?o
03?o000:<ol000<0003oooooool0Aoooo`03o`2Ioooooooo03Ooool008ooool00`0003?o03?o000:
<ol000<0003oooooool0Aoooo`03o`2Ioooooooo03Ooool008ooool00`0003?o03?o000:<ol000<0
003oooooool0Aoooo`03o`2Ioooooooo03Ooool008ooool200002c?o00030000oooooooo04Ooool0
0ol0VOooooooo`0goooo002?oooo00<0000co`0co`002S?o00030000oooooooo04Ooool00ol0VOoo
ooooo`0goooo002?oooo00<0000co`0co`002S?o00030000oooooooo04Ooool00ol0VOooooooo`0g
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo04Soool00ol0VOooooooo`0goooo002?
oooo00<0000co`0co`002C?o00030000oooooooo04Soool00ol0VOooooooo`0goooo002?oooo00<0
000co`0co`002C?o00030000oooooooo04Soool00ol0VOooooooo`0goooo002?oooo0P0000Xco`00
0`000?ooooooo`18oooo00?o09Woooooool0=oooo`00Soooo`030000<ol0<ol000Tco`000`000?oo
ooooo`18oooo00?o09Woooooool0=oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`18
oooo00?o09Woooooool0=oooo`00Soooo`030000<ol0<ol000Pco`000`000?ooooooo`19oooo00?o
09Woooooool0=oooo`00R?ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo04Woool0
0ol0VOooooooo`0goooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000
oooooooo04Woool00ol0VOooooooo`0goooo0029oooo00<0003oooooool00oooo`<00008<ol000<0
003oooooool0BOooo`03o`2Ioooooooo03Ooool008[oool00`000?ooooooo`02oooo00<0000co`0c
o`0023?o00030000oooooooo04Woool00ol0VOooooooo`0goooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0023?o00030000oooooooo04Woool00ol0VOooooooo`0goooo0028oooo0P00
00Goool00`0003?o03?o0007<ol000<0003oooooool0B_ooo`03o`2Ioooooooo03Ooool008ooool0
0`0003?o03?o0007<ol000<0003oooooool0B_ooo`03o`2Ioooooooo03Ooool008ooool00`0003?o
03?o0007<ol000<0003oooooool0B_ooo`03o`2Ioooooooo03Ooool008ooool00`0003?o03?o0007
<ol000<0003oooooool0B_ooo`03o`2Ioooooooo03Ooool008ooool2000023?o00030000oooooooo
04[oool00ol0VOooooooo`0goooo002?oooo00<0000co`0co`001c?o00030000oooooooo04[oool0
0ol0VOooooooo`0goooo002?oooo00<0000co`0co`001c?o00030000oooooooo04[oool00ol0VOoo
ooooo`0goooo002?oooo00<0000co`0co`001c?o00030000oooooooo04[oool00ol0VOooooooo`0g
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo04_oool00ol0VOooooooo`0goooo002?
oooo00<0000co`0co`001S?o00030000oooooooo04_oool00ol0VOooooooo`0goooo002?oooo0P00
00Lco`000`000?ooooooo`1;oooo00?o09Woooooool0=oooo`00Soooo`030000<ol0<ol000Hco`00
0`000?ooooooo`1;oooo00?o09Woooooool0=oooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`1;oooo00?o09Woooooool0=oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1;
oooo00?o09Woooooool0=oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1;oooo00?o
09Woooooool0=oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1;oooo00?o09Wooooo
ool0=oooo`00Soooo`800006<ol000<0003oooooool0C?ooo`03o`2Ioooooooo03Ooool008ooool0
0`0003?o03?o0005<ol000<0003oooooool0C?ooo`03o`2Ioooooooo03Ooool008ooool00`0003?o
03?o0005<ol000<0003oooooool0C?ooo`03o`2Ioooooooo03Ooool008ooool00`0003?o03?o0005
<ol000<0003oooooool0C?ooo`03o`2Ioooooooo03Ooool008ooool00`0003?o03?o0005<ol000<0
003oooooool0C?ooo`03o`2Ioooooooo03Ooool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool0C?ooo`03o`2Ioooooooo03Ooool008ooool200001S?o00030000oooooooo04coool00ol0VOoo
ooooo`0goooo002?oooo00<0000co`0co`001C?o00030000oooooooo04coool00ol0VOooooooo`0g
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo04coool00ol0VOooooooo`0goooo002?
oooo00<0000co`0co`0013?o00030000oooooooo04goool00ol0VOooooooo`0goooo002?oooo00<0
000co`0co`0013?o00030000oooooooo04goool00ol0VOooooooo`0goooo0029oooo0`0000?oool0
0`0003?o03?o0004<ol000<0003oooooool0COooo`03o`2Ioooooooo03Ooool008[oool00`000?oo
ooooo`02oooo00<0000co`0co`0013?o00030000oooooooo04goool00ol0VOooooooo`0goooo0027
oooo1@0000?oool3000013?o00030000oooooooo04goool00ol0VOooooooo`0goooo0027oooo00@0
003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool2
00001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo
01?oool7<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool02Oooo`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool400000c?o008000000c?o0?ooooooo`02oooo0`0000?oool300000_oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool00`000?ooooooo`07<ol01Oooo`030000oooooooo00?oool01@000?oo
ooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?oo
oc?o0006<ol00_ooo`D000000oooo`000000000300000oooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500003_ooo`030000<ol0<ol000Dco`02oooo00@0003oooooool00002oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool0
10000?ooooooo`0000Hco`03oooo00<0003oool000000oooo`030000oooo000000?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007<ol01?ooo`800004oooo0P0000;oool0
0`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.81909 .12361 L
.82924 .12361 L
.83479 .12361 L
.83996 .12361 L
.84438 .12361 L
.84565 .12361 L
.84686 .12361 L
s
.84686 .12361 m
.84729 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.13506 .12361 L
.14415 .12361 L
.14868 .12361 L
.14993 .12361 L
.15124 .12361 L
.15237 .12361 L
.1536 .12235 L
.16254 .11371 L
.18221 .09793 L
.20162 .08605 L
.2225 .07663 L
.2326 .07312 L
.24363 .06996 L
.25417 .06753 L
.26372 .06576 L
.27385 .0643 L
.28339 .06326 L
.28864 .06282 L
.29347 .0625 L
.29877 .06221 L
.30164 .06209 L
.30437 .062 L
.30674 .06193 L
.30932 .06188 L
.31046 .06186 L
.31167 .06184 L
.3128 .06183 L
.31384 .06182 L
.31504 .06181 L
.31633 .0618 L
.31747 .0618 L
.31867 .06181 L
.31999 .06181 L
.32122 .06182 L
.32256 .06183 L
.324 .06185 L
.32637 .06189 L
.32894 .06194 L
.33361 .06207 L
.34234 .06241 L
.3518 .06292 L
.36221 .06362 L
.38326 .06541 L
.4236 .0698 L
.46242 .07466 L
.48217 .07722 L
Mistroke
.4926 .07857 L
.49832 .07931 L
.5037 .07996 L
.5089 .08045 L
.51164 .08065 L
.51452 .08082 L
.51696 .08093 L
.51963 .08103 L
.52081 .08107 L
.52206 .0811 L
.52316 .08112 L
.52433 .08114 L
.52561 .08116 L
.52679 .08117 L
.52807 .08117 L
.52879 .08117 L
.52947 .08117 L
.5307 .08117 L
.53182 .08116 L
.53305 .08114 L
.53434 .08112 L
.5366 .08108 L
.5387 .08102 L
.54346 .08085 L
.54852 .08061 L
.55401 .08029 L
.56395 .07955 L
.58255 .07773 L
.62353 .07219 L
.66298 .06549 L
.70092 .0582 L
.74131 .04989 L
.78019 .04178 L
.79998 .03779 L
.82152 .03369 L
.83154 .03191 L
.83703 .03098 L
.84219 .03014 L
.84432 .02981 L
.84548 .02963 L
.84656 .02946 L
.84774 .12361 L
.84903 .12361 L
.85128 .12361 L
.86133 .12361 L
.90034 .12361 L
.94181 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.46) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`1@oooo1P1VocSoool0
08ooool00`000?ooooooo`1<oooo101Vo`Goool00`1Vooooooooo`0foooo002?oooo00<0003ooooo
ool0Aoooo`D0I_l9oooo00<0I_ooooooool0=_ooo`00Soooo`030000oooooooo04;oool506Ko3_oo
o`0306Kooooooooo03Koool008ooool00`000?ooooooo`0moooo1@1Voa?oool00`1Vooooooooo`0f
oooo002?oooo0P0003Woool506Ko6?ooo`0306Kooooooooo03Koool008ooool00`000?ooooooo`0c
oooo1@1Voagoool00`1Vooooooooo`0foooo002?oooo00<0003oooooool0;_ooo`D0I_lRoooo00<0
I_ooooooool0=_ooo`00EOoooaX0I_lPoooo00<0003oooooool0:Oooo`D0I_lWoooo00<0I_oooooo
ool0=_ooo`00D?ooo`D0I_lJoooo201VoaSoool00`000?ooooooo`0Roooo1`1Vobcoool00`1Voooo
ooooo`0foooo001=oooo0`1VobOoool:06Ko3_ooo`030000oooooooo01[oool806Ko<oooo`0306Ko
oooooooo03Koool004Woool406Ko=?ooo`L0I_l7oooo0P0001Koool506Ko>oooo`0306Kooooooooo
03Koool001Ooool40000;?ooo`80I_l;oooo1@0002ooool706Ko00<00000I_l0I_l02oooo`X0I_lR
oooo1@0001Woool00`1Vooooooooo`0Loooo100001Koool001Ooool00`000?ooooooo`0[oooo0P1V
o`ooool00`000?ooooooo`0foooo00<0003oooooool02`1Vobkoool00`000?ooooooo`0Ioooo00<0
I_ooooooool07?ooo`030000oooooooo01Ooool001Soool00`000?ooooooo`0Xoooo0P1Voa7oool0
0`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo01Woool00`1Vooooooooo`0M
oooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool09Oooo`80I_l;oooo1000
00Coool00`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo01Woool00`1Voooo
ooooo`0Noooo00<0003oooooool05Oooo`005oooo`040000oooooooo00009?ooo`80I_lEoooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0Ioooo00<0I_ooooooool07?oo
o`040000oooooooo00005_ooo`006?ooo`80000Toooo00<0I_ooooooool05?ooo`80000hoooo0P00
03Woool200006oooo`0306Kooooooooo01goool200005oooo`00?Oooo`0306Kooooooooo04ooool0
0`000?ooooooo`1Eoooo00<0I_ooooooool0=_ooo`00>oooo`80I_mBoooo00<0003oooooool0EOoo
o`0306Kooooooooo03Koool003[oool00`1Vooooooooo`1Boooo00<0003oooooool0EOooo`0306Ko
oooooooo03Koool003Woool00`1Vooooooooo`1Coooo00<0003oooooool0EOooo`0306Kooooooooo
03Koool003Soool00`1Vooooooooo`1Doooo00<0003oooooool0EOooo`0306Kooooooooo03Koool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0C000000?o09T000000000300000Koool0
0`000?ooooooo`09oooo00<0003oooooool05Oooo`005_ooo`030000oooooooo03[oool00`000?oo
ooooo`0ioooo00<0000co`0co`00>C?o00T0000Coooo00?o09Woooooool07_ooo`030000oooooooo
01Goool008ooool00`0003?o03?o000c<ol01P0001coool00ol0VOooooooo`0foooo002?oooo00<0
000co`0co`00<C?o0080000Roooo00?o09Woooooool0=_ooo`00Soooo`030000<ol0<ol002lco`02
00009?ooo`03o`2Ioooooooo03Koool008ooool00`0003?o03?o000/<ol00`0002Koool00ol0VOoo
ooooo`0foooo002?oooo0P0002Xco`030000:Oooo`03o`2Ioooooooo03Koool008ooool00`0003?o
03?o000W<ol00P0002coool00ol0VOooooooo`0foooo002?oooo00<0000co`0co`009S?o00030000
oooooooo02coool00ol0VOooooooo`0foooo002?oooo00<0000co`0co`009C?o00030000oooooooo
02goool00ol0VOooooooo`0foooo002?oooo00<0000co`0co`0093?o00030000oooooooo02koool0
0ol0VOooooooo`0foooo002?oooo00<0000co`0co`008S?o0080000aoooo00?o09Woooooool0=_oo
o`00Soooo`80000R<ol000<0003oooooool0<Oooo`03o`2Ioooooooo03Koool008ooool00`0003?o
03?o000P<ol000<0003oooooool0<_ooo`03o`2Ioooooooo03Koool008ooool00`0003?o03?o000O
<ol000<0003oooooool0<oooo`03o`2Ioooooooo03Koool008ooool00`0003?o03?o000O<ol000<0
003oooooool0<oooo`03o`2Ioooooooo03Koool008ooool00`0003?o03?o000N<ol000<0003ooooo
ool0=?ooo`03o`2Ioooooooo03Koool008ooool00`0003?o03?o000M<ol000<0003oooooool0=Ooo
o`03o`2Ioooooooo03Koool008ooool200007C?o00030000oooooooo03Koool00ol0VOooooooo`0f
oooo002?oooo00<0000co`0co`006c?o00030000oooooooo03Ooool00ol0VOooooooo`0foooo002?
oooo00<0000co`0co`006c?o00030000oooooooo03Ooool00ol0VOooooooo`0foooo002?oooo00<0
000co`0co`006S?o00030000oooooooo03Soool00ol0VOooooooo`0foooo002?oooo00<0000co`0c
o`006S?o00030000oooooooo03Soool00ol0VOooooooo`0foooo002?oooo00<0000co`0co`006C?o
00030000oooooooo03Woool00ol0VOooooooo`0foooo002?oooo0P0001Xco`000`000?ooooooo`0i
oooo00?o09Woooooool0=_ooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0joooo00?o
09Woooooool0=_ooo`00Soooo`030000<ol0<ol001Pco`000`000?ooooooo`0joooo00?o09Wooooo
ool0=_ooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0koooo00?o09Woooooool0=_oo
o`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`0koooo00?o09Woooooool0=_ooo`00Qooo
o`D00003oooo00<0000co`0co`005S?o00030000oooooooo03coool00ol0VOooooooo`0foooo0029
oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`000`000?ooooooo`0loooo00?o09Wooooo
ool0=_ooo`00ROooo`030000oooooooo00?oool300005C?o00030000oooooooo03goool00ol0VOoo
ooooo`0foooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`0m
oooo00?o09Woooooool0=_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E<ol000<0
003oooooool0?Oooo`03o`2Ioooooooo03Koool008Soool200001Oooo`030000<ol0<ol001@co`00
0`000?ooooooo`0noooo00?o09Woooooool0=_ooo`00Soooo`030000<ol0<ol001@co`000`000?oo
ooooo`0noooo00?o09Woooooool0=_ooo`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`0o
oooo00?o09Woooooool0=_ooo`00Soooo`80000D<ol000<0003oooooool0?oooo`03o`2Ioooooooo
03Koool008ooool00`0003?o03?o000C<ol000<0003oooooool0?oooo`03o`2Ioooooooo03Koool0
08ooool00`0003?o03?o000B<ol000<0003oooooool0@?ooo`03o`2Ioooooooo03Koool008ooool0
0`0003?o03?o000B<ol000<0003oooooool0@?ooo`03o`2Ioooooooo03Koool008ooool00`0003?o
03?o000B<ol000<0003oooooool0@?ooo`03o`2Ioooooooo03Koool008ooool00`0003?o03?o000A
<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Koool008ooool200004S?o00030000oooooooo
047oool00ol0VOooooooo`0foooo002?oooo00<0000co`0co`004C?o00030000oooooooo047oool0
0ol0VOooooooo`0foooo002?oooo00<0000co`0co`004C?o00030000oooooooo047oool00ol0VOoo
ooooo`0foooo002?oooo00<0000co`0co`0043?o00030000oooooooo04;oool00ol0VOooooooo`0f
oooo002?oooo00<0000co`0co`0043?o00030000oooooooo04;oool00ol0VOooooooo`0foooo002?
oooo00<0000co`0co`0043?o00030000oooooooo04;oool00ol0VOooooooo`0foooo002?oooo00<0
000co`0co`0043?o00030000oooooooo04;oool00ol0VOooooooo`0foooo002?oooo0P00010co`00
0`000?ooooooo`13oooo00?o09Woooooool0=_ooo`00Soooo`030000<ol0<ol000lco`000`000?oo
ooooo`13oooo00?o09Woooooool0=_ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`13
oooo00?o09Woooooool0=_ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`13oooo00?o
09Woooooool0=_ooo`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`13oooo00?o09Wooooo
ool0=_ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`14oooo00?o09Woooooool0=_oo
o`00Soooo`80000?<ol000<0003oooooool0A?ooo`03o`2Ioooooooo03Koool008ooool00`0003?o
03?o000><ol000<0003oooooool0A?ooo`03o`2Ioooooooo03Koool008ooool00`0003?o03?o000>
<ol000<0003oooooool0A?ooo`03o`2Ioooooooo03Koool008ooool00`0003?o03?o000=<ol000<0
003oooooool0AOooo`03o`2Ioooooooo03Koool008Ooool400001?ooo`030000<ol0<ol000dco`00
0`000?ooooooo`15oooo00?o09Woooooool0=_ooo`00Qoooo`030000oooooooo00Goool00`0003?o
03?o000=<ol000<0003oooooool0AOooo`03o`2Ioooooooo03Koool008Soool00`000?ooooooo`04
oooo0`0000dco`000`000?ooooooo`15oooo00?o09Woooooool0=_ooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000=<ol000<0003oooooool0AOooo`03o`2Ioooooooo03Koool008Ooool0
10000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0003oooooool0A_ooo`03o`2Ioooooooo
03Koool008Soool200001Oooo`030000<ol0<ol000`co`000`000?ooooooo`16oooo00?o09Wooooo
ool0=_ooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`16oooo00?o09Woooooool0=_oo
o`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`16oooo00?o09Woooooool0=_ooo`00Sooo
o`80000=<ol000<0003oooooool0A_ooo`03o`2Ioooooooo03Koool008ooool00`0003?o03?o000<
<ol000<0003oooooool0A_ooo`03o`2Ioooooooo03Koool008ooool00`0003?o03?o000;<ol000<0
003oooooool0Aoooo`03o`2Ioooooooo03Koool008ooool00`0003?o03?o000;<ol000<0003ooooo
ool0Aoooo`03o`2Ioooooooo03Koool008ooool00`0003?o03?o000;<ol000<0003oooooool0Aooo
o`03o`2Ioooooooo03Koool008ooool00`0003?o03?o000;<ol000<0003oooooool0Aoooo`03o`2I
oooooooo03Koool008ooool00`0003?o03?o000;<ol000<0003oooooool0Aoooo`03o`2Ioooooooo
03Koool008ooool2000033?o00030000oooooooo04Ooool00ol0VOooooooo`0foooo002?oooo00<0
000co`0co`002c?o00030000oooooooo04Ooool00ol0VOooooooo`0foooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo04Soool00ol0VOooooooo`0foooo002?oooo00<0000co`0co`002S?o
00030000oooooooo04Soool00ol0VOooooooo`0foooo002?oooo00<0000co`0co`002S?o00030000
oooooooo04Soool00ol0VOooooooo`0foooo002?oooo00<0000co`0co`002S?o00030000oooooooo
04Soool00ol0VOooooooo`0foooo002?oooo0P0000/co`000`000?ooooooo`18oooo00?o09Wooooo
ool0=_ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`18oooo00?o09Woooooool0=_oo
o`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`18oooo00?o09Woooooool0=_ooo`00Sooo
o`030000<ol0<ol000Tco`000`000?ooooooo`19oooo00?o09Woooooool0=_ooo`00Soooo`030000
<ol0<ol000Tco`000`000?ooooooo`19oooo00?o09Woooooool0=_ooo`00Soooo`030000<ol0<ol0
00Tco`000`000?ooooooo`19oooo00?o09Woooooool0=_ooo`00Soooo`80000:<ol000<0003ooooo
ool0BOooo`03o`2Ioooooooo03Koool008ooool00`0003?o03?o0009<ol000<0003oooooool0BOoo
o`03o`2Ioooooooo03Koool008ooool00`0003?o03?o0009<ol000<0003oooooool0BOooo`03o`2I
oooooooo03Koool008ooool00`0003?o03?o0008<ol000<0003oooooool0B_ooo`03o`2Ioooooooo
03Koool008Soool200001Oooo`030000<ol0<ol000Pco`000`000?ooooooo`1:oooo00?o09Wooooo
ool0=_ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`1:
oooo00?o09Woooooool0=_ooo`00ROooo`030000oooooooo00?oool3000023?o00030000oooooooo
04[oool00ol0VOooooooo`0foooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000Pco`00
0`000?ooooooo`1:oooo00?o09Woooooool0=_ooo`00Qoooo`040000oooooooo00001?ooo`030000
<ol0<ol000Pco`000`000?ooooooo`1:oooo00?o09Woooooool0=_ooo`00R?ooo`800005oooo00<0
000co`0co`001c?o00030000oooooooo04_oool00ol0VOooooooo`0foooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo04_oool00ol0VOooooooo`0foooo002?oooo00<0000co`0co`001c?o
00030000oooooooo04_oool00ol0VOooooooo`0foooo002?oooo00<0000co`0co`001c?o00030000
oooooooo04_oool00ol0VOooooooo`0foooo002?oooo0P0000Pco`000`000?ooooooo`1;oooo00?o
09Woooooool0=_ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1;oooo00?o09Wooooo
ool0=_ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1;oooo00?o09Woooooool0=_oo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1;oooo00?o09Woooooool0=_ooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`1<oooo00?o09Woooooool0=_ooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`1<oooo00?o09Woooooool0=_ooo`00Soooo`800007<ol000<0
003oooooool0C?ooo`03o`2Ioooooooo03Koool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool0C?ooo`03o`2Ioooooooo03Koool008ooool00`0003?o03?o0006<ol000<0003oooooool0C?oo
o`03o`2Ioooooooo03Koool008ooool00`0003?o03?o0006<ol000<0003oooooool0C?ooo`03o`2I
oooooooo03Koool008ooool00`0003?o03?o0006<ol000<0003oooooool0C?ooo`03o`2Ioooooooo
03Koool008ooool00`0003?o03?o0006<ol000<0003oooooool0C?ooo`03o`2Ioooooooo03Koool0
08ooool200001S?o00030000oooooooo04goool00ol0VOooooooo`0foooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo04goool00ol0VOooooooo`0foooo002?oooo00<0000co`0co`001C?o
00030000oooooooo04goool00ol0VOooooooo`0foooo002?oooo00<0000co`0co`001C?o00030000
oooooooo04goool00ol0VOooooooo`0foooo002?oooo00<0000co`0co`001C?o00030000oooooooo
04goool00ol0VOooooooo`0foooo002?oooo00<0000co`0co`001C?o00030000oooooooo04goool0
0ol0VOooooooo`0foooo002?oooo0P0000Hco`000`000?ooooooo`1=oooo00?o09Woooooool0=_oo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1=oooo00?o09Woooooool0=_ooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`1=oooo00?o09Woooooool0=_ooo`00Soooo`030000
<ol0<ol000@co`000`000?ooooooo`1>oooo00?o09Woooooool0=_ooo`00Soooo`030000<ol0<ol0
00@co`000`000?ooooooo`1>oooo00?o09Woooooool0=_ooo`00ROooo`<00003oooo00<0000co`0c
o`0013?o00030000oooooooo04koool00ol0VOooooooo`0foooo002:oooo00<0003oooooool00_oo
o`030000<ol0<ol000@co`000`000?ooooooo`1>oooo00?o09Woooooool0=_ooo`00Qoooo`D00003
oooo0`0000@co`000`000?ooooooo`1>oooo00?o09Woooooool0=_ooo`00Qoooo`040000oooooooo
00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?ooo`Lco`2:oooo0029oooo0P0000Coool7
<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool007Woool00`000?ooooooo`0Coooo1c?o
00koool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo00Woool7
<ol03oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`06oooo100000<co`02000000<co`3oooooool00_ooo`<000001?ooo`000000000000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00<0003oooooool01c?o00Goool010000?ooooooo`0000;oool01@000?oo
ooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?oo
oc?o0006<ol00_ooo`D000001Oooo`000?ooooooo`000004oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000>oooo00<0000co`0co`001C?o00;oool010000?ooooooo`0000;oool3
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00006<ol00oooo`030000oooo000000?oool00`000?ooooooo`03oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo017oool200001c?o00Coool200000oooo`<00002oooo00<0003ooooo
ool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.81909 .12361 L
.82924 .12361 L
.83996 .12361 L
.84438 .12361 L
.84911 .12361 L
.85051 .12361 L
.85183 .12361 L
s
.85183 .12361 m
.85231 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.12507 .12361 L
.13506 .12361 L
.13979 .12361 L
.14415 .12361 L
.14635 .12361 L
.14746 .12361 L
.14868 .12251 L
.1536 .11762 L
.16254 .1095 L
.18221 .0947 L
.20162 .08362 L
.2225 .0749 L
.2326 .07167 L
.24363 .06879 L
.25417 .0666 L
.26372 .06502 L
.27385 .06374 L
.28339 .06286 L
.28864 .0625 L
.29347 .06224 L
.29877 .06203 L
.30144 .06195 L
.30437 .06188 L
.30688 .06184 L
.30829 .06182 L
.30961 .06181 L
.31075 .06181 L
.31201 .0618 L
.31333 .0618 L
.31457 .06181 L
.31571 .06181 L
.31691 .06182 L
.31793 .06183 L
.31905 .06185 L
.32155 .06189 L
.32388 .06193 L
.32917 .06208 L
.33399 .06226 L
.34479 .06279 L
.36397 .06413 L
.38477 .06602 L
.42569 .07063 L
.46509 .07562 L
.48489 .07819 L
.49355 .07931 L
.50298 .0805 L
.50816 .081 L
Mistroke
.51296 .08134 L
.51754 .08157 L
.52011 .08167 L
.52243 .08173 L
.52374 .08175 L
.52512 .08177 L
.52631 .08179 L
.5276 .08179 L
.52833 .0818 L
.529 .0818 L
.52977 .0818 L
.5305 .08179 L
.53179 .08179 L
.53252 .08178 L
.53319 .08177 L
.53553 .08173 L
.53686 .0817 L
.53811 .08167 L
.54332 .0815 L
.54803 .08129 L
.55318 .081 L
.56354 .08026 L
.58206 .07849 L
.62267 .07312 L
.66177 .06659 L
.70332 .05866 L
.74335 .05045 L
.78187 .0424 L
.8014 .03844 L
.82284 .03431 L
.83268 .03253 L
.8381 .03159 L
.84324 .03073 L
.84801 .02997 L
.84932 .02976 L
.85071 .02954 L
.8519 .02936 L
.85321 .12361 L
.85438 .12361 L
.85546 .12361 L
.85789 .12361 L
.8623 .12361 L
.90189 .12361 L
.93997 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.48) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`1Aoooo1P1VocOoool0
08ooool00`000?ooooooo`1=oooo101Vo`Goool00`1Vooooooooo`0eoooo002?oooo00<0003ooooo
ool0Aoooo`H0I_l9oooo00<0I_ooooooool0=Oooo`00Soooo`030000oooooooo04;oool506Ko3ooo
o`0306Kooooooooo03Goool008ooool00`000?ooooooo`0noooo101VoaCoool00`1Vooooooooo`0e
oooo002?oooo0P0003[oool506Ko6?ooo`0306Kooooooooo03Goool008ooool00`000?ooooooo`0d
oooo1@1Voagoool00`1Vooooooooo`0eoooo002?oooo00<0003oooooool0;oooo`D0I_lRoooo00<0
I_ooooooool0=Oooo`00EOoooaX0I_lPoooo00<0003oooooool0:Oooo`H0I_lWoooo00<0I_oooooo
ool0=Oooo`00D?ooo`D0I_lJoooo201VoaSoool00`000?ooooooo`0Toooo1@1Vobgoool00`1Voooo
ooooo`0eoooo001;oooo1@1VobOoool:06Ko3_ooo`030000oooooooo01ooool506Ko<_ooo`0306Ko
oooooooo03Goool004Soool306Ko=_ooo`P0I_l6oooo0P0001Woool706Ko=oooo`0306Kooooooooo
03Goool001Ooool40000:_ooo`<0I_l<oooo1@00033oool606Ko00<00000I_ooool03?ooo``0I_lO
oooo1@0001_oool00`1Vooooooooo`0Joooo100001Koool001Ooool00`000?ooooooo`0Yoooo0P1V
oa7oool00`000?ooooooo`0foooo00<0003oool0I_l0301Vobgoool00`000?ooooooo`0Koooo00<0
I_ooooooool06_ooo`030000oooooooo01Ooool001Soool00`000?ooooooo`0Voooo0P1Voa?oool0
0`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo01_oool00`1Vooooooooo`0K
oooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool08oooo`80I_l=oooo1000
00Coool00`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo01_oool00`1Voooo
ooooo`0Loooo00<0003oooooool05Oooo`005oooo`040000oooooooo00008oooo`0306Kooooooooo
01Goool00`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo01_oool00`1Voooo
ooooo`0Joooo00@0003oooooool0000Foooo000Hoooo0P0002?oool00`1Vooooooooo`0Eoooo0P00
03Soool20000>Oooo`80000Moooo00<0I_ooooooool06oooo`80000Goooo000koooo0P1Voe;oool0
0`000?ooooooo`1Goooo00<0I_ooooooool0=?ooo`00>_ooo`0306Kooooooooo05;oool00`000?oo
ooooo`1Goooo00<0I_ooooooool0=?ooo`00>Oooo`0306Kooooooooo05?oool00`000?ooooooo`1G
oooo00<0I_ooooooool0=?ooo`00>?ooo`0306Kooooooooo05Coool00`000?ooooooo`1Goooo00<0
I_ooooooool0=?ooo`00=oooo`0306Kooooooooo05Goool00`000?ooooooo`1Goooo00<0I_oooooo
ool0=?ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o01@000000ol0V@000000000;
00001_ooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_oo
o`030000oooooooo03Woool00`0003?o03?o000i<ol02@0001Coool00ol0VOooooooo`0Moooo00<0
003oooooool05Oooo`00Soooo`030000<ol0<ol003<co`0600007Oooo`03o`2Ioooooooo03Goool0
08ooool00`0003?o03?o000a<ol00P0002?oool00ol0VOooooooo`0eoooo002?oooo00<0000co`0c
o`00;c?o0080000Uoooo00?o09Woooooool0=Oooo`00Soooo`030000<ol0<ol002`co`0300009ooo
o`03o`2Ioooooooo03Goool008ooool20000:S?o00<0000Zoooo00?o09Woooooool0=Oooo`00Sooo
o`030000<ol0<ol002Lco`020000;Oooo`03o`2Ioooooooo03Goool008ooool00`0003?o03?o000V
<ol000<0003oooooool0;Oooo`03o`2Ioooooooo03Goool008ooool00`0003?o03?o000U<ol000<0
003oooooool0;_ooo`03o`2Ioooooooo03Goool008ooool00`0003?o03?o000T<ol000<0003ooooo
ool0;oooo`03o`2Ioooooooo03Goool008ooool00`0003?o03?o000R<ol00P0003;oool00ol0VOoo
ooooo`0eoooo002?oooo0P00028co`000`000?ooooooo`0boooo00?o09Woooooool0=Oooo`00Sooo
o`030000<ol0<ol0020co`000`000?ooooooo`0coooo00?o09Woooooool0=Oooo`00Soooo`030000
<ol0<ol001lco`000`000?ooooooo`0doooo00?o09Woooooool0=Oooo`00Soooo`030000<ol0<ol0
01lco`000`000?ooooooo`0doooo00?o09Woooooool0=Oooo`00Soooo`030000<ol0<ol001hco`00
0`000?ooooooo`0eoooo00?o09Woooooool0=Oooo`00Soooo`030000<ol0<ol001dco`000`000?oo
ooooo`0foooo00?o09Woooooool0=Oooo`00Soooo`80000M<ol000<0003oooooool0=oooo`03o`2I
oooooooo03Goool008ooool00`0003?o03?o000K<ol000<0003oooooool0>?ooo`03o`2Ioooooooo
03Goool008ooool00`0003?o03?o000K<ol000<0003oooooool0>?ooo`03o`2Ioooooooo03Goool0
08ooool00`0003?o03?o000J<ol000<0003oooooool0>Oooo`03o`2Ioooooooo03Goool008ooool0
0`0003?o03?o000J<ol000<0003oooooool0>Oooo`03o`2Ioooooooo03Goool008ooool00`0003?o
03?o000I<ol000<0003oooooool0>_ooo`03o`2Ioooooooo03Goool008ooool200006S?o00030000
oooooooo03[oool00ol0VOooooooo`0eoooo002?oooo00<0000co`0co`0063?o00030000oooooooo
03_oool00ol0VOooooooo`0eoooo002?oooo00<0000co`0co`0063?o00030000oooooooo03_oool0
0ol0VOooooooo`0eoooo002?oooo00<0000co`0co`005c?o00030000oooooooo03coool00ol0VOoo
ooooo`0eoooo002?oooo00<0000co`0co`005c?o00030000oooooooo03coool00ol0VOooooooo`0e
oooo0027oooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool0?Oooo`03o`2Ioooooooo
03Goool008Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo03goool0
0ol0VOooooooo`0eoooo0029oooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0?_oo
o`03o`2Ioooooooo03Goool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000
oooooooo03koool00ol0VOooooooo`0eoooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`0noooo00?o09Woooooool0=Oooo`00R?ooo`800005oooo00<0000co`0c
o`0053?o00030000oooooooo03ooool00ol0VOooooooo`0eoooo002?oooo00<0000co`0co`0053?o
00030000oooooooo03ooool00ol0VOooooooo`0eoooo002?oooo00<0000co`0co`004c?o00030000
oooooooo043oool00ol0VOooooooo`0eoooo002?oooo0P0001@co`000`000?ooooooo`10oooo00?o
09Woooooool0=Oooo`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`10oooo00?o09Wooooo
ool0=Oooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`11oooo00?o09Woooooool0=Ooo
o`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`11oooo00?o09Woooooool0=Oooo`00Sooo
o`030000<ol0<ol0018co`000`000?ooooooo`11oooo00?o09Woooooool0=Oooo`00Soooo`030000
<ol0<ol0014co`000`000?ooooooo`12oooo00?o09Woooooool0=Oooo`00Soooo`80000B<ol000<0
003oooooool0@_ooo`03o`2Ioooooooo03Goool008ooool00`0003?o03?o000A<ol000<0003ooooo
ool0@_ooo`03o`2Ioooooooo03Goool008ooool00`0003?o03?o000A<ol000<0003oooooool0@_oo
o`03o`2Ioooooooo03Goool008ooool00`0003?o03?o000@<ol000<0003oooooool0@oooo`03o`2I
oooooooo03Goool008ooool00`0003?o03?o000@<ol000<0003oooooool0@oooo`03o`2Ioooooooo
03Goool008ooool00`0003?o03?o000@<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Goool0
08ooool00`0003?o03?o000@<ol000<0003oooooool0@oooo`03o`2Ioooooooo03Goool008ooool2
000043?o00030000oooooooo04Coool00ol0VOooooooo`0eoooo002?oooo00<0000co`0co`003c?o
00030000oooooooo04Coool00ol0VOooooooo`0eoooo002?oooo00<0000co`0co`003c?o00030000
oooooooo04Coool00ol0VOooooooo`0eoooo002?oooo00<0000co`0co`003c?o00030000oooooooo
04Coool00ol0VOooooooo`0eoooo002?oooo00<0000co`0co`003c?o00030000oooooooo04Coool0
0ol0VOooooooo`0eoooo002?oooo00<0000co`0co`003S?o00030000oooooooo04Goool00ol0VOoo
ooooo`0eoooo002?oooo0P0000lco`000`000?ooooooo`15oooo00?o09Woooooool0=Oooo`00Sooo
o`030000<ol0<ol000hco`000`000?ooooooo`15oooo00?o09Woooooool0=Oooo`00Soooo`030000
<ol0<ol000hco`000`000?ooooooo`15oooo00?o09Woooooool0=Oooo`00Soooo`030000<ol0<ol0
00dco`000`000?ooooooo`16oooo00?o09Woooooool0=Oooo`00Qoooo`@00004oooo00<0000co`0c
o`003C?o00030000oooooooo04Koool00ol0VOooooooo`0eoooo0027oooo00<0003oooooool01Ooo
o`030000<ol0<ol000dco`000`000?ooooooo`16oooo00?o09Woooooool0=Oooo`00R?ooo`030000
oooooooo00Coool300003C?o00030000oooooooo04Koool00ol0VOooooooo`0eoooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`16oooo00?o09Woooooool0=Ooo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`17oooo00?o
09Woooooool0=Oooo`00R?ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo04Ooool0
0ol0VOooooooo`0eoooo002?oooo00<0000co`0co`0033?o00030000oooooooo04Ooool00ol0VOoo
ooooo`0eoooo002?oooo00<0000co`0co`0033?o00030000oooooooo04Ooool00ol0VOooooooo`0e
oooo002?oooo0P0000dco`000`000?ooooooo`17oooo00?o09Woooooool0=Oooo`00Soooo`030000
<ol0<ol000`co`000`000?ooooooo`17oooo00?o09Woooooool0=Oooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`18oooo00?o09Woooooool0=Oooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`18oooo00?o09Woooooool0=Oooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`18oooo00?o09Woooooool0=Oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`18
oooo00?o09Woooooool0=Oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`18oooo00?o
09Woooooool0=Oooo`00Soooo`80000<<ol000<0003oooooool0B?ooo`03o`2Ioooooooo03Goool0
08ooool00`0003?o03?o000;<ol000<0003oooooool0B?ooo`03o`2Ioooooooo03Goool008ooool0
0`0003?o03?o000:<ol000<0003oooooool0BOooo`03o`2Ioooooooo03Goool008ooool00`0003?o
03?o000:<ol000<0003oooooool0BOooo`03o`2Ioooooooo03Goool008ooool00`0003?o03?o000:
<ol000<0003oooooool0BOooo`03o`2Ioooooooo03Goool008ooool00`0003?o03?o000:<ol000<0
003oooooool0BOooo`03o`2Ioooooooo03Goool008ooool200002c?o00030000oooooooo04Woool0
0ol0VOooooooo`0eoooo002?oooo00<0000co`0co`002S?o00030000oooooooo04Woool00ol0VOoo
ooooo`0eoooo002?oooo00<0000co`0co`002S?o00030000oooooooo04Woool00ol0VOooooooo`0e
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo04[oool00ol0VOooooooo`0eoooo002?
oooo00<0000co`0co`002C?o00030000oooooooo04[oool00ol0VOooooooo`0eoooo002?oooo00<0
000co`0co`002C?o00030000oooooooo04[oool00ol0VOooooooo`0eoooo002?oooo0P0000Xco`00
0`000?ooooooo`1:oooo00?o09Woooooool0=Oooo`00Soooo`030000<ol0<ol000Tco`000`000?oo
ooooo`1:oooo00?o09Woooooool0=Oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1:
oooo00?o09Woooooool0=Oooo`00Soooo`030000<ol0<ol000Pco`000`000?ooooooo`1;oooo00?o
09Woooooool0=Oooo`00R?ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo04_oool0
0ol0VOooooooo`0eoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000
oooooooo04_oool00ol0VOooooooo`0eoooo0029oooo00<0003oooooool00oooo`<00008<ol000<0
003oooooool0Boooo`03o`2Ioooooooo03Goool008[oool00`000?ooooooo`02oooo00<0000co`0c
o`0023?o00030000oooooooo04_oool00ol0VOooooooo`0eoooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0023?o00030000oooooooo04_oool00ol0VOooooooo`0eoooo0028oooo0P00
00Goool00`0003?o03?o0007<ol000<0003oooooool0C?ooo`03o`2Ioooooooo03Goool008ooool0
0`0003?o03?o0007<ol000<0003oooooool0C?ooo`03o`2Ioooooooo03Goool008ooool00`0003?o
03?o0007<ol000<0003oooooool0C?ooo`03o`2Ioooooooo03Goool008ooool00`0003?o03?o0007
<ol000<0003oooooool0C?ooo`03o`2Ioooooooo03Goool008ooool2000023?o00030000oooooooo
04coool00ol0VOooooooo`0eoooo002?oooo00<0000co`0co`001c?o00030000oooooooo04coool0
0ol0VOooooooo`0eoooo002?oooo00<0000co`0co`001c?o00030000oooooooo04coool00ol0VOoo
ooooo`0eoooo002?oooo00<0000co`0co`001c?o00030000oooooooo04coool00ol0VOooooooo`0e
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo04goool00ol0VOooooooo`0eoooo002?
oooo00<0000co`0co`001S?o00030000oooooooo04goool00ol0VOooooooo`0eoooo002?oooo0P00
00Lco`000`000?ooooooo`1=oooo00?o09Woooooool0=Oooo`00Soooo`030000<ol0<ol000Hco`00
0`000?ooooooo`1=oooo00?o09Woooooool0=Oooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`1=oooo00?o09Woooooool0=Oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1=
oooo00?o09Woooooool0=Oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1=oooo00?o
09Woooooool0=Oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1=oooo00?o09Wooooo
ool0=Oooo`00Soooo`800006<ol000<0003oooooool0C_ooo`03o`2Ioooooooo03Goool008ooool0
0`0003?o03?o0005<ol000<0003oooooool0C_ooo`03o`2Ioooooooo03Goool008ooool00`0003?o
03?o0005<ol000<0003oooooool0C_ooo`03o`2Ioooooooo03Goool008ooool00`0003?o03?o0005
<ol000<0003oooooool0C_ooo`03o`2Ioooooooo03Goool008ooool00`0003?o03?o0005<ol000<0
003oooooool0C_ooo`03o`2Ioooooooo03Goool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool0C_ooo`03o`2Ioooooooo03Goool008ooool200001S?o00030000oooooooo04koool00ol0VOoo
ooooo`0eoooo002?oooo00<0000co`0co`001C?o00030000oooooooo04koool00ol0VOooooooo`0e
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo04koool00ol0VOooooooo`0eoooo002?
oooo00<0000co`0co`0013?o00030000oooooooo04ooool00ol0VOooooooo`0eoooo002?oooo00<0
000co`0co`0013?o00030000oooooooo04ooool00ol0VOooooooo`0eoooo0029oooo0`0000?oool0
0`0003?o03?o0004<ol000<0003oooooool0Coooo`03o`2Ioooooooo03Goool008[oool00`000?oo
ooooo`02oooo00<0000co`0co`0013?o00030000oooooooo04ooool00ol0VOooooooo`0eoooo0027
oooo1@0000?oool3000013?o00030000oooooooo04ooool00ol0VOooooooo`0eoooo0027oooo00@0
003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool2
00001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo
01?oool7<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool02Oooo`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool400000c?o008000000c?o0?ooooooo`02oooo0`0000;oool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool00`000?ooooooo`07<ol01Oooo`040000oooooooo00000_ooo`050000
oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000
oooo<ol000Hco`02oooo1@000005oooo0000oooooooo000000Coool00`000?ooooooo`1goooo001h
oooo00<0003oooooool01@0000koool00`0003?o03?o0005<ol00_ooo`040000oooooooo00000ooo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Hco`03oooo00<0003oool000000_ooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`04oooo0P0000?oool200000oooo`030000
oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.79749 .12361 L
.81909 .12361 L
.82924 .12361 L
.83996 .12361 L
.84911 .12361 L
.85162 .12361 L
.85431 .12361 L
.85561 .12361 L
.85685 .12361 L
s
.85685 .12361 m
.85729 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.10458 .12361 L
.11448 .12361 L
.12507 .12361 L
.1302 .12361 L
.13506 .12361 L
.13942 .12361 L
.14061 .12361 L
.14188 .12361 L
.14296 .1235 L
.14415 .12227 L
.16519 .10345 L
.18444 .09034 L
.20432 .08016 L
.22321 .07308 L
.2328 .0703 L
.24302 .06787 L
.25259 .06603 L
.2614 .06468 L
.27169 .06347 L
.2771 .06298 L
.28282 .06257 L
.28779 .06228 L
.29243 .06208 L
.29505 .06199 L
.29753 .06193 L
.29889 .0619 L
.30038 .06187 L
.30174 .06185 L
.30299 .06183 L
.30412 .06182 L
.30532 .06181 L
.30652 .06181 L
.30783 .0618 L
.30897 .0618 L
.31019 .06181 L
.31134 .06182 L
.31239 .06183 L
.31372 .06184 L
.31495 .06186 L
.31772 .0619 L
.32017 .06196 L
.32276 .06203 L
.33276 .06241 L
.33845 .0627 L
.34377 .06301 L
.36406 .06453 L
.38259 .06629 L
Mistroke
.42235 .07081 L
.4606 .07566 L
.48196 .07843 L
.5013 .08092 L
.50602 .08142 L
.511 .08183 L
.51361 .08199 L
.51646 .08214 L
.51906 .08224 L
.52148 .08232 L
.52267 .08235 L
.52395 .08237 L
.52516 .08239 L
.52629 .08241 L
.52729 .08241 L
.52841 .08242 L
.52957 .08242 L
.53066 .08242 L
.53186 .08241 L
.53313 .0824 L
.53421 .08238 L
.53539 .08236 L
.53803 .08231 L
.54048 .08224 L
.54554 .08205 L
.55103 .08178 L
.56098 .08113 L
.57958 .07946 L
.59949 .07714 L
.62055 .07423 L
.65849 .06804 L
.69888 .06048 L
.73775 .0526 L
.77908 .04396 L
.79975 .03971 L
.8189 .03594 L
.83746 .03252 L
.84683 .03092 L
.8494 .0305 L
.85218 .03005 L
.85345 .02985 L
.85479 .02964 L
.85594 .02946 L
.85719 .12361 L
.85851 .12361 L
.85972 .12361 L
.86247 .12361 L
.86745 .12361 L
.87678 .12361 L
.89772 .12361 L
Mistroke
.93709 .12361 L
.97495 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`1Aoooo1`1VocKoool0
08ooool00`000?ooooooo`1<oooo1@1Vo`Koool00`1Vooooooooo`0doooo002?oooo00<0003ooooo
ool0Aoooo`D0I_l;oooo00<0I_ooooooool0=?ooo`00Soooo`030000oooooooo04;oool506Ko4?oo
o`0306Kooooooooo03Coool008ooool00`000?ooooooo`0loooo1P1VoaGoool00`1Vooooooooo`0d
oooo002?oooo0P0003Soool506Ko6oooo`0306Kooooooooo03Coool008ooool00`000?ooooooo`0b
oooo1@1Vob3oool00`1Vooooooooo`0doooo002?oooo00<0003oooooool0;Oooo`D0I_lUoooo00<0
I_ooooooool0=?ooo`00D_oooad0I_lPoooo00<0003oooooool0:?ooo`D0I_lZoooo00<0I_oooooo
ool0=?ooo`00COooo`D0I_lMoooo1`1VoaWoool00`000?ooooooo`0Soooo1@1Vobooool00`1Voooo
ooooo`0doooo001;oooo0P1VobWoool:06Ko3oooo`030000oooooooo01ooool406Ko=?ooo`0306Ko
oooooooo03Coool004Ooool406Ko=Oooo`P0I_l7oooo0P0001_oool506Ko>?ooo`0306Kooooooooo
03Coool001Ooool40000:Oooo`<0I_l=oooo1@0002ooool506Ko0_ooo`030000oooooooo00ooool;
06Ko7Oooo`D0000Loooo00<0I_ooooooool06Oooo`@0000Foooo000Goooo00<0003oooooool0:?oo
o`80I_lBoooo00<0003oooooool0=?ooo`80I_l00`00001Vo`1Vo`0?06Ko:_ooo`030000oooooooo
01coool00`1Vooooooooo`0Ioooo00<0003oooooool05oooo`006?ooo`030000oooooooo02Goool2
06Ko5?ooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool07?ooo`0306Ko
oooooooo01[oool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Soooo00<0
I_ooooooool03?ooo`@00004oooo00<0003oooooool0=_ooo`030000oooooooo03Woool00`000?oo
ooooo`0Loooo00<0I_ooooooool06oooo`030000oooooooo01Goool001Ooool010000?ooooooo`00
02;oool206Ko5oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool07?oo
o`0306Kooooooooo01Woool010000?ooooooo`0001Koool001Soool200008Oooo`80I_lHoooo0P00
03Soool20000>Oooo`80000Noooo00<0I_ooooooool06_ooo`80000Goooo000joooo00<0I_oooooo
ool0D_ooo`030000oooooooo05Soool00`1Vooooooooo`0coooo000ioooo00<0I_ooooooool0Dooo
o`030000oooooooo05Soool00`1Vooooooooo`0coooo000hoooo00<0I_ooooooool0E?ooo`030000
oooooooo05Soool00`1Vooooooooo`0coooo000goooo00<0I_ooooooool0EOooo`030000oooooooo
05Soool00`1Vooooooooo`0coooo000foooo00<0I_ooooooool0E_ooo`030000oooooooo05Soool0
0`1Vooooooooo`0coooo000@ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006<ol05@000003o`2I
0000000000X00006oooo00<0003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol003Tco`0900005Oooo`03o`2Ioooooooo
01coool00`000?ooooooo`0Eoooo002?oooo00<0000co`0co`00<c?o00H0000Noooo00?o09Wooooo
ool0=?ooo`00Soooo`030000<ol0<ol0034co`0200009?ooo`03o`2Ioooooooo03Coool008ooool0
0`0003?o03?o000_<ol00P0002Koool00ol0VOooooooo`0doooo002?oooo00<0000co`0co`00;3?o
00<0000Xoooo00?o09Woooooool0=?ooo`00Soooo`80000Z<ol00`0002_oool00ol0VOooooooo`0d
oooo002?oooo00<0000co`0co`009c?o0080000^oooo00?o09Woooooool0=?ooo`00Soooo`030000
<ol0<ol002Hco`000`000?ooooooo`0^oooo00?o09Woooooool0=?ooo`00Soooo`030000<ol0<ol0
02Dco`000`000?ooooooo`0_oooo00?o09Woooooool0=?ooo`00Soooo`030000<ol0<ol002@co`00
0`000?ooooooo`0`oooo00?o09Woooooool0=?ooo`00Soooo`030000<ol0<ol0028co`020000<ooo
o`03o`2Ioooooooo03Coool008ooool200008S?o00030000oooooooo03?oool00ol0VOooooooo`0d
oooo002?oooo00<0000co`0co`0083?o00030000oooooooo03Coool00ol0VOooooooo`0doooo002?
oooo00<0000co`0co`007c?o00030000oooooooo03Goool00ol0VOooooooo`0doooo002?oooo00<0
000co`0co`007c?o00030000oooooooo03Goool00ol0VOooooooo`0doooo002?oooo00<0000co`0c
o`007S?o00030000oooooooo03Koool00ol0VOooooooo`0doooo002?oooo00<0000co`0co`007C?o
00030000oooooooo03Ooool00ol0VOooooooo`0doooo002?oooo0P0001dco`000`000?ooooooo`0h
oooo00?o09Woooooool0=?ooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0ioooo00?o
09Woooooool0=?ooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0ioooo00?o09Wooooo
ool0=?ooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0joooo00?o09Woooooool0=?oo
o`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0joooo00?o09Woooooool0=?ooo`00Sooo
o`030000<ol0<ol001Tco`000`000?ooooooo`0koooo00?o09Woooooool0=?ooo`00Soooo`80000J
<ol000<0003oooooool0>oooo`03o`2Ioooooooo03Coool008ooool00`0003?o03?o000H<ol000<0
003oooooool0??ooo`03o`2Ioooooooo03Coool008ooool00`0003?o03?o000H<ol000<0003ooooo
ool0??ooo`03o`2Ioooooooo03Coool008ooool00`0003?o03?o000G<ol000<0003oooooool0?Ooo
o`03o`2Ioooooooo03Coool008ooool00`0003?o03?o000G<ol000<0003oooooool0?Oooo`03o`2I
oooooooo03Coool008Ooool500000oooo`030000<ol0<ol001Hco`000`000?ooooooo`0noooo00?o
09Woooooool0=?ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000F<ol000<0003ooooo
ool0?_ooo`03o`2Ioooooooo03Coool008Woool00`000?ooooooo`03oooo0`0001Dco`000`000?oo
ooooo`0ooooo00?o09Woooooool0=?ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E
<ol000<0003oooooool0?oooo`03o`2Ioooooooo03Coool008Woool00`000?ooooooo`03oooo00<0
000co`0co`005C?o00030000oooooooo03ooool00ol0VOooooooo`0doooo0028oooo0P0000Goool0
0`0003?o03?o000D<ol000<0003oooooool0@?ooo`03o`2Ioooooooo03Coool008ooool00`0003?o
03?o000D<ol000<0003oooooool0@?ooo`03o`2Ioooooooo03Coool008ooool00`0003?o03?o000C
<ol000<0003oooooool0@Oooo`03o`2Ioooooooo03Coool008ooool2000053?o00030000oooooooo
047oool00ol0VOooooooo`0doooo002?oooo00<0000co`0co`004c?o00030000oooooooo047oool0
0ol0VOooooooo`0doooo002?oooo00<0000co`0co`004S?o00030000oooooooo04;oool00ol0VOoo
ooooo`0doooo002?oooo00<0000co`0co`004S?o00030000oooooooo04;oool00ol0VOooooooo`0d
oooo002?oooo00<0000co`0co`004S?o00030000oooooooo04;oool00ol0VOooooooo`0doooo002?
oooo00<0000co`0co`004C?o00030000oooooooo04?oool00ol0VOooooooo`0doooo002?oooo0P00
018co`000`000?ooooooo`13oooo00?o09Woooooool0=?ooo`00Soooo`030000<ol0<ol0014co`00
0`000?ooooooo`13oooo00?o09Woooooool0=?ooo`00Soooo`030000<ol0<ol0014co`000`000?oo
ooooo`13oooo00?o09Woooooool0=?ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`14
oooo00?o09Woooooool0=?ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`14oooo00?o
09Woooooool0=?ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`14oooo00?o09Wooooo
ool0=?ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`14oooo00?o09Woooooool0=?oo
o`00Soooo`80000@<ol000<0003oooooool0AOooo`03o`2Ioooooooo03Coool008ooool00`0003?o
03?o000?<ol000<0003oooooool0AOooo`03o`2Ioooooooo03Coool008ooool00`0003?o03?o000?
<ol000<0003oooooool0AOooo`03o`2Ioooooooo03Coool008ooool00`0003?o03?o000?<ol000<0
003oooooool0AOooo`03o`2Ioooooooo03Coool008ooool00`0003?o03?o000?<ol000<0003ooooo
ool0AOooo`03o`2Ioooooooo03Coool008ooool00`0003?o03?o000><ol000<0003oooooool0A_oo
o`03o`2Ioooooooo03Coool008ooool200003c?o00030000oooooooo04Koool00ol0VOooooooo`0d
oooo002?oooo00<0000co`0co`003S?o00030000oooooooo04Koool00ol0VOooooooo`0doooo002?
oooo00<0000co`0co`003S?o00030000oooooooo04Koool00ol0VOooooooo`0doooo002?oooo00<0
000co`0co`003C?o00030000oooooooo04Ooool00ol0VOooooooo`0doooo0027oooo100000Coool0
0`0003?o03?o000=<ol000<0003oooooool0Aoooo`03o`2Ioooooooo03Coool008Ooool00`000?oo
ooooo`05oooo00<0000co`0co`003C?o00030000oooooooo04Ooool00ol0VOooooooo`0doooo0028
oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0Aoooo`03o`2Ioooooooo03Coool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo04Soool00ol0VOoo
ooooo`0coooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0033?o00030000oooooooo
04Woool00ol0VOooooooo`0coooo0028oooo0P0000Goool00`0003?o03?o000<<ol000<0003ooooo
ool0BOooo`03o`2Ioooooooo03?oool008ooool00`0003?o03?o000<<ol000<0003oooooool0BOoo
o`03o`2Ioooooooo03?oool008ooool00`0003?o03?o000<<ol000<0003oooooool0BOooo`03o`2I
oooooooo03?oool008ooool200003C?o00030000oooooooo04Woool00ol0VOooooooo`0coooo002?
oooo00<0000co`0co`0033?o00030000oooooooo04Woool00ol0VOooooooo`0coooo002?oooo00<0
000co`0co`002c?o00030000oooooooo04[oool00ol0VOooooooo`0coooo002?oooo00<0000co`0c
o`002c?o00030000oooooooo04[oool00ol0VOooooooo`0coooo002?oooo00<0000co`0co`002c?o
00030000oooooooo04[oool00ol0VOooooooo`0coooo002?oooo00<0000co`0co`002c?o00030000
oooooooo04[oool00ol0VOooooooo`0coooo002?oooo00<0000co`0co`002c?o00030000oooooooo
04[oool00ol0VOooooooo`0coooo002?oooo0P0000`co`000`000?ooooooo`1:oooo00?o09Wooooo
ool0<oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1:oooo00?o09Woooooool0<ooo
o`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1;oooo00?o09Woooooool0<oooo`00Sooo
o`030000<ol0<ol000Xco`000`000?ooooooo`1;oooo00?o09Woooooool0<oooo`00Soooo`030000
<ol0<ol000Xco`000`000?ooooooo`1;oooo00?o09Woooooool0<oooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`1;oooo00?o09Woooooool0<oooo`00Soooo`80000;<ol000<0003ooooo
ool0Boooo`03o`2Ioooooooo03?oool008ooool00`0003?o03?o000:<ol000<0003oooooool0Booo
o`03o`2Ioooooooo03?oool008ooool00`0003?o03?o000:<ol000<0003oooooool0Boooo`03o`2I
oooooooo03?oool008ooool00`0003?o03?o0009<ol000<0003oooooool0C?ooo`03o`2Ioooooooo
03?oool008ooool00`0003?o03?o0009<ol000<0003oooooool0C?ooo`03o`2Ioooooooo03?oool0
08ooool00`0003?o03?o0009<ol000<0003oooooool0C?ooo`03o`2Ioooooooo03?oool008ooool2
00002S?o00030000oooooooo04coool00ol0VOooooooo`0coooo002?oooo00<0000co`0co`002C?o
00030000oooooooo04coool00ol0VOooooooo`0coooo002?oooo00<0000co`0co`002C?o00030000
oooooooo04coool00ol0VOooooooo`0coooo002?oooo00<0000co`0co`0023?o00030000oooooooo
04goool00ol0VOooooooo`0coooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0003ooooo
ool0COooo`03o`2Ioooooooo03?oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008
<ol000<0003oooooool0COooo`03o`2Ioooooooo03?oool008Woool00`000?ooooooo`03oooo0`00
00Pco`000`000?ooooooo`1=oooo00?o09Woooooool0<oooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o0008<ol000<0003oooooool0COooo`03o`2Ioooooooo03?oool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0COooo`03o`2Ioooooooo03?oool0
08Soool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`1>oooo00?o09Woooooool0<ooo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1>oooo00?o09Woooooool0<oooo`00Sooo
o`030000<ol0<ol000Lco`000`000?ooooooo`1>oooo00?o09Woooooool0<oooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`1>oooo00?o09Woooooool0<oooo`00Soooo`800008<ol000<0
003oooooool0C_ooo`03o`2Ioooooooo03?oool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool0C_ooo`03o`2Ioooooooo03?oool008ooool00`0003?o03?o0007<ol000<0003oooooool0C_oo
o`03o`2Ioooooooo03?oool008ooool00`0003?o03?o0007<ol000<0003oooooool0C_ooo`03o`2I
oooooooo03?oool008ooool00`0003?o03?o0006<ol000<0003oooooool0Coooo`03o`2Ioooooooo
03?oool008ooool00`0003?o03?o0006<ol000<0003oooooool0Coooo`03o`2Ioooooooo03?oool0
08ooool200001c?o00030000oooooooo04ooool00ol0VOooooooo`0coooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo04ooool00ol0VOooooooo`0coooo002?oooo00<0000co`0co`001S?o
00030000oooooooo04ooool00ol0VOooooooo`0coooo002?oooo00<0000co`0co`001S?o00030000
oooooooo04ooool00ol0VOooooooo`0coooo002?oooo00<0000co`0co`001S?o00030000oooooooo
04ooool00ol0VOooooooo`0coooo002?oooo00<0000co`0co`001S?o00030000oooooooo04ooool0
0ol0VOooooooo`0coooo002?oooo0P0000Hco`000`000?ooooooo`1@oooo00?o09Woooooool0<ooo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1@oooo00?o09Woooooool0<oooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`1@oooo00?o09Woooooool0<oooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`1@oooo00?o09Woooooool0<oooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`1@oooo00?o09Woooooool0<oooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`1@oooo00?o09Woooooool0<oooo`00Soooo`800006<ol000<0003oooooool0D?oo
o`03o`2Ioooooooo03?oool008ooool00`0003?o03?o0005<ol000<0003oooooool0D?ooo`03o`2I
oooooooo03?oool008ooool00`0003?o03?o0005<ol000<0003oooooool0D?ooo`03o`2Ioooooooo
03?oool008ooool00`0003?o03?o0004<ol000<0003oooooool0DOooo`03o`2Ioooooooo03?oool0
08ooool00`0003?o03?o0004<ol000<0003oooooool0DOooo`03o`2Ioooooooo03?oool008Woool3
00000oooo`030000<ol0<ol000@co`000`000?ooooooo`1Aoooo00?o09Woooooool0<oooo`00R_oo
o`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0DOooo`03o`2Ioooooooo
03?oool008Ooool500000oooo`<00004<ol000<0003oooooool0DOooo`03o`2Ioooooooo03?oool0
08Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_oo
o`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001loooo00<0
003oooooool04?ooo`Lco`0;oooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool0
0`000?ooooooo`06oooo1c?o00coool00`000?ooooooo`1koooo001koooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01_ooo`@00003<ol00P0000Coool200001?ooo`030000oooooooo
07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Goool00`0003?o03?o0004<ol01Oooo`040000oooooooo00000oooo`030000oooooooo07_oool0
07[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`03<ol00000<ol000@co`08oooo00<0
003oooooool00_ooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003?ooo`8co`00
0`0003?o03?o0002<ol01_ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooo
oooo000000ooool0100003?o03?o000000<co`06oooo00<0003oooooool00oooo`030000oooooooo
07_oool007coool00`000?ooooooo`0@oooo00<co`000000000013?o00Koool300000_ooo`030000
oooooooo07coool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.52) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.84911 .12361 L
.85396 .12361 L
.85663 .12361 L
.85916 .12361 L
.86034 .12361 L
.86159 .12361 L
s
.86159 .12361 m
.86185 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.10458 .12361 L
.11448 .12361 L
.12507 .12361 L
.1302 .12361 L
.13273 .12361 L
.13506 .12361 L
.13615 .12361 L
.13718 .12361 L
.13824 .12345 L
.13942 .12224 L
.14415 .11755 L
.16269 .10173 L
.18292 .08846 L
.20406 .07826 L
.21459 .07434 L
.22415 .07137 L
.24382 .06675 L
.25462 .06496 L
.26479 .06369 L
.27456 .06281 L
.27947 .06248 L
.28487 .0622 L
.28948 .06202 L
.29207 .06194 L
.29443 .06189 L
.29662 .06185 L
.29786 .06183 L
.29901 .06182 L
.30001 .06181 L
.30111 .06181 L
.30226 .0618 L
.30334 .0618 L
.30452 .06181 L
.30578 .06181 L
.30696 .06182 L
.30804 .06183 L
.31068 .06186 L
.31318 .06191 L
.31814 .06203 L
.32353 .06222 L
.33315 .06267 L
.34203 .06321 L
.36079 .06466 L
.38143 .06666 L
.42177 .07132 L
.4606 .07627 L
.48035 .07883 L
Mistroke
.49077 .08018 L
.49649 .08092 L
.50188 .08159 L
.50708 .08212 L
.50982 .08235 L
.5127 .08255 L
.51514 .08268 L
.51781 .08281 L
.52024 .0829 L
.52251 .08296 L
.5237 .08298 L
.52499 .083 L
.52621 .08302 L
.52734 .08303 L
.52836 .08304 L
.52948 .08304 L
.53065 .08304 L
.53175 .08303 L
.53296 .08302 L
.53423 .08301 L
.53651 .08297 L
.53896 .08291 L
.54164 .08283 L
.54694 .08263 L
.55194 .08237 L
.56129 .08177 L
.58225 .07988 L
.62077 .07497 L
.66174 .06832 L
.70119 .06096 L
.73913 .05329 L
.77953 .04485 L
.8184 .03694 L
.83819 .03323 L
.84863 .0314 L
.85435 .03046 L
.85716 .03001 L
.85839 .02981 L
.85973 .0296 L
.86092 .02942 L
.86203 .12361 L
.8632 .12361 L
.86445 .12361 L
.86955 .12361 L
.8804 .12361 L
.89954 .12361 L
.94101 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.52) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`1Aoooo201VocGoool0
08ooool00`000?ooooooo`1<oooo1@1Vo`Ooool00`1Vooooooooo`0coooo002?oooo00<0003ooooo
ool0Aoooo`D0I_l<oooo00<0I_ooooooool0<oooo`00Soooo`030000oooooooo04?oool406Ko4Ooo
o`0306Kooooooooo03?oool008ooool00`000?ooooooo`10oooo0`1VoaGoool00`1Vooooooooo`0c
oooo002?oooo0P0003goool406Ko6?ooo`0306Kooooooooo03?oool008ooool00`000?ooooooo`0h
oooo101Voacoool00`1Vooooooooo`0coooo002?oooo00<0003oooooool0<oooo`D0I_lPoooo00<0
I_ooooooool0<oooo`00Dooooa`0I_lPoooo00<0003oooooool0;?ooo`L0I_lUoooo00<0I_oooooo
ool0<oooo`00C?ooo`L0I_lLoooo1`1VoaWoool00`000?ooooooo`0Toooo201Vobcoool00`1Voooo
ooooo`0coooo0019oooo0`1Vob[oool:06Ko3oooo`030000oooooooo01ooool506Ko=?ooo`0306Ko
oooooooo03?oool004Koool306Ko=oooo`P0I_l7oooo0P0001Woool706Ko>Oooo`0306Kooooooooo
03?oool001Ooool40000:?ooo`<0I_l>oooo1@0002ooool606Ko00?oool0003oool04Oooo`P0I_lO
oooo1@0001goool00`1Vooooooooo`0Hoooo100001Koool001Ooool00`000?ooooooo`0Woooo0P1V
oa?oool00`000?ooooooo`0eoooo00<0I_l00000I_l04@1VobWoool00`000?ooooooo`0Moooo00<0
I_ooooooool06?ooo`030000oooooooo01Ooool001Soool00`000?ooooooo`0Toooo0P1VoaGoool0
0`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo01goool00`1Vooooooooo`0I
oooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0003oooooool08Oooo`80I_l?oooo1000
00Coool00`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo01goool00`1Voooo
ooooo`0Joooo00<0003oooooool05Oooo`005oooo`040000oooooooo00008Oooo`0306Kooooooooo
01Ooool00`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo01goool00`1Voooo
ooooo`0Hoooo00@0003oooooool0000Foooo000Hoooo0P00023oool206Ko6Oooo`80000hoooo0P00
03Woool200007oooo`0306Kooooooooo01Woool200005oooo`00>Oooo`0306Kooooooooo05?oool0
0`000?ooooooo`1Ioooo00<0I_ooooooool0<_ooo`00>?ooo`0306Kooooooooo05Coool00`000?oo
ooooo`1Ioooo00<0I_ooooooool0<_ooo`00=oooo`0306Kooooooooo05Goool00`000?ooooooo`1I
oooo00<0I_ooooooool0<_ooo`00=_ooo`0306Kooooooooo05Koool00`000?ooooooo`1Ioooo00<0
I_ooooooool0<_ooo`00=Oooo`0306Kooooooooo05Ooool00`000?ooooooo`1Ioooo00<0I_oooooo
ool0<_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o01L000000ol0V@0000000008
00001_ooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_oo
o`030000oooooooo03Woool00`0003?o03?o000i<ol02@0001Ooool00ol0VOooooooo`0Joooo00<0
003oooooool05Oooo`00Soooo`030000<ol0<ol003<co`0600008?ooo`03o`2Ioooooooo03;oool0
08ooool00`0003?o03?o000a<ol00P0002Koool00ol0VOooooooo`0boooo002?oooo00<0000co`0c
o`00;c?o0080000Xoooo00?o09Woooooool0<_ooo`00Soooo`030000<ol0<ol002`co`030000:_oo
o`03o`2Ioooooooo03;oool008ooool20000:S?o00<0000]oooo00?o09Woooooool0<_ooo`00Sooo
o`030000<ol0<ol002Lco`020000<?ooo`03o`2Ioooooooo03;oool008ooool00`0003?o03?o000V
<ol000<0003oooooool0<?ooo`03o`2Ioooooooo03;oool008ooool00`0003?o03?o000U<ol000<0
003oooooool0<Oooo`03o`2Ioooooooo03;oool008ooool00`0003?o03?o000T<ol000<0003ooooo
ool0<_ooo`03o`2Ioooooooo03;oool008ooool00`0003?o03?o000R<ol00P0003Goool00ol0VOoo
ooooo`0boooo002?oooo0P00028co`000`000?ooooooo`0eoooo00?o09Woooooool0<_ooo`00Sooo
o`030000<ol0<ol0020co`000`000?ooooooo`0foooo00?o09Woooooool0<_ooo`00Soooo`030000
<ol0<ol001lco`000`000?ooooooo`0goooo00?o09Woooooool0<_ooo`00Soooo`030000<ol0<ol0
01lco`000`000?ooooooo`0goooo00?o09Woooooool0<_ooo`00Soooo`030000<ol0<ol001hco`00
0`000?ooooooo`0hoooo00?o09Woooooool0<_ooo`00Soooo`030000<ol0<ol001dco`000`000?oo
ooooo`0ioooo00?o09Woooooool0<_ooo`00Soooo`80000M<ol000<0003oooooool0>_ooo`03o`2I
oooooooo03;oool008ooool00`0003?o03?o000K<ol000<0003oooooool0>oooo`03o`2Ioooooooo
03;oool008ooool00`0003?o03?o000K<ol000<0003oooooool0>oooo`03o`2Ioooooooo03;oool0
08ooool00`0003?o03?o000J<ol000<0003oooooool0??ooo`03o`2Ioooooooo03;oool008ooool0
0`0003?o03?o000J<ol000<0003oooooool0??ooo`03o`2Ioooooooo03;oool008ooool00`0003?o
03?o000I<ol000<0003oooooool0?Oooo`03o`2Ioooooooo03;oool008ooool200006S?o00030000
oooooooo03goool00ol0VOooooooo`0boooo002?oooo00<0000co`0co`0063?o00030000oooooooo
03koool00ol0VOooooooo`0boooo002?oooo00<0000co`0co`0063?o00030000oooooooo03koool0
0ol0VOooooooo`0boooo002?oooo00<0000co`0co`005c?o00030000oooooooo03ooool00ol0VOoo
ooooo`0boooo002?oooo00<0000co`0co`005c?o00030000oooooooo03ooool00ol0VOooooooo`0b
oooo0027oooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool0@?ooo`03o`2Ioooooooo
03;oool008Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo043oool0
0ol0VOooooooo`0boooo0029oooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0@Ooo
o`03o`2Ioooooooo03;oool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000
oooooooo047oool00ol0VOooooooo`0boooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`11oooo00?o09Woooooool0<_ooo`00R?ooo`800005oooo00<0000co`0c
o`0053?o00030000oooooooo04;oool00ol0VOooooooo`0boooo002?oooo00<0000co`0co`0053?o
00030000oooooooo04;oool00ol0VOooooooo`0boooo002?oooo00<0000co`0co`004c?o00030000
oooooooo04?oool00ol0VOooooooo`0boooo002?oooo0P0001@co`000`000?ooooooo`13oooo00?o
09Woooooool0<_ooo`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`13oooo00?o09Wooooo
ool0<_ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`14oooo00?o09Woooooool0<_oo
o`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`14oooo00?o09Woooooool0<_ooo`00Sooo
o`030000<ol0<ol0018co`000`000?ooooooo`14oooo00?o09Woooooool0<_ooo`00Soooo`030000
<ol0<ol0014co`000`000?ooooooo`15oooo00?o09Woooooool0<_ooo`00Soooo`80000B<ol000<0
003oooooool0AOooo`03o`2Ioooooooo03;oool008ooool00`0003?o03?o000A<ol000<0003ooooo
ool0AOooo`03o`2Ioooooooo03;oool008ooool00`0003?o03?o000A<ol000<0003oooooool0AOoo
o`03o`2Ioooooooo03;oool008ooool00`0003?o03?o000@<ol000<0003oooooool0A_ooo`03o`2I
oooooooo03;oool008ooool00`0003?o03?o000@<ol000<0003oooooool0A_ooo`03o`2Ioooooooo
03;oool008ooool00`0003?o03?o000@<ol000<0003oooooool0A_ooo`03o`2Ioooooooo03;oool0
08ooool00`0003?o03?o000@<ol000<0003oooooool0A_ooo`03o`2Ioooooooo03;oool008ooool2
000043?o00030000oooooooo04Ooool00ol0VOooooooo`0boooo002?oooo00<0000co`0co`003c?o
00030000oooooooo04Ooool00ol0VOooooooo`0boooo002?oooo00<0000co`0co`003c?o00030000
oooooooo04Ooool00ol0VOooooooo`0boooo002?oooo00<0000co`0co`003c?o00030000oooooooo
04Ooool00ol0VOooooooo`0boooo002?oooo00<0000co`0co`003c?o00030000oooooooo04Ooool0
0ol0VOooooooo`0boooo002?oooo00<0000co`0co`003S?o00030000oooooooo04Soool00ol0VOoo
ooooo`0boooo002?oooo0P0000lco`000`000?ooooooo`18oooo00?o09Woooooool0<_ooo`00Sooo
o`030000<ol0<ol000hco`000`000?ooooooo`18oooo00?o09Woooooool0<_ooo`00Soooo`030000
<ol0<ol000hco`000`000?ooooooo`18oooo00?o09Woooooool0<_ooo`00Soooo`030000<ol0<ol0
00dco`000`000?ooooooo`19oooo00?o09Woooooool0<_ooo`00Qoooo`@00004oooo00<0000co`0c
o`003C?o00030000oooooooo04Woool00ol0VOooooooo`0boooo0027oooo00<0003oooooool01Ooo
o`030000<ol0<ol000dco`000`000?ooooooo`19oooo00?o09Woooooool0<_ooo`00R?ooo`030000
oooooooo00Coool300003C?o00030000oooooooo04Woool00ol0VOooooooo`0boooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`19oooo00?o09Woooooool0<_oo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1:oooo00?o
09Woooooool0<_ooo`00R?ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo04[oool0
0ol0VOooooooo`0boooo002?oooo00<0000co`0co`0033?o00030000oooooooo04[oool00ol0VOoo
ooooo`0boooo002?oooo00<0000co`0co`0033?o00030000oooooooo04[oool00ol0VOooooooo`0b
oooo002?oooo0P0000dco`000`000?ooooooo`1:oooo00?o09Woooooool0<_ooo`00Soooo`030000
<ol0<ol000`co`000`000?ooooooo`1:oooo00?o09Woooooool0<_ooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`1;oooo00?o09Woooooool0<_ooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`1;oooo00?o09Woooooool0<_ooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`1;oooo00?o09Woooooool0<_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1;
oooo00?o09Woooooool0<_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1;oooo00?o
09Woooooool0<_ooo`00Soooo`80000<<ol000<0003oooooool0Boooo`03o`2Ioooooooo03;oool0
08ooool00`0003?o03?o000;<ol000<0003oooooool0Boooo`03o`2Ioooooooo03;oool008ooool0
0`0003?o03?o000:<ol000<0003oooooool0C?ooo`03o`2Ioooooooo03;oool008ooool00`0003?o
03?o000:<ol000<0003oooooool0C?ooo`03o`2Ioooooooo03;oool008ooool00`0003?o03?o000:
<ol000<0003oooooool0C?ooo`03o`2Ioooooooo03;oool008ooool00`0003?o03?o000:<ol000<0
003oooooool0C?ooo`03o`2Ioooooooo03;oool008ooool200002c?o00030000oooooooo04coool0
0ol0VOooooooo`0boooo002?oooo00<0000co`0co`002S?o00030000oooooooo04coool00ol0VOoo
ooooo`0boooo002?oooo00<0000co`0co`002S?o00030000oooooooo04coool00ol0VOooooooo`0b
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo04goool00ol0VOooooooo`0boooo002?
oooo00<0000co`0co`002C?o00030000oooooooo04goool00ol0VOooooooo`0boooo002?oooo00<0
000co`0co`002C?o00030000oooooooo04goool00ol0VOooooooo`0boooo002?oooo0P0000Xco`00
0`000?ooooooo`1=oooo00?o09Woooooool0<_ooo`00Soooo`030000<ol0<ol000Tco`000`000?oo
ooooo`1=oooo00?o09Woooooool0<_ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1=
oooo00?o09Woooooool0<_ooo`00Soooo`030000<ol0<ol000Pco`000`000?ooooooo`1>oooo00?o
09Woooooool0<_ooo`00R?ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo04koool0
0ol0VOooooooo`0boooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000
oooooooo04koool00ol0VOooooooo`0boooo0029oooo00<0003oooooool00oooo`<00008<ol000<0
003oooooool0C_ooo`03o`2Ioooooooo03;oool008[oool00`000?ooooooo`02oooo00<0000co`0c
o`0023?o00030000oooooooo04koool00ol0VOooooooo`0boooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0023?o00030000oooooooo04koool00ol0VOooooooo`0boooo0028oooo0P00
00Goool00`0003?o03?o0007<ol000<0003oooooool0Coooo`03o`2Ioooooooo03;oool008ooool0
0`0003?o03?o0007<ol000<0003oooooool0Coooo`03o`2Ioooooooo03;oool008ooool00`0003?o
03?o0007<ol000<0003oooooool0Coooo`03o`2Ioooooooo03;oool008ooool00`0003?o03?o0007
<ol000<0003oooooool0Coooo`03o`2Ioooooooo03;oool008ooool2000023?o00030000oooooooo
04ooool00ol0VOooooooo`0boooo002?oooo00<0000co`0co`001c?o00030000oooooooo04ooool0
0ol0VOooooooo`0boooo002?oooo00<0000co`0co`001c?o00030000oooooooo04ooool00ol0VOoo
ooooo`0boooo002?oooo00<0000co`0co`001c?o00030000oooooooo04ooool00ol0VOooooooo`0b
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo053oool00ol0VOooooooo`0boooo002?
oooo00<0000co`0co`001S?o00030000oooooooo053oool00ol0VOooooooo`0boooo002?oooo0P00
00Lco`000`000?ooooooo`1@oooo00?o09Woooooool0<_ooo`00Soooo`030000<ol0<ol000Hco`00
0`000?ooooooo`1@oooo00?o09Woooooool0<_ooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`1@oooo00?o09Woooooool0<_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1@
oooo00?o09Woooooool0<_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1@oooo00?o
09Woooooool0<_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1@oooo00?o09Wooooo
ool0<_ooo`00Soooo`800006<ol000<0003oooooool0DOooo`03o`2Ioooooooo03;oool008ooool0
0`0003?o03?o0005<ol000<0003oooooool0DOooo`03o`2Ioooooooo03;oool008ooool00`0003?o
03?o0005<ol000<0003oooooool0DOooo`03o`2Ioooooooo03;oool008ooool00`0003?o03?o0005
<ol000<0003oooooool0DOooo`03o`2Ioooooooo03;oool008ooool00`0003?o03?o0005<ol000<0
003oooooool0DOooo`03o`2Ioooooooo03;oool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool0DOooo`03o`2Ioooooooo03;oool008ooool200001S?o00030000oooooooo057oool00ol0VOoo
ooooo`0boooo002?oooo00<0000co`0co`001C?o00030000oooooooo057oool00ol0VOooooooo`0b
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo057oool00ol0VOooooooo`0boooo002?
oooo00<0000co`0co`0013?o00030000oooooooo05;oool00ol0VOooooooo`0boooo002?oooo00<0
000co`0co`0013?o00030000oooooooo05;oool00ol0VOooooooo`0boooo0029oooo0`0000?oool0
0`0003?o03?o0004<ol000<0003oooooool0D_ooo`03o`2Ioooooooo03;oool008[oool00`000?oo
ooooo`02oooo00<0000co`0co`0013?o00030000oooooooo05;oool00ol0VOooooooo`0boooo0027
oooo1@0000?oool3000013?o00030000oooooooo05;oool00ol0VOooooooo`0boooo0027oooo00@0
003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool2
00001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo
01?oool7<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool02Oooo`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool400000c?o0080000013?o0?ooooooooooo`800003oooo100000?oool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00<0003oooooool01c?o00;oool010000?ooooooo`0000;oool00`000?oo
ooooo`04oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0>
oooo00<0003ooolco`001S?o00Goool01@000?ooooooooooo`000006oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000>oooo00<0000co`0co`001C?o00?oool200001Oooo`030000
oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000
oooooooo00001S?o00?oool00`000?ooooooo`02oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo017oool200001c?o00?oool300000oooo`800003oooo00<0
003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.54) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.84911 .12361 L
.85396 .12361 L
.85916 .12361 L
.86176 .12361 L
.86423 .12361 L
.86531 .12361 L
.86645 .12361 L
s
.86645 .12361 m
.86695 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.10458 .12361 L
.11448 .12361 L
.11992 .12361 L
.12507 .12361 L
.12986 .12361 L
.13117 .12361 L
.13189 .12361 L
.13256 .12361 L
.13375 .12317 L
.13506 .12183 L
.14415 .11311 L
.16269 .09826 L
.18292 .08587 L
.19388 .08056 L
.20406 .0764 L
.22415 .07007 L
.23472 .06761 L
.24467 .06576 L
.25361 .06445 L
.26328 .06336 L
.27278 .0626 L
.27818 .06229 L
.28322 .06207 L
.28595 .06198 L
.28853 .06191 L
.29086 .06187 L
.29216 .06185 L
.29338 .06183 L
.29469 .06182 L
.29538 .06181 L
.29613 .06181 L
.29687 .06181 L
.29765 .0618 L
.29831 .0618 L
.29904 .0618 L
.30036 .06181 L
.30109 .06181 L
.30176 .06182 L
.30306 .06183 L
.30428 .06184 L
.30667 .06188 L
.30891 .06192 L
.314 .06205 L
.31896 .06223 L
.32429 .06246 L
.34275 .06359 L
.36392 .06538 L
Mistroke
.38402 .06745 L
.42227 .07198 L
.46297 .0772 L
.4818 .07964 L
.4917 .08091 L
.50215 .08223 L
.50748 .08276 L
.51031 .08299 L
.51333 .08319 L
.51611 .08334 L
.51864 .08345 L
.52119 .08353 L
.5236 .08359 L
.52476 .08361 L
.52604 .08363 L
.52668 .08364 L
.52738 .08364 L
.52863 .08365 L
.52981 .08365 L
.53105 .08365 L
.53211 .08364 L
.53327 .08363 L
.53399 .08363 L
.53466 .08362 L
.53591 .0836 L
.53872 .08354 L
.54115 .08347 L
.54378 .08339 L
.55327 .08294 L
.5637 .08224 L
.58475 .08031 L
.62515 .0751 L
.66402 .06878 L
.70535 .06108 L
.74516 .05302 L
.78346 .04501 L
.82421 .03673 L
.84444 .03295 L
.85435 .03123 L
.85869 .03052 L
.86099 .03015 L
.86345 .02976 L
.86468 .02957 L
.86584 .02939 L
.86689 .12361 L
.86802 .12361 L
.87228 .12361 L
.88159 .12361 L
.90116 .12361 L
.94205 .12361 L
Mistroke
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.54) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`1Boooo2@1Voc?oool0
08ooool00`000?ooooooo`1=oooo1@1Vo`Soool00`1Vooooooooo`0aoooo002?oooo00<0003ooooo
ool0B?ooo`D0I_l=oooo00<0I_ooooooool0<Oooo`00Soooo`030000oooooooo04Coool406Ko4_oo
o`0306Kooooooooo037oool008ooool00`000?ooooooo`11oooo0`1VoaKoool00`1Vooooooooo`0a
oooo002?oooo0P0003koool406Ko6Oooo`0306Kooooooooo037oool008ooool00`000?ooooooo`0i
oooo101Voagoool00`1Vooooooooo`0aoooo002?oooo00<0003oooooool0=?ooo`D0I_lQoooo00<0
I_ooooooool0<Oooo`00D?oooaX0I_lUoooo00<0003oooooool0;oooo`D0I_lVoooo00<0I_oooooo
ool0<Oooo`00Boooo`D0I_lJoooo3@1VoaSoool00`000?ooooooo`0Zoooo1@1Vob_oool00`1Voooo
ooooo`0aoooo0017oooo101Vobcoool706Ko4Oooo`030000oooooooo02?oool706Ko<?ooo`0306Ko
oooooooo037oool004?oool406Ko=oooo`H0I_l;oooo0P0001Woool;06Ko=oooo`0306Kooooooooo
037oool001Ooool400009_ooo`80I_lAoooo1@0002_oool806Ko0oooo`030000oooooooo013oool8
06Ko7oooo`D0000Noooo00<0I_ooooooool05oooo`@0000Foooo000Goooo00<0003oooooool09_oo
o`0306Kooooooooo01?oool00`000?ooooooo`0coooo0`1Vo`03000006Ko06Ko0100I_lYoooo00<0
003oooooool07_ooo`0306Kooooooooo01Ooool00`000?ooooooo`0Goooo000Hoooo00<0003ooooo
ool09?ooo`0306Kooooooooo01Coool00`000?ooooooo`0foooo00<0003oooooool0>Oooo`030000
oooooooo01koool00`1Vooooooooo`0Hoooo00<0003oooooool05_ooo`004Oooo`@00004oooo00<0
003oooooool08Oooo`80I_l?oooo100000Coool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo01koool00`1Vooooooooo`0Ioooo00<0003oooooool05Oooo`005oooo`040000
oooooooo00008?ooo`80I_lIoooo00<0003oooooool0=_ooo`030000oooooooo03Woool00`000?oo
ooooo`0Noooo00<0I_ooooooool05oooo`040000oooooooo00005_ooo`006?ooo`80000Ooooo0P1V
oa[oool20000>?ooo`80000ioooo0P00023oool00`1Vooooooooo`0Hoooo0P0001Ooool003Soool0
0`1Vooooooooo`1Doooo00<0003oooooool0F_ooo`0306Kooooooooo037oool003Ooool00`1Voooo
ooooo`1Eoooo00<0003oooooool0F_ooo`0306Kooooooooo037oool003Koool00`1Vooooooooo`1F
oooo00<0003oooooool0F_ooo`0306Kooooooooo037oool003Goool00`1Vooooooooo`1Goooo00<0
003oooooool0F_ooo`0306Kooooooooo037oool003?oool206KoF_ooo`030000oooooooo05[oool0
0`1Vooooooooo`0aoooo000@ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006<ol060000003o`2I
0000000000L00006oooo00<0003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol003Tco`0900006?ooo`03o`2Ioooooooo
01Woool00`000?ooooooo`0Eoooo002?oooo00<0000co`0co`00<c?o00H0000Qoooo00?o09Wooooo
ool0<Oooo`00Soooo`030000<ol0<ol0034co`0200009oooo`03o`2Ioooooooo037oool008ooool0
0`0003?o03?o000_<ol00P0002Woool00ol0VOooooooo`0aoooo002?oooo00<0000co`0co`00;3?o
00<0000[oooo00?o09Woooooool0<Oooo`00Soooo`80000Z<ol00`0002koool00ol0VOooooooo`0a
oooo002?oooo00<0000co`0co`009c?o0080000aoooo00?o09Woooooool0<Oooo`00Soooo`030000
<ol0<ol002Hco`000`000?ooooooo`0aoooo00?o09Woooooool0<Oooo`00Soooo`030000<ol0<ol0
02Dco`000`000?ooooooo`0boooo00?o09Woooooool0<Oooo`00Soooo`030000<ol0<ol002@co`00
0`000?ooooooo`0coooo00?o09Woooooool0<Oooo`00Soooo`030000<ol0<ol0028co`020000=_oo
o`03o`2Ioooooooo037oool008ooool200008S?o00030000oooooooo03Koool00ol0VOooooooo`0a
oooo002?oooo00<0000co`0co`0083?o00030000oooooooo03Ooool00ol0VOooooooo`0aoooo002?
oooo00<0000co`0co`007c?o00030000oooooooo03Soool00ol0VOooooooo`0aoooo002?oooo00<0
000co`0co`007c?o00030000oooooooo03Soool00ol0VOooooooo`0aoooo002?oooo00<0000co`0c
o`007S?o00030000oooooooo03Woool00ol0VOooooooo`0aoooo002?oooo00<0000co`0co`007C?o
00030000oooooooo03[oool00ol0VOooooooo`0aoooo002?oooo0P0001dco`000`000?ooooooo`0k
oooo00?o09Woooooool0<Oooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0loooo00?o
09Woooooool0<Oooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0loooo00?o09Wooooo
ool0<Oooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0moooo00?o09Woooooool0<Ooo
o`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`0moooo00?o09Woooooool0<Oooo`00Sooo
o`030000<ol0<ol001Tco`000`000?ooooooo`0noooo00?o09Woooooool0<Oooo`00Soooo`80000J
<ol000<0003oooooool0?_ooo`03o`2Ioooooooo037oool008ooool00`0003?o03?o000H<ol000<0
003oooooool0?oooo`03o`2Ioooooooo037oool008ooool00`0003?o03?o000H<ol000<0003ooooo
ool0?oooo`03o`2Ioooooooo037oool008ooool00`0003?o03?o000G<ol000<0003oooooool0@?oo
o`03o`2Ioooooooo037oool008ooool00`0003?o03?o000G<ol000<0003oooooool0@?ooo`03o`2I
oooooooo037oool008Ooool500000oooo`030000<ol0<ol001Hco`000`000?ooooooo`11oooo00?o
09Woooooool0<Oooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000F<ol000<0003ooooo
ool0@Oooo`03o`2Ioooooooo037oool008Woool00`000?ooooooo`03oooo0`0001Dco`000`000?oo
ooooo`12oooo00?o09Woooooool0<Oooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E
<ol000<0003oooooool0@_ooo`03o`2Ioooooooo037oool008Woool00`000?ooooooo`03oooo00<0
000co`0co`005C?o00030000oooooooo04;oool00ol0VOooooooo`0aoooo0028oooo0P0000Goool0
0`0003?o03?o000D<ol000<0003oooooool0@oooo`03o`2Ioooooooo037oool008ooool00`0003?o
03?o000D<ol000<0003oooooool0@oooo`03o`2Ioooooooo037oool008ooool00`0003?o03?o000C
<ol000<0003oooooool0A?ooo`03o`2Ioooooooo037oool008ooool2000053?o00030000oooooooo
04Coool00ol0VOooooooo`0aoooo002?oooo00<0000co`0co`004c?o00030000oooooooo04Coool0
0ol0VOooooooo`0aoooo002?oooo00<0000co`0co`004S?o00030000oooooooo04Goool00ol0VOoo
ooooo`0aoooo002?oooo00<0000co`0co`004S?o00030000oooooooo04Goool00ol0VOooooooo`0a
oooo002?oooo00<0000co`0co`004S?o00030000oooooooo04Goool00ol0VOooooooo`0aoooo002?
oooo00<0000co`0co`004C?o00030000oooooooo04Koool00ol0VOooooooo`0aoooo002?oooo0P00
018co`000`000?ooooooo`16oooo00?o09Woooooool0<Oooo`00Soooo`030000<ol0<ol0014co`00
0`000?ooooooo`16oooo00?o09Woooooool0<Oooo`00Soooo`030000<ol0<ol0014co`000`000?oo
ooooo`16oooo00?o09Woooooool0<Oooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`17
oooo00?o09Woooooool0<Oooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`17oooo00?o
09Woooooool0<Oooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`17oooo00?o09Wooooo
ool0<Oooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`17oooo00?o09Woooooool0<Ooo
o`00Soooo`80000@<ol000<0003oooooool0B?ooo`03o`2Ioooooooo037oool008ooool00`0003?o
03?o000?<ol000<0003oooooool0B?ooo`03o`2Ioooooooo037oool008ooool00`0003?o03?o000?
<ol000<0003oooooool0B?ooo`03o`2Ioooooooo037oool008ooool00`0003?o03?o000?<ol000<0
003oooooool0B?ooo`03o`2Ioooooooo037oool008ooool00`0003?o03?o000?<ol000<0003ooooo
ool0B?ooo`03o`2Ioooooooo037oool008ooool00`0003?o03?o000><ol000<0003oooooool0BOoo
o`03o`2Ioooooooo037oool008ooool200003c?o00030000oooooooo04Woool00ol0VOooooooo`0a
oooo002?oooo00<0000co`0co`003S?o00030000oooooooo04Woool00ol0VOooooooo`0aoooo002?
oooo00<0000co`0co`003S?o00030000oooooooo04Woool00ol0VOooooooo`0aoooo002?oooo00<0
000co`0co`003C?o00030000oooooooo04[oool00ol0VOooooooo`0aoooo0027oooo100000Coool0
0`0003?o03?o000=<ol000<0003oooooool0B_ooo`03o`2Ioooooooo037oool008Ooool00`000?oo
ooooo`05oooo00<0000co`0co`003C?o00030000oooooooo04[oool00ol0VOooooooo`0aoooo0028
oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0B_ooo`03o`2Ioooooooo037oool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo04[oool00ol0VOoo
ooooo`0aoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0033?o00030000oooooooo
04_oool00ol0VOooooooo`0aoooo0028oooo0P0000Goool00`0003?o03?o000<<ol000<0003ooooo
ool0Boooo`03o`2Ioooooooo037oool008ooool00`0003?o03?o000<<ol000<0003oooooool0Booo
o`03o`2Ioooooooo037oool008ooool00`0003?o03?o000<<ol000<0003oooooool0Boooo`03o`2I
oooooooo037oool008ooool200003C?o00030000oooooooo04_oool00ol0VOooooooo`0aoooo002?
oooo00<0000co`0co`0033?o00030000oooooooo04_oool00ol0VOooooooo`0aoooo002?oooo00<0
000co`0co`002c?o00030000oooooooo04coool00ol0VOooooooo`0aoooo002?oooo00<0000co`0c
o`002c?o00030000oooooooo04coool00ol0VOooooooo`0aoooo002?oooo00<0000co`0co`002c?o
00030000oooooooo04coool00ol0VOooooooo`0aoooo002?oooo00<0000co`0co`002c?o00030000
oooooooo04coool00ol0VOooooooo`0aoooo002?oooo00<0000co`0co`002c?o00030000oooooooo
04coool00ol0VOooooooo`0aoooo002?oooo0P0000`co`000`000?ooooooo`1<oooo00?o09Wooooo
ool0<Oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1<oooo00?o09Woooooool0<Ooo
o`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1=oooo00?o09Woooooool0<Oooo`00Sooo
o`030000<ol0<ol000Xco`000`000?ooooooo`1=oooo00?o09Woooooool0<Oooo`00Soooo`030000
<ol0<ol000Xco`000`000?ooooooo`1=oooo00?o09Woooooool0<Oooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`1=oooo00?o09Woooooool0<Oooo`00Soooo`80000;<ol000<0003ooooo
ool0COooo`03o`2Ioooooooo037oool008ooool00`0003?o03?o000:<ol000<0003oooooool0COoo
o`03o`2Ioooooooo037oool008ooool00`0003?o03?o000:<ol000<0003oooooool0COooo`03o`2I
oooooooo037oool008ooool00`0003?o03?o0009<ol000<0003oooooool0C_ooo`03o`2Ioooooooo
037oool008ooool00`0003?o03?o0009<ol000<0003oooooool0C_ooo`03o`2Ioooooooo037oool0
08ooool00`0003?o03?o0009<ol000<0003oooooool0C_ooo`03o`2Ioooooooo037oool008ooool2
00002S?o00030000oooooooo04koool00ol0VOooooooo`0aoooo002?oooo00<0000co`0co`002C?o
00030000oooooooo04koool00ol0VOooooooo`0aoooo002?oooo00<0000co`0co`002C?o00030000
oooooooo04koool00ol0VOooooooo`0aoooo002?oooo00<0000co`0co`0023?o00030000oooooooo
04ooool00ol0VOooooooo`0aoooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0003ooooo
ool0Coooo`03o`2Ioooooooo037oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008
<ol000<0003oooooool0Coooo`03o`2Ioooooooo037oool008Woool00`000?ooooooo`03oooo0`00
00Pco`000`000?ooooooo`1?oooo00?o09Woooooool0<Oooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o0008<ol000<0003oooooool0Coooo`03o`2Ioooooooo037oool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0Coooo`03o`2Ioooooooo037oool0
08Soool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`1@oooo00?o09Woooooool0<Ooo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1@oooo00?o09Woooooool0<Oooo`00Sooo
o`030000<ol0<ol000Lco`000`000?ooooooo`1@oooo00?o09Woooooool0<Oooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`1@oooo00?o09Woooooool0<Oooo`00Soooo`800008<ol000<0
003oooooool0D?ooo`03o`2Ioooooooo037oool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool0D?ooo`03o`2Ioooooooo037oool008ooool00`0003?o03?o0007<ol000<0003oooooool0D?oo
o`03o`2Ioooooooo037oool008ooool00`0003?o03?o0007<ol000<0003oooooool0D?ooo`03o`2I
oooooooo037oool008ooool00`0003?o03?o0006<ol000<0003oooooool0DOooo`03o`2Ioooooooo
037oool008ooool00`0003?o03?o0006<ol000<0003oooooool0DOooo`03o`2Ioooooooo037oool0
08ooool200001c?o00030000oooooooo057oool00ol0VOooooooo`0aoooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo057oool00ol0VOooooooo`0aoooo002?oooo00<0000co`0co`001S?o
00030000oooooooo057oool00ol0VOooooooo`0aoooo002?oooo00<0000co`0co`001S?o00030000
oooooooo057oool00ol0VOooooooo`0aoooo002?oooo00<0000co`0co`001S?o00030000oooooooo
057oool00ol0VOooooooo`0aoooo002?oooo00<0000co`0co`001S?o00030000oooooooo057oool0
0ol0VOooooooo`0aoooo002?oooo0P0000Hco`000`000?ooooooo`1Boooo00?o09Woooooool0<Ooo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Boooo00?o09Woooooool0<Oooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`1Boooo00?o09Woooooool0<Oooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`1Boooo00?o09Woooooool0<Oooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`1Boooo00?o09Woooooool0<Oooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`1Boooo00?o09Woooooool0<Oooo`00Soooo`800006<ol000<0003oooooool0D_oo
o`03o`2Ioooooooo037oool008ooool00`0003?o03?o0005<ol000<0003oooooool0D_ooo`03o`2I
oooooooo037oool008ooool00`0003?o03?o0005<ol000<0003oooooool0D_ooo`03o`2Ioooooooo
037oool008ooool00`0003?o03?o0004<ol000<0003oooooool0Doooo`03o`2Ioooooooo037oool0
08ooool00`0003?o03?o0004<ol000<0003oooooool0Doooo`03o`2Ioooooooo037oool008Woool3
00000oooo`030000<ol0<ol000@co`000`000?ooooooo`1Coooo00?o09Woooooool0<Oooo`00R_oo
o`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0Doooo`03o`2Ioooooooo
037oool008Ooool500000oooo`<00004<ol000<0003oooooool0Doooo`03o`2Ioooooooo037oool0
08Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_oo
o`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0
003oooooool04oooo`Lco`0>oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool0
0`000?ooooooo`09oooo1c?o00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01_ooo`@00003<ol00P000004<ol0oooooooooooo0P0000Goool3
00000_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool00`000?ooooooo`07<ol00_ooo`040000oooooooo00001Ooo
o`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03_oo
o`030000oooo<ol000Hco`05oooo00<0003oooooool01@0000?oool00`000?ooooooo`1goooo001h
oooo00<0003oooooool01@0000koool00`0003?o03?o0005<ol00oooo`800003oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Hco`03oooo00<0003oooooool00oooo`030000oooo000000?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool04Oooo`800007<ol00oooo`<00004oooo0P0000;oool00`000?oo
ooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.56) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.84911 .12361 L
.85916 .12361 L
.86384 .12361 L
.86642 .12361 L
.86886 .12361 L
.86996 .12361 L
.87112 .12361 L
s
.87112 .12361 m
.87164 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.10458 .12361 L
.11448 .12361 L
.11992 .12361 L
.1226 .12361 L
.12507 .12361 L
.12739 .12361 L
.12857 .12361 L
.12986 .12228 L
.13506 .11714 L
.14415 .10894 L
.16519 .09339 L
.18444 .08272 L
.20432 .0746 L
.22321 .06912 L
.2328 .06704 L
.24302 .06527 L
.25266 .06398 L
.2614 .0631 L
.26628 .06272 L
.27143 .06239 L
.27582 .06218 L
.28065 .062 L
.28337 .06192 L
.28585 .06187 L
.28722 .06185 L
.28871 .06183 L
.28939 .06182 L
.29012 .06182 L
.29142 .06181 L
.2926 .0618 L
.29388 .0618 L
.29509 .06181 L
.2962 .06181 L
.29742 .06182 L
.29877 .06183 L
.30017 .06185 L
.30147 .06187 L
.30652 .06198 L
.30937 .06206 L
.31199 .06214 L
.32193 .06258 L
.33096 .06311 L
.34052 .06378 L
.3784 .06735 L
.41874 .07213 L
.45757 .07711 L
.47732 .07967 L
Mistroke
.48774 .08101 L
.49884 .08243 L
.50442 .08308 L
.50967 .08354 L
.51438 .08385 L
.51704 .08398 L
.51948 .08408 L
.52177 .08415 L
.52392 .0842 L
.52515 .08422 L
.52627 .08424 L
.52756 .08425 L
.52878 .08426 L
.52997 .08426 L
.53123 .08426 L
.53231 .08425 L
.53349 .08424 L
.53476 .08423 L
.53613 .08421 L
.5386 .08416 L
.54101 .0841 L
.54358 .08402 L
.5482 .08383 L
.55868 .08325 L
.56975 .08242 L
.5798 .0815 L
.61983 .07664 L
.65835 .07061 L
.69932 .06317 L
.73878 .05531 L
.77671 .04741 L
.81711 .03906 L
.83572 .03543 L
.85598 .03176 L
.86132 .03086 L
.86425 .03038 L
.867 .02994 L
.86933 .02958 L
.87064 .02937 L
.87184 .12361 L
.87309 .12361 L
.87445 .12361 L
.8772 .12361 L
.89731 .12361 L
.93784 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.56) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`1Eoooo1`1Voc;oool0
08ooool00`000?ooooooo`1@oooo1@1Vo`Koool00`1Vooooooooo`0`oooo002?oooo00<0003ooooo
ool0Boooo`D0I_l;oooo00<0I_ooooooool0<?ooo`00Soooo`030000oooooooo04Koool506Ko4?oo
o`0306Kooooooooo033oool008ooool00`000?ooooooo`11oooo1@1VoaGoool00`1Vooooooooo`0`
oooo002?oooo0P0003koool406Ko6_ooo`0306Kooooooooo033oool008ooool00`000?ooooooo`0h
oooo1@1Voakoool00`1Vooooooooo`0`oooo002?oooo00<0003oooooool0<oooo`D0I_lSoooo00<0
I_ooooooool0<?ooo`00D?oooa`0I_lSoooo00<0003oooooool0;_ooo`D0I_lXoooo00<0I_oooooo
ool0<?ooo`00Boooo`D0I_lLoooo2@1Voa[oool00`000?ooooooo`0Xoooo1P1Vobgoool00`1Voooo
ooooo`0`oooo0017oooo101Vob[oool806Ko4_ooo`030000oooooooo027oool706Ko<oooo`0306Ko
oooooooo033oool004?oool406Ko=_ooo`D0I_l=oooo0P0001[oool806Ko>_ooo`0306Kooooooooo
033oool001Ooool400009_ooo`80I_lAoooo1@0002Woool906Ko1?ooo`030000oooooooo01Coool5
06Ko7_ooo`D0000Ooooo00<0I_ooooooool05_ooo`@0000Foooo000Goooo00<0003oooooool09Ooo
o`80I_lEoooo00<0003oooooool0<_ooo`@0I_l00`00001Vo`1Vo`0D06Ko9Oooo`030000oooooooo
01ooool00`1Vooooooooo`0Foooo00<0003oooooool05oooo`006?ooo`030000oooooooo02;oool2
06Ko5oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool07oooo`0306Ko
oooooooo01Ooool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?ooooooo`0Ooooo0P1V
oa7oool400001?ooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool07ooo
o`0306Kooooooooo01Soool00`000?ooooooo`0Eoooo000Goooo00@0003oooooool0000Ooooo00<0
I_ooooooool06Oooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool07ooo
o`0306Kooooooooo01Koool010000?ooooooo`0001Koool001Soool200007oooo`0306Kooooooooo
01Woool20000>?ooo`80000ioooo0P00027oool00`1Vooooooooo`0Goooo0P0001Ooool003Ooool2
06KoE_ooo`030000oooooooo05_oool00`1Vooooooooo`0`oooo000foooo00<0I_ooooooool0E_oo
o`030000oooooooo05_oool00`1Vooooooooo`0`oooo000eoooo00<0I_ooooooool0Eoooo`030000
oooooooo05_oool00`1Vooooooooo`0`oooo000coooo0P1Voe[oool00`000?ooooooo`1Koooo00<0
I_ooooooool0<?ooo`00<_ooo`0306Kooooooooo05[oool00`000?ooooooo`1Koooo00<0I_oooooo
ool0<?ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o01T000000ol0V@0000000006
00001_ooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_oo
o`030000oooooooo03Woool00`0003?o03?o000i<ol02@0001Woool00ol0VOooooooo`0Hoooo00<0
003oooooool05Oooo`00Soooo`030000<ol0<ol003<co`0600008_ooo`03o`2Ioooooooo033oool0
08ooool00`0003?o03?o000a<ol00P0002Soool00ol0VOooooooo`0`oooo002?oooo00<0000co`0c
o`00;c?o0080000Zoooo00?o09Woooooool0<?ooo`00Soooo`030000<ol0<ol002`co`030000;?oo
o`03o`2Ioooooooo033oool008ooool20000:S?o00<0000_oooo00?o09Woooooool0<?ooo`00Sooo
o`030000<ol0<ol002Lco`020000<_ooo`03o`2Ioooooooo033oool008ooool00`0003?o03?o000V
<ol000<0003oooooool0<_ooo`03o`2Ioooooooo033oool008ooool00`0003?o03?o000U<ol000<0
003oooooool0<oooo`03o`2Ioooooooo033oool008ooool00`0003?o03?o000T<ol000<0003ooooo
ool0=?ooo`03o`2Ioooooooo033oool008ooool00`0003?o03?o000R<ol00P0003Ooool00ol0VOoo
ooooo`0`oooo002?oooo0P00028co`000`000?ooooooo`0goooo00?o09Woooooool0<?ooo`00Sooo
o`030000<ol0<ol0020co`000`000?ooooooo`0hoooo00?o09Woooooool0<?ooo`00Soooo`030000
<ol0<ol001lco`000`000?ooooooo`0ioooo00?o09Woooooool0<?ooo`00Soooo`030000<ol0<ol0
01lco`000`000?ooooooo`0ioooo00?o09Woooooool0<?ooo`00Soooo`030000<ol0<ol001hco`00
0`000?ooooooo`0joooo00?o09Woooooool0<?ooo`00Soooo`030000<ol0<ol001dco`000`000?oo
ooooo`0koooo00?o09Woooooool0<?ooo`00Soooo`80000M<ol000<0003oooooool0??ooo`03o`2I
oooooooo033oool008ooool00`0003?o03?o000K<ol000<0003oooooool0?Oooo`03o`2Ioooooooo
033oool008ooool00`0003?o03?o000K<ol000<0003oooooool0?Oooo`03o`2Ioooooooo033oool0
08ooool00`0003?o03?o000J<ol000<0003oooooool0?_ooo`03o`2Ioooooooo033oool008ooool0
0`0003?o03?o000J<ol000<0003oooooool0?_ooo`03o`2Ioooooooo033oool008ooool00`0003?o
03?o000I<ol000<0003oooooool0?oooo`03o`2Ioooooooo033oool008ooool200006S?o00030000
oooooooo03ooool00ol0VOooooooo`0`oooo002?oooo00<0000co`0co`0063?o00030000oooooooo
043oool00ol0VOooooooo`0`oooo002?oooo00<0000co`0co`0063?o00030000oooooooo043oool0
0ol0VOooooooo`0`oooo002?oooo00<0000co`0co`005c?o00030000oooooooo047oool00ol0VOoo
ooooo`0`oooo002?oooo00<0000co`0co`005c?o00030000oooooooo047oool00ol0VOooooooo`0`
oooo0027oooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool0@_ooo`03o`2Ioooooooo
033oool008Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo04;oool0
0ol0VOooooooo`0`oooo0029oooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0@ooo
o`03o`2Ioooooooo033oool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000
oooooooo04?oool00ol0VOooooooo`0`oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`13oooo00?o09Woooooool0<?ooo`00R?ooo`800005oooo00<0000co`0c
o`0053?o00030000oooooooo04Coool00ol0VOooooooo`0`oooo002?oooo00<0000co`0co`0053?o
00030000oooooooo04Coool00ol0VOooooooo`0`oooo002?oooo00<0000co`0co`004c?o00030000
oooooooo04Goool00ol0VOooooooo`0`oooo002?oooo0P0001@co`000`000?ooooooo`15oooo00?o
09Woooooool0<?ooo`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`15oooo00?o09Wooooo
ool0<?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`16oooo00?o09Woooooool0<?oo
o`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`16oooo00?o09Woooooool0<?ooo`00Sooo
o`030000<ol0<ol0018co`000`000?ooooooo`16oooo00?o09Woooooool0<?ooo`00Soooo`030000
<ol0<ol0014co`000`000?ooooooo`17oooo00?o09Woooooool0<?ooo`00Soooo`80000B<ol000<0
003oooooool0Aoooo`03o`2Ioooooooo033oool008ooool00`0003?o03?o000A<ol000<0003ooooo
ool0Aoooo`03o`2Ioooooooo033oool008ooool00`0003?o03?o000A<ol000<0003oooooool0Aooo
o`03o`2Ioooooooo033oool008ooool00`0003?o03?o000@<ol000<0003oooooool0B?ooo`03o`2I
oooooooo033oool008ooool00`0003?o03?o000@<ol000<0003oooooool0B?ooo`03o`2Ioooooooo
033oool008ooool00`0003?o03?o000@<ol000<0003oooooool0B?ooo`03o`2Ioooooooo033oool0
08ooool00`0003?o03?o000@<ol000<0003oooooool0B?ooo`03o`2Ioooooooo033oool008ooool2
000043?o00030000oooooooo04Woool00ol0VOooooooo`0`oooo002?oooo00<0000co`0co`003c?o
00030000oooooooo04Woool00ol0VOooooooo`0`oooo002?oooo00<0000co`0co`003c?o00030000
oooooooo04Woool00ol0VOooooooo`0`oooo002?oooo00<0000co`0co`003c?o00030000oooooooo
04Woool00ol0VOooooooo`0`oooo002?oooo00<0000co`0co`003c?o00030000oooooooo04Woool0
0ol0VOooooooo`0`oooo002?oooo00<0000co`0co`003S?o00030000oooooooo04[oool00ol0VOoo
ooooo`0`oooo002?oooo0P0000lco`000`000?ooooooo`1:oooo00?o09Woooooool0<?ooo`00Sooo
o`030000<ol0<ol000hco`000`000?ooooooo`1:oooo00?o09Woooooool0<?ooo`00Soooo`030000
<ol0<ol000hco`000`000?ooooooo`1:oooo00?o09Woooooool0<?ooo`00Soooo`030000<ol0<ol0
00dco`000`000?ooooooo`1;oooo00?o09Woooooool0<?ooo`00Qoooo`@00004oooo00<0000co`0c
o`003C?o00030000oooooooo04_oool00ol0VOooooooo`0`oooo0027oooo00<0003oooooool01Ooo
o`030000<ol0<ol000dco`000`000?ooooooo`1;oooo00?o09Woooooool0<?ooo`00R?ooo`030000
oooooooo00Coool300003C?o00030000oooooooo04_oool00ol0VOooooooo`0`oooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`1;oooo00?o09Woooooool0<?oo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1<oooo00?o
09Woooooool0<?ooo`00R?ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo04coool0
0ol0VOooooooo`0`oooo002?oooo00<0000co`0co`0033?o00030000oooooooo04coool00ol0VOoo
ooooo`0`oooo002?oooo00<0000co`0co`0033?o00030000oooooooo04coool00ol0VOooooooo`0`
oooo002?oooo0P0000dco`000`000?ooooooo`1<oooo00?o09Woooooool0<?ooo`00Soooo`030000
<ol0<ol000`co`000`000?ooooooo`1<oooo00?o09Woooooool0<?ooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`1=oooo00?o09Woooooool0<?ooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`1=oooo00?o09Woooooool0<?ooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`1=oooo00?o09Woooooool0<?ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1=
oooo00?o09Woooooool0<?ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1=oooo00?o
09Woooooool0<?ooo`00Soooo`80000<<ol000<0003oooooool0COooo`03o`2Ioooooooo033oool0
08ooool00`0003?o03?o000;<ol000<0003oooooool0COooo`03o`2Ioooooooo033oool008ooool0
0`0003?o03?o000:<ol000<0003oooooool0C_ooo`03o`2Ioooooooo033oool008ooool00`0003?o
03?o000:<ol000<0003oooooool0C_ooo`03o`2Ioooooooo033oool008ooool00`0003?o03?o000:
<ol000<0003oooooool0C_ooo`03o`2Ioooooooo033oool008ooool00`0003?o03?o000:<ol000<0
003oooooool0C_ooo`03o`2Ioooooooo033oool008ooool200002c?o00030000oooooooo04koool0
0ol0VOooooooo`0`oooo002?oooo00<0000co`0co`002S?o00030000oooooooo04koool00ol0VOoo
ooooo`0`oooo002?oooo00<0000co`0co`002S?o00030000oooooooo04koool00ol0VOooooooo`0`
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo04ooool00ol0VOooooooo`0`oooo002?
oooo00<0000co`0co`002C?o00030000oooooooo04ooool00ol0VOooooooo`0`oooo002?oooo00<0
000co`0co`002C?o00030000oooooooo04ooool00ol0VOooooooo`0`oooo002?oooo0P0000Xco`00
0`000?ooooooo`1?oooo00?o09Woooooool0<?ooo`00Soooo`030000<ol0<ol000Tco`000`000?oo
ooooo`1?oooo00?o09Woooooool0<?ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1?
oooo00?o09Woooooool0<?ooo`00Soooo`030000<ol0<ol000Pco`000`000?ooooooo`1@oooo00?o
09Woooooool0<?ooo`00R?ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo053oool0
0ol0VOooooooo`0`oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000
oooooooo053oool00ol0VOooooooo`0`oooo0029oooo00<0003oooooool00oooo`<00008<ol000<0
003oooooool0D?ooo`03o`2Ioooooooo033oool008[oool00`000?ooooooo`02oooo00<0000co`0c
o`0023?o00030000oooooooo053oool00ol0VOooooooo`0`oooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0023?o00030000oooooooo053oool00ol0VOooooooo`0`oooo0028oooo0P00
00Goool00`0003?o03?o0007<ol000<0003oooooool0DOooo`03o`2Ioooooooo033oool008ooool0
0`0003?o03?o0007<ol000<0003oooooool0DOooo`03o`2Ioooooooo033oool008ooool00`0003?o
03?o0007<ol000<0003oooooool0DOooo`03o`2Ioooooooo033oool008ooool00`0003?o03?o0007
<ol000<0003oooooool0DOooo`03o`2Ioooooooo033oool008ooool2000023?o00030000oooooooo
057oool00ol0VOooooooo`0`oooo002?oooo00<0000co`0co`001c?o00030000oooooooo057oool0
0ol0VOooooooo`0`oooo002?oooo00<0000co`0co`001c?o00030000oooooooo057oool00ol0VOoo
ooooo`0`oooo002?oooo00<0000co`0co`001c?o00030000oooooooo057oool00ol0VOooooooo`0`
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo05;oool00ol0VOooooooo`0`oooo002?
oooo00<0000co`0co`001S?o00030000oooooooo05;oool00ol0VOooooooo`0`oooo002?oooo0P00
00Lco`000`000?ooooooo`1Boooo00?o09Woooooool0<?ooo`00Soooo`030000<ol0<ol000Hco`00
0`000?ooooooo`1Boooo00?o09Woooooool0<?ooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`1Boooo00?o09Woooooool0<?ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1B
oooo00?o09Woooooool0<?ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Boooo00?o
09Woooooool0<?ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Boooo00?o09Wooooo
ool0<?ooo`00Soooo`800006<ol000<0003oooooool0Doooo`03o`2Ioooooooo033oool008ooool0
0`0003?o03?o0005<ol000<0003oooooool0Doooo`03o`2Ioooooooo033oool008ooool00`0003?o
03?o0005<ol000<0003oooooool0Doooo`03o`2Ioooooooo033oool008ooool00`0003?o03?o0005
<ol000<0003oooooool0Doooo`03o`2Ioooooooo033oool008ooool00`0003?o03?o0005<ol000<0
003oooooool0Doooo`03o`2Ioooooooo033oool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool0Doooo`03o`2Ioooooooo033oool008ooool200001S?o00030000oooooooo05?oool00ol0VOoo
ooooo`0`oooo002?oooo00<0000co`0co`001C?o00030000oooooooo05?oool00ol0VOooooooo`0`
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo05?oool00ol0VOooooooo`0`oooo002?
oooo00<0000co`0co`0013?o00030000oooooooo05Coool00ol0VOooooooo`0`oooo002?oooo00<0
000co`0co`0013?o00030000oooooooo05Coool00ol0VOooooooo`0`oooo0029oooo0`0000?oool0
0`0003?o03?o0004<ol000<0003oooooool0E?ooo`03o`2Ioooooooo033oool008[oool00`000?oo
ooooo`02oooo00<0000co`0co`0013?o00030000oooooooo05Coool00ol0VOooooooo`0`oooo0027
oooo1@0000?oool3000013?o00030000oooooooo05Coool00ol0VOooooooo`0`oooo0027oooo00@0
003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool2
00001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo
01?oool7<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool02Oooo`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool400000c?o0080000013?o0?ooooooooooo`800003oooo0`0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00<0003oooooool01c?o00;oool010000?ooooooo`0000;oool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo
00koool00`000?oooc?o0006<ol01Oooo`040000oooooooo00000_ooo`030000oooooooo00;oool0
0`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000koool00`0003?o03?o0005<ol00ooo
o`800003oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003ooo
o`040000oooooooo00001S?o00?oool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`03oooo0`0000?oool300000_oo
o`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.58) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.84911 .12361 L
.85916 .12361 L
.86384 .12361 L
.86886 .12361 L
.87129 .12361 L
.87359 .12361 L
.87459 .12361 L
.87566 .12361 L
s
.87566 .12361 m
.87613 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.0932 .12361 L
.10458 .12361 L
.11009 .12361 L
.11531 .12361 L
.11999 .12361 L
.12127 .12361 L
.12263 .12361 L
.12379 .12361 L
.12507 .12231 L
.14415 .10502 L
.16356 .09144 L
.18444 .08052 L
.19454 .0764 L
.20557 .07264 L
.21611 .06969 L
.22566 .06751 L
.23511 .06576 L
.24534 .06429 L
.25096 .06364 L
.25614 .06314 L
.26105 .06275 L
.26631 .06241 L
.2714 .06216 L
.27604 .06199 L
.27828 .06193 L
.28071 .06188 L
.28183 .06186 L
.28301 .06184 L
.28404 .06183 L
.28513 .06182 L
.28641 .06181 L
.28757 .06181 L
.28883 .0618 L
.28954 .0618 L
.2902 .06181 L
.2914 .06181 L
.2925 .06182 L
.29376 .06183 L
.29496 .06184 L
.29766 .06189 L
.30016 .06194 L
.3058 .0621 L
.31047 .06227 L
.31549 .0625 L
.32456 .063 L
.3452 .06455 L
.38648 .0688 L
Mistroke
.42624 .07368 L
.46448 .07863 L
.48584 .08138 L
.49592 .08266 L
.50518 .08375 L
.5099 .08416 L
.51488 .08447 L
.51747 .0846 L
.51989 .08469 L
.52253 .08477 L
.52402 .0848 L
.52537 .08483 L
.52655 .08484 L
.5278 .08485 L
.52887 .08486 L
.53005 .08486 L
.53131 .08486 L
.53202 .08486 L
.53267 .08486 L
.53387 .08485 L
.53513 .08483 L
.53742 .0848 L
.53954 .08475 L
.54436 .08461 L
.54943 .0844 L
.55491 .08411 L
.56486 .08346 L
.58346 .08181 L
.62443 .07674 L
.66389 .0705 L
.70182 .06361 L
.74222 .05558 L
.78109 .04748 L
.82242 .03895 L
.84309 .03493 L
.85219 .03325 L
.86224 .0315 L
.86684 .03073 L
.86926 .03033 L
.87181 .02993 L
.87404 .02958 L
.87531 .02938 L
.87649 .12361 L
.87758 .12361 L
.87857 .12361 L
.8808 .12361 L
.90053 .12361 L
.94048 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.58) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`1Foooo1`1Voc7oool0
08ooool00`000?ooooooo`1Boooo101Vo`Koool00`1Vooooooooo`0_oooo002?oooo00<0003ooooo
ool0COooo`D0I_l:oooo00<0I_ooooooool0;oooo`00Soooo`030000oooooooo04Ooool606Ko3ooo
o`0306Kooooooooo02ooool008ooool00`000?ooooooo`12oooo1@1VoaGoool00`1Vooooooooo`0_
oooo002?oooo0P0003koool506Ko6_ooo`0306Kooooooooo02ooool008ooool00`000?ooooooo`0h
oooo1@1Voaooool00`1Vooooooooo`0_oooo002?oooo00<0003oooooool0<oooo`D0I_lToooo00<0
I_ooooooool0;oooo`00C_oooad0I_lToooo00<0003oooooool0;_ooo`D0I_lYoooo00<0I_oooooo
ool0;oooo`00BOooo`D0I_lMoooo1@1Voaooool00`000?ooooooo`0Zoooo101Vobkoool00`1Voooo
ooooo`0_oooo0014oooo1@1VobOoool706Ko6?ooo`030000oooooooo02Goool506Ko<_ooo`0306Ko
oooooooo02ooool0047oool306Ko<oooo`X0I_l>oooo0P00027oool506Ko=oooo`0306Kooooooooo
02ooool001Ooool400009?ooo`80I_lCoooo1@0002Soool806Ko1_ooo`030000oooooooo01Soool8
06Ko5oooo`D0000Poooo00<0I_ooooooool05Oooo`@0000Foooo000Goooo00<0003oooooool08ooo
o`80I_lGoooo00<0003oooooool0<?ooo`H0I_l00`00001Vo`1Vo`0206Ko2?ooo`h0I_lQoooo00<0
003oooooool08?ooo`0306Kooooooooo01Goool00`000?ooooooo`0Goooo000Hoooo00<0003ooooo
ool08?ooo`80I_lIoooo00<0003oooooool0=_ooo`040000oooooooooooo2@1Vobooool00`000?oo
ooooo`0Poooo00<0I_ooooooool05_ooo`030000oooooooo01Koool0017oool400001?ooo`030000
oooooooo01koool00`1Vooooooooo`0Aoooo100000Coool00`000?ooooooo`0foooo00<0003ooooo
ool0>Oooo`030000oooooooo023oool00`1Vooooooooo`0Goooo00<0003oooooool05Oooo`005ooo
o`040000oooooooo00007_ooo`0306Kooooooooo01[oool00`000?ooooooo`0foooo00<0003ooooo
ool0>Oooo`030000oooooooo023oool00`1Vooooooooo`0Eoooo00@0003oooooool0000Foooo000H
oooo0P0001goool206Ko7?ooo`80000hoooo0P0003Woool200008_ooo`0306Kooooooooo01Koool2
00005oooo`00=_ooo`0306Kooooooooo05Koool00`000?ooooooo`1Loooo00<0I_ooooooool0;ooo
o`00=Oooo`0306Kooooooooo05Ooool00`000?ooooooo`1Loooo00<0I_ooooooool0;oooo`00=?oo
o`0306Kooooooooo05Soool00`000?ooooooo`1Loooo00<0I_ooooooool0;oooo`00<_ooo`80I_mK
oooo00<0003oooooool0G?ooo`0306Kooooooooo02ooool0037oool00`1Vooooooooo`1Koooo00<0
003oooooool0G?ooo`0306Kooooooooo02ooool0013ooooo00004Oooo`005_ooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o
00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol0
00Hco`0J000000?o09T0000000001@0000Koool00`000?ooooooo`09oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`00>C?o00T0000J
oooo00?o09Woooooool05oooo`030000oooooooo01Goool008ooool00`0003?o03?o000c<ol01P00
02?oool00ol0VOooooooo`0_oooo002?oooo00<0000co`0co`00<C?o0080000Yoooo00?o09Wooooo
ool0;oooo`00Soooo`030000<ol0<ol002lco`020000:oooo`03o`2Ioooooooo02ooool008ooool0
0`0003?o03?o000/<ol00`0002goool00ol0VOooooooo`0_oooo002?oooo0P0002Xco`030000<?oo
o`03o`2Ioooooooo02ooool008ooool00`0003?o03?o000W<ol00P0003?oool00ol0VOooooooo`0_
oooo002?oooo00<0000co`0co`009S?o00030000oooooooo03?oool00ol0VOooooooo`0_oooo002?
oooo00<0000co`0co`009C?o00030000oooooooo03Coool00ol0VOooooooo`0_oooo002?oooo00<0
000co`0co`0093?o00030000oooooooo03Goool00ol0VOooooooo`0_oooo002?oooo00<0000co`0c
o`008S?o0080000hoooo00?o09Woooooool0;oooo`00Soooo`80000R<ol000<0003oooooool0>?oo
o`03o`2Ioooooooo02ooool008ooool00`0003?o03?o000P<ol000<0003oooooool0>Oooo`03o`2I
oooooooo02ooool008ooool00`0003?o03?o000O<ol000<0003oooooool0>_ooo`03o`2Ioooooooo
02ooool008ooool00`0003?o03?o000O<ol000<0003oooooool0>_ooo`03o`2Ioooooooo02ooool0
08ooool00`0003?o03?o000N<ol000<0003oooooool0>oooo`03o`2Ioooooooo02ooool008ooool0
0`0003?o03?o000M<ol000<0003oooooool0??ooo`03o`2Ioooooooo02ooool008ooool200007C?o
00030000oooooooo03goool00ol0VOooooooo`0_oooo002?oooo00<0000co`0co`006c?o00030000
oooooooo03koool00ol0VOooooooo`0_oooo002?oooo00<0000co`0co`006c?o00030000oooooooo
03koool00ol0VOooooooo`0_oooo002?oooo00<0000co`0co`006S?o00030000oooooooo03ooool0
0ol0VOooooooo`0_oooo002?oooo00<0000co`0co`006S?o00030000oooooooo03ooool00ol0VOoo
ooooo`0_oooo002?oooo00<0000co`0co`006C?o00030000oooooooo043oool00ol0VOooooooo`0_
oooo002?oooo0P0001Xco`000`000?ooooooo`10oooo00?o09Woooooool0;oooo`00Soooo`030000
<ol0<ol001Pco`000`000?ooooooo`11oooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol0
01Pco`000`000?ooooooo`11oooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol001Lco`00
0`000?ooooooo`12oooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol001Lco`000`000?oo
ooooo`12oooo00?o09Woooooool0;oooo`00Qoooo`D00003oooo00<0000co`0co`005S?o00030000
oooooooo04?oool00ol0VOooooooo`0_oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
01Hco`000`000?ooooooo`13oooo00?o09Woooooool0;oooo`00ROooo`030000oooooooo00?oool3
00005C?o00030000oooooooo04Coool00ol0VOooooooo`0_oooo0029oooo00<0003oooooool00ooo
o`030000<ol0<ol001Dco`000`000?ooooooo`14oooo00?o09Woooooool0;oooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool0A?ooo`03o`2Ioooooooo02ooool0
08Soool200001Oooo`030000<ol0<ol001@co`000`000?ooooooo`15oooo00?o09Woooooool0;ooo
o`00Soooo`030000<ol0<ol001@co`000`000?ooooooo`15oooo00?o09Woooooool0;oooo`00Sooo
o`030000<ol0<ol001<co`000`000?ooooooo`16oooo00?o09Woooooool0;oooo`00Soooo`80000D
<ol000<0003oooooool0A_ooo`03o`2Ioooooooo02ooool008ooool00`0003?o03?o000C<ol000<0
003oooooool0A_ooo`03o`2Ioooooooo02ooool008ooool00`0003?o03?o000B<ol000<0003ooooo
ool0Aoooo`03o`2Ioooooooo02ooool008ooool00`0003?o03?o000B<ol000<0003oooooool0Aooo
o`03o`2Ioooooooo02ooool008ooool00`0003?o03?o000B<ol000<0003oooooool0Aoooo`03o`2I
oooooooo02ooool008ooool00`0003?o03?o000A<ol000<0003oooooool0B?ooo`03o`2Ioooooooo
02ooool008ooool200004S?o00030000oooooooo04Soool00ol0VOooooooo`0_oooo002?oooo00<0
000co`0co`004C?o00030000oooooooo04Soool00ol0VOooooooo`0_oooo002?oooo00<0000co`0c
o`004C?o00030000oooooooo04Soool00ol0VOooooooo`0_oooo002?oooo00<0000co`0co`0043?o
00030000oooooooo04Woool00ol0VOooooooo`0_oooo002?oooo00<0000co`0co`0043?o00030000
oooooooo04Woool00ol0VOooooooo`0_oooo002?oooo00<0000co`0co`0043?o00030000oooooooo
04Woool00ol0VOooooooo`0_oooo002?oooo00<0000co`0co`0043?o00030000oooooooo04Woool0
0ol0VOooooooo`0_oooo002?oooo0P00010co`000`000?ooooooo`1:oooo00?o09Woooooool0;ooo
o`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`1:oooo00?o09Woooooool0;oooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`1:oooo00?o09Woooooool0;oooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`1:oooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol0
00lco`000`000?ooooooo`1:oooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol000hco`00
0`000?ooooooo`1;oooo00?o09Woooooool0;oooo`00Soooo`80000?<ol000<0003oooooool0Booo
o`03o`2Ioooooooo02ooool008ooool00`0003?o03?o000><ol000<0003oooooool0Boooo`03o`2I
oooooooo02ooool008ooool00`0003?o03?o000><ol000<0003oooooool0Boooo`03o`2Ioooooooo
02ooool008ooool00`0003?o03?o000=<ol000<0003oooooool0C?ooo`03o`2Ioooooooo02ooool0
08Ooool400001?ooo`030000<ol0<ol000dco`000`000?ooooooo`1<oooo00?o09Woooooool0;ooo
o`00Qoooo`030000oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool0C?ooo`03o`2I
oooooooo02ooool008Soool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1<oooo00?o
09Woooooool0;oooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003ooooo
ool0C?ooo`03o`2Ioooooooo02ooool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000<
<ol000<0003oooooool0COooo`03o`2Ioooooooo02ooool008Soool200001Oooo`030000<ol0<ol0
00`co`000`000?ooooooo`1=oooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol000`co`00
0`000?ooooooo`1=oooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol000`co`000`000?oo
ooooo`1=oooo00?o09Woooooool0;oooo`00Soooo`80000=<ol000<0003oooooool0COooo`03o`2I
oooooooo02ooool008ooool00`0003?o03?o000<<ol000<0003oooooool0COooo`03o`2Ioooooooo
02ooool008ooool00`0003?o03?o000;<ol000<0003oooooool0C_ooo`03o`2Ioooooooo02ooool0
08ooool00`0003?o03?o000;<ol000<0003oooooool0C_ooo`03o`2Ioooooooo02ooool008ooool0
0`0003?o03?o000;<ol000<0003oooooool0C_ooo`03o`2Ioooooooo02ooool008ooool00`0003?o
03?o000;<ol000<0003oooooool0C_ooo`03o`2Ioooooooo02ooool008ooool00`0003?o03?o000;
<ol000<0003oooooool0C_ooo`03o`2Ioooooooo02ooool008ooool2000033?o00030000oooooooo
04koool00ol0VOooooooo`0_oooo002?oooo00<0000co`0co`002c?o00030000oooooooo04koool0
0ol0VOooooooo`0_oooo002?oooo00<0000co`0co`002S?o00030000oooooooo04ooool00ol0VOoo
ooooo`0_oooo002?oooo00<0000co`0co`002S?o00030000oooooooo04ooool00ol0VOooooooo`0_
oooo002?oooo00<0000co`0co`002S?o00030000oooooooo04ooool00ol0VOooooooo`0_oooo002?
oooo00<0000co`0co`002S?o00030000oooooooo04ooool00ol0VOooooooo`0_oooo002?oooo0P00
00/co`000`000?ooooooo`1?oooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol000Xco`00
0`000?ooooooo`1?oooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`1?oooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1@
oooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1@oooo00?o
09Woooooool0;oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1@oooo00?o09Wooooo
ool0;oooo`00Soooo`80000:<ol000<0003oooooool0D?ooo`03o`2Ioooooooo02ooool008ooool0
0`0003?o03?o0009<ol000<0003oooooool0D?ooo`03o`2Ioooooooo02ooool008ooool00`0003?o
03?o0009<ol000<0003oooooool0D?ooo`03o`2Ioooooooo02ooool008ooool00`0003?o03?o0008
<ol000<0003oooooool0DOooo`03o`2Ioooooooo02ooool008Soool200001Oooo`030000<ol0<ol0
00Pco`000`000?ooooooo`1Aoooo00?o09Woooooool0;oooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`1Aoooo00?o09Woooooool0;oooo`00ROooo`030000
oooooooo00?oool3000023?o00030000oooooooo057oool00ol0VOooooooo`0_oooo002:oooo00<0
003oooooool00_ooo`030000<ol0<ol000Pco`000`000?ooooooo`1Aoooo00?o09Woooooool0;ooo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`1Aoooo00?o
09Woooooool0;oooo`00R?ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo05;oool0
0ol0VOooooooo`0_oooo002?oooo00<0000co`0co`001c?o00030000oooooooo05;oool00ol0VOoo
ooooo`0_oooo002?oooo00<0000co`0co`001c?o00030000oooooooo05;oool00ol0VOooooooo`0_
oooo002?oooo00<0000co`0co`001c?o00030000oooooooo05;oool00ol0VOooooooo`0_oooo002?
oooo0P0000Pco`000`000?ooooooo`1Boooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol0
00Lco`000`000?ooooooo`1Boooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`1Boooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1Boooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1C
oooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Coooo00?o
09Woooooool0;oooo`00Soooo`800007<ol000<0003oooooool0Doooo`03o`2Ioooooooo02ooool0
08ooool00`0003?o03?o0006<ol000<0003oooooool0Doooo`03o`2Ioooooooo02ooool008ooool0
0`0003?o03?o0006<ol000<0003oooooool0Doooo`03o`2Ioooooooo02ooool008ooool00`0003?o
03?o0006<ol000<0003oooooool0Doooo`03o`2Ioooooooo02ooool008ooool00`0003?o03?o0006
<ol000<0003oooooool0Doooo`03o`2Ioooooooo02ooool008ooool00`0003?o03?o0006<ol000<0
003oooooool0Doooo`03o`2Ioooooooo02ooool008ooool200001S?o00030000oooooooo05Coool0
0ol0VOooooooo`0_oooo002?oooo00<0000co`0co`001C?o00030000oooooooo05Coool00ol0VOoo
ooooo`0_oooo002?oooo00<0000co`0co`001C?o00030000oooooooo05Coool00ol0VOooooooo`0_
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo05Coool00ol0VOooooooo`0_oooo002?
oooo00<0000co`0co`001C?o00030000oooooooo05Coool00ol0VOooooooo`0_oooo002?oooo00<0
000co`0co`001C?o00030000oooooooo05Coool00ol0VOooooooo`0_oooo002?oooo0P0000Hco`00
0`000?ooooooo`1Doooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`1Doooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1D
oooo00?o09Woooooool0;oooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`1Eoooo00?o
09Woooooool0;oooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`1Eoooo00?o09Wooooo
ool0;oooo`00ROooo`<00003oooo00<0000co`0co`0013?o00030000oooooooo05Goool00ol0VOoo
ooooo`0_oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`1E
oooo00?o09Woooooool0;oooo`00Qoooo`D00003oooo0`0000@co`000`000?ooooooo`1Eoooo00?o
09Woooooool0;oooo`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool0
00001?ooo`Lco`2:oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o
08[oool007Woool00`000?ooooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0
003oooooool02?ooo`030000oooooooo00Woool7<ol03oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000<co`02000000@co`3ooooo
ooooool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00Lco`02oooo00@0
003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000
oooooooo00;oool00`000?ooooooo`0>oooo00<0003ooolco`001S?o00Goool010000?ooooooo`00
00;oool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>
oooo00<0000co`0co`001C?o00?oool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000000ooool010000?ooooooo`0000Hco`03oooo00<0003oooooool00_oo
o`040000oooooooo00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P00
00Lco`03oooo0`0000?oool200000oooo`030000oooooooo07Woool008ooool7<ol0R_ooo`00Sooo
o`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.85916 .12361 L
.86886 .12361 L
.87359 .12361 L
.87791 .12361 L
.87903 .12361 L
.88025 .12361 L
s
.88025 .12361 m
.88071 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.0932 .12361 L
.10458 .12361 L
.11009 .12361 L
.1128 .12361 L
.11531 .12361 L
.11758 .12361 L
.11872 .12361 L
.11999 .12264 L
.12507 .11759 L
.14415 .10134 L
.16356 .08864 L
.18444 .07849 L
.19454 .07468 L
.20557 .07123 L
.21611 .06855 L
.22566 .06658 L
.23579 .06493 L
.24534 .06373 L
.25541 .06282 L
.26109 .06244 L
.26631 .06217 L
.27101 .062 L
.27364 .06193 L
.27604 .06188 L
.27828 .06184 L
.27954 .06183 L
.28071 .06182 L
.28173 .06181 L
.28286 .06181 L
.28403 .0618 L
.28513 .0618 L
.28634 .06181 L
.28766 .06182 L
.28833 .06182 L
.28904 .06183 L
.29032 .06184 L
.29281 .06188 L
.29508 .06193 L
.30059 .06208 L
.3058 .06227 L
.31552 .06275 L
.32581 .0634 L
.34426 .06489 L
.38215 .06885 L
.42249 .07381 L
.46131 .07884 L
.48106 .08138 L
Mistroke
.49149 .0827 L
.49721 .08342 L
.50259 .08408 L
.5078 .08458 L
.51053 .0848 L
.51342 .08498 L
.51586 .08512 L
.51853 .08524 L
.52096 .08532 L
.52322 .08538 L
.52441 .08541 L
.52571 .08543 L
.52693 .08544 L
.52806 .08545 L
.52907 .08546 L
.53019 .08546 L
.53136 .08546 L
.53246 .08546 L
.53367 .08545 L
.53495 .08544 L
.53604 .08543 L
.53722 .08541 L
.53988 .08535 L
.54235 .08528 L
.54742 .0851 L
.5529 .08485 L
.56285 .08424 L
.58145 .08268 L
.60136 .08051 L
.62242 .07778 L
.66036 .07193 L
.70075 .06472 L
.73963 .05707 L
.78096 .0485 L
.82077 .04023 L
.85907 .03287 L
.86925 .03111 L
.87424 .03029 L
.87642 .02994 L
.87766 .02975 L
.87882 .02957 L
.87995 .0294 L
.88115 .12361 L
.88244 .12361 L
.88362 .12361 L
.88879 .12361 L
.89982 .12361 L
.93977 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`1Foooo201Voc3oool0
08ooool00`000?ooooooo`1Aoooo1@1Vo`Ooool00`1Vooooooooo`0^oooo002?oooo00<0003ooooo
ool0C?ooo`D0I_l<oooo00<0I_ooooooool0;_ooo`00Soooo`030000oooooooo04Ooool506Ko4Ooo
o`0306Kooooooooo02koool008ooool00`000?ooooooo`13oooo101VoaKoool00`1Vooooooooo`0^
oooo002?oooo0P00047oool306Ko6_ooo`0306Kooooooooo02koool008ooool00`000?ooooooo`0l
oooo101Voagoool00`1Vooooooooo`0^oooo002?oooo00<0003oooooool0=_ooo`H0I_lQoooo00<0
I_ooooooool0;_ooo`00C_oooaL0I_lZoooo00<0003oooooool0;_ooo`P0I_lWoooo00<0I_oooooo
ool0;_ooo`00A_ooo`P0I_lGoooo1`1Vob?oool00`000?ooooooo`0Yoooo1@1Vobooool00`1Voooo
ooooo`0^oooo0014oooo0P1VobKoool:06Ko6Oooo`030000oooooooo02Coool506Ko=?ooo`0306Ko
oooooooo02koool0047oool306Ko<_ooo`X0I_l?oooo0P00023oool506Ko>Oooo`0306Kooooooooo
02koool001Ooool400009?ooo`80I_lCoooo1@0002Ooool806Ko1oooo`030000oooooooo01Goool:
06Ko6?ooo`D0000Roooo00<0I_ooooooool04oooo`@0000Foooo000Goooo00<0003oooooool08ooo
o`80I_lGoooo00<0003oooooool0;oooo`L0I_l00`00001Vooooo`0<oooo2@1VobCoool00`000?oo
ooooo`0Roooo00<0I_ooooooool04oooo`030000oooooooo01Ooool001Soool00`000?ooooooo`0P
oooo0P1VoaWoool00`000?ooooooo`0foooo00<0003oool0I_l0301Vobgoool00`000?ooooooo`0R
oooo00<0I_ooooooool05?ooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo
01koool00`1Vooooooooo`0Aoooo100000Coool00`000?ooooooo`0foooo00<0003oooooool0>Ooo
o`030000oooooooo02;oool00`1Vooooooooo`0Eoooo00<0003oooooool05Oooo`005oooo`040000
oooooooo00007Oooo`80I_lLoooo00<0003oooooool0=_ooo`030000oooooooo03Woool00`000?oo
ooooo`0Roooo00<0I_ooooooool04oooo`040000oooooooo00005_ooo`006?ooo`80000Loooo0P1V
oagoool20000>?ooo`80000ioooo0P0002Coool00`1Vooooooooo`0Doooo0P0001Ooool003Goool0
0`1Vooooooooo`1Goooo00<0003oooooool0G_ooo`0306Kooooooooo02goool003Coool00`1Voooo
ooooo`1Hoooo00<0003oooooool0G_ooo`0306Kooooooooo02goool003;oool206KoFoooo`030000
oooooooo05koool00`1Vooooooooo`0]oooo000aoooo00<0I_ooooooool0Foooo`030000oooooooo
05koool00`1Vooooooooo`0]oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo05koool0
0`1Vooooooooo`0]oooo000@ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0006<ol06`000003o`2I
0000000000@00006oooo00<0003oooooool02Oooo`030000oooooooo01Goool001Koool00`000?oo
ooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol003Tco`0900006oooo`03o`2Ioooooooo
01Koool00`000?ooooooo`0Eoooo002?oooo00<0000co`0co`00<c?o00H0000Toooo00?o09Wooooo
ool0;_ooo`00Soooo`030000<ol0<ol0034co`020000:_ooo`03o`2Ioooooooo02koool008ooool0
0`0003?o03?o000_<ol00P0002coool00ol0VOooooooo`0^oooo002?oooo00<0000co`0co`00;3?o
00<0000^oooo00?o09Woooooool0;_ooo`00Soooo`80000Z<ol00`00037oool00ol0VOooooooo`0^
oooo002?oooo00<0000co`0co`009c?o0080000doooo00?o09Woooooool0;_ooo`00Soooo`030000
<ol0<ol002Hco`000`000?ooooooo`0doooo00?o09Woooooool0;_ooo`00Soooo`030000<ol0<ol0
02Dco`000`000?ooooooo`0eoooo00?o09Woooooool0;_ooo`00Soooo`030000<ol0<ol002@co`00
0`000?ooooooo`0foooo00?o09Woooooool0;_ooo`00Soooo`030000<ol0<ol0028co`020000>Ooo
o`03o`2Ioooooooo02koool008ooool200008S?o00030000oooooooo03Woool00ol0VOooooooo`0^
oooo002?oooo00<0000co`0co`0083?o00030000oooooooo03[oool00ol0VOooooooo`0^oooo002?
oooo00<0000co`0co`007c?o00030000oooooooo03_oool00ol0VOooooooo`0^oooo002?oooo00<0
000co`0co`007c?o00030000oooooooo03_oool00ol0VOooooooo`0^oooo002?oooo00<0000co`0c
o`007S?o00030000oooooooo03coool00ol0VOooooooo`0^oooo002?oooo00<0000co`0co`007C?o
00030000oooooooo03goool00ol0VOooooooo`0^oooo002?oooo0P0001dco`000`000?ooooooo`0n
oooo00?o09Woooooool0;_ooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0ooooo00?o
09Woooooool0;_ooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`0ooooo00?o09Wooooo
ool0;_ooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`10oooo00?o09Woooooool0;_oo
o`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`10oooo00?o09Woooooool0;_ooo`00Sooo
o`030000<ol0<ol001Tco`000`000?ooooooo`11oooo00?o09Woooooool0;_ooo`00Soooo`80000J
<ol000<0003oooooool0@Oooo`03o`2Ioooooooo02koool008ooool00`0003?o03?o000H<ol000<0
003oooooool0@_ooo`03o`2Ioooooooo02koool008ooool00`0003?o03?o000H<ol000<0003ooooo
ool0@_ooo`03o`2Ioooooooo02koool008ooool00`0003?o03?o000G<ol000<0003oooooool0@ooo
o`03o`2Ioooooooo02koool008ooool00`0003?o03?o000G<ol000<0003oooooool0@oooo`03o`2I
oooooooo02koool008Ooool500000oooo`030000<ol0<ol001Hco`000`000?ooooooo`14oooo00?o
09Woooooool0;_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000F<ol000<0003ooooo
ool0A?ooo`03o`2Ioooooooo02koool008Woool00`000?ooooooo`03oooo0`0001Dco`000`000?oo
ooooo`15oooo00?o09Woooooool0;_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E
<ol000<0003oooooool0AOooo`03o`2Ioooooooo02koool008Woool00`000?ooooooo`03oooo00<0
000co`0co`005C?o00030000oooooooo04Goool00ol0VOooooooo`0^oooo0028oooo0P0000Goool0
0`0003?o03?o000D<ol000<0003oooooool0A_ooo`03o`2Ioooooooo02koool008ooool00`0003?o
03?o000D<ol000<0003oooooool0A_ooo`03o`2Ioooooooo02koool008ooool00`0003?o03?o000C
<ol000<0003oooooool0Aoooo`03o`2Ioooooooo02koool008ooool2000053?o00030000oooooooo
04Ooool00ol0VOooooooo`0^oooo002?oooo00<0000co`0co`004c?o00030000oooooooo04Ooool0
0ol0VOooooooo`0^oooo002?oooo00<0000co`0co`004S?o00030000oooooooo04Soool00ol0VOoo
ooooo`0^oooo002?oooo00<0000co`0co`004S?o00030000oooooooo04Soool00ol0VOooooooo`0^
oooo002?oooo00<0000co`0co`004S?o00030000oooooooo04Soool00ol0VOooooooo`0^oooo002?
oooo00<0000co`0co`004C?o00030000oooooooo04Woool00ol0VOooooooo`0^oooo002?oooo0P00
018co`000`000?ooooooo`19oooo00?o09Woooooool0;_ooo`00Soooo`030000<ol0<ol0014co`00
0`000?ooooooo`19oooo00?o09Woooooool0;_ooo`00Soooo`030000<ol0<ol0014co`000`000?oo
ooooo`19oooo00?o09Woooooool0;_ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`1:
oooo00?o09Woooooool0;_ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`1:oooo00?o
09Woooooool0;_ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`1:oooo00?o09Wooooo
ool0;_ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`1:oooo00?o09Woooooool0;_oo
o`00Soooo`80000@<ol000<0003oooooool0Boooo`03o`2Ioooooooo02koool008ooool00`0003?o
03?o000?<ol000<0003oooooool0Boooo`03o`2Ioooooooo02koool008ooool00`0003?o03?o000?
<ol000<0003oooooool0Boooo`03o`2Ioooooooo02koool008ooool00`0003?o03?o000?<ol000<0
003oooooool0Boooo`03o`2Ioooooooo02koool008ooool00`0003?o03?o000?<ol000<0003ooooo
ool0Boooo`03o`2Ioooooooo02koool008ooool00`0003?o03?o000><ol000<0003oooooool0C?oo
o`03o`2Ioooooooo02koool008ooool200003c?o00030000oooooooo04coool00ol0VOooooooo`0^
oooo002?oooo00<0000co`0co`003S?o00030000oooooooo04coool00ol0VOooooooo`0^oooo002?
oooo00<0000co`0co`003S?o00030000oooooooo04coool00ol0VOooooooo`0^oooo002?oooo00<0
000co`0co`003C?o00030000oooooooo04goool00ol0VOooooooo`0^oooo0027oooo100000Coool0
0`0003?o03?o000=<ol000<0003oooooool0COooo`03o`2Ioooooooo02koool008Ooool00`000?oo
ooooo`05oooo00<0000co`0co`003C?o00030000oooooooo04goool00ol0VOooooooo`0^oooo0028
oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0COooo`03o`2Ioooooooo02koool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo04koool00ol0VOoo
ooooo`0]oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0033?o00030000oooooooo
04ooool00ol0VOooooooo`0]oooo0028oooo0P0000Goool00`0003?o03?o000<<ol000<0003ooooo
ool0Coooo`03o`2Ioooooooo02goool008ooool00`0003?o03?o000<<ol000<0003oooooool0Cooo
o`03o`2Ioooooooo02goool008ooool00`0003?o03?o000<<ol000<0003oooooool0Coooo`03o`2I
oooooooo02goool008ooool200003C?o00030000oooooooo04ooool00ol0VOooooooo`0]oooo002?
oooo00<0000co`0co`0033?o00030000oooooooo04ooool00ol0VOooooooo`0]oooo002?oooo00<0
000co`0co`002c?o00030000oooooooo053oool00ol0VOooooooo`0]oooo002?oooo00<0000co`0c
o`002c?o00030000oooooooo053oool00ol0VOooooooo`0]oooo002?oooo00<0000co`0co`002c?o
00030000oooooooo053oool00ol0VOooooooo`0]oooo002?oooo00<0000co`0co`002c?o00030000
oooooooo053oool00ol0VOooooooo`0]oooo002?oooo00<0000co`0co`002c?o00030000oooooooo
053oool00ol0VOooooooo`0]oooo002?oooo0P0000`co`000`000?ooooooo`1@oooo00?o09Wooooo
ool0;Oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1@oooo00?o09Woooooool0;Ooo
o`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1Aoooo00?o09Woooooool0;Oooo`00Sooo
o`030000<ol0<ol000Xco`000`000?ooooooo`1Aoooo00?o09Woooooool0;Oooo`00Soooo`030000
<ol0<ol000Xco`000`000?ooooooo`1Aoooo00?o09Woooooool0;Oooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`1Aoooo00?o09Woooooool0;Oooo`00Soooo`80000;<ol000<0003ooooo
ool0DOooo`03o`2Ioooooooo02goool008ooool00`0003?o03?o000:<ol000<0003oooooool0DOoo
o`03o`2Ioooooooo02goool008ooool00`0003?o03?o000:<ol000<0003oooooool0DOooo`03o`2I
oooooooo02goool008ooool00`0003?o03?o0009<ol000<0003oooooool0D_ooo`03o`2Ioooooooo
02goool008ooool00`0003?o03?o0009<ol000<0003oooooool0D_ooo`03o`2Ioooooooo02goool0
08ooool00`0003?o03?o0009<ol000<0003oooooool0D_ooo`03o`2Ioooooooo02goool008ooool2
00002S?o00030000oooooooo05;oool00ol0VOooooooo`0]oooo002?oooo00<0000co`0co`002C?o
00030000oooooooo05;oool00ol0VOooooooo`0]oooo002?oooo00<0000co`0co`002C?o00030000
oooooooo05;oool00ol0VOooooooo`0]oooo002?oooo00<0000co`0co`0023?o00030000oooooooo
05?oool00ol0VOooooooo`0]oooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0003ooooo
ool0Doooo`03o`2Ioooooooo02goool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008
<ol000<0003oooooool0Doooo`03o`2Ioooooooo02goool008Woool00`000?ooooooo`03oooo0`00
00Pco`000`000?ooooooo`1Coooo00?o09Woooooool0;Oooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o0008<ol000<0003oooooool0Doooo`03o`2Ioooooooo02goool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0Doooo`03o`2Ioooooooo02goool0
08Soool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`1Doooo00?o09Woooooool0;Ooo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1Doooo00?o09Woooooool0;Oooo`00Sooo
o`030000<ol0<ol000Lco`000`000?ooooooo`1Doooo00?o09Woooooool0;Oooo`00Soooo`030000
<ol0<ol000Lco`000`000?ooooooo`1Doooo00?o09Woooooool0;Oooo`00Soooo`800008<ol000<0
003oooooool0E?ooo`03o`2Ioooooooo02goool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool0E?ooo`03o`2Ioooooooo02goool008ooool00`0003?o03?o0007<ol000<0003oooooool0E?oo
o`03o`2Ioooooooo02goool008ooool00`0003?o03?o0007<ol000<0003oooooool0E?ooo`03o`2I
oooooooo02goool008ooool00`0003?o03?o0006<ol000<0003oooooool0EOooo`03o`2Ioooooooo
02goool008ooool00`0003?o03?o0006<ol000<0003oooooool0EOooo`03o`2Ioooooooo02goool0
08ooool200001c?o00030000oooooooo05Goool00ol0VOooooooo`0]oooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo05Goool00ol0VOooooooo`0]oooo002?oooo00<0000co`0co`001S?o
00030000oooooooo05Goool00ol0VOooooooo`0]oooo002?oooo00<0000co`0co`001S?o00030000
oooooooo05Goool00ol0VOooooooo`0]oooo002?oooo00<0000co`0co`001S?o00030000oooooooo
05Goool00ol0VOooooooo`0]oooo002?oooo00<0000co`0co`001S?o00030000oooooooo05Goool0
0ol0VOooooooo`0]oooo002?oooo0P0000Hco`000`000?ooooooo`1Foooo00?o09Woooooool0;Ooo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Foooo00?o09Woooooool0;Oooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`1Foooo00?o09Woooooool0;Oooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`1Foooo00?o09Woooooool0;Oooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`1Foooo00?o09Woooooool0;Oooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`1Foooo00?o09Woooooool0;Oooo`00Soooo`800006<ol000<0003oooooool0E_oo
o`03o`2Ioooooooo02goool008ooool00`0003?o03?o0005<ol000<0003oooooool0E_ooo`03o`2I
oooooooo02goool008ooool00`0003?o03?o0005<ol000<0003oooooool0E_ooo`03o`2Ioooooooo
02goool008ooool00`0003?o03?o0004<ol000<0003oooooool0Eoooo`03o`2Ioooooooo02goool0
08ooool00`0003?o03?o0004<ol000<0003oooooool0Eoooo`03o`2Ioooooooo02goool008Woool3
00000oooo`030000<ol0<ol000@co`000`000?ooooooo`1Goooo00?o09Woooooool0;Oooo`00R_oo
o`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0Eoooo`03o`2Ioooooooo
02goool008Ooool500000oooo`<00004<ol000<0003oooooool0Eoooo`03o`2Ioooooooo02goool0
08Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_oo
o`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001loooo00<0
003oooooool04?ooo`Lco`0;oooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool0
0`000?ooooooo`06oooo1c?o00coool00`000?ooooooo`1koooo001koooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01_ooo`@00003<ol00P0000?oool300001?ooo`030000oooooooo
07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Goool00`0003?o03?o0004<ol01Oooo`040000oooooooo00000oooo`030000oooooooo07_oool0
07[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`03<ol00000<ol000@co`05oooo00@0
003oooooool00004oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<oooo0S?o
00030000<ol0<ol0008co`05oooo0`0000Coool00`000?ooooooo`1koooo001koooo00D0003ooooo
ooooool000003oooo`040000<ol0<ol000000c?o00Koool00`000?ooooooo`03oooo00<0003ooooo
ool0Noooo`00O?ooo`030000oooooooo013oool00c?o000000000004<ol01_ooo`<00002oooo00<0
003oooooool0O?ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.62) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.85916 .12361 L
.86886 .12361 L
.87791 .12361 L
.88246 .12361 L
.88378 .12361 L
.88502 .12361 L
s
.88502 .12361 m
.88546 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.0932 .12361 L
.09905 .12361 L
.10458 .12361 L
.10972 .12361 L
.11113 .12361 L
.11263 .12361 L
.1139 .12361 L
.11463 .12325 L
.11531 .12255 L
.12507 .11315 L
.14415 .0979 L
.1644 .08559 L
.18292 .0772 L
.20191 .07093 L
.21266 .06826 L
.22263 .06627 L
.2332 .06463 L
.24315 .06347 L
.25209 .06271 L
.25713 .06239 L
.26176 .06217 L
.26646 .06199 L
.2691 .06192 L
.2715 .06187 L
.27373 .06184 L
.275 .06182 L
.27616 .06181 L
.27718 .06181 L
.27831 .0618 L
.27948 .0618 L
.28059 .06181 L
.28179 .06181 L
.28311 .06182 L
.28449 .06183 L
.28577 .06185 L
.28807 .06188 L
.29053 .06193 L
.29615 .06209 L
.30125 .06228 L
.31123 .06278 L
.32043 .06336 L
.34123 .06504 L
.38063 .06923 L
.41852 .07392 L
.45886 .07913 L
.47744 .08152 L
.49769 .08408 L
Mistroke
.50301 .08471 L
.50867 .08524 L
.51143 .08545 L
.51402 .08561 L
.51886 .08584 L
.52131 .08592 L
.52265 .08596 L
.5239 .08599 L
.5261 .08603 L
.52727 .08604 L
.52852 .08605 L
.52922 .08606 L
.52987 .08606 L
.53058 .08606 L
.53133 .08606 L
.53259 .08606 L
.53331 .08605 L
.53399 .08605 L
.53524 .08603 L
.53638 .08602 L
.53896 .08597 L
.54146 .08591 L
.54372 .08585 L
.54879 .08566 L
.55792 .08519 L
.56859 .08446 L
.57864 .08361 L
.61716 .07923 L
.65813 .07312 L
.69758 .06621 L
.73552 .05886 L
.77591 .05054 L
.81479 .04242 L
.83458 .03841 L
.85612 .03426 L
.86614 .03245 L
.87163 .03151 L
.87679 .03065 L
.88117 .02994 L
.88236 .02975 L
.88363 .02956 L
.88471 .02939 L
.88589 .12361 L
.8872 .12361 L
.8884 .12361 L
.89109 .12361 L
.89593 .12361 L
.93588 .12361 L
.97432 .12361 L
.97619 .12361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.62) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`1Ioooo1`1Vobkoool0
08ooool00`000?ooooooo`1Eoooo101Vo`Koool00`1Vooooooooo`0/oooo002?oooo00<0003ooooo
ool0D?ooo`D0I_l:oooo00<0I_ooooooool0;?ooo`00Soooo`030000oooooooo04_oool506Ko3ooo
o`0306Kooooooooo02coool008ooool00`000?ooooooo`16oooo1@1VoaCoool00`1Vooooooooo`0/
oooo002?oooo0P0004;oool506Ko6Oooo`0306Kooooooooo02coool008ooool00`000?ooooooo`0l
oooo1@1Voakoool00`1Vooooooooo`0/oooo002?oooo00<0003oooooool0=oooo`D0I_lSoooo00<0
I_ooooooool0;?ooo`00BooooaT0I_l[oooo00<0003oooooool0<_ooo`D0I_lXoooo00<0I_oooooo
ool0;?ooo`00AOooo`H0I_lIoooo201Vob?oool00`000?ooooooo`0]oooo1@1Vobgoool00`1Voooo
ooooo`0/oooo0013oooo0P1VobOoool:06Ko6Oooo`030000oooooooo02Soool506Ko<_ooo`0306Ko
oooooooo02coool0047oool206Ko<oooo`X0I_l?oooo0P0002;oool706Ko=oooo`0306Kooooooooo
02coool001Ooool400008oooo`<0I_lCoooo1@0002Ooool706Ko2?ooo`030000oooooooo01Ooool:
06Ko5_ooo`D0000Soooo00<0I_ooooooool04_ooo`@0000Foooo000Goooo00<0003oooooool08_oo
o`80I_lHoooo00<0003oooooool0;_ooo`P0I_l00`000?ooooooo`0>oooo2@1Vob;oool00`000?oo
ooooo`0Soooo00<0I_ooooooool04_ooo`030000oooooooo01Ooool001Soool00`000?ooooooo`0O
oooo0P1Voa[oool00`000?ooooooo`0foooo00<00000I_l0I_l03P1Vob_oool00`000?ooooooo`0S
oooo00<0I_ooooooool04oooo`030000oooooooo01Koool0017oool400001?ooo`030000oooooooo
01coool206Ko5?ooo`@00004oooo00<0003oooooool0=_ooo`030000oooooooo03Woool00`000?oo
ooooo`0Soooo00<0I_ooooooool05?ooo`030000oooooooo01Goool001Ooool010000?ooooooo`00
01_oool206Ko7_ooo`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool08ooo
o`0306Kooooooooo01;oool010000?ooooooo`0001Koool001Soool200006oooo`0306Kooooooooo
01goool20000>?ooo`80000ioooo0P0002Goool00`1Vooooooooo`0Coooo0P0001Ooool003Coool0
0`1Vooooooooo`1Hoooo00<0003oooooool0Goooo`0306Kooooooooo02coool003;oool206KoFooo
o`030000oooooooo05ooool00`1Vooooooooo`0/oooo000aoooo00<0I_ooooooool0Foooo`030000
oooooooo05ooool00`1Vooooooooo`0/oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo
05ooool00`1Vooooooooo`0/oooo000^oooo0P1Voeooool00`000?ooooooo`1Ooooo00<0I_oooooo
ool0;?ooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`001S?o01d000000ol0V@0000000002
00001_ooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_oo
o`030000oooooooo03Woool00`0003?o03?o000i<ol02@0001goool00ol0VOooooooo`0Doooo00<0
003oooooool05Oooo`00Soooo`030000<ol0<ol003<co`0600009_ooo`03o`2Ioooooooo02coool0
08ooool00`0003?o03?o000a<ol00P0002coool00ol0VOooooooo`0/oooo002?oooo00<0000co`0c
o`00;c?o0080000^oooo00?o09Woooooool0;?ooo`00Soooo`030000<ol0<ol002`co`030000<?oo
o`03o`2Ioooooooo02coool008ooool20000:S?o00<0000coooo00?o09Woooooool0;?ooo`00Sooo
o`030000<ol0<ol002Lco`020000=_ooo`03o`2Ioooooooo02coool008ooool00`0003?o03?o000V
<ol000<0003oooooool0=_ooo`03o`2Ioooooooo02coool008ooool00`0003?o03?o000U<ol000<0
003oooooool0=oooo`03o`2Ioooooooo02coool008ooool00`0003?o03?o000T<ol000<0003ooooo
ool0>?ooo`03o`2Ioooooooo02coool008ooool00`0003?o03?o000R<ol00P0003_oool00ol0VOoo
ooooo`0/oooo002?oooo0P00028co`000`000?ooooooo`0koooo00?o09Woooooool0;?ooo`00Sooo
o`030000<ol0<ol0020co`000`000?ooooooo`0loooo00?o09Woooooool0;?ooo`00Soooo`030000
<ol0<ol001lco`000`000?ooooooo`0moooo00?o09Woooooool0;?ooo`00Soooo`030000<ol0<ol0
01lco`000`000?ooooooo`0moooo00?o09Woooooool0;?ooo`00Soooo`030000<ol0<ol001hco`00
0`000?ooooooo`0noooo00?o09Woooooool0;?ooo`00Soooo`030000<ol0<ol001dco`000`000?oo
ooooo`0ooooo00?o09Woooooool0;?ooo`00Soooo`80000M<ol000<0003oooooool0@?ooo`03o`2I
oooooooo02coool008ooool00`0003?o03?o000K<ol000<0003oooooool0@Oooo`03o`2Ioooooooo
02coool008ooool00`0003?o03?o000K<ol000<0003oooooool0@Oooo`03o`2Ioooooooo02coool0
08ooool00`0003?o03?o000J<ol000<0003oooooool0@_ooo`03o`2Ioooooooo02coool008ooool0
0`0003?o03?o000J<ol000<0003oooooool0@_ooo`03o`2Ioooooooo02coool008ooool00`0003?o
03?o000I<ol000<0003oooooool0@oooo`03o`2Ioooooooo02coool008ooool200006S?o00030000
oooooooo04?oool00ol0VOooooooo`0/oooo002?oooo00<0000co`0co`0063?o00030000oooooooo
04Coool00ol0VOooooooo`0/oooo002?oooo00<0000co`0co`0063?o00030000oooooooo04Coool0
0ol0VOooooooo`0/oooo002?oooo00<0000co`0co`005c?o00030000oooooooo04Goool00ol0VOoo
ooooo`0/oooo002?oooo00<0000co`0co`005c?o00030000oooooooo04Goool00ol0VOooooooo`0/
oooo0027oooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool0A_ooo`03o`2Ioooooooo
02coool008Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo04Koool0
0ol0VOooooooo`0/oooo0029oooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0Aooo
o`03o`2Ioooooooo02coool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000
oooooooo04Ooool00ol0VOooooooo`0/oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
01Dco`000`000?ooooooo`17oooo00?o09Woooooool0;?ooo`00R?ooo`800005oooo00<0000co`0c
o`0053?o00030000oooooooo04Soool00ol0VOooooooo`0/oooo002?oooo00<0000co`0co`0053?o
00030000oooooooo04Soool00ol0VOooooooo`0/oooo002?oooo00<0000co`0co`004c?o00030000
oooooooo04Woool00ol0VOooooooo`0/oooo002?oooo0P0001@co`000`000?ooooooo`19oooo00?o
09Woooooool0;?ooo`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`19oooo00?o09Wooooo
ool0;?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`1:oooo00?o09Woooooool0;?oo
o`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`1:oooo00?o09Woooooool0;?ooo`00Sooo
o`030000<ol0<ol0018co`000`000?ooooooo`1:oooo00?o09Woooooool0;?ooo`00Soooo`030000
<ol0<ol0014co`000`000?ooooooo`1;oooo00?o09Woooooool0;?ooo`00Soooo`80000B<ol000<0
003oooooool0Boooo`03o`2Ioooooooo02coool008ooool00`0003?o03?o000A<ol000<0003ooooo
ool0Boooo`03o`2Ioooooooo02coool008ooool00`0003?o03?o000A<ol000<0003oooooool0Booo
o`03o`2Ioooooooo02coool008ooool00`0003?o03?o000@<ol000<0003oooooool0C?ooo`03o`2I
oooooooo02coool008ooool00`0003?o03?o000@<ol000<0003oooooool0C?ooo`03o`2Ioooooooo
02coool008ooool00`0003?o03?o000@<ol000<0003oooooool0C?ooo`03o`2Ioooooooo02coool0
08ooool00`0003?o03?o000@<ol000<0003oooooool0C?ooo`03o`2Ioooooooo02coool008ooool2
000043?o00030000oooooooo04goool00ol0VOooooooo`0/oooo002?oooo00<0000co`0co`003c?o
00030000oooooooo04goool00ol0VOooooooo`0/oooo002?oooo00<0000co`0co`003c?o00030000
oooooooo04goool00ol0VOooooooo`0/oooo002?oooo00<0000co`0co`003c?o00030000oooooooo
04goool00ol0VOooooooo`0/oooo002?oooo00<0000co`0co`003c?o00030000oooooooo04goool0
0ol0VOooooooo`0/oooo002?oooo00<0000co`0co`003S?o00030000oooooooo04koool00ol0VOoo
ooooo`0/oooo002?oooo0P0000lco`000`000?ooooooo`1>oooo00?o09Woooooool0;?ooo`00Sooo
o`030000<ol0<ol000hco`000`000?ooooooo`1>oooo00?o09Woooooool0;?ooo`00Soooo`030000
<ol0<ol000hco`000`000?ooooooo`1>oooo00?o09Woooooool0;?ooo`00Soooo`030000<ol0<ol0
00dco`000`000?ooooooo`1?oooo00?o09Woooooool0;?ooo`00Qoooo`@00004oooo00<0000co`0c
o`003C?o00030000oooooooo04ooool00ol0VOooooooo`0/oooo0027oooo00<0003oooooool01Ooo
o`030000<ol0<ol000dco`000`000?ooooooo`1?oooo00?o09Woooooool0;?ooo`00R?ooo`030000
oooooooo00Coool300003C?o00030000oooooooo04ooool00ol0VOooooooo`0/oooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`1?oooo00?o09Woooooool0;?oo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1@oooo00?o
09Woooooool0;?ooo`00R?ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo053oool0
0ol0VOooooooo`0/oooo002?oooo00<0000co`0co`0033?o00030000oooooooo053oool00ol0VOoo
ooooo`0/oooo002?oooo00<0000co`0co`0033?o00030000oooooooo053oool00ol0VOooooooo`0/
oooo002?oooo0P0000dco`000`000?ooooooo`1@oooo00?o09Woooooool0;?ooo`00Soooo`030000
<ol0<ol000`co`000`000?ooooooo`1@oooo00?o09Woooooool0;?ooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`1Aoooo00?o09Woooooool0;?ooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`1Aoooo00?o09Woooooool0;?ooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`1Aoooo00?o09Woooooool0;?ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1A
oooo00?o09Woooooool0;?ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Aoooo00?o
09Woooooool0;?ooo`00Soooo`80000<<ol000<0003oooooool0DOooo`03o`2Ioooooooo02coool0
08ooool00`0003?o03?o000;<ol000<0003oooooool0DOooo`03o`2Ioooooooo02coool008ooool0
0`0003?o03?o000:<ol000<0003oooooool0D_ooo`03o`2Ioooooooo02coool008ooool00`0003?o
03?o000:<ol000<0003oooooool0D_ooo`03o`2Ioooooooo02coool008ooool00`0003?o03?o000:
<ol000<0003oooooool0D_ooo`03o`2Ioooooooo02coool008ooool00`0003?o03?o000:<ol000<0
003oooooool0D_ooo`03o`2Ioooooooo02coool008ooool200002c?o00030000oooooooo05;oool0
0ol0VOooooooo`0/oooo002?oooo00<0000co`0co`002S?o00030000oooooooo05;oool00ol0VOoo
ooooo`0/oooo002?oooo00<0000co`0co`002S?o00030000oooooooo05;oool00ol0VOooooooo`0/
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo05?oool00ol0VOooooooo`0/oooo002?
oooo00<0000co`0co`002C?o00030000oooooooo05?oool00ol0VOooooooo`0/oooo002?oooo00<0
000co`0co`002C?o00030000oooooooo05?oool00ol0VOooooooo`0/oooo002?oooo0P0000Xco`00
0`000?ooooooo`1Coooo00?o09Woooooool0;?ooo`00Soooo`030000<ol0<ol000Tco`000`000?oo
ooooo`1Coooo00?o09Woooooool0;?ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1C
oooo00?o09Woooooool0;?ooo`00Soooo`030000<ol0<ol000Pco`000`000?ooooooo`1Doooo00?o
09Woooooool0;?ooo`00R?ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo05Coool0
0ol0VOooooooo`0/oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000
oooooooo05Coool00ol0VOooooooo`0/oooo0029oooo00<0003oooooool00oooo`<00008<ol000<0
003oooooool0E?ooo`03o`2Ioooooooo02coool008[oool00`000?ooooooo`02oooo00<0000co`0c
o`0023?o00030000oooooooo05Coool00ol0VOooooooo`0/oooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0023?o00030000oooooooo05Coool00ol0VOooooooo`0/oooo0028oooo0P00
00Goool00`0003?o03?o0007<ol000<0003oooooool0EOooo`03o`2Ioooooooo02coool008ooool0
0`0003?o03?o0007<ol000<0003oooooool0EOooo`03o`2Ioooooooo02coool008ooool00`0003?o
03?o0007<ol000<0003oooooool0EOooo`03o`2Ioooooooo02coool008ooool00`0003?o03?o0007
<ol000<0003oooooool0EOooo`03o`2Ioooooooo02coool008ooool2000023?o00030000oooooooo
05Goool00ol0VOooooooo`0/oooo002?oooo00<0000co`0co`001c?o00030000oooooooo05Goool0
0ol0VOooooooo`0/oooo002?oooo00<0000co`0co`001c?o00030000oooooooo05Goool00ol0VOoo
ooooo`0/oooo002?oooo00<0000co`0co`001c?o00030000oooooooo05Goool00ol0VOooooooo`0/
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo05Koool00ol0VOooooooo`0/oooo002?
oooo00<0000co`0co`001S?o00030000oooooooo05Koool00ol0VOooooooo`0/oooo002?oooo0P00
00Lco`000`000?ooooooo`1Foooo00?o09Woooooool0;?ooo`00Soooo`030000<ol0<ol000Hco`00
0`000?ooooooo`1Foooo00?o09Woooooool0;?ooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`1Foooo00?o09Woooooool0;?ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1F
oooo00?o09Woooooool0;?ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Foooo00?o
09Woooooool0;?ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Foooo00?o09Wooooo
ool0;?ooo`00Soooo`800006<ol000<0003oooooool0Eoooo`03o`2Ioooooooo02coool008ooool0
0`0003?o03?o0005<ol000<0003oooooool0Eoooo`03o`2Ioooooooo02coool008ooool00`0003?o
03?o0005<ol000<0003oooooool0Eoooo`03o`2Ioooooooo02coool008ooool00`0003?o03?o0005
<ol000<0003oooooool0Eoooo`03o`2Ioooooooo02coool008ooool00`0003?o03?o0005<ol000<0
003oooooool0Eoooo`03o`2Ioooooooo02coool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool0Eoooo`03o`2Ioooooooo02coool008ooool200001S?o00030000oooooooo05Ooool00ol0VOoo
ooooo`0/oooo002?oooo00<0000co`0co`001C?o00030000oooooooo05Ooool00ol0VOooooooo`0/
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo05Ooool00ol0VOooooooo`0/oooo002?
oooo00<0000co`0co`0013?o00030000oooooooo05Soool00ol0VOooooooo`0/oooo002?oooo00<0
000co`0co`0013?o00030000oooooooo05Soool00ol0VOooooooo`0/oooo0029oooo0`0000?oool0
0`0003?o03?o0004<ol000<0003oooooool0F?ooo`03o`2Ioooooooo02coool008[oool00`000?oo
ooooo`02oooo00<0000co`0co`0013?o00030000oooooooo05Soool00ol0VOooooooo`0/oooo0027
oooo1@0000?oool3000013?o00030000oooooooo05Soool00ol0VOooooooo`0/oooo0027oooo00@0
003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool2
00001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo
01?oool7<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool02Oooo`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool400000c?o008000000c?o0?ooooooo`0300000oooo`@00003oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`030000oooooooo00Lco`02oooo00@0003oooooool00002oooo00<0003ooooo
ool01?ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03_oo
o`030000oooo<ol000Hco`02oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000<ol0<ol000Dco`02oooo0`00
00Goool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00ooool010000?ooooooo`0000Hco`03oooo00<0003oooooool00_ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`03oooo0`0000?oool2
00000oooo`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.64) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.85916 .12361 L
.87791 .12361 L
.88246 .12361 L
.88735 .12361 L
.88879 .12361 L
.8895 .12361 L
.89015 .12361 L
s
.89015 .12361 m
.89064 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.0932 .12361 L
.09905 .12361 L
.10192 .12361 L
.10458 .12361 L
.10708 .12361 L
.10834 .12361 L
.10905 .12361 L
.10972 .1234 L
.11044 .12266 L
.11113 .12196 L
.11241 .12066 L
.11531 .11782 L
.12507 .10897 L
.14415 .09467 L
.16396 .08341 L
.18234 .07563 L
.19291 .07214 L
.20287 .06943 L
.22147 .06566 L
.23124 .06426 L
.24155 .06317 L
.25036 .06251 L
.25536 .06224 L
.26003 .06205 L
.26263 .06197 L
.26503 .06191 L
.26767 .06186 L
.269 .06184 L
.27048 .06182 L
.27176 .06181 L
.27293 .06181 L
.27422 .0618 L
.27487 .0618 L
.27558 .0618 L
.27678 .06181 L
.27807 .06182 L
.27928 .06183 L
.28038 .06184 L
.28276 .06187 L
.28496 .06192 L
.28992 .06204 L
.2943 .06219 L
.29893 .06239 L
.30837 .06289 L
.31851 .06356 L
.33682 .06508 L
.3781 .06949 L
Mistroke
.41786 .07444 L
.4561 .07939 L
.47746 .08213 L
.4968 .08456 L
.50152 .08514 L
.50651 .08564 L
.51197 .08606 L
.51439 .08621 L
.51699 .08634 L
.51944 .08644 L
.52168 .08652 L
.52392 .08657 L
.52605 .08661 L
.52725 .08663 L
.52852 .08664 L
.52961 .08665 L
.53081 .08665 L
.5321 .08665 L
.53282 .08664 L
.53348 .08664 L
.5347 .08663 L
.53598 .08662 L
.53722 .0866 L
.53857 .08658 L
.541 .08652 L
.54555 .08639 L
.55087 .08617 L
.55576 .08593 L
.57414 .08465 L
.59294 .08284 L
.6136 .08041 L
.65399 .07459 L
.69287 .06796 L
.7342 .06007 L
.77401 .05193 L
.81231 .04392 L
.83167 .03994 L
.85306 .03572 L
.86279 .0339 L
.87328 .03203 L
.87811 .03121 L
.8832 .03037 L
.88754 .02968 L
.88873 .0295 L
.89 .0293 L
.8912 .12361 L
.89229 .12361 L
.93224 .12361 L
.97067 .12361 L
.97619 .12361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.64) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo063oool00`1Vooooooooo`0[oooo002?oooo00<0003ooooo
ool0Foooo`H0I_l]oooo002?oooo00<0003oooooool0E?ooo`L0I_l5oooo00<0I_ooooooool0:ooo
o`00Soooo`030000oooooooo04ooool506Ko3?ooo`0306Kooooooooo02_oool008ooool00`000?oo
ooooo`1:oooo1@1Voa7oool00`1Vooooooooo`0[oooo002?oooo00<0003oooooool0AOooo`D0I_lF
oooo00<0I_ooooooool0:oooo`00Soooo`800011oooo1@1Voa_oool00`1Vooooooooo`0[oooo002?
oooo00<0003oooooool0>oooo`D0I_lPoooo00<0I_ooooooool0:oooo`00Soooo`030000oooooooo
03Koool506Ko9Oooo`0306Kooooooooo02_oool004[ooolJ06Ko:oooo`030000oooooooo037oool5
06Ko:_ooo`0306Kooooooooo02_oool004Ooool306Ko6_ooo`L0I_lToooo00<0003oooooool0;?oo
o`D0I_l_oooo00<0I_ooooooool0:oooo`00@?ooo`L0I_lToooo2P1Voa[oool00`000?ooooooo`0W
oooo1@1VocCoool00`1Vooooooooo`0[oooo000noooo0P1VocGoool:06Ko4?ooo`80000Qoooo1`1V
ocWoool00`1Vooooooooo`0[oooo000Goooo1000027oool206Ko5_ooo`D0000Voooo201Vo`Soool0
0`000?ooooooo`0Hoooo201VoaOoool500009?ooo`0306Kooooooooo017oool400005_ooo`005ooo
o`030000oooooooo023oool206Ko6_ooo`030000oooooooo02koool506Ko0oooo`030000oooooooo
01?oool506Ko8Oooo`030000oooooooo02Coool00`1Vooooooooo`0Aoooo00<0003oooooool05ooo
o`006?ooo`030000oooooooo01goool206Ko7?ooo`030000oooooooo03?oool306Ko00<00000I_l0
I_l04`1VobKoool00`000?ooooooo`0Toooo00<0I_ooooooool04_ooo`030000oooooooo01Koool0
017oool400001?ooo`030000oooooooo01[oool206Ko5_ooo`@00004oooo00<0003oooooool0=_oo
o`030000oooooooo03Woool00`000?ooooooo`0Toooo00<0I_ooooooool04oooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0001[oool00`1Vooooooooo`0Noooo00<0003oooooool0=_oo
o`030000oooooooo03Woool00`000?ooooooo`0Toooo00<0I_ooooooool04Oooo`040000oooooooo
00005_ooo`006?ooo`80000Joooo00<0I_ooooooool07_ooo`80000hoooo0P0003Woool200009_oo
o`0306Kooooooooo01;oool200005oooo`00<_ooo`80I_mKoooo00<0003oooooool0H?ooo`0306Ko
oooooooo02_oool0037oool00`1Vooooooooo`1Koooo00<0003oooooool0H?ooo`0306Kooooooooo
02_oool0033oool00`1Vooooooooo`1Loooo00<0003oooooool0H?ooo`0306Kooooooooo02_oool0
02koool206KoGoooo`030000oooooooo063oool00`1Vooooooooo`0[oooo000]oooo00<0I_oooooo
ool0Goooo`030000oooooooo063oool00`1Vooooooooo`0[oooo000@ooooo`00017oool001Koool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0006<ol07P000004o`2I0000000000001_ooo`030000oooooooo00Woool00`000?oo
ooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000i
<ol02@0001koool00ol0VOooooooo`0Coooo00<0003oooooool05Oooo`00Soooo`030000<ol0<ol0
03<co`0600009oooo`03o`2Ioooooooo02_oool008ooool00`0003?o03?o000a<ol00P0002goool0
0ol0VOooooooo`0[oooo002?oooo00<0000co`0co`00;c?o0080000_oooo00?o09Woooooool0:ooo
o`00Soooo`030000<ol0<ol002`co`030000<Oooo`03o`2Ioooooooo02_oool008ooool20000:S?o
00<0000doooo00?o09Woooooool0:oooo`00Soooo`030000<ol0<ol002Lco`020000=oooo`03o`2I
oooooooo02_oool008ooool00`0003?o03?o000V<ol000<0003oooooool0=oooo`03o`2Ioooooooo
02_oool008ooool00`0003?o03?o000U<ol000<0003oooooool0>?ooo`03o`2Ioooooooo02_oool0
08ooool00`0003?o03?o000T<ol000<0003oooooool0>Oooo`03o`2Ioooooooo02_oool008ooool0
0`0003?o03?o000R<ol00P0003coool00ol0VOooooooo`0[oooo002?oooo0P00028co`000`000?oo
ooooo`0loooo00?o09Woooooool0:oooo`00Soooo`030000<ol0<ol0020co`000`000?ooooooo`0m
oooo00?o09Woooooool0:oooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0noooo00?o
09Woooooool0:oooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0noooo00?o09Wooooo
ool0:oooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`0ooooo00?o09Woooooool0:ooo
o`00Soooo`030000<ol0<ol001dco`000`000?ooooooo`10oooo00?o09Woooooool0:oooo`00Sooo
o`80000M<ol000<0003oooooool0@Oooo`03o`2Ioooooooo02_oool008ooool00`0003?o03?o000K
<ol000<0003oooooool0@_ooo`03o`2Ioooooooo02_oool008ooool00`0003?o03?o000K<ol000<0
003oooooool0@_ooo`03o`2Ioooooooo02_oool008ooool00`0003?o03?o000J<ol000<0003ooooo
ool0@oooo`03o`2Ioooooooo02_oool008ooool00`0003?o03?o000J<ol000<0003oooooool0@ooo
o`03o`2Ioooooooo02_oool008ooool00`0003?o03?o000I<ol000<0003oooooool0A?ooo`03o`2I
oooooooo02_oool008ooool200006S?o00030000oooooooo04Coool00ol0VOooooooo`0[oooo002?
oooo00<0000co`0co`0063?o00030000oooooooo04Goool00ol0VOooooooo`0[oooo002?oooo00<0
000co`0co`0063?o00030000oooooooo04Goool00ol0VOooooooo`0[oooo002?oooo00<0000co`0c
o`005c?o00030000oooooooo04Koool00ol0VOooooooo`0[oooo002?oooo00<0000co`0co`005c?o
00030000oooooooo04Koool00ol0VOooooooo`0[oooo0027oooo1@0000?oool00`0003?o03?o000F
<ol000<0003oooooool0Aoooo`03o`2Ioooooooo02_oool008Woool00`000?ooooooo`03oooo00<0
000co`0co`005S?o00030000oooooooo04Ooool00ol0VOooooooo`0[oooo0029oooo00<0003ooooo
ool00oooo`<0000E<ol000<0003oooooool0B?ooo`03o`2Ioooooooo02_oool008Woool00`000?oo
ooooo`03oooo00<0000co`0co`005C?o00030000oooooooo04Soool00ol0VOooooooo`0[oooo0029
oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`18oooo00?o09Wooooo
ool0:oooo`00R?ooo`800005oooo00<0000co`0co`0053?o00030000oooooooo04Woool00ol0VOoo
ooooo`0[oooo002?oooo00<0000co`0co`0053?o00030000oooooooo04Woool00ol0VOooooooo`0[
oooo002?oooo00<0000co`0co`004c?o00030000oooooooo04[oool00ol0VOooooooo`0[oooo002?
oooo0P0001@co`000`000?ooooooo`1:oooo00?o09Woooooool0:oooo`00Soooo`030000<ol0<ol0
01<co`000`000?ooooooo`1:oooo00?o09Woooooool0:oooo`00Soooo`030000<ol0<ol0018co`00
0`000?ooooooo`1;oooo00?o09Woooooool0:oooo`00Soooo`030000<ol0<ol0018co`000`000?oo
ooooo`1;oooo00?o09Woooooool0:oooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`1;
oooo00?o09Woooooool0:oooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`1<oooo00?o
09Woooooool0:oooo`00Soooo`80000B<ol000<0003oooooool0C?ooo`03o`2Ioooooooo02_oool0
08ooool00`0003?o03?o000A<ol000<0003oooooool0C?ooo`03o`2Ioooooooo02_oool008ooool0
0`0003?o03?o000A<ol000<0003oooooool0C?ooo`03o`2Ioooooooo02_oool008ooool00`0003?o
03?o000@<ol000<0003oooooool0COooo`03o`2Ioooooooo02_oool008ooool00`0003?o03?o000@
<ol000<0003oooooool0COooo`03o`2Ioooooooo02_oool008ooool00`0003?o03?o000@<ol000<0
003oooooool0COooo`03o`2Ioooooooo02_oool008ooool00`0003?o03?o000@<ol000<0003ooooo
ool0COooo`03o`2Ioooooooo02_oool008ooool2000043?o00030000oooooooo04koool00ol0VOoo
ooooo`0[oooo002?oooo00<0000co`0co`003c?o00030000oooooooo04koool00ol0VOooooooo`0[
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo04koool00ol0VOooooooo`0[oooo002?
oooo00<0000co`0co`003c?o00030000oooooooo04koool00ol0VOooooooo`0[oooo002?oooo00<0
000co`0co`003c?o00030000oooooooo04koool00ol0VOooooooo`0[oooo002?oooo00<0000co`0c
o`003S?o00030000oooooooo04ooool00ol0VOooooooo`0[oooo002?oooo0P0000lco`000`000?oo
ooooo`1?oooo00?o09Woooooool0:oooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`1?
oooo00?o09Woooooool0:oooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`1?oooo00?o
09Woooooool0:oooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`1@oooo00?o09Wooooo
ool0:oooo`00Qoooo`@00004oooo00<0000co`0co`003C?o00030000oooooooo053oool00ol0VOoo
ooooo`0[oooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`1@
oooo00?o09Woooooool0:oooo`00R?ooo`030000oooooooo00Coool300003C?o00030000oooooooo
053oool00ol0VOooooooo`0[oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000dco`00
0`000?ooooooo`1@oooo00?o09Woooooool0:oooo`00Qoooo`040000oooooooo00001?ooo`030000
<ol0<ol000`co`000`000?ooooooo`1Aoooo00?o09Woooooool0:oooo`00R?ooo`800005oooo00<0
000co`0co`0033?o00030000oooooooo057oool00ol0VOooooooo`0[oooo002?oooo00<0000co`0c
o`0033?o00030000oooooooo057oool00ol0VOooooooo`0[oooo002?oooo00<0000co`0co`0033?o
00030000oooooooo057oool00ol0VOooooooo`0[oooo002?oooo0P0000dco`000`000?ooooooo`1A
oooo00?o09Woooooool0:oooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`1Aoooo00?o
09Woooooool0:oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Boooo00?o09Wooooo
ool0:oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Boooo00?o09Woooooool0:ooo
o`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Boooo00?o09Woooooool0:oooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`1Boooo00?o09Woooooool0:oooo`00Soooo`030000
<ol0<ol000/co`000`000?ooooooo`1Boooo00?o09Woooooool0:oooo`00Soooo`80000<<ol000<0
003oooooool0D_ooo`03o`2Ioooooooo02_oool008ooool00`0003?o03?o000;<ol000<0003ooooo
ool0D_ooo`03o`2Ioooooooo02_oool008ooool00`0003?o03?o000:<ol000<0003oooooool0Dooo
o`03o`2Ioooooooo02_oool008ooool00`0003?o03?o000:<ol000<0003oooooool0Doooo`03o`2I
oooooooo02_oool008ooool00`0003?o03?o000:<ol000<0003oooooool0Doooo`03o`2Ioooooooo
02_oool008ooool00`0003?o03?o000:<ol000<0003oooooool0Doooo`03o`2Ioooooooo02_oool0
08ooool200002c?o00030000oooooooo05?oool00ol0VOooooooo`0[oooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo05?oool00ol0VOooooooo`0[oooo002?oooo00<0000co`0co`002S?o
00030000oooooooo05?oool00ol0VOooooooo`0[oooo002?oooo00<0000co`0co`002C?o00030000
oooooooo05Coool00ol0VOooooooo`0[oooo002?oooo00<0000co`0co`002C?o00030000oooooooo
05Coool00ol0VOooooooo`0[oooo002?oooo00<0000co`0co`002C?o00030000oooooooo05Coool0
0ol0VOooooooo`0[oooo002?oooo0P0000Xco`000`000?ooooooo`1Doooo00?o09Woooooool0:ooo
o`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1Doooo00?o09Woooooool0:oooo`00Sooo
o`030000<ol0<ol000Tco`000`000?ooooooo`1Doooo00?o09Woooooool0:oooo`00Soooo`030000
<ol0<ol000Pco`000`000?ooooooo`1Eoooo00?o09Woooooool0:oooo`00R?ooo`800005oooo00<0
000co`0co`0023?o00030000oooooooo05Goool00ol0VOooooooo`0[oooo0027oooo00@0003ooooo
ool00004oooo00<0000co`0co`0023?o00030000oooooooo05Goool00ol0VOooooooo`0[oooo0029
oooo00<0003oooooool00oooo`<00008<ol000<0003oooooool0EOooo`03o`2Ioooooooo02_oool0
08[oool00`000?ooooooo`02oooo00<0000co`0co`0023?o00030000oooooooo05Goool00ol0VOoo
ooooo`0[oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo
05Goool00ol0VOooooooo`0[oooo0028oooo0P0000Goool00`0003?o03?o0007<ol000<0003ooooo
ool0E_ooo`03o`2Ioooooooo02_oool008ooool00`0003?o03?o0007<ol000<0003oooooool0E_oo
o`03o`2Ioooooooo02_oool008ooool00`0003?o03?o0007<ol000<0003oooooool0E_ooo`03o`2I
oooooooo02_oool008ooool00`0003?o03?o0007<ol000<0003oooooool0E_ooo`03o`2Ioooooooo
02_oool008ooool2000023?o00030000oooooooo05Koool00ol0VOooooooo`0[oooo002?oooo00<0
000co`0co`001c?o00030000oooooooo05Koool00ol0VOooooooo`0[oooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo05Koool00ol0VOooooooo`0[oooo002?oooo00<0000co`0co`001c?o
00030000oooooooo05Koool00ol0VOooooooo`0[oooo002?oooo00<0000co`0co`001S?o00030000
oooooooo05Ooool00ol0VOooooooo`0[oooo002?oooo00<0000co`0co`001S?o00030000oooooooo
05Ooool00ol0VOooooooo`0[oooo002?oooo0P0000Lco`000`000?ooooooo`1Goooo00?o09Wooooo
ool0:oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Goooo00?o09Woooooool0:ooo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Goooo00?o09Woooooool0:oooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`1Goooo00?o09Woooooool0:oooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`1Goooo00?o09Woooooool0:oooo`00Soooo`030000<ol0<ol0
00Hco`000`000?ooooooo`1Goooo00?o09Woooooool0:oooo`00Soooo`800006<ol000<0003ooooo
ool0F?ooo`03o`2Ioooooooo02_oool008ooool00`0003?o03?o0005<ol000<0003oooooool0F?oo
o`03o`2Ioooooooo02_oool008ooool00`0003?o03?o0005<ol000<0003oooooool0F?ooo`03o`2I
oooooooo02_oool008ooool00`0003?o03?o0005<ol000<0003oooooool0F?ooo`03o`2Ioooooooo
02_oool008ooool00`0003?o03?o0005<ol000<0003oooooool0F?ooo`03o`2Ioooooooo02_oool0
08ooool00`0003?o03?o0005<ol000<0003oooooool0F?ooo`03o`2Ioooooooo02_oool008ooool2
00001S?o00030000oooooooo05Soool00ol0VOooooooo`0[oooo002?oooo00<0000co`0co`001C?o
00030000oooooooo05Soool00ol0VOooooooo`0[oooo002?oooo00<0000co`0co`001C?o00030000
oooooooo05Soool00ol0VOooooooo`0[oooo002?oooo00<0000co`0co`0013?o00030000oooooooo
05Woool00ol0VOooooooo`0[oooo002?oooo00<0000co`0co`0013?o00030000oooooooo05Woool0
0ol0VOooooooo`0[oooo0029oooo0`0000?oool00`0003?o03?o0004<ol000<0003oooooool0FOoo
o`03o`2Ioooooooo02_oool008[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o00030000
oooooooo05Woool00ol0VOooooooo`0[oooo0027oooo1@0000?oool3000013?o00030000oooooooo
05Woool00ol0VOooooooo`0[oooo0027oooo00@0003oooooool00004oooo1c?o08[oool008Soool0
0`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o08[oool0
08ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?oooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000c?o00800000
0c?o0?ooooooo`0300001Oooo`<00002oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00Lco`02
oooo00@0003oooooool00005oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0>oooo00<0003ooolco`001S?o00;oool010000?ooooooo`0000;oool5
00000oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000<ol0<ol0
00Dco`02oooo0`0000?oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000003oooo`040000oooooooo00001S?o00?oool00`000?ooooooo`03oooo00<0
003oool000000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`03
oooo0`0000Coool200000_ooo`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.66) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.83996 .12361 L
.85916 .12361 L
.87791 .12361 L
.88735 .12361 L
.88993 .12361 L
.89136 .12361 L
.89271 .12361 L
.89396 .12361 L
.89467 .12361 L
s
.89467 .12361 m
.89493 .61803 L
s
0 .4 1 r
.02381 .12361 m
.06244 .12361 L
.08255 .12361 L
.0932 .12361 L
.09905 .12361 L
.10192 .12361 L
.10319 .12361 L
.10386 .12361 L
.10458 .12361 L
.10587 .12247 L
.10708 .12124 L
.10972 .11861 L
.11531 .11336 L
.12507 .10505 L
.14415 .09166 L
.16529 .08057 L
.17501 .07658 L
.18538 .073 L
.19576 .07002 L
.20518 .06781 L
.21412 .06609 L
.22357 .06464 L
.23359 .06347 L
.24282 .06269 L
.24795 .06237 L
.25274 .06214 L
.25544 .06204 L
.258 .06196 L
.26095 .06189 L
.26224 .06187 L
.26364 .06185 L
.26487 .06183 L
.266 .06182 L
.26708 .06181 L
.26822 .06181 L
.26948 .0618 L
.27064 .0618 L
.27192 .06181 L
.27264 .06181 L
.27329 .06182 L
.27461 .06183 L
.27582 .06184 L
.27856 .06188 L
.28098 .06193 L
.28354 .062 L
.29232 .06231 L
.2973 .06254 L
.30197 .06279 L
.32225 .06422 L
.34079 .06591 L
Mistroke
.38055 .07035 L
.4188 .07518 L
.45949 .08044 L
.47833 .08284 L
.49867 .08538 L
.50411 .086 L
.50985 .0865 L
.51475 .08681 L
.51753 .08694 L
.52013 .08705 L
.52275 .08712 L
.52404 .08715 L
.52523 .08718 L
.52629 .0872 L
.52745 .08721 L
.52863 .08722 L
.52987 .08723 L
.53053 .08723 L
.53123 .08723 L
.53247 .08723 L
.53316 .08723 L
.5338 .08722 L
.53451 .08722 L
.53526 .08721 L
.53662 .0872 L
.53791 .08718 L
.54031 .08713 L
.54495 .087 L
.55006 .08681 L
.56036 .08627 L
.56991 .08562 L
.57883 .08488 L
.6177 .0806 L
.65903 .07458 L
.69885 .06775 L
.73714 .06043 L
.77789 .05211 L
.81713 .0439 L
.85485 .03629 L
.87579 .03242 L
.88497 .03086 L
.88983 .03007 L
.89249 .02965 L
.89381 .02945 L
.89502 .02926 L
.8962 .12361 L
.89746 .12361 L
.90012 .12361 L
.90476 .12361 L
.91384 .12361 L
Mistroke
.93367 .12361 L
.97153 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.66) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo067oool00`1Vooooooooo`0Zoooo002?oooo00<0003ooooo
ool0F_ooo`P0I_l/oooo002?oooo00<0003oooooool0EOooo`D0I_l7oooo00<0I_ooooooool0:_oo
o`00Soooo`030000oooooooo053oool506Ko3?ooo`0306Kooooooooo02[oool008ooool00`000?oo
ooooo`1;oooo1@1Voa7oool00`1Vooooooooo`0Zoooo002?oooo00<0003oooooool0A_ooo`D0I_lF
oooo00<0I_ooooooool0:_ooo`00Soooo`800012oooo1@1Voa_oool00`1Vooooooooo`0Zoooo002?
oooo00<0003oooooool0??ooo`D0I_lPoooo00<0I_ooooooool0:_ooo`00Soooo`030000oooooooo
03Ooool506Ko9Oooo`0306Kooooooooo02[oool004SooolM06Ko:_ooo`030000oooooooo03;oool5
06Ko:_ooo`0306Kooooooooo02[oool004Coool406Ko7Oooo`L0I_lSoooo00<0003oooooool0;Ooo
o`D0I_l_oooo00<0I_ooooooool0:_ooo`00@Oooo`<0I_lXoooo2P1VoaWoool00`000?ooooooo`0X
oooo1@1VocCoool00`1Vooooooooo`0Zoooo000loooo1@1VocGoool:06Ko3oooo`80000Roooo1`1V
ocWoool00`1Vooooooooo`0Zoooo000Goooo100001ooool206Ko6?ooo`D0000Woooo1`1Vo`Soool0
0`000?ooooooo`0Ioooo201VoaKoool500009Oooo`0306Kooooooooo013oool400005_ooo`005ooo
o`030000oooooooo01koool206Ko7?ooo`030000oooooooo02koool506Ko0oooo`030000oooooooo
01Coool506Ko8?ooo`030000oooooooo02Goool00`1Vooooooooo`0@oooo00<0003oooooool05ooo
o`006?ooo`030000oooooooo01_oool206Ko7_ooo`030000oooooooo03?oool306Ko00<00000I_l0
I_l0501VobGoool00`000?ooooooo`0Uoooo00<0I_ooooooool04Oooo`030000oooooooo01Koool0
017oool400001?ooo`030000oooooooo01Woool00`1Vooooooooo`0Foooo100000Coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo02Goool00`1Vooooooooo`0Boooo00<0
003oooooool05Oooo`005oooo`040000oooooooo00006Oooo`0306Kooooooooo01ooool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo02Goool00`1Vooooooooo`0@oooo00@0
003oooooool0000Foooo000Hoooo0P0001Soool206Ko8Oooo`80000hoooo0P0003Woool200009ooo
o`0306Kooooooooo017oool200005oooo`00<Oooo`0306Kooooooooo05_oool00`000?ooooooo`1Q
oooo00<0I_ooooooool0:_ooo`00<?ooo`0306Kooooooooo05coool00`000?ooooooo`1Qoooo00<0
I_ooooooool0:_ooo`00;_ooo`80I_mOoooo00<0003oooooool0HOooo`0306Kooooooooo02[oool0
02goool00`1Vooooooooo`1Ooooo00<0003oooooool0HOooo`0306Kooooooooo02[oool002coool0
0`1Vooooooooo`1Poooo00<0003oooooool0HOooo`0306Kooooooooo02[oool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Hco`0O000000?o09T0000000001_ooo`030000oooooooo00Woool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o
03?o000i<ol02@0001ooool00ol0VOooooooo`0Boooo00<0003oooooool05Oooo`00Soooo`030000
<ol0<ol003<co`060000:?ooo`03o`2Ioooooooo02[oool008ooool00`0003?o03?o000a<ol00P00
02koool00ol0VOooooooo`0Zoooo002?oooo00<0000co`0co`00;c?o0080000`oooo00?o09Wooooo
ool0:_ooo`00Soooo`030000<ol0<ol002`co`030000<_ooo`03o`2Ioooooooo02[oool008ooool2
0000:S?o00<0000eoooo00?o09Woooooool0:_ooo`00Soooo`030000<ol0<ol002Lco`020000>?oo
o`03o`2Ioooooooo02[oool008ooool00`0003?o03?o000V<ol000<0003oooooool0>?ooo`03o`2I
oooooooo02[oool008ooool00`0003?o03?o000U<ol000<0003oooooool0>Oooo`03o`2Ioooooooo
02[oool008ooool00`0003?o03?o000T<ol000<0003oooooool0>_ooo`03o`2Ioooooooo02[oool0
08ooool00`0003?o03?o000R<ol00P0003goool00ol0VOooooooo`0Zoooo002?oooo0P00028co`00
0`000?ooooooo`0moooo00?o09Woooooool0:_ooo`00Soooo`030000<ol0<ol0020co`000`000?oo
ooooo`0noooo00?o09Woooooool0:_ooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0o
oooo00?o09Woooooool0:_ooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`0ooooo00?o
09Woooooool0:_ooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`10oooo00?o09Wooooo
ool0:_ooo`00Soooo`030000<ol0<ol001dco`000`000?ooooooo`11oooo00?o09Woooooool0:_oo
o`00Soooo`80000M<ol000<0003oooooool0@_ooo`03o`2Ioooooooo02[oool008ooool00`0003?o
03?o000K<ol000<0003oooooool0@oooo`03o`2Ioooooooo02[oool008ooool00`0003?o03?o000K
<ol000<0003oooooool0@oooo`03o`2Ioooooooo02[oool008ooool00`0003?o03?o000J<ol000<0
003oooooool0A?ooo`03o`2Ioooooooo02[oool008ooool00`0003?o03?o000J<ol000<0003ooooo
ool0A?ooo`03o`2Ioooooooo02[oool008ooool00`0003?o03?o000I<ol000<0003oooooool0AOoo
o`03o`2Ioooooooo02[oool008ooool200006S?o00030000oooooooo04Goool00ol0VOooooooo`0Z
oooo002?oooo00<0000co`0co`0063?o00030000oooooooo04Koool00ol0VOooooooo`0Zoooo002?
oooo00<0000co`0co`0063?o00030000oooooooo04Koool00ol0VOooooooo`0Zoooo002?oooo00<0
000co`0co`005c?o00030000oooooooo04Ooool00ol0VOooooooo`0Zoooo002?oooo00<0000co`0c
o`005c?o00030000oooooooo04Ooool00ol0VOooooooo`0Zoooo0027oooo1@0000?oool00`0003?o
03?o000F<ol000<0003oooooool0B?ooo`03o`2Ioooooooo02[oool008Woool00`000?ooooooo`03
oooo00<0000co`0co`005S?o00030000oooooooo04Soool00ol0VOooooooo`0Zoooo0029oooo00<0
003oooooool00oooo`<0000E<ol000<0003oooooool0BOooo`03o`2Ioooooooo02[oool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo04Woool00ol0VOooooooo`0Z
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`19oooo00?o
09Woooooool0:_ooo`00R?ooo`800005oooo00<0000co`0co`0053?o00030000oooooooo04[oool0
0ol0VOooooooo`0Zoooo002?oooo00<0000co`0co`0053?o00030000oooooooo04[oool00ol0VOoo
ooooo`0Zoooo002?oooo00<0000co`0co`004c?o00030000oooooooo04_oool00ol0VOooooooo`0Z
oooo002?oooo0P0001@co`000`000?ooooooo`1;oooo00?o09Woooooool0:_ooo`00Soooo`030000
<ol0<ol001<co`000`000?ooooooo`1;oooo00?o09Woooooool0:_ooo`00Soooo`030000<ol0<ol0
018co`000`000?ooooooo`1<oooo00?o09Woooooool0:_ooo`00Soooo`030000<ol0<ol0018co`00
0`000?ooooooo`1<oooo00?o09Woooooool0:_ooo`00Soooo`030000<ol0<ol0018co`000`000?oo
ooooo`1<oooo00?o09Woooooool0:_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`1=
oooo00?o09Woooooool0:_ooo`00Soooo`80000B<ol000<0003oooooool0COooo`03o`2Ioooooooo
02[oool008ooool00`0003?o03?o000A<ol000<0003oooooool0COooo`03o`2Ioooooooo02[oool0
08ooool00`0003?o03?o000A<ol000<0003oooooool0COooo`03o`2Ioooooooo02[oool008ooool0
0`0003?o03?o000@<ol000<0003oooooool0C_ooo`03o`2Ioooooooo02[oool008ooool00`0003?o
03?o000@<ol000<0003oooooool0C_ooo`03o`2Ioooooooo02[oool008ooool00`0003?o03?o000@
<ol000<0003oooooool0C_ooo`03o`2Ioooooooo02[oool008ooool00`0003?o03?o000@<ol000<0
003oooooool0C_ooo`03o`2Ioooooooo02[oool008ooool2000043?o00030000oooooooo04ooool0
0ol0VOooooooo`0Zoooo002?oooo00<0000co`0co`003c?o00030000oooooooo04ooool00ol0VOoo
ooooo`0Zoooo002?oooo00<0000co`0co`003c?o00030000oooooooo04ooool00ol0VOooooooo`0Z
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo04ooool00ol0VOooooooo`0Zoooo002?
oooo00<0000co`0co`003c?o00030000oooooooo04ooool00ol0VOooooooo`0Zoooo002?oooo00<0
000co`0co`003S?o00030000oooooooo053oool00ol0VOooooooo`0Zoooo002?oooo0P0000lco`00
0`000?ooooooo`1@oooo00?o09Woooooool0:_ooo`00Soooo`030000<ol0<ol000hco`000`000?oo
ooooo`1@oooo00?o09Woooooool0:_ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`1@
oooo00?o09Woooooool0:_ooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`1Aoooo00?o
09Woooooool0:_ooo`00Qoooo`@00004oooo00<0000co`0co`003C?o00030000oooooooo057oool0
0ol0VOooooooo`0Zoooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol000dco`000`000?oo
ooooo`1Aoooo00?o09Woooooool0:_ooo`00R?ooo`030000oooooooo00Coool300003C?o00030000
oooooooo057oool00ol0VOooooooo`0Zoooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
00dco`000`000?ooooooo`1Aoooo00?o09Woooooool0:_ooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol000`co`000`000?ooooooo`1Boooo00?o09Woooooool0:_ooo`00R?ooo`800005
oooo00<0000co`0co`0033?o00030000oooooooo05;oool00ol0VOooooooo`0Zoooo002?oooo00<0
000co`0co`0033?o00030000oooooooo05;oool00ol0VOooooooo`0Zoooo002?oooo00<0000co`0c
o`0033?o00030000oooooooo05;oool00ol0VOooooooo`0Zoooo002?oooo0P0000dco`000`000?oo
ooooo`1Boooo00?o09Woooooool0:_ooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`1B
oooo00?o09Woooooool0:_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Coooo00?o
09Woooooool0:_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Coooo00?o09Wooooo
ool0:_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Coooo00?o09Woooooool0:_oo
o`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Coooo00?o09Woooooool0:_ooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`1Coooo00?o09Woooooool0:_ooo`00Soooo`80000<
<ol000<0003oooooool0Doooo`03o`2Ioooooooo02[oool008ooool00`0003?o03?o000;<ol000<0
003oooooool0Doooo`03o`2Ioooooooo02[oool008ooool00`0003?o03?o000:<ol000<0003ooooo
ool0E?ooo`03o`2Ioooooooo02[oool008ooool00`0003?o03?o000:<ol000<0003oooooool0E?oo
o`03o`2Ioooooooo02[oool008ooool00`0003?o03?o000:<ol000<0003oooooool0E?ooo`03o`2I
oooooooo02[oool008ooool00`0003?o03?o000:<ol000<0003oooooool0E?ooo`03o`2Ioooooooo
02[oool008ooool200002c?o00030000oooooooo05Coool00ol0VOooooooo`0Zoooo002?oooo00<0
000co`0co`002S?o00030000oooooooo05Coool00ol0VOooooooo`0Zoooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo05Coool00ol0VOooooooo`0Zoooo002?oooo00<0000co`0co`002C?o
00030000oooooooo05Goool00ol0VOooooooo`0Zoooo002?oooo00<0000co`0co`002C?o00030000
oooooooo05Goool00ol0VOooooooo`0Zoooo002?oooo00<0000co`0co`002C?o00030000oooooooo
05Goool00ol0VOooooooo`0Zoooo002?oooo0P0000Xco`000`000?ooooooo`1Eoooo00?o09Wooooo
ool0:_ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1Eoooo00?o09Woooooool0:_oo
o`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1Eoooo00?o09Woooooool0:_ooo`00Sooo
o`030000<ol0<ol000Pco`000`000?ooooooo`1Foooo00?o09Woooooool0:_ooo`00R?ooo`800005
oooo00<0000co`0co`0023?o00030000oooooooo05Koool00ol0VOooooooo`0Zoooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo05Koool00ol0VOooooooo`0Z
oooo0029oooo00<0003oooooool00oooo`<00008<ol000<0003oooooool0E_ooo`03o`2Ioooooooo
02[oool008[oool00`000?ooooooo`02oooo00<0000co`0co`0023?o00030000oooooooo05Koool0
0ol0VOooooooo`0Zoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000
oooooooo05Koool00ol0VOooooooo`0Zoooo0028oooo0P0000Goool00`0003?o03?o0007<ol000<0
003oooooool0Eoooo`03o`2Ioooooooo02[oool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool0Eoooo`03o`2Ioooooooo02[oool008ooool00`0003?o03?o0007<ol000<0003oooooool0Eooo
o`03o`2Ioooooooo02[oool008ooool00`0003?o03?o0007<ol000<0003oooooool0Eoooo`03o`2I
oooooooo02[oool008ooool2000023?o00030000oooooooo05Ooool00ol0VOooooooo`0Zoooo002?
oooo00<0000co`0co`001c?o00030000oooooooo05Ooool00ol0VOooooooo`0Zoooo002?oooo00<0
000co`0co`001c?o00030000oooooooo05Ooool00ol0VOooooooo`0Zoooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo05Ooool00ol0VOooooooo`0Zoooo002?oooo00<0000co`0co`001S?o
00030000oooooooo05Soool00ol0VOooooooo`0Zoooo002?oooo00<0000co`0co`001S?o00030000
oooooooo05Soool00ol0VOooooooo`0Zoooo002?oooo0P0000Lco`000`000?ooooooo`1Hoooo00?o
09Woooooool0:_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Hoooo00?o09Wooooo
ool0:_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Hoooo00?o09Woooooool0:_oo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Hoooo00?o09Woooooool0:_ooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`1Hoooo00?o09Woooooool0:_ooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`1Hoooo00?o09Woooooool0:_ooo`00Soooo`800006<ol000<0
003oooooool0FOooo`03o`2Ioooooooo02[oool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool0FOooo`03o`2Ioooooooo02[oool008ooool00`0003?o03?o0005<ol000<0003oooooool0FOoo
o`03o`2Ioooooooo02[oool008ooool00`0003?o03?o0005<ol000<0003oooooool0FOooo`03o`2I
oooooooo02[oool008ooool00`0003?o03?o0005<ol000<0003oooooool0FOooo`03o`2Ioooooooo
02[oool008ooool00`0003?o03?o0005<ol000<0003oooooool0FOooo`03o`2Ioooooooo02[oool0
08ooool200001S?o00030000oooooooo05Woool00ol0VOooooooo`0Zoooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo05Woool00ol0VOooooooo`0Zoooo002?oooo00<0000co`0co`001C?o
00030000oooooooo05Woool00ol0VOooooooo`0Zoooo002?oooo00<0000co`0co`0013?o00030000
oooooooo05[oool00ol0VOooooooo`0Zoooo002?oooo00<0000co`0co`0013?o00030000oooooooo
05[oool00ol0VOooooooo`0Zoooo0029oooo0`0000?oool00`0003?o03?o0004<ol000<0003ooooo
ool0F_ooo`03o`2Ioooooooo02[oool008[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o
00030000oooooooo05[oool00ol0VOooooooo`0Zoooo0027oooo1@0000?oool3000013?o00030000
oooooooo05[oool00ol0VOooooooo`0Zoooo0027oooo00@0003oooooool00004oooo1c?o08[oool0
08Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o
08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?oooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000c?o
008000000c?o0?ooooooo`0300000oooo`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo
00Lco`02oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0003ooolco`001S?o00;oool0
10000?ooooooo`0000;oool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0000koool00`0003?o03?o0005<ol00_ooo`<00003oooo0`0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00001S?o00?oool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool00`000?oo
ooooo`0Aoooo0P0000Lco`03oooo0`0000?oool300000_ooo`030000oooooooo07Woool008ooool7
<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.68) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.87754 .12361 L
.88797 .12361 L
.89307 .12361 L
.89548 .12361 L
.89771 .12361 L
.89886 .12361 L
s
.89886 .12361 m
.89935 .61803 L
s
0 .4 1 r
.02381 .12361 m
.04262 .12361 L
.06244 .12361 L
.08255 .12361 L
.08806 .12361 L
.09396 .12361 L
.09682 .12361 L
.09822 .12361 L
.09952 .12361 L
.1007 .12289 L
.10195 .12161 L
.10458 .11899 L
.12434 .10192 L
.14241 .08985 L
.16182 .08 L
.17265 .07569 L
.1827 .07235 L
.20169 .06755 L
.21172 .0657 L
.22241 .06418 L
.2327 .06311 L
.23849 .06266 L
.24382 .06234 L
.2485 .06212 L
.25363 .06195 L
.25622 .06189 L
.25764 .06186 L
.25899 .06184 L
.26024 .06183 L
.2609 .06182 L
.26161 .06182 L
.26285 .06181 L
.26399 .0618 L
.26513 .0618 L
.26637 .06181 L
.26767 .06181 L
.26888 .06182 L
.27002 .06183 L
.27105 .06184 L
.27336 .06188 L
.27586 .06193 L
.27856 .06199 L
.28346 .06215 L
.29297 .06256 L
.30174 .06307 L
.32051 .06447 L
.34115 .06643 L
.38149 .07105 L
.42031 .07599 L
.46159 .08132 L
Mistroke
.48222 .08393 L
.49226 .08517 L
.50135 .08628 L
.50594 .08675 L
.51089 .08714 L
.51557 .08742 L
.51987 .08761 L
.52224 .08768 L
.52445 .08774 L
.5257 .08776 L
.52687 .08778 L
.52752 .08779 L
.52823 .08779 L
.52947 .0878 L
.53068 .08781 L
.53137 .08781 L
.53202 .08781 L
.53333 .08781 L
.53406 .0878 L
.53473 .0878 L
.53586 .08779 L
.5371 .08777 L
.53959 .08773 L
.54214 .08767 L
.5449 .0876 L
.54989 .08741 L
.55924 .08695 L
.57016 .08622 L
.58021 .0854 L
.61966 .08105 L
.6576 .0756 L
.69799 .06877 L
.73687 .06143 L
.7782 .05303 L
.81801 .0447 L
.85631 .03692 L
.87567 .03328 L
.88596 .03148 L
.89136 .03058 L
.89431 .03011 L
.89706 .02968 L
.89831 .02948 L
.89949 .0293 L
.90015 .12361 L
.90086 .12361 L
.90209 .12361 L
.90761 .12361 L
.91729 .12361 L
.93629 .12361 L
.97619 .12361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.68) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo06;oool00`1Vooooooooo`0Yoooo002?oooo00<0003ooooo
ool0F_ooo`T0I_l[oooo002?oooo00<0003oooooool0EOooo`D0I_l8oooo00<0I_ooooooool0:Ooo
o`00Soooo`030000oooooooo057oool406Ko3Oooo`0306Kooooooooo02Woool008ooool00`000?oo
ooooo`1=oooo101Voa7oool00`1Vooooooooo`0Yoooo002?oooo00<0003oooooool0B_ooo`<0I_lE
oooo00<0I_ooooooool0:Oooo`00Soooo`800017oooo101VoaSoool00`1Vooooooooo`0Yoooo002?
oooo00<0003oooooool0@_ooo`@0I_lLoooo00<0I_ooooooool0:Oooo`00Soooo`030000oooooooo
03coool606Ko8?ooo`0306Kooooooooo02Woool004SooolL06Ko:oooo`030000oooooooo03Goool7
06Ko9_ooo`0306Kooooooooo02Woool004;oool606Ko7?ooo`P0I_lSoooo00<0003oooooool0;Ooo
o`P0I_l]oooo00<0I_ooooooool0:Oooo`00?_ooo`@0I_lZoooo2P1VoaWoool00`000?ooooooo`0X
oooo1@1VocGoool00`1Vooooooooo`0Yoooo000koooo0`1VocSoool806Ko4Oooo`80000Toooo1@1V
oc[oool00`1Vooooooooo`0Yoooo000Goooo100001koool206Ko6Oooo`D0000Uoooo1@1Vo`coool0
0`000?ooooooo`0Noooo1@1VoaCoool500009_ooo`0306Kooooooooo00ooool400005_ooo`005ooo
o`030000oooooooo01goool206Ko7Oooo`030000oooooooo02[oool906Ko0oooo`030000oooooooo
01Ooool706Ko6oooo`030000oooooooo02Koool00`1Vooooooooo`0?oooo00<0003oooooool05ooo
o`006?ooo`030000oooooooo01[oool206Ko7oooo`030000oooooooo03?oool306Ko00<00000I_l0
I_l05`1Vob;oool00`000?ooooooo`0Voooo00<0I_ooooooool04?ooo`030000oooooooo01Koool0
017oool400001?ooo`030000oooooooo01Soool00`1Vooooooooo`0Goooo100000Coool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo02Koool00`1Vooooooooo`0Aoooo00<0
003oooooool05Oooo`005oooo`040000oooooooo00006?ooo`0306Kooooooooo023oool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo02Koool00`1Vooooooooo`0?oooo00@0
003oooooool0000Foooo000Hoooo0P0001Ooool206Ko8_ooo`80000hoooo0P0003Woool20000:?oo
o`0306Kooooooooo013oool200005oooo`00<?ooo`0306Kooooooooo05coool00`000?ooooooo`1R
oooo00<0I_ooooooool0:Oooo`00;oooo`0306Kooooooooo05goool00`000?ooooooo`1Roooo00<0
I_ooooooool0:Oooo`00;Oooo`80I_mPoooo00<0003oooooool0H_ooo`0306Kooooooooo02Woool0
02coool00`1Vooooooooo`1Poooo00<0003oooooool0H_ooo`0306Kooooooooo02Woool002_oool0
0`1Vooooooooo`1Qoooo00<0003oooooool0H_ooo`0306Kooooooooo02Woool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Hco`0P000000?o09T0003oool01Oooo`030000oooooooo00Woool0
0`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o
03?o000i<ol02@00023oool00ol0VOooooooo`0Aoooo00<0003oooooool05Oooo`00Soooo`030000
<ol0<ol003<co`060000:Oooo`03o`2Ioooooooo02Woool008ooool00`0003?o03?o000a<ol00P00
02ooool00ol0VOooooooo`0Yoooo002?oooo00<0000co`0co`00;c?o0080000aoooo00?o09Wooooo
ool0:Oooo`00Soooo`030000<ol0<ol002`co`030000<oooo`03o`2Ioooooooo02Woool008ooool2
0000:S?o00<0000foooo00?o09Woooooool0:Oooo`00Soooo`030000<ol0<ol002Lco`020000>Ooo
o`03o`2Ioooooooo02Woool008ooool00`0003?o03?o000V<ol000<0003oooooool0>Oooo`03o`2I
oooooooo02Woool008ooool00`0003?o03?o000U<ol000<0003oooooool0>_ooo`03o`2Ioooooooo
02Woool008ooool00`0003?o03?o000T<ol000<0003oooooool0>oooo`03o`2Ioooooooo02Woool0
08ooool00`0003?o03?o000R<ol00P0003koool00ol0VOooooooo`0Yoooo002?oooo0P00028co`00
0`000?ooooooo`0noooo00?o09Woooooool0:Oooo`00Soooo`030000<ol0<ol0020co`000`000?oo
ooooo`0ooooo00?o09Woooooool0:Oooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`10
oooo00?o09Woooooool0:Oooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`10oooo00?o
09Woooooool0:Oooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`11oooo00?o09Wooooo
ool0:Oooo`00Soooo`030000<ol0<ol001dco`000`000?ooooooo`12oooo00?o09Woooooool0:Ooo
o`00Soooo`80000M<ol000<0003oooooool0@oooo`03o`2Ioooooooo02Woool008ooool00`0003?o
03?o000K<ol000<0003oooooool0A?ooo`03o`2Ioooooooo02Woool008ooool00`0003?o03?o000K
<ol000<0003oooooool0A?ooo`03o`2Ioooooooo02Woool008ooool00`0003?o03?o000J<ol000<0
003oooooool0AOooo`03o`2Ioooooooo02Woool008ooool00`0003?o03?o000J<ol000<0003ooooo
ool0AOooo`03o`2Ioooooooo02Woool008ooool00`0003?o03?o000I<ol000<0003oooooool0A_oo
o`03o`2Ioooooooo02Woool008ooool200006S?o00030000oooooooo04Koool00ol0VOooooooo`0Y
oooo002?oooo00<0000co`0co`0063?o00030000oooooooo04Ooool00ol0VOooooooo`0Yoooo002?
oooo00<0000co`0co`0063?o00030000oooooooo04Ooool00ol0VOooooooo`0Yoooo002?oooo00<0
000co`0co`005c?o00030000oooooooo04Soool00ol0VOooooooo`0Yoooo002?oooo00<0000co`0c
o`005c?o00030000oooooooo04Soool00ol0VOooooooo`0Yoooo0027oooo1@0000?oool00`0003?o
03?o000F<ol000<0003oooooool0BOooo`03o`2Ioooooooo02Woool008Woool00`000?ooooooo`03
oooo00<0000co`0co`005S?o00030000oooooooo04Woool00ol0VOooooooo`0Yoooo0029oooo00<0
003oooooool00oooo`<0000E<ol000<0003oooooool0B_ooo`03o`2Ioooooooo02Woool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo04[oool00ol0VOooooooo`0Y
oooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`1:oooo00?o
09Woooooool0:Oooo`00R?ooo`800005oooo00<0000co`0co`0053?o00030000oooooooo04_oool0
0ol0VOooooooo`0Yoooo002?oooo00<0000co`0co`0053?o00030000oooooooo04_oool00ol0VOoo
ooooo`0Yoooo002?oooo00<0000co`0co`004c?o00030000oooooooo04coool00ol0VOooooooo`0Y
oooo002?oooo0P0001@co`000`000?ooooooo`1<oooo00?o09Woooooool0:Oooo`00Soooo`030000
<ol0<ol001<co`000`000?ooooooo`1<oooo00?o09Woooooool0:Oooo`00Soooo`030000<ol0<ol0
018co`000`000?ooooooo`1=oooo00?o09Woooooool0:Oooo`00Soooo`030000<ol0<ol0018co`00
0`000?ooooooo`1=oooo00?o09Woooooool0:Oooo`00Soooo`030000<ol0<ol0018co`000`000?oo
ooooo`1=oooo00?o09Woooooool0:Oooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`1>
oooo00?o09Woooooool0:Oooo`00Soooo`80000B<ol000<0003oooooool0C_ooo`03o`2Ioooooooo
02Woool008ooool00`0003?o03?o000A<ol000<0003oooooool0C_ooo`03o`2Ioooooooo02Woool0
08ooool00`0003?o03?o000A<ol000<0003oooooool0C_ooo`03o`2Ioooooooo02Woool008ooool0
0`0003?o03?o000@<ol000<0003oooooool0Coooo`03o`2Ioooooooo02Woool008ooool00`0003?o
03?o000@<ol000<0003oooooool0Coooo`03o`2Ioooooooo02Woool008ooool00`0003?o03?o000@
<ol000<0003oooooool0Coooo`03o`2Ioooooooo02Woool008ooool00`0003?o03?o000@<ol000<0
003oooooool0Coooo`03o`2Ioooooooo02Woool008ooool2000043?o00030000oooooooo053oool0
0ol0VOooooooo`0Yoooo002?oooo00<0000co`0co`003c?o00030000oooooooo053oool00ol0VOoo
ooooo`0Yoooo002?oooo00<0000co`0co`003c?o00030000oooooooo053oool00ol0VOooooooo`0Y
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo053oool00ol0VOooooooo`0Yoooo002?
oooo00<0000co`0co`003c?o00030000oooooooo053oool00ol0VOooooooo`0Yoooo002?oooo00<0
000co`0co`003S?o00030000oooooooo057oool00ol0VOooooooo`0Yoooo002?oooo0P0000lco`00
0`000?ooooooo`1Aoooo00?o09Woooooool0:Oooo`00Soooo`030000<ol0<ol000hco`000`000?oo
ooooo`1Aoooo00?o09Woooooool0:Oooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`1A
oooo00?o09Woooooool0:Oooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`1Boooo00?o
09Woooooool0:Oooo`00Qoooo`@00004oooo00<0000co`0co`003C?o00030000oooooooo05;oool0
0ol0VOooooooo`0Yoooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol000dco`000`000?oo
ooooo`1Boooo00?o09Woooooool0:Oooo`00R?ooo`030000oooooooo00Coool300003C?o00030000
oooooooo05;oool00ol0VOooooooo`0Yoooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
00dco`000`000?ooooooo`1Boooo00?o09Woooooool0:Oooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol000`co`000`000?ooooooo`1Coooo00?o09Woooooool0:Oooo`00R?ooo`800005
oooo00<0000co`0co`0033?o00030000oooooooo05?oool00ol0VOooooooo`0Yoooo002?oooo00<0
000co`0co`0033?o00030000oooooooo05?oool00ol0VOooooooo`0Yoooo002?oooo00<0000co`0c
o`0033?o00030000oooooooo05?oool00ol0VOooooooo`0Yoooo002?oooo0P0000dco`000`000?oo
ooooo`1Coooo00?o09Woooooool0:Oooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`1C
oooo00?o09Woooooool0:Oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Doooo00?o
09Woooooool0:Oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Doooo00?o09Wooooo
ool0:Oooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Doooo00?o09Woooooool0:Ooo
o`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Doooo00?o09Woooooool0:Oooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`1Doooo00?o09Woooooool0:Oooo`00Soooo`80000<
<ol000<0003oooooool0E?ooo`03o`2Ioooooooo02Woool008ooool00`0003?o03?o000;<ol000<0
003oooooool0E?ooo`03o`2Ioooooooo02Woool008ooool00`0003?o03?o000:<ol000<0003ooooo
ool0EOooo`03o`2Ioooooooo02Woool008ooool00`0003?o03?o000:<ol000<0003oooooool0EOoo
o`03o`2Ioooooooo02Woool008ooool00`0003?o03?o000:<ol000<0003oooooool0EOooo`03o`2I
oooooooo02Woool008ooool00`0003?o03?o000:<ol000<0003oooooool0EOooo`03o`2Ioooooooo
02Woool008ooool200002c?o00030000oooooooo05Goool00ol0VOooooooo`0Yoooo002?oooo00<0
000co`0co`002S?o00030000oooooooo05Goool00ol0VOooooooo`0Yoooo002?oooo00<0000co`0c
o`002S?o00030000oooooooo05Goool00ol0VOooooooo`0Yoooo002?oooo00<0000co`0co`002C?o
00030000oooooooo05Koool00ol0VOooooooo`0Yoooo002?oooo00<0000co`0co`002C?o00030000
oooooooo05Koool00ol0VOooooooo`0Yoooo002?oooo00<0000co`0co`002C?o00030000oooooooo
05Koool00ol0VOooooooo`0Yoooo002?oooo0P0000Xco`000`000?ooooooo`1Foooo00?o09Wooooo
ool0:Oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1Foooo00?o09Woooooool0:Ooo
o`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1Foooo00?o09Woooooool0:Oooo`00Sooo
o`030000<ol0<ol000Pco`000`000?ooooooo`1Goooo00?o09Woooooool0:Oooo`00R?ooo`800005
oooo00<0000co`0co`0023?o00030000oooooooo05Ooool00ol0VOooooooo`0Yoooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo05Ooool00ol0VOooooooo`0Y
oooo0029oooo00<0003oooooool00oooo`<00008<ol000<0003oooooool0Eoooo`03o`2Ioooooooo
02Woool008[oool00`000?ooooooo`02oooo00<0000co`0co`0023?o00030000oooooooo05Ooool0
0ol0VOooooooo`0Yoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000
oooooooo05Ooool00ol0VOooooooo`0Yoooo0028oooo0P0000Goool00`0003?o03?o0007<ol000<0
003oooooool0F?ooo`03o`2Ioooooooo02Woool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool0F?ooo`03o`2Ioooooooo02Woool008ooool00`0003?o03?o0007<ol000<0003oooooool0F?oo
o`03o`2Ioooooooo02Woool008ooool00`0003?o03?o0007<ol000<0003oooooool0F?ooo`03o`2I
oooooooo02Woool008ooool2000023?o00030000oooooooo05Soool00ol0VOooooooo`0Yoooo002?
oooo00<0000co`0co`001c?o00030000oooooooo05Soool00ol0VOooooooo`0Yoooo002?oooo00<0
000co`0co`001c?o00030000oooooooo05Soool00ol0VOooooooo`0Yoooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo05Soool00ol0VOooooooo`0Yoooo002?oooo00<0000co`0co`001S?o
00030000oooooooo05Woool00ol0VOooooooo`0Yoooo002?oooo00<0000co`0co`001S?o00030000
oooooooo05Woool00ol0VOooooooo`0Yoooo002?oooo0P0000Lco`000`000?ooooooo`1Ioooo00?o
09Woooooool0:Oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Ioooo00?o09Wooooo
ool0:Oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Ioooo00?o09Woooooool0:Ooo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Ioooo00?o09Woooooool0:Oooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`1Ioooo00?o09Woooooool0:Oooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`1Ioooo00?o09Woooooool0:Oooo`00Soooo`800006<ol000<0
003oooooool0F_ooo`03o`2Ioooooooo02Woool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool0F_ooo`03o`2Ioooooooo02Woool008ooool00`0003?o03?o0005<ol000<0003oooooool0F_oo
o`03o`2Ioooooooo02Woool008ooool00`0003?o03?o0005<ol000<0003oooooool0F_ooo`03o`2I
oooooooo02Woool008ooool00`0003?o03?o0005<ol000<0003oooooool0F_ooo`03o`2Ioooooooo
02Woool008ooool00`0003?o03?o0005<ol000<0003oooooool0F_ooo`03o`2Ioooooooo02Woool0
08ooool200001S?o00030000oooooooo05[oool00ol0VOooooooo`0Yoooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo05[oool00ol0VOooooooo`0Yoooo002?oooo00<0000co`0co`001C?o
00030000oooooooo05[oool00ol0VOooooooo`0Yoooo002?oooo00<0000co`0co`0013?o00030000
oooooooo05_oool00ol0VOooooooo`0Yoooo002?oooo00<0000co`0co`0013?o00030000oooooooo
05_oool00ol0VOooooooo`0Yoooo0029oooo0`0000?oool00`0003?o03?o0004<ol000<0003ooooo
ool0Foooo`03o`2Ioooooooo02Woool008[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o
00030000oooooooo05_oool00ol0VOooooooo`0Yoooo0027oooo1@0000?oool3000013?o00030000
oooooooo05_oool00ol0VOooooooo`0Yoooo0027oooo00@0003oooooool00004oooo1c?o08[oool0
08Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o
08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?oooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000c?o
008000000c?o0?ooooooo`0300001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo
00Lco`02oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0003ooolco`001S?o00;oool0
10000?ooooooo`0000;oool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0000koool00`0003?o03?o0005<ol00_ooo`<00004oooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00001S?o00?oool0
0`000?ooooooo`02oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000
oooooooo017oool200001c?o00?oool300000oooo`800003oooo00<0003oooooool0NOooo`00Sooo
o`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.87754 .12361 L
.88797 .12361 L
.89307 .12361 L
.89771 .12361 L
.90008 .12361 L
.90133 .12361 L
.90265 .12361 L
.90381 .12361 L
s
.90381 .12361 m
.90432 .61803 L
s
0 .4 1 r
.02381 .12361 m
.04262 .12361 L
.06244 .12361 L
.08255 .12361 L
.08806 .12361 L
.09109 .12361 L
.09258 .12361 L
.09324 .12361 L
.09396 .12361 L
.09525 .12359 L
.09596 .12286 L
.09662 .12218 L
.09952 .11928 L
.10458 .11446 L
.12312 .09931 L
.14335 .08665 L
.16449 .07696 L
.17502 .07326 L
.18458 .07046 L
.19403 .06816 L
.20425 .06615 L
.21505 .06451 L
.22522 .06336 L
.23473 .0626 L
.24012 .06229 L
.24516 .06207 L
.24789 .06198 L
.25048 .06191 L
.2528 .06187 L
.2541 .06185 L
.25533 .06183 L
.25663 .06182 L
.25732 .06181 L
.25807 .06181 L
.25881 .06181 L
.25959 .0618 L
.26026 .0618 L
.26099 .0618 L
.2623 .06181 L
.26303 .06181 L
.2637 .06182 L
.265 .06183 L
.26622 .06184 L
.26862 .06188 L
.27085 .06192 L
.27595 .06205 L
.28091 .06223 L
.28624 .06246 L
.30469 .06359 L
.32587 .06539 L
Mistroke
.34597 .06745 L
.38421 .07198 L
.42491 .0772 L
.46409 .08225 L
.48411 .08476 L
.49463 .08605 L
.50037 .08674 L
.50573 .0873 L
.51054 .08769 L
.5157 .088 L
.51864 .08813 L
.52142 .08823 L
.52392 .0883 L
.52533 .08832 L
.52663 .08835 L
.52774 .08836 L
.52892 .08837 L
.53004 .08838 L
.53107 .08838 L
.53221 .08838 L
.53345 .08838 L
.53475 .08837 L
.53596 .08836 L
.53725 .08835 L
.53846 .08833 L
.54074 .08829 L
.54319 .08823 L
.54585 .08815 L
.55533 .08776 L
.56576 .08714 L
.58682 .08543 L
.62721 .08077 L
.66608 .07505 L
.70741 .06794 L
.74723 .06032 L
.78552 .05249 L
.82627 .04397 L
.86551 .03606 L
.88518 .03244 L
.89379 .03096 L
.89868 .03017 L
.90106 .02979 L
.90323 .02945 L
.90435 .02928 L
.90556 .12361 L
.90671 .12361 L
.90777 .12361 L
.91264 .12361 L
.92255 .12361 L
.9434 .12361 L
Mistroke
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo06?oool00`1Vooooooooo`0Xoooo002?oooo00<0003ooooo
ool0GOooo`L0I_lZoooo002?oooo00<0003oooooool0F?ooo`D0I_l6oooo00<0I_ooooooool0:?oo
o`00Soooo`030000oooooooo05?oool506Ko2oooo`0306Kooooooooo02Soool008ooool00`000?oo
ooooo`1>oooo1@1Voa3oool00`1Vooooooooo`0Xoooo002?oooo00<0003oooooool0B?ooo`H0I_lE
oooo00<0I_ooooooool0:?ooo`00Soooo`800014oooo1@1Voa_oool00`1Vooooooooo`0Xoooo002?
oooo00<0003oooooool0?oooo`@0I_lPoooo00<0I_ooooooool0:?ooo`00Soooo`030000oooooooo
03[oool506Ko9?ooo`0306Kooooooooo02Soool004KooolJ06Ko;oooo`030000oooooooo03Goool5
06Ko:Oooo`0306Kooooooooo02Soool0047oool506Ko6_ooo`d0I_lRoooo00<0003oooooool0<?oo
o`D0I_l^oooo00<0I_ooooooool0:?ooo`00?oooo`80I_l/oooo201Voa[oool00`000?ooooooo`0Z
oooo1P1Voc?oool00`1Vooooooooo`0Xoooo000loooo0`1VocKoool506Ko5Oooo`80000Voooo1@1V
ocWoool00`1Vooooooooo`0Xoooo000Goooo100001koool306Ko6?ooo`D0000Qoooo1`1Vo`koool0
0`000?ooooooo`0Poooo1@1Voa;oool50000:?ooo`0306Kooooooooo00goool400005_ooo`005ooo
o`030000oooooooo01goool206Ko7Oooo`030000oooooooo02Soool806Ko1_ooo`030000oooooooo
01Woool706Ko6Oooo`030000oooooooo02Soool00`1Vooooooooo`0=oooo00<0003oooooool05ooo
o`006?ooo`030000oooooooo01[oool206Ko7oooo`030000oooooooo033oool606Ko00<00000I_l0
I_l06@1Vob3oool00`000?ooooooo`0Xoooo00<0I_ooooooool03_ooo`030000oooooooo01Koool0
017oool400001?ooo`030000oooooooo01Ooool206Ko6Oooo`@00004oooo00<0003oooooool0=_oo
o`030000oooooooo03Woool00`000?ooooooo`0Xoooo00<0I_ooooooool03oooo`030000oooooooo
01Goool001Ooool010000?ooooooo`0001Koool206Ko8oooo`030000oooooooo03Koool00`000?oo
ooooo`0ioooo00<0003oooooool0:?ooo`0306Kooooooooo00goool010000?ooooooo`0001Koool0
01Soool200005Oooo`80I_lToooo0P0003Soool20000>Oooo`80000Zoooo00<0I_ooooooool03_oo
o`80000Goooo000^oooo00<0I_ooooooool0G_ooo`030000oooooooo06Coool00`1Vooooooooo`0W
oooo000]oooo00<0I_ooooooool0Goooo`030000oooooooo06Coool00`1Vooooooooo`0Woooo000/
oooo00<0I_ooooooool0H?ooo`030000oooooooo06Coool00`1Vooooooooo`0Woooo000[oooo00<0
I_ooooooool0HOooo`030000oooooooo06Coool00`1Vooooooooo`0Woooo000Yoooo0P1VofCoool0
0`000?ooooooo`1Toooo00<0I_ooooooool09oooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0c
o`001S?o024000000ol0VOooooooo`04oooo00<0003oooooool02Oooo`030000oooooooo01Goool0
01Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol003Tco`0900008Ooo
o`03o`2Ioooooooo013oool00`000?ooooooo`0Eoooo002?oooo00<0000co`0co`00<c?o00H0000Z
oooo00?o09Woooooool0:?ooo`00Soooo`030000<ol0<ol0034co`020000<?ooo`03o`2Ioooooooo
02Soool008ooool00`0003?o03?o000_<ol00P0003;oool00ol0VOooooooo`0Xoooo002?oooo00<0
000co`0co`00;3?o00<0000doooo00?o09Woooooool0:?ooo`00Soooo`80000Z<ol00`0003Ooool0
0ol0VOooooooo`0Xoooo002?oooo00<0000co`0co`009c?o0080000joooo00?o09Woooooool0:?oo
o`00Soooo`030000<ol0<ol002Hco`000`000?ooooooo`0joooo00?o09Woooooool0:?ooo`00Sooo
o`030000<ol0<ol002Dco`000`000?ooooooo`0koooo00?o09Woooooool0:?ooo`00Soooo`030000
<ol0<ol002@co`000`000?ooooooo`0loooo00?o09Woooooool0:?ooo`00Soooo`030000<ol0<ol0
028co`020000?oooo`03o`2Ioooooooo02Soool008ooool200008S?o00030000oooooooo03ooool0
0ol0VOooooooo`0Xoooo002?oooo00<0000co`0co`0083?o00030000oooooooo043oool00ol0VOoo
ooooo`0Xoooo002?oooo00<0000co`0co`007c?o00030000oooooooo047oool00ol0VOooooooo`0X
oooo002?oooo00<0000co`0co`007c?o00030000oooooooo047oool00ol0VOooooooo`0Xoooo002?
oooo00<0000co`0co`007S?o00030000oooooooo04;oool00ol0VOooooooo`0Xoooo002?oooo00<0
000co`0co`007C?o00030000oooooooo04?oool00ol0VOooooooo`0Xoooo002?oooo0P0001dco`00
0`000?ooooooo`14oooo00?o09Woooooool0:?ooo`00Soooo`030000<ol0<ol001/co`000`000?oo
ooooo`15oooo00?o09Woooooool0:?ooo`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`15
oooo00?o09Woooooool0:?ooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`16oooo00?o
09Woooooool0:?ooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`16oooo00?o09Wooooo
ool0:?ooo`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`17oooo00?o09Woooooool0:?oo
o`00Soooo`80000J<ol000<0003oooooool0Aoooo`03o`2Ioooooooo02Soool008ooool00`0003?o
03?o000H<ol000<0003oooooool0B?ooo`03o`2Ioooooooo02Soool008ooool00`0003?o03?o000H
<ol000<0003oooooool0B?ooo`03o`2Ioooooooo02Soool008ooool00`0003?o03?o000G<ol000<0
003oooooool0BOooo`03o`2Ioooooooo02Soool008ooool00`0003?o03?o000G<ol000<0003ooooo
ool0BOooo`03o`2Ioooooooo02Soool008Ooool500000oooo`030000<ol0<ol001Hco`000`000?oo
ooooo`1:oooo00?o09Woooooool0:?ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000F
<ol000<0003oooooool0B_ooo`03o`2Ioooooooo02Soool008Woool00`000?ooooooo`03oooo0`00
01Dco`000`000?ooooooo`1;oooo00?o09Woooooool0:?ooo`00ROooo`030000oooooooo00?oool0
0`0003?o03?o000E<ol000<0003oooooool0Boooo`03o`2Ioooooooo02Soool008Woool00`000?oo
ooooo`03oooo00<0000co`0co`005C?o00030000oooooooo04_oool00ol0VOooooooo`0Xoooo0028
oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool0C?ooo`03o`2Ioooooooo02Soool0
08ooool00`0003?o03?o000D<ol000<0003oooooool0C?ooo`03o`2Ioooooooo02Soool008ooool0
0`0003?o03?o000C<ol000<0003oooooool0COooo`03o`2Ioooooooo02Soool008ooool2000053?o
00030000oooooooo04goool00ol0VOooooooo`0Xoooo002?oooo00<0000co`0co`004c?o00030000
oooooooo04goool00ol0VOooooooo`0Xoooo002?oooo00<0000co`0co`004S?o00030000oooooooo
04koool00ol0VOooooooo`0Xoooo002?oooo00<0000co`0co`004S?o00030000oooooooo04koool0
0ol0VOooooooo`0Xoooo002?oooo00<0000co`0co`004S?o00030000oooooooo04koool00ol0VOoo
ooooo`0Xoooo002?oooo00<0000co`0co`004C?o00030000oooooooo04ooool00ol0VOooooooo`0X
oooo002?oooo0P00018co`000`000?ooooooo`1?oooo00?o09Woooooool0:?ooo`00Soooo`030000
<ol0<ol0014co`000`000?ooooooo`1?oooo00?o09Woooooool0:?ooo`00Soooo`030000<ol0<ol0
014co`000`000?ooooooo`1?oooo00?o09Woooooool0:?ooo`00Soooo`030000<ol0<ol0010co`00
0`000?ooooooo`1@oooo00?o09Woooooool0:?ooo`00Soooo`030000<ol0<ol0010co`000`000?oo
ooooo`1@oooo00?o09Woooooool0:?ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`1@
oooo00?o09Woooooool0:?ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`1@oooo00?o
09Woooooool0:?ooo`00Soooo`80000@<ol000<0003oooooool0DOooo`03o`2Ioooooooo02Soool0
08ooool00`0003?o03?o000?<ol000<0003oooooool0DOooo`03o`2Ioooooooo02Soool008ooool0
0`0003?o03?o000?<ol000<0003oooooool0DOooo`03o`2Ioooooooo02Soool008ooool00`0003?o
03?o000?<ol000<0003oooooool0DOooo`03o`2Ioooooooo02Soool008ooool00`0003?o03?o000?
<ol000<0003oooooool0DOooo`03o`2Ioooooooo02Soool008ooool00`0003?o03?o000><ol000<0
003oooooool0D_ooo`03o`2Ioooooooo02Soool008ooool200003c?o00030000oooooooo05;oool0
0ol0VOooooooo`0Xoooo002?oooo00<0000co`0co`003S?o00030000oooooooo05;oool00ol0VOoo
ooooo`0Xoooo002?oooo00<0000co`0co`003S?o00030000oooooooo05;oool00ol0VOooooooo`0X
oooo002?oooo00<0000co`0co`003C?o00030000oooooooo05?oool00ol0VOooooooo`0Xoooo0027
oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool0Doooo`03o`2Ioooooooo02Soool0
08Ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo05?oool00ol0VOoo
ooooo`0Xoooo0028oooo00<0003oooooool01?ooo`<0000=<ol000<0003oooooool0Doooo`03o`2I
oooooooo02Soool008Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o00030000oooooooo
05?oool00ol0VOooooooo`0Xoooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0033?o
00030000oooooooo05Coool00ol0VOooooooo`0Xoooo0028oooo0P0000Goool00`0003?o03?o000<
<ol000<0003oooooool0E?ooo`03o`2Ioooooooo02Soool008ooool00`0003?o03?o000<<ol000<0
003oooooool0E?ooo`03o`2Ioooooooo02Soool008ooool00`0003?o03?o000<<ol000<0003ooooo
ool0E?ooo`03o`2Ioooooooo02Soool008ooool200003C?o00030000oooooooo05Coool00ol0VOoo
ooooo`0Xoooo002?oooo00<0000co`0co`0033?o00030000oooooooo05Coool00ol0VOooooooo`0X
oooo002?oooo00<0000co`0co`002c?o00030000oooooooo05Goool00ol0VOooooooo`0Xoooo002?
oooo00<0000co`0co`002c?o00030000oooooooo05Goool00ol0VOooooooo`0Xoooo002?oooo00<0
000co`0co`002c?o00030000oooooooo05Goool00ol0VOooooooo`0Xoooo002?oooo00<0000co`0c
o`002c?o00030000oooooooo05Goool00ol0VOooooooo`0Xoooo002?oooo00<0000co`0co`002c?o
00030000oooooooo05Goool00ol0VOooooooo`0Xoooo002?oooo0P0000`co`000`000?ooooooo`1E
oooo00?o09Woooooool0:?ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Eoooo00?o
09Woooooool0:?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1Foooo00?o09Wooooo
ool0:?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1Foooo00?o09Woooooool0:?oo
o`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1Foooo00?o09Woooooool0:?ooo`00Sooo
o`030000<ol0<ol000Xco`000`000?ooooooo`1Foooo00?o09Woooooool0:?ooo`00Soooo`80000;
<ol000<0003oooooool0E_ooo`03o`2Ioooooooo02Soool008ooool00`0003?o03?o000:<ol000<0
003oooooool0E_ooo`03o`2Ioooooooo02Soool008ooool00`0003?o03?o000:<ol000<0003ooooo
ool0E_ooo`03o`2Ioooooooo02Soool008ooool00`0003?o03?o0009<ol000<0003oooooool0Eooo
o`03o`2Ioooooooo02Soool008ooool00`0003?o03?o0009<ol000<0003oooooool0Eoooo`03o`2I
oooooooo02Soool008ooool00`0003?o03?o0009<ol000<0003oooooool0Eoooo`03o`2Ioooooooo
02Soool008ooool200002S?o00030000oooooooo05Ooool00ol0VOooooooo`0Xoooo002?oooo00<0
000co`0co`002C?o00030000oooooooo05Ooool00ol0VOooooooo`0Xoooo002?oooo00<0000co`0c
o`002C?o00030000oooooooo05Ooool00ol0VOooooooo`0Xoooo002?oooo00<0000co`0co`0023?o
00030000oooooooo05Soool00ol0VOooooooo`0Xoooo0028oooo0P0000Goool00`0003?o03?o0008
<ol000<0003oooooool0F?ooo`03o`2Ioooooooo02Soool008Ooool010000?ooooooo`0000Coool0
0`0003?o03?o0008<ol000<0003oooooool0F?ooo`03o`2Ioooooooo02Soool008Woool00`000?oo
ooooo`03oooo0`0000Pco`000`000?ooooooo`1Hoooo00?o09Woooooool0:?ooo`00R_ooo`030000
oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0F?ooo`03o`2Ioooooooo02Soool0
08Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0F?ooo`03o`2I
oooooooo02Soool008Soool200001Oooo`030000<ol0<ol000Lco`000`000?ooooooo`1Ioooo00?o
09Woooooool0:?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1Ioooo00?o09Wooooo
ool0:?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1Ioooo00?o09Woooooool0:?oo
o`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1Ioooo00?o09Woooooool0:?ooo`00Sooo
o`800008<ol000<0003oooooool0FOooo`03o`2Ioooooooo02Soool008ooool00`0003?o03?o0007
<ol000<0003oooooool0FOooo`03o`2Ioooooooo02Soool008ooool00`0003?o03?o0007<ol000<0
003oooooool0FOooo`03o`2Ioooooooo02Soool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool0FOooo`03o`2Ioooooooo02Soool008ooool00`0003?o03?o0006<ol000<0003oooooool0F_oo
o`03o`2Ioooooooo02Soool008ooool00`0003?o03?o0006<ol000<0003oooooool0F_ooo`03o`2I
oooooooo02Soool008ooool200001c?o00030000oooooooo05[oool00ol0VOooooooo`0Xoooo002?
oooo00<0000co`0co`001S?o00030000oooooooo05[oool00ol0VOooooooo`0Xoooo002?oooo00<0
000co`0co`001S?o00030000oooooooo05[oool00ol0VOooooooo`0Xoooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo05[oool00ol0VOooooooo`0Xoooo002?oooo00<0000co`0co`001S?o
00030000oooooooo05[oool00ol0VOooooooo`0Xoooo002?oooo00<0000co`0co`001S?o00030000
oooooooo05[oool00ol0VOooooooo`0Xoooo002?oooo0P0000Hco`000`000?ooooooo`1Koooo00?o
09Woooooool0:?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Koooo00?o09Wooooo
ool0:?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Koooo00?o09Woooooool0:?oo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Koooo00?o09Woooooool0:?ooo`00Sooo
o`030000<ol0<ol000Dco`000`000?ooooooo`1Koooo00?o09Woooooool0:?ooo`00Soooo`030000
<ol0<ol000Dco`000`000?ooooooo`1Koooo00?o09Woooooool0:?ooo`00Soooo`800006<ol000<0
003oooooool0Foooo`03o`2Ioooooooo02Soool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool0Foooo`03o`2Ioooooooo02Soool008ooool00`0003?o03?o0005<ol000<0003oooooool0Fooo
o`03o`2Ioooooooo02Soool008ooool00`0003?o03?o0004<ol000<0003oooooool0G?ooo`03o`2I
oooooooo02Soool008ooool00`0003?o03?o0004<ol000<0003oooooool0G?ooo`03o`2Ioooooooo
02Soool008Woool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`1Loooo00?o09Wooooo
ool0:?ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0003oooooool0G?oo
o`03o`2Ioooooooo02Soool008Ooool500000oooo`<00004<ol000<0003oooooool0G?ooo`03o`2I
oooooooo02Soool008Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?ooo`030000oooo0000
00Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:
oooo001loooo00<0003oooooool04?ooo`Lco`0;oooo00<0003oooooool0O?ooo`00Noooo`030000
oooooooo00Soool00`000?ooooooo`06oooo1c?o00coool00`000?ooooooo`1koooo001koooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003<ol00P0000Goool00`000?oo
ooooo`02oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`030000<ol0<ol000@co`07oooo00<0003oooooool00_oo
o`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`03<ol0
0000<ol000@co`07oooo00<0003oooooool00oooo`030000oooooooo07[oool007_oool00`000?oo
ooooo`0500003?ooo`8co`000`0003?o03?o0002<ol02?ooo`050000oooooooooooo000007goool0
07_oool01@000?ooooooooooo`00000?oooo00@0000co`0co`000003<ol01Oooo`040000oooooooo
00000oooo`030000oooooooo07_oool007coool00`000?ooooooo`0@oooo00<co`000000000013?o
00Goool400000_ooo`030000oooooooo07coool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.72) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.87754 .12361 L
.88797 .12361 L
.89771 .12361 L
.90265 .12361 L
.90508 .12361 L
.90733 .12361 L
.90859 .12361 L
.90922 .12361 L
s
.90922 .12361 m
.9095 .61803 L
s
0 .4 1 r
.02381 .12361 m
.04262 .12361 L
.06244 .12361 L
.07216 .12361 L
.08255 .12361 L
.08562 .12361 L
.08713 .12361 L
.08852 .12361 L
.08979 .12361 L
.09043 .12361 L
.09113 .12293 L
.09396 .12007 L
.10458 .11021 L
.12562 .09434 L
.14487 .08343 L
.16474 .07511 L
.18364 .06948 L
.19323 .06733 L
.20344 .0655 L
.21309 .06415 L
.22183 .06323 L
.22671 .06283 L
.23186 .06248 L
.23625 .06224 L
.24108 .06204 L
.2438 .06196 L
.24628 .0619 L
.24765 .06187 L
.24914 .06185 L
.25054 .06183 L
.25185 .06182 L
.25304 .06181 L
.25416 .06181 L
.25539 .0618 L
.25609 .0618 L
.25672 .0618 L
.25793 .06181 L
.25924 .06182 L
.25991 .06182 L
.26062 .06183 L
.2619 .06185 L
.26449 .06189 L
.26723 .06195 L
.27214 .06208 L
.27743 .06228 L
.28324 .06255 L
.3034 .06385 L
.32284 .06555 L
.34374 .06773 L
.38501 .07268 L
Mistroke
.42477 .0778 L
.46302 .08272 L
.48438 .08538 L
.49446 .0866 L
.50372 .08767 L
.50844 .0881 L
.51342 .08844 L
.51842 .08868 L
.52126 .08879 L
.5239 .08886 L
.52509 .08888 L
.52637 .08891 L
.5275 .08892 L
.52871 .08893 L
.52979 .08894 L
.53098 .08895 L
.53206 .08895 L
.53308 .08895 L
.53428 .08894 L
.53555 .08893 L
.53663 .08892 L
.53781 .08891 L
.54045 .08886 L
.5429 .08881 L
.54796 .08866 L
.55345 .08843 L
.5634 .0879 L
.582 .0865 L
.60191 .08453 L
.62297 .08203 L
.66091 .07665 L
.7013 .06991 L
.74017 .06265 L
.7815 .05432 L
.82132 .04599 L
.85961 .03813 L
.87897 .03441 L
.88926 .03255 L
.89467 .03161 L
.90036 .03066 L
.9054 .02985 L
.90678 .02964 L
.90754 .02952 L
.90825 .02941 L
.90892 .02931 L
.90965 .12361 L
.91091 .12361 L
.92059 .12361 L
.9396 .12361 L
.97619 .12361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.72) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo06Goool00`1Vooooooooo`0Voooo002?oooo00<0003ooooo
ool0Goooo`L0I_lXoooo002?oooo00<0003oooooool0Foooo`@0I_l6oooo00<0I_ooooooool09_oo
o`00Soooo`030000oooooooo05Koool506Ko2_ooo`0306Kooooooooo02Koool008ooool00`000?oo
ooooo`1Aoooo1@1Vo`ooool00`1Vooooooooo`0Voooo002?oooo00<0003oooooool0C?ooo`D0I_lD
oooo00<0I_ooooooool09_ooo`00Soooo`800018oooo1@1VoaWoool00`1Vooooooooo`0Voooo002?
oooo00<0003oooooool0@_ooo`D0I_lNoooo00<0I_ooooooool09_ooo`00Soooo`030000oooooooo
03goool506Ko8oooo`0306Kooooooooo02Koool004KooolJ06Ko;oooo`030000oooooooo03Soool5
06Ko:?ooo`0306Kooooooooo02Koool0047oool506Ko6_ooo`d0I_lRoooo00<0003oooooool0<ooo
o`D0I_l]oooo00<0I_ooooooool09_ooo`00?Oooo`@0I_l/oooo201Voa[oool00`000?ooooooo`0/
oooo1`1Voc;oool00`1Vooooooooo`0Voooo000ioooo101VocSoool506Ko5Oooo`80000Uoooo201V
ocWoool00`1Vooooooooo`0Voooo000Goooo100001coool206Ko6oooo`D0000Qoooo1`1Vo`koool0
0`000?ooooooo`0Ooooo1@1Voa?oool50000:Oooo`0306Kooooooooo00coool400005_ooo`005ooo
o`030000oooooooo01_oool206Ko7oooo`030000oooooooo02Soool806Ko1_ooo`030000oooooooo
01Goool:06Ko6_ooo`030000oooooooo02Woool00`1Vooooooooo`0<oooo00<0003oooooool05ooo
o`006?ooo`030000oooooooo01Soool206Ko8Oooo`030000oooooooo033oool606Ko00@00000I_l0
I_l0I_l:oooo2P1VobCoool00`000?ooooooo`0Yoooo00<0I_ooooooool03Oooo`030000oooooooo
01Koool0017oool400001?ooo`030000oooooooo01Goool206Ko6oooo`@00004oooo00<0003ooooo
ool0=_ooo`040000oooooooooooo2P1Vobkoool00`000?ooooooo`0Yoooo00<0I_ooooooool03_oo
o`030000oooooooo01Goool001Ooool010000?ooooooo`0001Goool00`1Vooooooooo`0Soooo00<0
003oooooool0=_ooo`030000oooooooo03Woool00`000?ooooooo`0Yoooo00<0I_ooooooool03?oo
o`040000oooooooo00005_ooo`006?ooo`80000Eoooo00<0I_ooooooool08oooo`80000hoooo0P00
03Woool20000:oooo`0306Kooooooooo00goool200005oooo`00;Oooo`80I_mPoooo00<0003ooooo
ool0IOooo`0306Kooooooooo02Koool002coool00`1Vooooooooo`1Poooo00<0003oooooool0IOoo
o`0306Kooooooooo02Koool002_oool00`1Vooooooooo`1Qoooo00<0003oooooool0IOooo`0306Ko
oooooooo02Koool002[oool00`1Vooooooooo`1Roooo00<0003oooooool0IOooo`0306Kooooooooo
02Koool002Woool00`1Vooooooooo`1Soooo00<0003oooooool0IOooo`0306Kooooooooo02Koool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R000000?ooooo09Woool00oooo`030000
oooooooo00Woool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000oooooooo
03Woool00`0003?o03?o000i<ol02@0002?oool00ol0VOooooooo`0>oooo00<0003oooooool05Ooo
o`00Soooo`030000<ol0<ol003<co`060000;?ooo`03o`2Ioooooooo02Koool008ooool00`0003?o
03?o000a<ol00P0003;oool00ol0VOooooooo`0Voooo002?oooo00<0000co`0co`00;c?o0080000d
oooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol002`co`030000=_ooo`03o`2Ioooooooo
02Koool008ooool20000:S?o00<0000ioooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol0
02Lco`020000??ooo`03o`2Ioooooooo02Koool008ooool00`0003?o03?o000V<ol000<0003ooooo
ool0??ooo`03o`2Ioooooooo02Koool008ooool00`0003?o03?o000U<ol000<0003oooooool0?Ooo
o`03o`2Ioooooooo02Koool008ooool00`0003?o03?o000T<ol000<0003oooooool0?_ooo`03o`2I
oooooooo02Koool008ooool00`0003?o03?o000R<ol00P00047oool00ol0VOooooooo`0Voooo002?
oooo0P00028co`000`000?ooooooo`11oooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol0
020co`000`000?ooooooo`12oooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol001lco`00
0`000?ooooooo`13oooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol001lco`000`000?oo
ooooo`13oooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`14
oooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol001dco`000`000?ooooooo`15oooo00?o
09Woooooool09_ooo`00Soooo`80000M<ol000<0003oooooool0A_ooo`03o`2Ioooooooo02Koool0
08ooool00`0003?o03?o000K<ol000<0003oooooool0Aoooo`03o`2Ioooooooo02Koool008ooool0
0`0003?o03?o000K<ol000<0003oooooool0Aoooo`03o`2Ioooooooo02Koool008ooool00`0003?o
03?o000J<ol000<0003oooooool0B?ooo`03o`2Ioooooooo02Koool008ooool00`0003?o03?o000J
<ol000<0003oooooool0B?ooo`03o`2Ioooooooo02Koool008ooool00`0003?o03?o000I<ol000<0
003oooooool0BOooo`03o`2Ioooooooo02Koool008ooool200006S?o00030000oooooooo04Woool0
0ol0VOooooooo`0Voooo002?oooo00<0000co`0co`0063?o00030000oooooooo04[oool00ol0VOoo
ooooo`0Voooo002?oooo00<0000co`0co`0063?o00030000oooooooo04[oool00ol0VOooooooo`0V
oooo002?oooo00<0000co`0co`005c?o00030000oooooooo04_oool00ol0VOooooooo`0Voooo002?
oooo00<0000co`0co`005c?o00030000oooooooo04_oool00ol0VOooooooo`0Voooo0027oooo1@00
00?oool00`0003?o03?o000F<ol000<0003oooooool0C?ooo`03o`2Ioooooooo02Koool008Woool0
0`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo04coool00ol0VOooooooo`0V
oooo0029oooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0COooo`03o`2Ioooooooo
02Koool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo04goool0
0ol0VOooooooo`0Voooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`000`000?oo
ooooo`1=oooo00?o09Woooooool09_ooo`00R?ooo`800005oooo00<0000co`0co`0053?o00030000
oooooooo04koool00ol0VOooooooo`0Voooo002?oooo00<0000co`0co`0053?o00030000oooooooo
04koool00ol0VOooooooo`0Voooo002?oooo00<0000co`0co`004c?o00030000oooooooo04ooool0
0ol0VOooooooo`0Voooo002?oooo0P0001@co`000`000?ooooooo`1?oooo00?o09Woooooool09_oo
o`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`1?oooo00?o09Woooooool09_ooo`00Sooo
o`030000<ol0<ol0018co`000`000?ooooooo`1@oooo00?o09Woooooool09_ooo`00Soooo`030000
<ol0<ol0018co`000`000?ooooooo`1@oooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol0
018co`000`000?ooooooo`1@oooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol0014co`00
0`000?ooooooo`1Aoooo00?o09Woooooool09_ooo`00Soooo`80000B<ol000<0003oooooool0DOoo
o`03o`2Ioooooooo02Koool008ooool00`0003?o03?o000A<ol000<0003oooooool0DOooo`03o`2I
oooooooo02Koool008ooool00`0003?o03?o000A<ol000<0003oooooool0DOooo`03o`2Ioooooooo
02Koool008ooool00`0003?o03?o000@<ol000<0003oooooool0D_ooo`03o`2Ioooooooo02Koool0
08ooool00`0003?o03?o000@<ol000<0003oooooool0D_ooo`03o`2Ioooooooo02Koool008ooool0
0`0003?o03?o000@<ol000<0003oooooool0D_ooo`03o`2Ioooooooo02Koool008ooool00`0003?o
03?o000@<ol000<0003oooooool0D_ooo`03o`2Ioooooooo02Koool008ooool2000043?o00030000
oooooooo05?oool00ol0VOooooooo`0Voooo002?oooo00<0000co`0co`003c?o00030000oooooooo
05?oool00ol0VOooooooo`0Voooo002?oooo00<0000co`0co`003c?o00030000oooooooo05?oool0
0ol0VOooooooo`0Voooo002?oooo00<0000co`0co`003c?o00030000oooooooo05?oool00ol0VOoo
ooooo`0Voooo002?oooo00<0000co`0co`003c?o00030000oooooooo05?oool00ol0VOooooooo`0V
oooo002?oooo00<0000co`0co`003S?o00030000oooooooo05Coool00ol0VOooooooo`0Voooo002?
oooo0P0000lco`000`000?ooooooo`1Doooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol0
00hco`000`000?ooooooo`1Doooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol000hco`00
0`000?ooooooo`1Doooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol000dco`000`000?oo
ooooo`1Eoooo00?o09Woooooool09_ooo`00Qoooo`@00004oooo00<0000co`0co`003C?o00030000
oooooooo05Goool00ol0VOooooooo`0Voooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol0
00dco`000`000?ooooooo`1Eoooo00?o09Woooooool09_ooo`00R?ooo`030000oooooooo00Coool3
00003C?o00030000oooooooo05Goool00ol0VOooooooo`0Voooo0029oooo00<0003oooooool00ooo
o`030000<ol0<ol000dco`000`000?ooooooo`1Eoooo00?o09Woooooool09_ooo`00Qoooo`040000
oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1Foooo00?o09Woooooool09_oo
o`00R?ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo05Koool00ol0VOooooooo`0V
oooo002?oooo00<0000co`0co`0033?o00030000oooooooo05Koool00ol0VOooooooo`0Voooo002?
oooo00<0000co`0co`0033?o00030000oooooooo05Koool00ol0VOooooooo`0Voooo002?oooo0P00
00dco`000`000?ooooooo`1Foooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol000`co`00
0`000?ooooooo`1Foooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`1Goooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1G
oooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Goooo00?o
09Woooooool09_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Goooo00?o09Wooooo
ool09_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Goooo00?o09Woooooool09_oo
o`00Soooo`80000<<ol000<0003oooooool0Eoooo`03o`2Ioooooooo02Koool008ooool00`0003?o
03?o000;<ol000<0003oooooool0Eoooo`03o`2Ioooooooo02Koool008ooool00`0003?o03?o000:
<ol000<0003oooooool0F?ooo`03o`2Ioooooooo02Koool008ooool00`0003?o03?o000:<ol000<0
003oooooool0F?ooo`03o`2Ioooooooo02Koool008ooool00`0003?o03?o000:<ol000<0003ooooo
ool0F?ooo`03o`2Ioooooooo02Koool008ooool00`0003?o03?o000:<ol000<0003oooooool0F?oo
o`03o`2Ioooooooo02Koool008ooool200002c?o00030000oooooooo05Soool00ol0VOooooooo`0V
oooo002?oooo00<0000co`0co`002S?o00030000oooooooo05Soool00ol0VOooooooo`0Voooo002?
oooo00<0000co`0co`002S?o00030000oooooooo05Soool00ol0VOooooooo`0Voooo002?oooo00<0
000co`0co`002C?o00030000oooooooo05Woool00ol0VOooooooo`0Voooo002?oooo00<0000co`0c
o`002C?o00030000oooooooo05Woool00ol0VOooooooo`0Voooo002?oooo00<0000co`0co`002C?o
00030000oooooooo05Woool00ol0VOooooooo`0Voooo002?oooo0P0000Xco`000`000?ooooooo`1I
oooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1Ioooo00?o
09Woooooool09_ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1Ioooo00?o09Wooooo
ool09_ooo`00Soooo`030000<ol0<ol000Pco`000`000?ooooooo`1Joooo00?o09Woooooool09_oo
o`00R?ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo05[oool00ol0VOooooooo`0V
oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo05[oool0
0ol0VOooooooo`0Voooo0029oooo00<0003oooooool00oooo`<00008<ol000<0003oooooool0F_oo
o`03o`2Ioooooooo02Koool008[oool00`000?ooooooo`02oooo00<0000co`0co`0023?o00030000
oooooooo05[oool00ol0VOooooooo`0Voooo0027oooo00@0003oooooool00004oooo00<0000co`0c
o`0023?o00030000oooooooo05[oool00ol0VOooooooo`0Voooo0028oooo0P0000Goool00`0003?o
03?o0007<ol000<0003oooooool0Foooo`03o`2Ioooooooo02Koool008ooool00`0003?o03?o0007
<ol000<0003oooooool0Foooo`03o`2Ioooooooo02Koool008ooool00`0003?o03?o0007<ol000<0
003oooooool0Foooo`03o`2Ioooooooo02Koool008ooool00`0003?o03?o0007<ol000<0003ooooo
ool0Foooo`03o`2Ioooooooo02Koool008ooool2000023?o00030000oooooooo05_oool00ol0VOoo
ooooo`0Voooo002?oooo00<0000co`0co`001c?o00030000oooooooo05_oool00ol0VOooooooo`0V
oooo002?oooo00<0000co`0co`001c?o00030000oooooooo05_oool00ol0VOooooooo`0Voooo002?
oooo00<0000co`0co`001c?o00030000oooooooo05_oool00ol0VOooooooo`0Voooo002?oooo00<0
000co`0co`001S?o00030000oooooooo05coool00ol0VOooooooo`0Voooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo05coool00ol0VOooooooo`0Voooo002?oooo0P0000Lco`000`000?oo
ooooo`1Loooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1L
oooo00?o09Woooooool09_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Loooo00?o
09Woooooool09_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Loooo00?o09Wooooo
ool09_ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Loooo00?o09Woooooool09_oo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Loooo00?o09Woooooool09_ooo`00Sooo
o`800006<ol000<0003oooooool0GOooo`03o`2Ioooooooo02Koool008ooool00`0003?o03?o0005
<ol000<0003oooooool0GOooo`03o`2Ioooooooo02Koool008ooool00`0003?o03?o0005<ol000<0
003oooooool0GOooo`03o`2Ioooooooo02Koool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool0GOooo`03o`2Ioooooooo02Koool008ooool00`0003?o03?o0005<ol000<0003oooooool0GOoo
o`03o`2Ioooooooo02Koool008ooool00`0003?o03?o0005<ol000<0003oooooool0GOooo`03o`2I
oooooooo02Koool008ooool200001S?o00030000oooooooo05goool00ol0VOooooooo`0Voooo002?
oooo00<0000co`0co`001C?o00030000oooooooo05goool00ol0VOooooooo`0Voooo002?oooo00<0
000co`0co`001C?o00030000oooooooo05goool00ol0VOooooooo`0Voooo002?oooo00<0000co`0c
o`0013?o00030000oooooooo05koool00ol0VOooooooo`0Voooo002?oooo00<0000co`0co`0013?o
00030000oooooooo05koool00ol0VOooooooo`0Voooo0029oooo0`0000?oool00`0003?o03?o0004
<ol000<0003oooooool0G_ooo`03o`2Ioooooooo02Koool008[oool00`000?ooooooo`02oooo00<0
000co`0co`0013?o00030000oooooooo05koool00ol0VOooooooo`0Voooo0027oooo1@0000?oool3
000013?o00030000oooooooo05koool00ol0VOooooooo`0Voooo0027oooo00@0003oooooool00004
oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:
oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Koool400000c?o008000000c?o0?ooooooo`02oooo00@0003oooooooooool400000oooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Goool00`000?ooooooo`07<ol01?ooo`050000oooooooooooo000000Koool00`000?oo
ooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?oooc?o0006
<ol01?ooo`030000oooooooo00;oool00`000?ooooooo`04oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000>oooo00<0000co`0co`001C?o00Goool00`000?ooooooo`02oooo00<0
003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0
003oooooool00006<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`02oooo100000?oool200000ooo
o`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.74) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.87754 .12361 L
.88797 .12361 L
.89771 .12361 L
.90733 .12361 L
.91011 .12361 L
.91147 .12361 L
.91273 .12361 L
.91387 .12361 L
s
.91387 .12361 m
.91436 .61803 L
s
0 .4 1 r
.02381 .12361 m
.04262 .12361 L
.06244 .12361 L
.07216 .12361 L
.0775 .12361 L
.08255 .12361 L
.08394 .12361 L
.0847 .12361 L
.08542 .12361 L
.08619 .12312 L
.08703 .12225 L
.08852 .12074 L
.09396 .11548 L
.10458 .10621 L
.12312 .09289 L
.14335 .08188 L
.15431 .07721 L
.16449 .07359 L
.18458 .06815 L
.19514 .06608 L
.2051 .06456 L
.21404 .06352 L
.21904 .06306 L
.22371 .0627 L
.22868 .06239 L
.23321 .06216 L
.23825 .06198 L
.24102 .06191 L
.24227 .06188 L
.24364 .06186 L
.24487 .06184 L
.24619 .06183 L
.24691 .06182 L
.24758 .06181 L
.24889 .06181 L
.25001 .0618 L
.25125 .0618 L
.25254 .06181 L
.25373 .06181 L
.25442 .06182 L
.25516 .06182 L
.25651 .06184 L
.25904 .06188 L
.26199 .06193 L
.26471 .062 L
.26938 .06215 L
.2744 .06236 L
.28347 .06282 L
.30411 .06429 L
.34539 .06845 L
Mistroke
.38515 .0733 L
.42339 .07824 L
.46409 .08345 L
.48293 .08578 L
.49283 .08698 L
.50327 .08819 L
.50861 .08867 L
.51143 .08887 L
.51445 .08905 L
.51724 .08919 L
.51977 .08929 L
.52232 .08937 L
.52473 .08943 L
.52599 .08946 L
.52717 .08948 L
.5284 .08949 L
.52906 .0895 L
.52975 .0895 L
.53092 .08951 L
.53199 .08951 L
.53314 .08951 L
.5344 .0895 L
.53511 .0895 L
.53578 .0895 L
.53704 .08948 L
.53839 .08947 L
.53985 .08944 L
.54248 .08939 L
.54491 .08932 L
.5496 .08917 L
.55463 .08896 L
.56371 .08847 L
.58436 .08691 L
.60558 .08479 L
.62569 .08238 L
.66399 .07694 L
.70474 .07016 L
.74397 .06284 L
.78169 .05526 L
.82186 .04687 L
.86052 .0389 L
.88014 .03508 L
.89052 .03317 L
.90163 .03124 L
.90715 .03033 L
.90986 .0299 L
.91105 .02971 L
.91236 .02951 L
.91354 .02933 L
.91464 .12361 L
Mistroke
.9158 .12361 L
.91705 .12361 L
.92213 .12361 L
.94122 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.74) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo06Koool00`1Vooooooooo`0Uoooo002?oooo00<0003ooooo
ool0Goooo`P0I_lWoooo002?oooo00<0003oooooool0Foooo`@0I_l7oooo00<0I_ooooooool09Ooo
o`00Soooo`030000oooooooo05Koool506Ko2oooo`0306Kooooooooo02Goool008ooool00`000?oo
ooooo`1Boooo101Voa3oool00`1Vooooooooo`0Uoooo002?oooo00<0003oooooool0COooo`D0I_lD
oooo00<0I_ooooooool09Oooo`00Soooo`800018oooo1P1VoaWoool00`1Vooooooooo`0Uoooo002?
oooo00<0003oooooool0@_ooo`D0I_lOoooo00<0I_ooooooool09Oooo`00Soooo`030000oooooooo
03koool406Ko9?ooo`0306Kooooooooo02Goool004CooolO06Ko;?ooo`030000oooooooo03Woool5
06Ko:?ooo`0306Kooooooooo02Goool003koool606Ko7oooo`P0I_lToooo00<0003oooooool0=?oo
o`D0I_l]oooo00<0I_ooooooool09Oooo`00??ooo`80I_l]oooo1@1Voaooool00`000?ooooooo`0_
oooo1@1Voc;oool00`1Vooooooooo`0Uoooo000ioooo0`1VocCoool706Ko6?ooo`80000[oooo1@1V
ocOoool00`1Vooooooooo`0Uoooo000Goooo100001coool206Ko6oooo`D0000Noooo2P1Vo`koool0
0`000?ooooooo`0Soooo1`1Vo`goool50000:_ooo`0306Kooooooooo00_oool400005_ooo`005ooo
o`030000oooooooo01_oool206Ko7oooo`030000oooooooo02Soool806Ko1_ooo`030000oooooooo
01_oool806Ko5_ooo`030000oooooooo02[oool00`1Vooooooooo`0;oooo00<0003oooooool05ooo
o`006?ooo`030000oooooooo01Soool206Ko8Oooo`030000oooooooo033oool606Ko00<00000I_oo
ool03Oooo`h0I_lNoooo00<0003oooooool0:_ooo`0306Kooooooooo00coool00`000?ooooooo`0F
oooo000Aoooo100000Coool00`000?ooooooo`0Eoooo0P1Voa_oool400001?ooo`030000oooooooo
03Koool00`000?ooo`1Vo`0=06Ko;?ooo`030000oooooooo02[oool00`1Vooooooooo`0=oooo00<0
003oooooool05Oooo`005oooo`040000oooooooo00005?ooo`80I_lUoooo00<0003oooooool0=_oo
o`030000oooooooo03Woool00`000?ooooooo`0Zoooo00<0I_ooooooool02oooo`040000oooooooo
00005_ooo`006?ooo`80000Doooo00<0I_ooooooool09?ooo`80000hoooo0P0003Woool20000;?oo
o`0306Kooooooooo00coool200005oooo`00;?ooo`80I_mQoooo00<0003oooooool0I_ooo`0306Ko
oooooooo02Goool002_oool00`1Vooooooooo`1Qoooo00<0003oooooool0I_ooo`0306Kooooooooo
02Goool002Woool206KoI?ooo`030000oooooooo06Koool00`1Vooooooooo`0Uoooo000Xoooo00<0
I_ooooooool0I?ooo`030000oooooooo06Koool00`1Vooooooooo`0Uoooo000Woooo00<0I_oooooo
ool0IOooo`030000oooooooo06Koool00`1Vooooooooo`0Uoooo000@ooooo`00017oool001Koool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0006<ol08P0000;oool01Ol0VOooooooooooo`00000;oooo00<0003oooooool05Ooo
o`005_ooo`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`00>C?o00T0000T
oooo00?o09Woooooool03Oooo`030000oooooooo01Goool008ooool00`0003?o03?o000c<ol01P00
02goool00ol0VOooooooo`0Uoooo002?oooo00<0000co`0co`00<C?o0080000coooo00?o09Wooooo
ool09Oooo`00Soooo`030000<ol0<ol002lco`020000=Oooo`03o`2Ioooooooo02Goool008ooool0
0`0003?o03?o000/<ol00`0003Ooool00ol0VOooooooo`0Uoooo002?oooo0P0002Xco`030000>_oo
o`03o`2Ioooooooo02Goool008ooool00`0003?o03?o000W<ol00P0003goool00ol0VOooooooo`0U
oooo002?oooo00<0000co`0co`009S?o00030000oooooooo03goool00ol0VOooooooo`0Uoooo002?
oooo00<0000co`0co`009C?o00030000oooooooo03koool00ol0VOooooooo`0Uoooo002?oooo00<0
000co`0co`0093?o00030000oooooooo03ooool00ol0VOooooooo`0Uoooo002?oooo00<0000co`0c
o`008S?o00800012oooo00?o09Woooooool09Oooo`00Soooo`80000R<ol000<0003oooooool0@_oo
o`03o`2Ioooooooo02Goool008ooool00`0003?o03?o000P<ol000<0003oooooool0@oooo`03o`2I
oooooooo02Goool008ooool00`0003?o03?o000O<ol000<0003oooooool0A?ooo`03o`2Ioooooooo
02Goool008ooool00`0003?o03?o000O<ol000<0003oooooool0A?ooo`03o`2Ioooooooo02Goool0
08ooool00`0003?o03?o000N<ol000<0003oooooool0AOooo`03o`2Ioooooooo02Goool008ooool0
0`0003?o03?o000M<ol000<0003oooooool0A_ooo`03o`2Ioooooooo02Goool008ooool200007C?o
00030000oooooooo04Ooool00ol0VOooooooo`0Uoooo002?oooo00<0000co`0co`006c?o00030000
oooooooo04Soool00ol0VOooooooo`0Uoooo002?oooo00<0000co`0co`006c?o00030000oooooooo
04Soool00ol0VOooooooo`0Uoooo002?oooo00<0000co`0co`006S?o00030000oooooooo04Woool0
0ol0VOooooooo`0Uoooo002?oooo00<0000co`0co`006S?o00030000oooooooo04Woool00ol0VOoo
ooooo`0Uoooo002?oooo00<0000co`0co`006C?o00030000oooooooo04[oool00ol0VOooooooo`0U
oooo002?oooo0P0001Xco`000`000?ooooooo`1:oooo00?o09Woooooool09Oooo`00Soooo`030000
<ol0<ol001Pco`000`000?ooooooo`1;oooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol0
01Pco`000`000?ooooooo`1;oooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol001Lco`00
0`000?ooooooo`1<oooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol001Lco`000`000?oo
ooooo`1<oooo00?o09Woooooool09Oooo`00Qoooo`D00003oooo00<0000co`0co`005S?o00030000
oooooooo04goool00ol0VOooooooo`0Uoooo0029oooo00<0003oooooool00oooo`030000<ol0<ol0
01Hco`000`000?ooooooo`1=oooo00?o09Woooooool09Oooo`00ROooo`030000oooooooo00?oool3
00005C?o00030000oooooooo04koool00ol0VOooooooo`0Uoooo0029oooo00<0003oooooool00ooo
o`030000<ol0<ol001Dco`000`000?ooooooo`1>oooo00?o09Woooooool09Oooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool0C_ooo`03o`2Ioooooooo02Goool0
08Soool200001Oooo`030000<ol0<ol001@co`000`000?ooooooo`1?oooo00?o09Woooooool09Ooo
o`00Soooo`030000<ol0<ol001@co`000`000?ooooooo`1?oooo00?o09Woooooool09Oooo`00Sooo
o`030000<ol0<ol001<co`000`000?ooooooo`1@oooo00?o09Woooooool09Oooo`00Soooo`80000D
<ol000<0003oooooool0D?ooo`03o`2Ioooooooo02Goool008ooool00`0003?o03?o000C<ol000<0
003oooooool0D?ooo`03o`2Ioooooooo02Goool008ooool00`0003?o03?o000B<ol000<0003ooooo
ool0DOooo`03o`2Ioooooooo02Goool008ooool00`0003?o03?o000B<ol000<0003oooooool0DOoo
o`03o`2Ioooooooo02Goool008ooool00`0003?o03?o000B<ol000<0003oooooool0DOooo`03o`2I
oooooooo02Goool008ooool00`0003?o03?o000A<ol000<0003oooooool0D_ooo`03o`2Ioooooooo
02Goool008ooool200004S?o00030000oooooooo05;oool00ol0VOooooooo`0Uoooo002?oooo00<0
000co`0co`004C?o00030000oooooooo05;oool00ol0VOooooooo`0Uoooo002?oooo00<0000co`0c
o`004C?o00030000oooooooo05;oool00ol0VOooooooo`0Uoooo002?oooo00<0000co`0co`0043?o
00030000oooooooo05?oool00ol0VOooooooo`0Uoooo002?oooo00<0000co`0co`0043?o00030000
oooooooo05?oool00ol0VOooooooo`0Uoooo002?oooo00<0000co`0co`0043?o00030000oooooooo
05?oool00ol0VOooooooo`0Uoooo002?oooo00<0000co`0co`0043?o00030000oooooooo05?oool0
0ol0VOooooooo`0Uoooo002?oooo0P00010co`000`000?ooooooo`1Doooo00?o09Woooooool09Ooo
o`00Soooo`030000<ol0<ol000lco`000`000?ooooooo`1Doooo00?o09Woooooool09Oooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`1Doooo00?o09Woooooool09Oooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`1Doooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol0
00lco`000`000?ooooooo`1Doooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol000hco`00
0`000?ooooooo`1Eoooo00?o09Woooooool09Oooo`00Soooo`80000?<ol000<0003oooooool0EOoo
o`03o`2Ioooooooo02Goool008ooool00`0003?o03?o000><ol000<0003oooooool0EOooo`03o`2I
oooooooo02Goool008ooool00`0003?o03?o000><ol000<0003oooooool0EOooo`03o`2Ioooooooo
02Goool008ooool00`0003?o03?o000=<ol000<0003oooooool0E_ooo`03o`2Ioooooooo02Goool0
08Ooool400001?ooo`030000<ol0<ol000dco`000`000?ooooooo`1Foooo00?o09Woooooool09Ooo
o`00Qoooo`030000oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool0E_ooo`03o`2I
oooooooo02Goool008Soool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1Foooo00?o
09Woooooool09Oooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003ooooo
ool0E_ooo`03o`2Ioooooooo02Goool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000<
<ol000<0003oooooool0Eoooo`03o`2Ioooooooo02Goool008Soool200001Oooo`030000<ol0<ol0
00`co`000`000?ooooooo`1Goooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol000`co`00
0`000?ooooooo`1Goooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol000`co`000`000?oo
ooooo`1Goooo00?o09Woooooool09Oooo`00Soooo`80000=<ol000<0003oooooool0Eoooo`03o`2I
oooooooo02Goool008ooool00`0003?o03?o000<<ol000<0003oooooool0Eoooo`03o`2Ioooooooo
02Goool008ooool00`0003?o03?o000;<ol000<0003oooooool0F?ooo`03o`2Ioooooooo02Goool0
08ooool00`0003?o03?o000;<ol000<0003oooooool0F?ooo`03o`2Ioooooooo02Goool008ooool0
0`0003?o03?o000;<ol000<0003oooooool0F?ooo`03o`2Ioooooooo02Goool008ooool00`0003?o
03?o000;<ol000<0003oooooool0F?ooo`03o`2Ioooooooo02Goool008ooool00`0003?o03?o000;
<ol000<0003oooooool0F?ooo`03o`2Ioooooooo02Goool008ooool2000033?o00030000oooooooo
05Soool00ol0VOooooooo`0Uoooo002?oooo00<0000co`0co`002c?o00030000oooooooo05Soool0
0ol0VOooooooo`0Uoooo002?oooo00<0000co`0co`002S?o00030000oooooooo05Woool00ol0VOoo
ooooo`0Uoooo002?oooo00<0000co`0co`002S?o00030000oooooooo05Woool00ol0VOooooooo`0U
oooo002?oooo00<0000co`0co`002S?o00030000oooooooo05Woool00ol0VOooooooo`0Uoooo002?
oooo00<0000co`0co`002S?o00030000oooooooo05Woool00ol0VOooooooo`0Uoooo002?oooo0P00
00/co`000`000?ooooooo`1Ioooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol000Xco`00
0`000?ooooooo`1Ioooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`1Ioooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1J
oooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1Joooo00?o
09Woooooool09Oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1Joooo00?o09Wooooo
ool09Oooo`00Soooo`80000:<ol000<0003oooooool0F_ooo`03o`2Ioooooooo02Goool008ooool0
0`0003?o03?o0009<ol000<0003oooooool0F_ooo`03o`2Ioooooooo02Goool008ooool00`0003?o
03?o0009<ol000<0003oooooool0F_ooo`03o`2Ioooooooo02Goool008ooool00`0003?o03?o0008
<ol000<0003oooooool0Foooo`03o`2Ioooooooo02Goool008Soool200001Oooo`030000<ol0<ol0
00Pco`000`000?ooooooo`1Koooo00?o09Woooooool09Oooo`00Qoooo`040000oooooooo00001?oo
o`030000<ol0<ol000Pco`000`000?ooooooo`1Koooo00?o09Woooooool09Oooo`00ROooo`030000
oooooooo00?oool3000023?o00030000oooooooo05_oool00ol0VOooooooo`0Uoooo002:oooo00<0
003oooooool00_ooo`030000<ol0<ol000Pco`000`000?ooooooo`1Koooo00?o09Woooooool09Ooo
o`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`1Koooo00?o
09Woooooool09Oooo`00R?ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo05coool0
0ol0VOooooooo`0Uoooo002?oooo00<0000co`0co`001c?o00030000oooooooo05coool00ol0VOoo
ooooo`0Uoooo002?oooo00<0000co`0co`001c?o00030000oooooooo05coool00ol0VOooooooo`0U
oooo002?oooo00<0000co`0co`001c?o00030000oooooooo05coool00ol0VOooooooo`0Uoooo002?
oooo0P0000Pco`000`000?ooooooo`1Loooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol0
00Lco`000`000?ooooooo`1Loooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`1Loooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1Loooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1M
oooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Moooo00?o
09Woooooool09Oooo`00Soooo`800007<ol000<0003oooooool0GOooo`03o`2Ioooooooo02Goool0
08ooool00`0003?o03?o0006<ol000<0003oooooool0GOooo`03o`2Ioooooooo02Goool008ooool0
0`0003?o03?o0006<ol000<0003oooooool0GOooo`03o`2Ioooooooo02Goool008ooool00`0003?o
03?o0006<ol000<0003oooooool0GOooo`03o`2Ioooooooo02Goool008ooool00`0003?o03?o0006
<ol000<0003oooooool0GOooo`03o`2Ioooooooo02Goool008ooool00`0003?o03?o0006<ol000<0
003oooooool0GOooo`03o`2Ioooooooo02Goool008ooool200001S?o00030000oooooooo05koool0
0ol0VOooooooo`0Uoooo002?oooo00<0000co`0co`001C?o00030000oooooooo05koool00ol0VOoo
ooooo`0Uoooo002?oooo00<0000co`0co`001C?o00030000oooooooo05koool00ol0VOooooooo`0U
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo05koool00ol0VOooooooo`0Uoooo002?
oooo00<0000co`0co`001C?o00030000oooooooo05koool00ol0VOooooooo`0Uoooo002?oooo00<0
000co`0co`001C?o00030000oooooooo05koool00ol0VOooooooo`0Uoooo002?oooo0P0000Hco`00
0`000?ooooooo`1Noooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`1Noooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1N
oooo00?o09Woooooool09Oooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`1Ooooo00?o
09Woooooool09Oooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`1Ooooo00?o09Wooooo
ool09Oooo`00ROooo`<00003oooo00<0000co`0co`0013?o00030000oooooooo05ooool00ol0VOoo
ooooo`0Uoooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`1O
oooo00?o09Woooooool09Oooo`00Qoooo`D00003oooo0`0000@co`000`000?ooooooo`1Ooooo00?o
09Woooooool09Oooo`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool0
00001?ooo`Lco`2:oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o
08[oool007Woool00`000?ooooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0
003oooooool02?ooo`030000oooooooo00Woool7<ol03oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000<co`02000000<co`3ooooo
ool00_ooo`030000oooooooo00?oool300000_ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`07
<ol01?ooo`030000oooooooo00Coool01@000?ooooooooooo`00001joooo001goooo00<0003ooooo
ool00_ooo`030000oooooooo00koool00`000?oooc?o0006<ol01?ooo`040000oooooooooooo1@00
00?oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000koool00`0003?o03?o0005
<ol01Oooo`040000oooooooo00000_ooo`050000oooooooooooo000007[oool007Soool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00006<ol00_ooo`040000oooooooo00000oooo`030000
oooo000000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800007<ol00_oo
o`@00004oooo0P0000;oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool008ooool7<ol0R_oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.76) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.90802 .12361 L
.91306 .12361 L
.91526 .12361 L
.91765 .12361 L
.91894 .12361 L
s
.91894 .12361 m
.91942 .61803 L
s
0 .4 1 r
.02381 .12361 m
.04262 .12361 L
.06244 .12361 L
.06747 .12361 L
.07286 .12361 L
.07547 .12361 L
.07793 .12361 L
.07901 .12361 L
.08015 .12361 L
.0814 .12314 L
.08255 .12196 L
.10458 .10246 L
.12411 .08941 L
.14241 .08016 L
.15279 .07599 L
.16266 .07265 L
.18119 .06785 L
.19077 .06601 L
.20099 .06448 L
.21064 .06339 L
.21938 .06267 L
.22425 .06237 L
.2294 .06212 L
.2338 .06197 L
.2363 .06191 L
.23863 .06186 L
.23992 .06184 L
.24133 .06183 L
.24197 .06182 L
.24265 .06182 L
.24388 .06181 L
.24506 .0618 L
.24616 .0618 L
.24737 .06181 L
.24867 .06181 L
.24998 .06182 L
.25141 .06183 L
.2529 .06185 L
.25429 .06188 L
.25697 .06193 L
.25945 .06199 L
.2645 .06215 L
.26997 .06237 L
.2799 .06289 L
.29849 .06422 L
.33789 .06814 L
.37578 .07272 L
.41612 .07792 L
.45495 .0829 L
.47469 .08536 L
Mistroke
.49622 .08795 L
.50137 .08855 L
.50622 .08903 L
.5118 .08945 L
.51426 .08959 L
.51685 .08972 L
.51914 .08982 L
.52165 .08991 L
.52392 .08997 L
.52605 .09001 L
.52734 .09003 L
.52856 .09004 L
.52966 .09005 L
.53085 .09006 L
.53214 .09006 L
.5328 .09006 L
.53352 .09006 L
.53479 .09006 L
.53598 .09005 L
.53716 .09004 L
.53843 .09002 L
.54069 .08999 L
.54339 .08993 L
.54584 .08986 L
.55118 .08968 L
.55621 .08946 L
.57472 .08831 L
.59478 .08656 L
.61324 .08458 L
.6527 .0794 L
.69064 .07343 L
.73103 .06623 L
.7699 .05863 L
.81123 .05009 L
.85105 .04178 L
.88934 .03425 L
.89953 .03241 L
.90909 .03079 L
.91389 .03001 L
.91521 .0298 L
.91659 .02959 L
.91778 .0294 L
.91907 .12361 L
.91981 .12361 L
.92052 .12361 L
.92183 .12361 L
.92478 .12361 L
.93009 .12361 L
.96853 .12361 L
.97619 .12361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.76) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`1Roooo1P1VobKoool0
08ooool00`000?ooooooo`1Noooo101Vo`Goool00`1Vooooooooo`0Toooo002?oooo00<0003ooooo
ool0FOooo`D0I_l9oooo00<0I_ooooooool09?ooo`00Soooo`030000oooooooo05Coool506Ko3_oo
o`0306Kooooooooo02Coool008ooool00`000?ooooooo`1?oooo1@1Voa?oool00`1Vooooooooo`0T
oooo002?oooo0P0004_oool506Ko6?ooo`0306Kooooooooo02Coool008ooool00`000?ooooooo`14
oooo1P1Voagoool00`1Vooooooooo`0Toooo002?oooo00<0003oooooool0?oooo`D0I_lSoooo00<0
I_ooooooool09?ooo`00@ooooah0I_l^oooo00<0003oooooool0>oooo`@0I_lXoooo00<0I_oooooo
ool09?ooo`00??ooo`L0I_lNoooo2P1VobCoool00`000?ooooooo`0foooo1@1Vobcoool00`1Voooo
ooooo`0Toooo000ioooo0`1Vobooool706Ko7Oooo`030000oooooooo033oool606Ko<Oooo`0306Ko
oooooooo02Coool003Koool306Ko>Oooo`H0I_lGoooo0P0002[oool706Ko=oooo`0306Kooooooooo
02Coool001Ooool400006Oooo`80I_lNoooo1@0001ooool706Ko4?ooo`030000oooooooo02;oool7
06Ko3_ooo`D0000[oooo00<0I_ooooooool02_ooo`@0000Foooo000Goooo00<0003oooooool06Ooo
o`0306Kooooooooo023oool00`000?ooooooo`0Voooo201Vo`Soool00`000?ooooooo`0Moooo1@1V
oaOoool00`000?ooooooo`0[oooo00<0I_ooooooool02_ooo`030000oooooooo01Ooool001Soool0
0`000?ooooooo`0Foooo0P1Vob?oool00`000?ooooooo`0^oooo201Vo`030000oooooooo00koool?
06Ko7?ooo`030000oooooooo02_oool00`1Vooooooooo`0;oooo00<0003oooooool05_ooo`004Ooo
o`@00004oooo00<0003oooooool05?ooo`0306Kooooooooo01_oool400001?ooo`030000oooooooo
03Koool00`00001Vo`1Vo`0>06Ko:oooo`030000oooooooo02_oool00`1Vooooooooo`0<oooo00<0
003oooooool05Oooo`005oooo`040000oooooooo00004oooo`80I_lVoooo00<0003oooooool0=_oo
o`030000oooooooo03Woool00`000?ooooooo`0[oooo00<0I_ooooooool02_ooo`040000oooooooo
00005_ooo`006?ooo`80000Boooo0P1VobOoool20000>?ooo`80000ioooo0P0002goool00`1Voooo
ooooo`0;oooo0P0001Ooool002_oool00`1Vooooooooo`1Qoooo00<0003oooooool0Ioooo`0306Ko
oooooooo02Coool002[oool00`1Vooooooooo`1Roooo00<0003oooooool0Ioooo`0306Kooooooooo
02Coool002Woool00`1Vooooooooo`1Soooo00<0003oooooool0Ioooo`0306Kooooooooo02Coool0
02Ooool206KoI_ooo`030000oooooooo06Ooool00`1Vooooooooo`0Toooo000Voooo00<0I_oooooo
ool0I_ooo`030000oooooooo06Ooool00`1Vooooooooo`0Toooo000@ooooo`00017oool001Koool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0006<ol08P0000?oool01?l0VOooooooo`0000_oool00`000?ooooooo`0Eoooo000F
oooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000i<ol02@0002Goool0
0ol0VOooooooo`0<oooo00<0003oooooool05Oooo`00Soooo`030000<ol0<ol003<co`060000;_oo
o`03o`2Ioooooooo02Coool008ooool00`0003?o03?o000a<ol00P0003Coool00ol0VOooooooo`0T
oooo002?oooo00<0000co`0co`00;c?o0080000foooo00?o09Woooooool09?ooo`00Soooo`030000
<ol0<ol002`co`030000>?ooo`03o`2Ioooooooo02Coool008ooool20000:S?o00<0000koooo00?o
09Woooooool09?ooo`00Soooo`030000<ol0<ol002Lco`020000?_ooo`03o`2Ioooooooo02Coool0
08ooool00`0003?o03?o000V<ol000<0003oooooool0?_ooo`03o`2Ioooooooo02Coool008ooool0
0`0003?o03?o000U<ol000<0003oooooool0?oooo`03o`2Ioooooooo02Coool008ooool00`0003?o
03?o000T<ol000<0003oooooool0@?ooo`03o`2Ioooooooo02Coool008ooool00`0003?o03?o000R
<ol00P0004?oool00ol0VOooooooo`0Toooo002?oooo0P00028co`000`000?ooooooo`13oooo00?o
09Woooooool09?ooo`00Soooo`030000<ol0<ol0020co`000`000?ooooooo`14oooo00?o09Wooooo
ool09?ooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`15oooo00?o09Woooooool09?oo
o`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`15oooo00?o09Woooooool09?ooo`00Sooo
o`030000<ol0<ol001hco`000`000?ooooooo`16oooo00?o09Woooooool09?ooo`00Soooo`030000
<ol0<ol001dco`000`000?ooooooo`17oooo00?o09Woooooool09?ooo`00Soooo`80000M<ol000<0
003oooooool0B?ooo`03o`2Ioooooooo02Coool008ooool00`0003?o03?o000K<ol000<0003ooooo
ool0BOooo`03o`2Ioooooooo02Coool008ooool00`0003?o03?o000K<ol000<0003oooooool0BOoo
o`03o`2Ioooooooo02Coool008ooool00`0003?o03?o000J<ol000<0003oooooool0B_ooo`03o`2I
oooooooo02Coool008ooool00`0003?o03?o000J<ol000<0003oooooool0B_ooo`03o`2Ioooooooo
02Coool008ooool00`0003?o03?o000I<ol000<0003oooooool0Boooo`03o`2Ioooooooo02Coool0
08ooool200006S?o00030000oooooooo04_oool00ol0VOooooooo`0Toooo002?oooo00<0000co`0c
o`0063?o00030000oooooooo04coool00ol0VOooooooo`0Toooo002?oooo00<0000co`0co`0063?o
00030000oooooooo04coool00ol0VOooooooo`0Toooo002?oooo00<0000co`0co`005c?o00030000
oooooooo04goool00ol0VOooooooo`0Toooo002?oooo00<0000co`0co`005c?o00030000oooooooo
04goool00ol0VOooooooo`0Toooo0027oooo1@0000?oool00`0003?o03?o000F<ol000<0003ooooo
ool0C_ooo`03o`2Ioooooooo02Coool008Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o
00030000oooooooo04koool00ol0VOooooooo`0Toooo0029oooo00<0003oooooool00oooo`<0000E
<ol000<0003oooooool0Coooo`03o`2Ioooooooo02Coool008Woool00`000?ooooooo`03oooo00<0
000co`0co`005C?o00030000oooooooo04ooool00ol0VOooooooo`0Toooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`1?oooo00?o09Woooooool09?ooo`00R?oo
o`800005oooo00<0000co`0co`0053?o00030000oooooooo053oool00ol0VOooooooo`0Toooo002?
oooo00<0000co`0co`0053?o00030000oooooooo053oool00ol0VOooooooo`0Toooo002?oooo00<0
000co`0co`004c?o00030000oooooooo057oool00ol0VOooooooo`0Toooo002?oooo0P0001@co`00
0`000?ooooooo`1Aoooo00?o09Woooooool09?ooo`00Soooo`030000<ol0<ol001<co`000`000?oo
ooooo`1Aoooo00?o09Woooooool09?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`1B
oooo00?o09Woooooool09?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`1Boooo00?o
09Woooooool09?ooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`1Boooo00?o09Wooooo
ool09?ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`1Coooo00?o09Woooooool09?oo
o`00Soooo`80000B<ol000<0003oooooool0Doooo`03o`2Ioooooooo02Coool008ooool00`0003?o
03?o000A<ol000<0003oooooool0Doooo`03o`2Ioooooooo02Coool008ooool00`0003?o03?o000A
<ol000<0003oooooool0Doooo`03o`2Ioooooooo02Coool008ooool00`0003?o03?o000@<ol000<0
003oooooool0E?ooo`03o`2Ioooooooo02Coool008ooool00`0003?o03?o000@<ol000<0003ooooo
ool0E?ooo`03o`2Ioooooooo02Coool008ooool00`0003?o03?o000@<ol000<0003oooooool0E?oo
o`03o`2Ioooooooo02Coool008ooool00`0003?o03?o000@<ol000<0003oooooool0E?ooo`03o`2I
oooooooo02Coool008ooool2000043?o00030000oooooooo05Goool00ol0VOooooooo`0Toooo002?
oooo00<0000co`0co`003c?o00030000oooooooo05Goool00ol0VOooooooo`0Toooo002?oooo00<0
000co`0co`003c?o00030000oooooooo05Goool00ol0VOooooooo`0Toooo002?oooo00<0000co`0c
o`003c?o00030000oooooooo05Goool00ol0VOooooooo`0Toooo002?oooo00<0000co`0co`003c?o
00030000oooooooo05Goool00ol0VOooooooo`0Toooo002?oooo00<0000co`0co`003S?o00030000
oooooooo05Koool00ol0VOooooooo`0Toooo002?oooo0P0000lco`000`000?ooooooo`1Foooo00?o
09Woooooool09?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`1Foooo00?o09Wooooo
ool09?ooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`1Foooo00?o09Woooooool09?oo
o`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`1Goooo00?o09Woooooool09?ooo`00Qooo
o`@00004oooo00<0000co`0co`003C?o00030000oooooooo05Ooool00ol0VOooooooo`0Toooo0027
oooo00<0003oooooool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`1Goooo00?o09Wooooo
ool09?ooo`00R?ooo`030000oooooooo00Coool300003C?o00030000oooooooo05Ooool00ol0VOoo
ooooo`0Toooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000dco`000`000?ooooooo`1G
oooo00?o09Woooooool09?ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol000`co`00
0`000?ooooooo`1Hoooo00?o09Woooooool09?ooo`00R?ooo`800005oooo00<0000co`0co`0033?o
00030000oooooooo05Soool00ol0VOooooooo`0Toooo002?oooo00<0000co`0co`0033?o00030000
oooooooo05Soool00ol0VOooooooo`0Toooo002?oooo00<0000co`0co`0033?o00030000oooooooo
05Soool00ol0VOooooooo`0Toooo002?oooo0P0000dco`000`000?ooooooo`1Hoooo00?o09Wooooo
ool09?ooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`1Hoooo00?o09Woooooool09?oo
o`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Ioooo00?o09Woooooool09?ooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`1Ioooo00?o09Woooooool09?ooo`00Soooo`030000
<ol0<ol000/co`000`000?ooooooo`1Ioooo00?o09Woooooool09?ooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`1Ioooo00?o09Woooooool09?ooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`1Ioooo00?o09Woooooool09?ooo`00Soooo`80000<<ol000<0003oooooool0FOoo
o`03o`2Ioooooooo02Coool008ooool00`0003?o03?o000;<ol000<0003oooooool0FOooo`03o`2I
oooooooo02Coool008ooool00`0003?o03?o000:<ol000<0003oooooool0F_ooo`03o`2Ioooooooo
02Coool008ooool00`0003?o03?o000:<ol000<0003oooooool0F_ooo`03o`2Ioooooooo02Coool0
08ooool00`0003?o03?o000:<ol000<0003oooooool0F_ooo`03o`2Ioooooooo02Coool008ooool0
0`0003?o03?o000:<ol000<0003oooooool0F_ooo`03o`2Ioooooooo02Coool008ooool200002c?o
00030000oooooooo05[oool00ol0VOooooooo`0Toooo002?oooo00<0000co`0co`002S?o00030000
oooooooo05[oool00ol0VOooooooo`0Toooo002?oooo00<0000co`0co`002S?o00030000oooooooo
05[oool00ol0VOooooooo`0Toooo002?oooo00<0000co`0co`002C?o00030000oooooooo05_oool0
0ol0VOooooooo`0Toooo002?oooo00<0000co`0co`002C?o00030000oooooooo05_oool00ol0VOoo
ooooo`0Toooo002?oooo00<0000co`0co`002C?o00030000oooooooo05_oool00ol0VOooooooo`0T
oooo002?oooo0P0000Xco`000`000?ooooooo`1Koooo00?o09Woooooool09?ooo`00Soooo`030000
<ol0<ol000Tco`000`000?ooooooo`1Koooo00?o09Woooooool09?ooo`00Soooo`030000<ol0<ol0
00Tco`000`000?ooooooo`1Koooo00?o09Woooooool09?ooo`00Soooo`030000<ol0<ol000Pco`00
0`000?ooooooo`1Loooo00?o09Woooooool09?ooo`00R?ooo`800005oooo00<0000co`0co`0023?o
00030000oooooooo05coool00ol0VOooooooo`0Toooo0027oooo00@0003oooooool00004oooo00<0
000co`0co`0023?o00030000oooooooo05coool00ol0VOooooooo`0Toooo0029oooo00<0003ooooo
ool00oooo`<00008<ol000<0003oooooool0G?ooo`03o`2Ioooooooo02Coool008[oool00`000?oo
ooooo`02oooo00<0000co`0co`0023?o00030000oooooooo05coool00ol0VOooooooo`0Toooo0027
oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo05coool00ol0VOoo
ooooo`0Toooo0028oooo0P0000Goool00`0003?o03?o0007<ol000<0003oooooool0GOooo`03o`2I
oooooooo02Coool008ooool00`0003?o03?o0007<ol000<0003oooooool0GOooo`03o`2Ioooooooo
02Coool008ooool00`0003?o03?o0007<ol000<0003oooooool0GOooo`03o`2Ioooooooo02Coool0
08ooool00`0003?o03?o0007<ol000<0003oooooool0GOooo`03o`2Ioooooooo02Coool008ooool2
000023?o00030000oooooooo05goool00ol0VOooooooo`0Toooo002?oooo00<0000co`0co`001c?o
00030000oooooooo05goool00ol0VOooooooo`0Toooo002?oooo00<0000co`0co`001c?o00030000
oooooooo05goool00ol0VOooooooo`0Toooo002?oooo00<0000co`0co`001c?o00030000oooooooo
05goool00ol0VOooooooo`0Toooo002?oooo00<0000co`0co`001S?o00030000oooooooo05koool0
0ol0VOooooooo`0Toooo002?oooo00<0000co`0co`001S?o00030000oooooooo05koool00ol0VOoo
ooooo`0Toooo002?oooo0P0000Lco`000`000?ooooooo`1Noooo00?o09Woooooool09?ooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`1Noooo00?o09Woooooool09?ooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`1Noooo00?o09Woooooool09?ooo`00Soooo`030000<ol0<ol0
00Hco`000`000?ooooooo`1Noooo00?o09Woooooool09?ooo`00Soooo`030000<ol0<ol000Hco`00
0`000?ooooooo`1Noooo00?o09Woooooool09?ooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`1Noooo00?o09Woooooool09?ooo`00Soooo`800006<ol000<0003oooooool0Goooo`03o`2I
oooooooo02Coool008ooool00`0003?o03?o0005<ol000<0003oooooool0Goooo`03o`2Ioooooooo
02Coool008ooool00`0003?o03?o0005<ol000<0003oooooool0Goooo`03o`2Ioooooooo02Coool0
08ooool00`0003?o03?o0005<ol000<0003oooooool0Goooo`03o`2Ioooooooo02Coool008ooool0
0`0003?o03?o0005<ol000<0003oooooool0Goooo`03o`2Ioooooooo02Coool008ooool00`0003?o
03?o0005<ol000<0003oooooool0Goooo`03o`2Ioooooooo02Coool008ooool200001S?o00030000
oooooooo05ooool00ol0VOooooooo`0Toooo002?oooo00<0000co`0co`001C?o00030000oooooooo
05ooool00ol0VOooooooo`0Toooo002?oooo00<0000co`0co`001C?o00030000oooooooo05ooool0
0ol0VOooooooo`0Toooo002?oooo00<0000co`0co`0013?o00030000oooooooo063oool00ol0VOoo
ooooo`0Toooo002?oooo00<0000co`0co`0013?o00030000oooooooo063oool00ol0VOooooooo`0T
oooo0029oooo0`0000?oool00`0003?o03?o0004<ol000<0003oooooool0H?ooo`03o`2Ioooooooo
02Coool008[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o00030000oooooooo063oool0
0ol0VOooooooo`0Toooo0027oooo1@0000?oool3000013?o00030000oooooooo063oool00ol0VOoo
ooooo`0Toooo0027oooo00@0003oooooool00004oooo1c?o08[oool008Soool00`000?ooo`000004
oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_oo
o`00NOooo`030000oooooooo01?oool7<ol03_ooo`030000oooooooo07Woool007Soool00`000?oo
ooooo`08oooo00<0003oooooool02Oooo`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Koool400000c?o008000000c?o0?ooooooo`02
oooo00@0003oooooooooool300001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`07<ol01?oo
o`050000oooooooooooo000000;oool01@000?ooooooooooo`00001joooo001goooo00<0003ooooo
ool00_ooo`030000oooooooo00koool00`000?oooc?o0006<ol01?ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>
oooo00<0000co`0co`001C?o00Goool00`000?ooooooo`0300001?ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00006<ol00_ooo`040000oooooooo
00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Ooo
o`800007<ol00_ooo`@00003oooo0`0000;oool00`000?ooooooo`1ioooo002?oooo1c?o08[oool0
08ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.78) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.90802 .12361 L
.91765 .12361 L
.92014 .12361 L
.9225 .12361 L
.9238 .12361 L
s
.9238 .12361 m
.92409 .61803 L
s
0 .4 1 r
.02381 .12361 m
.04262 .12361 L
.06244 .12361 L
.06747 .12361 L
.07024 .12361 L
.07286 .12361 L
.07404 .12361 L
.07529 .12361 L
.07594 .12361 L
.07666 .12312 L
.07793 .12182 L
.08255 .11726 L
.10458 .09894 L
.12399 .08682 L
.14487 .07718 L
.15497 .07358 L
.166 .07034 L
.17654 .06783 L
.18609 .066 L
.19622 .06448 L
.20576 .0634 L
.21584 .06259 L
.22152 .06226 L
.22425 .06214 L
.22674 .06205 L
.22899 .06198 L
.23144 .06191 L
.23278 .06188 L
.23402 .06186 L
.23529 .06184 L
.23647 .06183 L
.23748 .06182 L
.23857 .06181 L
.23977 .06181 L
.24088 .0618 L
.24197 .0618 L
.24316 .06181 L
.2444 .06181 L
.24556 .06182 L
.24685 .06184 L
.24825 .06186 L
.2508 .0619 L
.25555 .06201 L
.2611 .0622 L
.26622 .06242 L
.28499 .06355 L
.30563 .06527 L
.34597 .06963 L
.38479 .07448 L
.42607 .07982 L
Mistroke
.46583 .08485 L
.4859 .08729 L
.49464 .08832 L
.50407 .08938 L
.50937 .08983 L
.51423 .09014 L
.51888 .09036 L
.52122 .09044 L
.52379 .09051 L
.5252 .09054 L
.52653 .09056 L
.52774 .09058 L
.52903 .0906 L
.5297 .0906 L
.53043 .09061 L
.53172 .09061 L
.53245 .09061 L
.53323 .09061 L
.53397 .09061 L
.53465 .09061 L
.53587 .0906 L
.53701 .09059 L
.53825 .09058 L
.53958 .09056 L
.5423 .09051 L
.54477 .09045 L
.54964 .0903 L
.55478 .09009 L
.56399 .08961 L
.58481 .08809 L
.60442 .0862 L
.62275 .08411 L
.66162 .07883 L
.70295 .07216 L
.74276 .06491 L
.78106 .05733 L
.82181 .04887 L
.86104 .04071 L
.89876 .0334 L
.90817 .03174 L
.91809 .0301 L
.92059 .0297 L
.92197 .02949 L
.92328 .02929 L
.92402 .12361 L
.92482 .12361 L
.92622 .12361 L
.92896 .12361 L
.93893 .12361 L
.97619 .12361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.78) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo06Soool00`1Vooooooooo`0Soooo002?oooo00<0003ooooo
ool0I?ooo`D0I_lUoooo002?oooo00<0003oooooool0G_ooo`H0I_l4oooo00<0I_ooooooool08ooo
o`00Soooo`030000oooooooo05Ooool706Ko2_ooo`0306Kooooooooo02?oool008ooool00`000?oo
ooooo`1Boooo1@1Voa7oool00`1Vooooooooo`0Soooo002?oooo00<0003oooooool0C_ooo`@0I_lF
oooo00<0I_ooooooool08oooo`00Soooo`80001;oooo101Voa[oool00`1Vooooooooo`0Soooo002?
oooo00<0003oooooool0A_ooo`@0I_lNoooo00<0I_ooooooool08oooo`00Soooo`030000oooooooo
04;oool406Ko8_ooo`0306Kooooooooo02?oool0047ooolJ06Ko=?ooo`030000oooooooo03koool4
06Ko9_ooo`0306Kooooooooo02?oool003coool506Ko6_ooo`P0I_l/oooo00<0003oooooool0=_oo
o`P0I_lZoooo00<0I_ooooooool08oooo`00>Oooo`<0I_lWoooo2P1Vob;oool00`000?ooooooo`0^
oooo201Voc;oool00`1Vooooooooo`0Soooo000goooo0P1VocCoool:06Ko6?ooo`80000Zoooo1@1V
oc[oool00`1Vooooooooo`0Soooo000Goooo100001Woool306Ko7Oooo`D0000Noooo201Voa3oool0
0`000?ooooooo`0Roooo1`1Vo`koool50000;?ooo`0306Kooooooooo00Woool400005_ooo`005ooo
o`030000oooooooo01Soool206Ko8_ooo`030000oooooooo02Koool506Ko2oooo`030000oooooooo
01[oool806Ko5oooo`030000oooooooo02coool00`1Vooooooooo`09oooo00<0003oooooool05ooo
o`006?ooo`030000oooooooo01Goool206Ko9?ooo`030000oooooooo02_oool;06Ko00<0003ooooo
ool04?ooo`X0I_lOoooo00<0003oooooool0;?ooo`0306Kooooooooo00[oool00`000?ooooooo`0F
oooo000Aoooo100000Coool00`000?ooooooo`0Boooo0P1Voakoool400001?ooo`030000oooooooo
03Koool00`00001Vo`1Vo`0@06Ko:Oooo`030000oooooooo02coool00`1Vooooooooo`0;oooo00<0
003oooooool05Oooo`005oooo`040000oooooooo00004Oooo`80I_lXoooo00<0003oooooool0=_oo
o`030000oooooooo03Woool00`000?ooooooo`0/oooo00<0I_ooooooool02Oooo`040000oooooooo
00005_ooo`006?ooo`80000Aoooo00<0I_ooooooool09oooo`80000hoooo0P0003Woool20000;_oo
o`0306Kooooooooo00[oool200005oooo`00:_ooo`0306Kooooooooo06;oool00`000?ooooooo`1X
oooo00<0I_ooooooool08oooo`00:Oooo`0306Kooooooooo06?oool00`000?ooooooo`1Xoooo00<0
I_ooooooool08oooo`009oooo`80I_mVoooo00<0003oooooool0J?ooo`0306Kooooooooo02?oool0
02Koool00`1Vooooooooo`1Voooo00<0003oooooool0J?ooo`0306Kooooooooo02?oool002Goool0
0`1Vooooooooo`1Woooo00<0003oooooool0J?ooo`0306Kooooooooo02?oool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`0003?o03?o0009
<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0c
o`002C?o00030000<ol0<ol000Hco`0R00001?ooo`03o`2Ioooo000000_oool00`000?ooooooo`0E
oooo000Foooo00<0003oooooool0>_ooo`030000oooooooo03Woool00`0003?o03?o000i<ol02@00
02Koool00ol0VOooooooo`0;oooo00<0003oooooool05Oooo`00Soooo`030000<ol0<ol003<co`06
0000;oooo`03o`2Ioooooooo02?oool008ooool00`0003?o03?o000a<ol00P0003Goool00ol0VOoo
ooooo`0Soooo002?oooo00<0000co`0co`00;c?o0080000goooo00?o09Woooooool08oooo`00Sooo
o`030000<ol0<ol002`co`030000>Oooo`03o`2Ioooooooo02?oool008ooool20000:S?o00<0000l
oooo00?o09Woooooool08oooo`00Soooo`030000<ol0<ol002Lco`020000?oooo`03o`2Ioooooooo
02?oool008ooool00`0003?o03?o000V<ol000<0003oooooool0?oooo`03o`2Ioooooooo02?oool0
08ooool00`0003?o03?o000U<ol000<0003oooooool0@?ooo`03o`2Ioooooooo02?oool008ooool0
0`0003?o03?o000T<ol000<0003oooooool0@Oooo`03o`2Ioooooooo02?oool008ooool00`0003?o
03?o000R<ol00P0004Coool00ol0VOooooooo`0Soooo002?oooo0P00028co`000`000?ooooooo`14
oooo00?o09Woooooool08oooo`00Soooo`030000<ol0<ol0020co`000`000?ooooooo`15oooo00?o
09Woooooool08oooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`16oooo00?o09Wooooo
ool08oooo`00Soooo`030000<ol0<ol001lco`000`000?ooooooo`16oooo00?o09Woooooool08ooo
o`00Soooo`030000<ol0<ol001hco`000`000?ooooooo`17oooo00?o09Woooooool08oooo`00Sooo
o`030000<ol0<ol001dco`000`000?ooooooo`18oooo00?o09Woooooool08oooo`00Soooo`80000M
<ol000<0003oooooool0BOooo`03o`2Ioooooooo02?oool008ooool00`0003?o03?o000K<ol000<0
003oooooool0B_ooo`03o`2Ioooooooo02?oool008ooool00`0003?o03?o000K<ol000<0003ooooo
ool0B_ooo`03o`2Ioooooooo02?oool008ooool00`0003?o03?o000J<ol000<0003oooooool0Booo
o`03o`2Ioooooooo02?oool008ooool00`0003?o03?o000J<ol000<0003oooooool0Boooo`03o`2I
oooooooo02?oool008ooool00`0003?o03?o000I<ol000<0003oooooool0C?ooo`03o`2Ioooooooo
02?oool008ooool200006S?o00030000oooooooo04coool00ol0VOooooooo`0Soooo002?oooo00<0
000co`0co`0063?o00030000oooooooo04goool00ol0VOooooooo`0Soooo002?oooo00<0000co`0c
o`0063?o00030000oooooooo04goool00ol0VOooooooo`0Soooo002?oooo00<0000co`0co`005c?o
00030000oooooooo04koool00ol0VOooooooo`0Soooo002?oooo00<0000co`0co`005c?o00030000
oooooooo04koool00ol0VOooooooo`0Soooo0027oooo1@0000?oool00`0003?o03?o000F<ol000<0
003oooooool0Coooo`03o`2Ioooooooo02?oool008Woool00`000?ooooooo`03oooo00<0000co`0c
o`005S?o00030000oooooooo04ooool00ol0VOooooooo`0Soooo0029oooo00<0003oooooool00ooo
o`<0000E<ol000<0003oooooool0D?ooo`03o`2Ioooooooo02?oool008Woool00`000?ooooooo`03
oooo00<0000co`0co`005C?o00030000oooooooo053oool00ol0VOooooooo`0Soooo0029oooo00<0
003oooooool00oooo`030000<ol0<ol001Dco`000`000?ooooooo`1@oooo00?o09Woooooool08ooo
o`00R?ooo`800005oooo00<0000co`0co`0053?o00030000oooooooo057oool00ol0VOooooooo`0S
oooo002?oooo00<0000co`0co`0053?o00030000oooooooo057oool00ol0VOooooooo`0Soooo002?
oooo00<0000co`0co`004c?o00030000oooooooo05;oool00ol0VOooooooo`0Soooo002?oooo0P00
01@co`000`000?ooooooo`1Boooo00?o09Woooooool08oooo`00Soooo`030000<ol0<ol001<co`00
0`000?ooooooo`1Boooo00?o09Woooooool08oooo`00Soooo`030000<ol0<ol0018co`000`000?oo
ooooo`1Coooo00?o09Woooooool08oooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`1C
oooo00?o09Woooooool08oooo`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`1Coooo00?o
09Woooooool08oooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`1Doooo00?o09Wooooo
ool08oooo`00Soooo`80000B<ol000<0003oooooool0E?ooo`03o`2Ioooooooo02?oool008ooool0
0`0003?o03?o000A<ol000<0003oooooool0E?ooo`03o`2Ioooooooo02?oool008ooool00`0003?o
03?o000A<ol000<0003oooooool0E?ooo`03o`2Ioooooooo02?oool008ooool00`0003?o03?o000@
<ol000<0003oooooool0EOooo`03o`2Ioooooooo02?oool008ooool00`0003?o03?o000@<ol000<0
003oooooool0EOooo`03o`2Ioooooooo02?oool008ooool00`0003?o03?o000@<ol000<0003ooooo
ool0EOooo`03o`2Ioooooooo02?oool008ooool00`0003?o03?o000@<ol000<0003oooooool0EOoo
o`03o`2Ioooooooo02?oool008ooool2000043?o00030000oooooooo05Koool00ol0VOooooooo`0S
oooo002?oooo00<0000co`0co`003c?o00030000oooooooo05Koool00ol0VOooooooo`0Soooo002?
oooo00<0000co`0co`003c?o00030000oooooooo05Koool00ol0VOooooooo`0Soooo002?oooo00<0
000co`0co`003c?o00030000oooooooo05Koool00ol0VOooooooo`0Soooo002?oooo00<0000co`0c
o`003c?o00030000oooooooo05Koool00ol0VOooooooo`0Soooo002?oooo00<0000co`0co`003S?o
00030000oooooooo05Ooool00ol0VOooooooo`0Soooo002?oooo0P0000lco`000`000?ooooooo`1G
oooo00?o09Woooooool08oooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`1Goooo00?o
09Woooooool08oooo`00Soooo`030000<ol0<ol000hco`000`000?ooooooo`1Goooo00?o09Wooooo
ool08oooo`00Soooo`030000<ol0<ol000dco`000`000?ooooooo`1Hoooo00?o09Woooooool08ooo
o`00Qoooo`@00004oooo00<0000co`0co`003C?o00030000oooooooo05Soool00ol0VOooooooo`0S
oooo0027oooo00<0003oooooool01Oooo`030000<ol0<ol000dco`000`000?ooooooo`1Hoooo00?o
09Woooooool08oooo`00R?ooo`030000oooooooo00Coool300003C?o00030000oooooooo05Soool0
0ol0VOooooooo`0Soooo0029oooo00<0003oooooool00oooo`030000<ol0<ol000dco`000`000?oo
ooooo`1Ioooo00?o09Woooooool08_ooo`00Qoooo`040000oooooooo00001?ooo`030000<ol0<ol0
00`co`000`000?ooooooo`1Joooo00?o09Woooooool08_ooo`00R?ooo`800005oooo00<0000co`0c
o`0033?o00030000oooooooo05[oool00ol0VOooooooo`0Roooo002?oooo00<0000co`0co`0033?o
00030000oooooooo05[oool00ol0VOooooooo`0Roooo002?oooo00<0000co`0co`0033?o00030000
oooooooo05[oool00ol0VOooooooo`0Roooo002?oooo0P0000dco`000`000?ooooooo`1Joooo00?o
09Woooooool08_ooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`1Joooo00?o09Wooooo
ool08_ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Koooo00?o09Woooooool08_oo
o`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Koooo00?o09Woooooool08_ooo`00Sooo
o`030000<ol0<ol000/co`000`000?ooooooo`1Koooo00?o09Woooooool08_ooo`00Soooo`030000
<ol0<ol000/co`000`000?ooooooo`1Koooo00?o09Woooooool08_ooo`00Soooo`030000<ol0<ol0
00/co`000`000?ooooooo`1Koooo00?o09Woooooool08_ooo`00Soooo`80000<<ol000<0003ooooo
ool0Foooo`03o`2Ioooooooo02;oool008ooool00`0003?o03?o000;<ol000<0003oooooool0Fooo
o`03o`2Ioooooooo02;oool008ooool00`0003?o03?o000:<ol000<0003oooooool0G?ooo`03o`2I
oooooooo02;oool008ooool00`0003?o03?o000:<ol000<0003oooooool0G?ooo`03o`2Ioooooooo
02;oool008ooool00`0003?o03?o000:<ol000<0003oooooool0G?ooo`03o`2Ioooooooo02;oool0
08ooool00`0003?o03?o000:<ol000<0003oooooool0G?ooo`03o`2Ioooooooo02;oool008ooool2
00002c?o00030000oooooooo05coool00ol0VOooooooo`0Roooo002?oooo00<0000co`0co`002S?o
00030000oooooooo05coool00ol0VOooooooo`0Roooo002?oooo00<0000co`0co`002S?o00030000
oooooooo05coool00ol0VOooooooo`0Roooo002?oooo00<0000co`0co`002C?o00030000oooooooo
05goool00ol0VOooooooo`0Roooo002?oooo00<0000co`0co`002C?o00030000oooooooo05goool0
0ol0VOooooooo`0Roooo002?oooo00<0000co`0co`002C?o00030000oooooooo05goool00ol0VOoo
ooooo`0Roooo002?oooo0P0000Xco`000`000?ooooooo`1Moooo00?o09Woooooool08_ooo`00Sooo
o`030000<ol0<ol000Tco`000`000?ooooooo`1Moooo00?o09Woooooool08_ooo`00Soooo`030000
<ol0<ol000Tco`000`000?ooooooo`1Moooo00?o09Woooooool08_ooo`00Soooo`030000<ol0<ol0
00Pco`000`000?ooooooo`1Noooo00?o09Woooooool08_ooo`00R?ooo`800005oooo00<0000co`0c
o`0023?o00030000oooooooo05koool00ol0VOooooooo`0Roooo0027oooo00@0003oooooool00004
oooo00<0000co`0co`0023?o00030000oooooooo05koool00ol0VOooooooo`0Roooo0029oooo00<0
003oooooool00oooo`<00008<ol000<0003oooooool0G_ooo`03o`2Ioooooooo02;oool008[oool0
0`000?ooooooo`02oooo00<0000co`0co`0023?o00030000oooooooo05koool00ol0VOooooooo`0R
oooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo05koool0
0ol0VOooooooo`0Roooo0028oooo0P0000Goool00`0003?o03?o0007<ol000<0003oooooool0Gooo
o`03o`2Ioooooooo02;oool008ooool00`0003?o03?o0007<ol000<0003oooooool0Goooo`03o`2I
oooooooo02;oool008ooool00`0003?o03?o0007<ol000<0003oooooool0Goooo`03o`2Ioooooooo
02;oool008ooool00`0003?o03?o0007<ol000<0003oooooool0Goooo`03o`2Ioooooooo02;oool0
08ooool2000023?o00030000oooooooo05ooool00ol0VOooooooo`0Roooo002?oooo00<0000co`0c
o`001c?o00030000oooooooo05ooool00ol0VOooooooo`0Roooo002?oooo00<0000co`0co`001c?o
00030000oooooooo05ooool00ol0VOooooooo`0Roooo002?oooo00<0000co`0co`001c?o00030000
oooooooo05ooool00ol0VOooooooo`0Roooo002?oooo00<0000co`0co`001S?o00030000oooooooo
063oool00ol0VOooooooo`0Roooo002?oooo00<0000co`0co`001S?o00030000oooooooo063oool0
0ol0VOooooooo`0Roooo002?oooo0P0000Lco`000`000?ooooooo`1Poooo00?o09Woooooool08_oo
o`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Poooo00?o09Woooooool08_ooo`00Sooo
o`030000<ol0<ol000Hco`000`000?ooooooo`1Poooo00?o09Woooooool08_ooo`00Soooo`030000
<ol0<ol000Hco`000`000?ooooooo`1Poooo00?o09Woooooool08_ooo`00Soooo`030000<ol0<ol0
00Hco`000`000?ooooooo`1Poooo00?o09Woooooool08_ooo`00Soooo`030000<ol0<ol000Hco`00
0`000?ooooooo`1Poooo00?o09Woooooool08_ooo`00Soooo`800006<ol000<0003oooooool0HOoo
o`03o`2Ioooooooo02;oool008ooool00`0003?o03?o0005<ol000<0003oooooool0HOooo`03o`2I
oooooooo02;oool008ooool00`0003?o03?o0005<ol000<0003oooooool0HOooo`03o`2Ioooooooo
02;oool008ooool00`0003?o03?o0005<ol000<0003oooooool0HOooo`03o`2Ioooooooo02;oool0
08ooool00`0003?o03?o0005<ol000<0003oooooool0HOooo`03o`2Ioooooooo02;oool008ooool0
0`0003?o03?o0005<ol000<0003oooooool0HOooo`03o`2Ioooooooo02;oool008ooool200001S?o
00030000oooooooo067oool00ol0VOooooooo`0Roooo002?oooo00<0000co`0co`001C?o00030000
oooooooo067oool00ol0VOooooooo`0Roooo002?oooo00<0000co`0co`001C?o00030000oooooooo
067oool00ol0VOooooooo`0Roooo002?oooo00<0000co`0co`0013?o00030000oooooooo06;oool0
0ol0VOooooooo`0Roooo002?oooo00<0000co`0co`0013?o00030000oooooooo06;oool00ol0VOoo
ooooo`0Roooo0029oooo0`0000?oool00`0003?o03?o0004<ol000<0003oooooool0H_ooo`03o`2I
oooooooo02;oool008[oool00`000?ooooooo`02oooo00<0000co`0co`0013?o00030000oooooooo
06;oool00ol0VOooooooo`0Roooo0027oooo1@0000?oool3000013?o00030000oooooooo06;oool0
0ol0VOooooooo`0Roooo0027oooo00@0003oooooool00004oooo1c?o08[oool008Soool00`000?oo
o`000004oooo1c?o08[oool008Woool200001?ooo`Lco`2:oooo002?oooo1c?o08[oool008ooool7
<ol0R_ooo`00NOooo`030000oooooooo01?oool7<ol03_ooo`030000oooooooo07Woool007Soool0
0`000?ooooooo`08oooo00<0003oooooool02Oooo`Lco`0?oooo00<0003oooooool0N?ooo`00N?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000c?o008000000c?o0?oo
ooooo`02oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo
00Lco`04oooo00D0003oooooooooool000000_ooo`050000oooooooooooo000007[oool007Ooool0
0`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooo<ol000Hco`04oooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0000koool00`0003?o03?o0005<ol01Oooo`040000oooooooooooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00001S?o00;oool0
10000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0
003oooooool04Oooo`800007<ol00_ooo`@00003oooo0P0000?oool00`000?ooooooo`1ioooo002?
oooo1c?o08[oool008ooool7<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.91765 .12361 L
.9225 .12361 L
.92516 .12361 L
.92648 .12361 L
.92769 .12361 L
.92838 .12361 L
s
.92838 .12361 m
.92868 .61803 L
s
0 .4 1 r
.02381 .12361 m
.04262 .12361 L
.0522 .12361 L
.06244 .12361 L
.06525 .12361 L
.0679 .12361 L
.06905 .12361 L
.07027 .12361 L
.07091 .12361 L
.07162 .12341 L
.07286 .12214 L
.08255 .11284 L
.10458 .09565 L
.12399 .08434 L
.14487 .07541 L
.15497 .0721 L
.166 .06913 L
.17654 .06687 L
.18609 .06523 L
.19622 .0639 L
.20576 .06297 L
.21101 .06259 L
.21584 .06231 L
.22114 .06208 L
.22381 .06199 L
.22674 .06191 L
.22925 .06186 L
.23067 .06184 L
.23198 .06183 L
.23312 .06182 L
.23438 .06181 L
.2357 .0618 L
.23694 .0618 L
.23808 .06181 L
.23928 .06181 L
.2403 .06182 L
.24142 .06183 L
.24392 .06186 L
.24625 .0619 L
.25154 .06204 L
.25636 .0622 L
.26716 .06271 L
.27714 .06333 L
.28635 .06401 L
.30714 .06588 L
.34655 .07027 L
.38443 .07504 L
.42477 .08027 L
.4636 .08516 L
.48335 .08755 L
Mistroke
.49377 .08878 L
.49949 .08944 L
.50487 .09 L
.51008 .09042 L
.51282 .0906 L
.5157 .09075 L
.51814 .09086 L
.52081 .09096 L
.52324 .09103 L
.52551 .09109 L
.5267 .09111 L
.52799 .09112 L
.52921 .09114 L
.53034 .09115 L
.53136 .09115 L
.53248 .09115 L
.53365 .09115 L
.53474 .09115 L
.53596 .09114 L
.53723 .09113 L
.53832 .09112 L
.53951 .09111 L
.54217 .09106 L
.54464 .091 L
.5497 .09085 L
.55519 .09063 L
.56513 .09011 L
.58373 .08878 L
.60365 .08692 L
.6247 .08454 L
.66264 .07942 L
.70304 .07298 L
.74191 .06598 L
.78324 .05786 L
.82305 .04961 L
.86135 .04162 L
.88071 .03772 L
.9021 .03365 L
.91183 .03193 L
.91694 .03106 L
.92233 .03018 L
.92462 .02982 L
.92706 .02944 L
.92778 .02933 L
.92846 .02922 L
.92974 .12361 L
.93094 .12361 L
.93224 .12361 L
.94133 .12361 L
.97619 .12361 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo06Woool206Ko8oooo`00Soooo`030000oooooooo06Goool6
06Ko8oooo`00Soooo`030000oooooooo067oool406Ko1Oooo`0306Kooooooooo027oool008ooool0
0`000?ooooooo`1Loooo1@1Vo`Woool00`1Vooooooooo`0Qoooo002?oooo00<0003oooooool0Eooo
o`D0I_l>oooo00<0I_ooooooool08Oooo`00Soooo`030000oooooooo05;oool506Ko4oooo`0306Ko
oooooooo027oool008ooool20000C_ooo`D0I_lHoooo00<0I_ooooooool08Oooo`00Soooo`030000
oooooooo04Soool506Ko7Oooo`0306Kooooooooo027oool008ooool00`000?ooooooo`13oooo1@1V
ob;oool00`1Vooooooooo`0Qoooo0011oooo6`1Voc?oool00`000?ooooooo`0moooo1P1VobOoool0
0`1Vooooooooo`0Qoooo000loooo1@1Voa_oool706Ko;?ooo`030000oooooooo03Soool506Ko;Ooo
o`0306Kooooooooo027oool003Ooool506Ko9oooo`X0I_lRoooo00<0003oooooool0<oooo`D0I_lb
oooo00<0I_ooooooool08Oooo`00=?ooo`<0I_lfoooo2P1VoaSoool20000;Oooo`L0I_lgoooo00<0
I_ooooooool08Oooo`005oooo`@0000Goooo0P1Vob3oool500007_ooo`P0I_l@oooo00<0003ooooo
ool08_ooo`X0I_l;oooo1@0002koool00`1Vooooooooo`07oooo100001Koool001Ooool00`000?oo
ooooo`0Foooo0P1VobCoool00`000?ooooooo`0Voooo1@1Vo`_oool00`000?ooooooo`0Koooo1`1V
oaOoool00`000?ooooooo`0^oooo00<0I_ooooooool01oooo`030000oooooooo01Ooool001Soool0
0`000?ooooooo`0Coooo0P1VobKoool00`000?ooooooo`0[oooo201Vo`?oool00`000?ooooooo`0E
oooo1P1Voakoool00`000?ooooooo`0^oooo00<0I_ooooooool02?ooo`030000oooooooo01Koool0
017oool400001?ooo`030000oooooooo013oool206Ko8?ooo`@00004oooo00<0003oooooool0<ooo
o`<0I_l00`00001Vo`1Vo`0E06Ko9?ooo`030000oooooooo02koool00`1Vooooooooo`09oooo00<0
003oooooool05Oooo`005oooo`040000oooooooo00004?ooo`0306Kooooooooo02Soool00`000?oo
ooooo`0foooo00<0003oooooool0>Oooo`030000oooooooo02koool00`1Vooooooooo`07oooo00@0
003oooooool0000Foooo000Hoooo0P00013oool00`1Vooooooooo`0Xoooo0P0003Soool20000>Ooo
o`80000`oooo00<0I_ooooooool02?ooo`80000Goooo000Yoooo00<0I_ooooooool0Hoooo`030000
oooooooo06[oool00`1Vooooooooo`0Qoooo000Woooo0P1VofKoool00`000?ooooooo`1Zoooo00<0
I_ooooooool08Oooo`009_ooo`0306Kooooooooo06Koool00`000?ooooooo`1Zoooo00<0I_oooooo
ool08Oooo`009Oooo`0306Kooooooooo06Ooool00`000?ooooooo`1Zoooo00<0I_ooooooool08Ooo
o`009?ooo`0306Kooooooooo06Soool00`000?ooooooo`1Zoooo00<0I_ooooooool08Oooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0003oooooool02Oooo`030000
oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol0
03Tco`090000:?ooo`03o`2Ioooooooo00Woool00`000?ooooooo`0Eoooo002?oooo00<0000co`0c
o`00<c?o00H0000aoooo00?o09Woooooool08Oooo`00Soooo`030000<ol0<ol0034co`020000=ooo
o`03o`2Ioooooooo027oool008ooool00`0003?o03?o000_<ol00P0003Woool00ol0VOooooooo`0Q
oooo002?oooo00<0000co`0co`00;3?o00<0000koooo00?o09Woooooool08Oooo`00Soooo`80000Z
<ol00`0003koool00ol0VOooooooo`0Qoooo002?oooo00<0000co`0co`009c?o00800011oooo00?o
09Woooooool08Oooo`00Soooo`030000<ol0<ol002Hco`000`000?ooooooo`11oooo00?o09Wooooo
ool08Oooo`00Soooo`030000<ol0<ol002Dco`000`000?ooooooo`12oooo00?o09Woooooool08Ooo
o`00Soooo`030000<ol0<ol002@co`000`000?ooooooo`13oooo00?o09Woooooool08Oooo`00Sooo
o`030000<ol0<ol0028co`020000A_ooo`03o`2Ioooooooo027oool008ooool200008S?o00030000
oooooooo04Koool00ol0VOooooooo`0Qoooo002?oooo00<0000co`0co`0083?o00030000oooooooo
04Ooool00ol0VOooooooo`0Qoooo002?oooo00<0000co`0co`007c?o00030000oooooooo04Soool0
0ol0VOooooooo`0Qoooo002?oooo00<0000co`0co`007c?o00030000oooooooo04Soool00ol0VOoo
ooooo`0Qoooo002?oooo00<0000co`0co`007S?o00030000oooooooo04Woool00ol0VOooooooo`0Q
oooo002?oooo00<0000co`0co`007C?o00030000oooooooo04[oool00ol0VOooooooo`0Qoooo002?
oooo0P0001dco`000`000?ooooooo`1;oooo00?o09Woooooool08Oooo`00Soooo`030000<ol0<ol0
01/co`000`000?ooooooo`1<oooo00?o09Woooooool08Oooo`00Soooo`030000<ol0<ol001/co`00
0`000?ooooooo`1<oooo00?o09Woooooool08Oooo`00Soooo`030000<ol0<ol001Xco`000`000?oo
ooooo`1=oooo00?o09Woooooool08Oooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`1=
oooo00?o09Woooooool08Oooo`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`1>oooo00?o
09Woooooool08Oooo`00Soooo`80000J<ol000<0003oooooool0C_ooo`03o`2Ioooooooo027oool0
08ooool00`0003?o03?o000H<ol000<0003oooooool0Coooo`03o`2Ioooooooo027oool008ooool0
0`0003?o03?o000H<ol000<0003oooooool0Coooo`03o`2Ioooooooo027oool008ooool00`0003?o
03?o000G<ol000<0003oooooool0D?ooo`03o`2Ioooooooo027oool008ooool00`0003?o03?o000G
<ol000<0003oooooool0D?ooo`03o`2Ioooooooo027oool008Ooool500000oooo`030000<ol0<ol0
01Hco`000`000?ooooooo`1Aoooo00?o09Woooooool08Oooo`00ROooo`030000oooooooo00?oool0
0`0003?o03?o000F<ol000<0003oooooool0DOooo`03o`2Ioooooooo027oool008Woool00`000?oo
ooooo`03oooo0`0001Dco`000`000?ooooooo`1Boooo00?o09Woooooool08Oooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool0D_ooo`03o`2Ioooooooo027oool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo05;oool00ol0VOoo
ooooo`0Qoooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool0Doooo`03o`2I
oooooooo027oool008ooool00`0003?o03?o000D<ol000<0003oooooool0Doooo`03o`2Ioooooooo
027oool008ooool00`0003?o03?o000C<ol000<0003oooooool0E?ooo`03o`2Ioooooooo027oool0
08ooool2000053?o00030000oooooooo05Coool00ol0VOooooooo`0Qoooo002?oooo00<0000co`0c
o`004c?o00030000oooooooo05Coool00ol0VOooooooo`0Qoooo002?oooo00<0000co`0co`004S?o
00030000oooooooo05Goool00ol0VOooooooo`0Qoooo002?oooo00<0000co`0co`004S?o00030000
oooooooo05Goool00ol0VOooooooo`0Qoooo002?oooo00<0000co`0co`004S?o00030000oooooooo
05Goool00ol0VOooooooo`0Qoooo002?oooo00<0000co`0co`004C?o00030000oooooooo05Koool0
0ol0VOooooooo`0Qoooo002?oooo0P00018co`000`000?ooooooo`1Foooo00?o09Woooooool08Ooo
o`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`1Foooo00?o09Woooooool08Oooo`00Sooo
o`030000<ol0<ol0014co`000`000?ooooooo`1Foooo00?o09Woooooool08Oooo`00Soooo`030000
<ol0<ol0010co`000`000?ooooooo`1Goooo00?o09Woooooool08Oooo`00Soooo`030000<ol0<ol0
010co`000`000?ooooooo`1Goooo00?o09Woooooool08Oooo`00Soooo`030000<ol0<ol0010co`00
0`000?ooooooo`1Goooo00?o09Woooooool08Oooo`00Soooo`030000<ol0<ol0010co`000`000?oo
ooooo`1Goooo00?o09Woooooool08Oooo`00Soooo`80000@<ol000<0003oooooool0F?ooo`03o`2I
oooooooo027oool008ooool00`0003?o03?o000?<ol000<0003oooooool0F?ooo`03o`2Ioooooooo
027oool008ooool00`0003?o03?o000?<ol000<0003oooooool0F?ooo`03o`2Ioooooooo027oool0
08ooool00`0003?o03?o000?<ol000<0003oooooool0F?ooo`03o`2Ioooooooo027oool008ooool0
0`0003?o03?o000?<ol000<0003oooooool0F?ooo`03o`2Ioooooooo027oool008ooool00`0003?o
03?o000><ol000<0003oooooool0FOooo`03o`2Ioooooooo027oool008ooool200003c?o00030000
oooooooo05Woool00ol0VOooooooo`0Qoooo002?oooo00<0000co`0co`003S?o00030000oooooooo
05Woool00ol0VOooooooo`0Qoooo002?oooo00<0000co`0co`003S?o00030000oooooooo05Woool0
0ol0VOooooooo`0Qoooo002?oooo00<0000co`0co`003C?o00030000oooooooo05[oool00ol0VOoo
ooooo`0Qoooo0027oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool0F_ooo`03o`2I
oooooooo027oool008Ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo
05[oool00ol0VOooooooo`0Qoooo0028oooo00<0003oooooool01?ooo`<0000=<ol000<0003ooooo
ool0F_ooo`03o`2Ioooooooo027oool008Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o
00030000oooooooo05[oool00ol0VOooooooo`0Qoooo0027oooo00@0003oooooool00004oooo00<0
000co`0co`0033?o00030000oooooooo05_oool00ol0VOooooooo`0Qoooo0028oooo0P0000Goool0
0`0003?o03?o000<<ol000<0003oooooool0Foooo`03o`2Ioooooooo027oool008ooool00`0003?o
03?o000<<ol000<0003oooooool0Foooo`03o`2Ioooooooo027oool008ooool00`0003?o03?o000<
<ol000<0003oooooool0Foooo`03o`2Ioooooooo027oool008ooool200003C?o00030000oooooooo
05_oool00ol0VOooooooo`0Qoooo002?oooo00<0000co`0co`0033?o00030000oooooooo05_oool0
0ol0VOooooooo`0Qoooo002?oooo00<0000co`0co`002c?o00030000oooooooo05coool00ol0VOoo
ooooo`0Qoooo002?oooo00<0000co`0co`002c?o00030000oooooooo05coool00ol0VOooooooo`0Q
oooo002?oooo00<0000co`0co`002c?o00030000oooooooo05coool00ol0VOooooooo`0Qoooo002?
oooo00<0000co`0co`002c?o00030000oooooooo05coool00ol0VOooooooo`0Qoooo002?oooo00<0
000co`0co`002c?o00030000oooooooo05coool00ol0VOooooooo`0Qoooo002?oooo0P0000`co`00
0`000?ooooooo`1Loooo00?o09Woooooool08Oooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`1Loooo00?o09Woooooool08Oooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1M
oooo00?o09Woooooool08Oooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1Moooo00?o
09Woooooool08Oooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1Moooo00?o09Wooooo
ool08Oooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1Moooo00?o09Woooooool08Ooo
o`00Soooo`80000;<ol000<0003oooooool0GOooo`03o`2Ioooooooo027oool008ooool00`0003?o
03?o000:<ol000<0003oooooool0GOooo`03o`2Ioooooooo027oool008ooool00`0003?o03?o000:
<ol000<0003oooooool0GOooo`03o`2Ioooooooo027oool008ooool00`0003?o03?o0009<ol000<0
003oooooool0G_ooo`03o`2Ioooooooo027oool008ooool00`0003?o03?o0009<ol000<0003ooooo
ool0G_ooo`03o`2Ioooooooo027oool008ooool00`0003?o03?o0009<ol000<0003oooooool0G_oo
o`03o`2Ioooooooo027oool008ooool200002S?o00030000oooooooo05koool00ol0VOooooooo`0Q
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo05koool00ol0VOooooooo`0Qoooo002?
oooo00<0000co`0co`002C?o00030000oooooooo05koool00ol0VOooooooo`0Qoooo002?oooo00<0
000co`0co`0023?o00030000oooooooo05ooool00ol0VOooooooo`0Qoooo0028oooo0P0000Goool0
0`0003?o03?o0008<ol000<0003oooooool0Goooo`03o`2Ioooooooo027oool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0Goooo`03o`2Ioooooooo027oool0
08Woool00`000?ooooooo`03oooo0`0000Pco`000`000?ooooooo`1Ooooo00?o09Woooooool08Ooo
o`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0Goooo`03o`2I
oooooooo027oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003ooooo
ool0Goooo`03o`2Ioooooooo027oool008Soool200001Oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1Poooo00?o09Woooooool08Oooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1P
oooo00?o09Woooooool08Oooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1Poooo00?o
09Woooooool08Oooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1Poooo00?o09Wooooo
ool08Oooo`00Soooo`800008<ol000<0003oooooool0H?ooo`03o`2Ioooooooo027oool008ooool0
0`0003?o03?o0007<ol000<0003oooooool0H?ooo`03o`2Ioooooooo027oool008ooool00`0003?o
03?o0007<ol000<0003oooooool0H?ooo`03o`2Ioooooooo027oool008ooool00`0003?o03?o0007
<ol000<0003oooooool0H?ooo`03o`2Ioooooooo027oool008ooool00`0003?o03?o0006<ol000<0
003oooooool0HOooo`03o`2Ioooooooo027oool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool0HOooo`03o`2Ioooooooo027oool008ooool200001c?o00030000oooooooo067oool00ol0VOoo
ooooo`0Qoooo002?oooo00<0000co`0co`001S?o00030000oooooooo067oool00ol0VOooooooo`0Q
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo067oool00ol0VOooooooo`0Qoooo002?
oooo00<0000co`0co`001S?o00030000oooooooo067oool00ol0VOooooooo`0Qoooo002?oooo00<0
000co`0co`001S?o00030000oooooooo067oool00ol0VOooooooo`0Qoooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo067oool00ol0VOooooooo`0Qoooo002?oooo0P0000Hco`000`000?oo
ooooo`1Roooo00?o09Woooooool08Oooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1R
oooo00?o09Woooooool08Oooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Roooo00?o
09Woooooool08Oooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Roooo00?o09Wooooo
ool08Oooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Roooo00?o09Woooooool08Ooo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Roooo00?o09Woooooool08Oooo`00Sooo
o`800006<ol000<0003oooooool0H_ooo`03o`2Ioooooooo027oool008ooool00`0003?o03?o0005
<ol000<0003oooooool0H_ooo`03o`2Ioooooooo027oool008ooool00`0003?o03?o0005<ol000<0
003oooooool0H_ooo`03o`2Ioooooooo027oool008ooool00`0003?o03?o0004<ol000<0003ooooo
ool0Hoooo`03o`2Ioooooooo027oool008ooool00`0003?o03?o0004<ol000<0003oooooool0Hooo
o`03o`2Ioooooooo027oool008Woool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`1S
oooo00?o09Woooooool08Oooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0
003oooooool0Hoooo`03o`2Ioooooooo027oool008Ooool500000oooo`<00004<ol000<0003ooooo
ool0Hoooo`03o`2Ioooooooo027oool008Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?oo
o`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_oo
o`00Soooo`Lco`2:oooo001loooo00<0003oooooool04?ooo`Lco`0;oooo00<0003oooooool0O?oo
o`00Noooo`030000oooooooo00Soool00`000?ooooooo`06oooo1c?o00coool00`000?ooooooo`1k
oooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003<ol00P00
00Coool200001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Goool00`0003?o03?o0004<ol01Oooo`040000oooooooo
00000oooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03Ooo
o`03<ol00000<ol000@co`05oooo00@0003oooooool00004oooo00<0003oooooool0N_ooo`00Nooo
o`030000oooooooo00D0000<oooo0S?o00030000<ol0<ol0008co`06oooo0P0000Coool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000003oooo`040000<ol0<ol000000c?o00Goool0
10000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04?ooo`03<ol0
0000000000@co`06oooo0P0000?oool00`000?ooooooo`1loooo002?oooo1c?o08[oool008ooool7
<ol0R_ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.82) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.91765 .12361 L
.9225 .12361 L
.92769 .12361 L
.92922 .12361 L
.93067 .12361 L
.93198 .12361 L
.93271 .12361 L
s
.93271 .12361 m
.93298 .61803 L
s
0 .4 1 r
.02381 .12361 m
.04262 .12361 L
.0522 .12361 L
.05746 .12361 L
.06244 .12361 L
.06506 .12361 L
.06577 .12361 L
.06653 .12361 L
.06718 .12307 L
.0679 .12234 L
.07286 .11743 L
.08255 .10868 L
.10458 .09257 L
.12399 .08203 L
.14487 .07377 L
.15497 .07074 L
.166 .06804 L
.17654 .066 L
.18609 .06456 L
.19622 .0634 L
.20576 .06262 L
.21101 .06231 L
.21584 .0621 L
.21837 .06201 L
.22114 .06193 L
.22254 .0619 L
.22403 .06187 L
.22532 .06185 L
.22674 .06183 L
.22806 .06182 L
.2293 .06181 L
.23061 .0618 L
.23135 .0618 L
.23202 .0618 L
.23316 .06181 L
.2344 .06181 L
.2357 .06182 L
.23691 .06183 L
.23971 .06187 L
.24226 .06192 L
.24798 .06207 L
.25294 .06225 L
.25833 .0625 L
.2681 .06305 L
.28797 .06454 L
.30902 .06655 L
.3469 .0709 L
.38724 .07602 L
.42607 .08104 L
.46734 .0862 L
Mistroke
.48798 .08866 L
.49802 .08982 L
.50711 .09073 L
.51169 .09106 L
.51665 .09133 L
.51893 .09143 L
.52133 .09151 L
.52358 .09158 L
.52563 .09162 L
.52676 .09164 L
.52798 .09166 L
.52927 .09167 L
.5305 .09168 L
.53164 .09169 L
.53286 .09169 L
.53389 .09169 L
.53504 .09169 L
.53569 .09168 L
.53638 .09168 L
.5376 .09167 L
.53892 .09165 L
.54036 .09163 L
.54295 .09158 L
.54535 .09153 L
.55042 .09137 L
.5559 .09115 L
.56585 .09064 L
.58445 .08931 L
.60436 .08747 L
.62542 .08512 L
.66336 .08005 L
.70375 .07368 L
.74263 .06674 L
.78396 .05868 L
.82377 .05045 L
.86207 .04245 L
.88143 .03851 L
.90282 .03439 L
.91255 .03263 L
.92304 .03083 L
.92787 .03005 L
.9305 .02964 L
.93179 .02944 L
.93296 .02926 L
.93403 .12361 L
.93505 .12361 L
.9373 .12361 L
.94205 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.82) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo06_oool00`1Vooooooooo`0Poooo002?oooo00<0003ooooo
ool0IOooo`L0I_lRoooo002?oooo00<0003oooooool0HOooo`@0I_l6oooo00<0I_ooooooool08?oo
o`00Soooo`030000oooooooo05coool506Ko2_ooo`0306Kooooooooo023oool008ooool00`000?oo
ooooo`1Goooo1@1Vo`ooool00`1Vooooooooo`0Poooo002?oooo00<0003oooooool0D_ooo`D0I_lD
oooo00<0I_ooooooool08?ooo`00Soooo`80001>oooo1@1VoaWoool00`1Vooooooooo`0Poooo002?
oooo00<0003oooooool0B?ooo`D0I_lNoooo00<0I_ooooooool08?ooo`00Soooo`030000oooooooo
04?oool506Ko8oooo`0306Kooooooooo023oool003oooolM06Ko<oooo`030000oooooooo03goool6
06Ko:?ooo`0306Kooooooooo023oool003Woool606Ko7Oooo`P0I_l[oooo00<0003oooooool0>?oo
o`D0I_l^oooo00<0I_ooooooool08?ooo`00=oooo`80I_l[oooo2@1Vob;oool00`000?ooooooo`0d
oooo101Voc?oool00`1Vooooooooo`0Poooo000doooo0`1VocKoool806Ko6_ooo`80000]oooo201V
ocOoool00`1Vooooooooo`0Poooo000Goooo100001Ooool206Ko8?ooo`D0000Loooo1@1VoaGoool0
0`000?ooooooo`0Toooo201Vo`_oool50000;oooo`0306Kooooooooo00Koool400005_ooo`005ooo
o`030000oooooooo01Koool206Ko9?ooo`030000oooooooo027oool806Ko3Oooo`030000oooooooo
023oool406Ko5Oooo`030000oooooooo02ooool00`1Vooooooooo`06oooo00<0003oooooool05ooo
o`006?ooo`030000oooooooo01?oool206Ko9_ooo`030000oooooooo02Woool806Ko1Oooo`030000
oooooooo01Goool;06Ko6Oooo`030000oooooooo02ooool00`1Vooooooooo`07oooo00<0003ooooo
ool05_ooo`004Oooo`@00004oooo00<0003oooooool04?ooo`80I_lPoooo100000Coool00`000?oo
ooooo`0aoooo1@1Vo`03000006Ko06Ko01D0I_lToooo00<0003oooooool0;oooo`0306Kooooooooo
00Soool00`000?ooooooo`0Eoooo000Goooo00@0003oooooool0000@oooo00<0I_ooooooool0:?oo
o`030000oooooooo03Koool00`000?ooooooo`0ioooo00<0003oooooool0;oooo`0306Kooooooooo
00Koool010000?ooooooo`0001Koool001Soool200003oooo`80I_lZoooo0P0003Soool20000>Ooo
o`80000aoooo00<0I_ooooooool01oooo`80000Goooo000Xoooo00<0I_ooooooool0I?ooo`030000
oooooooo06_oool00`1Vooooooooo`0Poooo000Voooo0P1VofOoool00`000?ooooooo`1[oooo00<0
I_ooooooool08?ooo`009Oooo`0306Kooooooooo06Ooool00`000?ooooooo`1[oooo00<0I_oooooo
ool08?ooo`009?ooo`0306Kooooooooo06Soool00`000?ooooooo`1[oooo00<0I_ooooooool08?oo
o`008oooo`0306Kooooooooo06Woool00`000?ooooooo`1[oooo00<0I_ooooooool08?ooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`001S?o02800006oooo00<0003o09Woool02Oooo`030000
oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol0
03Tco`090000:Oooo`03o`2Ioooooooo00Soool00`000?ooooooo`0Eoooo002?oooo00<0000co`0c
o`00<c?o00H0000boooo00?o09Woooooool08?ooo`00Soooo`030000<ol0<ol0034co`020000>?oo
o`03o`2Ioooooooo023oool008ooool00`0003?o03?o000_<ol00P0003[oool00ol0VOooooooo`0P
oooo002?oooo00<0000co`0co`00;3?o00<0000loooo00?o09Woooooool08?ooo`00Soooo`80000Z
<ol00`0003ooool00ol0VOooooooo`0Poooo002?oooo00<0000co`0co`009c?o00800012oooo00?o
09Woooooool08?ooo`00Soooo`030000<ol0<ol002Hco`000`000?ooooooo`12oooo00?o09Wooooo
ool08?ooo`00Soooo`030000<ol0<ol002Dco`000`000?ooooooo`13oooo00?o09Woooooool08?oo
o`00Soooo`030000<ol0<ol002@co`000`000?ooooooo`14oooo00?o09Woooooool08?ooo`00Sooo
o`030000<ol0<ol0028co`020000Aoooo`03o`2Ioooooooo023oool008ooool200008S?o00030000
oooooooo04Ooool00ol0VOooooooo`0Poooo002?oooo00<0000co`0co`0083?o00030000oooooooo
04Soool00ol0VOooooooo`0Poooo002?oooo00<0000co`0co`007c?o00030000oooooooo04Woool0
0ol0VOooooooo`0Poooo002?oooo00<0000co`0co`007c?o00030000oooooooo04Woool00ol0VOoo
ooooo`0Poooo002?oooo00<0000co`0co`007S?o00030000oooooooo04[oool00ol0VOooooooo`0P
oooo002?oooo00<0000co`0co`007C?o00030000oooooooo04_oool00ol0VOooooooo`0Poooo002?
oooo0P0001dco`000`000?ooooooo`1<oooo00?o09Woooooool08?ooo`00Soooo`030000<ol0<ol0
01/co`000`000?ooooooo`1=oooo00?o09Woooooool08?ooo`00Soooo`030000<ol0<ol001/co`00
0`000?ooooooo`1=oooo00?o09Woooooool08?ooo`00Soooo`030000<ol0<ol001Xco`000`000?oo
ooooo`1>oooo00?o09Woooooool08?ooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`1>
oooo00?o09Woooooool08?ooo`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`1?oooo00?o
09Woooooool08?ooo`00Soooo`80000J<ol000<0003oooooool0Coooo`03o`2Ioooooooo023oool0
08ooool00`0003?o03?o000H<ol000<0003oooooool0D?ooo`03o`2Ioooooooo023oool008ooool0
0`0003?o03?o000H<ol000<0003oooooool0D?ooo`03o`2Ioooooooo023oool008ooool00`0003?o
03?o000G<ol000<0003oooooool0DOooo`03o`2Ioooooooo023oool008ooool00`0003?o03?o000G
<ol000<0003oooooool0DOooo`03o`2Ioooooooo023oool008Ooool500000oooo`030000<ol0<ol0
01Hco`000`000?ooooooo`1Boooo00?o09Woooooool08?ooo`00ROooo`030000oooooooo00?oool0
0`0003?o03?o000F<ol000<0003oooooool0D_ooo`03o`2Ioooooooo023oool008Woool00`000?oo
ooooo`03oooo0`0001Dco`000`000?ooooooo`1Coooo00?o09Woooooool08?ooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool0Doooo`03o`2Ioooooooo023oool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo05?oool00ol0VOoo
ooooo`0Poooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool0E?ooo`03o`2I
oooooooo023oool008ooool00`0003?o03?o000D<ol000<0003oooooool0E?ooo`03o`2Ioooooooo
023oool008ooool00`0003?o03?o000C<ol000<0003oooooool0EOooo`03o`2Ioooooooo023oool0
08ooool2000053?o00030000oooooooo05Goool00ol0VOooooooo`0Poooo002?oooo00<0000co`0c
o`004c?o00030000oooooooo05Goool00ol0VOooooooo`0Poooo002?oooo00<0000co`0co`004S?o
00030000oooooooo05Koool00ol0VOooooooo`0Poooo002?oooo00<0000co`0co`004S?o00030000
oooooooo05Koool00ol0VOooooooo`0Poooo002?oooo00<0000co`0co`004S?o00030000oooooooo
05Koool00ol0VOooooooo`0Poooo002?oooo00<0000co`0co`004C?o00030000oooooooo05Ooool0
0ol0VOooooooo`0Poooo002?oooo0P00018co`000`000?ooooooo`1Goooo00?o09Woooooool08?oo
o`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`1Goooo00?o09Woooooool08?ooo`00Sooo
o`030000<ol0<ol0014co`000`000?ooooooo`1Goooo00?o09Woooooool08?ooo`00Soooo`030000
<ol0<ol0010co`000`000?ooooooo`1Hoooo00?o09Woooooool08?ooo`00Soooo`030000<ol0<ol0
010co`000`000?ooooooo`1Hoooo00?o09Woooooool08?ooo`00Soooo`030000<ol0<ol0010co`00
0`000?ooooooo`1Hoooo00?o09Woooooool08?ooo`00Soooo`030000<ol0<ol0010co`000`000?oo
ooooo`1Hoooo00?o09Woooooool08?ooo`00Soooo`80000@<ol000<0003oooooool0FOooo`03o`2I
oooooooo023oool008ooool00`0003?o03?o000?<ol000<0003oooooool0FOooo`03o`2Ioooooooo
023oool008ooool00`0003?o03?o000?<ol000<0003oooooool0FOooo`03o`2Ioooooooo023oool0
08ooool00`0003?o03?o000?<ol000<0003oooooool0FOooo`03o`2Ioooooooo023oool008ooool0
0`0003?o03?o000?<ol000<0003oooooool0FOooo`03o`2Ioooooooo023oool008ooool00`0003?o
03?o000><ol000<0003oooooool0F_ooo`03o`2Ioooooooo023oool008ooool200003c?o00030000
oooooooo05[oool00ol0VOooooooo`0Poooo002?oooo00<0000co`0co`003S?o00030000oooooooo
05[oool00ol0VOooooooo`0Poooo002?oooo00<0000co`0co`003S?o00030000oooooooo05[oool0
0ol0VOooooooo`0Poooo002?oooo00<0000co`0co`003C?o00030000oooooooo05_oool00ol0VOoo
ooooo`0Poooo0027oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool0Foooo`03o`2I
oooooooo023oool008Ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo
05_oool00ol0VOooooooo`0Poooo0028oooo00<0003oooooool01?ooo`<0000=<ol000<0003ooooo
ool0Foooo`03o`2Ioooooooo023oool008Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o
00030000oooooooo05_oool00ol0VOooooooo`0Poooo0027oooo00@0003oooooool00004oooo00<0
000co`0co`0033?o00030000oooooooo05coool00ol0VOooooooo`0Poooo0028oooo0P0000Goool0
0`0003?o03?o000<<ol000<0003oooooool0G?ooo`03o`2Ioooooooo023oool008ooool00`0003?o
03?o000<<ol000<0003oooooool0G?ooo`03o`2Ioooooooo023oool008ooool00`0003?o03?o000<
<ol000<0003oooooool0G?ooo`03o`2Ioooooooo023oool008ooool200003C?o00030000oooooooo
05coool00ol0VOooooooo`0Poooo002?oooo00<0000co`0co`0033?o00030000oooooooo05coool0
0ol0VOooooooo`0Poooo002?oooo00<0000co`0co`002c?o00030000oooooooo05goool00ol0VOoo
ooooo`0Poooo002?oooo00<0000co`0co`002c?o00030000oooooooo05goool00ol0VOooooooo`0P
oooo002?oooo00<0000co`0co`002c?o00030000oooooooo05goool00ol0VOooooooo`0Poooo002?
oooo00<0000co`0co`002c?o00030000oooooooo05goool00ol0VOooooooo`0Poooo002?oooo00<0
000co`0co`002c?o00030000oooooooo05goool00ol0VOooooooo`0Poooo002?oooo0P0000`co`00
0`000?ooooooo`1Moooo00?o09Woooooool08?ooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`1Moooo00?o09Woooooool08?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1N
oooo00?o09Woooooool08?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1Noooo00?o
09Woooooool08?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1Noooo00?o09Wooooo
ool08?ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1Noooo00?o09Woooooool08?oo
o`00Soooo`80000;<ol000<0003oooooool0G_ooo`03o`2Ioooooooo023oool008ooool00`0003?o
03?o000:<ol000<0003oooooool0G_ooo`03o`2Ioooooooo023oool008ooool00`0003?o03?o000:
<ol000<0003oooooool0G_ooo`03o`2Ioooooooo023oool008ooool00`0003?o03?o0009<ol000<0
003oooooool0Goooo`03o`2Ioooooooo023oool008ooool00`0003?o03?o0009<ol000<0003ooooo
ool0Goooo`03o`2Ioooooooo023oool008ooool00`0003?o03?o0009<ol000<0003oooooool0Gooo
o`03o`2Ioooooooo023oool008ooool200002S?o00030000oooooooo05ooool00ol0VOooooooo`0P
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo05ooool00ol0VOooooooo`0Poooo002?
oooo00<0000co`0co`002C?o00030000oooooooo05ooool00ol0VOooooooo`0Poooo002?oooo00<0
000co`0co`0023?o00030000oooooooo063oool00ol0VOooooooo`0Poooo0028oooo0P0000Goool0
0`0003?o03?o0008<ol000<0003oooooool0H?ooo`03o`2Ioooooooo023oool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0H?ooo`03o`2Ioooooooo023oool0
08Woool00`000?ooooooo`03oooo0`0000Pco`000`000?ooooooo`1Poooo00?o09Woooooool08?oo
o`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0H?ooo`03o`2I
oooooooo023oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003ooooo
ool0H?ooo`03o`2Ioooooooo023oool008Soool200001Oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1Qoooo00?o09Woooooool08?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1Q
oooo00?o09Woooooool08?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1Qoooo00?o
09Woooooool08?ooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1Qoooo00?o09Wooooo
ool08?ooo`00Soooo`800008<ol000<0003oooooool0HOooo`03o`2Ioooooooo023oool008ooool0
0`0003?o03?o0007<ol000<0003oooooool0HOooo`03o`2Ioooooooo023oool008ooool00`0003?o
03?o0007<ol000<0003oooooool0HOooo`03o`2Ioooooooo023oool008ooool00`0003?o03?o0007
<ol000<0003oooooool0HOooo`03o`2Ioooooooo023oool008ooool00`0003?o03?o0006<ol000<0
003oooooool0H_ooo`03o`2Ioooooooo023oool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool0H_ooo`03o`2Ioooooooo023oool008ooool200001c?o00030000oooooooo06;oool00ol0VOoo
ooooo`0Poooo002?oooo00<0000co`0co`001S?o00030000oooooooo06;oool00ol0VOooooooo`0P
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo06;oool00ol0VOooooooo`0Poooo002?
oooo00<0000co`0co`001S?o00030000oooooooo06;oool00ol0VOooooooo`0Poooo002?oooo00<0
000co`0co`001S?o00030000oooooooo06;oool00ol0VOooooooo`0Poooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo06;oool00ol0VOooooooo`0Poooo002?oooo0P0000Hco`000`000?oo
ooooo`1Soooo00?o09Woooooool08?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1S
oooo00?o09Woooooool08?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Soooo00?o
09Woooooool08?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Soooo00?o09Wooooo
ool08?ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Soooo00?o09Woooooool08?oo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Soooo00?o09Woooooool08?ooo`00Sooo
o`800006<ol000<0003oooooool0Hoooo`03o`2Ioooooooo023oool008ooool00`0003?o03?o0005
<ol000<0003oooooool0Hoooo`03o`2Ioooooooo023oool008ooool00`0003?o03?o0005<ol000<0
003oooooool0Hoooo`03o`2Ioooooooo023oool008ooool00`0003?o03?o0004<ol000<0003ooooo
ool0I?ooo`03o`2Ioooooooo023oool008ooool00`0003?o03?o0004<ol000<0003oooooool0I?oo
o`03o`2Ioooooooo023oool008Woool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`1T
oooo00?o09Woooooool08?ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0
003oooooool0I?ooo`03o`2Ioooooooo023oool008Ooool500000oooo`<00004<ol000<0003ooooo
ool0I?ooo`03o`2Ioooooooo023oool008Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?oo
o`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_oo
o`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>oooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o00ooool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003<ol00P00
0004<ol0oooooooooooo0P0000?oool400000oooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`07
<ol00_ooo`040000oooooooo00000_ooo`030000oooooooo00Coool00`000?ooooooo`1hoooo001g
oooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?oooc?o0006<ol00_ooo`040000
oooooooo00000oooo`030000oooooooo00Coool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0000koool00`0003?o03?o0005<ol00oooo`800005oooo00<0003oooooool00_ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003oooooool00006<ol00_oo
o`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Aoooo0P0000Lco`03oooo0P0000Coool200000oooo`030000oooooooo07Woool0
08ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.84) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.91765 .12361 L
.92769 .12361 L
.93044 .12361 L
.93339 .12361 L
.93482 .12361 L
.93618 .12361 L
.93739 .12361 L
s
.93739 .12361 m
.93792 .61803 L
s
0 .4 1 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.05288 .12361 L
.05546 .12361 L
.05789 .12361 L
.06007 .12361 L
.06131 .12361 L
.06244 .12305 L
.06371 .12175 L
.06487 .12059 L
.06747 .11803 L
.07218 .11361 L
.0829 .1045 L
.10458 .0897 L
.12357 .08007 L
.13443 .07574 L
.14429 .07245 L
.16396 .06747 L
.17476 .06551 L
.18493 .0641 L
.1947 .0631 L
.19961 .06272 L
.20501 .06238 L
.20962 .06216 L
.21216 .06206 L
.21457 .06198 L
.2168 .06192 L
.21923 .06187 L
.2203 .06185 L
.22144 .06184 L
.2225 .06183 L
.22348 .06182 L
.22462 .06181 L
.22587 .0618 L
.22708 .0618 L
.22837 .06181 L
.22958 .06181 L
.23072 .06182 L
.23174 .06183 L
.23285 .06184 L
.23541 .06188 L
.23811 .06193 L
.24296 .06206 L
.24745 .06222 L
.25166 .0624 L
.26124 .06292 L
.28152 .0644 L
.30006 .06612 L
Mistroke
.33982 .07061 L
.37807 .07545 L
.41876 .08072 L
.45794 .08564 L
.47796 .08804 L
.48848 .08927 L
.49958 .09053 L
.5044 .09103 L
.50955 .09145 L
.51251 .09164 L
.51521 .09179 L
.51795 .09192 L
.52049 .09201 L
.52274 .09208 L
.52522 .09214 L
.52771 .09218 L
.52908 .0922 L
.53036 .09221 L
.5315 .09222 L
.53271 .09222 L
.53373 .09222 L
.53486 .09222 L
.53607 .09221 L
.53737 .0922 L
.53859 .09219 L
.5397 .09217 L
.54202 .09214 L
.54456 .09208 L
.54971 .09194 L
.55447 .09176 L
.55892 .09156 L
.57973 .09026 L
.60006 .08851 L
.61861 .08656 L
.65842 .08149 L
.69672 .07565 L
.73747 .06858 L
.7767 .06108 L
.81442 .0534 L
.85459 .04499 L
.89325 .03712 L
.91287 .03342 L
.92325 .0316 L
.92896 .03064 L
.93177 .03019 L
.93435 .02978 L
.93565 .02958 L
.93686 .02939 L
.93812 .12361 L
.93879 .12361 L
Mistroke
.9395 .12361 L
.94509 .12361 L
.95486 .12361 L
.97395 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.84) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`1Xoooo1@1Vob7oool0
08ooool00`000?ooooooo`1Ooooo2@1Vo`Coool00`1Vooooooooo`0Ooooo002?oooo00<0003ooooo
ool0F_ooo`D0I_l=oooo00<0I_ooooooool07oooo`00Soooo`030000oooooooo05Koool406Ko4_oo
o`0306Kooooooooo01ooool008ooool00`000?ooooooo`1Coooo0`1VoaKoool00`1Vooooooooo`0O
oooo002?oooo0P00053oool406Ko6Oooo`0306Kooooooooo01ooool008ooool00`000?ooooooo`1;
oooo101Voagoool00`1Vooooooooo`0Ooooo002?oooo00<0003oooooool0A_ooo`D0I_lQoooo00<0
I_ooooooool07oooo`00?ooooa/0I_leoooo00<0003oooooool0?oooo`L0I_lVoooo00<0I_oooooo
ool07oooo`00>?ooo`L0I_lKoooo1`1Vobkoool00`000?ooooooo`0goooo201Vobgoool00`1Voooo
ooooo`0Ooooo000doooo101VobWoool:06Ko9?ooo`030000oooooooo03;oool506Ko=Oooo`0306Ko
oooooooo01ooool003;oool206Ko=oooo`P0I_lLoooo0P0002koool506Ko>_ooo`0306Kooooooooo
01ooool001Ooool400005Oooo`80I_lRoooo1@0001[oool506Ko5oooo`030000oooooooo02Soool5
06Ko2_ooo`D0000`oooo00<0I_ooooooool01Oooo`@0000Foooo000Goooo00<0003oooooool05?oo
o`80I_lVoooo00<0003oooooool07oooo`L0I_l@oooo00<0003oooooool08Oooo`L0I_lAoooo00<0
003oooooool0<?ooo`0306Kooooooooo00Goool00`000?ooooooo`0Goooo000Hoooo00<0003ooooo
ool04Oooo`80I_lXoooo00<0003oooooool09_ooo``0I_l4oooo00<0003oooooool06Oooo`P0I_lH
oooo00<0003oooooool0<?ooo`0306Kooooooooo00Koool00`000?ooooooo`0Foooo000Aoooo1000
00Coool00`000?ooooooo`0?oooo00<0I_ooooooool08?ooo`@00004oooo00<0003oooooool0<_oo
o`@0I_l00`00001Vo`1Vo`0I06Ko8?ooo`030000oooooooo033oool00`1Vooooooooo`07oooo00<0
003oooooool05Oooo`005oooo`040000oooooooo00003_ooo`80I_l[oooo00<0003oooooool0=_oo
o`030000oooooooo03Woool00`000?ooooooo`0`oooo00<0I_ooooooool01Oooo`040000oooooooo
00005_ooo`006?ooo`80000>oooo00<0I_ooooooool0:_ooo`80000hoooo0P0003Woool20000<_oo
o`0306Kooooooooo00Koool200005oooo`009_ooo`80I_mWoooo00<0003oooooool0K?ooo`0306Ko
oooooooo01ooool002Goool00`1Vooooooooo`1Woooo00<0003oooooool0K?ooo`0306Kooooooooo
01ooool002?oool206KoJ_ooo`030000oooooooo06coool00`1Vooooooooo`0Ooooo000Roooo00<0
I_ooooooool0J_ooo`030000oooooooo06coool00`1Vooooooooo`0Ooooo000Qoooo00<0I_oooooo
ool0Joooo`030000oooooooo06coool00`1Vooooooooo`0Ooooo000@ooooo`00017oool001Koool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0006<ol08P0000Koool00`000?ooool0V@09oooo00<0003oooooool05Oooo`005_oo
o`030000oooooooo03[oool00`000?ooooooo`0ioooo00<0000co`0co`00>C?o00T0000Zoooo00?o
09Woooooool01oooo`030000oooooooo01Goool008ooool00`0003?o03?o000c<ol01P0003?oool0
0ol0VOooooooo`0Ooooo002?oooo00<0000co`0co`00<C?o0080000ioooo00?o09Woooooool07ooo
o`00Soooo`030000<ol0<ol002lco`020000>oooo`03o`2Ioooooooo01ooool008ooool00`0003?o
03?o000/<ol00`0003goool00ol0VOooooooo`0Ooooo002?oooo0P0002Xco`030000@?ooo`03o`2I
oooooooo01ooool008ooool00`0003?o03?o000W<ol00P0004?oool00ol0VOooooooo`0Ooooo002?
oooo00<0000co`0co`009S?o00030000oooooooo04?oool00ol0VOooooooo`0Ooooo002?oooo00<0
000co`0co`009C?o00030000oooooooo04Coool00ol0VOooooooo`0Ooooo002?oooo00<0000co`0c
o`0093?o00030000oooooooo04Goool00ol0VOooooooo`0Ooooo002?oooo00<0000co`0co`008S?o
00800018oooo00?o09Woooooool07oooo`00Soooo`80000R<ol000<0003oooooool0B?ooo`03o`2I
oooooooo01ooool008ooool00`0003?o03?o000P<ol000<0003oooooool0BOooo`03o`2Ioooooooo
01ooool008ooool00`0003?o03?o000O<ol000<0003oooooool0B_ooo`03o`2Ioooooooo01ooool0
08ooool00`0003?o03?o000O<ol000<0003oooooool0B_ooo`03o`2Ioooooooo01ooool008ooool0
0`0003?o03?o000N<ol000<0003oooooool0Boooo`03o`2Ioooooooo01ooool008ooool00`0003?o
03?o000M<ol000<0003oooooool0C?ooo`03o`2Ioooooooo01ooool008ooool200007C?o00030000
oooooooo04goool00ol0VOooooooo`0Ooooo002?oooo00<0000co`0co`006c?o00030000oooooooo
04koool00ol0VOooooooo`0Ooooo002?oooo00<0000co`0co`006c?o00030000oooooooo04koool0
0ol0VOooooooo`0Ooooo002?oooo00<0000co`0co`006S?o00030000oooooooo04ooool00ol0VOoo
ooooo`0Ooooo002?oooo00<0000co`0co`006S?o00030000oooooooo04ooool00ol0VOooooooo`0O
oooo002?oooo00<0000co`0co`006C?o00030000oooooooo053oool00ol0VOooooooo`0Ooooo002?
oooo0P0001Xco`000`000?ooooooo`1@oooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol0
01Pco`000`000?ooooooo`1Aoooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol001Pco`00
0`000?ooooooo`1Aoooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol001Lco`000`000?oo
ooooo`1Boooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol001Lco`000`000?ooooooo`1B
oooo00?o09Woooooool07oooo`00Qoooo`D00003oooo00<0000co`0co`005S?o00030000oooooooo
05?oool00ol0VOooooooo`0Ooooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Hco`00
0`000?ooooooo`1Coooo00?o09Woooooool07oooo`00ROooo`030000oooooooo00?oool300005C?o
00030000oooooooo05Coool00ol0VOooooooo`0Ooooo0029oooo00<0003oooooool00oooo`030000
<ol0<ol001Dco`000`000?ooooooo`1Doooo00?o09Woooooool07oooo`00ROooo`030000oooooooo
00?oool00`0003?o03?o000E<ol000<0003oooooool0E?ooo`03o`2Ioooooooo01ooool008Soool2
00001Oooo`030000<ol0<ol001@co`000`000?ooooooo`1Eoooo00?o09Woooooool07oooo`00Sooo
o`030000<ol0<ol001@co`000`000?ooooooo`1Eoooo00?o09Woooooool07oooo`00Soooo`030000
<ol0<ol001<co`000`000?ooooooo`1Foooo00?o09Woooooool07oooo`00Soooo`80000D<ol000<0
003oooooool0E_ooo`03o`2Ioooooooo01ooool008ooool00`0003?o03?o000C<ol000<0003ooooo
ool0E_ooo`03o`2Ioooooooo01ooool008ooool00`0003?o03?o000B<ol000<0003oooooool0Eooo
o`03o`2Ioooooooo01ooool008ooool00`0003?o03?o000B<ol000<0003oooooool0Eoooo`03o`2I
oooooooo01ooool008ooool00`0003?o03?o000B<ol000<0003oooooool0Eoooo`03o`2Ioooooooo
01ooool008ooool00`0003?o03?o000A<ol000<0003oooooool0F?ooo`03o`2Ioooooooo01ooool0
08ooool200004S?o00030000oooooooo05Soool00ol0VOooooooo`0Ooooo002?oooo00<0000co`0c
o`004C?o00030000oooooooo05Soool00ol0VOooooooo`0Ooooo002?oooo00<0000co`0co`004C?o
00030000oooooooo05Soool00ol0VOooooooo`0Ooooo002?oooo00<0000co`0co`0043?o00030000
oooooooo05Woool00ol0VOooooooo`0Ooooo002?oooo00<0000co`0co`0043?o00030000oooooooo
05Woool00ol0VOooooooo`0Ooooo002?oooo00<0000co`0co`0043?o00030000oooooooo05Woool0
0ol0VOooooooo`0Ooooo002?oooo00<0000co`0co`0043?o00030000oooooooo05Woool00ol0VOoo
ooooo`0Ooooo002?oooo0P00010co`000`000?ooooooo`1Joooo00?o09Woooooool07oooo`00Sooo
o`030000<ol0<ol000lco`000`000?ooooooo`1Joooo00?o09Woooooool07oooo`00Soooo`030000
<ol0<ol000lco`000`000?ooooooo`1Joooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol0
00lco`000`000?ooooooo`1Joooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol000lco`00
0`000?ooooooo`1Joooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol000hco`000`000?oo
ooooo`1Koooo00?o09Woooooool07oooo`00Soooo`80000?<ol000<0003oooooool0Foooo`03o`2I
oooooooo01ooool008ooool00`0003?o03?o000><ol000<0003oooooool0Foooo`03o`2Ioooooooo
01ooool008ooool00`0003?o03?o000><ol000<0003oooooool0Foooo`03o`2Ioooooooo01ooool0
08ooool00`0003?o03?o000=<ol000<0003oooooool0G?ooo`03o`2Ioooooooo01ooool008Ooool4
00001?ooo`030000<ol0<ol000dco`000`000?ooooooo`1Loooo00?o09Woooooool07oooo`00Qooo
o`030000oooooooo00Goool00`0003?o03?o000=<ol000<0003oooooool0G?ooo`03o`2Ioooooooo
01ooool008Soool00`000?ooooooo`04oooo0`0000dco`000`000?ooooooo`1Loooo00?o09Wooooo
ool07oooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000=<ol000<0003oooooool0G?oo
o`03o`2Ioooooooo01ooool008Ooool010000?ooooooo`0000Coool00`0003?o03?o000<<ol000<0
003oooooool0GOooo`03o`2Ioooooooo01ooool008Soool200001Oooo`030000<ol0<ol000`co`00
0`000?ooooooo`1Moooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol000`co`000`000?oo
ooooo`1Moooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol000`co`000`000?ooooooo`1M
oooo00?o09Woooooool07oooo`00Soooo`80000=<ol000<0003oooooool0GOooo`03o`2Ioooooooo
01ooool008ooool00`0003?o03?o000<<ol000<0003oooooool0GOooo`03o`2Ioooooooo01ooool0
08ooool00`0003?o03?o000;<ol000<0003oooooool0G_ooo`03o`2Ioooooooo01ooool008ooool0
0`0003?o03?o000;<ol000<0003oooooool0G_ooo`03o`2Ioooooooo01ooool008ooool00`0003?o
03?o000;<ol000<0003oooooool0G_ooo`03o`2Ioooooooo01ooool008ooool00`0003?o03?o000;
<ol000<0003oooooool0G_ooo`03o`2Ioooooooo01ooool008ooool00`0003?o03?o000;<ol000<0
003oooooool0G_ooo`03o`2Ioooooooo01ooool008ooool2000033?o00030000oooooooo05koool0
0ol0VOooooooo`0Ooooo002?oooo00<0000co`0co`002c?o00030000oooooooo05koool00ol0VOoo
ooooo`0Ooooo002?oooo00<0000co`0co`002S?o00030000oooooooo05ooool00ol0VOooooooo`0O
oooo002?oooo00<0000co`0co`002S?o00030000oooooooo05ooool00ol0VOooooooo`0Ooooo002?
oooo00<0000co`0co`002S?o00030000oooooooo05ooool00ol0VOooooooo`0Ooooo002?oooo00<0
000co`0co`002S?o00030000oooooooo05ooool00ol0VOooooooo`0Ooooo002?oooo0P0000/co`00
0`000?ooooooo`1Ooooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`1Ooooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1O
oooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1Poooo00?o
09Woooooool07oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1Poooo00?o09Wooooo
ool07oooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1Poooo00?o09Woooooool07ooo
o`00Soooo`80000:<ol000<0003oooooool0H?ooo`03o`2Ioooooooo01ooool008ooool00`0003?o
03?o0009<ol000<0003oooooool0H?ooo`03o`2Ioooooooo01ooool008ooool00`0003?o03?o0009
<ol000<0003oooooool0H?ooo`03o`2Ioooooooo01ooool008ooool00`0003?o03?o0008<ol000<0
003oooooool0HOooo`03o`2Ioooooooo01ooool008Soool200001Oooo`030000<ol0<ol000Pco`00
0`000?ooooooo`1Qoooo00?o09Woooooool07oooo`00Qoooo`040000oooooooo00001?ooo`030000
<ol0<ol000Pco`000`000?ooooooo`1Qoooo00?o09Woooooool07oooo`00ROooo`030000oooooooo
00?oool3000023?o00030000oooooooo067oool00ol0VOooooooo`0Ooooo002:oooo00<0003ooooo
ool00_ooo`030000<ol0<ol000Pco`000`000?ooooooo`1Qoooo00?o09Woooooool07oooo`00Qooo
o`040000oooooooo00001?ooo`030000<ol0<ol000Pco`000`000?ooooooo`1Qoooo00?o09Wooooo
ool07oooo`00R?ooo`800005oooo00<0000co`0co`001c?o00030000oooooooo06;oool00ol0VOoo
ooooo`0Ooooo002?oooo00<0000co`0co`001c?o00030000oooooooo06;oool00ol0VOooooooo`0O
oooo002?oooo00<0000co`0co`001c?o00030000oooooooo06;oool00ol0VOooooooo`0Ooooo002?
oooo00<0000co`0co`001c?o00030000oooooooo06;oool00ol0VOooooooo`0Ooooo002?oooo0P00
00Pco`000`000?ooooooo`1Roooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`1Roooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1Roooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1R
oooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Soooo00?o
09Woooooool07oooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Soooo00?o09Wooooo
ool07oooo`00Soooo`800007<ol000<0003oooooool0Hoooo`03o`2Ioooooooo01ooool008ooool0
0`0003?o03?o0006<ol000<0003oooooool0Hoooo`03o`2Ioooooooo01ooool008ooool00`0003?o
03?o0006<ol000<0003oooooool0Hoooo`03o`2Ioooooooo01ooool008ooool00`0003?o03?o0006
<ol000<0003oooooool0Hoooo`03o`2Ioooooooo01ooool008ooool00`0003?o03?o0006<ol000<0
003oooooool0Hoooo`03o`2Ioooooooo01ooool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool0Hoooo`03o`2Ioooooooo01ooool008ooool200001S?o00030000oooooooo06Coool00ol0VOoo
ooooo`0Ooooo002?oooo00<0000co`0co`001C?o00030000oooooooo06Coool00ol0VOooooooo`0O
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo06Coool00ol0VOooooooo`0Ooooo002?
oooo00<0000co`0co`001C?o00030000oooooooo06Coool00ol0VOooooooo`0Ooooo002?oooo00<0
000co`0co`001C?o00030000oooooooo06Coool00ol0VOooooooo`0Ooooo002?oooo00<0000co`0c
o`001C?o00030000oooooooo06Coool00ol0VOooooooo`0Ooooo002?oooo0P0000Hco`000`000?oo
ooooo`1Toooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1T
oooo00?o09Woooooool07oooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Toooo00?o
09Woooooool07oooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`1Uoooo00?o09Wooooo
ool07oooo`00Soooo`030000<ol0<ol000@co`000`000?ooooooo`1Uoooo00?o09Woooooool07ooo
o`00ROooo`<00003oooo00<0000co`0co`0013?o00030000oooooooo06Goool00ol0VOooooooo`0O
oooo002:oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`000`000?ooooooo`1Uoooo00?o
09Woooooool07oooo`00Qoooo`D00003oooo0`0000@co`000`000?ooooooo`1Uoooo00?o09Wooooo
ool07oooo`00Qoooo`040000oooooooo00001?ooo`Lco`2:oooo0028oooo00<0003oool000001?oo
o`Lco`2:oooo0029oooo0P0000Coool7<ol0R_ooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool0
07Woool00`000?ooooooo`0Coooo1c?o00koool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo00Woool7<ol03oooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000<co`02000000@co`3oooooooooool2
00001Oooo`<00002oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00Lco`02oooo00@0003ooooo
ool00005oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0>oooo00<0003ooolco`001S?o00;oool010000?ooooooo`0000;oool500000oooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000<ol0<ol000Dco`03oooo0P00
00?oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00003oooo`040000oooooooo00001S?o00;oool010000?ooooooo`0000?oool00`000?ooo`000003
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200001c?o00?oool200001Ooo
o`800002oooo00<0003oooooool0NOooo`00Soooo`Lco`2:oooo002?oooo1c?o08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.86) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.91726 .12361 L
.92761 .12361 L
.93331 .12361 L
.93612 .12361 L
.93871 .12361 L
.94107 .12361 L
.94226 .12361 L
s
.94226 .12361 m
.94278 .61803 L
s
0 .4 1 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.0503 .12361 L
.05288 .12361 L
.05528 .12361 L
.05594 .12361 L
.05664 .12361 L
.05789 .12284 L
.05901 .12169 L
.06006 .12064 L
.06244 .11828 L
.08445 .09972 L
.10458 .08702 L
.12446 .07772 L
.14335 .07132 L
.15294 .06884 L
.16316 .06669 L
.17273 .0651 L
.18154 .06394 L
.19183 .06295 L
.19724 .06256 L
.20296 .06224 L
.20536 .06213 L
.20793 .06204 L
.21015 .06197 L
.21257 .06191 L
.21404 .06188 L
.21541 .06185 L
.21668 .06184 L
.21809 .06182 L
.21935 .06181 L
.22053 .06181 L
.22178 .0618 L
.22248 .0618 L
.22313 .0618 L
.2244 .06181 L
.22561 .06182 L
.22669 .06183 L
.22787 .06184 L
.2305 .06188 L
.23293 .06192 L
.23736 .06204 L
.24205 .0622 L
.25191 .06266 L
.26275 .06332 L
.2822 .06487 L
.30309 .06693 L
.34437 .07176 L
Mistroke
.38413 .07685 L
.42237 .08179 L
.46307 .08684 L
.48191 .08906 L
.49181 .09019 L
.50225 .09135 L
.50759 .09183 L
.51343 .09222 L
.516 .09235 L
.51875 .09247 L
.52132 .09256 L
.5237 .09263 L
.52631 .09268 L
.52768 .0927 L
.52913 .09272 L
.53039 .09273 L
.53158 .09274 L
.53287 .09274 L
.5336 .09274 L
.53427 .09274 L
.53543 .09274 L
.53651 .09273 L
.53769 .09272 L
.53896 .09271 L
.54154 .09267 L
.54389 .09263 L
.54875 .0925 L
.5539 .09232 L
.56311 .0919 L
.57303 .0913 L
.58392 .09051 L
.62431 .08655 L
.66319 .08153 L
.70452 .07517 L
.74433 .0682 L
.78263 .06085 L
.82338 .05252 L
.86261 .0443 L
.90033 .03667 L
.92128 .03276 L
.93046 .03118 L
.93531 .03038 L
.93798 .02996 L
.9405 .02956 L
.9416 .02939 L
.94276 .02921 L
.94404 .12361 L
.94521 .12361 L
.9495 .12361 L
.95788 .12361 L
Mistroke
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.86) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo06goool00`1Vooooooooo`0Noooo002?oooo00<0003ooooo
ool0I_ooo`P0I_lPoooo002?oooo00<0003oooooool0H?ooo`H0I_l7oooo00<0I_ooooooool07_oo
o`00Soooo`030000oooooooo05coool406Ko3Oooo`0306Kooooooooo01koool008ooool00`000?oo
ooooo`1Goooo1@1Voa7oool00`1Vooooooooo`0Noooo002?oooo00<0003oooooool0D_ooo`D0I_lF
oooo00<0I_ooooooool07_ooo`00Soooo`80001>oooo1@1Voa_oool00`1Vooooooooo`0Noooo002?
oooo00<0003oooooool0B?ooo`D0I_lPoooo00<0I_ooooooool07_ooo`00Soooo`030000oooooooo
04?oool506Ko9Oooo`0306Kooooooooo01koool003kooolH06Ko>Oooo`030000oooooooo03koool5
06Ko:_ooo`0306Kooooooooo01koool003Woool506Ko6?ooo`d0I_l/oooo00<0003oooooool0>Ooo
o`D0I_l_oooo00<0I_ooooooool07_ooo`00=?ooo`D0I_lZoooo201VobCoool00`000?ooooooo`0d
oooo1@1VocCoool00`1Vooooooooo`0Noooo000boooo0P1VocOoool506Ko7oooo`80000`oooo1@1V
ocWoool00`1Vooooooooo`0Noooo000Goooo100001Coool306Ko8_ooo`D0000Goooo1`1VoaSoool0
0`000?ooooooo`0Yoooo1P1Vo`Soool50000<_ooo`0306Kooooooooo00?oool400005_ooo`005ooo
o`030000oooooooo01?oool206Ko9oooo`030000oooooooo01koool:06Ko3_ooo`030000oooooooo
02;oool706Ko4?ooo`030000oooooooo03;oool00`1Vooooooooo`03oooo00<0003oooooool05ooo
o`006?ooo`030000oooooooo013oool206Ko:Oooo`030000oooooooo02Soool706Ko1oooo`030000
oooooooo01Soool:06Ko5oooo`030000oooooooo03;oool00`1Vooooooooo`04oooo00<0003ooooo
ool05_ooo`004Oooo`@00004oooo00<0003oooooool03Oooo`80I_lSoooo100000Coool00`000?oo
ooooo`0_oooo1`1Vo`03000006Ko06Ko0080I_l9oooo3@1Vob7oool00`000?ooooooo`0boooo00<0
I_ooooooool01Oooo`030000oooooooo01Goool001Ooool010000?ooooooo`0000coool206Ko;Ooo
o`030000oooooooo03Koool00`000?ooooooo`02oooo2@1Vobkoool00`000?ooooooo`0boooo00<0
I_ooooooool00oooo`040000oooooooo00005_ooo`006?ooo`80000<oooo00<0I_ooooooool0;?oo
o`80000hoooo0P0003Woool20000=?ooo`0306Kooooooooo00Coool200005oooo`009Oooo`0306Ko
oooooooo06Ooool00`000?ooooooo`1^oooo00<0I_ooooooool07Oooo`009?ooo`0306Kooooooooo
06Soool00`000?ooooooo`1^oooo00<0I_ooooooool07Oooo`008_ooo`80I_m[oooo00<0003ooooo
ool0K_ooo`0306Kooooooooo01goool0027oool00`1Vooooooooo`1[oooo00<0003oooooool0K_oo
o`0306Kooooooooo01goool0023oool00`1Vooooooooo`1/oooo00<0003oooooool0K_ooo`0306Ko
oooooooo01goool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`040000
ooooooooo`2I2?ooo`030000oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003ooooo
ool0>Oooo`030000<ol0<ol003Tco`090000:oooo`03o`2Ioooooooo00Koool00`000?ooooooo`0E
oooo002?oooo00<0000co`0co`00<c?o00H0000doooo00?o09Woooooool07_ooo`00Soooo`030000
<ol0<ol0034co`020000>_ooo`03o`2Ioooooooo01koool008ooool00`0003?o03?o000_<ol00P00
03coool00ol0VOooooooo`0Noooo002?oooo00<0000co`0co`00;3?o00<0000noooo00?o09Wooooo
ool07_ooo`00Soooo`80000Z<ol00`00047oool00ol0VOooooooo`0Noooo002?oooo00<0000co`0c
o`009c?o00800014oooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol002Hco`000`000?oo
ooooo`14oooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol002Dco`000`000?ooooooo`15
oooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol002@co`000`000?ooooooo`16oooo00?o
09Woooooool07_ooo`00Soooo`030000<ol0<ol0028co`020000BOooo`03o`2Ioooooooo01koool0
08ooool200008S?o00030000oooooooo04Woool00ol0VOooooooo`0Noooo002?oooo00<0000co`0c
o`0083?o00030000oooooooo04[oool00ol0VOooooooo`0Noooo002?oooo00<0000co`0co`007c?o
00030000oooooooo04_oool00ol0VOooooooo`0Noooo002?oooo00<0000co`0co`007c?o00030000
oooooooo04_oool00ol0VOooooooo`0Noooo002?oooo00<0000co`0co`007S?o00030000oooooooo
04coool00ol0VOooooooo`0Noooo002?oooo00<0000co`0co`007C?o00030000oooooooo04goool0
0ol0VOooooooo`0Noooo002?oooo0P0001dco`000`000?ooooooo`1>oooo00?o09Woooooool07_oo
o`00Soooo`030000<ol0<ol001/co`000`000?ooooooo`1?oooo00?o09Woooooool07_ooo`00Sooo
o`030000<ol0<ol001/co`000`000?ooooooo`1?oooo00?o09Woooooool07_ooo`00Soooo`030000
<ol0<ol001Xco`000`000?ooooooo`1@oooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol0
01Xco`000`000?ooooooo`1@oooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol001Tco`00
0`000?ooooooo`1Aoooo00?o09Woooooool07_ooo`00Soooo`80000J<ol000<0003oooooool0DOoo
o`03o`2Ioooooooo01koool008ooool00`0003?o03?o000H<ol000<0003oooooool0D_ooo`03o`2I
oooooooo01koool008ooool00`0003?o03?o000H<ol000<0003oooooool0D_ooo`03o`2Ioooooooo
01koool008ooool00`0003?o03?o000G<ol000<0003oooooool0Doooo`03o`2Ioooooooo01koool0
08ooool00`0003?o03?o000G<ol000<0003oooooool0Doooo`03o`2Ioooooooo01koool008Ooool5
00000oooo`030000<ol0<ol001Hco`000`000?ooooooo`1Doooo00?o09Woooooool07_ooo`00ROoo
o`030000oooooooo00?oool00`0003?o03?o000F<ol000<0003oooooool0E?ooo`03o`2Ioooooooo
01koool008Woool00`000?ooooooo`03oooo0`0001Dco`000`000?ooooooo`1Eoooo00?o09Wooooo
ool07_ooo`00ROooo`030000oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool0EOoo
o`03o`2Ioooooooo01koool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000
oooooooo05Goool00ol0VOooooooo`0Noooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0
003oooooool0E_ooo`03o`2Ioooooooo01koool008ooool00`0003?o03?o000D<ol000<0003ooooo
ool0E_ooo`03o`2Ioooooooo01koool008ooool00`0003?o03?o000C<ol000<0003oooooool0Eooo
o`03o`2Ioooooooo01koool008ooool2000053?o00030000oooooooo05Ooool00ol0VOooooooo`0N
oooo002?oooo00<0000co`0co`004c?o00030000oooooooo05Ooool00ol0VOooooooo`0Noooo002?
oooo00<0000co`0co`004S?o00030000oooooooo05Soool00ol0VOooooooo`0Noooo002?oooo00<0
000co`0co`004S?o00030000oooooooo05Soool00ol0VOooooooo`0Noooo002?oooo00<0000co`0c
o`004S?o00030000oooooooo05Soool00ol0VOooooooo`0Noooo002?oooo00<0000co`0co`004C?o
00030000oooooooo05Woool00ol0VOooooooo`0Noooo002?oooo0P00018co`000`000?ooooooo`1I
oooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`1Ioooo00?o
09Woooooool07_ooo`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`1Ioooo00?o09Wooooo
ool07_ooo`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`1Joooo00?o09Woooooool07_oo
o`00Soooo`030000<ol0<ol0010co`000`000?ooooooo`1Joooo00?o09Woooooool07_ooo`00Sooo
o`030000<ol0<ol0010co`000`000?ooooooo`1Joooo00?o09Woooooool07_ooo`00Soooo`030000
<ol0<ol0010co`000`000?ooooooo`1Joooo00?o09Woooooool07_ooo`00Soooo`80000@<ol000<0
003oooooool0Foooo`03o`2Ioooooooo01koool008ooool00`0003?o03?o000?<ol000<0003ooooo
ool0Foooo`03o`2Ioooooooo01koool008ooool00`0003?o03?o000?<ol000<0003oooooool0Fooo
o`03o`2Ioooooooo01koool008ooool00`0003?o03?o000?<ol000<0003oooooool0Foooo`03o`2I
oooooooo01koool008ooool00`0003?o03?o000?<ol000<0003oooooool0Foooo`03o`2Ioooooooo
01koool008ooool00`0003?o03?o000><ol000<0003oooooool0G?ooo`03o`2Ioooooooo01koool0
08ooool200003c?o00030000oooooooo05coool00ol0VOooooooo`0Noooo002?oooo00<0000co`0c
o`003S?o00030000oooooooo05coool00ol0VOooooooo`0Noooo002?oooo00<0000co`0co`003S?o
00030000oooooooo05coool00ol0VOooooooo`0Noooo002?oooo00<0000co`0co`003C?o00030000
oooooooo05goool00ol0VOooooooo`0Noooo0027oooo100000Coool00`0003?o03?o000=<ol000<0
003oooooool0GOooo`03o`2Ioooooooo01koool008Ooool00`000?ooooooo`05oooo00<0000co`0c
o`003C?o00030000oooooooo05goool00ol0VOooooooo`0Noooo0028oooo00<0003oooooool01?oo
o`<0000=<ol000<0003oooooool0GOooo`03o`2Ioooooooo01koool008Woool00`000?ooooooo`03
oooo00<0000co`0co`003C?o00030000oooooooo05goool00ol0VOooooooo`0Noooo0027oooo00@0
003oooooool00004oooo00<0000co`0co`0033?o00030000oooooooo05koool00ol0VOooooooo`0N
oooo0028oooo0P0000Goool00`0003?o03?o000<<ol000<0003oooooool0G_ooo`03o`2Ioooooooo
01koool008ooool00`0003?o03?o000<<ol000<0003oooooool0G_ooo`03o`2Ioooooooo01koool0
08ooool00`0003?o03?o000<<ol000<0003oooooool0G_ooo`03o`2Ioooooooo01koool008ooool2
00003C?o00030000oooooooo05koool00ol0VOooooooo`0Noooo002?oooo00<0000co`0co`0033?o
00030000oooooooo05koool00ol0VOooooooo`0Noooo002?oooo00<0000co`0co`002c?o00030000
oooooooo05ooool00ol0VOooooooo`0Noooo002?oooo00<0000co`0co`002c?o00030000oooooooo
05ooool00ol0VOooooooo`0Noooo002?oooo00<0000co`0co`002c?o00030000oooooooo05ooool0
0ol0VOooooooo`0Noooo002?oooo00<0000co`0co`002c?o00030000oooooooo05ooool00ol0VOoo
ooooo`0Noooo002?oooo00<0000co`0co`002c?o00030000oooooooo05ooool00ol0VOooooooo`0N
oooo002?oooo0P0000`co`000`000?ooooooo`1Ooooo00?o09Woooooool07_ooo`00Soooo`030000
<ol0<ol000/co`000`000?ooooooo`1Ooooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol0
00Xco`000`000?ooooooo`1Poooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol000Xco`00
0`000?ooooooo`1Poooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol000Xco`000`000?oo
ooooo`1Poooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1P
oooo00?o09Woooooool07_ooo`00Soooo`80000;<ol000<0003oooooool0H?ooo`03o`2Ioooooooo
01koool008ooool00`0003?o03?o000:<ol000<0003oooooool0H?ooo`03o`2Ioooooooo01koool0
08ooool00`0003?o03?o000:<ol000<0003oooooool0H?ooo`03o`2Ioooooooo01koool008ooool0
0`0003?o03?o0009<ol000<0003oooooool0HOooo`03o`2Ioooooooo01koool008ooool00`0003?o
03?o0009<ol000<0003oooooool0HOooo`03o`2Ioooooooo01koool008ooool00`0003?o03?o0009
<ol000<0003oooooool0HOooo`03o`2Ioooooooo01koool008ooool200002S?o00030000oooooooo
067oool00ol0VOooooooo`0Noooo002?oooo00<0000co`0co`002C?o00030000oooooooo067oool0
0ol0VOooooooo`0Noooo002?oooo00<0000co`0co`002C?o00030000oooooooo067oool00ol0VOoo
ooooo`0Noooo002?oooo00<0000co`0co`0023?o00030000oooooooo06;oool00ol0VOooooooo`0N
oooo0028oooo0P0000Goool00`0003?o03?o0008<ol000<0003oooooool0H_ooo`03o`2Ioooooooo
01koool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0H_oo
o`03o`2Ioooooooo01koool008Woool00`000?ooooooo`03oooo0`0000Pco`000`000?ooooooo`1R
oooo00?o09Woooooool07_ooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008<ol000<0
003oooooool0H_ooo`03o`2Ioooooooo01koool008Ooool010000?ooooooo`0000Coool00`0003?o
03?o0008<ol000<0003oooooool0H_ooo`03o`2Ioooooooo01koool008Soool200001Oooo`030000
<ol0<ol000Lco`000`000?ooooooo`1Soooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol0
00Lco`000`000?ooooooo`1Soooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol000Lco`00
0`000?ooooooo`1Soooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1Soooo00?o09Woooooool07_ooo`00Soooo`800008<ol000<0003oooooool0Hoooo`03o`2I
oooooooo01koool008ooool00`0003?o03?o0007<ol000<0003oooooool0Hoooo`03o`2Ioooooooo
01koool008ooool00`0003?o03?o0007<ol000<0003oooooool0Hoooo`03o`2Ioooooooo01koool0
08ooool00`0003?o03?o0007<ol000<0003oooooool0Hoooo`03o`2Ioooooooo01koool008ooool0
0`0003?o03?o0006<ol000<0003oooooool0I?ooo`03o`2Ioooooooo01koool008ooool00`0003?o
03?o0006<ol000<0003oooooool0I?ooo`03o`2Ioooooooo01koool008ooool200001c?o00030000
oooooooo06Coool00ol0VOooooooo`0Noooo002?oooo00<0000co`0co`001S?o00030000oooooooo
06Coool00ol0VOooooooo`0Noooo002?oooo00<0000co`0co`001S?o00030000oooooooo06Coool0
0ol0VOooooooo`0Noooo002?oooo00<0000co`0co`001S?o00030000oooooooo06Coool00ol0VOoo
ooooo`0Noooo002?oooo00<0000co`0co`001S?o00030000oooooooo06Coool00ol0VOooooooo`0N
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo06Coool00ol0VOooooooo`0Noooo002?
oooo0P0000Hco`000`000?ooooooo`1Uoooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol0
00Dco`000`000?ooooooo`1Uoooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol000Dco`00
0`000?ooooooo`1Uoooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol000Dco`000`000?oo
ooooo`1Uoooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1U
oooo00?o09Woooooool07_ooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Uoooo00?o
09Woooooool07_ooo`00Soooo`800006<ol000<0003oooooool0IOooo`03o`2Ioooooooo01koool0
08ooool00`0003?o03?o0005<ol000<0003oooooool0IOooo`03o`2Ioooooooo01koool008ooool0
0`0003?o03?o0005<ol000<0003oooooool0IOooo`03o`2Ioooooooo01koool008ooool00`0003?o
03?o0004<ol000<0003oooooool0I_ooo`03o`2Ioooooooo01koool008ooool00`0003?o03?o0004
<ol000<0003oooooool0I_ooo`03o`2Ioooooooo01koool008Woool300000oooo`030000<ol0<ol0
00@co`000`000?ooooooo`1Voooo00?o09Woooooool07_ooo`00R_ooo`030000oooooooo00;oool0
0`0003?o03?o0004<ol000<0003oooooool0I_ooo`03o`2Ioooooooo01koool008Ooool500000ooo
o`<00004<ol000<0003oooooool0I_ooo`03o`2Ioooooooo01koool008Ooool010000?ooooooo`00
00Coool7<ol0R_ooo`00R?ooo`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o
08[oool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo001ioooo00<0003oooooool04oooo`Lco`0>
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo1c?o
00ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01_ooo`@00003<ol00P000004<ol0oooooooooooo0P0000?oool300001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Goool00`000?ooooooo`07<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000
oooo<ol000Hco`02oooo00@0003oooooool00002oooo00@0003oooooool00004oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0000co`0co`001C?o00?oool200000ooo
o`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Hco`02oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo
07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`03oooo0P0000Coool300000_ooo`030000
oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.88) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.91726 .12361 L
.92761 .12361 L
.93331 .12361 L
.93871 .12361 L
.94357 .12361 L
.9449 .12361 L
.94631 .12361 L
.94752 .12361 L
s
.94752 .12361 m
.9478 .61803 L
s
0 .4 1 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04758 .12361 L
.049 .12361 L
.05035 .12361 L
.05157 .12361 L
.05288 .12309 L
.05403 .12191 L
.0553 .12064 L
.05785 .11812 L
.06244 .1138 L
.08274 .09755 L
.10458 .08452 L
.12562 .07548 L
.1356 .0722 L
.14487 .06965 L
.15482 .06739 L
.16385 .06574 L
.17388 .06429 L
.17908 .06369 L
.18458 .06316 L
.18935 .06277 L
.1946 .06243 L
.19937 .06219 L
.20382 .06202 L
.20652 .06194 L
.20908 .06188 L
.21137 .06184 L
.21267 .06183 L
.21387 .06182 L
.21515 .06181 L
.21635 .0618 L
.21767 .0618 L
.21841 .0618 L
.21909 .06181 L
.22038 .06181 L
.22112 .06182 L
.2218 .06182 L
.22318 .06184 L
.22464 .06186 L
.22727 .0619 L
.22969 .06196 L
.23517 .06212 L
.2399 .06231 L
.2451 .06255 L
.26369 .06373 L
.28314 .0654 L
.30403 .06755 L
.3453 .07248 L
Mistroke
.38506 .07759 L
.42331 .08251 L
.46401 .08752 L
.48284 .08971 L
.49274 .09083 L
.50319 .09197 L
.50852 .09242 L
.51135 .09261 L
.51437 .09279 L
.51715 .09292 L
.51969 .09302 L
.52209 .0931 L
.52464 .09316 L
.52587 .09319 L
.52723 .09321 L
.52847 .09323 L
.52961 .09324 L
.53025 .09325 L
.53095 .09325 L
.53166 .09326 L
.5324 .09326 L
.53305 .09326 L
.53375 .09326 L
.53501 .09326 L
.53628 .09325 L
.537 .09325 L
.53766 .09324 L
.53885 .09323 L
.54016 .09321 L
.54243 .09318 L
.54482 .09313 L
.55005 .09299 L
.55501 .09281 L
.56431 .09237 L
.57432 .09177 L
.58522 .09098 L
.62597 .08699 L
.6652 .08196 L
.70292 .07623 L
.74309 .06931 L
.78174 .06197 L
.82285 .05362 L
.86244 .04533 L
.90052 .03756 L
.92175 .03353 L
.931 .0319 L
.93588 .03107 L
.94105 .03022 L
.9432 .02988 L
.94552 .02952 L
Mistroke
.9462 .02941 L
.94685 .02931 L
.94807 .12361 L
.9492 .12361 L
.95045 .12361 L
.95912 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.88) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo06koool00`1Vooooooooo`0Moooo002?oooo00<0003ooooo
ool0J_ooo`D0I_lOoooo002?oooo00<0003oooooool0I_ooo`@0I_l4oooo00<0I_ooooooool07Ooo
o`00Soooo`030000oooooooo067oool506Ko2?ooo`0306Kooooooooo01goool008ooool00`000?oo
ooooo`1Loooo1@1Vo`goool00`1Vooooooooo`0Moooo002?oooo00<0003oooooool0Eoooo`D0I_lB
oooo00<0I_ooooooool07Oooo`00Soooo`80001Coooo1@1VoaOoool00`1Vooooooooo`0Moooo002?
oooo00<0003oooooool0COooo`D0I_lLoooo00<0I_ooooooool07Oooo`00Soooo`030000oooooooo
04Ooool606Ko8Oooo`0306Kooooooooo01goool003cooolJ06Ko>Oooo`030000oooooooo04;oool5
06Ko9oooo`0306Kooooooooo01goool003Ooool506Ko6_ooo`d0I_l/oooo00<0003oooooool0?_oo
o`@0I_l/oooo00<0I_ooooooool07Oooo`00<_ooo`D0I_l/oooo201VobCoool00`000?ooooooo`0f
oooo201Voc3oool00`1Vooooooooo`0Moooo000_oooo0`1VocWoool506Ko7oooo`80000_oooo201V
ocSoool00`1Vooooooooo`0Moooo000Goooo100001;oool206Ko9Oooo`D0000Goooo1`1VoaSoool0
0`000?ooooooo`0Zoooo101Vo`Woool50000<oooo`0306Kooooooooo00;oool400005_ooo`005ooo
o`030000oooooooo017oool206Ko:Oooo`030000oooooooo01koool:06Ko3_ooo`030000oooooooo
02?oool706Ko3oooo`030000oooooooo03?oool00`1Vooooooooo`02oooo00<0003oooooool05ooo
o`006?ooo`030000oooooooo00koool206Ko:oooo`030000oooooooo02Soool806Ko1_ooo`030000
oooooooo01Woool:06Ko5_ooo`030000oooooooo03?oool00`1Vooooooooo`03oooo00<0003ooooo
ool05_ooo`004Oooo`@00004oooo00<0003oooooool03?ooo`0306Kooooooooo02?oool400001?oo
o`030000oooooooo033oool606Ko00<00000I_l0I_l03Oooo``0I_lPoooo00<0003oooooool0<ooo
o`0306Kooooooooo00Coool00`000?ooooooo`0Eoooo000Goooo00@0003oooooool0000;oooo0P1V
obkoool00`000?ooooooo`0foooo00<0003oooooool03@1Vobcoool00`000?ooooooo`0coooo00<0
I_ooooooool00_ooo`040000oooooooo00005_ooo`006?ooo`80000;oooo00<0I_ooooooool0;Ooo
o`80000hoooo0P0003Woool20000=Oooo`0306Kooooooooo00?oool200005oooo`009?ooo`0306Ko
oooooooo06Soool00`000?ooooooo`1_oooo00<0I_ooooooool07?ooo`008_ooo`80I_m[oooo00<0
003oooooool0Koooo`0306Kooooooooo01coool0027oool00`1Vooooooooo`1[oooo00<0003ooooo
ool0Koooo`0306Kooooooooo01coool0023oool00`1Vooooooooo`1/oooo00<0003oooooool0Kooo
o`0306Kooooooooo01coool001ooool00`1Vooooooooo`1]oooo00<0003oooooool0Koooo`0306Ko
oooooooo01coool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Hco`0R00001_ooo`050000
ooooooooooooo`2I00Ooool00`000?ooooooo`0Eoooo000Foooo00<0003oooooool0>_ooo`030000
oooooooo03Woool00`0003?o03?o000i<ol02@0002coool00ol0VOooooooo`05oooo00<0003ooooo
ool05Oooo`00Soooo`030000<ol0<ol003<co`060000=Oooo`03o`2Ioooooooo01goool008ooool0
0`0003?o03?o000a<ol00P0003_oool00ol0VOooooooo`0Moooo002?oooo00<0000co`0co`00;c?o
0080000moooo00?o09Woooooool07Oooo`00Soooo`030000<ol0<ol002`co`030000?oooo`03o`2I
oooooooo01goool008ooool20000:S?o00<00012oooo00?o09Woooooool07Oooo`00Soooo`030000
<ol0<ol002Lco`020000AOooo`03o`2Ioooooooo01goool008ooool00`0003?o03?o000V<ol000<0
003oooooool0AOooo`03o`2Ioooooooo01goool008ooool00`0003?o03?o000U<ol000<0003ooooo
ool0A_ooo`03o`2Ioooooooo01goool008ooool00`0003?o03?o000T<ol000<0003oooooool0Aooo
o`03o`2Ioooooooo01goool008ooool00`0003?o03?o000R<ol00P0004[oool00ol0VOooooooo`0M
oooo002?oooo0P00028co`000`000?ooooooo`1:oooo00?o09Woooooool07Oooo`00Soooo`030000
<ol0<ol0020co`000`000?ooooooo`1;oooo00?o09Woooooool07Oooo`00Soooo`030000<ol0<ol0
01lco`000`000?ooooooo`1<oooo00?o09Woooooool07Oooo`00Soooo`030000<ol0<ol001lco`00
0`000?ooooooo`1<oooo00?o09Woooooool07Oooo`00Soooo`030000<ol0<ol001hco`000`000?oo
ooooo`1=oooo00?o09Woooooool07Oooo`00Soooo`030000<ol0<ol001dco`000`000?ooooooo`1>
oooo00?o09Woooooool07Oooo`00Soooo`80000M<ol000<0003oooooool0Coooo`03o`2Ioooooooo
01goool008ooool00`0003?o03?o000K<ol000<0003oooooool0D?ooo`03o`2Ioooooooo01goool0
08ooool00`0003?o03?o000K<ol000<0003oooooool0D?ooo`03o`2Ioooooooo01goool008ooool0
0`0003?o03?o000J<ol000<0003oooooool0DOooo`03o`2Ioooooooo01goool008ooool00`0003?o
03?o000J<ol000<0003oooooool0DOooo`03o`2Ioooooooo01goool008ooool00`0003?o03?o000I
<ol000<0003oooooool0D_ooo`03o`2Ioooooooo01goool008ooool200006S?o00030000oooooooo
05;oool00ol0VOooooooo`0Moooo002?oooo00<0000co`0co`0063?o00030000oooooooo05?oool0
0ol0VOooooooo`0Moooo002?oooo00<0000co`0co`0063?o00030000oooooooo05?oool00ol0VOoo
ooooo`0Moooo002?oooo00<0000co`0co`005c?o00030000oooooooo05Coool00ol0VOooooooo`0M
oooo002?oooo00<0000co`0co`005c?o00030000oooooooo05Coool00ol0VOooooooo`0Moooo0027
oooo1@0000?oool00`0003?o03?o000F<ol000<0003oooooool0EOooo`03o`2Ioooooooo01goool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`005S?o00030000oooooooo05Goool00ol0VOoo
ooooo`0Moooo0029oooo00<0003oooooool00oooo`<0000E<ol000<0003oooooool0E_ooo`03o`2I
oooooooo01goool008Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo
05Koool00ol0VOooooooo`0Moooo0029oooo00<0003oooooool00oooo`030000<ol0<ol001Dco`00
0`000?ooooooo`1Foooo00?o09Woooooool07Oooo`00R?ooo`800005oooo00<0000co`0co`0053?o
00030000oooooooo05Ooool00ol0VOooooooo`0Moooo002?oooo00<0000co`0co`0053?o00030000
oooooooo05Ooool00ol0VOooooooo`0Moooo002?oooo00<0000co`0co`004c?o00030000oooooooo
05Soool00ol0VOooooooo`0Moooo002?oooo0P0001@co`000`000?ooooooo`1Hoooo00?o09Wooooo
ool07Oooo`00Soooo`030000<ol0<ol001<co`000`000?ooooooo`1Hoooo00?o09Woooooool07Ooo
o`00Soooo`030000<ol0<ol0018co`000`000?ooooooo`1Ioooo00?o09Woooooool07Oooo`00Sooo
o`030000<ol0<ol0018co`000`000?ooooooo`1Ioooo00?o09Woooooool07Oooo`00Soooo`030000
<ol0<ol0018co`000`000?ooooooo`1Ioooo00?o09Woooooool07Oooo`00Soooo`030000<ol0<ol0
014co`000`000?ooooooo`1Joooo00?o09Woooooool07Oooo`00Soooo`80000B<ol000<0003ooooo
ool0F_ooo`03o`2Ioooooooo01goool008ooool00`0003?o03?o000A<ol000<0003oooooool0F_oo
o`03o`2Ioooooooo01goool008ooool00`0003?o03?o000A<ol000<0003oooooool0F_ooo`03o`2I
oooooooo01goool008ooool00`0003?o03?o000@<ol000<0003oooooool0Foooo`03o`2Ioooooooo
01goool008ooool00`0003?o03?o000@<ol000<0003oooooool0Foooo`03o`2Ioooooooo01goool0
08ooool00`0003?o03?o000@<ol000<0003oooooool0Foooo`03o`2Ioooooooo01goool008ooool0
0`0003?o03?o000@<ol000<0003oooooool0Foooo`03o`2Ioooooooo01goool008ooool2000043?o
00030000oooooooo05coool00ol0VOooooooo`0Moooo002?oooo00<0000co`0co`003c?o00030000
oooooooo05coool00ol0VOooooooo`0Moooo002?oooo00<0000co`0co`003c?o00030000oooooooo
05coool00ol0VOooooooo`0Moooo002?oooo00<0000co`0co`003c?o00030000oooooooo05coool0
0ol0VOooooooo`0Moooo002?oooo00<0000co`0co`003c?o00030000oooooooo05coool00ol0VOoo
ooooo`0Moooo002?oooo00<0000co`0co`003S?o00030000oooooooo05goool00ol0VOooooooo`0M
oooo002?oooo0P0000lco`000`000?ooooooo`1Moooo00?o09Woooooool07Oooo`00Soooo`030000
<ol0<ol000hco`000`000?ooooooo`1Moooo00?o09Woooooool07Oooo`00Soooo`030000<ol0<ol0
00hco`000`000?ooooooo`1Moooo00?o09Woooooool07Oooo`00Soooo`030000<ol0<ol000dco`00
0`000?ooooooo`1Noooo00?o09Woooooool07Oooo`00Qoooo`@00004oooo00<0000co`0co`003C?o
00030000oooooooo05koool00ol0VOooooooo`0Moooo0027oooo00<0003oooooool01Oooo`030000
<ol0<ol000dco`000`000?ooooooo`1Noooo00?o09Woooooool07Oooo`00R?ooo`030000oooooooo
00Coool300003C?o00030000oooooooo05koool00ol0VOooooooo`0Moooo0029oooo00<0003ooooo
ool00oooo`030000<ol0<ol000dco`000`000?ooooooo`1Ooooo00?o09Woooooool07?ooo`00Qooo
o`040000oooooooo00001?ooo`030000<ol0<ol000`co`000`000?ooooooo`1Poooo00?o09Wooooo
ool07?ooo`00R?ooo`800005oooo00<0000co`0co`0033?o00030000oooooooo063oool00ol0VOoo
ooooo`0Loooo002?oooo00<0000co`0co`0033?o00030000oooooooo063oool00ol0VOooooooo`0L
oooo002?oooo00<0000co`0co`0033?o00030000oooooooo063oool00ol0VOooooooo`0Loooo002?
oooo0P0000dco`000`000?ooooooo`1Poooo00?o09Woooooool07?ooo`00Soooo`030000<ol0<ol0
00`co`000`000?ooooooo`1Poooo00?o09Woooooool07?ooo`00Soooo`030000<ol0<ol000/co`00
0`000?ooooooo`1Qoooo00?o09Woooooool07?ooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`1Qoooo00?o09Woooooool07?ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Q
oooo00?o09Woooooool07?ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Qoooo00?o
09Woooooool07?ooo`00Soooo`030000<ol0<ol000/co`000`000?ooooooo`1Qoooo00?o09Wooooo
ool07?ooo`00Soooo`80000<<ol000<0003oooooool0HOooo`03o`2Ioooooooo01coool008ooool0
0`0003?o03?o000;<ol000<0003oooooool0HOooo`03o`2Ioooooooo01coool008ooool00`0003?o
03?o000:<ol000<0003oooooool0H_ooo`03o`2Ioooooooo01coool008ooool00`0003?o03?o000:
<ol000<0003oooooool0H_ooo`03o`2Ioooooooo01coool008ooool00`0003?o03?o000:<ol000<0
003oooooool0H_ooo`03o`2Ioooooooo01coool008ooool00`0003?o03?o000:<ol000<0003ooooo
ool0H_ooo`03o`2Ioooooooo01coool008ooool200002c?o00030000oooooooo06;oool00ol0VOoo
ooooo`0Loooo002?oooo00<0000co`0co`002S?o00030000oooooooo06;oool00ol0VOooooooo`0L
oooo002?oooo00<0000co`0co`002S?o00030000oooooooo06;oool00ol0VOooooooo`0Loooo002?
oooo00<0000co`0co`002C?o00030000oooooooo06?oool00ol0VOooooooo`0Loooo002?oooo00<0
000co`0co`002C?o00030000oooooooo06?oool00ol0VOooooooo`0Loooo002?oooo00<0000co`0c
o`002C?o00030000oooooooo06?oool00ol0VOooooooo`0Loooo002?oooo0P0000Xco`000`000?oo
ooooo`1Soooo00?o09Woooooool07?ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1S
oooo00?o09Woooooool07?ooo`00Soooo`030000<ol0<ol000Tco`000`000?ooooooo`1Soooo00?o
09Woooooool07?ooo`00Soooo`030000<ol0<ol000Pco`000`000?ooooooo`1Toooo00?o09Wooooo
ool07?ooo`00R?ooo`800005oooo00<0000co`0co`0023?o00030000oooooooo06Coool00ol0VOoo
ooooo`0Loooo0027oooo00@0003oooooool00004oooo00<0000co`0co`0023?o00030000oooooooo
06Coool00ol0VOooooooo`0Loooo0029oooo00<0003oooooool00oooo`<00008<ol000<0003ooooo
ool0I?ooo`03o`2Ioooooooo01coool008[oool00`000?ooooooo`02oooo00<0000co`0co`0023?o
00030000oooooooo06Coool00ol0VOooooooo`0Loooo0027oooo00@0003oooooool00004oooo00<0
000co`0co`0023?o00030000oooooooo06Coool00ol0VOooooooo`0Loooo0028oooo0P0000Goool0
0`0003?o03?o0007<ol000<0003oooooool0IOooo`03o`2Ioooooooo01coool008ooool00`0003?o
03?o0007<ol000<0003oooooool0IOooo`03o`2Ioooooooo01coool008ooool00`0003?o03?o0007
<ol000<0003oooooool0IOooo`03o`2Ioooooooo01coool008ooool00`0003?o03?o0007<ol000<0
003oooooool0IOooo`03o`2Ioooooooo01coool008ooool2000023?o00030000oooooooo06Goool0
0ol0VOooooooo`0Loooo002?oooo00<0000co`0co`001c?o00030000oooooooo06Goool00ol0VOoo
ooooo`0Loooo002?oooo00<0000co`0co`001c?o00030000oooooooo06Goool00ol0VOooooooo`0L
oooo002?oooo00<0000co`0co`001c?o00030000oooooooo06Goool00ol0VOooooooo`0Loooo002?
oooo00<0000co`0co`001S?o00030000oooooooo06Koool00ol0VOooooooo`0Loooo002?oooo00<0
000co`0co`001S?o00030000oooooooo06Koool00ol0VOooooooo`0Loooo002?oooo0P0000Lco`00
0`000?ooooooo`1Voooo00?o09Woooooool07?ooo`00Soooo`030000<ol0<ol000Hco`000`000?oo
ooooo`1Voooo00?o09Woooooool07?ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1V
oooo00?o09Woooooool07?ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Voooo00?o
09Woooooool07?ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Voooo00?o09Wooooo
ool07?ooo`00Soooo`030000<ol0<ol000Hco`000`000?ooooooo`1Voooo00?o09Woooooool07?oo
o`00Soooo`800006<ol000<0003oooooool0Ioooo`03o`2Ioooooooo01coool008ooool00`0003?o
03?o0005<ol000<0003oooooool0Ioooo`03o`2Ioooooooo01coool008ooool00`0003?o03?o0005
<ol000<0003oooooool0Ioooo`03o`2Ioooooooo01coool008ooool00`0003?o03?o0005<ol000<0
003oooooool0Ioooo`03o`2Ioooooooo01coool008ooool00`0003?o03?o0005<ol000<0003ooooo
ool0Ioooo`03o`2Ioooooooo01coool008ooool00`0003?o03?o0005<ol000<0003oooooool0Iooo
o`03o`2Ioooooooo01coool008ooool200001S?o00030000oooooooo06Ooool00ol0VOooooooo`0L
oooo002?oooo00<0000co`0co`001C?o00030000oooooooo06Ooool00ol0VOooooooo`0Loooo002?
oooo00<0000co`0co`001C?o00030000oooooooo06Ooool00ol0VOooooooo`0Loooo002?oooo00<0
000co`0co`0013?o00030000oooooooo06Soool00ol0VOooooooo`0Loooo002?oooo00<0000co`0c
o`0013?o00030000oooooooo06Soool00ol0VOooooooo`0Loooo0029oooo0`0000?oool00`0003?o
03?o0004<ol000<0003oooooool0J?ooo`03o`2Ioooooooo01coool008[oool00`000?ooooooo`02
oooo00<0000co`0co`0013?o00030000oooooooo06Soool00ol0VOooooooo`0Loooo0027oooo1@00
00?oool3000013?o00030000oooooooo06Soool00ol0VOooooooo`0Loooo0027oooo00@0003ooooo
ool00004oooo1c?o08[oool008Soool00`000?ooo`000004oooo1c?o08[oool008Woool200001?oo
o`Lco`2:oooo002?oooo1c?o08[oool008ooool7<ol0R_ooo`00NOooo`030000oooooooo01?oool7
<ol03_ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool02Ooo
o`Lco`0?oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Koool400000c?o0080000013?o0?ooooooooooo`800004oooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00<0003oooooool01c?o00;oool010000?ooooooo`0000;oool010000?ooooooo`00
00?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00koool0
0`000?oooc?o0006<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000<ol0<ol000Dco`03oooo0P00
00Coool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0
003oooooool00006<ol00_ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Lco`03oooo0P0000Coool200000ooo
o`030000oooooooo07Woool008ooool7<ol0R_ooo`00Soooo`Lco`2:oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
.2 1 0 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
.50085 1.09152 L
.50154 1.07509 L
.50226 1.0581 L
.50471 1.00308 L
.5095 .9065 L
.51896 .75038 L
.52891 .6239 L
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
.97619 .12361 L
.02381 .12361 L
F
0 g
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.48147 .12361 L
.49012 .12361 L
.49468 .12361 L
.49719 .12361 L
.49842 .12361 L
.49955 .12361 L
s
.49955 .12361 m
.50022 .61803 L
s
.52952 .61803 m
.53984 .51743 L
.55004 .44049 L
.55935 .38459 L
.57021 .33253 L
.58026 .29419 L
.59935 .24044 L
.60941 .21955 L
.62011 .20155 L
.62948 .18864 L
.63958 .17716 L
.65786 .16136 L
.66743 .15507 L
.6779 .1494 L
.68895 .14452 L
.699 .1409 L
.71861 .13555 L
.72939 .13335 L
.73956 .13165 L
.74928 .1303 L
.75957 .12912 L
.77803 .12751 L
.78746 .12687 L
.7976 .1263 L
.81591 .12552 L
.82604 .12519 L
.83709 .12489 L
.84764 .12466 L
.85719 .12449 L
.8769 .12421 L
.88772 .1241 L
.89789 .12402 L
.90768 .12395 L
.91801 .12389 L
.93649 .12381 L
.94599 .12377 L
.95617 .12374 L
.97451 .1237 L
.97619 .1237 L
s
1 0 .6 r
.02381 .12361 m
.06244 .12361 L
.10458 .12361 L
.14415 .12361 L
.18221 .12361 L
.22272 .12361 L
.26171 .12361 L
.30316 .12361 L
.34309 .12361 L
.3815 .12361 L
.42237 .12361 L
.46172 .12361 L
.49955 .12361 L
.53984 .12361 L
.57861 .12361 L
.61984 .12361 L
.65954 .12361 L
.69774 .12361 L
.73838 .12361 L
.77751 .12361 L
.81909 .12361 L
.85916 .12361 L
.89771 .12361 L
.91726 .12361 L
.92761 .12361 L
.93871 .12361 L
.94392 .12361 L
.94648 .12361 L
.94885 .12361 L
.951 .12361 L
.95208 .12361 L
s
.95208 .12361 m
.95256 .61803 L
s
0 .4 1 r
.02381 .12361 m
.03279 .12361 L
.04262 .12361 L
.04517 .12361 L
.04642 .12361 L
.04758 .12361 L
.04822 .12298 L
.04891 .12228 L
.05035 .12081 L
.05288 .11832 L
.06244 .10958 L
.0842 .09341 L
.10458 .0822 L
.12281 .07479 L
.14241 .06908 L
.15252 .06691 L
.16355 .06505 L
.17397 .06373 L
.18364 .06284 L
.18872 .06249 L
.19421 .0622 L
.19673 .0621 L
.19939 .06201 L
.20169 .06194 L
.20416 .06188 L
.20539 .06186 L
.20656 .06184 L
.2077 .06183 L
.20875 .06182 L
.20974 .06181 L
.2108 .06181 L
.21186 .0618 L
.21303 .0618 L
.21429 .06181 L
.21545 .06181 L
.21672 .06182 L
.21805 .06183 L
.22031 .06187 L
.22277 .06191 L
.22805 .06205 L
.23304 .06222 L
.24238 .06265 L
.25243 .06327 L
.26333 .06407 L
.30425 .06811 L
.34365 .07287 L
.38154 .07775 L
.42188 .08293 L
.4607 .08769 L
.48045 .08998 L
Mistroke
.49088 .09116 L
.50198 .09237 L
.50756 .09286 L
.51281 .09321 L
.51752 .09344 L
.52017 .09355 L
.52261 .09362 L
.52491 .09368 L
.52705 .09372 L
.52828 .09374 L
.5294 .09375 L
.5307 .09376 L
.53192 .09377 L
.53311 .09377 L
.53437 .09377 L
.53544 .09377 L
.53663 .09376 L
.5379 .09375 L
.53927 .09374 L
.54174 .0937 L
.54415 .09366 L
.54671 .0936 L
.55134 .09347 L
.56182 .09303 L
.57289 .09241 L
.58293 .09171 L
.62297 .08796 L
.66149 .08317 L
.70246 .07709 L
.74191 .07038 L
.77985 .06327 L
.82024 .05514 L
.85912 .04702 L
.90045 .03851 L
.92112 .03452 L
.93021 .03287 L
.94026 .03113 L
.94458 .03042 L
.94685 .03006 L
.94924 .02968 L
.95025 .02952 L
.95134 .02935 L
.95253 .12361 L
.95364 .12361 L
.95768 .12361 L
.97619 .12361 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.123607 0.123607 [
[.02381 .11111 -6 -9 ]
[.02381 .11111 6 0 ]
[.2619 .11111 -6 -9 ]
[.2619 .11111 6 0 ]
[.7381 .11111 -3 -9 ]
[.7381 .11111 3 0 ]
[.97619 .11111 -3 -9 ]
[.97619 .11111 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .24721 -6 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -6 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12361 m
.02381 .12986 L
s
[(-2)] .02381 .11111 0 1 Mshowa
.2619 .12361 m
.2619 .12986 L
s
[(-1)] .2619 .11111 0 1 Mshowa
.7381 .12361 m
.7381 .12986 L
s
[(1)] .7381 .11111 0 1 Mshowa
.97619 .12361 m
.97619 .12986 L
s
[(2)] .97619 .11111 0 1 Mshowa
.125 Mabswid
.07143 .12361 m
.07143 .12736 L
s
.11905 .12361 m
.11905 .12736 L
s
.16667 .12361 m
.16667 .12736 L
s
.21429 .12361 m
.21429 .12736 L
s
.30952 .12361 m
.30952 .12736 L
s
.35714 .12361 m
.35714 .12736 L
s
.40476 .12361 m
.40476 .12736 L
s
.45238 .12361 m
.45238 .12736 L
s
.54762 .12361 m
.54762 .12736 L
s
.59524 .12361 m
.59524 .12736 L
s
.64286 .12361 m
.64286 .12736 L
s
.69048 .12361 m
.69048 .12736 L
s
.78571 .12361 m
.78571 .12736 L
s
.83333 .12361 m
.83333 .12736 L
s
.88095 .12361 m
.88095 .12736 L
s
.92857 .12361 m
.92857 .12736 L
s
.25 Mabswid
0 .12361 m
1 .12361 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(1)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(2)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(3)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(4)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`1Zoooo1P1Voakoool0
08ooool00`000?ooooooo`1Voooo101Vo`Goool00`1Vooooooooo`0Loooo002?oooo00<0003ooooo
ool0HOooo`D0I_l9oooo00<0I_ooooooool07?ooo`00Soooo`030000oooooooo05_oool606Ko3_oo
o`0306Kooooooooo01coool008ooool00`000?ooooooo`1Foooo1@1VoaCoool00`1Vooooooooo`0L
oooo002?oooo0P0005;oool506Ko6Oooo`0306Kooooooooo01coool008ooool00`000?ooooooo`1<
oooo1@1Voakoool00`1Vooooooooo`0Loooo002?oooo00<0003oooooool0Aoooo`D0I_lSoooo00<0
I_ooooooool07?ooo`00??oooa`0I_lgoooo00<0003oooooool0@_ooo`D0I_lXoooo00<0I_oooooo
ool07?ooo`00=_ooo`H0I_lLoooo201Vobooool00`000?ooooooo`0moooo1@1Vobgoool00`1Voooo
ooooo`0Loooo000boooo101Vob[oool506Ko:_ooo`030000oooooooo03Soool506Ko<_ooo`0306Ko
oooooooo01coool002ooool306Ko<oooo`L0I_lSoooo0P0003Coool506Ko=oooo`0306Kooooooooo
01coool001Ooool400004_ooo`80I_lUoooo1@0001?oool:06Ko6Oooo`030000oooooooo02coool7
06Ko1?ooo`D0000doooo00@0I_ooooooooooool400005_ooo`005oooo`030000oooooooo017oool2
06Ko:Oooo`030000oooooooo01goool:06Ko3oooo`030000oooooooo02;oool:06Ko3Oooo`030000
oooooooo03Coool01@1Vooooooooooooo`00000Ioooo000Hoooo00<0003oooooool03_ooo`80I_l[
oooo00<0003oooooool09oooo`P0I_l7oooo00<0003oooooool06?ooo`X0I_lGoooo00<0003ooooo
ool0=?ooo`0306Kooooooooo00;oool00`000?ooooooo`0Foooo000Aoooo100000Coool00`000?oo
ooooo`0;oooo0P1VobGoool400001?ooo`030000oooooooo02ooool706Ko00<0003oooooool03ooo
o`T0I_lQoooo00<0003oooooool0=?ooo`0306Kooooooooo00?oool00`000?ooooooo`0Eoooo000G
oooo00@0003oooooool0000;oooo00<0I_ooooooool0;Oooo`030000oooooooo03Koool00`00001V
o`1Vo`0?06Ko:_ooo`030000oooooooo03Coool01@1Vooooooooooooo`000002oooo00<0003ooooo
ool05?ooo`006?ooo`80000:oooo0P1Vobooool20000>?ooo`80000ioooo0P0003Koool00`1Voooo
ooooo`02oooo0P0001Ooool002?oool00`1Vooooooooo`1Yoooo00<0003oooooool0L?ooo`0306Ko
oooooooo01_oool0027oool206KoK?ooo`030000oooooooo073oool00`1Vooooooooo`0Koooo000P
oooo00<0I_ooooooool0K?ooo`030000oooooooo073oool00`1Vooooooooo`0Koooo000Ooooo00<0
I_ooooooool0KOooo`030000oooooooo073oool00`1Vooooooooo`0Koooo000Noooo00<0I_oooooo
ool0K_ooo`030000oooooooo073oool00`1Vooooooooo`0Koooo000@ooooo`00017oool001Koool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0000co`0co`002C?o00030000
<ol0<ol000Tco`000`0003?o03?o0009<ol000<0000co`0co`002C?o00030000<ol0<ol000Tco`00
0`0003?o03?o0006<ol08P0000Koool00`000?ooooooo`03oooo00?o09Woooooool00oooo`030000
oooooooo01Goool001Koool00`000?ooooooo`0joooo00<0003oooooool0>Oooo`030000<ol0<ol0
03Tco`090000;_ooo`03o`2Ioooooooo00?oool00`000?ooooooo`0Eoooo002?oooo00<0000co`0c
o`00<c?o00H0000goooo00?o09Woooooool06oooo`00Soooo`030000<ol0<ol0034co`020000?Ooo
o`03o`2Ioooooooo01_oool008ooool00`0003?o03?o000_<ol00P0003ooool00ol0VOooooooo`0K
oooo002?oooo00<0000co`0co`00;3?o00<00011oooo00?o09Woooooool06oooo`00Soooo`80000Z
<ol00`0004Coool00ol0VOooooooo`0Koooo002?oooo00<0000co`0co`009c?o00800017oooo00?o
09Woooooool06oooo`00Soooo`030000<ol0<ol002Hco`000`000?ooooooo`17oooo00?o09Wooooo
ool06oooo`00Soooo`030000<ol0<ol002Dco`000`000?ooooooo`18oooo00?o09Woooooool06ooo
o`00Soooo`030000<ol0<ol002@co`000`000?ooooooo`19oooo00?o09Woooooool06oooo`00Sooo
o`030000<ol0<ol0028co`020000C?ooo`03o`2Ioooooooo01_oool008ooool200008S?o00030000
oooooooo04coool00ol0VOooooooo`0Koooo002?oooo00<0000co`0co`0083?o00030000oooooooo
04goool00ol0VOooooooo`0Koooo002?oooo00<0000co`0co`007c?o00030000oooooooo04koool0
0ol0VOooooooo`0Koooo002?oooo00<0000co`0co`007c?o00030000oooooooo04koool00ol0VOoo
ooooo`0Koooo002?oooo00<0000co`0co`007S?o00030000oooooooo04ooool00ol0VOooooooo`0K
oooo002?oooo00<0000co`0co`007C?o00030000oooooooo053oool00ol0VOooooooo`0Koooo002?
oooo0P0001dco`000`000?ooooooo`1Aoooo00?o09Woooooool06oooo`00Soooo`030000<ol0<ol0
01/co`000`000?ooooooo`1Boooo00?o09Woooooool06oooo`00Soooo`030000<ol0<ol001/co`00
0`000?ooooooo`1Boooo00?o09Woooooool06oooo`00Soooo`030000<ol0<ol001Xco`000`000?oo
ooooo`1Coooo00?o09Woooooool06oooo`00Soooo`030000<ol0<ol001Xco`000`000?ooooooo`1C
oooo00?o09Woooooool06oooo`00Soooo`030000<ol0<ol001Tco`000`000?ooooooo`1Doooo00?o
09Woooooool06oooo`00Soooo`80000J<ol000<0003oooooool0E?ooo`03o`2Ioooooooo01_oool0
08ooool00`0003?o03?o000H<ol000<0003oooooool0EOooo`03o`2Ioooooooo01_oool008ooool0
0`0003?o03?o000H<ol000<0003oooooool0EOooo`03o`2Ioooooooo01_oool008ooool00`0003?o
03?o000G<ol000<0003oooooool0E_ooo`03o`2Ioooooooo01_oool008ooool00`0003?o03?o000G
<ol000<0003oooooool0E_ooo`03o`2Ioooooooo01_oool008Ooool500000oooo`030000<ol0<ol0
01Hco`000`000?ooooooo`1Goooo00?o09Woooooool06oooo`00ROooo`030000oooooooo00?oool0
0`0003?o03?o000F<ol000<0003oooooool0Eoooo`03o`2Ioooooooo01_oool008Woool00`000?oo
ooooo`03oooo0`0001Dco`000`000?ooooooo`1Hoooo00?o09Woooooool06oooo`00ROooo`030000
oooooooo00?oool00`0003?o03?o000E<ol000<0003oooooool0F?ooo`03o`2Ioooooooo01_oool0
08Woool00`000?ooooooo`03oooo00<0000co`0co`005C?o00030000oooooooo05Soool00ol0VOoo
ooooo`0Koooo0028oooo0P0000Goool00`0003?o03?o000D<ol000<0003oooooool0FOooo`03o`2I
oooooooo01_oool008ooool00`0003?o03?o000D<ol000<0003oooooool0FOooo`03o`2Ioooooooo
01_oool008ooool00`0003?o03?o000C<ol000<0003oooooool0F_ooo`03o`2Ioooooooo01_oool0
08ooool2000053?o00030000oooooooo05[oool00ol0VOooooooo`0Koooo002?oooo00<0000co`0c
o`004c?o00030000oooooooo05[oool00ol0VOooooooo`0Koooo002?oooo00<0000co`0co`004S?o
00030000oooooooo05_oool00ol0VOooooooo`0Koooo002?oooo00<0000co`0co`004S?o00030000
oooooooo05_oool00ol0VOooooooo`0Koooo002?oooo00<0000co`0co`004S?o00030000oooooooo
05_oool00ol0VOooooooo`0Koooo002?oooo00<0000co`0co`004C?o00030000oooooooo05coool0
0ol0VOooooooo`0Koooo002?oooo0P00018co`000`000?ooooooo`1Loooo00?o09Woooooool06ooo
o`00Soooo`030000<ol0<ol0014co`000`000?ooooooo`1Loooo00?o09Woooooool06oooo`00Sooo
o`030000<ol0<ol0014co`000`000?ooooooo`1Loooo00?o09Woooooool06oooo`00Soooo`030000
<ol0<ol0010co`000`000?ooooooo`1Moooo00?o09Woooooool06oooo`00Soooo`030000<ol0<ol0
010co`000`000?ooooooo`1Moooo00?o09Woooooool06oooo`00Soooo`030000<ol0<ol0010co`00
0`000?ooooooo`1Moooo00?o09Woooooool06oooo`00Soooo`030000<ol0<ol0010co`000`000?oo
ooooo`1Moooo00?o09Woooooool06oooo`00Soooo`80000@<ol000<0003oooooool0G_ooo`03o`2I
oooooooo01_oool008ooool00`0003?o03?o000?<ol000<0003oooooool0G_ooo`03o`2Ioooooooo
01_oool008ooool00`0003?o03?o000?<ol000<0003oooooool0G_ooo`03o`2Ioooooooo01_oool0
08ooool00`0003?o03?o000?<ol000<0003oooooool0G_ooo`03o`2Ioooooooo01_oool008ooool0
0`0003?o03?o000?<ol000<0003oooooool0G_ooo`03o`2Ioooooooo01_oool008ooool00`0003?o
03?o000><ol000<0003oooooool0Goooo`03o`2Ioooooooo01_oool008ooool200003c?o00030000
oooooooo05ooool00ol0VOooooooo`0Koooo002?oooo00<0000co`0co`003S?o00030000oooooooo
05ooool00ol0VOooooooo`0Koooo002?oooo00<0000co`0co`003S?o00030000oooooooo05ooool0
0ol0VOooooooo`0Koooo002?oooo00<0000co`0co`003C?o00030000oooooooo063oool00ol0VOoo
ooooo`0Koooo0027oooo100000Coool00`0003?o03?o000=<ol000<0003oooooool0H?ooo`03o`2I
oooooooo01_oool008Ooool00`000?ooooooo`05oooo00<0000co`0co`003C?o00030000oooooooo
063oool00ol0VOooooooo`0Koooo0028oooo00<0003oooooool01?ooo`<0000=<ol000<0003ooooo
ool0H?ooo`03o`2Ioooooooo01_oool008Woool00`000?ooooooo`03oooo00<0000co`0co`003C?o
00030000oooooooo063oool00ol0VOooooooo`0Koooo0027oooo00@0003oooooool00004oooo00<0
000co`0co`0033?o00030000oooooooo067oool00ol0VOooooooo`0Koooo0028oooo0P0000Goool0
0`0003?o03?o000<<ol000<0003oooooool0HOooo`03o`2Ioooooooo01_oool008ooool00`0003?o
03?o000<<ol000<0003oooooool0HOooo`03o`2Ioooooooo01_oool008ooool00`0003?o03?o000<
<ol000<0003oooooool0HOooo`03o`2Ioooooooo01_oool008ooool200003C?o00030000oooooooo
067oool00ol0VOooooooo`0Koooo002?oooo00<0000co`0co`0033?o00030000oooooooo067oool0
0ol0VOooooooo`0Koooo002?oooo00<0000co`0co`002c?o00030000oooooooo06;oool00ol0VOoo
ooooo`0Koooo002?oooo00<0000co`0co`002c?o00030000oooooooo06;oool00ol0VOooooooo`0K
oooo002?oooo00<0000co`0co`002c?o00030000oooooooo06;oool00ol0VOooooooo`0Koooo002?
oooo00<0000co`0co`002c?o00030000oooooooo06;oool00ol0VOooooooo`0Koooo002?oooo00<0
000co`0co`002c?o00030000oooooooo06;oool00ol0VOooooooo`0Koooo002?oooo0P0000`co`00
0`000?ooooooo`1Roooo00?o09Woooooool06oooo`00Soooo`030000<ol0<ol000/co`000`000?oo
ooooo`1Roooo00?o09Woooooool06oooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1S
oooo00?o09Woooooool06oooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1Soooo00?o
09Woooooool06oooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1Soooo00?o09Wooooo
ool06oooo`00Soooo`030000<ol0<ol000Xco`000`000?ooooooo`1Soooo00?o09Woooooool06ooo
o`00Soooo`80000;<ol000<0003oooooool0Hoooo`03o`2Ioooooooo01_oool008ooool00`0003?o
03?o000:<ol000<0003oooooool0Hoooo`03o`2Ioooooooo01_oool008ooool00`0003?o03?o000:
<ol000<0003oooooool0Hoooo`03o`2Ioooooooo01_oool008ooool00`0003?o03?o0009<ol000<0
003oooooool0I?ooo`03o`2Ioooooooo01_oool008ooool00`0003?o03?o0009<ol000<0003ooooo
ool0I?ooo`03o`2Ioooooooo01_oool008ooool00`0003?o03?o0009<ol000<0003oooooool0I?oo
o`03o`2Ioooooooo01_oool008ooool200002S?o00030000oooooooo06Coool00ol0VOooooooo`0K
oooo002?oooo00<0000co`0co`002C?o00030000oooooooo06Coool00ol0VOooooooo`0Koooo002?
oooo00<0000co`0co`002C?o00030000oooooooo06Coool00ol0VOooooooo`0Koooo002?oooo00<0
000co`0co`0023?o00030000oooooooo06Goool00ol0VOooooooo`0Koooo0028oooo0P0000Goool0
0`0003?o03?o0008<ol000<0003oooooool0IOooo`03o`2Ioooooooo01_oool008Ooool010000?oo
ooooo`0000Coool00`0003?o03?o0008<ol000<0003oooooool0IOooo`03o`2Ioooooooo01_oool0
08Woool00`000?ooooooo`03oooo0`0000Pco`000`000?ooooooo`1Uoooo00?o09Woooooool06ooo
o`00R_ooo`030000oooooooo00;oool00`0003?o03?o0008<ol000<0003oooooool0IOooo`03o`2I
oooooooo01_oool008Ooool010000?ooooooo`0000Coool00`0003?o03?o0008<ol000<0003ooooo
ool0IOooo`03o`2Ioooooooo01_oool008Soool200001Oooo`030000<ol0<ol000Lco`000`000?oo
ooooo`1Voooo00?o09Woooooool06oooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1V
oooo00?o09Woooooool06oooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1Voooo00?o
09Woooooool06oooo`00Soooo`030000<ol0<ol000Lco`000`000?ooooooo`1Voooo00?o09Wooooo
ool06oooo`00Soooo`800008<ol000<0003oooooool0I_ooo`03o`2Ioooooooo01_oool008ooool0
0`0003?o03?o0007<ol000<0003oooooool0I_ooo`03o`2Ioooooooo01_oool008ooool00`0003?o
03?o0007<ol000<0003oooooool0I_ooo`03o`2Ioooooooo01_oool008ooool00`0003?o03?o0007
<ol000<0003oooooool0I_ooo`03o`2Ioooooooo01_oool008ooool00`0003?o03?o0006<ol000<0
003oooooool0Ioooo`03o`2Ioooooooo01_oool008ooool00`0003?o03?o0006<ol000<0003ooooo
ool0Ioooo`03o`2Ioooooooo01_oool008ooool200001c?o00030000oooooooo06Ooool00ol0VOoo
ooooo`0Koooo002?oooo00<0000co`0co`001S?o00030000oooooooo06Ooool00ol0VOooooooo`0K
oooo002?oooo00<0000co`0co`001S?o00030000oooooooo06Ooool00ol0VOooooooo`0Koooo002?
oooo00<0000co`0co`001S?o00030000oooooooo06Ooool00ol0VOooooooo`0Koooo002?oooo00<0
000co`0co`001S?o00030000oooooooo06Ooool00ol0VOooooooo`0Koooo002?oooo00<0000co`0c
o`001S?o00030000oooooooo06Ooool00ol0VOooooooo`0Koooo002?oooo0P0000Hco`000`000?oo
ooooo`1Xoooo00?o09Woooooool06oooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1X
oooo00?o09Woooooool06oooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Xoooo00?o
09Woooooool06oooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Xoooo00?o09Wooooo
ool06oooo`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Xoooo00?o09Woooooool06ooo
o`00Soooo`030000<ol0<ol000Dco`000`000?ooooooo`1Xoooo00?o09Woooooool06oooo`00Sooo
o`800006<ol000<0003oooooool0J?ooo`03o`2Ioooooooo01_oool008ooool00`0003?o03?o0005
<ol000<0003oooooool0J?ooo`03o`2Ioooooooo01_oool008ooool00`0003?o03?o0005<ol000<0
003oooooool0J?ooo`03o`2Ioooooooo01_oool008ooool00`0003?o03?o0004<ol000<0003ooooo
ool0JOooo`03o`2Ioooooooo01_oool008ooool00`0003?o03?o0004<ol000<0003oooooool0JOoo
o`03o`2Ioooooooo01_oool008Woool300000oooo`030000<ol0<ol000@co`000`000?ooooooo`1Y
oooo00?o09Woooooool06oooo`00R_ooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0
003oooooool0JOooo`03o`2Ioooooooo01_oool008Ooool500000oooo`<00004<ol000<0003ooooo
ool0JOooo`03o`2Ioooooooo01_oool008Ooool010000?ooooooo`0000Coool7<ol0R_ooo`00R?oo
o`030000oooo000000Coool7<ol0R_ooo`00ROooo`800004oooo1c?o08[oool008ooool7<ol0R_oo
o`00Soooo`Lco`2:oooo001loooo00<0003oooooool04?ooo`Lco`0;oooo00<0003oooooool0O?oo
o`00Noooo`030000oooooooo00Soool00`000?ooooooo`06oooo1c?o00coool00`000?ooooooo`1k
oooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003<ol00P00
00?oool300001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Goool00`0003?o03?o0004<ol01oooo`030000oooooooo
00;oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00goool0
0c?o000003?o0004<ol01_ooo`<00004oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000<oooo0S?o00030000<ol0<ol0008co`05oooo00@0003oooooool00003oooo00<0003ooooo
ool0Noooo`00Noooo`050000oooooooooooo000000ooool0100003?o03?o000000<co`05oooo00@0
003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo013oool00c?o0000
00000004<ol01_ooo`<00002oooo00<0003oooooool0O?ooo`00Soooo`Lco`2:oooo002?oooo1c?o
08[oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.37649, \
-1.14361, 0.0165645, 0.031907}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.37649, -1.14361, 0.0165645, 0.031907}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 819}},
ScreenStyleEnvironment->"Working",
WindowSize->{757, 792},
WindowMargins->{{Automatic, 169}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 170, 4, 96, "Title"],
Cell[1900, 58, 1143, 31, 277, "Text"],
Cell[3046, 91, 120, 4, 49, "Text"],
Cell[3169, 97, 630, 14, 19, "Input",
  CellOpen->False],
Cell[3802, 113, 121, 4, 49, "Text"],
Cell[3926, 119, 59, 1, 30, "Input"],
Cell[3988, 122, 108, 1, 49, "Text"],
Cell[4099, 125, 716, 16, 19, "Input",
  CellOpen->False],
Cell[4818, 143, 74, 2, 19, "Input",
  CellOpen->False],
Cell[4895, 147, 75, 2, 19, "Input",
  CellOpen->False],
Cell[4973, 151, 373, 12, 49, "Text"],

Cell[CellGroupData[{
Cell[5371, 167, 653, 11, 110, "Input"],

Cell[CellGroupData[{
Cell[6049, 182, 25167, 955, 186, 12428, 794, "GraphicsData", "PostScript", \
"Graphics"],
Cell[31219, 1139, 25234, 956, 186, 12430, 794, "GraphicsData", "PostScript", \
"Graphics"],
Cell[56456, 2097, 25244, 957, 186, 12431, 794, "GraphicsData", "PostScript", \
"Graphics"],
Cell[81703, 3056, 25217, 956, 186, 12429, 794, "GraphicsData", "PostScript", \
"Graphics"],
Cell[106923, 4014, 25248, 957, 186, 12431, 794, "GraphicsData", "PostScript", \
"Graphics"],
Cell[132174, 4973, 25184, 957, 186, 12444, 795, "GraphicsData", "PostScript", \
"Graphics"],
Cell[157361, 5932, 25292, 958, 186, 12447, 795, "GraphicsData", "PostScript", \
"Graphics"],
Cell[182656, 6892, 25280, 959, 186, 12463, 796, "GraphicsData", "PostScript", \
"Graphics"],
Cell[207939, 7853, 25266, 959, 186, 12478, 797, "GraphicsData", "PostScript", \
"Graphics"],
Cell[233208, 8814, 25287, 960, 186, 12478, 797, "GraphicsData", "PostScript", \
"Graphics"],
Cell[258498, 9776, 24644, 941, 186, 12062, 781, "GraphicsData", "PostScript", \
"Graphics"],
Cell[283145, 10719, 24872, 944, 186, 12084, 782, "GraphicsData", \
"PostScript", "Graphics"],
Cell[308020, 11665, 24865, 945, 186, 12101, 783, "GraphicsData", \
"PostScript", "Graphics"],
Cell[332888, 12612, 24873, 944, 186, 12085, 782, "GraphicsData", \
"PostScript", "Graphics"],
Cell[357764, 13558, 24901, 945, 186, 12101, 783, "GraphicsData", \
"PostScript", "Graphics"],
Cell[382668, 14505, 24802, 943, 186, 12083, 782, "GraphicsData", \
"PostScript", "Graphics"],
Cell[407473, 15450, 24924, 947, 186, 12115, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[432400, 16399, 24872, 945, 186, 12100, 783, "GraphicsData", \
"PostScript", "Graphics"],
Cell[457275, 17346, 24911, 946, 186, 12115, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[482189, 18294, 24881, 945, 186, 12101, 783, "GraphicsData", \
"PostScript", "Graphics"],
Cell[507073, 19241, 24797, 944, 186, 12098, 783, "GraphicsData", \
"PostScript", "Graphics"],
Cell[531873, 20187, 24915, 946, 186, 12115, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[556791, 21135, 24885, 946, 186, 12117, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[581679, 22083, 24922, 947, 186, 12130, 785, "GraphicsData", \
"PostScript", "Graphics"],
Cell[606604, 23032, 24921, 946, 186, 12117, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[631528, 23980, 24826, 945, 186, 12115, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[656357, 24927, 24962, 948, 186, 12133, 785, "GraphicsData", \
"PostScript", "Graphics"],
Cell[681322, 25877, 24921, 948, 186, 12149, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[706246, 26827, 24933, 947, 186, 12133, 785, "GraphicsData", \
"PostScript", "Graphics"],
Cell[731182, 27776, 24937, 947, 186, 12133, 785, "GraphicsData", \
"PostScript", "Graphics"],
Cell[756122, 28725, 24806, 946, 186, 12131, 785, "GraphicsData", \
"PostScript", "Graphics"],
Cell[780931, 29673, 24905, 946, 186, 12117, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[805839, 30621, 24896, 946, 186, 12116, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[830738, 31569, 24900, 946, 186, 12116, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[855641, 32517, 24932, 948, 186, 12148, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[880576, 33467, 24857, 947, 186, 12146, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[905436, 34416, 24932, 947, 186, 12132, 785, "GraphicsData", \
"PostScript", "Graphics"],
Cell[930371, 35365, 24935, 949, 186, 12163, 787, "GraphicsData", \
"PostScript", "Graphics"],
Cell[955309, 36316, 24935, 948, 186, 12147, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[980247, 37266, 24952, 949, 186, 12164, 787, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1005202, 38217, 24804, 945, 186, 12113, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1030009, 39164, 24908, 946, 186, 12116, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1054920, 40112, 24900, 947, 186, 12132, 785, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1079823, 41061, 24935, 948, 186, 12147, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1104761, 42011, 24957, 949, 186, 12148, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1129721, 42962, 24881, 948, 186, 12162, 787, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1154605, 43912, 24969, 949, 186, 12148, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1179577, 44863, 24948, 949, 186, 12164, 787, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1204528, 45814, 24948, 948, 186, 12148, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1229479, 46764, 24968, 949, 186, 12164, 787, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1254450, 47715, 24869, 949, 186, 12178, 788, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1279322, 48666, 24920, 950, 186, 12180, 788, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1304245, 49618, 24750, 946, 186, 12148, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1328998, 50566, 24653, 945, 186, 12148, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1353654, 51513, 24539, 944, 186, 12164, 787, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1378196, 52459, 24439, 944, 186, 12177, 788, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1402638, 53405, 24580, 945, 186, 12164, 787, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1427221, 54352, 23364, 930, 186, 12180, 788, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1450588, 55284, 22611, 920, 186, 12164, 787, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1473202, 56206, 22465, 919, 186, 12180, 788, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1495670, 57127, 22038, 913, 186, 12158, 787, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1517711, 58042, 22531, 933, 186, 12432, 804, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1540245, 58977, 22945, 939, 186, 12441, 805, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1563193, 59918, 23263, 946, 186, 12512, 809, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1586459, 60866, 25081, 968, 186, 12495, 808, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1611543, 61836, 24858, 965, 186, 12491, 808, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1636404, 62803, 24872, 966, 186, 12513, 809, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1661279, 63771, 24764, 964, 186, 12498, 808, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1686046, 64737, 24533, 960, 186, 12482, 807, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1710582, 65699, 24478, 961, 186, 12512, 809, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1735063, 66662, 24523, 963, 186, 12537, 811, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1759589, 67627, 24700, 965, 186, 12527, 810, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1784292, 68594, 24791, 967, 186, 12545, 811, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1809086, 69563, 25017, 969, 186, 12545, 811, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1834106, 70534, 25064, 971, 186, 12559, 812, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1859173, 71507, 25166, 976, 186, 12637, 817, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1884342, 72485, 25282, 973, 186, 12559, 812, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1909627, 73460, 25357, 976, 186, 12589, 814, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1934987, 74438, 25453, 976, 186, 12559, 812, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1960443, 75416, 25479, 973, 186, 12513, 809, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1985925, 76391, 25462, 976, 186, 12560, 812, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2011390, 77369, 25620, 978, 186, 12573, 813, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2037013, 78349, 25682, 980, 186, 12590, 814, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2062698, 79331, 25846, 988, 186, 12697, 821, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2088547, 80321, 25819, 983, 186, 12622, 816, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2114369, 81306, 25867, 989, 186, 12714, 822, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2140239, 82297, 25956, 988, 186, 12690, 820, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2166198, 83287, 25930, 988, 186, 12688, 820, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2192131, 84277, 26025, 990, 186, 12698, 821, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2218159, 85269, 26081, 991, 186, 12718, 822, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2244243, 86262, 26087, 996, 186, 12813, 828, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2270333, 87260, 26205, 999, 186, 12842, 830, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2296541, 88261, 26176, 997, 186, 12813, 828, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2322720, 89260, 26404, 1007, 186, 12952, 837, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2349127, 90269, 26402, 1006, 186, 12917, 835, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2375532, 91277, 26471, 1014, 186, 13059, 844, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2402006, 92293, 26702, 1023, 186, 13189, 852, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2428711, 93318, 26806, 1031, 186, 13317, 860, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2455520, 94351, 26827, 1030, 186, 13285, 858, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2482350, 95383, 26889, 1033, 186, 13339, 861, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2509242, 96418, 26766, 1031, 186, 13309, 860, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2536011, 97451, 26864, 1032, 186, 13310, 860, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2562878, 98485, 26920, 1036, 186, 13395, 865, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2589801, 99523, 26837, 1031, 186, 13295, 859, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2616641, 100556, 27010, 1042, 186, 13452, 870, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2643654, 101600, 26927, 1039, 186, 13438, 868, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2670584, 102641, 26940, 1038, 186, 13427, 867, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2697527, 103681, 26811, 1033, 186, 13350, 862, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2724341, 104716, 26909, 1040, 186, 13473, 870, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2751253, 105758, 26895, 1040, 186, 13467, 870, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2778151, 106800, 26627, 1033, 186, 13389, 865, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2804781, 107835, 26972, 1042, 186, 13483, 871, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2831756, 108879, 27027, 1046, 186, 13542, 875, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2858786, 109927, 26918, 1037, 186, 13409, 866, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2885707, 110966, 27025, 1040, 186, 13443, 868, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2912735, 112008, 26889, 1038, 186, 13420, 867, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2939627, 113048, 27023, 1041, 186, 13457, 869, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2966653, 114091, 26988, 1040, 186, 13446, 868, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2993644, 115133, 27045, 1042, 186, 13479, 870, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3020692, 116177, 27042, 1040, 186, 13444, 868, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3047737, 117219, 26978, 1040, 186, 13453, 869, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3074718, 118261, 27154, 1047, 186, 13523, 874, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3101875, 119310, 27090, 1045, 186, 13516, 873, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3128968, 120357, 27062, 1041, 186, 13443, 868, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3156033, 121400, 27139, 1044, 186, 13488, 871, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3183175, 122446, 27043, 1044, 186, 13493, 872, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3210221, 123492, 27256, 1050, 186, 13573, 877, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3237480, 124544, 27192, 1048, 186, 13545, 875, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3264675, 125594, 27160, 1045, 186, 13497, 872, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3291838, 126641, 27221, 1048, 186, 13542, 875, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3319062, 127691, 27096, 1048, 186, 13558, 876, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3346161, 128741, 27303, 1053, 186, 13628, 880, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3373467, 129796, 27156, 1043, 186, 13477, 870, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3400626, 130841, 27157, 1044, 186, 13486, 871, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3427786, 131887, 27107, 1041, 186, 13432, 868, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3454896, 132930, 27186, 1050, 186, 13592, 878, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3482085, 133982, 27173, 1044, 186, 13494, 871, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3509261, 135028, 27239, 1049, 186, 13568, 876, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3536503, 136079, 27155, 1043, 186, 13472, 870, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3563661, 137124, 27249, 1048, 186, 13533, 874, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3590913, 138174, 27106, 1044, 186, 13508, 872, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3618022, 139220, 27225, 1047, 186, 13534, 874, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3645250, 140269, 27247, 1049, 186, 13539, 875, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3672500, 141320, 27337, 1053, 186, 13605, 879, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3699840, 142375, 27262, 1048, 186, 13526, 874, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3727105, 143425, 27198, 1050, 186, 13579, 877, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3754306, 144477, 27322, 1050, 186, 13558, 876, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3781631, 145529, 27345, 1055, 186, 13641, 881, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3808979, 146586, 27253, 1048, 186, 13533, 874, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3836235, 147636, 27259, 1048, 186, 13523, 874, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3863497, 148686, 27170, 1048, 186, 13539, 875, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3890670, 149736, 27271, 1048, 186, 13531, 874, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3917944, 150786, 27335, 1054, 186, 13640, 881, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3945282, 151842, 27331, 1051, 186, 13575, 877, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3972616, 152895, 27445, 1058, 186, 13681, 884, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4000064, 153955, 27138, 1045, 186, 13507, 872, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

