(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2469112,     102613]*)
(*NotebookOutlinePosition[   2469855,     102638]*)
(*  CellTagsIndexPosition[   2469811,     102634]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["FOCUSING WITHIN NONHOMOGENEITY", "Text",
  FontSize->14,
  Background->None]], "Title",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  StyleBox["The wavefront  and the tail  are incident from the left.\n\nThe \
nonhomogeneity  ",
    FontSize->12],
  StyleBox["is located on the negative ",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"],
  StyleBox["x",
    FontSize->12,
    FontSlant->"Italic",
    CharacterEncoding->"WindowsANSI"],
  StyleBox["-axis.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"],
  StyleBox["  \n\nThe focusing location,  ",
    FontSize->12],
  StyleBox["x0",
    FontSize->12,
    FontVariations->{"CompatibilityType"->0},
    CharacterEncoding->"WindowsANSI"],
  StyleBox[" <0, is within the nonhomogeneity and needs to be specified. \n\n\
The potential   v[x], which is ",
    FontSize->12],
  StyleBox["the nonhomogeneity, is strictly positive.  \n\nThe transmission \
coefficient, left reflection coefficient, and right reflection coefficient, \
respectively, are denoted by  T[k],  L[k],  R[k].\n\nThe tail of the wave is \
denoted by  g[x,t].\n\nThe focusing moment is chosen as  t=0.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"]
}], "Text",
  FontSize->18,
  Background->RGBColor[1, 1, 0]],

Cell["\<\
The potential and the scattering coefficients are given next:\
\>", \
"Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(Clear[v, T, L, R, x0, g]; 
    v[x_] = UnitStep[\(-x\)]\ 16 \((Sqrt[2] + 
              1)\)^2\ E^\((\(-2\)\ Sqrt[
                  2]\ x)\)/\((\((1 + 
                        Sqrt[2])\)^2\ \ E^\((\(-2\)\ Sqrt[2]\ x)\) - 
                1)\)^2;\ \), "\[IndentingNewLine]", 
    \(\(T[k_] = k \((k + I\ Sqrt[2])\)/\((k + I)\)^2;\)\), "\n", 
    \(\(L[
          k_] = \(-2\) \((k + 
                I\ Sqrt[2])\)/\((\((k + I)\)^2\ \((k - 
                    I\ Sqrt[2])\))\);\)\), "\n", 
    \(\(R[k_] = 1/\((k + I)\)^2;\)\)}], "Input",
  CellOpen->False],

Cell["\<\
Specify the focusing location  x0, a nonnegative number, \
next:\
\>", "Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(\(x0 = \(-1\);\)\(\ \)\)\)], "Input"],

Cell["The tail  g[x,t]  of the focusing  wave is evaluated  next:", "Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(\(q[x_] = 
        2\ Sqrt[2]/\((\((1 + Sqrt[2])\)^2\ \ E^\((\(-2\)\ Sqrt[2]\ x)\) - 
                1)\);\)\), "\[IndentingNewLine]", 
    \(\(q0 = q[x0];\)\), "\[IndentingNewLine]", 
    \(\(q27[x_, t_] = 
        q0 - 2 + 
          Sqrt[2] + \((q0 - 1 + Sqrt[2])\) \((x - x0 - 
                t)\);\)\), "\[IndentingNewLine]", 
    \(\(q28[x_, t_] = 
        q[x]\ \((1 + 
              q0/\((2\ Sqrt[2])\))\)\ \ E^\((\(-Sqrt[2]\) \((x - x0 - 
                    t)\))\);\)\), "\[IndentingNewLine]", 
    \(\(q29[x_, t_] = 
        q0\ \((1 + 
              q[x]/\((2\ Sqrt[2])\))\)\ E^\((Sqrt[
                  2] \((x - x0 - t)\))\);\)\), "\[IndentingNewLine]", 
    \(\(q30[x_, 
          t_] = \(-2\)\ \ Sqrt[
            2]\ \((Sqrt[2] - 1)\)^2 \((1 + q[x]/\((2\ Sqrt[2])\))\) \((1 + 
              q0/\((2\ Sqrt[2])\))\) 
          E^\((\ Sqrt[2] \((x + x0 + t)\))\);\)\), "\[IndentingNewLine]", 
    \(\(q31[x_, 
          t_] = \(-q[
              x]\)\ q0\ \((\((Sqrt[2] + 1)\)^2\ /\((2\ Sqrt[
                    2])\))\)\ E^\((\(-Sqrt[2]\) \((x + x0 + 
                    t)\))\);\)\), "\[IndentingNewLine]", 
    \(\(q32[x_, 
          t_] = \((2\ q[x]\ q0 - \((Sqrt[2] - 1)\)^2 \((q[x] + q0)\) - 
              2\ Sqrt[2] \((Sqrt[2] - 1)\)^2)\)\ \ E^\((\ \(-\((x + x0 + 
                    t)\)\))\);\)\), "\[IndentingNewLine]", 
    \(\(q33[x_, 
          t_] = \(-\((x + x0 + t)\)\) \((Sqrt[2] - 1 + q[x])\) \((Sqrt[2] - 
              1 + q0)\)\ E^\((\(-\((x + x0 + 
                    t)\)\))\);\)\[IndentingNewLine]\n\), \
"\[IndentingNewLine]", 
    \(\(g[x_, t_] = \ 
        UnitStep[x]\ \ q27[x, 
              t]\ \ E^\((x - x0 - t)\)\ \ UnitStep[\(-x\) + x0 + t]\  + 
          UnitStep[\(-x\)] \((q28[x, t]\ \n\t\tUnitStep[x - x0 - t]\  + \ 
                q29[x, t]\ UnitStep[\(-x\) + x0 + t]\  + 
                q30[x, t]\ UnitStep[\(-x\) - x0 - t]\n + \((q31[x, t]\  + 
                      q32[x, t] + q33[x, t])\)\ UnitStep[
                    x + x0 + t]\ )\);\)\)}], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`Animation`\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`FilledPlot`\)], "Input",
  CellOpen->False],

Cell[TextData[{
  "The focusing wave is animated  next. The wavefront (",
  StyleBox["magenta",
    FontColor->RGBColor[1, 0, 1]],
  ") and the tail (",
  StyleBox["blue",
    FontColor->RGBColor[0, 0, 1]],
  ") are incident from the left onto the nonhomogeneity (",
  StyleBox["green",
    FontColor->RGBColor[0, 1, 0]],
  "):"
}], "Text",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Animate[{FilledPlot\[IndentingNewLine][{v[x]}, \ {x, \ \(-7\), \ 
              5}, \ PlotRange -> {\(-0.6\), 0.05}, \ 
            Fills \[Rule] {Hue[ .3]}], \[IndentingNewLine]\ \ \ \ \ \ \ \
Plot[{10\ UnitStep[x - x0 - t]}, \ {x, \ \(-7\), \ 5}, \ 
            PlotStyle \[Rule] \ Hue[ .9], 
            PlotRange -> {\(-0.6\), 
                0.05}], \[IndentingNewLine]\ \ \ \ \ \ \ Plot[{g[x, 
                t]}, {x, \ \(-7\), \ 5}, \ PlotStyle \[Rule] \ Hue[ .6], \ 
            PlotRange -> {\(-0.6\), 
                0.05}]}, \[IndentingNewLine]\ {t, \ \(-5\), \ 5.8,  .5}, 
        PlotLabel \[Rule] {"\<t\>", t}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -22.0938 0 ]
[.5 .63053 22.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -83.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.04262 .57049 L
.06244 .57049 L
.08255 .57049 L
.08806 .57049 L
.09396 .57049 L
.09682 .57049 L
.09952 .57049 L
.1007 .57049 L
.10195 .57049 L
.1026 .57049 L
s
.1026 .57049 m
.1026 .61803 L
s
0 .4 1 r
.02381 .57719 m
.04262 .57986 L
.06244 .58383 L
.07286 .58654 L
.08255 .58957 L
.0932 .59356 L
.09626 .59485 L
.09916 .59614 L
.10042 .59672 L
.10176 .59736 L
.10246 .59769 L
.10322 .57049 L
.10392 .57049 L
.10458 .57049 L
.10583 .57049 L
.10652 .57049 L
.10715 .57049 L
.10838 .57049 L
.10954 .57049 L
.1102 .57049 L
.1109 .57049 L
.11214 .57049 L
.11284 .57049 L
.11349 .57049 L
.1142 .57049 L
.11496 .57049 L
.11623 .57049 L
.11695 .57049 L
.11761 .57049 L
.11883 .57049 L
.12012 .57049 L
.12127 .57049 L
.12236 .57049 L
.12355 .57049 L
.12483 .57049 L
.12599 .57049 L
.12708 .57049 L
.12826 .57049 L
.12953 .57049 L
.13018 .57049 L
.13087 .57049 L
.13213 .57049 L
.13336 .57049 L
.13449 .57049 L
.13555 .57049 L
.13654 .57049 L
.13763 .57049 L
.13879 .57049 L
.14002 .57049 L
.14118 .57049 L
Mistroke
.14222 .57049 L
.14335 .57049 L
.144 .57049 L
.14469 .57049 L
.14591 .57049 L
.14723 .57049 L
.14798 .57049 L
.14868 .57049 L
.14995 .57049 L
.1511 .57049 L
.15174 .57049 L
.15244 .57049 L
.1537 .57049 L
.15482 .57049 L
.15606 .57049 L
.15735 .57049 L
.15856 .57049 L
.1597 .57049 L
.16073 .57049 L
.16187 .57049 L
.16306 .57049 L
.16438 .57049 L
.16558 .57049 L
.16624 .57049 L
.16696 .57049 L
.16826 .57049 L
.16948 .57049 L
.17078 .57049 L
.17188 .57049 L
.17309 .57049 L
.17383 .57049 L
.17452 .57049 L
.17583 .57049 L
.17655 .57049 L
.17723 .57049 L
.17797 .57049 L
.17876 .57049 L
.18005 .57049 L
.18127 .57049 L
.18197 .57049 L
.18261 .57049 L
.18331 .57049 L
.18405 .57049 L
.18528 .57049 L
.18593 .57049 L
.18662 .57049 L
.18788 .57049 L
.18904 .57049 L
.19016 .57049 L
.1912 .57049 L
Mistroke
.19235 .57049 L
.19358 .57049 L
.19488 .57049 L
.19562 .57049 L
.19631 .57049 L
.19756 .57049 L
.19826 .57049 L
.1989 .57049 L
.2001 .57049 L
.20141 .57049 L
.20264 .57049 L
.20377 .57049 L
.20483 .57049 L
.20597 .57049 L
.20704 .57049 L
.20802 .57049 L
.20917 .57049 L
.21042 .57049 L
.2116 .57049 L
.2127 .57049 L
.21382 .57049 L
.21487 .57049 L
.21603 .57049 L
.21727 .57049 L
.2185 .57049 L
.2198 .57049 L
.22091 .57049 L
.22213 .57049 L
.22345 .57049 L
.22467 .57049 L
.2253 .57049 L
.226 .57049 L
.22673 .57049 L
.22742 .57049 L
.22868 .57049 L
.22982 .57049 L
.23046 .57049 L
.23115 .57049 L
.23241 .57049 L
.23364 .57049 L
.23476 .57049 L
.23605 .57049 L
.23726 .57049 L
.23838 .57049 L
.23942 .57049 L
.24055 .57049 L
.24175 .57049 L
.24306 .57049 L
.24425 .57049 L
.24491 .57049 L
Mistroke
.24563 .57049 L
.24693 .57049 L
.24814 .57049 L
.24943 .57049 L
.25054 .57049 L
.25175 .57049 L
.25248 .57049 L
.25317 .57049 L
.25447 .57049 L
.2552 .57049 L
.25588 .57049 L
.25662 .57049 L
.25741 .57049 L
.25809 .57049 L
.25884 .57049 L
.25954 .57049 L
.26019 .57049 L
.26141 .57049 L
.26271 .57049 L
.26392 .57049 L
.26461 .57049 L
.26525 .57049 L
.26642 .57049 L
.26766 .57049 L
.26877 .57049 L
.26981 .57049 L
.27095 .57049 L
.27218 .57049 L
.27341 .57049 L
.27411 .57049 L
.27476 .57049 L
.27607 .57049 L
.27681 .57049 L
.27748 .57049 L
.27867 .57049 L
.27997 .57049 L
.2812 .57049 L
.28233 .57049 L
.28339 .57049 L
.28452 .57049 L
.2856 .57049 L
.28657 .57049 L
.28772 .57049 L
.28897 .57049 L
.29014 .57049 L
.29124 .57049 L
.29247 .57049 L
.29363 .57049 L
.29468 .57049 L
.2958 .57049 L
Mistroke
.29704 .57049 L
.29834 .57049 L
.29945 .57049 L
.30067 .57049 L
.30197 .57049 L
.30318 .57049 L
.30381 .57049 L
.30451 .57049 L
.30524 .57049 L
.30592 .57049 L
.30717 .57049 L
.30831 .57049 L
.30957 .57049 L
.31089 .57049 L
.31201 .57049 L
.3132 .57049 L
.31432 .57049 L
.31534 .57049 L
.31654 .57049 L
.31784 .57049 L
.31907 .57049 L
.3202 .57049 L
.32141 .57049 L
.32271 .57049 L
.32393 .57049 L
.32505 .57049 L
.32636 .57049 L
.3271 .57049 L
.32778 .57049 L
.32904 .57049 L
.32967 .57049 L
.33037 .57049 L
.33105 .57049 L
.33176 .57049 L
.33304 .57049 L
.33375 .57049 L
.33441 .57049 L
.33514 .57049 L
.33592 .57049 L
.33659 .57049 L
.33732 .57049 L
.33801 .57049 L
.33865 .57049 L
.33985 .57049 L
.34113 .57049 L
.34234 .57049 L
.34365 .57049 L
.34489 .57049 L
.34605 .57049 L
.34719 .57049 L
Mistroke
.34822 .57049 L
.34942 .57049 L
.35054 .57049 L
.35178 .57049 L
.35308 .57049 L
.35419 .57049 L
.35541 .57049 L
.35672 .57049 L
.35746 .57049 L
.35813 .57049 L
.35943 .57049 L
.36067 .57049 L
.36172 .57049 L
.36288 .57049 L
.36409 .57049 L
.36522 .57049 L
.36628 .57049 L
.36725 .57049 L
.36832 .57049 L
.36944 .57049 L
.37058 .57049 L
.3718 .57049 L
.37295 .57049 L
.37399 .57049 L
.37522 .57049 L
.37591 .57049 L
.37655 .57049 L
.37773 .57049 L
.37897 .57049 L
.38018 .57049 L
.3815 .57049 L
.38275 .57049 L
.38391 .57049 L
.38505 .57049 L
.38609 .57049 L
.38729 .57049 L
.38841 .57049 L
.38965 .57049 L
.39095 .57049 L
.39207 .57049 L
.39329 .57049 L
.3946 .57049 L
.39534 .57049 L
.39601 .57049 L
.39732 .57049 L
.39855 .57049 L
.3997 .57049 L
.40077 .57049 L
.40188 .57049 L
.40312 .57049 L
Mistroke
.40418 .57049 L
.40515 .57049 L
.40627 .57049 L
.40733 .57049 L
.40848 .57049 L
.40969 .57049 L
.41085 .57049 L
.41189 .57049 L
.41312 .57049 L
.41381 .57049 L
.41445 .57049 L
.41561 .57049 L
.41687 .57049 L
.41813 .57049 L
.41932 .57049 L
.42048 .57049 L
.42156 .57049 L
.42272 .57049 L
.424 .57049 L
.42464 .57049 L
.42533 .57049 L
.42659 .57049 L
.42769 .57049 L
.4289 .57049 L
.43016 .57049 L
.43133 .57049 L
.43243 .57049 L
.43343 .57049 L
.43458 .57049 L
.43567 .57049 L
.43687 .57049 L
.43818 .57049 L
.43884 .57049 L
.43955 .57049 L
.44083 .57049 L
.4421 .57049 L
.44331 .57049 L
.4444 .57049 L
.44558 .57049 L
.44631 .57049 L
.447 .57049 L
.44828 .57049 L
.449 .57049 L
.44966 .57049 L
.45039 .57049 L
.45116 .57049 L
.45243 .57049 L
.45362 .57049 L
.45494 .57049 L
.4556 .57049 L
Mistroke
.45633 .57049 L
.45698 .57049 L
.45767 .57049 L
.45894 .57049 L
.46019 .57049 L
.46135 .57049 L
.46261 .57049 L
.46333 .57049 L
.464 .57049 L
.46471 .57049 L
.46535 .57049 L
.4661 .57049 L
.4668 .57049 L
.468 .57049 L
.46927 .57049 L
.47036 .57049 L
.47155 .57049 L
.47284 .57049 L
.47356 .57049 L
.47421 .57049 L
.47549 .57049 L
.4767 .57049 L
.47788 .57049 L
.47894 .57049 L
.48016 .57049 L
.48132 .57049 L
.48239 .57049 L
.48337 .57049 L
.48445 .57049 L
.48559 .57049 L
.48674 .57049 L
.48798 .57049 L
.48915 .57049 L
.49021 .57049 L
.49145 .57049 L
.49216 .57049 L
.49281 .57049 L
.494 .57049 L
.49527 .57049 L
.49647 .57049 L
.49779 .57049 L
.49903 .57049 L
.50018 .57049 L
.50132 .57049 L
.50236 .57049 L
.50355 .57049 L
.50468 .57049 L
.50591 .57049 L
.50721 .57049 L
.50832 .57049 L
Mistroke
.50954 .57049 L
.51085 .57049 L
.51159 .57049 L
.51226 .57049 L
.51356 .57049 L
.5148 .57049 L
.51585 .57049 L
.517 .57049 L
.51821 .57049 L
.51935 .57049 L
.52041 .57049 L
.52138 .57049 L
.52244 .57049 L
.52356 .57049 L
.5247 .57049 L
.52592 .57049 L
.52707 .57049 L
.52812 .57049 L
.52934 .57049 L
.53004 .57049 L
.53068 .57049 L
.53185 .57049 L
.5331 .57049 L
.53431 .57049 L
.53563 .57049 L
.53687 .57049 L
.53803 .57049 L
.53914 .57049 L
.54035 .57049 L
.54149 .57049 L
.54253 .57049 L
.54378 .57049 L
.54511 .57049 L
.54622 .57049 L
.54744 .57049 L
.54875 .57049 L
.54948 .57049 L
.55015 .57049 L
.55144 .57049 L
.55267 .57049 L
.55372 .57049 L
.55488 .57049 L
.55609 .57049 L
.55723 .57049 L
.55829 .57049 L
.55926 .57049 L
.56032 .57049 L
.56144 .57049 L
.5626 .57049 L
.56367 .57049 L
Mistroke
.56494 .57049 L
.56609 .57049 L
.5673 .57049 L
.56861 .57049 L
.56984 .57049 L
.57098 .57049 L
.57224 .57049 L
.57343 .57049 L
.5745 .57049 L
.57567 .57049 L
.57693 .57049 L
.57757 .57049 L
.57828 .57049 L
.57953 .57049 L
.5807 .57049 L
.58978 .57049 L
.61043 .57049 L
.64908 .57049 L
.69018 .57049 L
.72977 .57049 L
.76784 .57049 L
.80837 .57049 L
.84737 .57049 L
.88884 .57049 L
.92878 .57049 L
.96721 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -22.0938 0 ]
[.5 .63053 22.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -83.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOoo
o`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002@oooo0P0000Coool200001?ooo`800006oooo00<0003ooooo
ool0NOooo`00Soooo`040000oooooooo00002?ooo`040000oooooooo00001Oooo`030000oooooooo
07Woool008ooool010000?ooooooo`0000_oool00`000?ooooooo`03oooo0P0007[oool008Woool4
00000_ooo`040000oooooooo00002Oooo`800006oooo00<0003oooooool0NOooo`00Soooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool3
00001Oooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool0
0:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?ooo`800004
oooo0P0000Goool300001?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000_oool0
0`000?ooooooo`03oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002?ooo`D00004
oooo0P0007[oool008Woool400000_ooo`040000oooooooo00002?ooo`040000oooooooo00001Ooo
o`030000oooooooo07Woool008ooool010000?ooooooo`0000Woool00`000?ooo`000005oooo00<0
003oooooool0NOooo`00T?ooo`80000;oooo0P0000Goool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool0093oool200001?ooo`800004oooo0P0000Koool00`000?ooooooo`1i
oooo002?oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool0NOoo
o`00Soooo`040000oooooooo00002_ooo`030000oooooooo00Coool20000N_ooo`00ROooo`@00002
oooo00@0003oooooool0000;oooo00<0003oooooool00oooo`030000oooooooo07Woool008ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P00
00[oool200001_ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?oo
o`800004oooo0P0000?oool400001Oooo`030000oooooooo07Woool008ooool010000?ooooooo`00
00Soool00`000?ooooooo`06oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool20000N_ooo`00ROooo`@00002oooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002@oooo0P0000Coool200000oooo`D00004oooo00<0003oooooool0NOooo`00Sooo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002?oooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`80001joooo0029oooo100000;oool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo
00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool002Woool30000:?ooo`<0000T
oooo100002Goool00`000?ooooooo`0Toooo100002Ooool300009oooo`00:Oooo`040000oooooooo
0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo0P0002Goool00`000?ooooooo`0Y
oooo00<0003oooooool09_ooo`00:Oooo`040000oooooooo00009Oooo`D0000Uoooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo1@0002Ooool002?oool400000_oo
o`<0000Poooo100000;oool010000?ooooooo`0001ooool400001?ooo`030000oooooooo02Coool0
0`000?ooooooo`0Voooo00<0003oooooool09?ooo`040000oooooooo0000:?ooo`00:_ooo`030000
oooooooo02Koool00`000?ooo`00000Uoooo00@0003oooooool0000Uoooo00<0003oooooool09?oo
o`040000oooooooo00009_ooo`030000oooo000002Soool002[oool300009oooo`80000Voooo0P00
02Koool00`000?ooooooo`0Uoooo0P0002Soool20000:?ooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`003Oooool0000600003_ooo`004oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00?o09T0003oool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oool0
0000300000Dco`000`0003?o03?o0008<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0008<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo01;oool001?oool306Ko4Oooo`03o`2I0000oooo02Ooool00`000?ooooooo`0Qoooo1P00
02Tco`000`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo02Ooool001Koool5
06Ko3?ooo`03o`2I06Kooooo053oool300009c?o00030000oooooooo07Woool001_oool606Ko1_oo
o`0306Kooooooooo05?oool200009C?o00030000oooooooo07Woool0027oool306Ko0oooo`0306Ko
oooooooo05Goool00`0003?o03?o000R<ol00P0007[oool002Coool206Ko00?oool0I_ooool0Eooo
o`030000<ol0<ol0024co`000`000?ooooooo`1ioooo000Voooo0P1VoeWoool200008C?o00030000
oooooooo07Woool002Ooool00ol0VOooooooo`1Ioooo00<0000co`0co`007S?o00030000oooooooo
07Woool002Ooool00ol0VOooooooo`1Ioooo00<0000co`0co`007S?o00030000oooooooo07Woool0
02Ooool00ol0VOooooooo`1Joooo00<0000co`0co`007C?o0080001joooo000Woooo00?o09Wooooo
ool0Foooo`030000<ol0<ol001`co`000`000?ooooooo`1ioooo000Woooo00?o09Woooooool0G?oo
o`030000<ol0<ol001/co`000`000?ooooooo`1ioooo000Woooo00?o09Woooooool0G?ooo`030000
<ol0<ol001/co`000`000?ooooooo`1ioooo0027oooo7C?o07coool008SooolL<ol0O?ooo`00R?oo
oa`co`1loooo0028oooo73?o07coool008WooolK<ol0O?ooo`00Ooooo`030000oooooooo00OooolE
<ol000<0000co`0co`000c?o07coool007koool00`000?ooooooo`08oooo00<0000co`0co`004c?o
00030000<ol0<ol0008co`1loooo001noooo00<0003oooooool00_ooo`800004oooo00<0000co`0c
o`003C?o00800004<ol000<0000co`0co`000S?o07coool007koool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000<ol0<ol000@co`0400000c?o00040000<ol0<ol000000c?o
00030000<ol0<ol0008co`1loooo001moooo00<0003oooooool00_ooo`030000oooooooo00Koool@
<ol000<0000co`0co`000S?o00040000<ol0<ol0<ol0O?ooo`00O_ooo`030000oooooooo00D00005
oooo3S?o00800004<ol000<0000co`0co`000S?o07coool007koool01@000?ooooooooooo`000009
oooo3C?o00030000<ol0<ol000<co`000`0003?o03?o0002<ol0O?ooo`00Ooooo`030000oooooooo
00[oool=<ol00`00008co`000`0003?o03?o0003<ol0O?ooo`00S?oooaPco`1loooo002<oooo63?o
07coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.08255 .57049 L
.10458 .57049 L
.11448 .57049 L
.12507 .57049 L
.1302 .57049 L
.13506 .57049 L
.13942 .57049 L
.14061 .57049 L
.14188 .57049 L
s
.14188 .57049 m
.14189 .61803 L
s
0 .4 1 r
.02381 .5738 m
.04262 .57511 L
.06244 .57707 L
.07286 .57841 L
.08255 .5799 L
.09388 .582 L
.10458 .58442 L
.11437 .58708 L
.125 .59053 L
.12969 .59228 L
.13466 .5943 L
.1389 .59617 L
.14006 .59671 L
.14131 .5973 L
.14249 .59787 L
.14357 .57049 L
.14486 .57049 L
.14607 .57049 L
.14716 .57049 L
.14834 .57049 L
.14962 .57049 L
.15027 .57049 L
.15098 .57049 L
.15224 .57049 L
.15342 .57049 L
.1545 .57049 L
.15568 .57049 L
.1568 .57049 L
.15783 .57049 L
.15903 .57049 L
.1603 .57049 L
.16137 .57049 L
.16256 .57049 L
.16387 .57049 L
.16452 .57049 L
.16524 .57049 L
.16652 .57049 L
.1677 .57049 L
.16842 .57049 L
.16911 .57049 L
.17038 .57049 L
.1711 .57049 L
.17176 .57049 L
.17248 .57049 L
.17325 .57049 L
.17444 .57049 L
.17572 .57049 L
.17692 .57049 L
.17803 .57049 L
.17932 .57049 L
Mistroke
.18005 .57049 L
.18072 .57049 L
.18196 .57049 L
.18328 .57049 L
.18453 .57049 L
.18524 .57049 L
.1859 .57049 L
.18659 .57049 L
.18723 .57049 L
.18796 .57049 L
.18866 .57049 L
.18989 .57049 L
.19102 .57049 L
.19227 .57049 L
.1929 .57049 L
.19359 .57049 L
.1943 .57049 L
.19504 .57049 L
.19567 .57049 L
.19636 .57049 L
.19711 .57049 L
.19791 .57049 L
.19866 .57049 L
.19934 .57049 L
.20004 .57049 L
.20068 .57049 L
.20138 .57049 L
.20212 .57049 L
.20473 .57049 L
.20596 .57049 L
.20713 .57049 L
.20778 .57049 L
.20848 .57049 L
.20971 .57049 L
.21087 .57049 L
.21212 .57049 L
.21318 .57049 L
.21435 .57049 L
.21502 .57049 L
.21572 .57049 L
.21697 .57049 L
.21767 .57049 L
.21832 .57049 L
.21903 .57049 L
.2198 .57049 L
.22046 .57049 L
.22118 .57049 L
.22248 .57049 L
.22375 .57049 L
.22492 .57049 L
Mistroke
.22617 .57049 L
.22735 .57049 L
.22842 .57049 L
.22958 .57049 L
.23084 .57049 L
.23154 .57049 L
.23218 .57049 L
.23342 .57049 L
.23459 .57049 L
.23569 .57049 L
.23687 .57049 L
.23799 .57049 L
.239 .57049 L
.24014 .57049 L
.24122 .57049 L
.24239 .57049 L
.24366 .57049 L
.24496 .57049 L
.24561 .57049 L
.24634 .57049 L
.24762 .57049 L
.24882 .57049 L
.25002 .57049 L
.25113 .57049 L
.2523 .57049 L
.25357 .57049 L
.25487 .57049 L
.2556 .57049 L
.25626 .57049 L
.25753 .57049 L
.25873 .57049 L
.2594 .57049 L
.26012 .57049 L
.2614 .57049 L
.26211 .57049 L
.26277 .57049 L
.2635 .57049 L
.26429 .57049 L
.26498 .57049 L
.26563 .57049 L
.26684 .57049 L
.26814 .57049 L
.26888 .57049 L
.26955 .57049 L
.27068 .57049 L
.27192 .57049 L
.27322 .57049 L
.27443 .57049 L
.27512 .57049 L
.27586 .57049 L
Mistroke
.27657 .57049 L
.27722 .57049 L
.27846 .57049 L
.27977 .57049 L
.28044 .57049 L
.28117 .57049 L
.28248 .57049 L
.28328 .57049 L
.28405 .57049 L
.28473 .57049 L
.28548 .57049 L
.28613 .57049 L
.28684 .57049 L
.28812 .57049 L
.28937 .57049 L
.29052 .57049 L
.29177 .57049 L
.29248 .57049 L
.29314 .57049 L
.29382 .57049 L
.29456 .57049 L
.29526 .57049 L
.2959 .57049 L
.29709 .57049 L
.29834 .57049 L
.2994 .57049 L
.30057 .57049 L
.30182 .57049 L
.30252 .57049 L
.30316 .57049 L
.30434 .57049 L
.30558 .57049 L
.30682 .57049 L
.30751 .57049 L
.30815 .57049 L
.30933 .57049 L
.31058 .57049 L
.3117 .57049 L
.31274 .57049 L
.31389 .57049 L
.31512 .57049 L
.31643 .57049 L
.31717 .57049 L
.31785 .57049 L
.31911 .57049 L
.31981 .57049 L
.32045 .57049 L
.32165 .57049 L
.32296 .57049 L
.32418 .57049 L
Mistroke
.32532 .57049 L
.32638 .57049 L
.32752 .57049 L
.3286 .57049 L
.32958 .57049 L
.33073 .57049 L
.33198 .57049 L
.33316 .57049 L
.33425 .57049 L
.33537 .57049 L
.33643 .57049 L
.33758 .57049 L
.33882 .57049 L
.34006 .57049 L
.34136 .57049 L
.34257 .57049 L
.34368 .57049 L
.34492 .57049 L
.34557 .57049 L
.34626 .57049 L
.34742 .57049 L
.34869 .57049 L
.34983 .57049 L
.35105 .57049 L
.35219 .57049 L
.35324 .57049 L
.35455 .57049 L
.35575 .57049 L
.35638 .57049 L
.35707 .57049 L
.3578 .57049 L
.35848 .57049 L
.35973 .57049 L
.36087 .57049 L
.36213 .57049 L
.36276 .57049 L
.36345 .57049 L
.36469 .57049 L
.36586 .57049 L
.36691 .57049 L
.36805 .57049 L
.36929 .57049 L
.37061 .57049 L
.37173 .57049 L
.37297 .57049 L
.37412 .57049 L
.37517 .57049 L
.37639 .57049 L
.37754 .57049 L
.3786 .57049 L
Mistroke
.37959 .57049 L
.38067 .57049 L
.38183 .57049 L
.38307 .57049 L
.38378 .57049 L
.38443 .57049 L
.38513 .57049 L
.38576 .57049 L
.38649 .57049 L
.38719 .57049 L
.38841 .57049 L
.38955 .57049 L
.39079 .57049 L
.39142 .57049 L
.39212 .57049 L
.39282 .57049 L
.39356 .57049 L
.39488 .57049 L
.39562 .57049 L
.3963 .57049 L
.39705 .57049 L
.39786 .57049 L
.39855 .57049 L
.39931 .57049 L
.40002 .57049 L
.40068 .57049 L
.40193 .57049 L
.40324 .57049 L
.4045 .57049 L
.40564 .57049 L
.40696 .57049 L
.40821 .57049 L
.40936 .57049 L
.41043 .57049 L
.4116 .57049 L
.41285 .57049 L
.41357 .57049 L
.41423 .57049 L
.41495 .57049 L
.41571 .57049 L
.41699 .57049 L
.41772 .57049 L
.4184 .57049 L
.41967 .57049 L
.42082 .57049 L
.42146 .57049 L
.42216 .57049 L
.42342 .57049 L
.42464 .57049 L
.42576 .57049 L
Mistroke
.42697 .57049 L
.42828 .57049 L
.4295 .57049 L
.43062 .57049 L
.4317 .57049 L
.43285 .57049 L
.43355 .57049 L
.43419 .57049 L
.4349 .57049 L
.43565 .57049 L
.43691 .57049 L
.43763 .57049 L
.43829 .57049 L
.43953 .57049 L
.44085 .57049 L
.44207 .57049 L
.44324 .57049 L
.44444 .57049 L
.44513 .57049 L
.44577 .57049 L
.44707 .57049 L
.44773 .57049 L
.44846 .57049 L
.44969 .57049 L
.45099 .57049 L
.45219 .57049 L
.4533 .57049 L
.45399 .57049 L
.45473 .57049 L
.45543 .57049 L
.45608 .57049 L
.4573 .57049 L
.4586 .57049 L
.45927 .57049 L
.45999 .57049 L
.46129 .57049 L
.46209 .57049 L
.46284 .57049 L
.46358 .57049 L
.46426 .57049 L
.46551 .57049 L
.46616 .57049 L
.46685 .57049 L
.46802 .57049 L
.4693 .57049 L
.47044 .57049 L
.47166 .57049 L
.47281 .57049 L
.47386 .57049 L
.47517 .57049 L
Mistroke
.47638 .57049 L
.47701 .57049 L
.4777 .57049 L
.47843 .57049 L
.47911 .57049 L
.48036 .57049 L
.48151 .57049 L
.48276 .57049 L
.48409 .57049 L
.48524 .57049 L
.48629 .57049 L
.4875 .57049 L
.48864 .57049 L
.4897 .57049 L
.49067 .57049 L
.49174 .57049 L
.49287 .57049 L
.49401 .57049 L
.49524 .57049 L
.49639 .57049 L
.49745 .57049 L
.49869 .57049 L
.49938 .57049 L
.50003 .57049 L
.50122 .57049 L
.50248 .57049 L
.50373 .57049 L
.50444 .57049 L
.5051 .57049 L
.5058 .57049 L
.50643 .57049 L
.50717 .57049 L
.50786 .57049 L
.5091 .57049 L
.51023 .57049 L
.51148 .57049 L
.51211 .57049 L
.51281 .57049 L
.51355 .57049 L
.51425 .57049 L
.51489 .57049 L
.51558 .57049 L
.51633 .57049 L
.51712 .57049 L
.51788 .57049 L
.51856 .57049 L
.51926 .57049 L
.51989 .57049 L
.5206 .57049 L
.52134 .57049 L
Mistroke
.52258 .57049 L
.52329 .57049 L
.52395 .57049 L
.52521 .57049 L
.52591 .57049 L
.52657 .57049 L
.52777 .57049 L
.52905 .57049 L
.53019 .57049 L
.53126 .57049 L
.53243 .57049 L
.5337 .57049 L
.53496 .57049 L
.53568 .57049 L
.53635 .57049 L
.53706 .57049 L
.5377 .57049 L
.53844 .57049 L
.53915 .57049 L
.54039 .57049 L
.54154 .57049 L
.5428 .57049 L
.54344 .57049 L
.54414 .57049 L
.54544 .57049 L
.54664 .57049 L
.54795 .57049 L
.54869 .57049 L
.54935 .57049 L
.55058 .57049 L
.55127 .57049 L
.5519 .57049 L
.55307 .57049 L
.5543 .57049 L
.55541 .57049 L
.55659 .57049 L
.55771 .57049 L
.55873 .57049 L
.55993 .57049 L
.56123 .57049 L
.56245 .57049 L
.56359 .57049 L
.56472 .57049 L
.56591 .57049 L
.56721 .57049 L
.56841 .57049 L
.56972 .57049 L
.57046 .57049 L
.57115 .57049 L
.57239 .57049 L
Mistroke
.57309 .57049 L
.57372 .57049 L
.57439 .57049 L
.57511 .57049 L
.57638 .57049 L
.57775 .57049 L
.57853 .57049 L
.57926 .57049 L
.58057 .57049 L
.58178 .57049 L
.58448 .57049 L
.62429 .57049 L
.66258 .57049 L
.70332 .57049 L
.74255 .57049 L
.78027 .57049 L
.82043 .57049 L
.85908 .57049 L
.90019 .57049 L
.93977 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOoo
o`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002@oooo0P0000Coool200001?ooo`800006oooo00<0003ooooo
ool0NOooo`00Soooo`040000oooooooo00002?ooo`040000oooooooo00001Oooo`030000oooooooo
07Woool008ooool010000?ooooooo`0000_oool00`000?ooooooo`03oooo0P0007[oool008Woool4
00000_ooo`040000oooooooo00002Oooo`800006oooo00<0003oooooool0NOooo`00Soooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool3
00001Oooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool0
0:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?ooo`800004
oooo0P0000Goool300001?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000_oool0
0`000?ooooooo`03oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002?ooo`D00004
oooo0P0007[oool008Woool400000_ooo`040000oooooooo00002?ooo`040000oooooooo00001Ooo
o`030000oooooooo07Woool008ooool010000?ooooooo`0000Woool00`000?ooo`000005oooo00<0
003oooooool0NOooo`00T?ooo`80000;oooo0P0000Goool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool0093oool200001?ooo`800004oooo0P0000Koool00`000?ooooooo`1i
oooo002?oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool0NOoo
o`00Soooo`040000oooooooo00002_ooo`030000oooooooo00Coool20000N_ooo`00ROooo`@00002
oooo00@0003oooooool0000;oooo00<0003oooooool00oooo`030000oooooooo07Woool008ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P00
00[oool200001_ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?oo
o`800004oooo0P0000?oool400001Oooo`030000oooooooo07Woool008ooool010000?ooooooo`00
00Soool00`000?ooooooo`06oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool20000N_ooo`00ROooo`@00002oooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002@oooo0P0000Coool200000oooo`D00004oooo00<0003oooooool0NOooo`00Sooo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002?oooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`80001joooo0029oooo100000;oool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo
00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool002Woool30000:?ooo`<0000T
oooo100002Goool00`000?ooooooo`0Toooo100002Ooool300009oooo`00:Oooo`040000oooooooo
0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo0P0002Goool00`000?ooooooo`0Y
oooo00<0003oooooool09_ooo`00:Oooo`040000oooooooo00009Oooo`D0000Uoooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo1@0002Ooool002?oool400000_oo
o`<0000Poooo100000;oool010000?ooooooo`0001ooool400001?ooo`030000oooooooo02Coool0
0`000?ooooooo`0Voooo00<0003oooooool09?ooo`040000oooooooo0000:?ooo`00:_ooo`030000
oooooooo02Koool00`000?ooo`00000Uoooo00@0003oooooool0000Uoooo00<0003oooooool09?oo
o`040000oooooooo00009_ooo`030000oooo000002Soool002[oool300009oooo`80000Voooo0P00
02Koool00`000?ooooooo`0Uoooo0P0002Soool20000:?ooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`003Oooool0000600003_ooo`004oooo`03000006Ko06Ko00D0I_l2
oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooo000000`00005<ol000<0000co`0co`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`0023?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`0Boooo000Koooo1P1Vo`Ooool00`000?ooooooo`07oooo00<0I_ooooooool07?oo
o`030000oooooooo027oool60000:C?o00030000oooooooo02Koool00`000?ooooooo`0Voooo00<0
003oooooool09oooo`008Oooo`H0I_l;oooo00<0I_ooooooool0AOooo`<0000W<ol000<0003ooooo
ool0NOooo`009oooo`80I_l9oooo00<0I_ooooooool0B?ooo`80000U<ol000<0003oooooool0NOoo
o`00:Oooo`<0I_l6oooo00<0I_ooooooool0B_ooo`030000<ol0<ol0028co`020000N_ooo`00;?oo
o`D0I_l00oooo`1Vooooo`1<oooo00<0000co`0co`008C?o00030000oooooooo07Woool0037oool2
06KoC_ooo`80000Q<ol000<0003oooooool0NOooo`00<_ooo`03o`2Ioooooooo04koool00`0003?o
03?o000N<ol000<0003oooooool0NOooo`00<_ooo`03o`2Ioooooooo04koool00`0003?o03?o000N
<ol000<0003oooooool0NOooo`00<_ooo`03o`2Ioooooooo04ooool00`0003?o03?o000M<ol00P00
07[oool003;oool00ol0VOooooooo`1@oooo00<0000co`0co`0073?o00030000oooooooo07Woool0
03;oool00ol0VOooooooo`1Aoooo00<0000co`0co`006c?o00030000oooooooo07Woool003;oool0
0ol0VOooooooo`1Aoooo00<0000co`0co`006c?o00030000oooooooo07Woool008OooolM<ol0O?oo
o`00R?oooa`co`1loooo0028oooo73?o07coool008SooolL<ol0O?ooo`00ROoooa/co`1loooo001i
oooo00<0003oooooool03Ooooa/co`000`000?ooooooo`1ioooo001hoooo00<0003oooooool02?oo
o`030000oooooooo00CooolJ<ol000?oool0003oool0NOooo`00N?ooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Coool:<ol00`00008co`02000013?o00800003<ol000?oool0003o
ool0NOooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01?ooo`@00006<ol000<0000co`0co`001S?o00040000<ol0<ol000000S?o0003oooo0000oooo
07Woool007Ooool00`000?ooooooo`02oooo00<0003oooooool03?ooo`Lco`0500002S?o00030000
<ol0<ol000;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000_oool7<ol000@0
000co`0co`000009<ol00P0000<co`000oooo`000?ooo`1ioooo001hoooo00D0003oooooooooool0
00003oooo`Lco`000`0003?o00000009<ol000<0000co`0co`000S?o0003oooo0000oooo07Woool0
07Woool00`000?ooooooo`0@oooo23?o00800009<ol00`00008co`000`000?ooooooo`1ioooo002<
oooo63?o07coool008cooolH<ol0O?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.16408 .57049 L
.17277 .57049 L
.17735 .57049 L
.17986 .57049 L
.18109 .57049 L
.18221 .57049 L
s
.18221 .57049 m
.18221 .61803 L
s
0 .4 1 r
.02381 .57212 m
.04262 .57277 L
.06244 .57373 L
.07286 .5744 L
.08255 .57513 L
.09388 .57617 L
.10458 .57736 L
.125 .58037 L
.14357 .58425 L
.16355 .59013 L
.17243 .5935 L
.17733 .5956 L
.17974 .59671 L
.18092 .59726 L
.18199 .59777 L
.18316 .57049 L
.1844 .57049 L
.18505 .57049 L
.18576 .57049 L
.18704 .57049 L
.18821 .57049 L
.18944 .57049 L
.1905 .57049 L
.19166 .57049 L
.19284 .57049 L
.19392 .57049 L
.19516 .57049 L
.19634 .57049 L
.19743 .57049 L
.19843 .57049 L
.19954 .57049 L
.20071 .57049 L
.2019 .57049 L
.20315 .57049 L
.2038 .57049 L
.20451 .57049 L
.20577 .57049 L
.20696 .57049 L
.20823 .57049 L
.20943 .57049 L
.21052 .57049 L
.21181 .57049 L
.21247 .57049 L
.21319 .57049 L
.21397 .57049 L
.21469 .57049 L
.21536 .57049 L
.21608 .57049 L
.21676 .57049 L
.21749 .57049 L
Mistroke
.21819 .57049 L
.21883 .57049 L
.22004 .57049 L
.22134 .57049 L
.22259 .57049 L
.22329 .57049 L
.22395 .57049 L
.22465 .57049 L
.22529 .57049 L
.22602 .57049 L
.22671 .57049 L
.22794 .57049 L
.22908 .57049 L
.23033 .57049 L
.23096 .57049 L
.23165 .57049 L
.23235 .57049 L
.23309 .57049 L
.23373 .57049 L
.23442 .57049 L
.23517 .57049 L
.23596 .57049 L
.23672 .57049 L
.2374 .57049 L
.23809 .57049 L
.23873 .57049 L
.23943 .57049 L
.24017 .57049 L
.24142 .57049 L
.24213 .57049 L
.24279 .57049 L
.24404 .57049 L
.24475 .57049 L
.2454 .57049 L
.2466 .57049 L
.24788 .57049 L
.24902 .57049 L
.25009 .57049 L
.25126 .57049 L
.25253 .57049 L
.25379 .57049 L
.25451 .57049 L
.25518 .57049 L
.25589 .57049 L
.25653 .57049 L
.25728 .57049 L
.25797 .57049 L
.25921 .57049 L
.25986 .57049 L
.26054 .57049 L
Mistroke
.2617 .57049 L
.26297 .57049 L
.26426 .57049 L
.26546 .57049 L
.26677 .57049 L
.26751 .57049 L
.26817 .57049 L
.2694 .57049 L
.27072 .57049 L
.27197 .57049 L
.27312 .57049 L
.27423 .57049 L
.27527 .57049 L
.27641 .57049 L
.27763 .57049 L
.27891 .57049 L
.28012 .57049 L
.2824 .57049 L
.2837 .57049 L
.28492 .57049 L
.28619 .57049 L
.28687 .57049 L
.28759 .57049 L
.28882 .57049 L
.2901 .57049 L
.2912 .57049 L
.2924 .57049 L
.29307 .57049 L
.2938 .57049 L
.29449 .57049 L
.29513 .57049 L
.29587 .57049 L
.29665 .57049 L
.29731 .57049 L
.29804 .57049 L
.29934 .57049 L
.30008 .57049 L
.30075 .57049 L
.30205 .57049 L
.30328 .57049 L
.30453 .57049 L
.30524 .57049 L
.30588 .57049 L
.30707 .57049 L
.30833 .57049 L
.30946 .57049 L
.31051 .57049 L
.31167 .57049 L
.3129 .57049 L
.31422 .57049 L
Mistroke
.31497 .57049 L
.31566 .57049 L
.31692 .57049 L
.31756 .57049 L
.31826 .57049 L
.31947 .57049 L
.32078 .57049 L
.32201 .57049 L
.32314 .57049 L
.32427 .57049 L
.32548 .57049 L
.32662 .57049 L
.32765 .57049 L
.32887 .57049 L
.33018 .57049 L
.33143 .57049 L
.33257 .57049 L
.33366 .57049 L
.33483 .57049 L
.33593 .57049 L
.33694 .57049 L
.33806 .57049 L
.33913 .57049 L
.34029 .57049 L
.34154 .57049 L
.34276 .57049 L
.34388 .57049 L
.3451 .57049 L
.34639 .57049 L
.34751 .57049 L
.34856 .57049 L
.3497 .57049 L
.35094 .57049 L
.35164 .57049 L
.35229 .57049 L
.35356 .57049 L
.35472 .57049 L
.35595 .57049 L
.35727 .57049 L
.3585 .57049 L
.3592 .57049 L
.35986 .57049 L
.36062 .57049 L
.36131 .57049 L
.36199 .57049 L
.36263 .57049 L
.36383 .57049 L
.36513 .57049 L
.36579 .57049 L
.36652 .57049 L
Mistroke
.36775 .57049 L
.36904 .57049 L
.37024 .57049 L
.37136 .57049 L
.37266 .57049 L
.3734 .57049 L
.37408 .57049 L
.37532 .57049 L
.37595 .57049 L
.37665 .57049 L
.37739 .57049 L
.37818 .57049 L
.37893 .57049 L
.37961 .57049 L
.38093 .57049 L
.38159 .57049 L
.38231 .57049 L
.38296 .57049 L
.38364 .57049 L
.38486 .57049 L
.38617 .57049 L
.38692 .57049 L
.38761 .57049 L
.38887 .57049 L
.39002 .57049 L
.39066 .57049 L
.39135 .57049 L
.39261 .57049 L
.39373 .57049 L
.39496 .57049 L
.39625 .57049 L
.39746 .57049 L
.39859 .57049 L
.39962 .57049 L
.40076 .57049 L
.40195 .57049 L
.40327 .57049 L
.40446 .57049 L
.40512 .57049 L
.40583 .57049 L
.40713 .57049 L
.40835 .57049 L
.40964 .57049 L
.41075 .57049 L
.41196 .57049 L
.41269 .57049 L
.41338 .57049 L
.41468 .57049 L
.41541 .57049 L
.41609 .57049 L
Mistroke
.41683 .57049 L
.41762 .57049 L
.4183 .57049 L
.41905 .57049 L
.41975 .57049 L
.4204 .57049 L
.42162 .57049 L
.42292 .57049 L
.42414 .57049 L
.42482 .57049 L
.42546 .57049 L
.42663 .57049 L
.42788 .57049 L
.42898 .57049 L
.43002 .57049 L
.43117 .57049 L
.4324 .57049 L
.43363 .57049 L
.43433 .57049 L
.43498 .57049 L
.43629 .57049 L
.43703 .57049 L
.4377 .57049 L
.4389 .57049 L
.4402 .57049 L
.44143 .57049 L
.44256 .57049 L
.44362 .57049 L
.44475 .57049 L
.44582 .57049 L
.4468 .57049 L
.44795 .57049 L
.44919 .57049 L
.45037 .57049 L
.45147 .57049 L
.4527 .57049 L
.45386 .57049 L
.45491 .57049 L
.45603 .57049 L
.45727 .57049 L
.45857 .57049 L
.45968 .57049 L
.46089 .57049 L
.46221 .57049 L
.46342 .57049 L
.46405 .57049 L
.46475 .57049 L
.46547 .57049 L
.46615 .57049 L
.46741 .57049 L
Mistroke
.46855 .57049 L
.46987 .57049 L
.47113 .57049 L
.47225 .57049 L
.47344 .57049 L
.47456 .57049 L
.47558 .57049 L
.47679 .57049 L
.47809 .57049 L
.47932 .57049 L
.48045 .57049 L
.48165 .57049 L
.48279 .57049 L
.4841 .57049 L
.4853 .57049 L
.48662 .57049 L
.48736 .57049 L
.48805 .57049 L
.4893 .57049 L
.48993 .57049 L
.49062 .57049 L
.4913 .57049 L
.49201 .57049 L
.49329 .57049 L
.494 .57049 L
.49467 .57049 L
.49539 .57049 L
.49617 .57049 L
.49684 .57049 L
.49757 .57049 L
.49826 .57049 L
.4989 .57049 L
.5001 .57049 L
.50138 .57049 L
.50259 .57049 L
.5039 .57049 L
.50515 .57049 L
.5063 .57049 L
.50745 .57049 L
.50848 .57049 L
.50968 .57049 L
.5108 .57049 L
.51203 .57049 L
.51317 .57049 L
.51436 .57049 L
.51567 .57049 L
.51636 .57049 L
.517 .57049 L
.51772 .57049 L
.51841 .57049 L
Mistroke
.51962 .57049 L
.52093 .57049 L
.52207 .57049 L
.52313 .57049 L
.52429 .57049 L
.52555 .57049 L
.52679 .57049 L
.5281 .57049 L
.52924 .57049 L
.53045 .57049 L
.53159 .57049 L
.53262 .57049 L
.53367 .57049 L
.53465 .57049 L
.5358 .57049 L
.53685 .57049 L
.53801 .57049 L
.53924 .57049 L
.54045 .57049 L
.54178 .57049 L
.54302 .57049 L
.54418 .57049 L
.54533 .57049 L
.54637 .57049 L
.5475 .57049 L
.54869 .57049 L
.55 .57049 L
.55121 .57049 L
.5525 .57049 L
.55324 .57049 L
.55392 .57049 L
.55516 .57049 L
.5563 .57049 L
.5576 .57049 L
.55884 .57049 L
.55989 .57049 L
.56105 .57049 L
.56227 .57049 L
.5634 .57049 L
.56446 .57049 L
.56543 .57049 L
.56656 .57049 L
.56762 .57049 L
.56876 .57049 L
.56998 .57049 L
.57114 .57049 L
.57218 .57049 L
.57341 .57049 L
.5741 .57049 L
.57474 .57049 L
Mistroke
.57592 .57049 L
.57716 .57049 L
.57838 .57049 L
.57906 .57049 L
.5797 .57049 L
.58087 .57049 L
.58211 .57049 L
.58663 .57049 L
.59679 .57049 L
.61512 .57049 L
.65287 .57049 L
.69307 .57049 L
.73175 .57049 L
.77289 .57049 L
.81251 .57049 L
.85061 .57049 L
.89117 .57049 L
.93021 .57049 L
.9717 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOoo
o`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002@oooo0P0000Coool200001?ooo`800006oooo00<0003ooooo
ool0NOooo`00Soooo`040000oooooooo00002?ooo`040000oooooooo00001Oooo`030000oooooooo
07Woool008ooool010000?ooooooo`0000_oool00`000?ooooooo`03oooo0P0007[oool008Woool4
00000_ooo`040000oooooooo00002Oooo`800006oooo00<0003oooooool0NOooo`00Soooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool3
00001Oooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool0
0:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?ooo`800004
oooo0P0000Goool300001?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000_oool0
0`000?ooooooo`03oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002?ooo`D00004
oooo0P0007[oool008Woool400000_ooo`040000oooooooo00002?ooo`040000oooooooo00001Ooo
o`030000oooooooo07Woool008ooool010000?ooooooo`0000Woool00`000?ooo`000005oooo00<0
003oooooool0NOooo`00T?ooo`80000;oooo0P0000Goool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool0093oool200001?ooo`800004oooo0P0000Koool00`000?ooooooo`1i
oooo002?oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool0NOoo
o`00Soooo`040000oooooooo00002_ooo`030000oooooooo00Coool20000N_ooo`00ROooo`@00002
oooo00@0003oooooool0000;oooo00<0003oooooool00oooo`030000oooooooo07Woool008ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P00
00[oool200001_ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?oo
o`800004oooo0P0000?oool400001Oooo`030000oooooooo07Woool008ooool010000?ooooooo`00
00Soool00`000?ooooooo`06oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool20000N_ooo`00ROooo`@00002oooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002@oooo0P0000Coool200000oooo`D00004oooo00<0003oooooool0NOooo`00Sooo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002?oooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`80001joooo0029oooo100000;oool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo
00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool002Woool30000:?ooo`<0000T
oooo100002Goool00`000?ooooooo`0Toooo100002Ooool300009oooo`00:Oooo`040000oooooooo
0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo0P0002Goool00`000?ooooooo`0Y
oooo00<0003oooooool09_ooo`00:Oooo`040000oooooooo00009Oooo`D0000Uoooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo1@0002Ooool002?oool400000_oo
o`<0000Poooo100000;oool010000?ooooooo`0001ooool400001?ooo`030000oooooooo02Coool0
0`000?ooooooo`0Voooo00<0003oooooool09?ooo`040000oooooooo0000:?ooo`00:_ooo`030000
oooooooo02Koool00`000?ooo`00000Uoooo00@0003oooooool0000Uoooo00<0003oooooool09?oo
o`040000oooooooo00009_ooo`030000oooo000002Soool002[oool300009oooo`80000Voooo0P00
02Koool00`000?ooooooo`0Uoooo0P0002Soool20000:?ooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`003Oooool0000600003_ooo`004oooo`03000006Ko06Ko00L0I_l0
0`00001Vo`1Vo`0406Ko1?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooo000000`00005<ol000<0000co`0co`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`0023?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`0Boooo000Toooo101Vo`03000006Ko06Ko017oool00`1Vooooooooo`0Boooo00<0
003oooooool08Oooo`H0000Y<ol000<0003oooooool09_ooo`030000oooooooo02Koool00`000?oo
ooooo`0Woooo000[oooo1@1Vo`coool00`1Vooooooooo`0koooo0`0002Lco`000`000?ooooooo`1i
oooo000`oooo1@1Vo`Ooool00`1Vooooooooo`0noooo0P0002Dco`000`000?ooooooo`1ioooo000e
oooo101Vo`?oool00`1Vooooooooo`10oooo00<0000co`0co`008S?o0080001joooo000ioooo0P1V
o`03oooo06Kooooo04;oool00`0003?o03?o000Q<ol000<0003oooooool0NOooo`00>oooo`80I_m4
oooo0P00024co`000`000?ooooooo`1ioooo000loooo00?o09Woooooool0A?ooo`030000<ol0<ol0
01hco`000`000?ooooooo`1ioooo000loooo00?o09Woooooool0A?ooo`030000<ol0<ol001hco`00
0`000?ooooooo`1ioooo000loooo00?o09Woooooool0AOooo`030000<ol0<ol001dco`020000N_oo
o`00??ooo`03o`2Ioooooooo04Koool00`0003?o03?o000L<ol000<0003oooooool0NOooo`00??oo
o`03o`2Ioooooooo04Ooool00`0003?o03?o000K<ol000<0003oooooool0NOooo`00??ooo`03o`2I
oooooooo04Ooool00`0003?o03?o000K<ol000<0003oooooool0NOooo`00Qooooadco`1loooo0028
oooo73?o07coool008SooolL<ol0O?ooo`00R?oooa`co`1loooo0029oooo6c?o07coool007coool0
0`000?ooooooo`0:oooo63?o00030000<ol0<ol007coool007_oool00`000?ooooooo`08oooo00@0
003ooooooooooolH<ol000<0000co`3oool0Noooo`00Noooo`030000oooooooo00;oool200001?oo
o`040000oooooooooooo3C?o00<00002<ol00P0000@co`000`0003?o0?ooo`1koooo001koooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool010000?ooooooooooo`<co`0400001S?o
00030000<ol0<ol000Lco`000`0003?o0?ooo`1koooo001joooo00<0003oooooool00_ooo`030000
oooooooo00Woool:<ol01@0000Tco`000`000?ooooooo`1joooo001koooo00<0003oooooool01@00
00Soool:<ol000@0000co`0co`000009<ol000<0000co`3oool0Noooo`00Noooo`050000oooooooo
oooo000000coool:<ol000<0000co`0000002C?o00030000<ol0oooo07_oool007coool00`000?oo
ooooo`0=oooo2c?o00800008<ol000<0000co`0co`00O?ooo`00S?oooaPco`1loooo002<oooo63?o
07coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.20178 .57049 L
.20742 .57049 L
.21274 .57049 L
.21753 .57049 L
.21884 .57049 L
.22022 .57049 L
.22141 .57049 L
s
.22141 .57049 m
.22142 .61803 L
s
0 .4 1 r
.02381 .5713 m
.04262 .57162 L
.06244 .57209 L
.07286 .57242 L
.08255 .57278 L
.09388 .57329 L
.10458 .57388 L
.125 .57537 L
.14357 .57728 L
.16355 .58018 L
.18199 .58394 L
.20071 .58927 L
.21136 .5932 L
.21653 .59539 L
.21905 .59653 L
.22015 .59704 L
.22134 .59761 L
.22257 .57049 L
.22374 .57049 L
.2263 .57049 L
.22701 .57049 L
.22767 .57049 L
.22836 .57049 L
.22912 .57049 L
.23037 .57049 L
.23108 .57049 L
.23172 .57049 L
.23298 .57049 L
.23414 .57049 L
.23542 .57049 L
.23607 .57049 L
.23678 .57049 L
.23798 .57049 L
.23926 .57049 L
.24047 .57049 L
.24158 .57049 L
.24266 .57049 L
.24382 .57049 L
.24491 .57049 L
.24589 .57049 L
.24706 .57049 L
.24832 .57049 L
.24951 .57049 L
.25061 .57049 L
.26011 .57049 L
.26992 .57049 L
.27058 .57049 L
.27128 .57049 L
.27204 .57049 L
.27275 .57049 L
Mistroke
.27348 .57049 L
.27416 .57049 L
.27543 .57049 L
.27669 .57049 L
.27785 .57049 L
.27912 .57049 L
.27976 .57049 L
.28047 .57049 L
.28175 .57049 L
.28296 .57049 L
.28405 .57049 L
.28523 .57049 L
.28651 .57049 L
.28716 .57049 L
.28788 .57049 L
.28914 .57049 L
.29032 .57049 L
.29145 .57049 L
.29263 .57049 L
.29364 .57049 L
.29475 .57049 L
.29594 .57049 L
.29722 .57049 L
.29842 .57049 L
.29951 .57049 L
.30064 .57049 L
.30188 .57049 L
.30318 .57049 L
.30439 .57049 L
.3055 .57049 L
.30655 .57049 L
.30777 .57049 L
.30888 .57049 L
.3101 .57049 L
.3114 .57049 L
.31251 .57049 L
.31373 .57049 L
.31504 .57049 L
.31578 .57049 L
.31645 .57049 L
.3177 .57049 L
.31901 .57049 L
.32014 .57049 L
.32121 .57049 L
.32244 .57049 L
.32356 .57049 L
.32461 .57049 L
.32559 .57049 L
.32666 .57049 L
.32779 .57049 L
Mistroke
.32893 .57049 L
.33015 .57049 L
.33131 .57049 L
.33236 .57049 L
.3336 .57049 L
.3343 .57049 L
.33495 .57049 L
.33613 .57049 L
.3374 .57049 L
.33864 .57049 L
.33936 .57049 L
.34001 .57049 L
.3407 .57049 L
.34143 .57049 L
.34212 .57049 L
.34276 .57049 L
.34399 .57049 L
.34513 .57049 L
.34637 .57049 L
.347 .57049 L
.3477 .57049 L
.3484 .57049 L
.34914 .57049 L
.35046 .57049 L
.3512 .57049 L
.35188 .57049 L
.35263 .57049 L
.35344 .57049 L
.35414 .57049 L
.35489 .57049 L
.3556 .57049 L
.35626 .57049 L
.35751 .57049 L
.35883 .57049 L
.36008 .57049 L
.36122 .57049 L
.36254 .57049 L
.36379 .57049 L
.36495 .57049 L
.36602 .57049 L
.36719 .57049 L
.36844 .57049 L
.36915 .57049 L
.36981 .57049 L
.37053 .57049 L
.37129 .57049 L
.37258 .57049 L
.3733 .57049 L
.37398 .57049 L
.37525 .57049 L
Mistroke
.37641 .57049 L
.37705 .57049 L
.37774 .57049 L
.379 .57049 L
.3802 .57049 L
.38135 .57049 L
.38267 .57049 L
.38387 .57049 L
.385 .57049 L
.38605 .57049 L
.38721 .57049 L
.38844 .57049 L
.38914 .57049 L
.38978 .57049 L
.39048 .57049 L
.39124 .57049 L
.39253 .57049 L
.39323 .57049 L
.39389 .57049 L
.39513 .57049 L
.39627 .57049 L
.39759 .57049 L
.39883 .57049 L
.40003 .57049 L
.40072 .57049 L
.40137 .57049 L
.40266 .57049 L
.40339 .57049 L
.40406 .57049 L
.40519 .57049 L
.40642 .57049 L
.4077 .57049 L
.4089 .57049 L
.40958 .57049 L
.41033 .57049 L
.41103 .57049 L
.41167 .57049 L
.4129 .57049 L
.4142 .57049 L
.41487 .57049 L
.41559 .57049 L
.41689 .57049 L
.41769 .57049 L
.41844 .57049 L
.41912 .57049 L
.41986 .57049 L
.42051 .57049 L
.42119 .57049 L
.42242 .57049 L
.42374 .57049 L
Mistroke
.42448 .57049 L
.42518 .57049 L
.42645 .57049 L
.4276 .57049 L
.42826 .57049 L
.42895 .57049 L
.43019 .57049 L
.43129 .57049 L
.4325 .57049 L
.43379 .57049 L
.43501 .57049 L
.43615 .57049 L
.4372 .57049 L
.43835 .57049 L
.43956 .57049 L
.44076 .57049 L
.44205 .57049 L
.44328 .57049 L
.44441 .57049 L
.44573 .57049 L
.44639 .57049 L
.44712 .57049 L
.4484 .57049 L
.44959 .57049 L
.45026 .57049 L
.45099 .57049 L
.45168 .57049 L
.45232 .57049 L
.45307 .57049 L
.45386 .57049 L
.45453 .57049 L
.45526 .57049 L
.45657 .57049 L
.45731 .57049 L
.45798 .57049 L
.45923 .57049 L
.46054 .57049 L
.46177 .57049 L
.46246 .57049 L
.46311 .57049 L
.46428 .57049 L
.46553 .57049 L
.46664 .57049 L
.46769 .57049 L
.46883 .57049 L
.47006 .57049 L
.47137 .57049 L
.47211 .57049 L
.47279 .57049 L
.47405 .57049 L
Mistroke
.47475 .57049 L
.47538 .57049 L
.47659 .57049 L
.47789 .57049 L
.47912 .57049 L
.48025 .57049 L
.48131 .57049 L
.48245 .57049 L
.48353 .57049 L
.48451 .57049 L
.48568 .57049 L
.48693 .57049 L
.488 .57049 L
.48918 .57049 L
.49037 .57049 L
.4915 .57049 L
.49271 .57049 L
.49402 .57049 L
.49518 .57049 L
.49641 .57049 L
.49746 .57049 L
.49861 .57049 L
.49993 .57049 L
.50114 .57049 L
.50245 .57049 L
.50315 .57049 L
.50389 .57049 L
.50515 .57049 L
.50632 .57049 L
.50701 .57049 L
.50766 .57049 L
.50888 .57049 L
.51001 .57049 L
.5112 .57049 L
.51233 .57049 L
.51335 .57049 L
.51456 .57049 L
.51586 .57049 L
.51709 .57049 L
.51822 .57049 L
.51944 .57049 L
.52074 .57049 L
.52197 .57049 L
.52309 .57049 L
.5244 .57049 L
.52514 .57049 L
.52583 .57049 L
.52708 .57049 L
.52772 .57049 L
.52842 .57049 L
Mistroke
.52913 .57049 L
.52981 .57049 L
.53109 .57049 L
.5318 .57049 L
.53247 .57049 L
.53319 .57049 L
.53397 .57049 L
.53464 .57049 L
.53537 .57049 L
.53606 .57049 L
.5367 .57049 L
.53797 .57049 L
.53917 .57049 L
.54035 .57049 L
.54163 .57049 L
.54279 .57049 L
.54387 .57049 L
.54502 .57049 L
.5463 .57049 L
.54695 .57049 L
.54764 .57049 L
.5489 .57049 L
.55009 .57049 L
.5512 .57049 L
.55236 .57049 L
.55363 .57049 L
.55465 .57049 L
.55572 .57049 L
.5569 .57049 L
.55798 .57049 L
.55926 .57049 L
.55999 .57049 L
.56067 .57049 L
.56189 .57049 L
.56321 .57049 L
.56448 .57049 L
.56569 .57049 L
.56678 .57049 L
.56796 .57049 L
.56869 .57049 L
.56937 .57049 L
.57064 .57049 L
.57136 .57049 L
.57202 .57049 L
.57274 .57049 L
.5735 .57049 L
.57477 .57049 L
.57595 .57049 L
.57725 .57049 L
.57797 .57049 L
Mistroke
.57864 .57049 L
.57982 .57049 L
.58093 .57049 L
.58345 .57049 L
.58856 .57049 L
.59774 .57049 L
.61851 .57049 L
.65722 .57049 L
.69839 .57049 L
.73804 .57049 L
.77618 .57049 L
.81677 .57049 L
.85584 .57049 L
.89737 .57049 L
.93738 .57049 L
.97587 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOoo
o`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002@oooo0P0000Coool200001?ooo`800006oooo00<0003ooooo
ool0NOooo`00Soooo`040000oooooooo00002?ooo`040000oooooooo00001Oooo`030000oooooooo
07Woool008ooool010000?ooooooo`0000_oool00`000?ooooooo`03oooo0P0007[oool008Woool4
00000_ooo`040000oooooooo00002Oooo`800006oooo00<0003oooooool0NOooo`00Soooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool3
00001Oooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool0
0:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?ooo`800004
oooo0P0000Goool300001?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000_oool0
0`000?ooooooo`03oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002?ooo`D00004
oooo0P0007[oool008Woool400000_ooo`040000oooooooo00002?ooo`040000oooooooo00001Ooo
o`030000oooooooo07Woool008ooool010000?ooooooo`0000Woool00`000?ooo`000005oooo00<0
003oooooool0NOooo`00T?ooo`80000;oooo0P0000Goool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool0093oool200001?ooo`800004oooo0P0000Koool00`000?ooooooo`1i
oooo002?oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool0NOoo
o`00Soooo`040000oooooooo00002_ooo`030000oooooooo00Coool20000N_ooo`00ROooo`@00002
oooo00@0003oooooool0000;oooo00<0003oooooool00oooo`030000oooooooo07Woool008ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P00
00[oool200001_ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?oo
o`800004oooo0P0000?oool400001Oooo`030000oooooooo07Woool008ooool010000?ooooooo`00
00Soool00`000?ooooooo`06oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool20000N_ooo`00ROooo`@00002oooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002@oooo0P0000Coool200000oooo`D00004oooo00<0003oooooool0NOooo`00Sooo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002?oooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`80001joooo0029oooo100000;oool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo
00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool002Woool30000:?ooo`<0000T
oooo100002Goool00`000?ooooooo`0Toooo100002Ooool300009oooo`00:Oooo`040000oooooooo
0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo0P0002Goool00`000?ooooooo`0Y
oooo00<0003oooooool09_ooo`00:Oooo`040000oooooooo00009Oooo`D0000Uoooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo1@0002Ooool002?oool400000_oo
o`<0000Poooo100000;oool010000?ooooooo`0001ooool400001?ooo`030000oooooooo02Coool0
0`000?ooooooo`0Voooo00<0003oooooool09?ooo`040000oooooooo0000:?ooo`00:_ooo`030000
oooooooo02Koool00`000?ooo`00000Uoooo00@0003oooooool0000Uoooo00<0003oooooool09?oo
o`040000oooooooo00009_ooo`030000oooo000002Soool002[oool300009oooo`80000Voooo0P00
02Koool00`000?ooooooo`0Uoooo0P0002Soool20000:?ooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`003Oooool0000600003_ooo`004oooo`030000oooooooo00L0I_l0
0`00001Vo`1Vo`0806Ko00<00000I_l0I_l01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00?o09T0003oool02?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oool0
0000300000Dco`000`0003?o03?o0008<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0008<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo01;oool002Soool00`000?ooooooo`0:06Ko4Oooo`03o`2I06Kooooo00Soool00`000?oo
ooooo`0Qoooo1P0002Tco`000`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool003Goool506Ko3?ooo`03o`2I06Kooooo037oool300009c?o00030000oooooooo07Woool0
03[oool506Ko1oooo`0306Kooooooooo03Coool200009C?o00030000oooooooo07Woool003ooool4
06Ko0oooo`0306Kooooooooo03Koool00`0003?o03?o000R<ol00P0007[oool004?oool206Ko00?o
ool0I_ooool0>?ooo`030000<ol0<ol0024co`000`000?ooooooo`1ioooo0015oooo0P1Voc[oool2
00008C?o00030000oooooooo07Woool004Koool00ol0VOooooooo`0joooo00<0000co`0co`007S?o
00030000oooooooo07Woool004Koool00ol0VOooooooo`0joooo00<0000co`0co`007S?o00030000
oooooooo07Woool004Koool00ol0VOooooooo`0koooo00<0000co`0co`007C?o0080001joooo0016
oooo00?o09Woooooool0??ooo`030000<ol0<ol001`co`000`000?ooooooo`1ioooo0016oooo00?o
09Woooooool0?Oooo`030000<ol0<ol001/co`000`000?ooooooo`1ioooo0016oooo00?o09Wooooo
ool0?Oooo`030000<ol0<ol001/co`000`000?ooooooo`1ioooo0027oooo7C?o07coool008SooolL
<ol0O?ooo`00R?oooa`co`1loooo0028oooo73?o07coool008WooolK<ol0O?ooo`00NOooo`030000
oooooooo00gooolK<ol000<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?oo
ooooo`04oooo6S?o0003oooo0000oooo07Woool007Soool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`04oooo2C?o00800004<ol00P0000@co`0200000c?o0003oooo0000oooo07Woool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool4
00000c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o0003oooo0000oooo07Woool0
07Ooool00`000?ooooooo`02oooo00<0003oooooool03?ooo`Tco`000`0003?o03?o000:<ol000<0
000co`0co`000_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500002oooo`Xco`00
0`0003?o03?o0007<ol00P0000<co`000oooo`000?ooo`1ioooo001hoooo00D0003oooooooooool0
00003oooo`Hco`00100003?o03?o000000Tco`000`0003?o03?o0002<ol000?oool0003oool0NOoo
o`00NOooo`030000oooooooo013oool7<ol00P0000Xco`0300000S?o00030000oooooooo07Woool0
08cooolH<ol0O?ooo`00S?oooaPco`1loooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.24141 .57049 L
.25127 .57049 L
.25666 .57049 L
.2593 .57049 L
.26045 .57049 L
.26171 .57049 L
s
.26171 .57049 m
.26172 .61803 L
s
0 .4 1 r
.02381 .57089 m
.04262 .57105 L
.06244 .57128 L
.07286 .57144 L
.08255 .57162 L
.09388 .57187 L
.10458 .57216 L
.125 .57289 L
.14357 .57384 L
.16355 .57527 L
.18199 .57712 L
.20071 .57975 L
.21136 .58169 L
.22134 .58386 L
.24158 .58967 L
.25055 .59299 L
.25547 .59506 L
.25789 .59614 L
.26011 .59717 L
.26132 .59775 L
.26259 .57049 L
.26387 .57049 L
.2646 .57049 L
.26527 .57049 L
.26644 .57049 L
.26769 .57049 L
.26886 .57049 L
.26995 .57049 L
.27106 .57049 L
.27223 .57049 L
.27323 .57049 L
.27433 .57049 L
.27551 .57049 L
.27679 .57049 L
.27799 .57049 L
.27909 .57049 L
.2803 .57049 L
.28159 .57049 L
.28281 .57049 L
.28392 .57049 L
.28522 .57049 L
.28595 .57049 L
.28663 .57049 L
.28787 .57049 L
.28919 .57049 L
.29045 .57049 L
.29116 .57049 L
.2918 .57049 L
.29306 .57049 L
.29425 .57049 L
Mistroke
.29492 .57049 L
.29563 .57049 L
.29691 .57049 L
.29758 .57049 L
.2983 .57049 L
.29909 .57049 L
.29982 .57049 L
.30052 .57049 L
.30119 .57049 L
.30243 .57049 L
.30376 .57049 L
.3045 .57049 L
.30519 .57049 L
.30633 .57049 L
.30759 .57049 L
.3089 .57049 L
.31013 .57049 L
.31078 .57049 L
.3115 .57049 L
.31224 .57049 L
.31293 .57049 L
.31417 .57049 L
.31487 .57049 L
.31549 .57049 L
.31624 .57049 L
.31692 .57049 L
.31767 .57049 L
.31847 .57049 L
.31916 .57049 L
.3198 .57049 L
.32051 .57049 L
.32127 .57049 L
.32192 .57049 L
.32262 .57049 L
.32386 .57049 L
.32456 .57049 L
.32532 .57049 L
.32603 .57049 L
.32669 .57049 L
.32788 .57049 L
.32913 .57049 L
.33041 .57049 L
.33114 .57049 L
.33182 .57049 L
.33308 .57049 L
.33426 .57049 L
.33532 .57049 L
.33648 .57049 L
.33773 .57049 L
.33837 .57049 L
Mistroke
.33906 .57049 L
.3403 .57049 L
.34145 .57049 L
.3427 .57049 L
.34339 .57049 L
.34403 .57049 L
.34528 .57049 L
.34642 .57049 L
.34708 .57049 L
.34778 .57049 L
.34903 .57049 L
.34972 .57049 L
.35037 .57049 L
.35108 .57049 L
.35184 .57049 L
.35311 .57049 L
.35383 .57049 L
.3545 .57049 L
.35571 .57049 L
.35701 .57049 L
.35816 .57049 L
.35925 .57049 L
.36043 .57049 L
.36172 .57049 L
.36288 .57049 L
.36397 .57049 L
.36516 .57049 L
.36643 .57049 L
.36707 .57049 L
.36776 .57049 L
.36902 .57049 L
.37025 .57049 L
.37138 .57049 L
.37246 .57049 L
.37361 .57049 L
.3747 .57049 L
.37569 .57049 L
.3768 .57049 L
.37786 .57049 L
.379 .57049 L
.38024 .57049 L
.3809 .57049 L
.38158 .57049 L
.38281 .57049 L
.38413 .57049 L
.38488 .57049 L
.38558 .57049 L
.38685 .57049 L
.38801 .57049 L
.38864 .57049 L
Mistroke
.38934 .57049 L
.3906 .57049 L
.39172 .57049 L
.39296 .57049 L
.39426 .57049 L
.39547 .57049 L
.39651 .57049 L
.39762 .57049 L
.39884 .57049 L
.39997 .57049 L
.4007 .57049 L
.40139 .57049 L
.40268 .57049 L
.40391 .57049 L
.40461 .57049 L
.40525 .57049 L
.40637 .57049 L
.4076 .57049 L
.40888 .57049 L
.41008 .57049 L
.41076 .57049 L
.41149 .57049 L
.41219 .57049 L
.41283 .57049 L
.41404 .57049 L
.41533 .57049 L
.416 .57049 L
.41671 .57049 L
.41801 .57049 L
.41876 .57049 L
.41955 .57049 L
.42022 .57049 L
.42096 .57049 L
.42228 .57049 L
.4235 .57049 L
.42413 .57049 L
.42483 .57049 L
.42556 .57049 L
.42624 .57049 L
.4275 .57049 L
.42865 .57049 L
.42928 .57049 L
.42997 .57049 L
.43123 .57049 L
.43246 .57049 L
.43358 .57049 L
.43486 .57049 L
.43607 .57049 L
.4372 .57049 L
.43823 .57049 L
Mistroke
.43937 .57049 L
.44056 .57049 L
.44187 .57049 L
.44306 .57049 L
.44372 .57049 L
.44443 .57049 L
.44573 .57049 L
.44695 .57049 L
.44824 .57049 L
.44934 .57049 L
.45055 .57049 L
.45125 .57049 L
.45198 .57049 L
.45328 .57049 L
.454 .57049 L
.45468 .57049 L
.45542 .57049 L
.45621 .57049 L
.45689 .57049 L
.45764 .57049 L
.45834 .57049 L
.45899 .57049 L
.46021 .57049 L
.46151 .57049 L
.46273 .57049 L
.46405 .57049 L
.4653 .57049 L
.46645 .57049 L
.46758 .57049 L
.46864 .57049 L
.46975 .57049 L
.47097 .57049 L
.47221 .57049 L
.47351 .57049 L
.47463 .57049 L
.47585 .57049 L
.47717 .57049 L
.4779 .57049 L
.47857 .57049 L
.47988 .57049 L
.48111 .57049 L
.48217 .57049 L
.48333 .57049 L
.48455 .57049 L
.48568 .57049 L
.48675 .57049 L
.48772 .57049 L
.48884 .57049 L
.4899 .57049 L
.49105 .57049 L
Mistroke
.49227 .57049 L
.49342 .57049 L
.49446 .57049 L
.49569 .57049 L
.49639 .57049 L
.49702 .57049 L
.4982 .57049 L
.49944 .57049 L
.50066 .57049 L
.50135 .57049 L
.50199 .57049 L
.50316 .57049 L
.5044 .57049 L
.50551 .57049 L
.50655 .57049 L
.50769 .57049 L
.50892 .57049 L
.51016 .57049 L
.51085 .57049 L
.51148 .57049 L
.51271 .57049 L
.51387 .57049 L
.51506 .57049 L
.51636 .57049 L
.51705 .57049 L
.51778 .57049 L
.51908 .57049 L
.52021 .57049 L
.52128 .57049 L
.52251 .57049 L
.52364 .57049 L
.52488 .57049 L
.52558 .57049 L
.52623 .57049 L
.5274 .57049 L
.52865 .57049 L
.52979 .57049 L
.53102 .57049 L
.53218 .57049 L
.53325 .57049 L
.53422 .57049 L
.53528 .57049 L
.53639 .57049 L
.53742 .57049 L
.53868 .57049 L
.53932 .57049 L
.54003 .57049 L
.54127 .57049 L
.54244 .57049 L
.54315 .57049 L
Mistroke
.54381 .57049 L
.54507 .57049 L
.54577 .57049 L
.54642 .57049 L
.54714 .57049 L
.5479 .57049 L
.54918 .57049 L
.54991 .57049 L
.55058 .57049 L
.5518 .57049 L
.5531 .57049 L
.55426 .57049 L
.55535 .57049 L
.55654 .57049 L
.55782 .57049 L
.55905 .57049 L
.5602 .57049 L
.56146 .57049 L
.5621 .57049 L
.5628 .57049 L
.56397 .57049 L
.56524 .57049 L
.56643 .57049 L
.56753 .57049 L
.56859 .57049 L
.56959 .57049 L
.57068 .57049 L
.57184 .57049 L
.57306 .57049 L
.57422 .57049 L
.57526 .57049 L
.57639 .57049 L
.57761 .57049 L
.57874 .57049 L
.58004 .57049 L
.58127 .57049 L
.58584 .57049 L
.59624 .57049 L
.61728 .57049 L
.6555 .57049 L
.69617 .57049 L
.73533 .57049 L
.77694 .57049 L
.81703 .57049 L
.85561 .57049 L
.89664 .57049 L
.93616 .57049 L
.97416 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOoo
o`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002@oooo0P0000Coool200001?ooo`800006oooo00<0003ooooo
ool0NOooo`00Soooo`040000oooooooo00002?ooo`040000oooooooo00001Oooo`030000oooooooo
07Woool008ooool010000?ooooooo`0000_oool00`000?ooooooo`03oooo0P0007[oool008Woool4
00000_ooo`040000oooooooo00002Oooo`800006oooo00<0003oooooool0NOooo`00Soooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool3
00001Oooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool0
0:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?ooo`800004
oooo0P0000Goool300001?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000_oool0
0`000?ooooooo`03oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002?ooo`D00004
oooo0P0007[oool008Woool400000_ooo`040000oooooooo00002?ooo`040000oooooooo00001Ooo
o`030000oooooooo07Woool008ooool010000?ooooooo`0000Woool00`000?ooo`000005oooo00<0
003oooooool0NOooo`00T?ooo`80000;oooo0P0000Goool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool0093oool200001?ooo`800004oooo0P0000Koool00`000?ooooooo`1i
oooo002?oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool0NOoo
o`00Soooo`040000oooooooo00002_ooo`030000oooooooo00Coool20000N_ooo`00ROooo`@00002
oooo00@0003oooooool0000;oooo00<0003oooooool00oooo`030000oooooooo07Woool008ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P00
00[oool200001_ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?oo
o`800004oooo0P0000?oool400001Oooo`030000oooooooo07Woool008ooool010000?ooooooo`00
00Soool00`000?ooooooo`06oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool20000N_ooo`00ROooo`@00002oooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002@oooo0P0000Coool200000oooo`D00004oooo00<0003oooooool0NOooo`00Sooo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002?oooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`80001joooo0029oooo100000;oool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo
00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool002Woool30000:?ooo`<0000T
oooo100002Goool00`000?ooooooo`0Toooo100002Ooool300009oooo`00:Oooo`040000oooooooo
0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo0P0002Goool00`000?ooooooo`0Y
oooo00<0003oooooool09_ooo`00:Oooo`040000oooooooo00009Oooo`D0000Uoooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo1@0002Ooool002?oool400000_oo
o`<0000Poooo100000;oool010000?ooooooo`0001ooool400001?ooo`030000oooooooo02Coool0
0`000?ooooooo`0Voooo00<0003oooooool09?ooo`040000oooooooo0000:?ooo`00:_ooo`030000
oooooooo02Koool00`000?ooo`00000Uoooo00@0003oooooool0000Uoooo00<0003oooooool09?oo
o`040000oooooooo00009_ooo`030000oooo000002Soool002[oool300009oooo`80000Voooo0P00
02Koool00`000?ooooooo`0Uoooo0P0002Soool20000:?ooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`003Oooool0000600003_ooo`004oooo`030000oooooooo00Ooool0
0`000?ooo`1Vo`0806Ko00<00000I_l0I_l01`1Vo`03000006Ko06Ko00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oool0
0000300000Dco`000`0003?o03?o0008<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0008<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo01;oool002Soool00`000?ooooooo`0:oooo2P1Voa;oool00`000?ooooooo`0Qoooo1P00
02Tco`000`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo02Ooool003ooool6
06Ko3?ooo`0306Kooooooooo02Koool300009c?o00030000oooooooo07Woool004Goool406Ko2?oo
o`0306Kooooooooo02Woool200009C?o00030000oooooooo07Woool004Woool406Ko1?ooo`0306Ko
oooooooo02_oool00`0003?o03?o000R<ol00P0007[oool004goool206Ko0_ooo`0306Kooooooooo
02coool00`0003?o03?o000Q<ol000<0003oooooool0NOooo`00Coooo`<0I_l_oooo0P00024co`00
0`000?ooooooo`1ioooo001Aoooo00?o09Woooooool0;oooo`030000<ol0<ol001hco`000`000?oo
ooooo`1ioooo001Aoooo00?o09Woooooool0;oooo`030000<ol0<ol001hco`000`000?ooooooo`1i
oooo001Aoooo00?o09Woooooool0<?ooo`030000<ol0<ol001dco`020000N_ooo`00DOooo`03o`2I
oooooooo037oool00`0003?o03?o000L<ol000<0003oooooool0NOooo`00DOooo`03o`2Ioooooooo
03;oool00`0003?o03?o000K<ol000<0003oooooool0NOooo`00DOooo`03o`2Ioooooooo03;oool0
0`0003?o03?o000K<ol000<0003oooooool0NOooo`00Qooooadco`1loooo0028oooo73?o07coool0
08SooolL<ol0O?ooo`00R?oooa`co`1loooo0029oooo6c?o07coool007coool00`000?ooooooo`0:
oooo63?o00030000<ol0<ol007coool007_oool00`000?ooooooo`08oooo00@0003ooooooooooolH
<ol000<0000co`3oool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`040000oooooooo
oooo33?o00800004<ol00P0000@co`000`0003?o0?ooo`1koooo001koooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool010000?ooooooooooo`<co`0400000c?o00040000<ol0<ol0
00002C?o00030000<ol0oooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool02Ooo
o``co`000`0003?o03?o0009<ol000<0003oooooool0N_ooo`00Noooo`030000oooooooo00D00008
oooo3C?o00030000<ol0<ol000Lco`000`0003?o0?ooo`1koooo001koooo00D0003oooooooooool0
00003?ooo`Tco`00100003?o03?o000000Tco`000`0003?o0?ooo`1koooo001loooo00<0003ooooo
ool03Oooo`Xco`0200002C?o00030000<ol0<ol007coool008cooolH<ol0O?ooo`00S?oooaPco`1l
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.26171 .57049 L
.27193 .57049 L
.28302 .57049 L
.2881 .57049 L
.29349 .57049 L
.29809 .57049 L
.29935 .57049 L
.30004 .57049 L
.3007 .57049 L
s
.3007 .57049 m
.30071 .61803 L
s
0 .4 1 r
.02381 .57069 m
.04262 .57077 L
.06244 .57088 L
.07286 .57096 L
.08255 .57105 L
.09388 .57117 L
.10458 .57132 L
.125 .57168 L
.14357 .57214 L
.16355 .57285 L
.18199 .57376 L
.20071 .57505 L
.21136 .57601 L
.22134 .57708 L
.24158 .57994 L
.26011 .58364 L
.27909 .58893 L
.28984 .59282 L
.29504 .59499 L
.29732 .596 L
.29861 .5966 L
.29982 .59717 L
.30101 .59774 L
.30229 .57049 L
.30299 .57049 L
.30365 .57049 L
.30489 .57049 L
.30556 .57049 L
.30626 .57049 L
.30752 .57049 L
.30823 .57049 L
.30888 .57049 L
.30961 .57049 L
.31039 .57049 L
.31159 .57049 L
.31292 .57049 L
.31358 .57049 L
.3143 .57049 L
.31558 .57049 L
.31686 .57049 L
.31807 .57049 L
.31916 .57049 L
.32034 .57049 L
.32151 .57049 L
.32277 .57049 L
.32396 .57049 L
.32504 .57049 L
.32626 .57049 L
.32741 .57049 L
.32866 .57049 L
Mistroke
.32937 .57049 L
.33002 .57049 L
.33119 .57049 L
.33229 .57049 L
.33328 .57049 L
.33435 .57049 L
.33551 .57049 L
.33674 .57049 L
.3378 .57049 L
.33895 .57049 L
.34026 .57049 L
.34147 .57049 L
.3421 .57049 L
.3428 .57049 L
.34352 .57049 L
.34421 .57049 L
.34546 .57049 L
.3466 .57049 L
.34786 .57049 L
.34918 .57049 L
.3503 .57049 L
.35149 .57049 L
.35261 .57049 L
.35363 .57049 L
.35483 .57049 L
.35614 .57049 L
.35736 .57049 L
.3585 .57049 L
.35971 .57049 L
.361 .57049 L
.36223 .57049 L
.36334 .57049 L
.36465 .57049 L
.36539 .57049 L
.36608 .57049 L
.36733 .57049 L
.36797 .57049 L
.36867 .57049 L
.36935 .57049 L
.37006 .57049 L
.37134 .57049 L
.37206 .57049 L
.37283 .57049 L
.37355 .57049 L
.37421 .57049 L
.37549 .57049 L
.3767 .57049 L
.37801 .57049 L
.37874 .57049 L
.37942 .57049 L
Mistroke
.38067 .57049 L
.38186 .57049 L
.38293 .57049 L
.38409 .57049 L
.38535 .57049 L
.38605 .57049 L
.38669 .57049 L
.3891 .57049 L
.39019 .57049 L
.39134 .57049 L
.39261 .57049 L
.39377 .57049 L
.39485 .57049 L
.39587 .57049 L
.39698 .57049 L
.39816 .57049 L
.39883 .57049 L
.39954 .57049 L
.40082 .57049 L
.40153 .57049 L
.40219 .57049 L
.40292 .57049 L
.40371 .57049 L
.40435 .57049 L
.40504 .57049 L
.40577 .57049 L
.40645 .57049 L
.40774 .57049 L
.40896 .57049 L
.41015 .57049 L
.41145 .57049 L
.41263 .57049 L
.41372 .57049 L
.41489 .57049 L
.41618 .57049 L
.41683 .57049 L
.41753 .57049 L
.4188 .57049 L
.41948 .57049 L
.42013 .57049 L
.42135 .57049 L
.42265 .57049 L
.42338 .57049 L
.42406 .57049 L
.42519 .57049 L
.42643 .57049 L
.42773 .57049 L
.42894 .57049 L
.42962 .57049 L
.43037 .57049 L
Mistroke
.43108 .57049 L
.43173 .57049 L
.43296 .57049 L
.43427 .57049 L
.43495 .57049 L
.43568 .57049 L
.43699 .57049 L
.43779 .57049 L
.43855 .57049 L
.43924 .57049 L
.43999 .57049 L
.44064 .57049 L
.44135 .57049 L
.44263 .57049 L
.44388 .57049 L
.44503 .57049 L
.44627 .57049 L
.44696 .57049 L
.44759 .57049 L
.44834 .57049 L
.44905 .57049 L
.4497 .57049 L
.45041 .57049 L
.4516 .57049 L
.45285 .57049 L
.45394 .57049 L
.45512 .57049 L
.45634 .57049 L
.45748 .57049 L
.45814 .57049 L
.45884 .57049 L
.46009 .57049 L
.46132 .57049 L
.46202 .57049 L
.46266 .57049 L
.46384 .57049 L
.46509 .57049 L
.46621 .57049 L
.46725 .57049 L
.46839 .57049 L
.46963 .57049 L
.47095 .57049 L
.4722 .57049 L
.47341 .57049 L
.47454 .57049 L
.47523 .57049 L
.47589 .57049 L
.4771 .57049 L
.47841 .57049 L
.47915 .57049 L
Mistroke
.47982 .57049 L
.48089 .57049 L
.48203 .57049 L
.48311 .57049 L
.48409 .57049 L
.48524 .57049 L
.48649 .57049 L
.48766 .57049 L
.48876 .57049 L
.48989 .57049 L
.49114 .57049 L
.49235 .57049 L
.49366 .57049 L
.49481 .57049 L
.49602 .57049 L
.49706 .57049 L
.49819 .57049 L
.49942 .57049 L
.50073 .57049 L
.50141 .57049 L
.50217 .57049 L
.50349 .57049 L
.50473 .57049 L
.50543 .57049 L
.50607 .57049 L
.50731 .57049 L
.50848 .57049 L
.50961 .57049 L
.51081 .57049 L
.51183 .57049 L
.51296 .57049 L
.51416 .57049 L
.51547 .57049 L
.5167 .57049 L
.51783 .57049 L
.51905 .57049 L
.52035 .57049 L
.52158 .57049 L
.5227 .57049 L
.52401 .57049 L
.52476 .57049 L
.52544 .57049 L
.5267 .57049 L
.52733 .57049 L
.52803 .57049 L
.52875 .57049 L
.52943 .57049 L
.53071 .57049 L
.53142 .57049 L
.53208 .57049 L
Mistroke
.53281 .57049 L
.53359 .57049 L
.53426 .57049 L
.53499 .57049 L
.53568 .57049 L
.53632 .57049 L
.53752 .57049 L
.53879 .57049 L
.54001 .57049 L
.5407 .57049 L
.54134 .57049 L
.54251 .57049 L
.54375 .57049 L
.54486 .57049 L
.5459 .57049 L
.54704 .57049 L
.54827 .57049 L
.5495 .57049 L
.5502 .57049 L
.55085 .57049 L
.55217 .57049 L
.5529 .57049 L
.55357 .57049 L
.55477 .57049 L
.55607 .57049 L
.5573 .57049 L
.55843 .57049 L
.55948 .57049 L
.56048 .57049 L
.56163 .57049 L
.56267 .57049 L
.56383 .57049 L
.56508 .57049 L
.56625 .57049 L
.56734 .57049 L
.56857 .57049 L
.56974 .57049 L
.57078 .57049 L
.57191 .57049 L
.57314 .57049 L
.57444 .57049 L
.57555 .57049 L
.57677 .57049 L
.57929 .57049 L
.57998 .57049 L
.58062 .57049 L
.58129 .57049 L
.58203 .57049 L
.58461 .57049 L
.587 .57049 L
Mistroke
.59632 .57049 L
.61725 .57049 L
.656 .57049 L
.6972 .57049 L
.73688 .57049 L
.77505 .57049 L
.81567 .57049 L
.85478 .57049 L
.89633 .57049 L
.93638 .57049 L
.9749 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOoo
o`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002@oooo0P0000Coool200001?ooo`800006oooo00<0003ooooo
ool0NOooo`00Soooo`040000oooooooo00002?ooo`040000oooooooo00001Oooo`030000oooooooo
07Woool008ooool010000?ooooooo`0000_oool00`000?ooooooo`03oooo0P0007[oool008Woool4
00000_ooo`040000oooooooo00002Oooo`800006oooo00<0003oooooool0NOooo`00Soooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool3
00001Oooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool0
0:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?ooo`800004
oooo0P0000Goool300001?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000_oool0
0`000?ooooooo`03oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002?ooo`D00004
oooo0P0007[oool008Woool400000_ooo`040000oooooooo00002?ooo`040000oooooooo00001Ooo
o`030000oooooooo07Woool008ooool010000?ooooooo`0000Woool00`000?ooo`000005oooo00<0
003oooooool0NOooo`00T?ooo`80000;oooo0P0000Goool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool0093oool200001?ooo`800004oooo0P0000Koool00`000?ooooooo`1i
oooo002?oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool0NOoo
o`00Soooo`040000oooooooo00002_ooo`030000oooooooo00Coool20000N_ooo`00ROooo`@00002
oooo00@0003oooooool0000;oooo00<0003oooooool00oooo`030000oooooooo07Woool008ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P00
00[oool200001_ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?oo
o`800004oooo0P0000?oool400001Oooo`030000oooooooo07Woool008ooool010000?ooooooo`00
00Soool00`000?ooooooo`06oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool20000N_ooo`00ROooo`@00002oooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002@oooo0P0000Coool200000oooo`D00004oooo00<0003oooooool0NOooo`00Sooo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002?oooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`80001joooo0029oooo100000;oool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo
00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool002Woool30000:?ooo`<0000T
oooo100002Goool00`000?ooooooo`0Toooo100002Ooool300009oooo`00:Oooo`040000oooooooo
0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo0P0002Goool00`000?ooooooo`0Y
oooo00<0003oooooool09_ooo`00:Oooo`040000oooooooo00009Oooo`D0000Uoooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo1@0002Ooool002?oool400000_oo
o`<0000Poooo100000;oool010000?ooooooo`0001ooool400001?ooo`030000oooooooo02Coool0
0`000?ooooooo`0Voooo00<0003oooooool09?ooo`040000oooooooo0000:?ooo`00:_ooo`030000
oooooooo02Koool00`000?ooo`00000Uoooo00@0003oooooool0000Uoooo00<0003oooooool09?oo
o`040000oooooooo00009_ooo`030000oooo000002Soool002[oool300009oooo`80000Voooo0P00
02Koool00`000?ooooooo`0Uoooo0P0002Soool20000:?ooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`003Oooool0000600003_ooo`004oooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool01`1Vo`03000006Ko06Ko00L0I_l00`00001Vo`1Vo`04
06Ko1?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooo000000`00005<ol000<0000co`0co`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`0023?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`0Boooo000Xoooo00<0003oooooool06?ooo`H0I_l8oooo00<0003oooooool01ooo
o`0306Kooooooooo01Ooool60000:C?o00030000oooooooo02Koool00`000?ooooooo`0Voooo00<0
003oooooool09oooo`00BOooo`D0I_l=oooo00<0I_ooooooool07?ooo`<0000W<ol000<0003ooooo
ool0NOooo`00C_ooo`D0I_l8oooo00<0I_ooooooool07oooo`80000U<ol000<0003oooooool0NOoo
o`00Doooo`@0I_l4oooo00<0I_ooooooool08Oooo`030000<ol0<ol0028co`020000N_ooo`00Eooo
o`80I_l2oooo00<0I_ooooooool08_ooo`030000<ol0<ol0024co`000`000?ooooooo`1ioooo001I
oooo0`1VobGoool200008C?o00030000oooooooo07Woool005_oool00ol0VOooooooo`0Uoooo00<0
000co`0co`007S?o00030000oooooooo07Woool005_oool00ol0VOooooooo`0Uoooo00<0000co`0c
o`007S?o00030000oooooooo07Woool005_oool00ol0VOooooooo`0Voooo00<0000co`0co`007C?o
0080001joooo001Koooo00?o09Woooooool09oooo`030000<ol0<ol001`co`000`000?ooooooo`1i
oooo001Koooo00?o09Woooooool0:?ooo`030000<ol0<ol001/co`000`000?ooooooo`1ioooo001K
oooo00?o09Woooooool0:?ooo`030000<ol0<ol001/co`000`000?ooooooo`1ioooo0027oooo7C?o
07coool008SooolL<ol0O?ooo`00R?oooa`co`1loooo0028oooo73?o07coool008WooolK<ol0O?oo
o`00NOooo`030000oooooooo00gooolK<ol000<0003oooooool0NOooo`00N?ooo`030000oooooooo
00Soool00`000?ooooooo`04oooo6S?o0003oooo0000oooo07Woool007Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`04oooo23?o00@00003<ol00P0000@co`0200000c?o0003oooo
0000oooo07Woool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Coool400000c?o00030000<ol0<ol000Tco`00100003?o03?o0000008co`000oooo`00
0?ooo`1ioooo001goooo00<0003oooooool00_ooo`030000oooooooo00coool8<ol000<0000co`0c
o`002c?o00030000<ol0<ol000;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
00_oool9<ol000<0000co`0co`0023?o00800003<ol000?oool0003oool0NOooo`00N?ooo`050000
oooooooooooo000000ooool6<ol000@0000co`0co`000009<ol000<0000co`0co`000S?o0003oooo
0000oooo07Woool007Woool00`000?ooooooo`0@oooo1c?o0080000:<ol00`00008co`000`000?oo
ooooo`1ioooo002<oooo63?o07coool008cooolH<ol0O?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.26171 .57049 L
.28158 .57049 L
.30316 .57049 L
.31323 .57049 L
.32392 .57049 L
.33304 .57049 L
.33554 .57049 L
.33823 .57049 L
.33953 .57049 L
.34076 .57049 L
s
.34076 .57049 m
.34077 .61803 L
s
0 .4 1 r
.02381 .57059 m
.04262 .57063 L
.06244 .57068 L
.07286 .57072 L
.08255 .57077 L
.09388 .57083 L
.10458 .5709 L
.125 .57107 L
.14357 .5713 L
.16355 .57165 L
.18199 .5721 L
.20071 .57274 L
.21136 .5732 L
.22134 .57373 L
.24158 .57514 L
.26011 .57696 L
.27909 .57956 L
.28984 .58147 L
.29982 .58361 L
.32034 .5894 L
.32939 .59271 L
.33433 .59476 L
.33895 .59684 L
.34013 .5974 L
.34125 .59794 L
.34255 .57049 L
.34373 .57049 L
.34503 .57049 L
.34624 .57049 L
.34687 .57049 L
.34756 .57049 L
.34829 .57049 L
.34897 .57049 L
.3501 .57049 L
.35129 .57049 L
.3523 .57049 L
.35341 .57049 L
.35461 .57049 L
.35589 .57049 L
.3571 .57049 L
.35819 .57049 L
.35949 .57049 L
.36015 .57049 L
.36087 .57049 L
.36214 .57049 L
.36333 .57049 L
.36405 .57049 L
.36474 .57049 L
.36602 .57049 L
.36674 .57049 L
Mistroke
.3674 .57049 L
.36813 .57049 L
.3689 .57049 L
.37022 .57049 L
.37096 .57049 L
.37164 .57049 L
.37289 .57049 L
.37421 .57049 L
.3754 .57049 L
.3765 .57049 L
.37772 .57049 L
.37901 .57049 L
.38024 .57049 L
.38093 .57049 L
.38159 .57049 L
.3829 .57049 L
.38364 .57049 L
.38432 .57049 L
.38546 .57049 L
.3867 .57049 L
.388 .57049 L
.38921 .57049 L
.38991 .57049 L
.39066 .57049 L
.39137 .57049 L
.39202 .57049 L
.39326 .57049 L
.39458 .57049 L
.39525 .57049 L
.39598 .57049 L
.3973 .57049 L
.3981 .57049 L
.39887 .57049 L
.39955 .57049 L
.40029 .57049 L
.40154 .57049 L
.4027 .57049 L
.40398 .57049 L
.4047 .57049 L
.40536 .57049 L
.40661 .57049 L
.40732 .57049 L
.40798 .57049 L
.40868 .57049 L
.40932 .57049 L
.41001 .57049 L
.41075 .57049 L
.41199 .57049 L
.41314 .57049 L
.41437 .57049 L
Mistroke
.41507 .57049 L
.41573 .57049 L
.41691 .57049 L
.41799 .57049 L
.41916 .57049 L
.42043 .57049 L
.42172 .57049 L
.42293 .57049 L
.42411 .57049 L
.4252 .57049 L
.42638 .57049 L
.42767 .57049 L
.42832 .57049 L
.42902 .57049 L
.43028 .57049 L
.43146 .57049 L
.43274 .57049 L
.43395 .57049 L
.43507 .57049 L
.43607 .57049 L
.43718 .57049 L
.43834 .57049 L
.43943 .57049 L
.44074 .57049 L
.44196 .57049 L
.44324 .57049 L
.44391 .57049 L
.44463 .57049 L
.44592 .57049 L
.44713 .57049 L
.44822 .57049 L
.44941 .57049 L
.45071 .57049 L
.45142 .57049 L
.45209 .57049 L
.45328 .57049 L
.45457 .57049 L
.45528 .57049 L
.45606 .57049 L
.4568 .57049 L
.45749 .57049 L
.45878 .57049 L
.4595 .57049 L
.46016 .57049 L
.46137 .57049 L
.46249 .57049 L
.46373 .57049 L
.46442 .57049 L
.46505 .57049 L
.46633 .57049 L
Mistroke
.46704 .57049 L
.46771 .57049 L
.46892 .57049 L
.47022 .57049 L
.47131 .57049 L
.47249 .57049 L
.4736 .57049 L
.47461 .57049 L
.4758 .57049 L
.4771 .57049 L
.47832 .57049 L
.47946 .57049 L
.48076 .57049 L
.4815 .57049 L
.48218 .57049 L
.48343 .57049 L
.48474 .57049 L
.48593 .57049 L
.48703 .57049 L
.48824 .57049 L
.48954 .57049 L
.49021 .57049 L
.49092 .57049 L
.49171 .57049 L
.49243 .57049 L
.49373 .57049 L
.49447 .57049 L
.49517 .57049 L
.49645 .57049 L
.49763 .57049 L
.49893 .57049 L
.49958 .57049 L
.50029 .57049 L
.50161 .57049 L
.50283 .57049 L
.50346 .57049 L
.50416 .57049 L
.50489 .57049 L
.50558 .57049 L
.50683 .57049 L
.50798 .57049 L
.50861 .57049 L
.5093 .57049 L
.51056 .57049 L
.51179 .57049 L
.51291 .57049 L
.51419 .57049 L
.51541 .57049 L
.51653 .57049 L
.51756 .57049 L
Mistroke
.5187 .57049 L
.5199 .57049 L
.5212 .57049 L
.52239 .57049 L
.52305 .57049 L
.52377 .57049 L
.52507 .57049 L
.52989 .57049 L
.53057 .57049 L
.53131 .57049 L
.53196 .57049 L
.53265 .57049 L
.53338 .57049 L
.53404 .57049 L
.53478 .57049 L
.53558 .57049 L
.5369 .57049 L
.53764 .57049 L
.53831 .57049 L
.53961 .57049 L
.54084 .57049 L
.542 .57049 L
.54324 .57049 L
.54441 .57049 L
.54548 .57049 L
.54674 .57049 L
.54745 .57049 L
.5481 .57049 L
.54931 .57049 L
.55058 .57049 L
.5518 .57049 L
.55311 .57049 L
.55434 .57049 L
.55548 .57049 L
.55674 .57049 L
.55745 .57049 L
.55811 .57049 L
.55881 .57049 L
.55945 .57049 L
.56019 .57049 L
.56089 .57049 L
.56195 .57049 L
.56312 .57049 L
.56435 .57049 L
.56549 .57049 L
.56656 .57049 L
.56754 .57049 L
.56867 .57049 L
.56974 .57049 L
.57089 .57049 L
Mistroke
.57212 .57049 L
.57328 .57049 L
.57434 .57049 L
.57558 .57049 L
.57627 .57049 L
.57692 .57049 L
.5781 .57049 L
.57935 .57049 L
.58057 .57049 L
.5819 .57049 L
.58431 .57049 L
.58883 .57049 L
.59899 .57049 L
.61733 .57049 L
.65812 .57049 L
.69739 .57049 L
.73515 .57049 L
.77536 .57049 L
.81406 .57049 L
.8552 .57049 L
.89484 .57049 L
.93295 .57049 L
.97352 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOoo
o`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002@oooo0P0000Coool200001?ooo`800006oooo00<0003ooooo
ool0NOooo`00Soooo`040000oooooooo00002?ooo`040000oooooooo00001Oooo`030000oooooooo
07Woool008ooool010000?ooooooo`0000_oool00`000?ooooooo`03oooo0P0007[oool008Woool4
00000_ooo`040000oooooooo00002Oooo`800006oooo00<0003oooooool0NOooo`00Soooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool3
00001Oooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool0
0:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?ooo`800004
oooo0P0000Goool300001?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000_oool0
0`000?ooooooo`03oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002?ooo`D00004
oooo0P0007[oool008Woool400000_ooo`040000oooooooo00002?ooo`040000oooooooo00001Ooo
o`030000oooooooo07Woool008ooool010000?ooooooo`0000Woool00`000?ooo`000005oooo00<0
003oooooool0NOooo`00T?ooo`80000;oooo0P0000Goool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool0093oool200001?ooo`800004oooo0P0000Koool00`000?ooooooo`1i
oooo002?oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool0NOoo
o`00Soooo`040000oooooooo00002_ooo`030000oooooooo00Coool20000N_ooo`00ROooo`@00002
oooo00@0003oooooool0000;oooo00<0003oooooool00oooo`030000oooooooo07Woool008ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P00
00[oool200001_ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?oo
o`800004oooo0P0000?oool400001Oooo`030000oooooooo07Woool008ooool010000?ooooooo`00
00Soool00`000?ooooooo`06oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool20000N_ooo`00ROooo`@00002oooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002@oooo0P0000Coool200000oooo`D00004oooo00<0003oooooool0NOooo`00Sooo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002?oooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`80001joooo0029oooo100000;oool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo
00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool002Woool30000:?ooo`<0000T
oooo100002Goool00`000?ooooooo`0Toooo100002Ooool300009oooo`00:Oooo`040000oooooooo
0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo0P0002Goool00`000?ooooooo`0Y
oooo00<0003oooooool09_ooo`00:Oooo`040000oooooooo00009Oooo`D0000Uoooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo1@0002Ooool002?oool400000_oo
o`<0000Poooo100000;oool010000?ooooooo`0001ooool400001?ooo`030000oooooooo02Coool0
0`000?ooooooo`0Voooo00<0003oooooool09?ooo`040000oooooooo0000:?ooo`00:_ooo`030000
oooooooo02Koool00`000?ooo`00000Uoooo00@0003oooooool0000Uoooo00<0003oooooool09?oo
o`040000oooooooo00009_ooo`030000oooo000002Soool002[oool300009oooo`80000Voooo0P00
02Koool00`000?ooooooo`0Uoooo0P0002Soool20000:?ooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`003Oooool0000600003_ooo`004oooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00L0I_l00`00001Vo`1Vo`08
06Ko00<00000I_l0I_l0101Vo`?oool00`000?ooooooo`07oooo00<0003oooooool01oooo`03o`2I
0000oooo00d00005<ol000<0000co`0co`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`0023?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`0Boooo000Xoooo00<0003oooooool08oooo`<0I_l00`00001Vooooo`0Aoooo00?o
09T0I_ooool03Oooo`H0000Y<ol000<0003oooooool09_ooo`030000oooooooo02Koool00`000?oo
ooooo`0Woooo001Coooo1`1Vo`_oool00ol0V@1Vooooo`0Boooo0`0002Lco`000`000?ooooooo`1i
oooo001Joooo101Vo`Ooool00ol0V@1Vooooo`0Eoooo0P0002Dco`000`000?ooooooo`1ioooo001N
oooo0`1Vo`Coool00ol0V@1Vooooo`0Goooo00<0000co`0co`008S?o0080001joooo001Qoooo0P1V
o`;oool00ol0V@1Vooooo`0Hoooo00<0000co`0co`008C?o00030000oooooooo07Woool006?oool4
06Ko6_ooo`80000Q<ol000<0003oooooool0NOooo`00IOooo`03o`2Ioooooooo01_oool00`0003?o
03?o000N<ol000<0003oooooool0NOooo`00IOooo`03o`2Ioooooooo01_oool00`0003?o03?o000N
<ol000<0003oooooool0NOooo`00IOooo`03o`2Ioooooooo01coool00`0003?o03?o000M<ol00P00
07[oool006Goool00ol0VOooooooo`0Moooo00<0000co`0co`0073?o00030000oooooooo07Woool0
06Goool00ol0VOooooooo`0Noooo00<0000co`0co`006c?o00030000oooooooo07Woool006Goool0
0ol0VOooooooo`0Noooo00<0000co`0co`006c?o00030000oooooooo07Woool008OooolM<ol0O?oo
o`00R?oooa`co`1loooo0028oooo73?o07coool008SooolL<ol0O?ooo`00ROoooa/co`1loooo001l
oooo00<0003oooooool02_oooaPco`000`0003?o03?o001loooo001koooo00<0003oooooool02?oo
o`040000oooooooooooo63?o00030000<ol0oooo07_oool007_oool00`000?ooooooo`02oooo0P00
00Coool010000?ooooooooooo`/co`0400000c?o00800004<ol000<0000co`3oool0Noooo`00Nooo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00@0003oooooooooool3<ol01000
00<co`000`0003?o03?o000:<ol000<0000co`3oool0Noooo`00N_ooo`030000oooooooo00;oool0
0`000?ooooooo`09oooo2c?o00030000<ol0<ol000Xco`000`000?ooooooo`1joooo001koooo00<0
003oooooool01@0000Soool<<ol000<0000co`0co`0023?o00030000<ol0oooo07_oool007_oool0
1@000?ooooooooooo`00000<oooo2C?o00040000<ol0<ol000002C?o00030000<ol0oooo07_oool0
07coool00`000?ooooooo`0=oooo2S?o00800009<ol000<0000co`0co`00O?ooo`00S?oooaPco`1l
oooo002<oooo63?o07coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.26171 .57049 L
.30316 .57049 L
.32392 .57049 L
.34309 .57049 L
.36173 .57049 L
.37114 .57049 L
.37372 .57049 L
.37649 .57049 L
.37783 .57049 L
.3791 .57049 L
.38025 .57049 L
s
.38025 .57049 m
.38026 .61803 L
s
0 .4 1 r
.02381 .57054 m
.04262 .57056 L
.06244 .57059 L
.07286 .57061 L
.08255 .57063 L
.09388 .57066 L
.10458 .57069 L
.125 .57078 L
.14357 .57089 L
.16355 .57106 L
.18199 .57128 L
.20071 .57159 L
.21136 .57182 L
.22134 .57207 L
.24158 .57276 L
.26011 .57365 L
.27909 .57491 L
.28984 .57585 L
.29982 .57689 L
.32034 .57971 L
.33895 .58334 L
.35819 .5886 L
.36904 .59246 L
.37385 .59442 L
.3765 .59558 L
.37781 .59617 L
.37901 .59673 L
.3802 .59729 L
.38145 .57049 L
.38271 .57049 L
.38344 .57049 L
.38411 .57049 L
.38526 .57049 L
.3865 .57049 L
.3876 .57049 L
.38875 .57049 L
.38984 .57049 L
.391 .57049 L
.392 .57049 L
.39309 .57049 L
.39437 .57049 L
.39558 .57049 L
.39675 .57049 L
.39784 .57049 L
.39903 .57049 L
.40031 .57049 L
.40152 .57049 L
.40262 .57049 L
.40391 .57049 L
.40464 .57049 L
Mistroke
.40532 .57049 L
.40656 .57049 L
.40788 .57049 L
.40855 .57049 L
.40926 .57049 L
.41003 .57049 L
.41075 .57049 L
.41204 .57049 L
.41277 .57049 L
.41345 .57049 L
.41473 .57049 L
.41589 .57049 L
.41654 .57049 L
.41724 .57049 L
.4185 .57049 L
.4197 .57049 L
.4208 .57049 L
.42203 .57049 L
.42332 .57049 L
.42451 .57049 L
.42577 .57049 L
.4265 .57049 L
.42715 .57049 L
.42844 .57049 L
.42962 .57049 L
.43071 .57049 L
.43191 .57049 L
.43317 .57049 L
.43427 .57049 L
.43529 .57049 L
.43642 .57049 L
.43762 .57049 L
.4383 .57049 L
.43901 .57049 L
.44029 .57049 L
.44101 .57049 L
.44168 .57049 L
.44241 .57049 L
.4432 .57049 L
.44385 .57049 L
.44453 .57049 L
.44577 .57049 L
.44707 .57049 L
.44775 .57049 L
.44849 .57049 L
.44921 .57049 L
.44988 .57049 L
.45119 .57049 L
.45239 .57049 L
.45366 .57049 L
Mistroke
.45482 .57049 L
.45591 .57049 L
.45711 .57049 L
.4584 .57049 L
.45909 .57049 L
.45973 .57049 L
.46094 .57049 L
.46224 .57049 L
.46297 .57049 L
.46365 .57049 L
.46477 .57049 L
.46601 .57049 L
.46731 .57049 L
.46851 .57049 L
.4692 .57049 L
.46995 .57049 L
.47065 .57049 L
.4713 .57049 L
.47253 .57049 L
.47384 .57049 L
.47452 .57049 L
.47524 .57049 L
.47655 .57049 L
.47732 .57049 L
.47812 .57049 L
.4788 .57049 L
.47955 .57049 L
.4802 .57049 L
.48091 .57049 L
.48219 .57049 L
.48344 .57049 L
.48458 .57049 L
.48583 .57049 L
.48654 .57049 L
.4872 .57049 L
.48789 .57049 L
.48863 .57049 L
.48931 .57049 L
.48996 .57049 L
.49113 .57049 L
.49237 .57049 L
.49354 .57049 L
.49459 .57049 L
.49585 .57049 L
.49655 .57049 L
.4972 .57049 L
.49839 .57049 L
.49964 .57049 L
.5022 .57049 L
.50346 .57049 L
Mistroke
.50462 .57049 L
.50568 .57049 L
.5068 .57049 L
.50792 .57049 L
.50916 .57049 L
.51048 .57049 L
.51169 .57049 L
.51236 .57049 L
.51308 .57049 L
.51377 .57049 L
.51441 .57049 L
.51566 .57049 L
.51679 .57049 L
.5181 .57049 L
.51934 .57049 L
.5204 .57049 L
.52157 .57049 L
.52279 .57049 L
.52393 .57049 L
.52499 .57049 L
.52596 .57049 L
.52709 .57049 L
.52815 .57049 L
.5293 .57049 L
.53052 .57049 L
.53157 .57049 L
.53272 .57049 L
.53395 .57049 L
.53464 .57049 L
.53528 .57049 L
.53645 .57049 L
.53769 .57049 L
.53892 .57049 L
.53962 .57049 L
.54026 .57049 L
.54144 .57049 L
.54268 .57049 L
.5438 .57049 L
.54485 .57049 L
.54599 .57049 L
.54723 .57049 L
.54853 .57049 L
.54927 .57049 L
.54996 .57049 L
.55121 .57049 L
.55192 .57049 L
.55255 .57049 L
.55376 .57049 L
.55506 .57049 L
.55629 .57049 L
Mistroke
.55742 .57049 L
.55848 .57049 L
.55962 .57049 L
.5607 .57049 L
.56168 .57049 L
.56283 .57049 L
.56408 .57049 L
.56526 .57049 L
.56635 .57049 L
.56748 .57049 L
.56853 .57049 L
.56968 .57049 L
.57093 .57049 L
.57216 .57049 L
.57346 .57049 L
.57457 .57049 L
.57578 .57049 L
.57643 .57049 L
.57711 .57049 L
.57833 .57049 L
.57964 .57049 L
.58039 .57049 L
.58108 .57049 L
.58608 .57049 L
.59542 .57049 L
.61638 .57049 L
.65525 .57049 L
.69656 .57049 L
.73637 .57049 L
.77465 .57049 L
.81539 .57049 L
.85461 .57049 L
.89232 .57049 L
.93247 .57049 L
.97112 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOoo
o`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002@oooo0P0000Coool200001?ooo`800006oooo00<0003ooooo
ool0NOooo`00Soooo`040000oooooooo00002?ooo`040000oooooooo00001Oooo`030000oooooooo
07Woool008ooool010000?ooooooo`0000_oool00`000?ooooooo`03oooo0P0007[oool008Woool4
00000_ooo`040000oooooooo00002Oooo`800006oooo00<0003oooooool0NOooo`00Soooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool3
00001Oooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool0
0:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?ooo`800004
oooo0P0000Goool300001?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000_oool0
0`000?ooooooo`03oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002?ooo`D00004
oooo0P0007[oool008Woool400000_ooo`040000oooooooo00002?ooo`040000oooooooo00001Ooo
o`030000oooooooo07Woool008ooool010000?ooooooo`0000Woool00`000?ooo`000005oooo00<0
003oooooool0NOooo`00T?ooo`80000;oooo0P0000Goool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool0093oool200001?ooo`800004oooo0P0000Koool00`000?ooooooo`1i
oooo002?oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool0NOoo
o`00Soooo`040000oooooooo00002_ooo`030000oooooooo00Coool20000N_ooo`00ROooo`@00002
oooo00@0003oooooool0000;oooo00<0003oooooool00oooo`030000oooooooo07Woool008ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P00
00[oool200001_ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?oo
o`800004oooo0P0000?oool400001Oooo`030000oooooooo07Woool008ooool010000?ooooooo`00
00Soool00`000?ooooooo`06oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool20000N_ooo`00ROooo`@00002oooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002@oooo0P0000Coool200000oooo`D00004oooo00<0003oooooool0NOooo`00Sooo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002?oooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`80001joooo0029oooo100000;oool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo
00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool002Woool30000:?ooo`<0000T
oooo100002Goool00`000?ooooooo`0Toooo100002Ooool300009oooo`00:Oooo`040000oooooooo
0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo0P0002Goool00`000?ooooooo`0Y
oooo00<0003oooooool09_ooo`00:Oooo`040000oooooooo00009Oooo`D0000Uoooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo1@0002Ooool002?oool400000_oo
o`<0000Poooo100000;oool010000?ooooooo`0001ooool400001?ooo`030000oooooooo02Coool0
0`000?ooooooo`0Voooo00<0003oooooool09?ooo`040000oooooooo0000:?ooo`00:_ooo`030000
oooooooo02Koool00`000?ooo`00000Uoooo00@0003oooooool0000Uoooo00<0003oooooool09?oo
o`040000oooooooo00009_ooo`030000oooo000002Soool002[oool300009oooo`80000Voooo0P00
02Koool00`000?ooooooo`0Uoooo0P0002Soool20000:?ooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`003Oooool0000600003_ooo`004oooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
06Ko00<00000I_l0I_l01`1Vo`03000006Ko06Ko00<0I_l4oooo00<0003oooooool02?ooo`030000
oooo000000`00005<ol000<0000co`0co`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`0023?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`0Boooo000Xoooo00<0003oooooool09_ooo`030000oooooooo00?oool706Ko4_oo
o`0306Kooooooooo00;oool60000:C?o00030000oooooooo02Koool00`000?ooooooo`0Voooo00<0
003oooooool09oooo`00G_ooo`D0I_l=oooo00<0I_ooooooool01oooo`<0000W<ol000<0003ooooo
ool0NOooo`00Hoooo`D0I_l8oooo00<0I_ooooooool02_ooo`80000U<ol000<0003oooooool0NOoo
o`00J?ooo`@0I_l4oooo00<0I_ooooooool03?ooo`030000<ol0<ol0028co`020000N_ooo`00K?oo
o`80I_l2oooo00<0I_ooooooool03Oooo`030000<ol0<ol0024co`000`000?ooooooo`1ioooo001^
oooo0`1Voa3oool200008C?o00030000oooooooo07Woool0073oool00ol0VOooooooo`0@oooo00<0
000co`0co`007S?o00030000oooooooo07Woool0073oool00ol0VOooooooo`0@oooo00<0000co`0c
o`007S?o00030000oooooooo07Woool0073oool00ol0VOooooooo`0Aoooo00<0000co`0co`007C?o
0080001joooo001`oooo00?o09Woooooool04_ooo`030000<ol0<ol001`co`000`000?ooooooo`1i
oooo001`oooo00?o09Woooooool04oooo`030000<ol0<ol001/co`000`000?ooooooo`1ioooo001`
oooo00?o09Woooooool04oooo`030000<ol0<ol001/co`000`000?ooooooo`1ioooo0027oooo7C?o
07coool008SooolL<ol0O?ooo`00R?oooa`co`1loooo0028oooo73?o07coool008WooolK<ol0O?oo
o`00NOooo`030000oooooooo00gooolK<ol000<0003oooooool0NOooo`00N?ooo`030000oooooooo
00Soool00`000?ooooooo`04oooo6S?o0003oooo0000oooo07Woool007Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`04oooo23?o00D00002<ol00P0000@co`0200000c?o0003oooo
0000oooo07Woool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Coool400001C?o00030000<ol0<ol000Lco`00100003?o03?o0000008co`000oooo`00
0?ooo`1ioooo001goooo00<0003oooooool00_ooo`030000oooooooo00coool9<ol000<0000co`0c
o`002S?o00030000<ol0<ol000;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
00_oool9<ol000<0000co`0co`0023?o00800003<ol000?oool0003oool0NOooo`00N?ooo`050000
oooooooooooo000000ooool8<ol000<0000co`0co`0023?o00030000<ol0<ol0008co`000oooo`00
0?ooo`1ioooo001ioooo00<0003oooooool04?ooo`Lco`0200002S?o00<00002<ol000<0003ooooo
ool0NOooo`00S?oooaPco`1loooo002<oooo63?o07coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.26171 .57049 L
.30316 .57049 L
.34309 .57049 L
.3815 .57049 L
.40134 .57049 L
.41134 .57049 L
.41408 .57049 L
.41703 .57049 L
.41846 .57049 L
.41917 .57049 L
.41982 .57049 L
s
.41982 .57049 m
.41982 .61803 L
s
0 .4 1 r
.02381 .57051 m
.04262 .57052 L
.06244 .57054 L
.07286 .57055 L
.08255 .57056 L
.09388 .57057 L
.10458 .57059 L
.125 .57063 L
.14357 .57068 L
.16355 .57076 L
.18199 .57086 L
.20071 .57101 L
.21136 .57112 L
.22134 .57124 L
.24158 .57156 L
.26011 .57198 L
.27909 .57257 L
.28984 .57301 L
.29982 .5735 L
.32034 .57483 L
.33895 .57654 L
.35819 .57901 L
.36904 .58083 L
.37901 .58284 L
.39784 .58777 L
.40853 .59139 L
.41371 .59342 L
.41599 .59437 L
.41728 .59493 L
.4185 .59546 L
.41967 .59599 L
.42093 .57049 L
.42158 .57049 L
.42227 .57049 L
.42351 .57049 L
.42416 .57049 L
.42485 .57049 L
.42611 .57049 L
.42688 .57049 L
.4276 .57049 L
.42825 .57049 L
.42895 .57049 L
.43014 .57049 L
.43146 .57049 L
.43212 .57049 L
.43282 .57049 L
.4341 .57049 L
.43538 .57049 L
.43659 .57049 L
.43767 .57049 L
Mistroke
.43885 .57049 L
.44011 .57049 L
.4413 .57049 L
.44237 .57049 L
.44352 .57049 L
.44478 .57049 L
.44541 .57049 L
.44611 .57049 L
.44734 .57049 L
.44848 .57049 L
.44964 .57049 L
.45074 .57049 L
.45172 .57049 L
.45279 .57049 L
.45396 .57049 L
.45519 .57049 L
.45625 .57049 L
.45741 .57049 L
.45863 .57049 L
.45977 .57049 L
.46101 .57049 L
.46171 .57049 L
.46234 .57049 L
.46363 .57049 L
.46435 .57049 L
.46501 .57049 L
.46624 .57049 L
.46753 .57049 L
.46863 .57049 L
.46981 .57049 L
.47093 .57049 L
.47195 .57049 L
.47314 .57049 L
.47444 .57049 L
.47566 .57049 L
.4768 .57049 L
.47799 .57049 L
.47927 .57049 L
.48049 .57049 L
.4816 .57049 L
.48284 .57049 L
.48354 .57049 L
.48419 .57049 L
.4855 .57049 L
.48624 .57049 L
.48691 .57049 L
.48758 .57049 L
.48829 .57049 L
.48956 .57049 L
.49027 .57049 L
Mistroke
.49093 .57049 L
.49166 .57049 L
.49244 .57049 L
.49311 .57049 L
.49384 .57049 L
.49453 .57049 L
.49517 .57049 L
.49638 .57049 L
.49767 .57049 L
.49902 .57049 L
.50027 .57049 L
.50159 .57049 L
.50228 .57049 L
.50303 .57049 L
.50366 .57049 L
.50435 .57049 L
.50561 .57049 L
.50683 .57049 L
.50796 .57049 L
.5086 .57049 L
.50929 .57049 L
.51053 .57049 L
.51125 .57049 L
.51201 .57049 L
.51265 .57049 L
.51336 .57049 L
.5141 .57049 L
.5148 .57049 L
.5156 .57049 L
.51633 .57049 L
.51702 .57049 L
.51766 .57049 L
.51835 .57049 L
.51909 .57049 L
.52034 .57049 L
.52149 .57049 L
.52281 .57049 L
.52406 .57049 L
.52514 .57049 L
.52628 .57049 L
.52754 .57049 L
.5287 .57049 L
.52942 .57049 L
.53008 .57049 L
.53078 .57049 L
.53156 .57049 L
.53287 .57049 L
.53358 .57049 L
.53425 .57049 L
.53552 .57049 L
Mistroke
.53667 .57049 L
.53731 .57049 L
.53801 .57049 L
.53927 .57049 L
.54038 .57049 L
.5416 .57049 L
.54275 .57049 L
.54381 .57049 L
.54505 .57049 L
.54637 .57049 L
.54759 .57049 L
.5487 .57049 L
.54939 .57049 L
.55003 .57049 L
.55073 .57049 L
.55146 .57049 L
.5527 .57049 L
.55341 .57049 L
.55407 .57049 L
.55534 .57049 L
.55649 .57049 L
.55713 .57049 L
.55783 .57049 L
.5591 .57049 L
.56031 .57049 L
.56161 .57049 L
.56236 .57049 L
.56304 .57049 L
.5637 .57049 L
.56439 .57049 L
.56506 .57049 L
.56578 .57049 L
.56708 .57049 L
.56776 .57049 L
.56849 .57049 L
.56928 .57049 L
.57002 .57049 L
.57131 .57049 L
.57205 .57049 L
.57274 .57049 L
.57398 .57049 L
.57467 .57049 L
.57531 .57049 L
.57649 .57049 L
.57778 .57049 L
.57899 .57049 L
.58012 .57049 L
.58141 .57049 L
.58277 .57049 L
.58521 .57049 L
Mistroke
.59071 .57049 L
.60068 .57049 L
.61929 .57049 L
.6573 .57049 L
.69777 .57049 L
.73672 .57049 L
.77812 .57049 L
.818 .57049 L
.85637 .57049 L
.89719 .57049 L
.9365 .57049 L
.97429 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOoo
o`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002@oooo0P0000Coool200001?ooo`800006oooo00<0003ooooo
ool0NOooo`00Soooo`040000oooooooo00002?ooo`040000oooooooo00001Oooo`030000oooooooo
07Woool008ooool010000?ooooooo`0000_oool00`000?ooooooo`03oooo0P0007[oool008Woool4
00000_ooo`040000oooooooo00002Oooo`800006oooo00<0003oooooool0NOooo`00Soooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool3
00001Oooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool0
0:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?ooo`800004
oooo0P0000Goool300001?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000_oool0
0`000?ooooooo`03oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002?ooo`D00004
oooo0P0007[oool008Woool400000_ooo`040000oooooooo00002?ooo`040000oooooooo00001Ooo
o`030000oooooooo07Woool008ooool010000?ooooooo`0000Woool00`000?ooo`000005oooo00<0
003oooooool0NOooo`00T?ooo`80000;oooo0P0000Goool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool0093oool200001?ooo`800004oooo0P0000Koool00`000?ooooooo`1i
oooo002?oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool0NOoo
o`00Soooo`040000oooooooo00002_ooo`030000oooooooo00Coool20000N_ooo`00ROooo`@00002
oooo00@0003oooooool0000;oooo00<0003oooooool00oooo`030000oooooooo07Woool008ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P00
00[oool200001_ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?oo
o`800004oooo0P0000?oool400001Oooo`030000oooooooo07Woool008ooool010000?ooooooo`00
00Soool00`000?ooooooo`06oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool20000N_ooo`00ROooo`@00002oooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002@oooo0P0000Coool200000oooo`D00004oooo00<0003oooooool0NOooo`00Sooo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002?oooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`80001joooo0029oooo100000;oool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo
00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool002Woool30000:?ooo`<0000T
oooo100002Goool00`000?ooooooo`0Toooo100002Ooool300009oooo`00:Oooo`040000oooooooo
0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo0P0002Goool00`000?ooooooo`0Y
oooo00<0003oooooool09_ooo`00:Oooo`040000oooooooo00009Oooo`D0000Uoooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo1@0002Ooool002?oool400000_oo
o`<0000Poooo100000;oool010000?ooooooo`0001ooool400001?ooo`030000oooooooo02Coool0
0`000?ooooooo`0Voooo00<0003oooooool09?ooo`040000oooooooo0000:?ooo`00:_ooo`030000
oooooooo02Koool00`000?ooo`00000Uoooo00@0003oooooool0000Uoooo00<0003oooooool09?oo
o`040000oooooooo00009_ooo`030000oooo000002Soool002[oool300009oooo`80000Voooo0P00
02Koool00`000?ooooooo`0Uoooo0P0002Soool20000:?ooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`003Oooool0000600003_ooo`004oooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oool0I_l01`1Vo`03000006Ko06Ko00L0I_l00`00001Vo`1Vo`0506Ko0oooo`030000
oooo000000`00005<ol000<0000co`0co`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`0023?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`0Boooo000Xoooo00<0003oooooool09_ooo`030000oooooooo00ooool506Ko3Ooo
o`H0000Y<ol000<0003oooooool09_ooo`030000oooooooo02Koool00`000?ooooooo`0Woooo001X
oooo1P1Vo`coool00`1Vo`000000000W<ol000<0003oooooool0NOooo`00K_ooo`@0I_l8oooo00<0
I_ooooooool00P0002Dco`000`000?ooooooo`1ioooo001boooo101Vo`Coool00`1Vooooooooo`02
oooo00<0000co`0co`008S?o0080001joooo001foooo0`1Vo`03oooo06Kooooo00Coool00`0003?o
03?o000Q<ol000<0003oooooool0NOooo`00NOooo`80I_l6oooo0P00024co`000`000?ooooooo`1i
oooo001joooo00?o09Woooooool01_ooo`030000<ol0<ol001hco`000`000?ooooooo`1ioooo001j
oooo00?o09Woooooool01_ooo`030000<ol0<ol001hco`000`000?ooooooo`1ioooo001joooo00?o
09Woooooool01oooo`030000<ol0<ol001dco`020000N_ooo`00N_ooo`03o`2Ioooooooo00Soool0
0`0003?o03?o000L<ol000<0003oooooool0NOooo`00N_ooo`03o`2Ioooooooo00Woool00`0003?o
03?o000K<ol000<0003oooooool0NOooo`00N_ooo`03o`2Ioooooooo00Woool00`0003?o03?o000K
<ol000<0003oooooool0NOooo`00Qooooadco`1loooo0028oooo73?o07coool008SooolL<ol0O?oo
o`00R?oooa`co`1loooo0029oooo6c?o07coool007coool00`000?ooooooo`0:oooo63?o00030000
<ol0<ol007coool007_oool00`000?ooooooo`08oooo00@0003ooooooooooolH<ol000<0000co`3o
ool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`040000oooooooooooo2c?o00D00002
<ol00P0000@co`000`0003?o0?ooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool010000?ooooooooooo`<co`0400001C?o00030000<ol0<ol000Pco`000`0003?o
0?ooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00Woool<<ol000<0000co`0c
o`002C?o00030000oooooooo07[oool007_oool00`000?ooooooo`0500002?ooo``co`000`0003?o
03?o0008<ol000<0000co`3oool0Noooo`00Noooo`050000oooooooooooo000000coool;<ol000<0
000co`0co`0023?o00030000<ol0oooo07_oool007coool00`000?ooooooo`0=oooo2S?o00800009
<ol000<0000co`0co`00O?ooo`00S?oooaPco`1loooo002<oooo63?o07coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.26171 .57049 L
.30316 .57049 L
.34309 .57049 L
.3815 .57049 L
.40095 .57049 L
.42237 .57049 L
.43215 .57049 L
.44268 .57049 L
.44778 .57049 L
.45262 .57049 L
.45697 .57049 L
.45816 .57049 L
.45943 .57049 L
s
.45943 .57049 m
.45944 .61803 L
s
0 .4 1 r
.02381 .5705 m
.04262 .57051 L
.06244 .57051 L
.07286 .57051 L
.08255 .57052 L
.09388 .57052 L
.10458 .57053 L
.125 .57055 L
.14357 .57057 L
.16355 .5706 L
.18199 .57064 L
.20071 .5707 L
.21136 .57074 L
.22134 .57079 L
.24158 .57092 L
.26011 .57108 L
.27909 .57132 L
.28984 .57149 L
.29982 .57169 L
.32034 .57221 L
.33895 .57289 L
.35819 .57387 L
.36904 .57459 L
.37901 .57539 L
.39784 .57734 L
.40853 .57878 L
.4185 .5804 L
.43885 .58474 L
.44785 .58722 L
.45278 .58876 L
.45741 .59034 L
.45851 .59073 L
.45968 .59116 L
.46095 .57049 L
.46212 .57049 L
.46341 .57049 L
.46461 .57049 L
.46592 .57049 L
.46666 .57049 L
.46732 .57049 L
.4685 .57049 L
.46959 .57049 L
.47076 .57049 L
.47204 .57049 L
.47316 .57049 L
.4742 .57049 L
.47531 .57049 L
.4765 .57049 L
.47716 .57049 L
.47788 .57049 L
Mistroke
.47916 .57049 L
.47994 .57049 L
.48068 .57049 L
.48135 .57049 L
.48206 .57049 L
.48269 .57049 L
.48338 .57049 L
.4846 .57049 L
.48529 .57049 L
.48602 .57049 L
.48671 .57049 L
.48734 .57049 L
.48861 .57049 L
.48978 .57049 L
.49107 .57049 L
.49172 .57049 L
.49244 .57049 L
.49363 .57049 L
.49492 .57049 L
.49614 .57049 L
.49726 .57049 L
.49854 .57049 L
.49975 .57049 L
.50084 .57049 L
.50201 .57049 L
.5033 .57049 L
.50394 .57049 L
.50465 .57049 L
.50591 .57049 L
.50708 .57049 L
.50827 .57049 L
.50939 .57049 L
.51039 .57049 L
.51149 .57049 L
.51268 .57049 L
.51394 .57049 L
.51502 .57049 L
.51622 .57049 L
.51752 .57049 L
.51818 .57049 L
.5189 .57049 L
.52017 .57049 L
.52135 .57049 L
.52208 .57049 L
.52276 .57049 L
.52403 .57049 L
.52475 .57049 L
.52541 .57049 L
.52613 .57049 L
.5269 .57049 L
Mistroke
.52809 .57049 L
.52936 .57049 L
.53057 .57049 L
.53167 .57049 L
.53296 .57049 L
.53369 .57049 L
.53437 .57049 L
.53561 .57049 L
.53693 .57049 L
.53818 .57049 L
.53888 .57049 L
.53954 .57049 L
.54024 .57049 L
.54087 .57049 L
.5416 .57049 L
.5423 .57049 L
.54344 .57049 L
.54466 .57049 L
.54529 .57049 L
.54599 .57049 L
.54723 .57049 L
.54793 .57049 L
.54867 .57049 L
.54999 .57049 L
.55073 .57049 L
.55141 .57049 L
.55217 .57049 L
.55297 .57049 L
.55367 .57049 L
.55433 .57049 L
.55502 .57049 L
.55577 .57049 L
.55702 .57049 L
.55772 .57049 L
.55836 .57049 L
.559 .57049 L
.5597 .57049 L
.56097 .57049 L
.56168 .57049 L
.56234 .57049 L
.56311 .57049 L
.5638 .57049 L
.56508 .57049 L
.5658 .57049 L
.56646 .57049 L
.56766 .57049 L
.56893 .57049 L
.57008 .57049 L
.5713 .57049 L
.57246 .57049 L
Mistroke
.57351 .57049 L
.57475 .57049 L
.57545 .57049 L
.57609 .57049 L
.57728 .57049 L
.57853 .57049 L
.57974 .57049 L
.58105 .57049 L
.58344 .57049 L
.58794 .57049 L
.59806 .57049 L
.61636 .57049 L
.65699 .57049 L
.69611 .57049 L
.73768 .57049 L
.77773 .57049 L
.81627 .57049 L
.85726 .57049 L
.89674 .57049 L
.9347 .57049 L
.97511 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOoo
o`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002@oooo0P0000Coool200001?ooo`800006oooo00<0003ooooo
ool0NOooo`00Soooo`040000oooooooo00002?ooo`040000oooooooo00001Oooo`030000oooooooo
07Woool008ooool010000?ooooooo`0000_oool00`000?ooooooo`03oooo0P0007[oool008Woool4
00000_ooo`040000oooooooo00002Oooo`800006oooo00<0003oooooool0NOooo`00Soooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool3
00001Oooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool0
0:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?ooo`800004
oooo0P0000Goool300001?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000_oool0
0`000?ooooooo`03oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002?ooo`D00004
oooo0P0007[oool008Woool400000_ooo`040000oooooooo00002?ooo`040000oooooooo00001Ooo
o`030000oooooooo07Woool008ooool010000?ooooooo`0000Woool00`000?ooo`000005oooo00<0
003oooooool0NOooo`00T?ooo`80000;oooo0P0000Goool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool0093oool200001?ooo`800004oooo0P0000Koool00`000?ooooooo`1i
oooo002?oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool0NOoo
o`00Soooo`040000oooooooo00002_ooo`030000oooooooo00Coool20000N_ooo`00ROooo`@00002
oooo00@0003oooooool0000;oooo00<0003oooooool00oooo`030000oooooooo07Woool008ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P00
00[oool200001_ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?oo
o`800004oooo0P0000?oool400001Oooo`030000oooooooo07Woool008ooool010000?ooooooo`00
00Soool00`000?ooooooo`06oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool20000N_ooo`00ROooo`@00002oooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002@oooo0P0000Coool200000oooo`D00004oooo00<0003oooooool0NOooo`00Sooo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002?oooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`80001joooo0029oooo100000;oool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo
00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool002Woool30000:?ooo`<0000T
oooo100002Goool00`000?ooooooo`0Toooo100002Ooool300009oooo`00:Oooo`040000oooooooo
0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo0P0002Goool00`000?ooooooo`0Y
oooo00<0003oooooool09_ooo`00:Oooo`040000oooooooo00009Oooo`D0000Uoooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo1@0002Ooool002?oool400000_oo
o`<0000Poooo100000;oool010000?ooooooo`0001ooool400001?ooo`030000oooooooo02Coool0
0`000?ooooooo`0Voooo00<0003oooooool09?ooo`040000oooooooo0000:?ooo`00:_ooo`030000
oooooooo02Koool00`000?ooo`00000Uoooo00@0003oooooool0000Uoooo00<0003oooooool09?oo
o`040000oooooooo00009_ooo`030000oooo000002Soool002[oool300009oooo`80000Voooo0P00
02Koool00`000?ooooooo`0Uoooo0P0002Soool20000:?ooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`003Oooool0000600003_ooo`004oooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00?oool406Ko00<00000I_l0I_l0201Vo`030000
06Ko06Ko00D0I_l700001C?o00030000<ol0<ol000Lco`000ol0V@0003?o0008<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Pco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Soool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`07
oooo00<0003oooooool04_ooo`00:?ooo`030000oooooooo02Koool00`000?ooooooo`0Joooo2`1V
o`800009<ol000?o09T0I_lco`007C?o00030000oooooooo02Koool00`000?ooooooo`0Voooo00<0
003oooooool09oooo`00NOooo`@0I_l7<ol000<0I_lco`0co`007C?o00030000oooooooo07Woool0
07goool306Ko13?o000306Ko<ol0<ol001dco`000`000?ooooooo`1ioooo001ooooo00<00000I_l0
I_l00`1Voalco`020000N_ooo`00P?ooo`050000<ol0<ol0<ol006Ko01lco`000`000?ooooooo`1i
oooo0021oooo0P000003<ol0o`2I<ol001hco`000`000?ooooooo`1ioooo0023oooo00<0003o09Tc
o`007S?o00030000oooooooo07Woool008?oool00`000?l0VC?o000N<ol000<0003oooooool0NOoo
o`00Q?ooo`03o`2I<ol0<ol001dco`020000N_ooo`00Q?ooo`03o`2I0000<ol001dco`000`000?oo
ooooo`1ioooo0024oooo00?o09Woool000007C?o00030000oooooooo07Woool008Coool00ol0VOoo
o`00000M<ol000<0003oooooool0NOooo`00Qooooadco`1loooo0028oooo73?o07coool008SooolL
<ol0O?ooo`00R?oooa`co`1loooo0029oooo6c?o07coool007Woool00`000?ooooooo`0=oooo6c?o
00030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool01?oooaXco`00
0oooo`000?ooo`1ioooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01?oo
o`Tco`02000013?o00800004<ol00P0000<co`000oooo`000?ooo`1ioooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000<co`00100003?o
03?o000000Pco`00100003?o03?o0000008co`000oooo`000?ooo`1ioooo001goooo00<0003ooooo
ool00_ooo`030000oooooooo00coool7<ol000@0000co`0co`00000;<ol000<0000co`0co`000_oo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500002oooo`Lco`00100003?o03?o0000
00Tco`0200000c?o0003oooo0000oooo07Woool007Soool01@000?ooooooooooo`00000?oooo1S?o
00040000<ol0<ol000002C?o00030000<ol0<ol0008co`000oooo`000?ooo`1ioooo001ioooo00<0
003oooooool04?ooo`Lco`0200002S?o00<00002<ol000<0003oooooool0NOooo`00S?oooaPco`1l
oooo002<oooo63?o07coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.26171 .57049 L
.30316 .57049 L
.34309 .57049 L
.3815 .57049 L
.42237 .57049 L
.46172 .57049 L
.48147 .57049 L
.49012 .57049 L
.49468 .57049 L
.49719 .57049 L
.49842 .57049 L
.49955 .57049 L
s
.49955 .57049 m
.49956 .61803 L
s
0 .4 1 r
.02381 .57049 m
.06244 .57049 L
.06361 .57049 L
.06484 .57049 L
.06548 .57049 L
.06619 .57049 L
.06744 .57049 L
.06861 .57049 L
.06988 .57049 L
.07107 .57049 L
.07216 .57049 L
.07285 .57049 L
.07349 .57049 L
.0742 .57049 L
.07495 .57049 L
.07567 .57049 L
.07634 .57049 L
.0776 .57049 L
.07884 .57049 L
.07998 .57049 L
.08123 .57049 L
.08255 .57049 L
.08326 .57049 L
.08391 .57049 L
.08466 .57049 L
.08537 .57049 L
.08662 .57049 L
.08733 .57049 L
.08799 .57049 L
.08865 .57049 L
.08937 .57049 L
.09015 .57049 L
.09088 .57049 L
.09166 .57049 L
.09249 .57049 L
.09326 .57049 L
.09396 .57049 L
.09523 .57049 L
.09588 .57049 L
.09658 .57049 L
.09784 .57049 L
.09903 .57049 L
.0997 .57049 L
.10043 .57049 L
.1012 .57049 L
.10192 .57049 L
.1032 .57049 L
.10392 .57049 L
.10458 .57049 L
.10586 .57049 L
Mistroke
.10702 .57049 L
.10766 .57049 L
.10836 .57049 L
.10962 .57049 L
.1108 .57049 L
.11205 .57049 L
.11312 .57049 L
.11429 .57049 L
.115 .57049 L
.11568 .57049 L
.11694 .57049 L
.11764 .57049 L
.1183 .57049 L
.11901 .57049 L
.11977 .57049 L
.12097 .57049 L
.12223 .57049 L
.12289 .57049 L
.12361 .57049 L
.12488 .57049 L
.12607 .57049 L
.12733 .57049 L
.12853 .57049 L
.12961 .57049 L
.13071 .57049 L
.13189 .57049 L
.13301 .57049 L
.13405 .57049 L
.13526 .57049 L
.13639 .57049 L
.13763 .57049 L
.13896 .57049 L
.14015 .57049 L
.14143 .57049 L
.14216 .57049 L
.14283 .57049 L
.14415 .57049 L
.1454 .57049 L
.14671 .57049 L
.14801 .57049 L
.14874 .57049 L
.14943 .57049 L
.15066 .57049 L
.15179 .57049 L
.15301 .57049 L
.15431 .57049 L
.15498 .57049 L
.15573 .57049 L
.15704 .57049 L
.15777 .57049 L
Mistroke
.15856 .57049 L
.15931 .57049 L
.15999 .57049 L
.16131 .57049 L
.16206 .57049 L
.16275 .57049 L
.16402 .57049 L
.16472 .57049 L
.16537 .57049 L
.16663 .57049 L
.16726 .57049 L
.16796 .57049 L
.16919 .57049 L
.17034 .57049 L
.17104 .57049 L
.1717 .57049 L
.17294 .57049 L
.17364 .57049 L
.17428 .57049 L
.17498 .57049 L
.17573 .57049 L
.17688 .57049 L
.17812 .57049 L
.17929 .57049 L
.18036 .57049 L
.18155 .57049 L
.18286 .57049 L
.18351 .57049 L
.18422 .57049 L
.18548 .57049 L
.18672 .57049 L
.18742 .57049 L
.18807 .57049 L
.18876 .57049 L
.1894 .57049 L
.19012 .57049 L
.19082 .57049 L
.19204 .57049 L
.19317 .57049 L
.19441 .57049 L
.19573 .57049 L
.19649 .57049 L
.19718 .57049 L
.19794 .57049 L
.19874 .57049 L
.19944 .57049 L
.20009 .57049 L
.20085 .57049 L
.20156 .57049 L
.2022 .57049 L
Mistroke
.2029 .57049 L
.20411 .57049 L
.2048 .57049 L
.20553 .57049 L
.20684 .57049 L
.20809 .57049 L
.20923 .57049 L
.21054 .57049 L
.21179 .57049 L
.21294 .57049 L
.21401 .57049 L
.21518 .57049 L
.21643 .57049 L
.2171 .57049 L
.2178 .57049 L
.21857 .57049 L
.21928 .57049 L
.22057 .57049 L
.22129 .57049 L
.22197 .57049 L
.22324 .57049 L
.2244 .57049 L
.22504 .57049 L
.22573 .57049 L
.227 .57049 L
.22821 .57049 L
.22933 .57049 L
.23055 .57049 L
.23184 .57049 L
.23297 .57049 L
.23401 .57049 L
.23516 .57049 L
.23639 .57049 L
.23709 .57049 L
.23773 .57049 L
.23844 .57049 L
.23919 .57049 L
.24044 .57049 L
.24116 .57049 L
.24182 .57049 L
.24307 .57049 L
.24421 .57049 L
.24552 .57049 L
.24676 .57049 L
.25163 .57049 L
.2523 .57049 L
.25303 .57049 L
.25435 .57049 L
.25552 .57049 L
.25681 .57049 L
Mistroke
.25756 .57049 L
.25825 .57049 L
.25905 .57049 L
.25977 .57049 L
.26109 .57049 L
.26182 .57049 L
.2625 .57049 L
.26379 .57049 L
.26448 .57049 L
.2652 .57049 L
.26642 .57049 L
.26712 .57049 L
.26777 .57049 L
.26895 .57049 L
.27021 .57049 L
.2713 .57049 L
.27248 .57049 L
.2732 .57049 L
.27386 .57049 L
.27517 .57049 L
.27644 .57049 L
.27762 .57049 L
.27878 .57049 L
.28002 .57049 L
.28073 .57049 L
.2814 .57049 L
.28266 .57049 L
.2833 .57049 L
.28398 .57049 L
.2852 .57049 L
.28652 .57049 L
.28727 .57049 L
.28798 .57049 L
.28906 .57049 L
.29024 .57049 L
.29147 .57049 L
.29262 .57049 L
.2937 .57049 L
.29468 .57049 L
.29582 .57049 L
.29689 .57049 L
.29805 .57049 L
.29928 .57049 L
.30033 .57049 L
.30149 .57049 L
.30274 .57049 L
.30344 .57049 L
.30408 .57049 L
.30532 .57049 L
.3065 .57049 L
Mistroke
.30765 .57049 L
.30887 .57049 L
.30951 .57049 L
.3102 .57049 L
.31143 .57049 L
.3126 .57049 L
.31384 .57049 L
.31501 .57049 L
.31609 .57049 L
.3174 .57049 L
.31815 .57049 L
.31884 .57049 L
.3201 .57049 L
.32074 .57049 L
.32145 .57049 L
.32265 .57049 L
.32395 .57049 L
.32518 .57049 L
.32631 .57049 L
.32738 .57049 L
.32852 .57049 L
.3296 .57049 L
.33059 .57049 L
.33174 .57049 L
.33299 .57049 L
.33418 .57049 L
.33527 .57049 L
.33639 .57049 L
.33745 .57049 L
.3386 .57049 L
.33985 .57049 L
.34115 .57049 L
.34238 .57049 L
.34349 .57049 L
.3447 .57049 L
.34535 .57049 L
.34603 .57049 L
.34726 .57049 L
.34858 .57049 L
.34933 .57049 L
.35003 .57049 L
.3513 .57049 L
.35245 .57049 L
.35309 .57049 L
.35378 .57049 L
.35504 .57049 L
.35617 .57049 L
.35741 .57049 L
.3587 .57049 L
.35991 .57049 L
Mistroke
.36095 .57049 L
.36206 .57049 L
.36328 .57049 L
.36441 .57049 L
.36514 .57049 L
.36583 .57049 L
.36712 .57049 L
.36835 .57049 L
.36899 .57049 L
.36969 .57049 L
.37091 .57049 L
.37221 .57049 L
.3734 .57049 L
.37452 .57049 L
.3752 .57049 L
.37593 .57049 L
.37662 .57049 L
.37727 .57049 L
.37856 .57049 L
.37977 .57049 L
.38107 .57049 L
.38176 .57049 L
.3825 .57049 L
.38324 .57049 L
.38401 .57049 L
.38468 .57049 L
.3854 .57049 L
.38672 .57049 L
.38793 .57049 L
.38857 .57049 L
.38927 .57049 L
.39 .57049 L
.39068 .57049 L
.39193 .57049 L
.39308 .57049 L
.39371 .57049 L
.39441 .57049 L
.39566 .57049 L
.39689 .57049 L
.39801 .57049 L
.39929 .57049 L
.4005 .57049 L
.40163 .57049 L
.40266 .57049 L
.4038 .57049 L
.40499 .57049 L
.4063 .57049 L
.40749 .57049 L
.40815 .57049 L
.40886 .57049 L
Mistroke
.41016 .57049 L
.41138 .57049 L
.41267 .57049 L
.41377 .57049 L
.41498 .57049 L
.41567 .57049 L
.4164 .57049 L
.4177 .57049 L
.41843 .57049 L
.4191 .57049 L
.41984 .57049 L
.42063 .57049 L
.42132 .57049 L
.42206 .57049 L
.42277 .57049 L
.42341 .57049 L
.42464 .57049 L
.42594 .57049 L
.42715 .57049 L
.42847 .57049 L
.42972 .57049 L
.43088 .57049 L
.43202 .57049 L
.43306 .57049 L
.43426 .57049 L
.43539 .57049 L
.43663 .57049 L
.43793 .57049 L
.43904 .57049 L
.44027 .57049 L
.44158 .57049 L
.44232 .57049 L
.44299 .57049 L
.4443 .57049 L
.44553 .57049 L
.44659 .57049 L
.44775 .57049 L
.44896 .57049 L
.4501 .57049 L
.45116 .57049 L
.45213 .57049 L
.45325 .57049 L
.45432 .57049 L
.45546 .57049 L
.45668 .57049 L
.45783 .57049 L
.45888 .57049 L
.46011 .57049 L
.4608 .57049 L
.46144 .57049 L
Mistroke
.46261 .57049 L
.46385 .57049 L
.46507 .57049 L
.46576 .57049 L
.4664 .57049 L
.46757 .57049 L
.46881 .57049 L
.46987 .57049 L
.47098 .57049 L
.47221 .57049 L
.47333 .57049 L
.47452 .57049 L
.47582 .57049 L
.47703 .57049 L
.47816 .57049 L
.47885 .57049 L
.47951 .57049 L
.48073 .57049 L
.48205 .57049 L
.4828 .57049 L
.48349 .57049 L
.48454 .57049 L
.48568 .57049 L
.48675 .57049 L
.48773 .57049 L
.48887 .57049 L
.49012 .57049 L
.4913 .57049 L
.49239 .57049 L
.49363 .57049 L
.49479 .57049 L
.49583 .57049 L
.49696 .57049 L
.49819 .57049 L
.49949 .57049 L
.5006 .57049 L
.50182 .57049 L
.50313 .57049 L
.50434 .57049 L
.50502 .57049 L
.50567 .57049 L
.50634 .57049 L
.50708 .57049 L
.50833 .57049 L
.50947 .57049 L
.51073 .57049 L
.51205 .57049 L
.51316 .57049 L
.51436 .57049 L
.51548 .57049 L
Mistroke
.5165 .57049 L
.5177 .57049 L
.519 .57049 L
.52023 .57049 L
.52136 .57049 L
.52257 .57049 L
.52387 .57049 L
.52509 .57049 L
.52621 .57049 L
.52752 .57049 L
.52826 .57049 L
.52894 .57049 L
.5302 .57049 L
.53083 .57049 L
.53154 .57049 L
.53221 .57049 L
.53293 .57049 L
.5342 .57049 L
.53491 .57049 L
.53558 .57049 L
.5363 .57049 L
.53708 .57049 L
.53775 .57049 L
.53848 .57049 L
.53917 .57049 L
.53981 .57049 L
.54101 .57049 L
.54229 .57049 L
.5435 .57049 L
.54481 .57049 L
.54606 .57049 L
.54721 .57049 L
.54833 .57049 L
.54939 .57049 L
.55061 .57049 L
.55171 .57049 L
.55408 .57049 L
.55537 .57049 L
.55658 .57049 L
.55788 .57049 L
.55857 .57049 L
.55932 .57049 L
.56064 .57049 L
.56184 .57049 L
.56297 .57049 L
.56418 .57049 L
.56521 .57049 L
.56634 .57049 L
.56756 .57049 L
.56887 .57049 L
Mistroke
.5701 .57049 L
.57124 .57049 L
.57231 .57049 L
.57331 .57049 L
.57441 .57049 L
.57558 .57049 L
.57681 .57049 L
.57797 .57049 L
.57901 .57049 L
.58014 .57049 L
.58137 .57049 L
.5825 .57049 L
.58504 .57049 L
.58961 .57049 L
.60003 .57049 L
.62108 .57049 L
.66085 .57049 L
.69911 .57049 L
.73982 .57049 L
.77902 .57049 L
.82067 .57049 L
.86081 .57049 L
.89942 .57049 L
.94049 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOoo
o`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002@oooo0P0000Coool200001?ooo`800006oooo00<0003ooooo
ool0NOooo`00Soooo`040000oooooooo00002?ooo`040000oooooooo00001Oooo`030000oooooooo
07Woool008ooool010000?ooooooo`0000_oool00`000?ooooooo`03oooo0P0007[oool008Woool4
00000_ooo`040000oooooooo00002Oooo`800006oooo00<0003oooooool0NOooo`00Soooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool3
00001Oooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool0
0:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?ooo`800004
oooo0P0000Goool300001?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000_oool0
0`000?ooooooo`03oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002?ooo`D00004
oooo0P0007[oool008Woool400000_ooo`040000oooooooo00002?ooo`040000oooooooo00001Ooo
o`030000oooooooo07Woool008ooool010000?ooooooo`0000Woool00`000?ooo`000005oooo00<0
003oooooool0NOooo`00T?ooo`80000;oooo0P0000Goool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool0093oool200001?ooo`800004oooo0P0000Koool00`000?ooooooo`1i
oooo002?oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool0NOoo
o`00Soooo`040000oooooooo00002_ooo`030000oooooooo00Coool20000N_ooo`00ROooo`@00002
oooo00@0003oooooool0000;oooo00<0003oooooool00oooo`030000oooooooo07Woool008ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P00
00[oool200001_ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?oo
o`800004oooo0P0000?oool400001Oooo`030000oooooooo07Woool008ooool010000?ooooooo`00
00Soool00`000?ooooooo`06oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool20000N_ooo`00ROooo`@00002oooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002@oooo0P0000Coool200000oooo`D00004oooo00<0003oooooool0NOooo`00Sooo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002?oooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`80001joooo0029oooo100000;oool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo
00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool002Woool30000:?ooo`<0000T
oooo100002Goool00`000?ooooooo`0Toooo100002Ooool300009oooo`00:Oooo`040000oooooooo
0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo0P0002Goool00`000?ooooooo`0Y
oooo00<0003oooooool09_ooo`00:Oooo`040000oooooooo00009Oooo`D0000Uoooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo1@0002Ooool002?oool400000_oo
o`<0000Poooo100000;oool010000?ooooooo`0001ooool400001?ooo`030000oooooooo02Coool0
0`000?ooooooo`0Voooo00<0003oooooool09?ooo`040000oooooooo0000:?ooo`00:_ooo`030000
oooooooo02Koool00`000?ooo`00000Uoooo00@0003oooooool0000Uoooo00<0003oooooool09?oo
o`040000oooooooo00009_ooo`030000oooo000002Soool002[oool300009oooo`80000Voooo0P00
02Koool00`000?ooooooo`0Uoooo0P0002Soool20000:?ooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`003Oooool0000600003_ooo`004oooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oool0
0000300000Dco`000`0003?o03?o0008<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0008<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo01;oool002Soool00`000?ooooooo`0Voooo00<0003oooooool08Oooo`H0000D<ol000?o
09Tco`0co`004S?o00030000oooooooo02Koool00`000?ooooooo`0Voooo00<0003oooooool09ooo
o`00N_ooo`<0000B<ol000?o09Tco`0co`004S?o00030000oooooooo07Woool007goool2000043?o
0003o`2I<ol0<ol0018co`000`000?ooooooo`1ioooo001ooooo00<0000co`0co`003C?o0003o`2I
<ol0<ol0018co`020000N_ooo`00P?ooo`030000<ol0<ol000`co`000ol0VC?o03?o000B<ol000<0
003oooooool0NOooo`00POooo`80000<<ol000?o09Tco`0co`004S?o00030000oooooooo07Woool0
08?oool00`0003?o03?o0009<ol000?o09Tco`0co`004S?o00030000oooooooo07Woool008?oool0
0`0003?o03?o0009<ol000?o09Tco`0co`004S?o00030000oooooooo07Woool008Coool00`0003?o
03?o0008<ol000?o09Tco`0co`004S?o0080001joooo0025oooo00<0000co`0co`001c?o0003o`2I
<ol0<ol0018co`000`000?ooooooo`1ioooo0026oooo00<0000co`0co`001S?o0003o`2I<ol0<ol0
018co`000`000?ooooooo`1ioooo0026oooo00<0000co`0co`001S?o0003o`2I<ol0<ol0018co`00
0`000?ooooooo`1ioooo0027oooo7C?o07coool008SooolL<ol0O?ooo`00R?oooa`co`1loooo0028
oooo73?o07coool008WooolK<ol0O?ooo`00Ooooo`030000oooooooo00OooolE<ol000<0000co`0c
o`000c?o07coool007koool00`000?ooooooo`08oooo00<0000co`0co`004c?o00030000<ol0<ol0
008co`1loooo001noooo00<0003oooooool00_ooo`800004oooo00<0000co`0co`001c?o00800004
<ol00P0000@co`000`0003?o03?o0002<ol0O?ooo`00O_ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0000co`0co`001C?o00040000<ol0<ol000002C?o00030000<ol0<ol0
008co`1loooo001moooo00<0003oooooool00_ooo`030000oooooooo00Koool7<ol000@0000co`0c
o`00000:<ol000@0000co`0co`0co`1loooo001noooo00<0003oooooool01@0000Goool7<ol000@0
000co`0co`000009<ol000<0000co`0co`000S?o07coool007koool01@000?ooooooooooo`000009
oooo1S?o00040000<ol0<ol000002C?o00030000<ol0<ol0008co`1loooo001ooooo00<0003ooooo
ool02_ooo`Lco`0200002C?o00030000<ol0<ol000<co`1loooo002<oooo63?o07coool008cooolH
<ol0O?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.26171 .57049 L
.30316 .57049 L
.34309 .57049 L
.3815 .57049 L
.42237 .57049 L
.46172 .57049 L
.49955 .57049 L
.51896 .57049 L
.52455 .57049 L
.52986 .57049 L
.53463 .57049 L
.53594 .57049 L
.53733 .57049 L
.53865 .57049 L
s
.53865 .57049 m
.53865 .61803 L
s
0 .4 1 r
.02381 .57048 m
.04262 .57048 L
.06244 .57048 L
.07286 .57047 L
.08255 .57047 L
.09388 .57046 L
.10458 .57046 L
.125 .57044 L
.14357 .57042 L
.16355 .57039 L
.18199 .57035 L
.20071 .57029 L
.21136 .57025 L
.22134 .5702 L
.24158 .57007 L
.26011 .5699 L
.27909 .56967 L
.28984 .56949 L
.29982 .5693 L
.32034 .56877 L
.33895 .56809 L
.35819 .56711 L
.36904 .56639 L
.37901 .56559 L
.39784 .56364 L
.40853 .5622 L
.4185 .56059 L
.43885 .55625 L
.45741 .55065 L
.4765 .54255 L
.48728 .53656 L
.49726 .52984 L
.51592 .5133 L
.52655 .5008 L
.53131 .49424 L
.53383 .4905 L
.53652 .48628 L
.53789 .48402 L
.53919 .48183 L
.54035 .57049 L
.54162 .57049 L
.54281 .57049 L
.54408 .57049 L
.54516 .57049 L
.54635 .57049 L
.54704 .57049 L
.5477 .57049 L
.54893 .57049 L
.54962 .57049 L
.55026 .57049 L
Mistroke
.55096 .57049 L
.5517 .57049 L
.55235 .57049 L
.55305 .57049 L
.55433 .57049 L
.55557 .57049 L
.5567 .57049 L
.55778 .57049 L
.55893 .57049 L
.56001 .57049 L
.561 .57049 L
.56216 .57049 L
.56342 .57049 L
.56461 .57049 L
.56571 .57049 L
.56684 .57049 L
.5679 .57049 L
.56907 .57049 L
.57032 .57049 L
.57156 .57049 L
.57287 .57049 L
.57521 .57049 L
.57645 .57049 L
.5771 .57049 L
.57779 .57049 L
.57906 .57049 L
.58023 .57049 L
.58135 .57049 L
.5824 .57049 L
.58478 .57049 L
.59499 .57049 L
.61337 .57049 L
.65225 .57049 L
.69358 .57049 L
.73339 .57049 L
.77169 .57049 L
.81244 .57049 L
.85167 .57049 L
.88939 .57049 L
.92956 .57049 L
.96821 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOoo
o`00Y?ooo`030000oooooooo07Woool00:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool0
0:Coool00`000?ooooooo`1ioooo002@oooo0P0000Coool200001?ooo`800006oooo00<0003ooooo
ool0NOooo`00Soooo`040000oooooooo00002?ooo`040000oooooooo00001Oooo`030000oooooooo
07Woool008ooool010000?ooooooo`0000_oool00`000?ooooooo`03oooo0P0007[oool008Woool4
00000_ooo`040000oooooooo00002Oooo`800006oooo00<0003oooooool0NOooo`00Soooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool3
00001Oooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool0
0:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?ooo`800004
oooo0P0000Goool300001?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000_oool0
0`000?ooooooo`03oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002?ooo`D00004
oooo0P0007[oool008Woool400000_ooo`040000oooooooo00002?ooo`040000oooooooo00001Ooo
o`030000oooooooo07Woool008ooool010000?ooooooo`0000Woool00`000?ooo`000005oooo00<0
003oooooool0NOooo`00T?ooo`80000;oooo0P0000Goool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`80001joooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Y?ooo`80001joooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool0093oool200001?ooo`800004oooo0P0000Koool00`000?ooooooo`1i
oooo002?oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool0NOoo
o`00Soooo`040000oooooooo00002_ooo`030000oooooooo00Coool20000N_ooo`00ROooo`@00002
oooo00@0003oooooool0000;oooo00<0003oooooool00oooo`030000oooooooo07Woool008ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P00
00[oool200001_ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool0
0`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0
003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00T?oo
o`800004oooo0P0000?oool400001Oooo`030000oooooooo07Woool008ooool010000?ooooooo`00
00Soool00`000?ooooooo`06oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002Ooo
o`030000oooooooo00Goool20000N_ooo`00ROooo`@00002oooo00@0003oooooool0000:oooo00<0
003oooooool01?ooo`030000oooooooo07Woool008ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool00`000?ooooooo`1ioooo002@oooo0P0000[oool200001_ooo`030000oooooooo
07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1i
oooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?oo
ooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003ooooo
ool0NOooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P00
07[oool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool00`000?oo
ooooo`1ioooo002@oooo0P0000Coool200000oooo`D00004oooo00<0003oooooool0NOooo`00Sooo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002?oooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`80001joooo0029oooo100000;oool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo
00001_ooo`0506Kooooooooooooo000000Koool00`000?ooooooo`1ioooo002@oooo0P0000Koool2
06Ko0_ooo`800006oooo00<0003oooooool0NOooo`00V?ooo`80I_l:oooo00<0003oooooool0NOoo
o`00Uoooo`0306Kooooo06Ko00[oool20000N_ooo`00U_ooo`0406Kooooooooo06Ko2_ooo`030000
oooooooo07Woool009Koool0101Vooooooooo`1Vo`[oool00`000?ooooooo`1ioooo002Eoooo00D0
I_ooooooooooool0I_l02_ooo`030000oooooooo07Woool009Coool00`1Vooooooooo`02oooo00<0
I_ooooooool02?ooo`030000oooooooo07Woool009?oool00`1Vooooooooo`03oooo00<0I_oooooo
ool02?ooo`80001joooo002Boooo00<0I_ooooooool01?ooo`0306Kooooooooo00Soool00`000?oo
ooooo`1ioooo002Aoooo00<0I_ooooooool01Oooo`0306Kooooooooo00Soool00`000?ooooooo`1i
oooo002@oooo00<0I_ooooooool01_ooo`0306Kooooooooo00Soool00`000?ooooooo`1ioooo000Y
oooo0`0002Soool300009?ooo`@0000@oooo00<0I_ooooooool01oooo`0306Kooooooooo00Soool0
0`000?ooooooo`0Toooo100002Ooool300009oooo`00:Oooo`040000oooooooo0000:?ooo`030000
oooooooo02?oool00`000?ooooooo`0@oooo00<0I_ooooooool02?ooo`0306Kooooooooo00Soool2
00009Oooo`030000oooooooo02Woool00`000?ooooooo`0Voooo000Yoooo00@0003oooooool0000U
oooo1@0002Goool00`000?ooooooo`0=oooo0P1Vo`_oool00`1Vooooooooo`08oooo00<0003ooooo
ool09Oooo`030000oooooooo02Goool500009oooo`008oooo`@00002oooo0`00023oool400000_oo
o`040000oooooooo00007oooo`@00004oooo00<0003oooooool02_ooo`80I_l=oooo00<0I_oooooo
ool02?ooo`030000oooooooo02Koool00`000?ooooooo`0Toooo00@0003oooooool0000Xoooo000Z
oooo00<0003oooooool09_ooo`030000oooo000002Goool010000?ooooooo`0000Woool206Ko3ooo
o`0306Kooooooooo00Soool00`000?ooooooo`0Toooo00@0003oooooool0000Voooo00<0003oool0
0000:?ooo`00:_ooo`<0000Woooo0P0002Koool200002?ooo`80I_lAoooo00<0I_ooooooool02?oo
o`030000oooooooo02Goool20000:?ooo`80000Xoooo0023oooo0`1Voa?oool00`1Vooooooooo`08
oooo0P0007[oool0087oool206Ko5_ooo`0306Kooooooooo00Soool00`000?ooooooo`1ioooo001m
oooo101VoaSoool00`1Vooooooooo`08oooo00<0003oooooool0NOooo`00L_ooo`/0I_lLoooo00<0
I_ooooooool02?ooo`030000oooooooo07Woool006Soool:06Ko9oooo`0306Kooooooooo00Soool0
0`000?ooooooo`1ioooo000=ooooo`0000H0000>oooo000Coooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Soool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooo`00000<
00001C?o00030000<ol0<ol000Pco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Pco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Soool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003ooooo
ool04_ooo`00:?ooo`030000oooooooo02Koool00`000?ooooooo`0Qoooo1P0001hco`000ol0VC?o
03?o0008<ol000<0003oooooool09_ooo`030000oooooooo02Koool00`000?ooooooo`0Woooo001j
oooo0`0001`co`000ol0VC?o03?o0008<ol000<0003oooooool0NOooo`00OOooo`80000J<ol000?o
09Tco`0co`0023?o00030000oooooooo07Woool007ooool00`0003?o03?o000G<ol000?o09Tco`0c
o`0023?o0080001joooo0020oooo00<0000co`0co`005S?o0003o`2I<ol0<ol000Pco`000`000?oo
ooooo`1ioooo0021oooo0P0001Hco`000ol0VC?o03?o0008<ol000<0003oooooool0NOooo`00Pooo
o`030000<ol0<ol001<co`000ol0VC?o03?o0008<ol000<0003oooooool0NOooo`00Poooo`030000
<ol0<ol001<co`000ol0VC?o03?o0008<ol000<0003oooooool0NOooo`00Q?ooo`030000<ol0<ol0
018co`000ol0VC?o03?o0008<ol00P0007[oool008Goool00`0003?o03?o000A<ol000?o09Tco`0c
o`0023?o00030000oooooooo07Woool008Koool00`0003?o03?o000@<ol000?o09Tco`0co`0023?o
00030000oooooooo07Woool008Koool00`0003?o03?o000@<ol000?o09Tco`0co`0023?o00030000
oooooooo07Woool008OooolM<ol0O?ooo`00R?oooa`co`1loooo0028oooo73?o07coool008SooolL
<ol0O?ooo`00ROoooa/co`1loooo001loooo00<0003oooooool02_oooaPco`000`0003?o03?o001l
oooo001koooo00<0003oooooool02?ooo`040000oooooooooooo63?o00030000<ol0oooo07_oool0
07_oool00`000?ooooooo`02oooo0P0000Coool010000?ooooooooooo`Hco`02000013?o00800004
<ol00P0000@co`000`0003?o0?ooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool010000?ooooooooooo`@co`00100003?o03?o000000Pco`00100003?o03?o0000
00<co`000`0003?o0?ooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00Woool4
<ol000@0000co`0co`00000;<ol000<0000co`0co`000S?o00030000oooooooo07[oool007_oool0
0`000?ooooooo`0500002?ooo`@co`00100003?o03?o000000Tco`02000013?o00030000<ol0oooo
07_oool007_oool01@000?ooooooooooo`00000<oooo0c?o00040000<ol0<ol000002C?o00030000
<ol0<ol000<co`000`0003?o0?ooo`1koooo001loooo00<0003oooooool03Oooo`@co`0200002S?o
00<00002<ol000<0000co`0co`00O?ooo`00S?oooaPco`1loooo002<oooo63?o07coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.26171 .57049 L
.30316 .57049 L
.34309 .57049 L
.3815 .57049 L
.42237 .57049 L
.46172 .57049 L
.49955 .57049 L
.53984 .57049 L
.55838 .57049 L
.56817 .57049 L
.57355 .57049 L
.57618 .57049 L
.57734 .57049 L
.57861 .57049 L
.57931 .57049 L
s
.57931 .57049 m
.57931 .61803 L
s
0 .4 1 r
.02381 .57047 m
.04262 .57046 L
.06244 .57045 L
.07286 .57044 L
.08255 .57043 L
.09388 .57042 L
.10458 .5704 L
.125 .57036 L
.14357 .57031 L
.16355 .57023 L
.18199 .57012 L
.20071 .56998 L
.21136 .56987 L
.22134 .56975 L
.24158 .56943 L
.26011 .56901 L
.27909 .56841 L
.28984 .56797 L
.29982 .56748 L
.32034 .56615 L
.33895 .56445 L
.35819 .56197 L
.36904 .56015 L
.37901 .55814 L
.39784 .55322 L
.40853 .54959 L
.4185 .54552 L
.43885 .53459 L
.45741 .52046 L
.4765 .50004 L
.48728 .48494 L
.49726 .46801 L
.51592 .42631 L
.52655 .39478 L
.53652 .35817 L
.54635 .31333 L
.5567 .25334 L
.56554 .18751 L
.57018 .14556 L
.57521 .09248 L
.57655 .07679 L
.57796 .05934 L
.57917 .0437 L
.57985 .57049 L
.58049 .57049 L
.58548 .57049 L
.59482 .57049 L
.61577 .57049 L
.65459 .57049 L
.69587 .57049 L
Mistroke
.73563 .57049 L
.77388 .57049 L
.81457 .57049 L
.85376 .57049 L
.89539 .57049 L
.93551 .57049 L
.97411 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002T
oooo00<0003oooooool0NOooo`00Xoooo`0306Ko0000oooo07[oool00:?oool00`1Vo`000000001j
oooo002Soooo00<0I_l0003oool0N_ooo`00Xoooo`0306Ko0000oooo07[oool00:?oool00`1Vo`00
0?ooo`1joooo002Soooo00<0I_l0003oool0N_ooo`00Xoooo`0306Ko0000000007[oool00:?oool0
0`1Vo`000?ooo`1joooo002Soooo00<0I_l0003oool0N_ooo`00T?ooo`800004oooo0P0000Coool2
00001Oooo`0306Ko0000oooo07[oool008ooool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`1Vo`000?ooo`1joooo002?oooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`0306Ko0000000007[oool008Woool400000_ooo`040000oooooooo00002Oooo`800005oooo00<0
I_l0003oool0N_ooo`00Soooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`1Vo`00
0?ooo`1joooo002@oooo0P0000[oool300001?ooo`0306Ko0000oooo07[oool00:;oool00`1Voooo
o`00001koooo002Roooo00@0I_ooool00000001joooo002Roooo00<0I_ooool00000Noooo`00X_oo
o`0306Kooooo000007_oool00:;oool00`1Vooooo`00001koooo002Roooo00<0I_ooool00000Nooo
o`00X_ooo`0406Kooooo00000000N_ooo`00XOooo`0406Kooooooooo0000Noooo`00XOooo`0406Ko
oooooooo0000Noooo`00XOooo`0406Kooooooooo0000Noooo`00XOooo`0406Kooooooooo0000Nooo
o`00XOooo`0306Kooooooooo0080001joooo002Qoooo00@0I_ooooooool0001koooo002Qoooo00@0
I_ooooooool0001koooo002Qoooo00@0I_ooooooool0001koooo002Poooo00D0I_ooooooooooool0
0000Noooo`00X?ooo`0406Kooooooooooooo0P0007[oool00:3oool01@1Vooooooooooooo`00001k
oooo002Poooo00D0I_ooooooooooool00000Noooo`00T?ooo`800004oooo0P0000Goool3000000D0
I_ooooooooooool00000Noooo`00Soooo`040000oooooooo00002oooo`030000oooo06Ko00?oool0
0`000?ooooooo`1ioooo002?oooo00@0003oooooool00008oooo1@00000406Kooooooooooooo0P00
07[oool008Woool400000_ooo`040000oooooooo00002?ooo`060000oooooooo0000oooo06Ko0ooo
o`030000oooooooo07Woool008ooool010000?ooooooo`0000Woool01@000?ooo`000?ooo`1Vo`03
oooo00<0003oooooool0NOooo`00T?ooo`80000;oooo0P000003oooo06Kooooo00;oool00`000?oo
ooooo`1ioooo002Ooooo00<0I_ooooooool00_ooo`030000oooooooo07Woool009ooool00`1Voooo
ooooo`02oooo0P0007[oool009ooool00`1Vooooooooo`02oooo00<0003oooooool0NOooo`00Wooo
o`0306Kooooooooo00;oool00`000?ooooooo`1ioooo002Ooooo00<0I_ooooooool00_ooo`030000
oooooooo07Woool009ooool00`1Vooooooooo`02oooo00<0003oooooool0NOooo`00Woooo`0306Ko
oooooooo00;oool20000N_ooo`00Woooo`0306Kooooooooo00;oool00`000?ooooooo`1ioooo002O
oooo00<0I_ooooooool00_ooo`030000oooooooo07Woool009koool00`1Vooooooooo`03oooo00<0
003oooooool0NOooo`00W_ooo`0306Kooooooooo00?oool00`000?ooooooo`1ioooo002Noooo00<0
I_ooooooool00oooo`80001joooo002Noooo00<0I_ooooooool00oooo`030000oooooooo07Woool0
09koool00`1Vooooooooo`03oooo00<0003oooooool0NOooo`00W_ooo`0306Kooooooooo00?oool0
0`000?ooooooo`1ioooo002Noooo00<0I_ooooooool00oooo`030000oooooooo07Woool009goool0
0`1Vooooooooo`04oooo0P0007[oool009goool00`1Vooooooooo`04oooo00<0003oooooool0NOoo
o`00WOooo`0306Kooooooooo00Coool00`000?ooooooo`1ioooo002@oooo0P0000Coool200001?oo
o`800006oooo00<0003oooooool0NOooo`00Soooo`040000oooooooo00002?ooo`040000oooo06Ko
00001Oooo`030000oooooooo07Woool008ooool010000?ooooooo`0000Woool00`1Vo`000?ooo`05
oooo0P0007[oool008Woool400000_ooo`040000oooooooo00002Oooo`0306Kooooo000000Goool0
0`000?ooooooo`1ioooo002?oooo00@0003oooooool00008oooo00@00000I_ooool00005oooo00<0
003oooooool0NOooo`00T?ooo`80000:oooo0P0000Koool00`000?ooooooo`1ioooo002Loooo00<0
I_ooooooool01Oooo`030000oooooooo07Woool009_oool00`1Vooooooooo`06oooo0P0007[oool0
09_oool00`1Vooooooooo`06oooo00<0003oooooool0NOooo`00Voooo`0306Kooooooooo00Koool0
0`000?ooooooo`1ioooo002Koooo00<0I_ooooooool01_ooo`030000oooooooo07Woool009[oool0
0`1Vooooooooo`07oooo00<0003oooooool0NOooo`00V_ooo`0306Kooooooooo00Ooool20000N_oo
o`00V_ooo`0306Kooooooooo00Ooool00`000?ooooooo`1ioooo002Joooo00<0I_ooooooool01ooo
o`030000oooooooo07Woool009Woool00`1Vooooooooo`08oooo00<0003oooooool0NOooo`00VOoo
o`0306Kooooooooo00Soool00`000?ooooooo`1ioooo002Ioooo00<0I_ooooooool02?ooo`80001j
oooo002Ioooo00<0I_ooooooool02?ooo`030000oooooooo07Woool009Soool00`1Vooooooooo`09
oooo00<0003oooooool0NOooo`00V?ooo`0306Kooooooooo00Woool00`000?ooooooo`1ioooo002H
oooo00<0I_ooooooool02Oooo`030000oooooooo07Woool009Soool00`1Vooooooooo`09oooo0P00
07[oool009Soool00`1Vooooooooo`09oooo00<0003oooooool0NOooo`00Uoooo`0306Kooooooooo
00[oool00`000?ooooooo`1ioooo002@oooo0P0000Coool200000oooo`@00005oooo00<0003ooooo
ool0NOooo`00Soooo`040000oooooooo00001?ooo`0506Kooooooooooooo000000Soool00`000?oo
ooooo`1ioooo002?oooo00@0003oooooool00004oooo00<0I_ooooooool00_ooo`030000oooooooo
00Goool20000N_ooo`00ROooo`@00002oooo00@0003oooooool00003oooo00<0I_ooooooool01?oo
o`030000oooooooo00Coool00`000?ooooooo`1ioooo002?oooo00@0003oooooool00003oooo00<0
I_ooooooool00_ooo`040000oooooooo00001Oooo`030000oooooooo07Woool0093oool200001?oo
o`0306Kooooooooo00?oool200001_ooo`030000oooooooo07Woool009Koool00`1Vooooooooo`0;
oooo00<0003oooooool0NOooo`00UOooo`0306Kooooooooo00coool20000N_ooo`00UOooo`0306Ko
oooooooo00coool00`000?ooooooo`1ioooo002Eoooo00<0I_ooooooool03?ooo`030000oooooooo
07Woool009Coool00`1Vooooooooo`0=oooo00<0003oooooool0NOooo`00U?ooo`0306Kooooooooo
00goool00`000?ooooooo`1ioooo002Doooo00<0I_ooooooool03Oooo`80001joooo002Coooo00<0
I_ooooooool03_ooo`030000oooooooo07Woool009?oool00`1Vooooooooo`0>oooo00<0003ooooo
ool0NOooo`00Toooo`0306Kooooooooo00koool00`000?ooooooo`1ioooo002Boooo00<0I_oooooo
ool03oooo`030000oooooooo07Woool009;oool00`1Vooooooooo`0?oooo0P0007[oool0097oool0
0`1Vooooooooo`0@oooo00<0003oooooool0NOooo`00TOooo`0306Kooooooooo013oool00`000?oo
ooooo`1ioooo002@oooo00<0I_ooooooool04Oooo`030000oooooooo07Woool0093oool00`1Voooo
ooooo`0Aoooo00<0003oooooool0NOooo`00Soooo`0306Kooooooooo01;oool20000N_ooo`00Sooo
o`0306Kooooooooo01;oool00`000?ooooooo`1ioooo002>oooo00@0I_ooool000000004oooo0P00
00?oool500001?ooo`030000oooooooo07Woool008koool01@1Vo`000?ooooooo`00000:oooo00<0
003oooooool01?ooo`030000oooooooo07Woool008goool00`1Vooooo`000002oooo00<0003ooooo
ool02?ooo`030000oooooooo00Coool20000N_ooo`00ROooo`@000000`1Vooooo`000002oooo00<0
003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002<oooo00@0I_oooooo
ool00002oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`1ioooo002<
oooo00@0I_ooooooooooool200002_ooo`800006oooo00<0003oooooool0NOooo`00Roooo`0306Ko
oooooooo01Koool00`000?ooooooo`1ioooo002:oooo00<0I_ooooooool05oooo`80001joooo002:
oooo00<0I_ooooooool05oooo`030000oooooooo07Woool008Woool00`1Vooooooooo`0Hoooo00<0
003oooooool0NOooo`00R?ooo`0306Kooooooooo01Woool00`000?ooooooo`1ioooo0027oooo00<0
I_ooooooool06_ooo`030000oooooooo07Woool008Koool00`1Vooooooooo`0Koooo0P0007[oool0
08Goool00`1Vooooooooo`0Loooo00<0003oooooool0NOooo`00Q?ooo`0306Kooooooooo01goool0
0`000?ooooooo`1ioooo0023oooo00<0I_ooooooool07_ooo`030000oooooooo07Woool002Woool3
0000:?ooo`<0000Toooo100000;oool206Ko8Oooo`030000oooooooo02Coool400009oooo`<0000W
oooo000Yoooo00@0003oooooool0000Xoooo00<0003oooooool08oooo`030000oooooooo00;oool0
0`1Vooooooooo`0Qoooo0P0002Goool00`000?ooooooo`0Yoooo00<0003oooooool09_ooo`00:Ooo
o`040000oooooooo00009Oooo`D0000Uoooo00@0003oooooool0I_lToooo00<0003oooooool09Ooo
o`030000oooooooo02Goool500009oooo`008oooo`@00002oooo0`00023oool400000_ooo`040000
oooooooo00007oooo`@00004oooo00<00000I_ooool09?ooo`030000oooooooo02Koool00`000?oo
ooooo`0Toooo00@0003oooooool0000Xoooo000Zoooo00<0003oooooool09_ooo`030000oooo0000
02Goool01000001Vooooo`0002Goool00`000?ooooooo`0Toooo00@0003oooooool0000Voooo00<0
003oool00000:?ooo`00:_ooo`<0000Woooo0P0002?oool206Ko00?oool0000000009_ooo`030000
oooooooo02Goool20000:?ooo`80000Xoooo001foooo0`1Vob_oool20000N_ooo`00L_ooo`@0I_l^
oooo00<0003oooooool0NOooo`00Koooo`<0I_lboooo00<0003oooooool0NOooo`00J?ooo`L0I_le
oooo00<0003oooooool0NOooo`00F_ooo`h0I_lloooo00<0003oooooool0NOooo`003Oooool00006
00003_ooo`004oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oool00000300000Dco`000`0003?o03?o0008<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0008<ol000<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`08oooo00<0003oooooool01oooo`030000oooooooo01;oool002Soool00`000?ooooooo`0V
oooo00<0003oooooool08Oooo`H0000Y<ol000<0003oooooool09_ooo`030000oooooooo02Koool0
0`000?ooooooo`0Woooo001joooo0`0002Lco`000`000?ooooooo`1ioooo001moooo0P0002Dco`00
0`000?ooooooo`1ioooo001ooooo00<0000co`0co`008S?o0080001joooo0020oooo00<0000co`0c
o`008C?o00030000oooooooo07Woool0087oool200008C?o00030000oooooooo07Woool008?oool0
0`0003?o03?o000N<ol000<0003oooooool0NOooo`00Poooo`030000<ol0<ol001hco`000`000?oo
ooooo`1ioooo0024oooo00<0000co`0co`007C?o0080001joooo0025oooo00<0000co`0co`0073?o
00030000oooooooo07Woool008Koool00`0003?o03?o000K<ol000<0003oooooool0NOooo`00Q_oo
o`030000<ol0<ol001/co`000`000?ooooooo`1ioooo0027oooo7C?o07coool008SooolL<ol0O?oo
o`00R?oooa`co`1loooo0028oooo73?o07coool008WooolK<ol0O?ooo`00Ooooo`030000oooooooo
00OooolE<ol000<0000co`0co`000c?o07coool007koool00`000?ooooooo`08oooo00<0000co`0c
o`004c?o00030000<ol0<ol0008co`1loooo001noooo00<0003oooooool00_ooo`800004oooo00<0
000co`0co`001S?o00D00002<ol00P0000@co`000`0003?o03?o0002<ol0O?ooo`00O_ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0000co`0co`001c?o00030000<ol0<ol0
00Pco`000`0003?o03?o0002<ol0O?ooo`00OOooo`030000oooooooo00;oool00`000?ooooooo`06
oooo2C?o00030000<ol0<ol000Tco`00100003?o03?o03?o07coool007koool00`000?ooooooo`05
00001Oooo`Tco`000`0003?o03?o0008<ol000<0000co`0co`000S?o07coool007koool01@000?oo
ooooooooo`000009oooo23?o00030000<ol0<ol000Pco`000`0003?o03?o0002<ol0O?ooo`00Oooo
o`030000oooooooo00[oool7<ol00P0000Tco`000`0003?o03?o0003<ol0O?ooo`00S?oooaPco`1l
oooo002<oooo63?o07coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.26171 .57049 L
.30316 .57049 L
.34309 .57049 L
.3815 .57049 L
.42237 .57049 L
.46172 .57049 L
.49955 .57049 L
.53984 .57049 L
.57861 .57049 L
.58872 .57049 L
.59975 .57049 L
.60479 .57049 L
.61016 .57049 L
.61278 .57049 L
.61524 .57049 L
.61745 .57049 L
.61869 .57049 L
s
.61869 .57049 m
.6187 .61803 L
s
0 .4 1 r
.02381 .57045 m
.04262 .57043 L
.06244 .5704 L
.07286 .57038 L
.08255 .57036 L
.09388 .57033 L
.10458 .5703 L
.125 .57021 L
.14357 .5701 L
.16355 .56993 L
.18199 .56971 L
.20071 .5694 L
.21136 .56917 L
.22134 .56891 L
.24158 .56823 L
.26011 .56734 L
.27909 .56607 L
.28984 .56514 L
.29982 .5641 L
.32034 .56127 L
.33895 .55765 L
.35819 .55239 L
.36904 .54853 L
.37901 .54426 L
.39784 .53379 L
.40853 .52609 L
.4185 .51744 L
.43885 .49421 L
.45741 .4642 L
.4765 .42082 L
.48728 .38873 L
.49726 .35276 L
.51592 .26417 L
.52655 .19718 L
.53131 .16208 L
.53383 .14204 L
.53652 .1194 L
.53789 .10733 L
.53919 .09559 L
.54035 .09284 L
.54162 .09614 L
.54635 .1076 L
.55138 .11798 L
.55413 .12276 L
.5567 .1266 L
.5591 .12958 L
.56129 .13174 L
.56245 .13266 L
.56372 .13346 L
.56442 .13381 L
Mistroke
.56506 .13408 L
.56633 .13444 L
.5675 .13456 L
.56859 .13448 L
.56957 .13425 L
.57063 .13381 L
.57179 .1331 L
.57302 .13208 L
.57521 .1295 L
.57643 .1276 L
.57777 .12514 L
.58018 .11959 L
.58471 .10872 L
.59489 .0854 L
.60436 .06571 L
.61323 .04977 L
.61545 .04628 L
.61777 .04284 L
.61899 .04114 L
.61968 .57049 L
.62032 .57049 L
.62266 .57049 L
.63305 .57049 L
.65407 .57049 L
.69317 .57049 L
.73472 .57049 L
.77475 .57049 L
.81327 .57049 L
.85424 .57049 L
.89369 .57049 L
.93163 .57049 L
.97203 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo00Ooool00`1Vooooooooo`1_oooo002Toooo00<0
003oooooool01oooo`0306Kooooooooo06ooool00:Coool00`000?ooooooo`06oooo0P1Vog7oool0
0:Coool00`000?ooooooo`05oooo00<0I_ooool0I_l0LOooo`00Y?ooo`800005oooo00@0I_oooooo
ool0I_maoooo002Toooo00<0003oooooool01?ooo`0406Kooooooooo06KoLOooo`00Y?ooo`030000
oooooooo00?oool01@1Vooooooooooooo`1Vo`1aoooo002Toooo00<0003oooooool00oooo`0506Ko
oooooooooooo06Ko077oool00:Coool00`000?ooooooo`03oooo00D0I_ooooooooooool0I_l0LOoo
o`00Y?ooo`800003oooo00<0I_ooooooool00_ooo`0306Kooooooooo06ooool00:Coool00`000?oo
ooooo`02oooo00<0I_ooooooool00_ooo`0306Kooooooooo06ooool00:Coool01@000?oooooooooo
o`1Vo`05oooo00<0I_ooooooool0Koooo`00T?ooo`800004oooo0P0000Coool200001_ooo`050000
oooooooooooo06Ko00Goool00`1Vooooooooo`1_oooo002?oooo00@0003oooooool00008oooo00@0
003oooooool00005oooo00@0003oooooool0I_l6oooo00<0I_ooooooool0Koooo`00Soooo`040000
oooooooo00001_ooo`0306Kooooooooo00;oool00`000?ooooooo`03oooo0P000003oooo06Kooooo
00Goool00`1Vooooooooo`1_oooo0029oooo100000;oool010000?ooooooo`0000Koool206Ko00?o
ool0000000001_ooo`030000oooo06Ko00Ooool00`1Vooooooooo`1_oooo002?oooo00@0003ooooo
ool00006oooo0P1Vo`03oooo0000oooo00Koool00`000?ooo`1Vo`07oooo00<0I_ooooooool0Kooo
o`00T?ooo`800007oooo00<0I_ooool0I_l00`0000Goool00`00001Vooooo`07oooo00<0I_oooooo
ool0Koooo`00VOooo`0306Kooooo06Ko00Soool00`00001Vooooo`07oooo00<0I_ooooooool0Kooo
o`00VOooo`0306Kooooo06Ko00Soool200002?ooo`0306Kooooooooo06ooool009Soool01@1Voooo
ooooooooo`1Vo`07oooo00<0003oooooool01oooo`0306Kooooooooo06ooool009Soool01@1Voooo
ooooooooo`1Vo`07oooo00<0003oooooool01oooo`0306Kooooooooo06ooool009Soool00`1Voooo
ooooo`02oooo00<0I_ooooooool00oooo`0306Ko0000oooo00Soool00`1Vooooooooo`1_oooo002H
oooo00<0I_ooooooool00oooo`0306Kooooooooo00;oool00`1Vo`000?ooo`08oooo00<0I_oooooo
ool0Koooo`00V?ooo`0306Kooooooooo00Coool406Ko00?oool0000000002?ooo`0306Kooooooooo
06ooool009Soool00`1Vooooooooo`05oooo0P1Vo`;oool00`000?ooooooo`07oooo00<0I_oooooo
ool0Koooo`00V?ooo`0306Kooooooooo00Woool00`000?ooooooo`07oooo00<0I_ooooooool0Kooo
o`00V?ooo`0306Kooooooooo00Woool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00V?oo
o`0306Kooooooooo00Woool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00V?ooo`0306Ko
oooooooo00Woool200002?ooo`0306Kooooooooo06ooool009Ooool00`1Vooooooooo`0:oooo00<0
003oooooool01oooo`0306Kooooooooo06ooool009Ooool00`1Vooooooooo`0:oooo00<0003ooooo
ool01oooo`0306Kooooooooo06ooool009Ooool00`1Vooooooooo`0:oooo00<0003oooooool01ooo
o`0306Kooooooooo06ooool009Ooool00`1Vooooooooo`0:oooo00<0003oooooool01oooo`0306Ko
oooooooo06ooool009Ooool00`1Vooooooooo`0:oooo0P0000Soool00`1Vooooooooo`1_oooo002G
oooo00<0I_ooooooool02_ooo`030000oooooooo00Ooool00`1Vooooooooo`1_oooo002Goooo00<0
I_ooooooool02_ooo`030000oooooooo00Ooool00`1Vooooooooo`1_oooo002@oooo0P0000Coool2
00001Oooo`<00004oooo00<0003oooooool01oooo`0306Kooooooooo06ooool008ooool010000?oo
ooooo`0000?oool00`1Vooooooooo`05oooo00<0003oooooool00oooo`030000oooooooo00Ooool0
0`1Vooooooooo`1_oooo002?oooo00@0003oooooool00003oooo00<0I_ooooooool00_ooo`D00004
oooo0P0000Soool00`1Vooooooooo`1_oooo0029oooo100000;oool010000?ooooooo`0000?oool0
0`1Vooooooooo`02oooo00@0003oooooool00005oooo00<0003oooooool01oooo`0306Kooooooooo
06ooool008ooool010000?ooooooo`0000?oool00`1Vooooooooo`03oooo00<0003oool000001Ooo
o`030000oooooooo00Ooool00`1Vooooooooo`1_oooo002@oooo0P0000Coool00`1Vooooooooo`04
oooo0P0000Goool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00U_ooo`0306Kooooooooo
00_oool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00UOooo`0306Kooooooooo00coool2
00002?ooo`0306Kooooooooo06ooool009Goool00`1Vooooooooo`0<oooo00<0003oooooool01ooo
o`0306Kooooooooo06ooool009Goool00`1Vooooooooo`0<oooo00<0003oooooool01oooo`0306Ko
oooooooo06ooool009Goool00`1Vooooooooo`0<oooo00<0003oooooool01oooo`0306Kooooooooo
06ooool009Goool00`1Vooooooooo`0<oooo00<0003oooooool01oooo`0306Kooooooooo06ooool0
09Goool00`1Vooooooooo`0<oooo0P0000Soool00`1Vooooooooo`1_oooo002Doooo00<0I_oooooo
ool03Oooo`030000oooooooo00Ooool00`1Vooooooooo`1_oooo002Doooo00<0I_ooooooool03Ooo
o`030000oooooooo00Ooool00`1Vooooooooo`1_oooo002Doooo00<0I_ooooooool03Oooo`030000
oooooooo00Ooool00`1Vooooooooo`1_oooo002Doooo00<0I_ooooooool03Oooo`030000oooooooo
00Ooool00`1Vooooooooo`1_oooo002Doooo00<0I_ooooooool03Oooo`800008oooo00<0I_oooooo
ool0Koooo`00U?ooo`0306Kooooooooo00goool00`000?ooooooo`07oooo00<0I_ooooooool0Kooo
o`00Toooo`0306Kooooooooo00koool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00Tooo
o`0306Kooooooooo00koool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00Toooo`0306Ko
oooooooo00koool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00Toooo`0306Kooooooooo
00koool200002?ooo`0306Kooooooooo06ooool009?oool00`1Vooooooooo`0>oooo00<0003ooooo
ool01oooo`0306Kooooooooo06ooool009;oool00`1Vooooooooo`0?oooo00<0003oooooool01ooo
o`0306Kooooooooo06ooool0093oool2000000@0I_ooooooooooool200001?ooo`800006oooo00<0
003oooooool01oooo`0306Kooooooooo06ooool008ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00Soooo`040000oooooooo
00002_ooo`030000oooooooo00Coool200002?ooo`0306Kooooooooo06ooool008Woool400000_oo
o`040000oooooooo00002oooo`030000oooooooo00?oool00`000?ooooooo`07oooo00<0I_oooooo
ool0Koooo`00Soooo`040000oooo06Ko00002?ooo`040000oooooooo00001Oooo`030000oooooooo
00Ooool00`1Vooooooooo`1_oooo002@oooo0P0000[oool200001_ooo`030000oooooooo00Ooool0
0`1Vooooooooo`1_oooo002Aoooo00<0I_ooooooool04?ooo`030000oooooooo00Ooool00`1Voooo
ooooo`1_oooo002Aoooo00<0I_ooooooool04?ooo`800008oooo00<0I_ooooooool0Koooo`00T?oo
o`0306Kooooooooo017oool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00T?ooo`0306Ko
oooooooo017oool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00T?ooo`0306Kooooooooo
017oool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00T?ooo`0306Kooooooooo017oool0
0`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00T?ooo`0306Kooooooooo017oool200002?oo
o`0306Kooooooooo06ooool008ooool00`1Vooooooooo`0Boooo00<0003oooooool01oooo`0306Ko
oooooooo06ooool008ooool00`1Vooooooooo`0Boooo00<0003oooooool01oooo`0306Kooooooooo
06ooool008ooool00`1Vooooooooo`0Boooo00<0003oooooool01oooo`0306Kooooooooo06ooool0
08ooool00`1Vooooooooo`0Boooo00<0003oooooool01oooo`0306Kooooooooo06ooool008ooool0
0`1Vooooooooo`0Boooo0P0000Soool00`1Vooooooooo`1_oooo002>oooo00<0I_ooooooool04ooo
o`030000oooooooo00Ooool00`1Vooooooooo`1_oooo002>oooo00<0I_ooooooool04oooo`030000
oooooooo00Ooool00`1Vooooooooo`1_oooo002>oooo00<0I_ooooooool04oooo`030000oooooooo
00Ooool00`1Vooooooooo`1_oooo002>oooo00<0I_ooooooool04oooo`030000oooooooo00Ooool0
0`1Vooooooooo`1_oooo002>oooo00<0I_ooooooool04oooo`800008oooo00<0I_ooooooool0Kooo
o`00SOooo`0306Kooooooooo01Coool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00SOoo
o`0306Kooooooooo01Coool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00SOooo`0306Ko
oooooooo00800004oooo0P0000?oool400001Oooo`030000oooooooo00Ooool00`1Vooooooooo`1_
oooo002=oooo00<0I_ooool000000_ooo`030000oooooooo00Koool00`000?ooooooo`06oooo00<0
003oooooool01oooo`0306Kooooooooo06ooool008coool0101Vooooooooo`0000;oool00`000?oo
ooooo`07oooo00<0003oooooool01Oooo`800008oooo00<0I_ooooooool0Koooo`00ROooo`@00002
oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00Ooool00`1Voooo
ooooo`1_oooo002<oooo00@0I_ooooooool00002oooo00<0003oooooool01_ooo`040000oooooooo
00001Oooo`030000oooooooo00Ooool00`1Vooooooooo`1_oooo002<oooo00@0I_ooooooooooool2
00002_ooo`800006oooo00<0003oooooool01oooo`0306Kooooooooo06ooool008_oool00`1Voooo
ooooo`0Foooo00<0003oooooool01oooo`0306Kooooooooo06ooool008_oool00`1Vooooooooo`0F
oooo0P0000Soool00`1Vooooooooo`1_oooo002:oooo00<0I_ooooooool05oooo`030000oooooooo
00Ooool00`1Vooooooooo`1_oooo002:oooo00<0I_ooooooool05oooo`030000oooooooo00Ooool0
0`1Vooooooooo`1_oooo002:oooo00<0I_ooooooool05oooo`030000oooooooo00Ooool00`1Voooo
ooooo`1_oooo0029oooo00<0I_ooooooool06?ooo`030000oooooooo00Ooool00`1Vooooooooo`1_
oooo0029oooo00<0I_ooooooool06?ooo`800008oooo00<0I_ooooooool0Koooo`00ROooo`0306Ko
oooooooo01Soool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00R?ooo`0306Kooooooooo
01Woool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00R?ooo`0306Kooooooooo01Woool0
0`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00Qoooo`0306Kooooooooo01[oool00`000?oo
ooooo`07oooo00<0I_ooooooool0Koooo`00Qoooo`0306Kooooooooo01[oool200002?ooo`0306Ko
oooooooo06ooool008Koool00`1Vooooooooo`0Koooo00<0003oooooool01oooo`0306Kooooooooo
06ooool008Koool00`1Vooooooooo`0Koooo00<0003oooooool01oooo`0306Kooooooooo06ooool0
08Koool00`1Vooooooooo`0Koooo00<0003oooooool01oooo`0306Kooooooooo06ooool008Goool0
0`1Vooooooooo`0Loooo00<0003oooooool01oooo`0306Kooooooooo06ooool008Goool00`1Voooo
ooooo`0Loooo0P0000Soool00`1Vooooooooo`1_oooo0024oooo00<0I_ooooooool07Oooo`030000
oooooooo00Ooool00`1Vooooooooo`1_oooo0024oooo00<0I_ooooooool02Oooo`800004oooo0P00
00?oool500001?ooo`030000oooooooo00Ooool00`1Vooooooooo`1_oooo0023oooo00<0I_oooooo
ool02Oooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`07oooo00<0
I_ooooooool0Koooo`00Poooo`0306Kooooooooo00Woool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo0P0000Soool00`1Vooooooooo`1_oooo0022oooo00<0I_ooooooool01?ooo`@00002
oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo00Ooool00`1Voooo
ooooo`1_oooo0021oooo00<0I_ooooooool02oooo`040000oooooooo00002_ooo`030000oooooooo
00Coool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00P?ooo`0306Kooooooooo00goool2
00002_ooo`800006oooo00<0003oooooool01oooo`0306Kooooooooo06ooool0083oool00`1Voooo
ooooo`0Qoooo00<0003oooooool01oooo`0306Kooooooooo06ooool007ooool00`1Vooooooooo`0R
oooo0P0000Soool00`1Vooooooooo`1_oooo001noooo00<0I_ooooooool08oooo`030000oooooooo
00Ooool00`1Vooooooooo`1_oooo001moooo00<0I_ooooooool09?ooo`030000oooooooo00Ooool0
0`1Vooooooooo`1_oooo001loooo00<0I_ooooooool09Oooo`030000oooooooo00Ooool00`1Voooo
ooooo`1_oooo001loooo00<0I_ooooooool09Oooo`030000oooooooo00Ooool00`1Vooooooooo`1_
oooo001koooo00<0I_ooooooool09_ooo`800008oooo00<0I_ooooooool0Koooo`00N_ooo`0306Ko
oooooooo02Ooool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00NOooo`0306Kooooooooo
02Soool00`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00N?ooo`0306Kooooooooo02Woool0
0`000?ooooooo`07oooo00<0I_ooooooool0Koooo`00:Oooo`<0000Xoooo0`00023oool0101Voooo
ooooooooo`@0000Uoooo00<0003oooooool01oooo`0306Kooooooooo01[oool400009oooo`<0000W
oooo000Yoooo00@0003oooooool0000Xoooo00<0003oooooool07Oooo`80I_l4oooo00<0003ooooo
ool09_ooo`800008oooo00<0I_ooooooool06_ooo`030000oooooooo02Woool00`000?ooooooo`0V
oooo000Yoooo00@0003oooooool0000Uoooo1@0001coool206Ko1oooo`030000oooooooo02Goool0
0`000?ooooooo`07oooo00<0I_ooooooool06oooo`030000oooooooo02Goool500009oooo`008ooo
o`@00002oooo0`00023oool400000_ooo`040000oooooooo00006oooo`80I_l2oooo100000Coool0
0`000?ooooooo`0Toooo00<0003oooooool01oooo`0306Kooooooooo01coool00`000?ooooooo`0T
oooo00@0003oooooool0000Xoooo000Zoooo00<0003oooooool09_ooo`030000oooo000001Woool2
06Ko2_ooo`040000oooooooo00009Oooo`030000oooooooo00Ooool00`1Vooooooooo`0Joooo00@0
003oooooool0000Voooo00<0003oool00000:?ooo`00:_ooo`<0000Woooo0P0001Soool00`1Voooo
ooooo`0;oooo0P0002Koool00`000?ooooooo`07oooo00<0I_ooooooool06oooo`80000Xoooo0P00
02Soool006coool206Ko=_ooo`800008oooo00<0I_ooooooool0Koooo`00J?ooo`@0I_lhoooo00<0
003oooooool01oooo`0306Kooooooooo06ooool006?oool506Ko??ooo`030000oooooooo00Ooool0
0`1Vooooooooo`1_oooo001Noooo1@1Vod7oool00`000?ooooooo`07oooo00<0I_ooooooool0Kooo
o`00Coooo`l0I_m6oooo00<0003oooooool01oooo`0306Kooooooooo06ooool000gooooo00001P00
00koool001?oool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooo000000`00005<ol000<0000co`0co`0023?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`0023?o00030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool02?ooo`030000oooooooo00Ooool00`000?ooooooo`0Boooo000Xoooo00<0003oooooool09_oo
o`030000oooooooo027oool60000:C?o00030000oooooooo00Ooool00ol0VOooooooo`0Loooo00<0
003oooooool09_ooo`030000oooooooo02Ooool007[oool300009c?o00030000oooooooo00Ooool0
0ol0VOooooooo`1_oooo001moooo0P0002Dco`000`000?ooooooo`07oooo00?o09Woooooool0Kooo
o`00Ooooo`030000<ol0<ol0028co`0200002?ooo`03o`2Ioooooooo06ooool0083oool00`0003?o
03?o000Q<ol000<0003oooooool01oooo`03o`2Ioooooooo06ooool0087oool200008C?o00030000
oooooooo00Ooool00ol0VOooooooo`1_oooo0023oooo00<0000co`0co`007S?o00030000oooooooo
00Ooool00ol0VOooooooo`1_oooo0023oooo00<0000co`0co`007S?o00030000oooooooo00Ooool0
0ol0VOooooooo`1_oooo0024oooo00<0000co`0co`007C?o00800008oooo00?o09Woooooool0Kooo
o`00QOooo`030000<ol0<ol001`co`000`000?ooooooo`07oooo00?o09Woooooool0Koooo`00Q_oo
o`030000<ol0<ol001/co`000`000?ooooooo`07oooo00?o09Woooooool0Koooo`00Q_ooo`030000
<ol0<ol001/co`000`000?ooooooo`07oooo00?o09Woooooool0Koooo`00Qooooadco`1loooo0028
oooo73?o07coool008SooolL<ol0O?ooo`00R?oooa`co`1loooo0029oooo6c?o07coool007coool0
0`000?ooooooo`0:oooo63?o00030000<ol0<ol007coool007_oool00`000?ooooooo`08oooo00@0
003ooooooooooolH<ol000<0000co`3oool0Noooo`00Noooo`030000oooooooo00;oool200001?oo
o`040000oooooooooooo1C?o00D00002<ol00P0000@co`02000013?o00030000<ol0oooo07_oool0
07_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`040000oooooooooooo1S?o
00030000<ol0<ol000Lco`00100003?o03?o000000<co`000`0003?o0?ooo`1koooo001joooo00<0
003oooooool00_ooo`030000oooooooo00Woool6<ol000<0000co`0co`002S?o00030000<ol0<ol0
008co`000`000?ooooooo`1joooo001koooo00<0003oooooool01@0000Soool6<ol000<0000co`0c
o`0023?o00800004<ol000<0000co`3oool0Noooo`00Noooo`050000oooooooooooo000000coool5
<ol000<0000co`0co`0023?o00030000<ol0<ol000<co`000`0003?o0?ooo`1koooo001loooo00<0
003oooooool03Oooo`@co`0200002S?o00<00002<ol000<0000co`0co`00O?ooo`00S?oooaPco`1l
oooo002<oooo63?o07coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.26171 .57049 L
.30316 .57049 L
.34309 .57049 L
.3815 .57049 L
.42237 .57049 L
.46172 .57049 L
.49955 .57049 L
.53984 .57049 L
.57861 .57049 L
.59832 .57049 L
.61984 .57049 L
.6298 .57049 L
.64043 .57049 L
.64559 .57049 L
.65045 .57049 L
.65482 .57049 L
.65602 .57049 L
.65728 .57049 L
.65836 .57049 L
s
.65836 .57049 m
.65837 .61803 L
s
0 .4 1 r
.02381 .5704 m
.04262 .57036 L
.06244 .5703 L
.07286 .57026 L
.08255 .57022 L
.09388 .57016 L
.10458 .57009 L
.125 .56991 L
.14357 .56968 L
.16355 .56934 L
.18199 .56889 L
.20071 .56825 L
.21136 .56778 L
.22134 .56725 L
.24158 .56585 L
.26011 .56403 L
.27909 .56143 L
.28984 .55951 L
.29982 .55738 L
.32034 .55158 L
.33895 .54415 L
.35819 .53337 L
.36904 .52546 L
.37901 .51669 L
.39784 .49524 L
.40853 .47945 L
.4185 .46171 L
.43885 .41407 L
.45741 .35253 L
.4765 .26358 L
.48728 .19779 L
.49208 .16401 L
.4946 .14502 L
.49726 .12404 L
.49842 .11454 L
.49965 .10416 L
.50037 .10248 L
.50101 .1047 L
.50228 .109 L
.50688 .12427 L
.51592 .15231 L
.52664 .1818 L
.53652 .20471 L
.54584 .22172 L
.55054 .22826 L
.55319 .23126 L
.55571 .2336 L
.557 .23459 L
.55841 .23551 L
.55971 .23619 L
Mistroke
.56089 .23667 L
.56161 .23689 L
.56229 .23705 L
.563 .23717 L
.56377 .23723 L
.56445 .23723 L
.56517 .23717 L
.56645 .23692 L
.56765 .2365 L
.56893 .23584 L
.57014 .235 L
.57125 .23406 L
.57395 .23095 L
.5765 .22684 L
.58111 .21642 L
.58618 .20384 L
.59645 .17807 L
.61489 .1318 L
.6359 .0825 L
.6451 .06367 L
.64996 .05477 L
.65262 .05025 L
.65514 .04626 L
.65634 .04446 L
.65761 .04263 L
.65827 .0417 L
.65899 .57049 L
.66027 .57049 L
.66493 .57049 L
.67403 .57049 L
.69388 .57049 L
.73427 .57049 L
.77315 .57049 L
.81448 .57049 L
.85429 .57049 L
.89259 .57049 L
.93334 .57049 L
.97257 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo017oool00`1Vooooooooo`1Uoooo002Toooo00<0
003oooooool04Oooo`0306Kooooooooo06Goool00:Coool00`000?ooooooo`0@oooo0P1VofOoool0
0:Coool00`000?ooooooo`0@oooo0P1VofOoool00:Coool200004?ooo`0306Kooooo06Ko06Ooool0
0:Coool00`000?ooooooo`0>oooo00@0I_ooooooool0I_mWoooo002Toooo00<0003oooooool03_oo
o`0406Kooooooooo06KoIoooo`00Y?ooo`030000oooooooo00goool01@1Vooooooooooooo`1Vo`1W
oooo002Toooo00<0003oooooool03Oooo`0506Kooooooooooooo06Ko06Ooool00:Coool200003Ooo
o`0306Kooooooooo00;oool00`1Vooooooooo`1Uoooo002Toooo00<0003oooooool03?ooo`0306Ko
oooooooo00;oool00`1Vooooooooo`1Uoooo002Toooo00<0003oooooool02oooo`0306Kooooooooo
00?oool00`1Vooooooooo`1Uoooo002@oooo0P0000Coool200001?ooo`800006oooo00<0003ooooo
ool02oooo`0306Kooooooooo00?oool00`1Vooooooooo`1Uoooo002?oooo00@0003oooooool00008
oooo00@0003oooooool00005oooo00<0003oooooool02_ooo`0306Kooooooooo00Coool00`1Voooo
ooooo`1Uoooo002?oooo00@0003oooooool0000;oooo00<0003oooooool00oooo`80000;oooo00<0
I_ooooooool01?ooo`0306Kooooooooo06Goool008Woool400000_ooo`040000oooooooo00002Ooo
o`800006oooo00<0003oooooool02Oooo`0306Kooooooooo00Goool00`1Vooooooooo`1Uoooo002?
oooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo00Woool00`1Voooo
ooooo`05oooo00<0I_ooooooool0IOooo`00Soooo`0306Ko0000000000[oool300001Oooo`030000
oooooooo00Woool00`1Vooooooooo`05oooo00<0I_ooooooool0IOooo`00Soooo`80I_lCoooo00<0
003oooooool02?ooo`0306Kooooooooo00Koool00`1Vooooooooo`1Uoooo002?oooo0P1Voa?oool2
00002Oooo`0306Kooooooooo00Koool00`1Vooooooooo`1Uoooo002?oooo0P1Voa?oool00`000?oo
ooooo`08oooo00<0I_ooooooool01_ooo`0306Kooooooooo06Goool008koool0101Vooooooooo`1V
oa;oool00`000?ooooooo`07oooo00<0I_ooooooool01oooo`0306Kooooooooo06Goool008koool0
101Vooooooooo`1Voa;oool00`000?ooooooo`07oooo00<0I_ooooooool01oooo`0306Kooooooooo
06Goool008koool0101Vooooooooo`1Voa;oool00`000?ooooooo`06oooo00<0I_ooooooool02?oo
o`0306Kooooooooo06Goool008koool01@1Vooooooooooooo`1Vo`0Aoooo0P0000Ooool00`1Voooo
ooooo`08oooo00<0I_ooooooool0IOooo`00S_ooo`0506Kooooooooooooo06Ko017oool00`000?oo
ooooo`06oooo00<0I_ooooooool02?ooo`0306Kooooooooo06Goool008koool01@1Voooooooooooo
o`1Vo`0Aoooo00<0003oooooool01Oooo`0306Kooooooooo00Woool00`1Vooooooooo`1Uoooo002>
oooo00D0I_ooooooooooool0I_l04Oooo`030000oooooooo00Goool00`1Vooooooooo`09oooo00<0
I_ooooooool0IOooo`00S_ooo`0306Kooooooooo00;oool00`1Vooooooooo`0>oooo00<0003ooooo
ool01?ooo`0306Kooooooooo00[oool00`1Vooooooooo`1Uoooo002>oooo00<0I_ooooooool00_oo
o`0306Kooooooooo00koool200001Oooo`0306Kooooooooo00[oool00`1Vooooooooo`1Uoooo002=
oooo00<0I_ooooooool00oooo`0306Kooooooooo00koool00`000?ooooooo`03oooo00<0I_oooooo
ool02oooo`0306Kooooooooo06Goool008goool00`1Vooooooooo`04oooo00<0I_ooooooool03Ooo
o`030000oooooooo00?oool00`1Vooooooooo`0;oooo00<0I_ooooooool0IOooo`00SOooo`0306Ko
oooooooo00Coool00`1Vooooooooo`0=oooo00<0003oooooool00oooo`0306Kooooooooo00_oool0
0`1Vooooooooo`1Uoooo002=oooo00<0I_ooooooool01?ooo`0306Kooooooooo00goool00`000?oo
ooooo`02oooo00<0I_ooooooool03?ooo`0306Kooooooooo06Goool008goool00`1Vooooooooo`05
oooo00<0I_ooooooool03?ooo`800003oooo00<0I_ooooooool03?ooo`0306Kooooooooo06Goool0
08goool00`1Vooooooooo`05oooo00<0I_ooooooool03?ooo`050000oooooooooooo06Ko00ooool0
0`1Vooooooooo`1Uoooo002=oooo00<0I_ooooooool01_ooo`0306Kooooooooo00_oool01@000?oo
ooooooooo`1Vo`0?oooo00<0I_ooooooool0IOooo`00S?ooo`0406Kooooooooooooo0P0000Coool2
00001Oooo`<00004oooo00D0003oooooooooool0I_l03oooo`0306Kooooooooo06Goool008coool0
101Vooooooooo`0000;oool01@000?ooooooooooo`1Vo`07oooo00<0003oooooool00oooo`040000
oooooooo06Ko4?ooo`0306Kooooooooo06Goool008coool0101Vooooooooo`0000;oool00`000?oo
ooooo`02oooo00@0I_ooooooooooool500001?ooo`8000000oooo`1Vooooo`0?oooo00<0I_oooooo
ool0IOooo`00ROooo`@00002oooo00@0003oooooool00004oooo00D0I_ooooooooooool000000_oo
o`030000oooooooo00?oool00`000?ooo`1Vo`0Aoooo00<0I_ooooooool0IOooo`00S?ooo`0406Ko
oooooooo00000_ooo`030000oooooooo00;oool00`1Vooooooooo`02oooo00<0003oool000001Ooo
o`030000oooo06Ko017oool00`1Vooooooooo`1Uoooo002<oooo00@0I_ooooooooooool200001_oo
o`0306Kooooooooo00;oool200001Oooo`03000006Kooooo017oool00`1Vooooooooo`1Uoooo002<
oooo00<0I_ooooooool02Oooo`0306Kooooooooo00Woool00`00001Vooooo`0Aoooo00<0I_oooooo
ool0IOooo`00Roooo`0306Kooooooooo00_oool00`1Vooooooooo`08oooo0P0001;oool00`1Voooo
ooooo`1Uoooo002;oooo00<0I_ooooooool02oooo`0306Kooooooooo00Soool00`000?ooooooo`0A
oooo00<0I_ooooooool0IOooo`00Roooo`0306Kooooooooo00coool00`1Vooooooooo`07oooo00<0
003oooooool04Oooo`0306Kooooooooo06Goool008_oool00`1Vooooooooo`0=oooo00<0I_oooooo
ool01_ooo`030000oooooooo017oool00`1Vooooooooo`1Uoooo002;oooo00<0I_ooooooool03Ooo
o`0306Kooooooooo00Goool00`1Vo`000?ooo`0Boooo00<0I_ooooooool0IOooo`00Roooo`0306Ko
oooooooo00koool00`1Vooooooooo`04oooo00<0I_l0000000004_ooo`0306Kooooooooo06Goool0
08[oool00`1Vooooooooo`0@oooo00<0I_ooooooool00_ooo`0306Kooooo000001?oool00`1Voooo
ooooo`1Uoooo002:oooo00<0I_ooooooool04Oooo`D0I_l00oooo`000?ooo`0Boooo00<0I_oooooo
ool0IOooo`00R_ooo`0306Kooooooooo01Ooool00`000?ooooooo`0Aoooo00<0I_ooooooool0IOoo
o`00R_ooo`0306Kooooooooo01Ooool00`000?ooooooo`0Aoooo00<0I_ooooooool0IOooo`00R_oo
o`0306Kooooooooo01Ooool200004_ooo`0306Kooooooooo06Goool008[oool00`1Vooooooooo`0G
oooo00<0003oooooool04Oooo`0306Kooooooooo06Goool008Woool00`1Vooooooooo`0Hoooo00<0
003oooooool04Oooo`0306Kooooooooo06Goool008Woool00`1Vooooooooo`0Hoooo00<0003ooooo
ool04Oooo`0306Kooooooooo06Goool008Woool00`1Vooooooooo`0Hoooo00<0003oooooool04Ooo
o`0306Kooooooooo06Goool008Woool00`1Vooooooooo`0Hoooo0P0001;oool00`1Vooooooooo`1U
oooo0029oooo00<0I_ooooooool06?ooo`030000oooooooo017oool00`1Vooooooooo`1Uoooo0028
oooo00<0I_ooooooool06Oooo`030000oooooooo017oool00`1Vooooooooo`1Uoooo0028oooo00<0
I_ooooooool01Oooo`800004oooo0P0000Coool200001_ooo`030000oooooooo017oool00`1Voooo
ooooo`1Uoooo0028oooo00<0I_ooooooool01?ooo`040000oooooooo00002?ooo`040000oooooooo
00001Oooo`030000oooooooo017oool00`1Vooooooooo`1Uoooo0028oooo00<0I_ooooooool01?oo
o`040000oooooooo00002_ooo`030000oooooooo00Coool200004_ooo`0306Kooooooooo06Goool0
08Ooool00`1Vooooo`00000300000_ooo`040000oooooooo00002oooo`030000oooooooo00?oool0
0`000?ooooooo`0Aoooo00<0I_ooooooool0IOooo`00Qoooo`0306Kooooooooo00Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`0Aoooo00<0I_ooooooool0IOoo
o`00Qoooo`0306Kooooooooo00Koool200002_ooo`800006oooo00<0003oooooool04Oooo`0306Ko
oooooooo06Goool008Ooool00`1Vooooooooo`0Joooo00<0003oooooool04Oooo`0306Kooooooooo
06Goool008Ooool00`1Vooooooooo`0Joooo0P0001;oool00`1Vooooooooo`1Uoooo0026oooo00<0
I_ooooooool06oooo`030000oooooooo017oool00`1Vooooooooo`1Uoooo0026oooo00<0I_oooooo
ool06oooo`030000oooooooo017oool00`1Vooooooooo`1Uoooo0026oooo00<0I_ooooooool06ooo
o`030000oooooooo017oool00`1Vooooooooo`1Uoooo0026oooo00<0I_ooooooool06oooo`030000
oooooooo017oool00`1Vooooooooo`1Uoooo0026oooo00<0I_ooooooool06oooo`80000Boooo00<0
I_ooooooool0IOooo`00QOooo`0306Kooooooooo01coool00`000?ooooooo`0Aoooo00<0I_oooooo
ool0IOooo`00QOooo`0306Kooooooooo01coool00`000?ooooooo`0Aoooo00<0I_ooooooool0IOoo
o`00QOooo`0306Kooooooooo01coool00`000?ooooooo`0Aoooo00<0I_ooooooool0IOooo`00QOoo
o`0306Kooooooooo01coool00`000?ooooooo`0Aoooo00<0I_ooooooool0IOooo`00Q?ooo`0306Ko
oooooooo01goool200004_ooo`0306Kooooooooo06Goool008Coool00`1Vooooooooo`0Moooo00<0
003oooooool04Oooo`0306Kooooooooo06Goool008Coool00`1Vooooooooo`0Moooo00<0003ooooo
ool04Oooo`0306Kooooooooo06Goool008Coool00`1Vooooooooo`0Moooo00<0003oooooool04Ooo
o`0306Kooooooooo06Goool008?oool00`1Vooooooooo`0Noooo00<0003oooooool04Oooo`0306Ko
oooooooo06Goool008?oool00`1Vooooooooo`0Noooo0P0001;oool00`1Vooooooooo`1Uoooo0023
oooo00<0I_ooooooool07_ooo`030000oooooooo017oool00`1Vooooooooo`1Uoooo0023oooo00<0
I_ooooooool07_ooo`030000oooooooo017oool00`1Vooooooooo`1Uoooo0022oooo00<0I_oooooo
ool02oooo`800004oooo0P0000?oool400001Oooo`030000oooooooo017oool00`1Vooooooooo`1U
oooo0022oooo00<0I_ooooooool02_ooo`040000oooooooo00002?ooo`030000oooooooo00Koool0
0`000?ooooooo`0Aoooo00<0I_ooooooool0IOooo`00P_ooo`0306Kooooooooo00[oool010000?oo
ooooo`0000Woool00`000?ooooooo`05oooo0P0001;oool00`1Vooooooooo`1Uoooo0021oooo00<0
I_ooooooool01Oooo`@00002oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000
oooooooo017oool00`1Vooooooooo`1Uoooo0021oooo00<0I_ooooooool02oooo`040000oooooooo
00002?ooo`040000oooooooo00001Oooo`030000oooooooo017oool00`1Vooooooooo`1Uoooo0021
oooo00<0I_ooooooool03?ooo`80000:oooo0P0000Koool00`000?ooooooo`0Aoooo00<0I_oooooo
ool0IOooo`00P?ooo`0306Kooooooooo027oool00`000?ooooooo`0Aoooo00<0I_ooooooool0IOoo
o`00P?ooo`0306Kooooooooo027oool200004_ooo`0306Kooooooooo06Goool0083oool00`1Voooo
ooooo`0Qoooo00<0003oooooool04Oooo`0306Kooooooooo06Goool0083oool00`1Vooooooooo`0Q
oooo00<0003oooooool04Oooo`0306Kooooooooo06Goool007ooool00`1Vooooooooo`0Roooo00<0
003oooooool04Oooo`0306Kooooooooo06Goool007ooool00`1Vooooooooo`0Roooo00<0003ooooo
ool04Oooo`0306Kooooooooo06Goool007ooool00`1Vooooooooo`0Roooo0P0001;oool00`1Voooo
ooooo`1Uoooo001noooo00<0I_ooooooool08oooo`030000oooooooo017oool00`1Vooooooooo`1U
oooo001noooo00<0I_ooooooool08oooo`030000oooooooo017oool00`1Vooooooooo`1Uoooo001m
oooo00<0I_ooooooool09?ooo`030000oooooooo017oool00`1Vooooooooo`1Uoooo001moooo00<0
I_ooooooool09?ooo`030000oooooooo017oool00`1Vooooooooo`1Uoooo001loooo00<0I_oooooo
ool09Oooo`80000Boooo00<0I_ooooooool0IOooo`00O?ooo`0306Kooooooooo02Goool00`000?oo
ooooo`0Aoooo00<0I_ooooooool0IOooo`00O?ooo`0306Kooooooooo02Goool00`000?ooooooo`0A
oooo00<0I_ooooooool0IOooo`00Noooo`0306Kooooooooo02Koool00`000?ooooooo`0Aoooo00<0
I_ooooooool0IOooo`00Noooo`0306Kooooooooo02Koool00`000?ooooooo`0Aoooo00<0I_oooooo
ool0IOooo`00N_ooo`0306Kooooooooo02Ooool200004_ooo`0306Kooooooooo06Goool007[oool0
0`1Vooooooooo`0Woooo00<0003oooooool04Oooo`0306Kooooooooo06Goool007Woool00`1Voooo
ooooo`0Doooo0P0000Coool200000oooo`D00004oooo00<0003oooooool04Oooo`0306Kooooooooo
06Goool007Woool00`1Vooooooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool01?oo
o`030000oooooooo017oool00`1Vooooooooo`1Uoooo001hoooo00<0I_ooooooool05?ooo`040000
oooooooo00002_ooo`030000oooooooo00Coool200004_ooo`0306Kooooooooo06Goool007Soool0
0`1Vooooooooo`0>oooo100000;oool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0
003oooooool04Oooo`0306Kooooooooo06Goool007Ooool00`1Vooooooooo`0Eoooo00@0003ooooo
ool0000:oooo00<0003oooooool01?ooo`030000oooooooo017oool00`1Vooooooooo`1Uoooo001f
oooo00<0I_ooooooool05oooo`80000:oooo0P0000Koool00`000?ooooooo`0Aoooo00<0I_oooooo
ool0IOooo`00MOooo`0306Kooooooooo02coool00`000?ooooooo`0Aoooo00<0I_ooooooool0IOoo
o`00MOooo`0306Kooooooooo02coool200004_ooo`0306Kooooooooo06Goool007Coool00`1Voooo
ooooo`0]oooo00<0003oooooool04Oooo`0306Kooooooooo06Goool007?oool00`1Vooooooooo`0^
oooo00<0003oooooool04Oooo`0306Kooooooooo06Goool007;oool00`1Vooooooooo`0_oooo00<0
003oooooool04Oooo`0306Kooooooooo06Goool0077oool00`1Vooooooooo`0`oooo00<0003ooooo
ool04Oooo`0306Kooooooooo06Goool0073oool00`1Vooooooooo`0aoooo0P0001;oool00`1Voooo
ooooo`1Uoooo001_oooo00<0I_ooooooool0<_ooo`030000oooooooo017oool00`1Vooooooooo`1U
oooo001^oooo00<0I_ooooooool0<oooo`030000oooooooo017oool00`1Vooooooooo`1Uoooo001^
oooo00<0I_ooooooool0<oooo`030000oooooooo017oool00`1Vooooooooo`1Uoooo000Yoooo0`00
02Soool300005_ooo`0306Kooooooooo00_oool400009Oooo`030000oooooooo017oool00`1Voooo
ooooo`0@oooo100002Ooool300009oooo`00:Oooo`040000oooooooo0000:?ooo`030000oooooooo
01?oool206Ko3_ooo`030000oooooooo02Koool200004_ooo`0306Kooooooooo013oool00`000?oo
ooooo`0Yoooo00<0003oooooool09_ooo`00:Oooo`040000oooooooo00009Oooo`D0000Boooo0P1V
oa7oool00`000?ooooooo`0Uoooo00<0003oooooool04Oooo`0306Kooooooooo017oool00`000?oo
ooooo`0Uoooo1@0002Ooool002?oool400000_ooo`<0000Poooo100000;oool010000?ooooooo`00
017oool206Ko3?ooo`@00004oooo00<0003oooooool09?ooo`030000oooooooo017oool00`1Voooo
ooooo`0Boooo00<0003oooooool09?ooo`040000oooooooo0000:?ooo`00:_ooo`030000oooooooo
02Koool00`000?ooo`00000>oooo0`1VoaCoool010000?ooooooo`0002Goool00`000?ooooooo`0A
oooo00<0I_ooooooool04?ooo`040000oooooooo00009_ooo`030000oooo000002Soool002[oool3
00009oooo`80000<oooo0P1VoaSoool200009_ooo`030000oooooooo017oool00`1Vooooooooo`0A
oooo0P0002Soool20000:?ooo`00Goooo`<0I_m2oooo0P0001;oool00`1Vooooooooo`1Uoooo001M
oooo0P1VodGoool00`000?ooooooo`0Aoooo00<0I_ooooooool0IOooo`00Eoooo`H0I_m7oooo00<0
003oooooool04Oooo`0306Kooooooooo06Goool005?oool406KoCOooo`030000oooooooo017oool0
0`1Vooooooooo`1Uoooo0016oooo3@1Voe7oool00`000?ooooooo`0Aoooo00<0I_ooooooool0IOoo
o`003Oooool0000600003_ooo`004oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oool00000300000Dco`000`0003?o
03?o0008<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0008<ol000<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo01;oool002Soool0
0`000?ooooooo`0Voooo00<0003oooooool08Oooo`H0000Y<ol000<0003oooooool04Oooo`03o`2I
oooooooo01;oool00`000?ooooooo`0Voooo00<0003oooooool09oooo`00N_ooo`<0000W<ol000<0
003oooooool04Oooo`03o`2Ioooooooo06Goool007goool200009C?o00030000oooooooo017oool0
0ol0VOooooooo`1Uoooo001ooooo00<0000co`0co`008S?o0080000Boooo00?o09Woooooool0IOoo
o`00P?ooo`030000<ol0<ol0024co`000`000?ooooooo`0Aoooo00?o09Woooooool0IOooo`00POoo
o`80000Q<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Goool008?oool00`0003?o03?o000N
<ol000<0003oooooool04Oooo`03o`2Ioooooooo06Goool008?oool00`0003?o03?o000N<ol000<0
003oooooool04Oooo`03o`2Ioooooooo06Goool008Coool00`0003?o03?o000M<ol00P0001;oool0
0ol0VOooooooo`1Uoooo0025oooo00<0000co`0co`0073?o00030000oooooooo017oool00ol0VOoo
ooooo`1Uoooo0026oooo00<0000co`0co`006c?o00030000oooooooo017oool00ol0VOooooooo`1U
oooo0026oooo00<0000co`0co`006c?o00030000oooooooo017oool00ol0VOooooooo`1Uoooo0027
oooo7C?o07coool008SooolL<ol0O?ooo`00R?oooa`co`1loooo0028oooo73?o07coool008WooolK
<ol0O?ooo`00Ooooo`030000oooooooo00OooolE<ol000<0000co`0co`000c?o07coool007koool0
0`000?ooooooo`08oooo00<0000co`0co`004c?o00030000<ol0<ol0008co`1loooo001noooo00<0
003oooooool00_ooo`800004oooo00<0000co`0co`001S?o00@00003<ol00P0000@co`000`0003?o
03?o0002<ol0O?ooo`00O_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
000co`0co`001C?o00030000<ol0<ol000Xco`000`0003?o03?o0002<ol0O?ooo`00OOooo`030000
oooooooo00;oool00`000?ooooooo`06oooo23?o00030000<ol0<ol000Xco`00100003?o03?o03?o
07coool007koool00`000?ooooooo`0500001Oooo`Tco`000`0003?o03?o0008<ol000<0000co`0c
o`000S?o07coool007koool01@000?ooooooooooo`000009oooo1S?o00040000<ol0<ol000002C?o
00030000<ol0<ol0008co`1loooo001ooooo00<0003oooooool02_ooo`Lco`0200002C?o00030000
<ol0<ol000<co`1loooo002<oooo63?o07coool008cooolH<ol0O?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.26171 .57049 L
.30316 .57049 L
.34309 .57049 L
.3815 .57049 L
.42237 .57049 L
.46172 .57049 L
.49955 .57049 L
.53984 .57049 L
.57861 .57049 L
.61984 .57049 L
.65954 .57049 L
.67958 .57049 L
.6883 .57049 L
.69289 .57049 L
.6954 .57049 L
.69662 .57049 L
.69774 .57049 L
s
.69774 .57049 m
.69774 .61803 L
s
0 .4 1 r
.02381 .5703 m
.04262 .57022 L
.06244 .5701 L
.07286 .57003 L
.08255 .56994 L
.09388 .56981 L
.10458 .56967 L
.125 .56931 L
.14357 .56884 L
.16355 .56814 L
.18199 .56723 L
.20071 .56593 L
.21136 .56498 L
.22134 .5639 L
.24158 .56104 L
.26011 .55735 L
.27909 .55205 L
.28984 .54816 L
.29982 .54382 L
.32034 .53204 L
.33895 .51692 L
.35819 .49501 L
.36904 .47891 L
.37901 .46109 L
.39784 .41747 L
.40853 .38535 L
.4185 .34929 L
.43885 .2524 L
.44785 .19693 L
.45278 .1625 L
.45741 .12727 L
.45851 .11842 L
.45968 .10891 L
.46095 .10589 L
.46212 .11009 L
.46732 .12844 L
.4765 .15932 L
.49726 .2218 L
.51722 .271 L
.52593 .28862 L
.53536 .30467 L
.54061 .31204 L
.54545 .31772 L
.55008 .32204 L
.55264 .32392 L
.55497 .32528 L
.55616 .32584 L
.55746 .32634 L
.55817 .32657 L
.55883 .32674 L
Mistroke
.56013 .32699 L
.56135 .32711 L
.56246 .32712 L
.56375 .32699 L
.56495 .32675 L
.56559 .32656 L
.56629 .32632 L
.5677 .32568 L
.56901 .32491 L
.57023 .32402 L
.57298 .32139 L
.57593 .3175 L
.5785 .31306 L
.58123 .30743 L
.58612 .297 L
.59721 .27246 L
.61734 .22489 L
.65514 .13039 L
.67615 .08126 L
.68535 .06258 L
.69021 .05377 L
.69288 .04932 L
.6954 .04539 L
.69659 .04362 L
.69786 .04183 L
.69852 .57049 L
.69925 .57049 L
.70053 .57049 L
.70519 .57049 L
.71428 .57049 L
.73414 .57049 L
.77453 .57049 L
.8134 .57049 L
.85473 .57049 L
.89455 .57049 L
.93284 .57049 L
.97359 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo01coool00`1Vooooooooo`1Joooo002Toooo00<0
003oooooool06oooo`80I_mLoooo002Toooo00<0003oooooool06_ooo`0306Kooooo06Ko05coool0
0:Coool00`000?ooooooo`0Joooo00<0I_ooool0I_l0G?ooo`00Y?ooo`80000Koooo00<0I_ooool0
I_l0G?ooo`00Y?ooo`030000oooooooo01Woool0101Vooooooooo`1Voecoool00:Coool00`000?oo
ooooo`0Hoooo00D0I_ooooooooooool0I_l0G?ooo`00Y?ooo`030000oooooooo01Soool01@1Voooo
ooooooooo`1Vo`1Loooo002Toooo00<0003oooooool05oooo`0306Kooooooooo00;oool00`1Voooo
ooooo`1Joooo002Toooo0P0001Soool00`1Vooooooooo`02oooo00<0I_ooooooool0F_ooo`00Y?oo
o`030000oooooooo01Koool00`1Vooooooooo`03oooo00<0I_ooooooool0F_ooo`00Y?ooo`030000
oooooooo01Koool00`1Vooooooooo`03oooo00<0I_ooooooool0F_ooo`00T?ooo`800004oooo0P00
00Coool200001_ooo`030000oooooooo01Koool00`1Vooooooooo`03oooo00<0I_ooooooool0F_oo
o`00Soooo`040000oooooooo00002?ooo`040000oooooooo00001Oooo`030000oooooooo01Goool0
0`1Vooooooooo`04oooo00<0I_ooooooool0F_ooo`00Soooo`040000oooooooo00002oooo`030000
oooooooo00?oool200005_ooo`0306Kooooooooo00Coool00`1Vooooooooo`1Joooo0029oooo1000
00;oool010000?ooooooo`0000Woool200001_ooo`030000oooooooo01Coool00`1Vooooooooo`05
oooo00<0I_ooooooool0F_ooo`00Soooo`040000oooooooo00002Oooo`030000oooooooo00Goool0
0`000?ooooooo`0Doooo00<0I_ooooooool01Oooo`0306Kooooooooo05[oool008Goool00`1Voooo
ooooo`08oooo0P0000[oool300001Oooo`030000oooooooo01?oool00`1Vooooooooo`06oooo00<0
I_ooooooool0F_ooo`00Q?ooo`80I_lNoooo00<0003oooooool04oooo`0306Kooooooooo00Koool0
0`1Vooooooooo`1Joooo0024oooo0P1Voakoool200004oooo`0306Kooooooooo00Ooool00`1Voooo
ooooo`1Joooo0024oooo0P1Voakoool00`000?ooooooo`0Boooo00<0I_ooooooool01oooo`0306Ko
oooooooo05[oool008Coool00`1Vooooo`1Vo`0Moooo00<0003oooooool04Oooo`0306Kooooooooo
00Soool00`1Vooooooooo`1Joooo0024oooo00<0I_ooool0I_l07Oooo`030000oooooooo017oool0
0`1Vooooooooo`08oooo00<0I_ooooooool0F_ooo`00Q?ooo`0306Kooooo06Ko01goool00`000?oo
ooooo`0@oooo00<0I_ooooooool02Oooo`0306Kooooooooo05[oool008Coool00`1Vooooo`1Vo`0M
oooo0P00017oool00`1Vooooooooo`09oooo00<0I_ooooooool0F_ooo`00Q?ooo`0406Kooooooooo
06Ko7?ooo`030000oooooooo013oool00`1Vooooooooo`09oooo00<0I_ooooooool0F_ooo`00Q?oo
o`0406Kooooooooo06Ko7?ooo`030000oooooooo00ooool00`1Vooooooooo`0:oooo00<0I_oooooo
ool0F_ooo`00Q?ooo`0406Kooooooooo06Ko7?ooo`030000oooooooo00ooool00`1Vooooooooo`0:
oooo00<0I_ooooooool0F_ooo`00Poooo`0306Kooooooooo00;oool00`1Vooooooooo`0Ioooo00<0
003oooooool03_ooo`0306Kooooooooo00_oool00`1Vooooooooo`1Joooo0023oooo00<0I_oooooo
ool00_ooo`0306Kooooooooo01Woool200003oooo`0306Kooooooooo00_oool00`1Vooooooooo`1J
oooo0023oooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool00`000?ooooooo`0>oooo00<0
I_ooooooool02oooo`0306Kooooooooo05[oool008?oool00`1Vooooooooo`03oooo00<0I_oooooo
ool06?ooo`030000oooooooo00goool00`1Vooooooooo`0<oooo00<0I_ooooooool0F_ooo`00Pooo
o`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool03Oooo`0306Kooooooooo
00coool00`1Vooooooooo`1Joooo0023oooo00<0I_ooooooool01?ooo`0306Kooooooooo01Ooool0
0`000?ooooooo`0=oooo00<0I_ooooooool03?ooo`0306Kooooooooo05[oool008?oool00`1Voooo
ooooo`04oooo00<0I_ooooooool05oooo`80000=oooo00<0I_ooooooool03Oooo`0306Kooooooooo
05[oool008;oool00`1Vooooooooo`05oooo00<0I_ooooooool05oooo`030000oooooooo00coool0
0`1Vooooooooo`0=oooo00<0I_ooooooool0F_ooo`00P_ooo`0306Kooooooooo00Koool00`1Voooo
ooooo`0Foooo00<0003oooooool02oooo`0306Kooooooooo00koool00`1Vooooooooo`1Joooo0022
oooo00<0I_ooooooool01_ooo`0306Kooooooooo00;oool200001?ooo`800005oooo0`0000Coool0
0`000?ooooooo`0;oooo00<0I_ooooooool03_ooo`0306Kooooooooo05[oool008;oool00`1Voooo
ooooo`06oooo00D0I_ooooooooooool000000_ooo`030000oooooooo00Woool00`000?ooooooo`03
oooo00<0003oooooool02oooo`0306Kooooooooo00koool00`1Vooooooooo`1Joooo0021oooo00<0
I_ooooooool01oooo`0506Kooooooooooooo000000;oool00`000?ooooooo`06oooo1@0000Coool2
00002oooo`0306Kooooooooo00ooool00`1Vooooooooo`1Joooo0021oooo00<0I_ooooooool01Ooo
o`@00002oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool02_oo
o`0306Kooooooooo00ooool00`1Vooooooooo`1Joooo0021oooo00<0I_ooooooool02?ooo`0406Ko
oooooooo00000_ooo`030000oooooooo00Ooool00`000?ooo`000005oooo00<0003oooooool02_oo
o`0306Kooooooooo00ooool00`1Vooooooooo`1Joooo0021oooo00<0I_ooooooool02?ooo`0406Ko
oooooooooooo0P0000_oool200001Oooo`030000oooooooo00Woool00`1Vooooooooo`0@oooo00<0
I_ooooooool0F_ooo`00POooo`0306Kooooooooo00Woool00`1Vooooooooo`0Doooo00<0003ooooo
ool02Oooo`0306Kooooooooo013oool00`1Vooooooooo`1Joooo0021oooo00<0I_ooooooool02Ooo
o`0306Kooooooooo01Coool200002Oooo`0306Kooooooooo017oool00`1Vooooooooo`1Joooo0020
oooo00<0I_ooooooool02_ooo`0306Kooooooooo01Coool00`000?ooooooo`08oooo00<0I_oooooo
ool04Oooo`0306Kooooooooo05[oool0083oool00`1Vooooooooo`0;oooo00<0I_ooooooool04ooo
o`030000oooooooo00Soool00`1Vooooooooo`0Aoooo00<0I_ooooooool0F_ooo`00P?ooo`0306Ko
oooooooo00_oool00`1Vooooooooo`0Coooo00<0003oooooool01oooo`0306Kooooooooo01;oool0
0`1Vooooooooo`1Joooo0020oooo00<0I_ooooooool02oooo`0306Kooooooooo01?oool00`000?oo
ooooo`07oooo00<0I_ooooooool04_ooo`0306Kooooooooo05[oool0083oool00`1Vooooooooo`0<
oooo00<0I_ooooooool04_ooo`800008oooo00<0I_ooooooool04_ooo`0306Kooooooooo05[oool0
083oool00`1Vooooooooo`0<oooo00<0I_ooooooool04_ooo`030000oooooooo00Koool00`1Voooo
ooooo`0Coooo00<0I_ooooooool0F_ooo`00P?ooo`0306Kooooooooo00goool00`1Vooooooooo`0A
oooo00<0003oooooool01_ooo`0306Kooooooooo01?oool00`1Vooooooooo`1Joooo001ooooo00<0
I_ooooooool03_ooo`0306Kooooooooo017oool00`000?ooooooo`05oooo00<0I_ooooooool05?oo
o`0306Kooooooooo05[oool007ooool00`1Vooooooooo`0>oooo00<0I_ooooooool04Oooo`030000
oooooooo00Goool00`1Vooooooooo`0Doooo00<0I_ooooooool0F_ooo`00Ooooo`0306Kooooooooo
00ooool00`1Vooooooooo`0@oooo0P0000Goool00`1Vooooooooo`0Eoooo00<0I_ooooooool0F_oo
o`00Ooooo`0306Kooooooooo00ooool00`1Vooooooooo`0@oooo00<0003oooooool01?ooo`0306Ko
oooooooo01Goool00`1Vooooooooo`1Joooo001ooooo00<0I_ooooooool03oooo`0306Kooooooooo
013oool00`000?ooooooo`03oooo00<0I_ooooooool05_ooo`0306Kooooooooo05[oool007ooool0
0`1Vooooooooo`0@oooo00<0I_ooooooool03oooo`030000oooooooo00?oool00`1Vooooooooo`0F
oooo00<0I_ooooooool0F_ooo`00O_ooo`0306Kooooooooo017oool00`1Vooooooooo`0?oooo00<0
003oooooool00_ooo`0306Kooooooooo01Ooool00`1Vooooooooo`1Joooo001noooo00<0I_oooooo
ool04_ooo`0306Kooooooooo00koool200000oooo`0306Kooooooooo01Ooool00`1Vooooooooo`1J
oooo001noooo00<0I_ooooooool04_ooo`0306Kooooooooo00koool01@000?ooooooooooo`1Vo`0J
oooo00<0I_ooooooool0F_ooo`00O_ooo`0306Kooooooooo01?oool00`1Vooooooooo`0=oooo00D0
003oooooooooool0I_l06_ooo`0306Kooooooooo05[oool007koool00`1Vooooooooo`0?oooo0P00
00;oool0101Vooooo`00000000Coool200001_ooo`040000oooooooo06Ko6oooo`0306Kooooooooo
05[oool007goool00`1Vooooooooo`0?oooo00@0003oooooool00002oooo00<0I_ooooooool00ooo
o`040000oooooooo00001Oooo`040000oooooooo06Ko6oooo`0306Kooooooooo05[oool007goool0
0`1Vooooooooo`0?oooo00@0003oooooool00002oooo00<0I_ooooooool01Oooo`030000oooooooo
00Coool2000000<0I_ooooooool06_ooo`0306Kooooooooo05[oool007goool00`1Vooooooooo`09
oooo100000;oool010000?ooooooo`0000?oool00`1Vooooooooo`05oooo00<0003oooooool00ooo
o`030000oooo06Ko01coool00`1Vooooooooo`1Joooo001moooo00<0I_ooooooool03oooo`040000
oooooooo00000oooo`0306Kooooooooo00;oool010000?ooooooo`0000Goool00`00001Vooooo`0L
oooo00<0I_ooooooool0F_ooo`00OOooo`0306Kooooooooo013oool200001Oooo`0306Kooooooooo
00;oool200001_ooo`03000006Kooooo01coool00`1Vooooooooo`1Joooo001loooo00<0I_oooooo
ool06?ooo`0306Kooooooooo00[oool00`00001Vooooo`0Loooo00<0I_ooooooool0F_ooo`00O?oo
o`0306Kooooooooo01Woool00`1Vooooooooo`09oooo0P0001goool00`1Vooooooooo`1Joooo001l
oooo00<0I_ooooooool06_ooo`0306Kooooooooo00Soool00`000?ooooooo`0Loooo00<0I_oooooo
ool0F_ooo`00O?ooo`0306Kooooooooo01_oool00`1Vooooooooo`06oooo00<0I_l0003oool07Ooo
o`0306Kooooooooo05[oool007coool00`1Vooooooooo`0Loooo00<0I_ooooooool01Oooo`0306Ko
0000oooo01goool00`1Vooooooooo`1Joooo001loooo00<0I_ooooooool07?ooo`0306Kooooooooo
00Coool00`1Vooooo`00000Noooo00<0I_ooooooool0F_ooo`00Noooo`0306Kooooooooo01koool2
06Ko0oooo`0306Kooooooooo0080000Moooo00<0I_ooooooool0F_ooo`00Noooo`0306Kooooooooo
023oool306Ko0oooo`030000oooooooo01coool00`1Vooooooooo`1Joooo001koooo00<0I_oooooo
ool09_ooo`030000oooooooo01coool00`1Vooooooooo`1Joooo001koooo00<0I_ooooooool09_oo
o`030000oooooooo01coool00`1Vooooooooo`1Joooo001koooo00<0I_ooooooool09_ooo`030000
oooooooo01coool00`1Vooooooooo`1Joooo001joooo00<0I_ooooooool09oooo`80000Moooo00<0
I_ooooooool0F_ooo`00N_ooo`0306Kooooooooo02Ooool00`000?ooooooo`0Loooo00<0I_oooooo
ool0F_ooo`00N_ooo`0306Kooooooooo02Ooool00`000?ooooooo`0Loooo00<0I_ooooooool0F_oo
o`00N_ooo`0306Kooooooooo02Ooool00`000?ooooooo`0Loooo00<0I_ooooooool0F_ooo`00NOoo
o`0306Kooooooooo02Soool00`000?ooooooo`0Loooo00<0I_ooooooool0F_ooo`00NOooo`0306Ko
oooooooo02Soool200007Oooo`0306Kooooooooo05[oool007Woool00`1Vooooooooo`0Xoooo00<0
003oooooool07?ooo`0306Kooooooooo05[oool007Soool00`1Vooooooooo`0Yoooo00<0003ooooo
ool07?ooo`0306Kooooooooo05[oool007Soool00`1Vooooooooo`0Eoooo0P0000Coool200000ooo
o`@00005oooo00<0003oooooool07?ooo`0306Kooooooooo05[oool007Soool00`1Vooooooooo`0D
oooo00@0003oooooool00008oooo00<0003oooooool01_ooo`030000oooooooo01coool00`1Voooo
ooooo`1Joooo001goooo00<0I_ooooooool05Oooo`040000oooooooo00002Oooo`030000oooooooo
00Goool200007Oooo`0306Kooooooooo05[oool007Ooool00`1Vooooooooo`0?oooo100000;oool0
10000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool07?ooo`0306Kooooooooo
05[oool007Ooool00`1Vooooooooo`0Eoooo00@0003oooooool00008oooo00@0003oooooool00005
oooo00<0003oooooool07?ooo`0306Kooooooooo05[oool007Koool00`1Vooooooooo`0Goooo0P00
00[oool200001_ooo`030000oooooooo01coool00`1Vooooooooo`1Joooo001foooo00<0I_oooooo
ool0:oooo`030000oooooooo01coool00`1Vooooooooo`1Joooo001eoooo00<0I_ooooooool0;?oo
o`80000Moooo00<0I_ooooooool0F_ooo`00MOooo`0306Kooooooooo02coool00`000?ooooooo`0L
oooo00<0I_ooooooool0F_ooo`00MOooo`0306Kooooooooo02coool00`000?ooooooo`0Loooo00<0
I_ooooooool0F_ooo`00M?ooo`0306Kooooooooo02goool00`000?ooooooo`0Loooo00<0I_oooooo
ool0F_ooo`00M?ooo`0306Kooooooooo02goool00`000?ooooooo`0Loooo00<0I_ooooooool0F_oo
o`00M?ooo`0306Kooooooooo02goool200007Oooo`0306Kooooooooo05[oool007?oool00`1Voooo
ooooo`0^oooo00<0003oooooool07?ooo`0306Kooooooooo05[oool007?oool00`1Vooooooooo`0^
oooo00<0003oooooool07?ooo`0306Kooooooooo05[oool007;oool00`1Vooooooooo`0_oooo00<0
003oooooool07?ooo`0306Kooooooooo05[oool007;oool00`1Vooooooooo`0_oooo00<0003ooooo
ool07?ooo`0306Kooooooooo05[oool0077oool00`1Vooooooooo`0`oooo0P0001goool00`1Voooo
ooooo`1Joooo001aoooo00<0I_ooooooool0<?ooo`030000oooooooo01coool00`1Vooooooooo`1J
oooo001aoooo00<0I_ooooooool0<?ooo`030000oooooooo01coool00`1Vooooooooo`1Joooo001`
oooo00<0I_ooooooool0<Oooo`030000oooooooo01coool00`1Vooooooooo`1Joooo001`oooo00<0
I_ooooooool0<Oooo`030000oooooooo01coool00`1Vooooooooo`1Joooo001_oooo00<0I_oooooo
ool0<_ooo`80000Moooo00<0I_ooooooool0F_ooo`00Koooo`0306Kooooooooo03;oool00`000?oo
ooooo`0Loooo00<0I_ooooooool0F_ooo`00K_ooo`0306Kooooooooo01ooool200001?ooo`800003
oooo1@0000Coool00`000?ooooooo`0Loooo00<0I_ooooooool0F_ooo`00K_ooo`0306Kooooooooo
01koool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool07?ooo`0306Ko
oooooooo05[oool006goool00`1Vooooooooo`0Ooooo00@0003oooooool0000:oooo00<0003ooooo
ool01?ooo`80000Moooo00<0I_ooooooool0F_ooo`00KOooo`0306Kooooooooo01Woool400000_oo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`0Loooo00<0I_oooooo
ool0F_ooo`00K?ooo`0306Kooooooooo023oool010000?ooooooo`0000[oool00`000?ooooooo`04
oooo00<0003oooooool07?ooo`0306Kooooooooo05[oool006coool00`1Vooooooooo`0Qoooo0P00
00[oool200001_ooo`030000oooooooo01coool00`1Vooooooooo`1Joooo001[oooo00<0I_oooooo
ool0=_ooo`030000oooooooo01coool00`1Vooooooooo`1Joooo001[oooo00<0I_ooooooool0=_oo
o`80000Moooo00<0I_ooooooool0F_ooo`00J_ooo`0306Kooooooooo03Ooool00`000?ooooooo`0L
oooo00<0I_ooooooool0F_ooo`00JOooo`0306Kooooooooo03Soool00`000?ooooooo`0Loooo00<0
I_ooooooool0F_ooo`00J?ooo`0306Kooooooooo03Woool00`000?ooooooo`0Loooo00<0I_oooooo
ool0F_ooo`00Ioooo`0306Kooooooooo03[oool00`000?ooooooo`0Loooo00<0I_ooooooool0F_oo
o`00I_ooo`0306Kooooooooo03_oool200007Oooo`0306Kooooooooo05[oool006Goool00`1Voooo
ooooo`0loooo00<0003oooooool07?ooo`0306Kooooooooo05[oool006Coool00`1Vooooooooo`0m
oooo00<0003oooooool07?ooo`0306Kooooooooo05[oool006;oool206Ko@?ooo`030000oooooooo
01coool00`1Vooooooooo`1Joooo000Yoooo0`0002Soool300002_ooo`0306Kooooooooo01Ooool4
00009Oooo`030000oooooooo01coool00`1Vooooooooo`05oooo100002Ooool300009oooo`00:Ooo
o`040000oooooooo0000:?ooo`030000oooooooo00Soool00`1Vooooooooo`0Hoooo00<0003ooooo
ool09_ooo`80000Moooo00<0I_ooooooool01Oooo`030000oooooooo02Woool00`000?ooooooo`0V
oooo000Yoooo00@0003oooooool0000Uoooo1@0000Ooool206Ko7?ooo`030000oooooooo02Goool0
0`000?ooooooo`0Loooo00<0I_ooooooool01_ooo`030000oooooooo02Goool500009oooo`008ooo
o`@00002oooo0`00023oool400000_ooo`040000oooooooo00001_ooo`80I_lGoooo100000Coool0
0`000?ooooooo`0Toooo00<0003oooooool07?ooo`0306Kooooooooo00Ooool00`000?ooooooo`0T
oooo00@0003oooooool0000Xoooo000Zoooo00<0003oooooool09_ooo`030000oooo000000Coool2
06Ko7oooo`040000oooooooo00009Oooo`030000oooooooo01coool00`1Vooooooooo`05oooo00@0
003oooooool0000Voooo00<0003oool00000:?ooo`00:_ooo`<0000Woooo0P000004oooo06Ko06Ko
06Ko8_ooo`80000Voooo00<0003oooooool07?ooo`0306Kooooooooo00Koool20000:?ooo`80000X
oooo001Doooo0`1Vodgoool200007Oooo`0306Kooooooooo05[oool005;oool206KoD?ooo`030000
oooooooo01coool00`1Vooooooooo`1Joooo001?oooo0`1Voe;oool00`000?ooooooo`0Loooo00<0
I_ooooooool0F_ooo`00B_ooo`D0I_mEoooo00<0003oooooool07?ooo`0306Kooooooooo05[oool0
03[oool@06KoF_ooo`030000oooooooo01coool00`1Vooooooooo`1Joooo000=ooooo`0000H0000>
oooo000Coooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooo`00000<00001C?o00030000<ol0<ol000Pco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Pco`000`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool04_ooo`00:?ooo`030000oooooooo02Koool0
0`000?ooooooo`0Qoooo1P0002Tco`000`000?ooooooo`0Loooo00?o09Woooooool01oooo`030000
oooooooo02Koool00`000?ooooooo`0Woooo001joooo0`0002Lco`000`000?ooooooo`0Loooo00?o
09Woooooool0F_ooo`00OOooo`80000U<ol000<0003oooooool07?ooo`03o`2Ioooooooo05[oool0
07ooool00`0003?o03?o000R<ol00P0001goool00ol0VOooooooo`1Joooo0020oooo00<0000co`0c
o`008C?o00030000oooooooo01coool00ol0VOooooooo`1Joooo0021oooo0P00024co`000`000?oo
ooooo`0Loooo00?o09Woooooool0F_ooo`00Poooo`030000<ol0<ol001hco`000`000?ooooooo`0L
oooo00?o09Woooooool0F_ooo`00Poooo`030000<ol0<ol001hco`000`000?ooooooo`0Loooo00?o
09Woooooool0F_ooo`00Q?ooo`030000<ol0<ol001dco`0200007Oooo`03o`2Ioooooooo05[oool0
08Goool00`0003?o03?o000L<ol000<0003oooooool07?ooo`03o`2Ioooooooo05[oool008Koool0
0`0003?o03?o000K<ol000<0003oooooool07?ooo`03o`2Ioooooooo05[oool008Koool00`0003?o
03?o000K<ol000<0003oooooool07?ooo`03o`2Ioooooooo05[oool008OooolM<ol0O?ooo`00R?oo
oa`co`1loooo0028oooo73?o07coool008SooolL<ol0O?ooo`00ROoooa/co`1loooo001loooo00<0
003oooooool02_oooaPco`000`0003?o03?o001loooo001koooo00<0003oooooool02?ooo`040000
oooooooooooo63?o00030000<ol0oooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool0
10000?ooooooooooo`Dco`0400000c?o00800004<ol00P0000@co`000`0003?o0?ooo`1koooo001k
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool010000?ooooooooooo`@co`00
0`0003?o03?o0009<ol000@0000co`0co`000003<ol000<0000co`3oool0Noooo`00N_ooo`030000
oooooooo00;oool00`000?ooooooo`09oooo1C?o00030000<ol0<ol000/co`000`0003?o03?o0002
<ol000<0003oooooool0N_ooo`00Noooo`030000oooooooo00D00008oooo1S?o00030000<ol0<ol0
00Pco`02000013?o00030000<ol0oooo07_oool007_oool01@000?ooooooooooo`00000<oooo0c?o
00040000<ol0<ol000002C?o00030000<ol0<ol000<co`000`0003?o0?ooo`1koooo001loooo00<0
003oooooool03Oooo`@co`0200002S?o00<00002<ol000<0000co`0co`00O?ooo`00S?oooaPco`1l
oooo002<oooo63?o07coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.26171 .57049 L
.30316 .57049 L
.34309 .57049 L
.3815 .57049 L
.42237 .57049 L
.46172 .57049 L
.49955 .57049 L
.53984 .57049 L
.57861 .57049 L
.61984 .57049 L
.65954 .57049 L
.69774 .57049 L
.71741 .57049 L
.72307 .57049 L
.72841 .57049 L
.7332 .57049 L
.73451 .57049 L
.7359 .57049 L
.73708 .57049 L
s
.73708 .57049 m
.73709 .61803 L
s
0 .4 1 r
.02381 .5701 m
.04262 .56994 L
.06244 .5697 L
.07286 .56954 L
.08255 .56937 L
.09388 .56911 L
.10458 .56882 L
.125 .56809 L
.14357 .56715 L
.16355 .56572 L
.18199 .56386 L
.20071 .56124 L
.21136 .5593 L
.22134 .55712 L
.24158 .55131 L
.26011 .54381 L
.27909 .53307 L
.28984 .52518 L
.29982 .51636 L
.32034 .49246 L
.33895 .46178 L
.35819 .4173 L
.36904 .38464 L
.37901 .34847 L
.39784 .25994 L
.40853 .19476 L
.41371 .15837 L
.4185 .12158 L
.41975 .11144 L
.42093 .10524 L
.42215 .10971 L
.42351 .1146 L
.42895 .13395 L
.43885 .16758 L
.45741 .22513 L
.4961 .32128 L
.51614 .35792 L
.52634 .37277 L
.53195 .37971 L
.53724 .3854 L
.5422 .38991 L
.54758 .3938 L
.54996 .39515 L
.55247 .39632 L
.55462 .3971 L
.55584 .39744 L
.55698 .39769 L
.55811 .39787 L
.55935 .39799 L
.56052 .39803 L
Mistroke
.56161 .398 L
.56268 .39789 L
.56365 .39773 L
.56478 .39747 L
.56583 .39715 L
.56822 .39614 L
.57041 .39483 L
.57281 .39292 L
.57535 .39033 L
.58032 .38323 L
.58485 .37572 L
.59502 .35799 L
.61337 .32295 L
.65327 .23401 L
.69165 .13825 L
.71107 .09177 L
.72138 .06971 L
.72679 .05929 L
.73248 .04945 L
.73493 .04561 L
.73628 .04362 L
.73755 .04182 L
.73827 .57049 L
.73905 .57049 L
.74041 .57049 L
.74308 .57049 L
.75278 .57049 L
.7718 .57049 L
.81277 .57049 L
.85223 .57049 L
.89017 .57049 L
.93056 .57049 L
.96944 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo02Koool00`1Vooooooooo`1@oooo002Toooo00<0
003oooooool09Oooo`80I_mBoooo002Toooo00<0003oooooool09Oooo`80I_mBoooo002Toooo00<0
003oooooool09?ooo`0306Kooooo06Ko05;oool00:Coool200009Oooo`0306Kooooo06Ko05;oool0
0:Coool00`000?ooooooo`0Soooo00@0I_ooooooool0I_mBoooo002Toooo00<0003oooooool08ooo
o`0406Kooooooooo06KoD_ooo`00Y?ooo`030000oooooooo02;oool01@1Vooooooooooooo`1Vo`1B
oooo002Toooo00<0003oooooool08_ooo`0506Kooooooooooooo06Ko05;oool00:Coool200008_oo
o`0306Kooooooooo00;oool00`1Vooooooooo`1@oooo002Toooo00<0003oooooool08Oooo`0306Ko
oooooooo00;oool00`1Vooooooooo`1@oooo002Toooo00<0003oooooool08?ooo`0306Kooooooooo
00?oool00`1Vooooooooo`1@oooo002@oooo0P0000Coool200001?ooo`800006oooo00<0003ooooo
ool08?ooo`0306Kooooooooo00?oool00`1Vooooooooo`1@oooo002?oooo00@0003oooooool00008
oooo00@0003oooooool00005oooo00<0003oooooool07oooo`0306Kooooooooo00Coool00`1Voooo
ooooo`1@oooo002?oooo00@0003oooooool0000;oooo00<0003oooooool00oooo`80000Poooo00<0
I_ooooooool01?ooo`0306Kooooooooo053oool008Woool400000_ooo`040000oooooooo00002Ooo
o`800006oooo00<0003oooooool07_ooo`0306Kooooooooo00Goool00`1Vooooooooo`1@oooo002?
oooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000oooooooo01koool00`1Voooo
ooooo`05oooo00<0I_ooooooool0D?ooo`00N_ooo`0306Kooooooooo01?oool200002_ooo`<00005
oooo00<0003oooooool07Oooo`0306Kooooooooo00Koool00`1Vooooooooo`1@oooo001joooo0P1V
obSoool00`000?ooooooo`0Moooo00<0I_ooooooool01_ooo`0306Kooooooooo053oool007[oool2
06Ko:?ooo`80000Noooo00<0I_ooooooool01_ooo`0306Kooooooooo053oool007[oool206Ko:?oo
o`030000oooooooo01coool00`1Vooooooooo`07oooo00<0I_ooooooool0D?ooo`00N_ooo`80I_lX
oooo00<0003oooooool07?ooo`0306Kooooooooo00Ooool00`1Vooooooooo`1@oooo001joooo00<0
I_ooool0I_l09oooo`030000oooooooo01coool00`1Vooooooooo`07oooo00<0I_ooooooool0D?oo
o`00N_ooo`0306Kooooo06Ko02Ooool00`000?ooooooo`0Koooo00<0I_ooooooool02?ooo`0306Ko
oooooooo053oool007Woool0101Vooooooooo`1VobOoool200007?ooo`0306Kooooooooo00Soool0
0`1Vooooooooo`1@oooo001ioooo00@0I_ooooooool0I_lWoooo00<0003oooooool06_ooo`0306Ko
oooooooo00Woool00`1Vooooooooo`1@oooo001ioooo00D0I_ooooooooooool0I_l09_ooo`030000
oooooooo01[oool00`1Vooooooooo`09oooo00<0I_ooooooool0D?ooo`00NOooo`0506Kooooooooo
oooo06Ko02Koool00`000?ooooooo`0Joooo00<0I_ooooooool02Oooo`0306Kooooooooo053oool0
07Woool01@1Vooooooooooooo`1Vo`0Voooo00<0003oooooool06Oooo`0306Kooooooooo00[oool0
0`1Vooooooooo`1@oooo001hoooo00<0I_ooooooool00oooo`0306Kooooooooo02?oool200006_oo
o`0306Kooooooooo00[oool00`1Vooooooooo`1@oooo001hoooo00<0I_ooooooool00oooo`0306Ko
oooooooo02?oool00`000?ooooooo`0Hoooo00<0I_ooooooool02oooo`0306Kooooooooo053oool0
07Soool00`1Vooooooooo`03oooo00<0I_ooooooool08oooo`030000oooooooo01Soool00`1Voooo
ooooo`0;oooo00<0I_ooooooool0D?ooo`00N?ooo`0306Kooooooooo00Coool00`1Vooooooooo`0R
oooo00<0003oooooool06?ooo`0306Kooooooooo00_oool00`1Vooooooooo`1@oooo001hoooo00<0
I_ooooooool01?ooo`0306Kooooooooo02;oool00`000?ooooooo`0Goooo00<0I_ooooooool03?oo
o`0306Kooooooooo053oool007Soool00`1Vooooooooo`04oooo00<0I_ooooooool08_ooo`80000H
oooo00<0I_ooooooool03?ooo`0306Kooooooooo053oool007Soool00`1Vooooooooo`05oooo00<0
I_ooooooool08Oooo`030000oooooooo01Koool00`1Vooooooooo`0=oooo00<0I_ooooooool0D?oo
o`00Moooo`0306Kooooooooo00Koool00`1Vooooooooo`0Qoooo00<0003oooooool05_ooo`0306Ko
oooooooo00goool00`1Vooooooooo`1@oooo001goooo00<0I_ooooooool01_ooo`0306Kooooooooo
00goool200001?ooo`800005oooo0`0000Coool00`000?ooooooo`0Foooo00<0I_ooooooool03Ooo
o`0306Kooooooooo053oool007Ooool00`1Vooooooooo`07oooo00<0I_ooooooool02oooo`040000
oooooooo00002oooo`030000oooooooo00?oool00`000?ooooooo`0Eoooo00<0I_ooooooool03_oo
o`0306Kooooooooo053oool007Ooool00`1Vooooooooo`07oooo00<0I_ooooooool02oooo`040000
oooooooo00002?ooo`D00004oooo0P0001Koool00`1Vooooooooo`0>oooo00<0I_ooooooool0D?oo
o`00Moooo`0306Kooooooooo00Ooool00`1Vooooooooo`05oooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Goool00`000?ooooooo`0Doooo00<0I_ooooooool03oooo`0306Ko
oooooooo053oool007Ooool00`1Vooooooooo`08oooo00<0I_ooooooool02_ooo`040000oooooooo
00002Oooo`030000oooo000000Goool00`000?ooooooo`0Doooo00<0I_ooooooool03oooo`0306Ko
oooooooo053oool007Ooool00`1Vooooooooo`08oooo00<0I_ooooooool02oooo`80000;oooo0P00
00Goool00`000?ooooooo`0Doooo00<0I_ooooooool03oooo`0306Kooooooooo053oool007Koool0
0`1Vooooooooo`09oooo00<0I_ooooooool07oooo`030000oooooooo01?oool00`1Vooooooooo`0@
oooo00<0I_ooooooool0D?ooo`00M_ooo`0306Kooooooooo00[oool00`1Vooooooooo`0Noooo0P00
01Coool00`1Vooooooooo`0@oooo00<0I_ooooooool0D?ooo`00M_ooo`0306Kooooooooo00[oool0
0`1Vooooooooo`0Noooo00<0003oooooool04_ooo`0306Kooooooooo017oool00`1Vooooooooo`1@
oooo001foooo00<0I_ooooooool02_ooo`0306Kooooooooo01koool00`000?ooooooo`0Boooo00<0
I_ooooooool04Oooo`0306Kooooooooo053oool007Koool00`1Vooooooooo`0;oooo00<0I_oooooo
ool07Oooo`030000oooooooo01;oool00`1Vooooooooo`0Aoooo00<0I_ooooooool0D?ooo`00M_oo
o`0306Kooooooooo00_oool00`1Vooooooooo`0Moooo00<0003oooooool04Oooo`0306Kooooooooo
01;oool00`1Vooooooooo`1@oooo001eoooo00<0I_ooooooool03?ooo`0306Kooooooooo01goool2
00004_ooo`0306Kooooooooo01;oool00`1Vooooooooo`1@oooo001eoooo00<0I_ooooooool03Ooo
o`0306Kooooooooo01coool00`000?ooooooo`0@oooo00<0I_ooooooool04oooo`0306Kooooooooo
053oool007Goool00`1Vooooooooo`0=oooo00<0I_ooooooool07?ooo`030000oooooooo013oool0
0`1Vooooooooo`0Coooo00<0I_ooooooool0D?ooo`00MOooo`0306Kooooooooo00koool00`1Voooo
ooooo`0Koooo00<0003oooooool04?ooo`0306Kooooooooo01?oool00`1Vooooooooo`1@oooo001e
oooo00<0I_ooooooool03_ooo`0306Kooooooooo01_oool00`000?ooooooo`0?oooo00<0I_oooooo
ool05?ooo`0306Kooooooooo053oool007Goool00`1Vooooooooo`0>oooo00<0I_ooooooool06ooo
o`80000@oooo00<0I_ooooooool05?ooo`0306Kooooooooo053oool007Coool00`1Vooooooooo`0@
oooo00<0I_ooooooool06_ooo`030000oooooooo00koool00`1Vooooooooo`0Eoooo00<0I_oooooo
ool0D?ooo`00M?ooo`0306Kooooooooo013oool00`1Vooooooooo`0Joooo00<0003oooooool03_oo
o`0306Kooooooooo01Goool00`1Vooooooooo`1@oooo001doooo00<0I_ooooooool04Oooo`0306Ko
oooooooo01Woool00`000?ooooooo`0=oooo00<0I_ooooooool05_ooo`0306Kooooooooo053oool0
07Coool00`1Vooooooooo`0Aoooo00<0I_ooooooool06Oooo`030000oooooooo00goool00`1Voooo
ooooo`0Foooo00<0I_ooooooool0D?ooo`00M?ooo`0306Kooooooooo017oool00`1Vooooooooo`0I
oooo0P0000koool00`1Vooooooooo`0Foooo00<0I_ooooooool0D?ooo`00Loooo`0306Kooooooooo
01?oool00`1Vooooooooo`0Hoooo00<0003oooooool03?ooo`0306Kooooooooo01Ooool00`1Voooo
ooooo`1@oooo001coooo00<0I_ooooooool04oooo`0306Kooooooooo01Soool00`000?ooooooo`0<
oooo00<0I_ooooooool05oooo`0306Kooooooooo053oool007?oool00`1Vooooooooo`0Doooo00<0
I_ooooooool00oooo`800004oooo0P0000Coool200001_ooo`030000oooooooo00_oool00`1Voooo
ooooo`0Hoooo00<0I_ooooooool0D?ooo`00Loooo`0306Kooooooooo01Coool00`1Vooooooooo`02
oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool02oooo`0306Ko
oooooooo01Soool00`1Vooooooooo`1@oooo001boooo00<0I_ooooooool05Oooo`0306Kooooooooo
00;oool010000?ooooooo`0000[oool00`000?ooooooo`04oooo0P0000_oool00`1Vooooooooo`0I
oooo00<0I_ooooooool0D?ooo`00L_ooo`0306Kooooooooo01Coool400000_ooo`040000oooooooo
00002oooo`030000oooooooo00?oool00`000?ooooooo`0:oooo00<0I_ooooooool06Oooo`0306Ko
oooooooo053oool007;oool00`1Vooooooooo`0Foooo00D0I_ooooooooooool000000_ooo`030000
oooooooo00Koool010000?ooooooo`0000Goool00`000?ooooooo`09oooo00<0I_ooooooool06_oo
o`0306Kooooooooo053oool007;oool00`1Vooooooooo`0Goooo00@0I_ooooooooooool200002_oo
o`800006oooo00<0003oooooool02Oooo`0306Kooooooooo01[oool00`1Vooooooooo`1@oooo001b
oooo00<0I_ooooooool05oooo`0306Kooooooooo01Goool00`000?ooooooo`09oooo00<0I_oooooo
ool06_ooo`0306Kooooooooo053oool0077oool00`1Vooooooooo`0Hoooo00<0I_ooooooool05Ooo
o`800009oooo00<0I_ooooooool06oooo`0306Kooooooooo053oool0077oool00`1Vooooooooo`0I
oooo00<0I_ooooooool05?ooo`030000oooooooo00Soool00`1Vooooooooo`0Koooo00<0I_oooooo
ool0D?ooo`00LOooo`0306Kooooooooo01Woool00`1Vooooooooo`0Doooo00<0003oooooool01ooo
o`0306Kooooooooo01coool00`1Vooooooooo`1@oooo001aoooo00<0I_ooooooool06_ooo`0306Ko
oooooooo01?oool00`000?ooooooo`07oooo00<0I_ooooooool07?ooo`0306Kooooooooo053oool0
077oool00`1Vooooooooo`0Joooo00<0I_ooooooool04oooo`030000oooooooo00Koool00`1Voooo
ooooo`0Moooo00<0I_ooooooool0D?ooo`00L?ooo`0306Kooooooooo01_oool00`1Vooooooooo`0C
oooo0P0000Ooool00`1Vooooooooo`0Moooo00<0I_ooooooool0D?ooo`00L?ooo`0306Kooooooooo
01coool00`1Vooooooooo`0Boooo00<0003oooooool01Oooo`0306Kooooooooo01koool00`1Voooo
ooooo`1@oooo001`oooo00<0I_ooooooool07?ooo`0306Kooooooooo01;oool00`000?ooooooo`05
oooo00<0I_ooooooool07_ooo`0306Kooooooooo053oool0073oool00`1Vooooooooo`0Moooo00<0
I_ooooooool04Oooo`030000oooooooo00Coool00`1Vooooooooo`0Ooooo00<0I_ooooooool0D?oo
o`00Koooo`0306Kooooooooo01koool00`1Vooooooooo`0Aoooo00<0003oooooool01?ooo`0306Ko
oooooooo01ooool00`1Vooooooooo`1@oooo001_oooo00<0I_ooooooool07oooo`0306Kooooooooo
013oool200001?ooo`0306Kooooooooo023oool00`1Vooooooooo`1@oooo001_oooo00<0I_oooooo
ool07oooo`0306Kooooooooo013oool00`000?ooooooo`03oooo00<0I_ooooooool08?ooo`0306Ko
oooooooo053oool006ooool00`1Vooooooooo`0Poooo00<0I_ooooooool03oooo`030000oooooooo
00;oool00`1Vooooooooo`0Qoooo00<0I_ooooooool0D?ooo`00Koooo`0306Kooooooooo023oool0
0`1Vooooooooo`0?oooo00<0003oooooool00_ooo`0306Kooooooooo027oool00`1Vooooooooo`1@
oooo001^oooo00<0I_ooooooool08_ooo`0306Kooooooooo00koool01@000?ooooooooooo`1Vo`0T
oooo00<0I_ooooooool0D?ooo`00K_ooo`0306Kooooooooo02?oool00`1Vooooooooo`0=oooo0P00
0003oooo06Kooooo02Coool00`1Vooooooooo`1@oooo001^oooo00<0I_ooooooool08oooo`0306Ko
oooooooo00goool010000?ooooooo`1VobGoool00`1Vooooooooo`1@oooo001^oooo00<0I_oooooo
ool09?ooo`0306Kooooooooo00coool00`000?ooo`1Vo`0Voooo00<0I_ooooooool0D?ooo`00K_oo
o`0306Kooooooooo01ooool200001?ooo`800003oooo100000Goool00`000?ooo`1Vo`0Voooo00<0
I_ooooooool0D?ooo`00KOooo`0306Kooooooooo01ooool010000?ooooooo`0000?oool00`1Voooo
ooooo`02oooo00<0003oooooool01_ooo`03000006Kooooo02Koool00`1Vooooooooo`1@oooo001]
oooo00<0I_ooooooool07oooo`040000oooooooo00001?ooo`0306Kooooooooo00;oool00`000?oo
ooooo`05oooo0P0002Ooool00`1Vooooooooo`1@oooo001]oooo00<0I_ooooooool06Oooo`@00002
oooo00@0003oooooool00005oooo0P1Vo`?oool00`000?ooooooo`03oooo00<0I_l0003oool09ooo
o`0306Kooooooooo053oool006goool00`1Vooooooooo`0Ooooo00@0003oooooool00007oooo00D0
I_l0003oooooool000001?ooo`0306Ko0000oooo02Ooool00`1Vooooooooo`1@oooo001/oooo00<0
I_ooooooool08Oooo`800009oooo00<0I_l0000000000oooo`80I_l00oooo`000?ooo`0Woooo00<0
I_ooooooool0D?ooo`00K?ooo`0306Kooooooooo02goool606Ko0_ooo`030000oooooooo02Koool0
0`1Vooooooooo`1@oooo001[oooo00<0I_ooooooool0=_ooo`80000Woooo00<0I_ooooooool0D?oo
o`00Joooo`0306Kooooooooo03Koool00`000?ooooooo`0Voooo00<0I_ooooooool0D?ooo`00Jooo
o`0306Kooooooooo03Koool00`000?ooooooo`0Voooo00<0I_ooooooool0D?ooo`00J_ooo`0306Ko
oooooooo03Ooool00`000?ooooooo`0Voooo00<0I_ooooooool0D?ooo`00J_ooo`0306Kooooooooo
03Ooool00`000?ooooooo`0Voooo00<0I_ooooooool0D?ooo`00J_ooo`0306Kooooooooo03Ooool2
00009oooo`0306Kooooooooo053oool006Woool00`1Vooooooooo`0hoooo00<0003oooooool09_oo
o`0306Kooooooooo053oool006Woool00`1Vooooooooo`0hoooo00<0003oooooool09_ooo`0306Ko
oooooooo053oool006Soool00`1Vooooooooo`0ioooo00<0003oooooool09_ooo`0306Kooooooooo
053oool006Soool00`1Vooooooooo`0ioooo00<0003oooooool09_ooo`0306Kooooooooo053oool0
06Ooool00`1Vooooooooo`0joooo0P0002Ooool00`1Vooooooooo`1@oooo001Woooo00<0I_oooooo
ool0>_ooo`030000oooooooo02Koool00`1Vooooooooo`1@oooo001Woooo00<0I_ooooooool0>_oo
o`030000oooooooo02Koool00`1Vooooooooo`1@oooo001Voooo00<0I_ooooooool0>oooo`030000
oooooooo02Koool00`1Vooooooooo`1@oooo001Voooo00<0I_ooooooool0>oooo`030000oooooooo
02Koool00`1Vooooooooo`1@oooo001Uoooo00<0I_ooooooool0??ooo`80000Woooo00<0I_oooooo
ool0D?ooo`00IOooo`0306Kooooooooo03coool00`000?ooooooo`0Voooo00<0I_ooooooool0D?oo
o`00I?ooo`0306Kooooooooo02Woool200001?ooo`800003oooo1@0000Coool00`000?ooooooo`0V
oooo00<0I_ooooooool0D?ooo`00I?ooo`0306Kooooooooo02Soool010000?ooooooo`0000[oool0
0`000?ooooooo`04oooo00<0003oooooool09_ooo`0306Kooooooooo053oool006?oool00`1Voooo
ooooo`0Yoooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`80000Woooo00<0I_oooooo
ool0D?ooo`00H_ooo`0306Kooooooooo02Coool400000_ooo`040000oooooooo00002_ooo`030000
oooooooo00Coool00`000?ooooooo`0Voooo00<0I_ooooooool0D?ooo`00H_ooo`0306Kooooooooo
02[oool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool09_ooo`0306Ko
oooooooo053oool0067oool00`1Vooooooooo`0/oooo0P0000[oool200001_ooo`030000oooooooo
02Koool00`1Vooooooooo`1@oooo001Qoooo00<0I_ooooooool0@?ooo`030000oooooooo02Koool0
0`1Vooooooooo`1@oooo001Poooo00<0I_ooooooool0@Oooo`80000Woooo00<0I_ooooooool0D?oo
o`00Goooo`0306Kooooooooo04;oool00`000?ooooooo`0Voooo00<0I_ooooooool0D?ooo`00G_oo
o`0306Kooooooooo04?oool00`000?ooooooo`0Voooo00<0I_ooooooool0D?ooo`00GOooo`0306Ko
oooooooo04Coool00`000?ooooooo`0Voooo00<0I_ooooooool0D?ooo`00GOooo`0306Kooooooooo
04Coool00`000?ooooooo`0Voooo00<0I_ooooooool0D?ooo`00G?ooo`0306Kooooooooo04Goool2
00009oooo`0306Kooooooooo053oool005_oool00`1Vooooooooo`16oooo00<0003oooooool09_oo
o`0306Kooooooooo053oool005Woool206KoBOooo`030000oooooooo02Koool00`1Vooooooooo`1@
oooo001Hoooo00<0I_ooooooool0BOooo`030000oooooooo02Koool00`1Vooooooooo`1@oooo000Y
oooo0`0002Soool3000000<0I_ooooooool08Oooo`@0000Uoooo00<0003oooooool09?ooo`@0000W
oooo0`0002Ooool002Woool010000?ooooooo`0002Soool00`00001Vooooo`0Soooo00<0003ooooo
ool09_ooo`80000Uoooo00<0003oool0I_l0:Oooo`030000oooooooo02Koool002Woool010000?oo
ooooo`0002Goool500009Oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo00<00000I_oo
ool09Oooo`D0000Woooo000Soooo100000;oool300008?ooo`@00002oooo00@00000I_ooool0000O
oooo100000Coool00`000?ooooooo`0Toooo00<0003oooooool09_ooo`030000oooooooo02Coool0
10000?ooooooo`0002Soool002[oool00`000?ooooooo`0Soooo0P1Vo`04oooo0000oooo00009Ooo
o`040000oooooooo00009Oooo`030000oooooooo02Coool010000?ooo`1Vo`0002Koool00`000?oo
o`00000Xoooo000Zoooo0`00027oool206Ko1?ooo`80000Voooo0P0002Koool00`000?ooooooo`0U
oooo0P0002Soool20000:?ooo`00Boooo`<0I_mFoooo0P0002Ooool00`1Vooooooooo`1@oooo0018
oooo0`1VoeWoool00`000?ooooooo`0Voooo00<0I_ooooooool0D?ooo`00@oooo`D0I_mLoooo00<0
003oooooool09_ooo`0306Kooooooooo053oool003ooool406KoHOooo`030000oooooooo02Koool0
0`1Vooooooooo`1@oooo000`oooo3`1VofGoool00`000?ooooooo`0Voooo00<0I_ooooooool0D?oo
o`003Oooool0000600003_ooo`004oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oool00000300000Dco`000`0003?o
03?o0008<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0008<ol000<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo01;oool002Soool0
0`000?ooooooo`0Voooo00<0003oooooool08Oooo`H0000Y<ol000<0003oooooool09_ooo`030000
oooooooo02Koool00`000?ooooooo`0Woooo001joooo0`0002Lco`000`000?ooooooo`0Voooo00?o
09Woooooool0D?ooo`00OOooo`80000U<ol000<0003oooooool09_ooo`03o`2Ioooooooo053oool0
07ooool00`0003?o03?o000R<ol00P0002Ooool00ol0VOooooooo`1@oooo0020oooo00<0000co`0c
o`008C?o00030000oooooooo02Koool00ol0VOooooooo`1@oooo0021oooo0P00024co`000`000?oo
ooooo`0Voooo00?o09Woooooool0D?ooo`00Poooo`030000<ol0<ol001hco`000`000?ooooooo`0V
oooo00?o09Woooooool0D?ooo`00Poooo`030000<ol0<ol001hco`000`000?ooooooo`0Voooo00?o
09Woooooool0D?ooo`00Q?ooo`030000<ol0<ol001dco`0200009oooo`03o`2Ioooooooo053oool0
08Goool00`0003?o03?o000L<ol000<0003oooooool09_ooo`03o`2Ioooooooo053oool008Koool0
0`0003?o03?o000K<ol000<0003oooooool09_ooo`03o`2Ioooooooo053oool008Koool00`0003?o
03?o000K<ol000<0003oooooool09_ooo`03o`2Ioooooooo053oool008OooolM<ol0O?ooo`00R?oo
oa`co`1loooo0028oooo73?o07coool008SooolL<ol0O?ooo`00ROoooa/co`1loooo001ooooo00<0
003oooooool01ooooaDco`000`0003?o03?o0003<ol0O?ooo`00O_ooo`030000oooooooo00Soool0
0`0003?o03?o000C<ol000<0000co`0co`000S?o07coool007koool00`000?ooooooo`02oooo0P00
00Coool00`0003?o03?o0007<ol00P0000@co`02000013?o00030000<ol0<ol0008co`1loooo001n
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`0003?o03?o0005<ol000@0
000co`0co`000009<ol000<0000co`0co`000S?o07coool007goool00`000?ooooooo`02oooo00<0
003oooooool01_ooo`Tco`000`0003?o03?o0009<ol000@0000co`0co`0co`1loooo001noooo00<0
003oooooool01@0000Goool:<ol000<0000co`0co`001c?o00030000<ol0<ol0008co`1loooo001n
oooo00D0003oooooooooool000002Oooo`Hco`00100003?o03?o000000Tco`000`0003?o03?o0002
<ol0O?ooo`00Ooooo`030000oooooooo00[oool7<ol00P0000Tco`000`0003?o03?o0003<ol0O?oo
o`00S?oooaPco`1loooo002<oooo63?o07coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.26171 .57049 L
.30316 .57049 L
.34309 .57049 L
.3815 .57049 L
.42237 .57049 L
.46172 .57049 L
.49955 .57049 L
.53984 .57049 L
.57861 .57049 L
.61984 .57049 L
.65954 .57049 L
.69774 .57049 L
.73838 .57049 L
.75718 .57049 L
.76707 .57049 L
.77247 .57049 L
.77511 .57049 L
.77626 .57049 L
.77751 .57049 L
s
.77751 .57049 m
.77752 .61803 L
s
0 .4 1 r
.02381 .56969 m
.04262 .56937 L
.06244 .56889 L
.07286 .56857 L
.08255 .56821 L
.09388 .56769 L
.10458 .56711 L
.125 .56562 L
.14357 .56371 L
.16355 .56081 L
.18199 .55704 L
.20071 .55171 L
.21136 .54779 L
.22134 .54337 L
.24158 .53159 L
.26011 .51638 L
.27909 .49459 L
.28984 .47857 L
.29982 .46069 L
.32034 .41221 L
.33895 .34997 L
.35819 .25974 L
.36904 .1935 L
.37385 .15972 L
.3765 .13985 L
.37901 .12013 L
.3802 .11054 L
.38145 .10614 L
.38211 .10854 L
.38283 .11117 L
.38411 .11579 L
.38875 .13235 L
.39784 .16355 L
.4185 .22831 L
.4587 .33 L
.49739 .39954 L
.51743 .42511 L
.52751 .43511 L
.53318 .43982 L
.53853 .4436 L
.54346 .44646 L
.54606 .44771 L
.54881 .44883 L
.55112 .4496 L
.55235 .44993 L
.55366 .45024 L
.55487 .45047 L
.55598 .45064 L
.55709 .45076 L
.55814 .45084 L
Mistroke
.55946 .45087 L
.56066 .45084 L
.56133 .4508 L
.56204 .45073 L
.56334 .45055 L
.56457 .45031 L
.56586 .44998 L
.56817 .44918 L
.57086 .44788 L
.57338 .44626 L
.57614 .44398 L
.57909 .44088 L
.62051 .38241 L
.6604 .30782 L
.69879 .21979 L
.71821 .17123 L
.73962 .11788 L
.74939 .09486 L
.75991 .07204 L
.76475 .06251 L
.76984 .05331 L
.77419 .04626 L
.77538 .04447 L
.77665 .04263 L
.77785 .57049 L
.77894 .57049 L
.81897 .57049 L
.85749 .57049 L
.89846 .57049 L
.93792 .57049 L
.97586 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`0`oooo00<0
I_ooooooool0A_ooo`00Y?ooo`030000oooooooo02ooool206KoB?ooo`00Y?ooo`030000oooooooo
02koool00`1Vooooo`1Vo`18oooo002Toooo0P0002ooool00`1Vooooo`1Vo`18oooo002Toooo00<0
003oooooool0;Oooo`0406Kooooooooo06KoB?ooo`00Y?ooo`030000oooooooo02goool0101Voooo
ooooo`1VodSoool00:Coool00`000?ooooooo`0/oooo00D0I_ooooooooooool0I_l0B?ooo`00Y?oo
o`030000oooooooo02coool01@1Vooooooooooooo`1Vo`18oooo002Toooo0P0002coool00`1Voooo
ooooo`02oooo00<0I_ooooooool0A_ooo`00Y?ooo`030000oooooooo02_oool00`1Vooooooooo`02
oooo00<0I_ooooooool0A_ooo`00Y?ooo`030000oooooooo02[oool00`1Vooooooooo`03oooo00<0
I_ooooooool0A_ooo`00T?ooo`800004oooo0P0000Coool200001_ooo`030000oooooooo02[oool0
0`1Vooooooooo`03oooo00<0I_ooooooool0A_ooo`00Soooo`040000oooooooo00002?ooo`040000
oooooooo00001Oooo`030000oooooooo02Woool00`1Vooooooooo`04oooo00<0I_ooooooool0A_oo
o`00Soooo`040000oooooooo00002oooo`030000oooooooo00?oool20000:_ooo`0306Kooooooooo
00Coool00`1Vooooooooo`16oooo0029oooo100000;oool010000?ooooooo`0000Woool200001_oo
o`030000oooooooo02Soool00`1Vooooooooo`05oooo00<0I_ooooooool0A_ooo`00Soooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`0Xoooo00<0I_ooooooool01Ooo
o`0306Kooooooooo04Koool0073oool00`1Vooooooooo`0Moooo0P0000[oool300001Oooo`030000
oooooooo02Ooool00`1Vooooooooo`06oooo00<0I_ooooooool0A_ooo`00L?ooo`0306Kooooooooo
037oool00`000?ooooooo`0Woooo00<0I_ooooooool01_ooo`0306Kooooooooo04Koool0073oool0
0`1Vooooooooo`0aoooo0P0002Ooool00`1Vooooooooo`07oooo00<0I_ooooooool0A_ooo`00Kooo
o`0306Kooooo06Ko03;oool00`000?ooooooo`0Voooo00<0I_ooooooool01oooo`0306Kooooooooo
04Koool006ooool00`1Vooooo`1Vo`0boooo00<0003oooooool09_ooo`0306Kooooooooo00Ooool0
0`1Vooooooooo`16oooo001_oooo00<0I_ooool0I_l0<_ooo`030000oooooooo02Goool00`1Voooo
ooooo`08oooo00<0I_ooooooool0A_ooo`00Koooo`0406Kooooooooo06Ko<Oooo`030000oooooooo
02Goool00`1Vooooooooo`08oooo00<0I_ooooooool0A_ooo`00Koooo`0406Kooooooooo06Ko<Ooo
o`80000Voooo00<0I_ooooooool02?ooo`0306Kooooooooo04Koool006ooool0101Vooooooooo`1V
oc7oool00`000?ooooooo`0Toooo00<0I_ooooooool02Oooo`0306Kooooooooo04Koool006ooool0
101Vooooooooo`1Voc7oool00`000?ooooooo`0Toooo00<0I_ooooooool02Oooo`0306Kooooooooo
04Koool006ooool01@1Vooooooooooooo`1Vo`0`oooo00<0003oooooool08oooo`0306Kooooooooo
00[oool00`1Vooooooooo`16oooo001_oooo00D0I_ooooooooooool0I_l0<?ooo`030000oooooooo
02?oool00`1Vooooooooo`0:oooo00<0I_ooooooool0A_ooo`00K_ooo`0306Kooooooooo00;oool0
0`1Vooooooooo`0^oooo0P0002Coool00`1Vooooooooo`0:oooo00<0I_ooooooool0A_ooo`00K_oo
o`0306Kooooooooo00;oool00`1Vooooooooo`0^oooo00<0003oooooool08_ooo`0306Kooooooooo
00_oool00`1Vooooooooo`16oooo001^oooo00<0I_ooooooool00oooo`0306Kooooooooo02goool0
0`000?ooooooo`0Roooo00<0I_ooooooool02oooo`0306Kooooooooo04Koool006koool00`1Voooo
ooooo`03oooo00<0I_ooooooool0;Oooo`030000oooooooo02;oool00`1Vooooooooo`0;oooo00<0
I_ooooooool0A_ooo`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0]oooo00<0003ooooo
ool08Oooo`0306Kooooooooo00coool00`1Vooooooooo`16oooo001^oooo00<0I_ooooooool01?oo
o`0306Kooooooooo02coool200008_ooo`0306Kooooooooo00coool00`1Vooooooooo`16oooo001^
oooo00<0I_ooooooool01?ooo`0306Kooooooooo02coool00`000?ooooooo`0Qoooo00<0I_oooooo
ool03?ooo`0306Kooooooooo04Koool006goool00`1Vooooooooo`05oooo00<0I_ooooooool0;?oo
o`030000oooooooo023oool00`1Vooooooooo`0=oooo00<0I_ooooooool0A_ooo`00KOooo`0306Ko
oooooooo00Koool00`1Vooooooooo`0Goooo0P0000Coool200001Oooo`<00004oooo00<0003ooooo
ool08?ooo`0306Kooooooooo00goool00`1Vooooooooo`16oooo001]oooo00<0I_ooooooool01_oo
o`0306Kooooooooo01Koool010000?ooooooo`0000_oool00`000?ooooooo`03oooo00<0003ooooo
ool07oooo`0306Kooooooooo00koool00`1Vooooooooo`16oooo001]oooo00<0I_ooooooool01_oo
o`0306Kooooooooo01Koool010000?ooooooo`0000Soool500001?ooo`80000Poooo00<0I_oooooo
ool03_ooo`0306Kooooooooo04Koool006goool00`1Vooooooooo`07oooo00<0I_ooooooool03ooo
o`@00002oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool07ooo
o`0306Kooooooooo00koool00`1Vooooooooo`16oooo001]oooo00<0I_ooooooool01oooo`0306Ko
oooooooo01Goool010000?ooooooo`0000Woool00`000?ooo`000005oooo00<0003oooooool07_oo
o`0306Kooooooooo00ooool00`1Vooooooooo`16oooo001]oooo00<0I_ooooooool02?ooo`0306Ko
oooooooo01Goool200002oooo`800005oooo00<0003oooooool07_ooo`0306Kooooooooo00ooool0
0`1Vooooooooo`16oooo001/oooo00<0I_ooooooool02Oooo`0306Kooooooooo02Woool00`000?oo
ooooo`0Noooo00<0I_ooooooool03oooo`0306Kooooooooo04Koool006coool00`1Vooooooooo`09
oooo00<0I_ooooooool0:Oooo`80000Noooo00<0I_ooooooool04?ooo`0306Kooooooooo04Koool0
06coool00`1Vooooooooo`0:oooo00<0I_ooooooool0:?ooo`030000oooooooo01goool00`1Voooo
ooooo`0@oooo00<0I_ooooooool0A_ooo`00K?ooo`0306Kooooooooo00[oool00`1Vooooooooo`0X
oooo00<0003oooooool07?ooo`0306Kooooooooo017oool00`1Vooooooooo`16oooo001/oooo00<0
I_ooooooool02_ooo`0306Kooooooooo02Soool00`000?ooooooo`0Loooo00<0I_ooooooool04Ooo
o`0306Kooooooooo04Koool006coool00`1Vooooooooo`0;oooo00<0I_ooooooool09oooo`030000
oooooooo01coool00`1Vooooooooo`0Aoooo00<0I_ooooooool0A_ooo`00Joooo`0306Kooooooooo
00coool00`1Vooooooooo`0Woooo0P0001coool00`1Vooooooooo`0Boooo00<0I_ooooooool0A_oo
o`00Joooo`0306Kooooooooo00coool00`1Vooooooooo`0Woooo00<0003oooooool06oooo`0306Ko
oooooooo01;oool00`1Vooooooooo`16oooo001[oooo00<0I_ooooooool03Oooo`0306Kooooooooo
02Koool00`000?ooooooo`0Joooo00<0I_ooooooool04oooo`0306Kooooooooo04Koool006_oool0
0`1Vooooooooo`0=oooo00<0I_ooooooool09_ooo`030000oooooooo01[oool00`1Vooooooooo`0C
oooo00<0I_ooooooool0A_ooo`00Joooo`0306Kooooooooo00goool00`1Vooooooooo`0Voooo00<0
003oooooool06Oooo`0306Kooooooooo01Coool00`1Vooooooooo`16oooo001[oooo00<0I_oooooo
ool03_ooo`0306Kooooooooo02Goool200006_ooo`0306Kooooooooo01Coool00`1Vooooooooo`16
oooo001Zoooo00<0I_ooooooool03oooo`0306Kooooooooo02Goool00`000?ooooooo`0Ioooo00<0
I_ooooooool05?ooo`0306Kooooooooo04Koool006[oool00`1Vooooooooo`0@oooo00<0I_oooooo
ool09?ooo`030000oooooooo01Soool00`1Vooooooooo`0Eoooo00<0I_ooooooool0A_ooo`00J_oo
o`0306Kooooooooo013oool00`1Vooooooooo`0Toooo00<0003oooooool06?ooo`0306Kooooooooo
01Goool00`1Vooooooooo`16oooo001Zoooo00<0I_ooooooool04?ooo`0306Kooooooooo02Coool0
0`000?ooooooo`0Goooo00<0I_ooooooool05_ooo`0306Kooooooooo04Koool006[oool00`1Voooo
ooooo`0Aoooo00<0I_ooooooool08oooo`80000Hoooo00<0I_ooooooool05_ooo`0306Kooooooooo
04Koool006Woool00`1Vooooooooo`0Boooo00<0I_ooooooool08oooo`030000oooooooo01Koool0
0`1Vooooooooo`0Goooo00<0I_ooooooool0A_ooo`00JOooo`0306Kooooooooo01;oool00`1Voooo
ooooo`0Soooo00<0003oooooool05_ooo`0306Kooooooooo01Ooool00`1Vooooooooo`16oooo001Y
oooo00<0I_ooooooool04oooo`0306Kooooooooo00koool200001?ooo`800004oooo0P0000Koool0
0`000?ooooooo`0Eoooo00<0I_ooooooool06?ooo`0306Kooooooooo04Koool006Woool00`1Voooo
ooooo`0Coooo00<0I_ooooooool03Oooo`040000oooooooo00002?ooo`040000oooooooo00001Ooo
o`030000oooooooo01Goool00`1Vooooooooo`0Hoooo00<0I_ooooooool0A_ooo`00JOooo`0306Ko
oooooooo01Coool00`1Vooooooooo`0<oooo00@0003oooooool0000:oooo00<0003oooooool01?oo
o`80000Foooo00<0I_ooooooool06?ooo`0306Kooooooooo04Koool006Soool00`1Vooooooooo`0E
oooo00<0I_ooooooool01_ooo`@00002oooo00@0003oooooool0000;oooo00<0003oooooool00ooo
o`030000oooooooo01Coool00`1Vooooooooo`0Ioooo00<0I_ooooooool0A_ooo`00J?ooo`0306Ko
oooooooo01Goool00`1Vooooooooo`0<oooo00@0003oooooool00008oooo00@0003oooooool00005
oooo00<0003oooooool05?ooo`0306Kooooooooo01Woool00`1Vooooooooo`16oooo001Xoooo00<0
I_ooooooool05_ooo`0306Kooooooooo00coool200002_ooo`800006oooo00<0003oooooool04ooo
o`0306Kooooooooo01[oool00`1Vooooooooo`16oooo001Xoooo00<0I_ooooooool05_ooo`0306Ko
oooooooo023oool00`000?ooooooo`0Coooo00<0I_ooooooool06_ooo`0306Kooooooooo04Koool0
06Ooool00`1Vooooooooo`0Goooo00<0I_ooooooool08?ooo`80000Coooo00<0I_ooooooool06ooo
o`0306Kooooooooo04Koool006Ooool00`1Vooooooooo`0Hoooo00<0I_ooooooool07oooo`030000
oooooooo01;oool00`1Vooooooooo`0Koooo00<0I_ooooooool0A_ooo`00Ioooo`0306Kooooooooo
01Soool00`1Vooooooooo`0Ooooo00<0003oooooool04Oooo`0306Kooooooooo01coool00`1Voooo
ooooo`16oooo001Woooo00<0I_ooooooool06Oooo`0306Kooooooooo01koool00`000?ooooooo`0A
oooo00<0I_ooooooool07?ooo`0306Kooooooooo04Koool006Ooool00`1Vooooooooo`0Ioooo00<0
I_ooooooool07_ooo`030000oooooooo013oool00`1Vooooooooo`0Moooo00<0I_ooooooool0A_oo
o`00I_ooo`0306Kooooooooo01[oool00`1Vooooooooo`0Noooo0P00017oool00`1Vooooooooo`0M
oooo00<0I_ooooooool0A_ooo`00I_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0Moooo00<0
003oooooool03oooo`0306Kooooooooo01koool00`1Vooooooooo`16oooo001Voooo00<0I_oooooo
ool06oooo`0306Kooooooooo01goool00`000?ooooooo`0?oooo00<0I_ooooooool07_ooo`0306Ko
oooooooo04Koool006Koool00`1Vooooooooo`0Loooo00<0I_ooooooool07?ooo`030000oooooooo
00koool00`1Vooooooooo`0Ooooo00<0I_ooooooool0A_ooo`00I_ooo`0306Kooooooooo01coool0
0`1Vooooooooo`0Loooo00<0003oooooool03Oooo`0306Kooooooooo023oool00`1Vooooooooo`16
oooo001Uoooo00<0I_ooooooool07_ooo`0306Kooooooooo01_oool200003_ooo`0306Kooooooooo
023oool00`1Vooooooooo`16oooo001Uoooo00<0I_ooooooool07_ooo`0306Kooooooooo01_oool0
0`000?ooooooo`0<oooo00<0I_ooooooool08Oooo`0306Kooooooooo04Koool006Goool00`1Voooo
ooooo`0Ooooo00<0I_ooooooool06_ooo`030000oooooooo00coool00`1Vooooooooo`0Qoooo00<0
I_ooooooool0A_ooo`00IOooo`0306Kooooooooo01ooool00`1Vooooooooo`0Joooo00<0003ooooo
ool02oooo`0306Kooooooooo02;oool00`1Vooooooooo`16oooo001Toooo00<0I_ooooooool08Ooo
o`0306Kooooooooo01Woool00`000?ooooooo`0:oooo00<0I_ooooooool08oooo`0306Kooooooooo
04Koool006Coool00`1Vooooooooo`0Qoooo00<0I_ooooooool06Oooo`80000;oooo00<0I_oooooo
ool08oooo`0306Kooooooooo04Koool006Coool00`1Vooooooooo`0Roooo00<0I_ooooooool06?oo
o`030000oooooooo00Woool00`1Vooooooooo`0Toooo00<0I_ooooooool0A_ooo`00Hoooo`0306Ko
oooooooo02Coool00`1Vooooooooo`0Goooo00<0003oooooool02Oooo`0306Kooooooooo02Coool0
0`1Vooooooooo`16oooo001Soooo00<0I_ooooooool09?ooo`0306Kooooooooo00?oool200001?oo
o`800003oooo100000Goool00`000?ooooooo`08oooo00<0I_ooooooool09Oooo`0306Kooooooooo
04Koool006?oool00`1Vooooooooo`0Uoooo00D0I_ooooooooooool000000_ooo`030000oooooooo
00Koool00`000?ooooooo`06oooo00<0003oooooool02?ooo`0306Kooooooooo02Goool00`1Voooo
ooooo`16oooo001Roooo00<0I_ooooooool09_ooo`0506Kooooooooooooo000000;oool00`000?oo
ooooo`07oooo00<0003oooooool01Oooo`800008oooo00<0I_ooooooool09_ooo`0306Kooooooooo
04Koool006;oool00`1Vooooooooo`0Toooo100000;oool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool01_ooo`0306Kooooooooo02Ooool00`1Vooooooooo`16oooo001R
oooo00<0I_ooooooool09oooo`0406Kooooooooo00000_ooo`030000oooooooo00Koool010000?oo
ooooo`0000Goool00`000?ooooooo`06oooo00<0I_ooooooool09oooo`0306Kooooooooo04Koool0
06;oool00`1Vooooooooo`0Xoooo00<0I_ooooooool00P0000[oool200001_ooo`030000oooooooo
00Goool00`1Vooooooooo`0Xoooo00<0I_ooooooool0A_ooo`00HOooo`0306Kooooooooo02Woool0
0`1Vooooooooo`0Doooo00<0003oooooool01?ooo`0306Kooooooooo02Woool00`1Vooooooooo`16
oooo001Qoooo00<0I_ooooooool0:_ooo`0306Kooooooooo01?oool200001Oooo`0306Kooooooooo
02Woool00`1Vooooooooo`16oooo001Qoooo00<0I_ooooooool0:oooo`0306Kooooooooo01;oool0
0`000?ooooooo`03oooo00<0I_ooooooool0:_ooo`0306Kooooooooo04Koool0063oool00`1Voooo
ooooo`0]oooo00<0I_ooooooool04Oooo`030000oooooooo00;oool00`1Vooooooooo`0[oooo00<0
I_ooooooool0A_ooo`00H?ooo`0306Kooooooooo02koool00`1Vooooooooo`0@oooo00<0003ooooo
ool00_ooo`0306Kooooooooo02_oool00`1Vooooooooo`16oooo001Poooo00<0I_ooooooool0;ooo
o`0306Kooooooooo00ooool01@000?ooooooooooo`1Vo`0^oooo00<0I_ooooooool0A_ooo`00Gooo
o`0306Kooooooooo037oool00`1Vooooooooo`0>oooo0P000003oooo06Kooooo02koool00`1Voooo
ooooo`16oooo001Ooooo00<0I_ooooooool0<_ooo`0306Kooooooooo00goool010000?ooooooo`1V
obooool00`1Vooooooooo`16oooo001Noooo00<0I_ooooooool0=?ooo`0306Kooooooooo00coool0
0`000?ooo`1Vo`0`oooo00<0I_ooooooool0A_ooo`00G_ooo`0306Kooooooooo03Coool00`1Voooo
ooooo`0<oooo00<00000I_ooool0<?ooo`0306Kooooooooo04Koool005koool00`1Vooooooooo`0e
oooo00<0I_ooooooool02oooo`03000006Kooooo033oool00`1Vooooooooo`16oooo001Moooo00<0
I_ooooooool0=oooo`80I_l;oooo0P00037oool00`1Vooooooooo`16oooo001Moooo00<0I_oooooo
ool0>Oooo`0306Kooooooooo00Ooool00`1Vo`000?ooo`0aoooo00<0I_ooooooool0A_ooo`00GOoo
o`0306Kooooooooo03[oool206Ko1Oooo`80I_l00oooo`000?ooo`0aoooo00<0I_ooooooool0A_oo
o`00G?ooo`0306Kooooooooo03goool606Ko0_ooo`030000oooooooo033oool00`1Vooooooooo`16
oooo001Loooo00<0I_ooooooool0AOooo`030000oooooooo033oool00`1Vooooooooo`16oooo001K
oooo00<0I_ooooooool0A_ooo`80000aoooo00<0I_ooooooool0A_ooo`00Foooo`0306Kooooooooo
04Koool00`000?ooooooo`0`oooo00<0I_ooooooool0A_ooo`00F_ooo`0306Kooooooooo03?oool2
00001?ooo`800003oooo1@0000Coool00`000?ooooooo`0`oooo00<0I_ooooooool0A_ooo`00FOoo
o`0306Kooooooooo03?oool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003ooooo
ool0<?ooo`0306Kooooooooo04Koool005Woool00`1Vooooooooo`0coooo00@0003oooooool0000:
oooo00<0003oooooool01?ooo`80000aoooo00<0I_ooooooool0A_ooo`00F?ooo`0306Kooooooooo
02koool400000_ooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`0`
oooo00<0I_ooooooool0A_ooo`00Eoooo`0306Kooooooooo03Goool010000?ooooooo`0000[oool0
0`000?ooooooo`04oooo00<0003oooooool0<?ooo`0306Kooooooooo04Koool005Koool00`1Voooo
ooooo`0goooo0P0000[oool200001_ooo`030000oooooooo033oool00`1Vooooooooo`16oooo001F
oooo00<0I_ooooooool0Boooo`030000oooooooo033oool00`1Vooooooooo`16oooo001Eoooo00<0
I_ooooooool0C?ooo`80000aoooo00<0I_ooooooool0A_ooo`00E?ooo`0306Kooooooooo04goool0
0`000?ooooooo`0`oooo00<0I_ooooooool0A_ooo`00Doooo`0306Kooooooooo04koool00`000?oo
ooooo`0`oooo00<0I_ooooooool0A_ooo`00D_ooo`0306Kooooooooo04ooool00`000?ooooooo`0`
oooo00<0I_ooooooool0A_ooo`00D_ooo`0306Kooooooooo04ooool00`000?ooooooo`0`oooo00<0
I_ooooooool0A_ooo`00DOooo`0306Kooooooooo053oool20000<Oooo`0306Kooooooooo04Koool0
053oool00`1Vooooooooo`1Aoooo00<0003oooooool0<?ooo`0306Kooooooooo04Koool004ooool0
0`1Vooooooooo`1Boooo00<0003oooooool0<?ooo`0306Kooooooooo04Koool004koool00`1Voooo
ooooo`1Coooo00<0003oooooool0<?ooo`0306Kooooooooo04Koool002Woool300008Oooo`0306Ko
oooooooo00Coool300009?ooo`@0000Uoooo00<0003oooooool09?ooo`@00008oooo00<0I_oooooo
ool07?ooo`<0000Woooo000Yoooo00@0003oooooool0000Ooooo00<0I_ooooooool01_ooo`030000
oooooooo02?oool00`000?ooooooo`0Voooo0P0002Goool00`000?ooooooo`09oooo00<0I_oooooo
ool07Oooo`030000oooooooo02Koool002Woool010000?ooooooo`0001goool206Ko1_ooo`D0000U
oooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`08oooo00<0I_oooooo
ool06_ooo`D0000Woooo000Soooo100000;oool300007?ooo`80I_l2oooo100000;oool010000?oo
ooooo`0001ooool400001?ooo`030000oooooooo02Coool00`000?ooooooo`0Voooo00<0003ooooo
ool01oooo`0306Kooooooooo01[oool010000?ooooooo`0002Soool002[oool00`000?ooooooo`0I
oooo0P1Vo`_oool00`000?ooo`00000Uoooo00@0003oooooool0000Uoooo00<0003oooooool09?oo
o`040000oooooooo00002?ooo`0306Kooooooooo01_oool00`000?ooo`00000Xoooo000Zoooo0`00
01Koool306Ko3_ooo`80000Voooo0P0002Koool00`000?ooooooo`0Uoooo0P0000Woool00`1Voooo
ooooo`0Loooo0P0002Soool0043oool306KoHOooo`80000aoooo00<0I_ooooooool0A_ooo`00?_oo
o`80I_mToooo00<0003oooooool0<?ooo`0306Kooooooooo04Koool003[oool406KoI_ooo`030000
oooooooo033oool00`1Vooooooooo`16oooo000eoooo1@1Vof[oool00`000?ooooooo`0`oooo00<0
I_ooooooool0A_ooo`009oooo`h0I_m_oooo00<0003oooooool0<?ooo`0306Kooooooooo04Koool0
00gooooo00001P0000koool001?oool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooo000000`00005<ol000<0000co`0c
o`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`0023?o00030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`0Boooo000Xoooo00<0
003oooooool09_ooo`030000oooooooo027oool60000:C?o00030000oooooooo02Koool00`000?oo
ooooo`07oooo00?o09Woooooool07?ooo`030000oooooooo02Ooool007[oool300009c?o00030000
oooooooo033oool00ol0VOooooooo`16oooo001moooo0P0002Dco`000`000?ooooooo`0`oooo00?o
09Woooooool0A_ooo`00Ooooo`030000<ol0<ol0028co`020000<Oooo`03o`2Ioooooooo04Koool0
083oool00`0003?o03?o000Q<ol000<0003oooooool0<?ooo`03o`2Ioooooooo04Koool0087oool2
00008C?o00030000oooooooo033oool00ol0VOooooooo`16oooo0023oooo00<0000co`0co`007S?o
00030000oooooooo033oool00ol0VOooooooo`16oooo0023oooo00<0000co`0co`007S?o00030000
oooooooo033oool00ol0VOooooooo`16oooo0024oooo00<0000co`0co`007C?o0080000aoooo00?o
09Woooooool0A_ooo`00QOooo`030000<ol0<ol001`co`000`000?ooooooo`0`oooo00?o09Wooooo
ool0A_ooo`00Q_ooo`030000<ol0<ol001/co`000`000?ooooooo`0`oooo00?o09Woooooool0A_oo
o`00Q_ooo`030000<ol0<ol001/co`000`000?ooooooo`0`oooo00?o09Woooooool0A_ooo`00Qooo
oadco`1loooo0028oooo73?o07coool008SooolL<ol0O?ooo`00R?oooa`co`1loooo0029oooo6c?o
07coool007coool00`000?ooooooo`0:oooo63?o00030000<ol0<ol007coool007_oool00`000?oo
ooooo`08oooo00@0003ooooooooooolH<ol000<0000co`3oool0Noooo`00Noooo`030000oooooooo
00;oool200001?ooo`040000oooooooooooo1S?o00800004<ol00P0000@co`02000013?o00030000
<ol0oooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`040000
oooooooooooo13?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0oooo
07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool02Oooo`Hco`000`0003?o03?o000:
<ol000<0000co`0co`000S?o00030000oooooooo07[oool007_oool00`000?ooooooo`0500002?oo
o`Lco`000`0003?o03?o0007<ol00P0000@co`000`0003?o0?ooo`1koooo001koooo00D0003ooooo
ooooool000003?ooo`<co`00100003?o03?o000000Tco`000`0003?o03?o0003<ol000<0000co`3o
ool0Noooo`00O?ooo`030000oooooooo00goool4<ol00P0000Xco`0300000S?o00030000<ol0<ol0
07coool008cooolH<ol0O?ooo`00S?oooaPco`1loooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.26171 .57049 L
.30316 .57049 L
.34309 .57049 L
.3815 .57049 L
.42237 .57049 L
.46172 .57049 L
.49955 .57049 L
.53984 .57049 L
.57861 .57049 L
.61984 .57049 L
.65954 .57049 L
.69774 .57049 L
.73838 .57049 L
.77751 .57049 L
.7878 .57049 L
.79892 .57049 L
.80403 .57049 L
.80943 .57049 L
.81404 .57049 L
.8153 .57049 L
.81599 .57049 L
.81665 .57049 L
s
.81665 .57049 m
.81666 .61803 L
s
0 .4 1 r
.02381 .56886 m
.04262 .56822 L
.06244 .56725 L
.07286 .56659 L
.08255 .56585 L
.09388 .56482 L
.10458 .56362 L
.125 .56061 L
.14357 .55673 L
.16355 .55085 L
.18199 .54321 L
.20071 .53241 L
.21136 .52445 L
.22134 .51549 L
.24158 .49159 L
.26011 .46073 L
.27909 .41655 L
.28984 .38406 L
.29982 .34779 L
.32034 .24946 L
.32939 .19329 L
.33433 .15855 L
.33895 .12323 L
.34013 .11369 L
.34125 .10447 L
.34255 .10902 L
.34373 .11331 L
.34897 .13207 L
.35819 .16377 L
.37901 .22911 L
.41734 .3273 L
.43673 .36687 L
.45813 .40354 L
.47861 .43238 L
.49739 .45382 L
.51674 .47106 L
.5269 .47807 L
.5325 .48129 L
.5376 .48378 L
.54218 .48564 L
.54714 .48722 L
.54987 .48788 L
.55107 .48812 L
.55239 .48835 L
.55354 .48851 L
.55479 .48865 L
.55611 .48876 L
.55734 .48883 L
.55856 .48885 L
.55969 .48883 L
Mistroke
.56094 .48877 L
.56163 .48872 L
.56226 .48866 L
.56342 .48852 L
.56467 .48832 L
.56693 .48782 L
.56916 .48714 L
.5715 .48622 L
.5757 .48394 L
.57826 .48211 L
.58068 .48006 L
.58521 .47604 L
.59538 .46641 L
.61373 .44681 L
.65211 .39527 L
.69294 .32253 L
.73226 .2349 L
.77007 .14062 L
.79108 .09033 L
.80027 .07066 L
.80514 .06119 L
.81032 .05197 L
.81296 .04767 L
.81426 .04567 L
.81545 .0439 L
.81654 .04234 L
.81769 .57049 L
.81884 .57049 L
.82011 .57049 L
.8292 .57049 L
.84906 .57049 L
.88945 .57049 L
.92833 .57049 L
.96966 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`0joooo00<0
I_ooooooool0??ooo`00Y?ooo`030000oooooooo03[oool00`1Vooooooooo`0loooo002Toooo00<0
003oooooool0>Oooo`80I_lnoooo002Toooo0P0003[oool206Ko?_ooo`00Y?ooo`030000oooooooo
03Soool00`1Vooooo`1Vo`0noooo002Toooo00<0003oooooool0>?ooo`0306Kooooo06Ko03koool0
0:Coool00`000?ooooooo`0goooo00@0I_ooooooool0I_lnoooo002Toooo00<0003oooooool0=_oo
o`0506Kooooooooooooo06Ko03koool00:Coool20000=oooo`0506Kooooooooooooo06Ko03koool0
0:Coool00`000?ooooooo`0eoooo00<0I_ooooooool00_ooo`0306Kooooooooo03coool00:Coool0
0`000?ooooooo`0eoooo00<0I_ooooooool00_ooo`0306Kooooooooo03coool0093oool200001?oo
o`800004oooo0P0000Koool00`000?ooooooo`0doooo00<0I_ooooooool00oooo`0306Kooooooooo
03coool008ooool010000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`0d
oooo00<0I_ooooooool00oooo`0306Kooooooooo03coool008ooool010000?ooooooo`0000_oool0
0`000?ooooooo`03oooo0P0003Goool00`1Vooooooooo`03oooo00<0I_ooooooool0??ooo`00ROoo
o`@00002oooo00@0003oooooool00009oooo0P0000Koool00`000?ooooooo`0coooo00<0I_oooooo
ool01?ooo`0306Kooooooooo03coool008ooool010000?ooooooo`0000Woool00`000?ooooooo`05
oooo00<0003oooooool0<oooo`0306Kooooooooo00Coool00`1Vooooooooo`0loooo001Voooo00<0
I_ooooooool09oooo`80000:oooo0`0000Goool00`000?ooooooo`0boooo00<0I_ooooooool01Ooo
o`0306Kooooooooo03coool006Goool206Ko?Oooo`030000oooooooo03;oool00`1Vooooooooo`05
oooo00<0I_ooooooool0??ooo`00IOooo`80I_lmoooo0P0003;oool00`1Vooooooooo`06oooo00<0
I_ooooooool0??ooo`00IOooo`80I_lmoooo00<0003oooooool0<Oooo`0306Kooooooooo00Koool0
0`1Vooooooooo`0loooo001Uoooo00<0I_ooool0I_l0??ooo`030000oooooooo033oool00`1Voooo
ooooo`07oooo00<0I_ooooooool0??ooo`00IOooo`0306Kooooo06Ko03coool00`000?ooooooo`0`
oooo00<0I_ooooooool01oooo`0306Kooooooooo03coool006Goool0101Vooooooooo`1Voc_oool0
0`000?ooooooo`0_oooo00<0I_ooooooool02?ooo`0306Kooooooooo03coool006Goool0101Voooo
ooooo`1Voc_oool20000<?ooo`0306Kooooooooo00Soool00`1Vooooooooo`0loooo001Uoooo00@0
I_ooooooool0I_lkoooo00<0003oooooool0;_ooo`0306Kooooooooo00Woool00`1Vooooooooo`0l
oooo001Uoooo00@0I_ooooooool0I_lkoooo00<0003oooooool0;_ooo`0306Kooooooooo00Woool0
0`1Vooooooooo`0loooo001Toooo00<0I_ooooooool00_ooo`0306Kooooooooo03Soool00`000?oo
ooooo`0^oooo00<0I_ooooooool02Oooo`0306Kooooooooo03coool006Coool00`1Vooooooooo`02
oooo00<0I_ooooooool0>?ooo`030000oooooooo02goool00`1Vooooooooo`0:oooo00<0I_oooooo
ool0??ooo`00I?ooo`0306Kooooooooo00;oool00`1Vooooooooo`0hoooo0P0002koool00`1Voooo
ooooo`0:oooo00<0I_ooooooool0??ooo`00I?ooo`0306Kooooooooo00;oool00`1Vooooooooo`0h
oooo00<0003oooooool0;Oooo`0306Kooooooooo00[oool00`1Vooooooooo`0loooo001Toooo00<0
I_ooooooool00oooo`0306Kooooooooo03Ooool00`000?ooooooo`0/oooo00<0I_ooooooool02ooo
o`0306Kooooooooo03coool006Coool00`1Vooooooooo`03oooo00<0I_ooooooool0=oooo`030000
oooooooo02coool00`1Vooooooooo`0;oooo00<0I_ooooooool0??ooo`00I?ooo`0306Kooooooooo
00?oool00`1Vooooooooo`0goooo00<0003oooooool0:oooo`0306Kooooooooo00coool00`1Voooo
ooooo`0loooo001Soooo00<0I_ooooooool01Oooo`0306Kooooooooo03Koool20000;?ooo`0306Ko
oooooooo00coool00`1Vooooooooo`0loooo001Soooo00<0I_ooooooool01Oooo`0306Kooooooooo
03Koool00`000?ooooooo`0[oooo00<0I_ooooooool03?ooo`0306Kooooooooo03coool006?oool0
0`1Vooooooooo`05oooo00<0I_ooooooool0=_ooo`030000oooooooo02[oool00`1Vooooooooo`0=
oooo00<0I_ooooooool0??ooo`00Hoooo`0306Kooooooooo00Goool00`1Vooooooooo`0Roooo0P00
00Coool200001Oooo`<00004oooo00<0003oooooool0:_ooo`0306Kooooooooo00goool00`1Voooo
ooooo`0loooo001Roooo00<0I_ooooooool01oooo`0306Kooooooooo023oool010000?ooooooo`00
00_oool00`000?ooooooo`03oooo00<0003oooooool0:_ooo`0306Kooooooooo00goool00`1Voooo
ooooo`0loooo001Roooo00<0I_ooooooool01oooo`0306Kooooooooo023oool010000?ooooooo`00
00Soool500001?ooo`80000Zoooo00<0I_ooooooool03_ooo`0306Kooooooooo03coool006;oool0
0`1Vooooooooo`07oooo00<0I_ooooooool06_ooo`@00002oooo00@0003oooooool00008oooo00@0
003oooooool00005oooo00<0003oooooool0:Oooo`0306Kooooooooo00koool00`1Vooooooooo`0l
oooo001Roooo00<0I_ooooooool02?ooo`0306Kooooooooo01ooool010000?ooooooo`0000Woool0
0`000?ooo`000005oooo00<0003oooooool0:Oooo`0306Kooooooooo00koool00`1Vooooooooo`0l
oooo001Roooo00<0I_ooooooool02?ooo`0306Kooooooooo023oool200002oooo`800005oooo00<0
003oooooool0:?ooo`0306Kooooooooo00ooool00`1Vooooooooo`0loooo001Roooo00<0I_oooooo
ool02?ooo`0306Kooooooooo03Coool00`000?ooooooo`0Xoooo00<0I_ooooooool03oooo`0306Ko
oooooooo03coool0067oool00`1Vooooooooo`0:oooo00<0I_ooooooool0<oooo`80000Yoooo00<0
I_ooooooool03oooo`0306Kooooooooo03coool0067oool00`1Vooooooooo`0:oooo00<0I_oooooo
ool0<oooo`030000oooooooo02Ooool00`1Vooooooooo`0@oooo00<0I_ooooooool0??ooo`00HOoo
o`0306Kooooooooo00[oool00`1Vooooooooo`0coooo00<0003oooooool09oooo`0306Kooooooooo
013oool00`1Vooooooooo`0loooo001Qoooo00<0I_ooooooool02_ooo`0306Kooooooooo03?oool0
0`000?ooooooo`0Voooo00<0I_ooooooool04Oooo`0306Kooooooooo03coool0067oool00`1Voooo
ooooo`0;oooo00<0I_ooooooool0<_ooo`030000oooooooo02Koool00`1Vooooooooo`0Aoooo00<0
I_ooooooool0??ooo`00HOooo`0306Kooooooooo00_oool00`1Vooooooooo`0boooo0P0002Ooool0
0`1Vooooooooo`0Aoooo00<0I_ooooooool0??ooo`00HOooo`0306Kooooooooo00_oool00`1Voooo
ooooo`0boooo00<0003oooooool09Oooo`0306Kooooooooo01;oool00`1Vooooooooo`0loooo001Q
oooo00<0I_ooooooool03?ooo`0306Kooooooooo037oool00`000?ooooooo`0Uoooo00<0I_oooooo
ool04_ooo`0306Kooooooooo03coool0063oool00`1Vooooooooo`0=oooo00<0I_ooooooool0<Ooo
o`030000oooooooo02Goool00`1Vooooooooo`0Boooo00<0I_ooooooool0??ooo`00H?ooo`0306Ko
oooooooo00koool00`1Vooooooooo`0`oooo00<0003oooooool09?ooo`0306Kooooooooo01?oool0
0`1Vooooooooo`0loooo001Poooo00<0I_ooooooool03_ooo`0306Kooooooooo033oool200009Ooo
o`0306Kooooooooo01?oool00`1Vooooooooo`0loooo001Poooo00<0I_ooooooool03_ooo`0306Ko
oooooooo033oool00`000?ooooooo`0Soooo00<0I_ooooooool05?ooo`0306Kooooooooo03coool0
063oool00`1Vooooooooo`0?oooo00<0I_ooooooool0;oooo`030000oooooooo02?oool00`1Voooo
ooooo`0Doooo00<0I_ooooooool0??ooo`00H?ooo`0306Kooooooooo00ooool00`1Vooooooooo`0_
oooo00<0003oooooool08_ooo`0306Kooooooooo01Goool00`1Vooooooooo`0loooo001Ooooo00<0
I_ooooooool04?ooo`0306Kooooooooo02ooool00`000?ooooooo`0Roooo00<0I_ooooooool05Ooo
o`0306Kooooooooo03coool005ooool00`1Vooooooooo`0Aoooo00<0I_ooooooool0;_ooo`80000R
oooo00<0I_ooooooool05_ooo`0306Kooooooooo03coool005ooool00`1Vooooooooo`0Aoooo00<0
I_ooooooool0;_ooo`030000oooooooo027oool00`1Vooooooooo`0Foooo00<0I_ooooooool0??oo
o`00Goooo`0306Kooooooooo01;oool00`1Vooooooooo`0]oooo00<0003oooooool08?ooo`0306Ko
oooooooo01Ooool00`1Vooooooooo`0loooo001Ooooo00<0I_ooooooool04_ooo`0306Kooooooooo
01Woool200001?ooo`800004oooo0P0000Koool00`000?ooooooo`0Poooo00<0I_ooooooool05ooo
o`0306Kooooooooo03coool005koool00`1Vooooooooo`0Coooo00<0I_ooooooool06?ooo`040000
oooooooo00002?ooo`040000oooooooo00001Oooo`030000oooooooo01ooool00`1Vooooooooo`0H
oooo00<0I_ooooooool0??ooo`00G_ooo`0306Kooooooooo01Coool00`1Vooooooooo`0Goooo00@0
003oooooool0000:oooo00<0003oooooool01?ooo`80000Poooo00<0I_ooooooool06?ooo`0306Ko
oooooooo03coool005koool00`1Vooooooooo`0Doooo00<0I_ooooooool04Oooo`@00002oooo00@0
003oooooool0000;oooo00<0003oooooool00oooo`030000oooooooo01koool00`1Vooooooooo`0I
oooo00<0I_ooooooool0??ooo`00G_ooo`0306Kooooooooo01Goool00`1Vooooooooo`0Foooo00@0
003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool07_ooo`0306Kooooooooo
01Woool00`1Vooooooooo`0loooo001Noooo00<0I_ooooooool05Oooo`0306Kooooooooo01Ooool2
00002_ooo`800006oooo00<0003oooooool07Oooo`0306Kooooooooo01[oool00`1Vooooooooo`0l
oooo001Moooo00<0I_ooooooool05_ooo`0306Kooooooooo02_oool00`000?ooooooo`0Moooo00<0
I_ooooooool06_ooo`0306Kooooooooo03coool005goool00`1Vooooooooo`0Goooo00<0I_oooooo
ool0:_ooo`80000Moooo00<0I_ooooooool06oooo`0306Kooooooooo03coool005goool00`1Voooo
ooooo`0Goooo00<0I_ooooooool0:_ooo`030000oooooooo01coool00`1Vooooooooo`0Loooo00<0
I_ooooooool0>oooo`00GOooo`0306Kooooooooo01Ooool00`1Vooooooooo`0Zoooo00<0003ooooo
ool06oooo`0306Kooooooooo01goool00`1Vooooooooo`0koooo001Moooo00<0I_ooooooool06?oo
o`0306Kooooooooo02Woool00`000?ooooooo`0Koooo00<0I_ooooooool07Oooo`0306Kooooooooo
03_oool005coool00`1Vooooooooo`0Ioooo00<0I_ooooooool0:Oooo`030000oooooooo01[oool0
0`1Vooooooooo`0Noooo00<0I_ooooooool0>oooo`00G?ooo`0306Kooooooooo01[oool00`1Voooo
ooooo`0Xoooo0P0001_oool00`1Vooooooooo`0Noooo00<0I_ooooooool0>oooo`00G?ooo`0306Ko
oooooooo01[oool00`1Vooooooooo`0Xoooo00<0003oooooool06Oooo`0306Kooooooooo01ooool0
0`1Vooooooooo`0koooo001Loooo00<0I_ooooooool06_ooo`0306Kooooooooo02Soool00`000?oo
ooooo`0Ioooo00<0I_ooooooool07oooo`0306Kooooooooo03_oool005coool00`1Vooooooooo`0K
oooo00<0I_ooooooool09oooo`030000oooooooo01Soool00`1Vooooooooo`0Poooo00<0I_oooooo
ool0>oooo`00Foooo`0306Kooooooooo01coool00`1Vooooooooo`0Woooo00<0003oooooool06?oo
o`0306Kooooooooo023oool00`1Vooooooooo`0koooo001Koooo00<0I_ooooooool07Oooo`0306Ko
oooooooo02Koool200006?ooo`0306Kooooooooo027oool00`1Vooooooooo`0koooo001Koooo00<0
I_ooooooool07Oooo`0306Kooooooooo02Koool00`000?ooooooo`0Goooo00<0I_ooooooool08Ooo
o`0306Kooooooooo03_oool005_oool00`1Vooooooooo`0Noooo00<0I_ooooooool09Oooo`030000
oooooooo01Koool00`1Vooooooooo`0Roooo00<0I_ooooooool0>oooo`00F_ooo`0306Kooooooooo
01ooool00`1Vooooooooo`0Uoooo00<0003oooooool05_ooo`0306Kooooooooo02;oool00`1Voooo
ooooo`0koooo001Joooo00<0I_ooooooool08?ooo`0306Kooooooooo02Coool00`000?ooooooo`0E
oooo00<0I_ooooooool08oooo`0306Kooooooooo03_oool005[oool00`1Vooooooooo`0Poooo00<0
I_ooooooool09?ooo`80000Foooo00<0I_ooooooool08oooo`0306Kooooooooo03_oool005Woool0
0`1Vooooooooo`0Roooo00<0I_ooooooool08oooo`030000oooooooo01Coool00`1Vooooooooo`0T
oooo00<0I_ooooooool0>oooo`00FOooo`0306Kooooooooo02?oool00`1Vooooooooo`0Roooo00<0
003oooooool05?ooo`0306Kooooooooo02Coool00`1Vooooooooo`0koooo001Ioooo00<0I_oooooo
ool08oooo`0306Kooooooooo00koool200001?ooo`800003oooo100000Goool00`000?ooooooo`0C
oooo00<0I_ooooooool09Oooo`0306Kooooooooo03_oool005Woool00`1Vooooooooo`0Toooo00<0
I_ooooooool03?ooo`040000oooooooo00002?ooo`030000oooooooo00Koool00`000?ooooooo`0C
oooo00<0I_ooooooool09Oooo`0306Kooooooooo03_oool005Soool00`1Vooooooooo`0Uoooo00<0
I_ooooooool03?ooo`040000oooooooo00002Oooo`030000oooooooo00Goool200004oooo`0306Ko
oooooooo02Koool00`1Vooooooooo`0koooo001Hoooo00<0I_ooooooool09_ooo`0306Kooooooooo
00Goool400000_ooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`0B
oooo00<0I_ooooooool09_ooo`0306Kooooooooo03_oool005Soool00`1Vooooooooo`0Woooo00<0
I_ooooooool02_ooo`040000oooooooo00002?ooo`040000oooooooo00001Oooo`030000oooooooo
017oool00`1Vooooooooo`0Woooo00<0I_ooooooool0>oooo`00Eoooo`0306Kooooooooo02Soool0
0`1Vooooooooo`0;oooo0P0000[oool200001_ooo`030000oooooooo017oool00`1Vooooooooo`0W
oooo00<0I_ooooooool0>oooo`00Eoooo`0306Kooooooooo02Woool00`1Vooooooooo`0Noooo00<0
003oooooool04?ooo`0306Kooooooooo02Soool00`1Vooooooooo`0koooo001Foooo00<0I_oooooo
ool0:_ooo`0306Kooooooooo01koool200004?ooo`0306Kooooooooo02Woool00`1Vooooooooo`0k
oooo001Foooo00<0I_ooooooool0:oooo`0306Kooooooooo01goool00`000?ooooooo`0>oooo00<0
I_ooooooool0:_ooo`0306Kooooooooo03_oool005Koool00`1Vooooooooo`0/oooo00<0I_oooooo
ool07?ooo`030000oooooooo00koool00`1Vooooooooo`0Zoooo00<0I_ooooooool0>oooo`00EOoo
o`0306Kooooooooo02goool00`1Vooooooooo`0Loooo00<0003oooooool03Oooo`0306Kooooooooo
02_oool00`1Vooooooooo`0koooo001Eoooo00<0I_ooooooool0;_ooo`0306Kooooooooo01_oool0
0`000?ooooooo`0<oooo00<0I_ooooooool0;?ooo`0306Kooooooooo03_oool005Goool00`1Voooo
ooooo`0_oooo00<0I_ooooooool06_ooo`80000<oooo00<0I_ooooooool0;Oooo`0306Kooooooooo
03_oool005Coool00`1Vooooooooo`0aoooo00<0I_ooooooool06Oooo`030000oooooooo00_oool0
0`1Vooooooooo`0]oooo00<0I_ooooooool0>oooo`00E?ooo`0306Kooooooooo037oool00`1Voooo
ooooo`0Ioooo00<0003oooooool02_ooo`0306Kooooooooo02koool00`1Vooooooooo`0koooo001C
oooo00<0I_ooooooool0<oooo`0306Kooooooooo01Soool00`000?ooooooo`09oooo00<0I_oooooo
ool0;oooo`0306Kooooooooo03_oool005?oool00`1Vooooooooo`0doooo00<0I_ooooooool05ooo
o`030000oooooooo00Soool00`1Vooooooooo`0`oooo00<0I_ooooooool0>oooo`00D_ooo`0306Ko
oooooooo03Koool00`1Vooooooooo`0Foooo0P0000Woool00`1Vooooooooo`0`oooo00<0I_oooooo
ool0>oooo`00D_ooo`0306Kooooooooo03Koool00`1Vooooooooo`0Foooo00<0003oooooool01ooo
o`0306Kooooooooo037oool00`1Vooooooooo`0koooo001Boooo00<0I_ooooooool0=oooo`0306Ko
oooooooo01Goool00`000?ooooooo`06oooo00<0I_ooooooool0<_ooo`0306Kooooooooo03_oool0
057oool00`1Vooooooooo`0ioooo00<0I_ooooooool05?ooo`030000oooooooo00Goool00`1Voooo
ooooo`0coooo00<0I_ooooooool0>oooo`00DOooo`0306Kooooooooo03[oool00`1Vooooooooo`0C
oooo00<0003oooooool01?ooo`0306Kooooooooo03Coool00`1Vooooooooo`0koooo001@oooo00<0
I_ooooooool0??ooo`0306Kooooooooo01;oool200001?ooo`0306Kooooooooo03Goool00`1Voooo
ooooo`0koooo001@oooo00<0I_ooooooool0?Oooo`80I_lBoooo00<0003oooooool00_ooo`0306Ko
oooooooo03Koool00`1Vooooooooo`0koooo001?oooo00<0I_ooooooool0?_ooo`800000101Voooo
ooooooooo`800003oooo1@0000Coool01@000?ooooooooooo`1Vo`0ioooo00<0I_ooooooool0>ooo
o`00Coooo`0306Kooooooooo03goool01@000?ooooooo`00001Vo`09oooo00<0003oooooool01?oo
o`040000oooooooo06Ko>_ooo`0306Kooooooooo03_oool004koool00`1Vooooooooo`0noooo00D0
003oooooool0003oool00P1Vo`Ooool00`000?ooooooo`04oooo0P00000306Kooooooooo03Woool0
0`1Vooooooooo`0koooo001>oooo00<0I_ooooooool0>?ooo`@00002oooo00@0003oooooool00003
oooo00<0I_ooooooool01?ooo`030000oooooooo00Coool00`00001Vooooo`0koooo00<0I_oooooo
ool0>oooo`00COooo`0306Kooooooooo03ooool010000?ooooooo`0000Coool00`1Vooooooooo`03
oooo00<0003oooooool00oooo`0306Ko0000oooo03coool00`1Vooooooooo`0koooo001=oooo00<0
I_ooooooool0@?ooo`800006oooo0`1Vo`03oooo0000000000Coool206Ko00<0003oooooool0>ooo
o`0306Kooooooooo03_oool004coool00`1Vooooooooo`1<oooo1`1Vo`;oool00`000?ooooooo`0k
oooo00<0I_ooooooool0>oooo`00C?ooo`0306Kooooooooo05Goool20000??ooo`0306Kooooooooo
03_oool004_oool00`1Vooooooooo`1Foooo00<0003oooooool0>oooo`0306Kooooooooo03_oool0
04[oool00`1Vooooooooo`1Goooo00<0003oooooool0>oooo`0306Kooooooooo03_oool004Woool0
0`1Vooooooooo`1Hoooo00<0003oooooool0>oooo`0306Kooooooooo03_oool004Soool00`1Voooo
ooooo`1Ioooo00<0003oooooool0>oooo`0306Kooooooooo03_oool004Ooool00`1Vooooooooo`1J
oooo0P0003coool00`1Vooooooooo`0koooo0016oooo00<0I_ooooooool0Foooo`030000oooooooo
03_oool00`1Vooooooooo`0koooo0015oooo00<0I_ooooooool0G?ooo`030000oooooooo03_oool0
0`1Vooooooooo`0koooo0014oooo00<0I_ooooooool0GOooo`030000oooooooo03_oool00`1Voooo
ooooo`0koooo000Yoooo0`0001Koool206Ko4?ooo`<0000Toooo100002Goool00`000?ooooooo`0T
oooo100001?oool00`1Vooooooooo`0Aoooo0`0002Ooool002Woool010000?ooooooo`0001Coool0
0`1Vooooooooo`0Aoooo00<0003oooooool08oooo`030000oooooooo02Koool200009Oooo`030000
oooooooo01Coool00`1Vooooooooo`0Boooo00<0003oooooool09_ooo`00:Oooo`040000oooooooo
00004_ooo`80I_lAoooo1@0002Goool00`000?ooooooo`0Uoooo00<0003oooooool09Oooo`030000
oooooooo01?oool00`1Vooooooooo`0?oooo1@0002Ooool002?oool400000_ooo`<0000Aoooo0P1V
o`goool400000_ooo`040000oooooooo00007oooo`@00004oooo00<0003oooooool09?ooo`030000
oooooooo02Koool00`000?ooooooo`0Boooo00<0I_ooooooool03oooo`040000oooooooo0000:?oo
o`00:_ooo`030000oooooooo00koool206Ko5_ooo`030000oooo000002Goool010000?ooooooo`00
02Goool00`000?ooooooo`0Toooo00@0003oooooool0000Coooo00<0I_ooooooool04?ooo`030000
oooo000002Soool002[oool300003?ooo`80I_lIoooo0P0002Koool200009_ooo`030000oooooooo
02Goool200005?ooo`0306Kooooooooo017oool20000:?ooo`00=_ooo`<0I_m[oooo0P0003coool0
0`1Vooooooooo`0koooo000doooo0P1Vofkoool00`000?ooooooo`0koooo00<0I_ooooooool0>ooo
o`00<?ooo`@0I_m`oooo00<0003oooooool0>oooo`0306Kooooooooo03_oool002Ooool906KoM?oo
o`030000oooooooo03_oool00`1Vooooooooo`0koooo000Koooo301Voggoool00`000?ooooooo`0k
oooo00<0I_ooooooool0>oooo`003Oooool0000600003_ooo`004oooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oool0
0000300000Dco`000`0003?o03?o0008<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0008<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000
oooooooo01;oool002Soool00`000?ooooooo`0Voooo00<0003oooooool08Oooo`H0000Y<ol000<0
003oooooool09_ooo`030000oooooooo01;oool00ol0VOooooooo`0Aoooo00<0003oooooool09ooo
o`00N_ooo`<0000W<ol000<0003oooooool0>oooo`03o`2Ioooooooo03_oool007goool200009C?o
00030000oooooooo03_oool00ol0VOooooooo`0koooo001ooooo00<0000co`0co`008S?o0080000l
oooo00?o09Woooooool0>oooo`00P?ooo`030000<ol0<ol0024co`000`000?ooooooo`0koooo00?o
09Woooooool0>oooo`00POooo`80000Q<ol000<0003oooooool0>oooo`03o`2Ioooooooo03_oool0
08?oool00`0003?o03?o000N<ol000<0003oooooool0>oooo`03o`2Ioooooooo03_oool008?oool0
0`0003?o03?o000N<ol000<0003oooooool0>oooo`03o`2Ioooooooo03_oool008Coool00`0003?o
03?o000M<ol00P0003coool00ol0VOooooooo`0koooo0025oooo00<0000co`0co`0073?o00030000
oooooooo03_oool00ol0VOooooooo`0koooo0026oooo00<0000co`0co`006c?o00030000oooooooo
03_oool00ol0VOooooooo`0koooo0026oooo00<0000co`0co`006c?o00030000oooooooo03_oool0
0ol0VOooooooo`0koooo0027oooo7C?o07coool008SooolL<ol0O?ooo`00R?oooa`co`1loooo0028
oooo73?o07coool008WooolK<ol0O?ooo`00Ooooo`030000oooooooo00OooolE<ol000<0000co`0c
o`000c?o07coool007koool00`000?ooooooo`08oooo00<0000co`0co`004c?o00030000<ol0<ol0
008co`1loooo001noooo00<0003oooooool00_ooo`800004oooo00<0000co`0co`0023?o00<00002
<ol00P0000@co`000`0003?o03?o0002<ol0O?ooo`00O_ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0000co`0co`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0002
<ol0O?ooo`00OOooo`030000oooooooo00;oool00`000?ooooooo`06oooo1c?o00D00009<ol000@0
000co`0co`0co`1loooo001noooo00<0003oooooool01@0000Goool7<ol000@0000co`0co`000009
<ol000<0000co`0co`000S?o07coool007koool01@000?ooooooooooo`000009oooo1c?o00030000
<ol0000000Tco`000`0003?o03?o0002<ol0O?ooo`00Ooooo`030000oooooooo00[oool8<ol00P00
00Pco`000`0003?o03?o0003<ol0O?ooo`00S?oooaPco`1loooo002<oooo63?o07coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.26171 .57049 L
.30316 .57049 L
.34309 .57049 L
.3815 .57049 L
.42237 .57049 L
.46172 .57049 L
.49955 .57049 L
.53984 .57049 L
.57861 .57049 L
.61984 .57049 L
.65954 .57049 L
.69774 .57049 L
.73838 .57049 L
.77751 .57049 L
.79749 .57049 L
.81909 .57049 L
.82924 .57049 L
.83996 .57049 L
.84911 .57049 L
.85162 .57049 L
.85431 .57049 L
.85561 .57049 L
.85685 .57049 L
s
.85685 .57049 m
.85685 .61803 L
s
0 .4 1 r
.02381 .56719 m
.04262 .56588 L
.06244 .56392 L
.07286 .56258 L
.08255 .56109 L
.09388 .55898 L
.10458 .55656 L
.125 .55045 L
.14357 .54259 L
.16355 .53066 L
.18199 .51516 L
.20071 .49325 L
.21136 .47711 L
.22134 .45894 L
.24158 .41047 L
.26011 .34789 L
.27909 .25828 L
.28984 .19238 L
.29504 .1557 L
.29732 .13851 L
.29861 .12843 L
.29982 .11881 L
.30101 .10912 L
.30229 .10691 L
.30299 .10947 L
.30365 .11189 L
.30489 .11639 L
.31039 .13594 L
.32034 .16988 L
.33895 .22803 L
.37728 .32667 L
.41806 .40375 L
.43831 .43308 L
.45733 .45602 L
.47572 .47445 L
.49508 .49021 L
.50472 .49673 L
.51526 .50286 L
.52478 .50748 L
.53376 .51099 L
.53869 .51253 L
.54404 .51387 L
.5464 .51434 L
.5489 .51476 L
.55103 .51505 L
.55215 .51517 L
.55337 .51528 L
.5541 .51533 L
.55477 .51537 L
.55547 .51541 L
Mistroke
.5561 .51544 L
.55731 .51546 L
.55859 .51547 L
.55932 .51545 L
.55998 .51543 L
.56071 .5154 L
.56148 .51535 L
.56278 .51525 L
.5642 .51509 L
.56673 .5147 L
.56944 .5141 L
.572 .51335 L
.57432 .51249 L
.57915 .5101 L
.58426 .50695 L
.59345 .50091 L
.61422 .48526 L
.65203 .4484 L
.69228 .39451 L
.73102 .32576 L
.77221 .23426 L
.81189 .13529 L
.83189 .0878 L
.84061 .06934 L
.85005 .05189 L
.85261 .04773 L
.85401 .04557 L
.85531 .04364 L
.85643 .04205 L
.85763 .57049 L
.85831 .57049 L
.85895 .57049 L
.86016 .57049 L
.8697 .57049 L
.89066 .57049 L
.92896 .57049 L
.96971 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`14oooo0P1V
oc?oool00:Coool00`000?ooooooo`14oooo0P1Voc?oool00:Coool00`000?ooooooo`13oooo00<0
I_ooool0I_l0<oooo`00Y?ooo`800014oooo00<0I_ooool0I_l0<oooo`00Y?ooo`030000oooooooo
04;oool0101Vooooooooo`1Voc?oool00:Coool00`000?ooooooo`12oooo00@0I_ooooooool0I_lc
oooo002Toooo00<0003oooooool0@Oooo`0506Kooooooooooooo06Ko03?oool00:Coool00`000?oo
ooooo`11oooo00D0I_ooooooooooool0I_l0<oooo`00Y?ooo`800011oooo00<0I_ooooooool00_oo
o`0306Kooooooooo037oool00:Coool00`000?ooooooo`0ooooo00<0I_ooooooool00oooo`0306Ko
oooooooo037oool00:Coool00`000?ooooooo`0ooooo00<0I_ooooooool00oooo`0306Kooooooooo
037oool0093oool200001?ooo`800004oooo0P0000Koool00`000?ooooooo`0noooo00<0I_oooooo
ool01?ooo`0306Kooooooooo037oool008ooool010000?ooooooo`0000Soool010000?ooooooo`00
00Goool00`000?ooooooo`0noooo00<0I_ooooooool01?ooo`0306Kooooooooo037oool008ooool0
10000?ooooooo`0000_oool00`000?ooooooo`03oooo0P0003koool00`1Vooooooooo`05oooo00<0
I_ooooooool0<Oooo`00ROooo`@00002oooo00@0003oooooool00009oooo0P0000Koool00`000?oo
ooooo`0moooo00<0I_ooooooool01Oooo`0306Kooooooooo037oool008ooool010000?ooooooo`00
00Woool00`000?ooooooo`05oooo00<0003oooooool0??ooo`0306Kooooooooo00Koool00`1Voooo
ooooo`0aoooo001Koooo00<0I_ooooooool0<_ooo`80000:oooo0`0000Goool00`000?ooooooo`0l
oooo00<0I_ooooooool01_ooo`0306Kooooooooo037oool005_oool206KoAoooo`030000oooooooo
03coool00`1Vooooooooo`06oooo00<0I_ooooooool0<Oooo`00Foooo`80I_m7oooo0P0003coool0
0`1Vooooooooo`07oooo00<0I_ooooooool0<Oooo`00Foooo`80I_m7oooo00<0003oooooool0>ooo
o`0306Kooooooooo00Ooool00`1Vooooooooo`0aoooo001Koooo0P1VodOoool00`000?ooooooo`0k
oooo00<0I_ooooooool01oooo`0306Kooooooooo037oool005[oool0101Vooooooooo`1VodKoool0
0`000?ooooooo`0joooo00<0I_ooooooool02?ooo`0306Kooooooooo037oool005[oool0101Voooo
ooooo`1VodKoool00`000?ooooooo`0joooo00<0I_ooooooool02?ooo`0306Kooooooooo037oool0
05[oool01@1Vooooooooooooo`1Vo`15oooo0P0003[oool00`1Vooooooooo`09oooo00<0I_oooooo
ool0<Oooo`00F_ooo`0506Kooooooooooooo06Ko04Goool00`000?ooooooo`0ioooo00<0I_oooooo
ool02Oooo`0306Kooooooooo037oool005[oool01@1Vooooooooooooo`1Vo`15oooo00<0003ooooo
ool0>Oooo`0306Kooooooooo00Woool00`1Vooooooooo`0aoooo001Joooo00D0I_ooooooooooool0
I_l0AOooo`030000oooooooo03Soool00`1Vooooooooo`0:oooo00<0I_ooooooool0<Oooo`00F_oo
o`0306Kooooooooo00;oool00`1Vooooooooo`12oooo00<0003oooooool0>?ooo`0306Kooooooooo
00[oool00`1Vooooooooo`0aoooo001Joooo00<0I_ooooooool00_ooo`0306Kooooooooo04;oool2
0000>?ooo`0306Kooooooooo00_oool00`1Vooooooooo`0aoooo001Joooo00<0I_ooooooool00_oo
o`0306Kooooooooo04;oool00`000?ooooooo`0goooo00<0I_ooooooool02oooo`0306Kooooooooo
037oool005[oool00`1Vooooooooo`02oooo00<0I_ooooooool0@_ooo`030000oooooooo03Ooool0
0`1Vooooooooo`0;oooo00<0I_ooooooool0<Oooo`00F_ooo`0306Kooooooooo00?oool00`1Voooo
ooooo`11oooo00<0003oooooool0=_ooo`0306Kooooooooo00coool00`1Vooooooooo`0aoooo001I
oooo00<0I_ooooooool01?ooo`0306Kooooooooo047oool00`000?ooooooo`0foooo00<0I_oooooo
ool03?ooo`0306Kooooooooo037oool005Woool00`1Vooooooooo`04oooo00<0I_ooooooool0@Ooo
o`80000goooo00<0I_ooooooool03?ooo`0306Kooooooooo037oool005Woool00`1Vooooooooo`04
oooo00<0I_ooooooool0@Oooo`030000oooooooo03Goool00`1Vooooooooo`0=oooo00<0I_oooooo
ool0<Oooo`00FOooo`0306Kooooooooo00Goool00`1Vooooooooo`10oooo00<0003oooooool0=Ooo
o`0306Kooooooooo00goool00`1Vooooooooo`0aoooo001Ioooo00<0I_ooooooool01Oooo`0306Ko
oooooooo02coool200001?ooo`800005oooo0`0000Coool00`000?ooooooo`0doooo00<0I_oooooo
ool03_ooo`0306Kooooooooo037oool005Soool00`1Vooooooooo`06oooo00<0I_ooooooool0:ooo
o`040000oooooooo00002oooo`030000oooooooo00?oool00`000?ooooooo`0doooo00<0I_oooooo
ool03_ooo`0306Kooooooooo037oool005Soool00`1Vooooooooo`07oooo00<0I_ooooooool0:_oo
o`040000oooooooo00002?ooo`D00004oooo0P0003Goool00`1Vooooooooo`0>oooo00<0I_oooooo
ool0<Oooo`00F?ooo`0306Kooooooooo00Ooool00`1Vooooooooo`0Toooo100000;oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`0coooo00<0I_ooooooool03ooo
o`0306Kooooooooo037oool005Soool00`1Vooooooooo`07oooo00<0I_ooooooool0:_ooo`040000
oooooooo00002Oooo`030000oooo000000Goool00`000?ooooooo`0coooo00<0I_ooooooool03ooo
o`0306Kooooooooo037oool005Soool00`1Vooooooooo`08oooo00<0I_ooooooool0:_ooo`80000;
oooo0P0000Goool00`000?ooooooo`0boooo00<0I_ooooooool04?ooo`0306Kooooooooo037oool0
05Ooool00`1Vooooooooo`09oooo00<0I_ooooooool0?_ooo`030000oooooooo03;oool00`1Voooo
ooooo`0@oooo00<0I_ooooooool0<Oooo`00Eoooo`0306Kooooooooo00Woool00`1Vooooooooo`0n
oooo0P0003?oool00`1Vooooooooo`0@oooo00<0I_ooooooool0<Oooo`00Eoooo`0306Kooooooooo
00[oool00`1Vooooooooo`0moooo00<0003oooooool0<Oooo`0306Kooooooooo017oool00`1Voooo
ooooo`0aoooo001Goooo00<0I_ooooooool02_ooo`0306Kooooooooo03goool00`000?ooooooo`0a
oooo00<0I_ooooooool04Oooo`0306Kooooooooo037oool005Ooool00`1Vooooooooo`0:oooo00<0
I_ooooooool0?Oooo`030000oooooooo037oool00`1Vooooooooo`0Aoooo00<0I_ooooooool0<Ooo
o`00Eoooo`0306Kooooooooo00_oool00`1Vooooooooo`0loooo00<0003oooooool0<?ooo`0306Ko
oooooooo01;oool00`1Vooooooooo`0aoooo001Foooo00<0I_ooooooool03?ooo`0306Kooooooooo
03coool20000<Oooo`0306Kooooooooo01;oool00`1Vooooooooo`0aoooo001Foooo00<0I_oooooo
ool03?ooo`0306Kooooooooo03coool00`000?ooooooo`0_oooo00<0I_ooooooool04oooo`0306Ko
oooooooo037oool005Koool00`1Vooooooooo`0=oooo00<0I_ooooooool0>oooo`030000oooooooo
02ooool00`1Vooooooooo`0Coooo00<0I_ooooooool0<Oooo`00E_ooo`0306Kooooooooo00goool0
0`1Vooooooooo`0koooo00<0003oooooool0;oooo`0306Kooooooooo01?oool00`1Vooooooooo`0a
oooo001Foooo00<0I_ooooooool03_ooo`0306Kooooooooo03[oool00`000?ooooooo`0^oooo00<0
I_ooooooool05?ooo`0306Kooooooooo037oool005Koool00`1Vooooooooo`0>oooo00<0I_oooooo
ool0>_ooo`80000_oooo00<0I_ooooooool05?ooo`0306Kooooooooo037oool005Goool00`1Voooo
ooooo`0?oooo00<0I_ooooooool0>_ooo`030000oooooooo02goool00`1Vooooooooo`0Eoooo00<0
I_ooooooool0<Oooo`00EOooo`0306Kooooooooo013oool00`1Vooooooooo`0ioooo00<0003ooooo
ool0;Oooo`0306Kooooooooo01Goool00`1Vooooooooo`0aoooo001Eoooo00<0I_ooooooool04?oo
o`0306Kooooooooo03Woool00`000?ooooooo`0/oooo00<0I_ooooooool05_ooo`0306Kooooooooo
037oool005Goool00`1Vooooooooo`0@oooo00<0I_ooooooool0>Oooo`030000oooooooo02coool0
0`1Vooooooooo`0Foooo00<0I_ooooooool0<Oooo`00EOooo`0306Kooooooooo017oool00`1Voooo
ooooo`0hoooo0P0002coool00`1Vooooooooo`0Goooo00<0I_ooooooool0<Oooo`00E?ooo`0306Ko
oooooooo01;oool00`1Vooooooooo`0hoooo00<0003oooooool0:oooo`0306Kooooooooo01Ooool0
0`1Vooooooooo`0aoooo001Doooo00<0I_ooooooool04oooo`0306Kooooooooo03Ooool00`000?oo
ooooo`0Zoooo00<0I_ooooooool06?ooo`0306Kooooooooo037oool005Coool00`1Vooooooooo`0C
oooo00<0I_ooooooool08oooo`800004oooo0P0000Coool200001_ooo`030000oooooooo02[oool0
0`1Vooooooooo`0Hoooo00<0I_ooooooool0<Oooo`00E?ooo`0306Kooooooooo01?oool00`1Voooo
ooooo`0Roooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool0:Ooo
o`0306Kooooooooo01Woool00`1Vooooooooo`0aoooo001Coooo00<0I_ooooooool05Oooo`0306Ko
oooooooo027oool010000?ooooooo`0000[oool00`000?ooooooo`04oooo0P0002[oool00`1Voooo
ooooo`0Ioooo00<0I_ooooooool0<Oooo`00Doooo`0306Kooooooooo01Goool00`1Vooooooooo`0K
oooo100000;oool010000?ooooooo`0000_oool00`000?ooooooo`03oooo00<0003oooooool0:?oo
o`0306Kooooooooo01[oool00`1Vooooooooo`0aoooo001Coooo00<0I_ooooooool05_ooo`0306Ko
oooooooo023oool010000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`0X
oooo00<0I_ooooooool06_ooo`0306Kooooooooo037oool005?oool00`1Vooooooooo`0Foooo00<0
I_ooooooool08Oooo`80000:oooo0P0000Koool00`000?ooooooo`0Woooo00<0I_ooooooool06ooo
o`0306Kooooooooo037oool005?oool00`1Vooooooooo`0Foooo00<0I_ooooooool0=Oooo`030000
oooooooo02Ooool00`1Vooooooooo`0Koooo00<0I_ooooooool0<Oooo`00D_ooo`0306Kooooooooo
01Soool00`1Vooooooooo`0doooo0P0002Ooool00`1Vooooooooo`0Loooo00<0I_ooooooool0<Ooo
o`00D_ooo`0306Kooooooooo01Soool00`1Vooooooooo`0doooo00<0003oooooool09_ooo`0306Ko
oooooooo01coool00`1Vooooooooo`0aoooo001Boooo00<0I_ooooooool06?ooo`0306Kooooooooo
03Coool00`000?ooooooo`0Uoooo00<0I_ooooooool07Oooo`0306Kooooooooo037oool005;oool0
0`1Vooooooooo`0Ioooo00<0I_ooooooool0<oooo`030000oooooooo02Goool00`1Vooooooooo`0M
oooo00<0I_ooooooool0<Oooo`00D_ooo`0306Kooooooooo01Woool00`1Vooooooooo`0coooo00<0
003oooooool09?ooo`0306Kooooooooo01koool00`1Vooooooooo`0aoooo001Aoooo00<0I_oooooo
ool06oooo`0306Kooooooooo03;oool200009Oooo`0306Kooooooooo01koool00`1Vooooooooo`0a
oooo001Aoooo00<0I_ooooooool06oooo`0306Kooooooooo03;oool00`000?ooooooo`0Soooo00<0
I_ooooooool07oooo`0306Kooooooooo037oool0057oool00`1Vooooooooo`0Loooo00<0I_oooooo
ool0<Oooo`030000oooooooo02?oool00`1Vooooooooo`0Ooooo00<0I_ooooooool0<Oooo`00DOoo
o`0306Kooooooooo01coool00`1Vooooooooo`0aoooo00<0003oooooool08_ooo`0306Kooooooooo
023oool00`1Vooooooooo`0aoooo001@oooo00<0I_ooooooool07_ooo`0306Kooooooooo033oool0
0`000?ooooooo`0Roooo00<0I_ooooooool08?ooo`0306Kooooooooo037oool0053oool00`1Voooo
ooooo`0Noooo00<0I_ooooooool0<?ooo`80000Roooo00<0I_ooooooool08Oooo`0306Kooooooooo
037oool0053oool00`1Vooooooooo`0Ooooo00<0I_ooooooool0;oooo`030000oooooooo027oool0
0`1Vooooooooo`0Qoooo00<0I_ooooooool0<Oooo`00D?ooo`0306Kooooooooo01ooool00`1Voooo
ooooo`0_oooo00<0003oooooool08?ooo`0306Kooooooooo02;oool00`1Vooooooooo`0aoooo001@
oooo00<0I_ooooooool08?ooo`0306Kooooooooo02koool00`000?ooooooo`0Poooo00<0I_oooooo
ool08_ooo`0306Kooooooooo037oool004ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool0;_oo
o`030000oooooooo01ooool00`1Vooooooooo`0Soooo00<0I_ooooooool0<Oooo`00Coooo`0306Ko
oooooooo02;oool00`1Vooooooooo`0]oooo0P0001ooool00`1Vooooooooo`0Toooo00<0I_oooooo
ool0<Oooo`00Coooo`0306Kooooooooo02;oool00`1Vooooooooo`0]oooo00<0003oooooool07_oo
o`0306Kooooooooo02Coool00`1Vooooooooo`0aoooo001?oooo00<0I_ooooooool08oooo`0306Ko
oooooooo02coool00`000?ooooooo`0Moooo00<0I_ooooooool09Oooo`0306Kooooooooo037oool0
04koool00`1Vooooooooo`0Uoooo00<0I_ooooooool05oooo`800004oooo0P0000?oool400001Ooo
o`030000oooooooo01goool00`1Vooooooooo`0Uoooo00<0I_ooooooool0<Oooo`00C_ooo`0306Ko
oooooooo02Goool00`1Vooooooooo`0Foooo00@0003oooooool00008oooo00<0003oooooool01_oo
o`030000oooooooo01coool00`1Vooooooooo`0Voooo00<0I_ooooooool0<Oooo`00C_ooo`0306Ko
oooooooo02Koool00`1Vooooooooo`0Eoooo00@0003oooooool00009oooo00<0003oooooool01Ooo
o`80000Moooo00<0I_ooooooool09_ooo`0306Kooooooooo037oool004koool00`1Vooooooooo`0V
oooo00<0I_ooooooool03oooo`@00002oooo00@0003oooooool0000:oooo00<0003oooooool01?oo
o`030000oooooooo01_oool00`1Vooooooooo`0Woooo00<0I_ooooooool0<Oooo`00COooo`0306Ko
oooooooo02Soool00`1Vooooooooo`0Doooo00@0003oooooool00008oooo00@0003oooooool00005
oooo00<0003oooooool06oooo`0306Kooooooooo02Ooool00`1Vooooooooo`0aoooo001=oooo00<0
I_ooooooool0:?ooo`0306Kooooooooo01Goool200002_ooo`800006oooo00<0003oooooool06_oo
o`0306Kooooooooo02Soool00`1Vooooooooo`0aoooo001=oooo00<0I_ooooooool0:Oooo`0306Ko
oooooooo02Soool00`000?ooooooo`0Ioooo00<0I_ooooooool0:Oooo`0306Kooooooooo037oool0
04goool00`1Vooooooooo`0Yoooo00<0I_ooooooool0:?ooo`80000Joooo00<0I_ooooooool0:Ooo
o`0306Kooooooooo037oool004coool00`1Vooooooooo`0[oooo00<0I_ooooooool09oooo`030000
oooooooo01Soool00`1Vooooooooo`0Zoooo00<0I_ooooooool0<Oooo`00C?ooo`0306Kooooooooo
02coool00`1Vooooooooo`0Voooo00<0003oooooool05oooo`0306Kooooooooo02_oool00`1Voooo
ooooo`0aoooo001<oooo00<0I_ooooooool0;?ooo`0306Kooooooooo02Koool00`000?ooooooo`0F
oooo00<0I_ooooooool0;?ooo`0306Kooooooooo037oool004_oool00`1Vooooooooo`0^oooo00<0
I_ooooooool09Oooo`030000oooooooo01Koool00`1Vooooooooo`0/oooo00<0I_ooooooool0<Ooo
o`00Boooo`0306Kooooooooo02ooool00`1Vooooooooo`0Toooo0P0001Koool00`1Vooooooooo`0]
oooo00<0I_ooooooool0<Oooo`00B_ooo`0306Kooooooooo037oool00`1Vooooooooo`0Soooo00<0
003oooooool05?ooo`0306Kooooooooo02koool00`1Vooooooooo`0aoooo001:oooo00<0I_oooooo
ool0<Oooo`0306Kooooooooo02?oool00`000?ooooooo`0Doooo00<0I_ooooooool0;_ooo`0306Ko
oooooooo037oool004Woool00`1Vooooooooo`0coooo00<0I_ooooooool08_ooo`030000oooooooo
01?oool00`1Vooooooooo`0_oooo00<0I_ooooooool0<Oooo`00BOooo`0306Kooooooooo03Coool0
0`1Vooooooooo`0Qoooo00<0003oooooool04_ooo`0306Kooooooooo033oool00`1Vooooooooo`0a
oooo0018oooo00<0I_ooooooool0=_ooo`0306Kooooooooo023oool200004_ooo`0306Kooooooooo
037oool00`1Vooooooooo`0aoooo0018oooo00<0I_ooooooool0=_ooo`0306Kooooooooo023oool0
0`000?ooooooo`0Aoooo00<0I_ooooooool0<Oooo`0306Kooooooooo037oool004Ooool00`1Voooo
ooooo`0hoooo00<0I_ooooooool07oooo`030000oooooooo013oool00`1Vooooooooo`0boooo00<0
I_ooooooool0<Oooo`00Aoooo`0306Kooooooooo03Woool00`1Vooooooooo`0Noooo00<0003ooooo
ool03oooo`0306Kooooooooo03?oool00`1Vooooooooo`0aoooo0016oooo00<0I_ooooooool0>ooo
o`0306Kooooooooo01goool00`000?ooooooo`0>oooo00<0I_ooooooool0=?ooo`0306Kooooooooo
037oool004Koool00`1Vooooooooo`0loooo00<0I_ooooooool07?ooo`80000>oooo00<0I_oooooo
ool0=Oooo`0306Kooooooooo037oool004Koool00`1Vooooooooo`0moooo00<0I_ooooooool06ooo
o`030000oooooooo00coool00`1Vooooooooo`0foooo00<0I_ooooooool0<Oooo`00AOooo`0306Ko
oooooooo03ooool00`1Vooooooooo`06oooo0P0000Coool200000oooo`D00004oooo00<0003ooooo
ool02oooo`0306Kooooooooo03Ooool00`1Vooooooooo`0aoooo0015oooo00<0I_ooooooool0@?oo
o`0306Kooooooooo00Coool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003ooooo
ool02_ooo`0306Kooooooooo03Soool00`1Vooooooooo`0aoooo0014oooo00<0I_ooooooool0@_oo
o`0306Kooooooooo00?oool010000?ooooooo`0000[oool00`000?ooooooo`04oooo0P0000[oool0
0`1Vooooooooo`0ioooo00<0I_ooooooool0<Oooo`00A?ooo`0306Kooooooooo04;oool400000_oo
o`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`08oooo00<0I_oooooo
ool0>_ooo`0306Kooooooooo037oool004?oool00`1Vooooooooo`15oooo0P1Vo`;oool010000?oo
ooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool01oooo`0306Kooooooooo03_oool0
0`1Vooooooooo`0aoooo0012oooo00<0I_ooooooool0B?ooo`0306Kooooooooo0080000:oooo0P00
00Koool00`000?ooooooo`06oooo00<0I_ooooooool0??ooo`0306Kooooooooo037oool004;oool0
0`1Vooooooooo`19oooo00<0I_ooooooool04oooo`030000oooooooo00Coool206Ko?oooo`0306Ko
oooooooo037oool0047oool00`1Vooooooooo`1;oooo00<0I_ooooooool04_ooo`800004oooo00<0
I_ooooooool0?oooo`0306Kooooooooo037oool0043oool00`1Vooooooooo`1=oooo00<0I_oooooo
ool04Oooo`040000oooooooooooo0P1Vod;oool00`1Vooooooooo`0aoooo000ooooo00<0I_oooooo
ool0Coooo`80I_lAoooo00@0003oooooool0I_m4oooo00<0I_ooooooool0<Oooo`00?_ooo`0306Ko
oooooooo05;oool00`1Vooooooooo`0>oooo00<0003oool0I_l0AOooo`0306Kooooooooo037oool0
03koool00`1Vooooooooo`1Coooo0`1Vo`goool00`00001Vooooo`15oooo00<0I_ooooooool0<Ooo
o`00?Oooo`0306Kooooooooo05Ooool306Ko2?ooo`80I_l20000A_ooo`0306Kooooooooo037oool0
03coool00`1Vooooooooo`1Koooo201Vo`;oool00`000?ooooooo`15oooo00<0I_ooooooool0<Ooo
o`00>oooo`0306Kooooooooo06Koool00`000?ooooooo`15oooo00<0I_ooooooool0<Oooo`00>Ooo
o`80I_mYoooo00<0003oooooool0AOooo`0306Kooooooooo037oool002Woool300003?ooo`0306Ko
oooooooo01Woool300009?ooo`@0000Uoooo00<0003oooooool09?ooo`@0000Moooo00<0I_oooooo
ool01oooo`<0000Woooo000Yoooo00@0003oooooool0000:oooo00<0I_ooooooool06oooo`030000
oooooooo02?oool00`000?ooooooo`0Voooo0P0002Goool00`000?ooooooo`0Noooo00<0I_oooooo
ool02?ooo`030000oooooooo02Koool002Woool010000?ooooooo`0000Soool206Ko6oooo`D0000U
oooo00<0003oooooool09Oooo`030000oooooooo02Goool00`000?ooooooo`0Moooo00<0I_oooooo
ool01Oooo`D0000Woooo000Soooo100000;oool300001oooo`80I_lGoooo100000;oool010000?oo
ooooo`0001ooool400001?ooo`030000oooooooo02Coool00`000?ooooooo`0Voooo00<0003ooooo
ool07?ooo`0306Kooooooooo00Goool010000?ooooooo`0002Soool002[oool00`000?ooooooo`04
oooo0P1Vob3oool00`000?ooo`00000Uoooo00@0003oooooool0000Uoooo00<0003oooooool09?oo
o`040000oooooooo00007Oooo`0306Kooooooooo00Koool00`000?ooo`00000Xoooo000Zoooo0`00
00;oool206Ko8oooo`80000Voooo0P0002Koool00`000?ooooooo`0Uoooo0P0001koool00`1Voooo
ooooo`07oooo0P0002Soool002coool306KoMOooo`800016oooo00<0I_ooooooool0<Oooo`00:_oo
o`80I_mhoooo00<0003oooooool0AOooo`0306Kooooooooo037oool002Coool606KoN_ooo`030000
oooooooo04Goool00`1Vooooooooo`0aoooo000Ooooo1@1Voh3oool00`000?ooooooo`15oooo00<0
I_ooooooool0<Oooo`004oooo``0I_n5oooo00<0003oooooool0AOooo`0306Kooooooooo037oool0
00gooooo00001P0000koool001?oool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooo000000`00005<ol000<0000co`0c
o`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`0023?o00030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`0Boooo000Xoooo00<0
003oooooool09_ooo`030000oooooooo027oool60000:C?o00030000oooooooo02Koool00`000?oo
ooooo`0Loooo00?o09Woooooool01oooo`030000oooooooo02Ooool007[oool300009c?o00030000
oooooooo04Goool00ol0VOooooooo`0aoooo001moooo0P0002Dco`000`000?ooooooo`15oooo00?o
09Woooooool0<Oooo`00Ooooo`030000<ol0<ol0028co`020000A_ooo`03o`2Ioooooooo037oool0
083oool00`0003?o03?o000Q<ol000<0003oooooool0AOooo`03o`2Ioooooooo037oool0087oool2
00008C?o00030000oooooooo04Goool00ol0VOooooooo`0aoooo0023oooo00<0000co`0co`007S?o
00030000oooooooo04Goool00ol0VOooooooo`0aoooo0023oooo00<0000co`0co`007S?o00030000
oooooooo04Goool00ol0VOooooooo`0aoooo0024oooo00<0000co`0co`007C?o00800016oooo00?o
09Woooooool0<Oooo`00QOooo`030000<ol0<ol001`co`000`000?ooooooo`15oooo00?o09Wooooo
ool0<Oooo`00Q_ooo`030000<ol0<ol001/co`000`000?ooooooo`15oooo00?o09Woooooool0<Ooo
o`00Q_ooo`030000<ol0<ol001/co`000`000?ooooooo`15oooo00?o09Woooooool0<Oooo`00Qooo
oadco`1loooo0028oooo73?o07coool008SooolL<ol0O?ooo`00R?oooa`co`1loooo0029oooo6c?o
07coool007coool00`000?ooooooo`0:oooo63?o00030000<ol0<ol007coool007_oool00`000?oo
ooooo`08oooo00@0003ooooooooooolH<ol000<0000co`3oool0Noooo`00Noooo`030000oooooooo
00;oool200001?ooo`040000oooooooooooo1c?o00<00002<ol00P0000@co`02000013?o00030000
<ol0oooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`040000
oooooooooooo1c?o00030000<ol0<ol000Hco`00100003?o03?o000000<co`000`0003?o0?ooo`1k
oooo001joooo00<0003oooooool00_ooo`030000oooooooo00Woool4<ol01@0000Xco`000`0003?o
03?o0002<ol000<0003oooooool0N_ooo`00Noooo`030000oooooooo00D00008oooo13?o00040000
<ol0<ol000002C?o00800004<ol000<0000co`3oool0Noooo`00Noooo`050000oooooooooooo0000
00coool4<ol000<0000co`0000002C?o00030000<ol0<ol000<co`000`0003?o0?ooo`1koooo001l
oooo00<0003oooooool03Oooo`Dco`0200002C?o00<00002<ol000<0000co`0co`00O?ooo`00S?oo
oaPco`1loooo002<oooo63?o07coool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.26171 .57049 L
.30316 .57049 L
.34309 .57049 L
.3815 .57049 L
.42237 .57049 L
.46172 .57049 L
.49955 .57049 L
.53984 .57049 L
.57861 .57049 L
.61984 .57049 L
.65954 .57049 L
.69774 .57049 L
.73838 .57049 L
.77751 .57049 L
.81909 .57049 L
.83996 .57049 L
.85916 .57049 L
.87791 .57049 L
.88735 .57049 L
.88993 .57049 L
.89271 .57049 L
.89405 .57049 L
.89533 .57049 L
.89647 .57049 L
s
.89647 .57049 m
.89647 .61803 L
s
0 .4 1 r
.02381 .56379 m
.04262 .56113 L
.06244 .55716 L
.07286 .55444 L
.08255 .55141 L
.09388 .54715 L
.10458 .54224 L
.125 .52985 L
.14357 .5139 L
.16355 .4897 L
.18199 .45828 L
.20071 .41383 L
.21136 .38109 L
.22134 .34425 L
.24158 .24595 L
.25055 .18973 L
.25547 .15483 L
.25789 .13655 L
.26011 .11902 L
.26132 .10922 L
.26259 .10686 L
.26387 .11153 L
.26527 .11662 L
.26995 .13331 L
.27909 .16468 L
.29982 .22967 L
.34024 .33255 L
.37915 .40517 L
.39896 .43388 L
.42051 .45981 L
.46036 .49577 L
.48013 .50884 L
.50114 .51975 L
.51051 .52368 L
.52061 .52727 L
.53008 .53 L
.53889 .53194 L
.54352 .53271 L
.54589 .53303 L
.54846 .53332 L
.54993 .53345 L
.55128 .53356 L
.55255 .53364 L
.55322 .53367 L
.55395 .53371 L
.5552 .53375 L
.55637 .53378 L
.55705 .53378 L
.55771 .53378 L
.55893 .53377 L
Mistroke
.55962 .53376 L
.56026 .53374 L
.56147 .53368 L
.56277 .5336 L
.56417 .53349 L
.5667 .53321 L
.56903 .53286 L
.57158 .53235 L
.57438 .53165 L
.58003 .52965 L
.59958 .52069 L
.62051 .50908 L
.64036 .4958 L
.66192 .47841 L
.70182 .43641 L
.74265 .37728 L
.78197 .3025 L
.81977 .21501 L
.84079 .16233 L
.86003 .1146 L
.87891 .07214 L
.8884 .05416 L
.891 .04979 L
.89378 .04544 L
.89512 .04346 L
.89639 .04166 L
.89753 .57049 L
.89877 .57049 L
.93974 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo04ooool00`1Vooooooooo`0Woooo002Toooo00<0
003oooooool0Coooo`0306Kooooooooo02Ooool00:Coool00`000?ooooooo`1>oooo0P1VobWoool0
0:Coool00`000?ooooooo`1>oooo0P1VobWoool00:Coool20000C_ooo`0306Kooooo06Ko02Woool0
0:Coool00`000?ooooooo`1<oooo00@0I_ooooooool0I_lYoooo002Toooo00<0003oooooool0C?oo
o`0406Kooooooooo06Ko:Oooo`00Y?ooo`030000oooooooo04_oool01@1Vooooooooooooo`1Vo`0Y
oooo002Toooo00<0003oooooool0Boooo`0506Kooooooooooooo06Ko02Woool00:Coool20000C?oo
o`0506Kooooooooooooo06Ko02Woool00:Coool00`000?ooooooo`1:oooo00<0I_ooooooool00_oo
o`0306Kooooooooo02Ooool00:Coool00`000?ooooooo`1:oooo00<0I_ooooooool00_ooo`0306Ko
oooooooo02Ooool0093oool200001?ooo`800004oooo0P0000Koool00`000?ooooooo`19oooo00<0
I_ooooooool00oooo`0306Kooooooooo02Ooool008ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool00`000?ooooooo`19oooo00<0I_ooooooool00oooo`0306Kooooooooo02Ooool0
08ooool010000?ooooooo`0000_oool00`000?ooooooo`03oooo0P0004Woool00`1Vooooooooo`04
oooo00<0I_ooooooool09oooo`00ROooo`@00002oooo00@0003oooooool00009oooo0P0000Koool0
0`000?ooooooo`18oooo00<0I_ooooooool01?ooo`0306Kooooooooo02Ooool008ooool010000?oo
ooooo`0000Woool00`000?ooooooo`05oooo00<0003oooooool0Aoooo`0306Kooooooooo00Goool0
0`1Vooooooooo`0Woooo001Aoooo00<0I_ooooooool0??ooo`80000:oooo0`0000Goool00`000?oo
ooooo`17oooo00<0I_ooooooool01Oooo`0306Kooooooooo02Ooool0057oool00`1Vooooooooo`1@
oooo00<0003oooooool0A_ooo`0306Kooooooooo00Koool00`1Vooooooooo`0Woooo001Aoooo00<0
I_ooooooool0D?ooo`800017oooo00<0I_ooooooool01_ooo`0306Kooooooooo02Ooool0053oool0
0`1Vooooo`1Vo`1Aoooo00<0003oooooool0A_ooo`0306Kooooooooo00Koool00`1Vooooooooo`0W
oooo001@oooo00<0I_ooool0I_l0DOooo`030000oooooooo04Goool00`1Vooooooooo`07oooo00<0
I_ooooooool09oooo`00D?ooo`0306Kooooo06Ko057oool00`000?ooooooo`15oooo00<0I_oooooo
ool01oooo`0306Kooooooooo02Ooool0053oool0101Vooooooooo`1Voe3oool00`000?ooooooo`14
oooo00<0I_ooooooool02?ooo`0306Kooooooooo02Ooool0053oool0101Vooooooooo`1Voe3oool2
0000AOooo`0306Kooooooooo00Soool00`1Vooooooooo`0Woooo001@oooo00@0I_ooooooool0I_m@
oooo00<0003oooooool0A?ooo`0306Kooooooooo00Soool00`1Vooooooooo`0Woooo001@oooo00@0
I_ooooooool0I_m@oooo00<0003oooooool0@oooo`0306Kooooooooo00Woool00`1Vooooooooo`0W
oooo001@oooo00D0I_ooooooooooool0I_l0Coooo`030000oooooooo04?oool00`1Vooooooooo`09
oooo00<0I_ooooooool09oooo`00Coooo`0306Kooooooooo00;oool00`1Vooooooooo`1=oooo00<0
003oooooool0@oooo`0306Kooooooooo00Woool00`1Vooooooooo`0Woooo001?oooo00<0I_oooooo
ool00_ooo`0306Kooooooooo04goool20000@oooo`0306Kooooooooo00[oool00`1Vooooooooo`0W
oooo001?oooo00<0I_ooooooool00_ooo`0306Kooooooooo04goool00`000?ooooooo`12oooo00<0
I_ooooooool02_ooo`0306Kooooooooo02Ooool004ooool00`1Vooooooooo`03oooo00<0I_oooooo
ool0C?ooo`030000oooooooo047oool00`1Vooooooooo`0;oooo00<0I_ooooooool09oooo`00Cooo
o`0306Kooooooooo00?oool00`1Vooooooooo`1<oooo00<0003oooooool0@Oooo`0306Kooooooooo
00_oool00`1Vooooooooo`0Woooo001?oooo00<0I_ooooooool00oooo`0306Kooooooooo04coool0
0`000?ooooooo`11oooo00<0I_ooooooool02oooo`0306Kooooooooo02Ooool004ooool00`1Voooo
ooooo`04oooo00<0I_ooooooool0Boooo`800011oooo00<0I_ooooooool03?ooo`0306Kooooooooo
02Ooool004koool00`1Vooooooooo`05oooo00<0I_ooooooool0Boooo`030000oooooooo043oool0
0`1Vooooooooo`0<oooo00<0I_ooooooool09oooo`00C_ooo`0306Kooooooooo00Goool00`1Voooo
ooooo`1;oooo00<0003oooooool0?oooo`0306Kooooooooo00goool00`1Vooooooooo`0Woooo001>
oooo00<0I_ooooooool01_ooo`0306Kooooooooo03Koool200001?ooo`800005oooo0`0000Coool0
0`000?ooooooo`0ooooo00<0I_ooooooool03Oooo`0306Kooooooooo02Ooool004koool00`1Voooo
ooooo`06oooo00<0I_ooooooool0=Oooo`040000oooooooo00002oooo`030000oooooooo00?oool0
0`000?ooooooo`0noooo00<0I_ooooooool03_ooo`0306Kooooooooo02Ooool004koool00`1Voooo
ooooo`06oooo00<0I_ooooooool0=Oooo`040000oooooooo00002?ooo`D00004oooo0P0003ooool0
0`1Vooooooooo`0>oooo00<0I_ooooooool09oooo`00C_ooo`0306Kooooooooo00Ooool00`1Voooo
ooooo`0^oooo100000;oool010000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?oo
ooooo`0noooo00<0I_ooooooool03_ooo`0306Kooooooooo02Ooool004koool00`1Vooooooooo`07
oooo00<0I_ooooooool0=?ooo`040000oooooooo00002Oooo`030000oooo000000Goool00`000?oo
ooooo`0moooo00<0I_ooooooool03oooo`0306Kooooooooo02Ooool004koool00`1Vooooooooo`08
oooo00<0I_ooooooool0=?ooo`80000;oooo0P0000Goool00`000?ooooooo`0moooo00<0I_oooooo
ool03oooo`0306Kooooooooo02Ooool004goool00`1Vooooooooo`09oooo00<0I_ooooooool0B?oo
o`030000oooooooo03coool00`1Vooooooooo`0@oooo00<0I_ooooooool09oooo`00COooo`0306Ko
oooooooo00Woool00`1Vooooooooo`18oooo0P0003goool00`1Vooooooooo`0@oooo00<0I_oooooo
ool09oooo`00COooo`0306Kooooooooo00[oool00`1Vooooooooo`17oooo00<0003oooooool0>ooo
o`0306Kooooooooo017oool00`1Vooooooooo`0Woooo001=oooo00<0I_ooooooool02_ooo`0306Ko
oooooooo04Ooool00`000?ooooooo`0koooo00<0I_ooooooool04Oooo`0306Kooooooooo02Ooool0
04goool00`1Vooooooooo`0:oooo00<0I_ooooooool0Aoooo`030000oooooooo03_oool00`1Voooo
ooooo`0Aoooo00<0I_ooooooool09oooo`00COooo`0306Kooooooooo00_oool00`1Vooooooooo`16
oooo00<0003oooooool0>_ooo`0306Kooooooooo01;oool00`1Vooooooooo`0Woooo001=oooo00<0
I_ooooooool02oooo`0306Kooooooooo04Koool20000>oooo`0306Kooooooooo01;oool00`1Voooo
ooooo`0Woooo001=oooo00<0I_ooooooool02oooo`0306Kooooooooo04Koool00`000?ooooooo`0i
oooo00<0I_ooooooool04oooo`0306Kooooooooo02Ooool004coool00`1Vooooooooo`0=oooo00<0
I_ooooooool0AOooo`030000oooooooo03Woool00`1Vooooooooo`0Coooo00<0I_ooooooool09ooo
o`00C?ooo`0306Kooooooooo00goool00`1Vooooooooo`15oooo00<0003oooooool0>?ooo`0306Ko
oooooooo01Coool00`1Vooooooooo`0Woooo001<oooo00<0I_ooooooool03Oooo`0306Kooooooooo
04Goool00`000?ooooooo`0hoooo00<0I_ooooooool05?ooo`0306Kooooooooo02Ooool004coool0
0`1Vooooooooo`0>oooo00<0I_ooooooool0A?ooo`80000hoooo00<0I_ooooooool05Oooo`0306Ko
oooooooo02Ooool004coool00`1Vooooooooo`0>oooo00<0I_ooooooool0A?ooo`030000oooooooo
03Ooool00`1Vooooooooo`0Eoooo00<0I_ooooooool09oooo`00C?ooo`0306Kooooooooo00ooool0
0`1Vooooooooo`13oooo00<0003oooooool0=_ooo`0306Kooooooooo01Koool00`1Vooooooooo`0W
oooo001;oooo00<0I_ooooooool04?ooo`0306Kooooooooo04?oool00`000?ooooooo`0foooo00<0
I_ooooooool05_ooo`0306Kooooooooo02Ooool004_oool00`1Vooooooooo`0@oooo00<0I_oooooo
ool0@oooo`030000oooooooo03Koool00`1Vooooooooo`0Foooo00<0I_ooooooool09oooo`00Booo
o`0306Kooooooooo017oool00`1Vooooooooo`12oooo0P0003Koool00`1Vooooooooo`0Goooo00<0
I_ooooooool09oooo`00Boooo`0306Kooooooooo017oool00`1Vooooooooo`12oooo00<0003ooooo
ool0=Oooo`0306Kooooooooo01Ooool00`1Vooooooooo`0Woooo001:oooo00<0I_ooooooool04_oo
o`0306Kooooooooo04;oool00`000?ooooooo`0doooo00<0I_ooooooool06?ooo`0306Kooooooooo
02Ooool004[oool00`1Vooooooooo`0Coooo00<0I_ooooooool0;Oooo`800004oooo0P0000Coool2
00001_ooo`030000oooooooo03Coool00`1Vooooooooo`0Hoooo00<0I_ooooooool09oooo`00B_oo
o`0306Kooooooooo01?oool00`1Vooooooooo`0/oooo00@0003oooooool00008oooo00@0003ooooo
ool00005oooo00<0003oooooool0<oooo`0306Kooooooooo01Woool00`1Vooooooooo`0Woooo001:
oooo00<0I_ooooooool05?ooo`0306Kooooooooo02_oool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo0P0003Coool00`1Vooooooooo`0Ioooo00<0I_ooooooool09oooo`00BOooo`0306Ko
oooooooo01Goool00`1Vooooooooo`0Uoooo100000;oool010000?ooooooo`0000_oool00`000?oo
ooooo`03oooo00<0003oooooool0<_ooo`0306Kooooooooo01[oool00`1Vooooooooo`0Woooo0019
oooo00<0I_ooooooool05Oooo`0306Kooooooooo02_oool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool00`000?ooooooo`0boooo00<0I_ooooooool06_ooo`0306Kooooooooo02Ooool0
04Woool00`1Vooooooooo`0Foooo00<0I_ooooooool0:oooo`80000:oooo0P0000Koool00`000?oo
ooooo`0aoooo00<0I_ooooooool06oooo`0306Kooooooooo02Ooool004Woool00`1Vooooooooo`0F
oooo00<0I_ooooooool0?oooo`030000oooooooo037oool00`1Vooooooooo`0Koooo00<0I_oooooo
ool09oooo`00B?ooo`0306Kooooooooo01Ooool00`1Vooooooooo`0ooooo0P00037oool00`1Voooo
ooooo`0Loooo00<0I_ooooooool09oooo`00B?ooo`0306Kooooooooo01Soool00`1Vooooooooo`0n
oooo00<0003oooooool0<?ooo`0306Kooooooooo01goool00`1Vooooooooo`0Voooo0018oooo00<0
I_ooooooool06?ooo`0306Kooooooooo03koool00`000?ooooooo`0_oooo00<0I_ooooooool07_oo
o`0306Kooooooooo02Koool004Soool00`1Vooooooooo`0Ioooo00<0I_ooooooool0?Oooo`030000
oooooooo02ooool00`1Vooooooooo`0Noooo00<0I_ooooooool09_ooo`00Aoooo`0306Kooooooooo
01[oool00`1Vooooooooo`0moooo00<0003oooooool0;_ooo`0306Kooooooooo01ooool00`1Voooo
ooooo`0Voooo0017oooo00<0I_ooooooool06_ooo`0306Kooooooooo03goool20000;oooo`0306Ko
oooooooo01ooool00`1Vooooooooo`0Voooo0017oooo00<0I_ooooooool06oooo`0306Kooooooooo
03coool00`000?ooooooo`0]oooo00<0I_ooooooool08?ooo`0306Kooooooooo02Koool004Ooool0
0`1Vooooooooo`0Koooo00<0I_ooooooool0??ooo`030000oooooooo02goool00`1Vooooooooo`0P
oooo00<0I_ooooooool09_ooo`00A_ooo`0306Kooooooooo01goool00`1Vooooooooo`0koooo00<0
003oooooool0;?ooo`0306Kooooooooo027oool00`1Vooooooooo`0Voooo0016oooo00<0I_oooooo
ool07Oooo`0306Kooooooooo03_oool00`000?ooooooo`0/oooo00<0I_ooooooool08Oooo`0306Ko
oooooooo02Koool004Koool00`1Vooooooooo`0Noooo00<0I_ooooooool0>_ooo`80000/oooo00<0
I_ooooooool08_ooo`0306Kooooooooo02Koool004Koool00`1Vooooooooo`0Noooo00<0I_oooooo
ool0>_ooo`030000oooooooo02_oool00`1Vooooooooo`0Roooo00<0I_ooooooool09_ooo`00A_oo
o`0306Kooooooooo01ooool00`1Vooooooooo`0ioooo00<0003oooooool0:_ooo`0306Kooooooooo
02?oool00`1Vooooooooo`0Voooo0015oooo00<0I_ooooooool08?ooo`0306Kooooooooo03Woool0
0`000?ooooooo`0Zoooo00<0I_ooooooool08oooo`0306Kooooooooo02Koool004Goool00`1Voooo
ooooo`0Qoooo00<0I_ooooooool0>?ooo`030000oooooooo02Woool00`1Vooooooooo`0Toooo00<0
I_ooooooool09_ooo`00AOooo`0306Kooooooooo027oool00`1Vooooooooo`0hoooo0P0002[oool0
0`1Vooooooooo`0Toooo00<0I_ooooooool09_ooo`00AOooo`0306Kooooooooo02;oool00`1Voooo
ooooo`0goooo00<0003oooooool0:?ooo`0306Kooooooooo02Goool00`1Vooooooooo`0Voooo0015
oooo00<0I_ooooooool08_ooo`0306Kooooooooo03Ooool00`000?ooooooo`0Xoooo00<0I_oooooo
ool09Oooo`0306Kooooooooo02Koool004Coool00`1Vooooooooo`0Toooo00<0I_ooooooool08_oo
o`800004oooo0P0000?oool400001Oooo`030000oooooooo02Ooool00`1Vooooooooo`0Voooo00<0
I_ooooooool09_ooo`00A?ooo`0306Kooooooooo02Coool00`1Vooooooooo`0Qoooo00@0003ooooo
ool00008oooo00<0003oooooool01_ooo`030000oooooooo02Ooool00`1Vooooooooo`0Voooo00<0
I_ooooooool09_ooo`00A?ooo`0306Kooooooooo02Goool00`1Vooooooooo`0Poooo00@0003ooooo
ool00009oooo00<0003oooooool01Oooo`80000Woooo00<0I_ooooooool09oooo`0306Kooooooooo
02Koool004Coool00`1Vooooooooo`0Uoooo00<0I_ooooooool06_ooo`@00002oooo00@0003ooooo
ool0000:oooo00<0003oooooool01?ooo`030000oooooooo02Koool00`1Vooooooooo`0Woooo00<0
I_ooooooool09_ooo`00@oooo`0306Kooooooooo02Ooool00`1Vooooooooo`0Ooooo00@0003ooooo
ool00008oooo00@0003oooooool00005oooo00<0003oooooool09Oooo`0306Kooooooooo02Soool0
0`1Vooooooooo`0Voooo0013oooo00<0I_ooooooool09oooo`0306Kooooooooo023oool200002_oo
o`800006oooo00<0003oooooool09?ooo`0306Kooooooooo02Woool00`1Vooooooooo`0Voooo0012
oooo00<0I_ooooooool0:Oooo`0306Kooooooooo03?oool00`000?ooooooo`0Toooo00<0I_oooooo
ool0:Oooo`0306Kooooooooo02Koool004;oool00`1Vooooooooo`0Yoooo00<0I_ooooooool0<ooo
o`80000Toooo00<0I_ooooooool0:_ooo`0306Kooooooooo02Koool004;oool00`1Vooooooooo`0Z
oooo00<0I_ooooooool0<_ooo`030000oooooooo02;oool00`1Vooooooooo`0[oooo00<0I_oooooo
ool09_ooo`00@Oooo`0306Kooooooooo02coool00`1Vooooooooo`0aoooo00<0003oooooool08_oo
o`0306Kooooooooo02_oool00`1Vooooooooo`0Voooo0011oooo00<0I_ooooooool0;?ooo`0306Ko
oooooooo037oool00`000?ooooooo`0Qoooo00<0I_ooooooool0;?ooo`0306Kooooooooo02Koool0
047oool00`1Vooooooooo`0]oooo00<0I_ooooooool0<?ooo`030000oooooooo023oool00`1Voooo
ooooo`0]oooo00<0I_ooooooool09_ooo`00@?ooo`0306Kooooooooo02ooool00`1Vooooooooo`0_
oooo0P00027oool00`1Vooooooooo`0]oooo00<0I_ooooooool09_ooo`00@?ooo`0306Kooooooooo
033oool00`1Vooooooooo`0^oooo00<0003oooooool07oooo`0306Kooooooooo02koool00`1Voooo
ooooo`0Voooo000ooooo00<0I_ooooooool0<Oooo`0306Kooooooooo02koool00`000?ooooooo`0N
oooo00<0I_ooooooool0;oooo`0306Kooooooooo02Koool003ooool00`1Vooooooooo`0boooo00<0
I_ooooooool0;Oooo`030000oooooooo01koool00`1Vooooooooo`0_oooo00<0I_ooooooool09_oo
o`00?_ooo`0306Kooooooooo03Coool00`1Vooooooooo`0/oooo00<0003oooooool07Oooo`0306Ko
oooooooo033oool00`1Vooooooooo`0Voooo000noooo00<0I_ooooooool0=Oooo`0306Kooooooooo
02_oool200007Oooo`0306Kooooooooo037oool00`1Vooooooooo`0Voooo000noooo00<0I_oooooo
ool0=_ooo`0306Kooooooooo02[oool00`000?ooooooo`0Koooo00<0I_ooooooool0<_ooo`0306Ko
oooooooo02Koool003goool00`1Vooooooooo`0goooo00<0I_ooooooool0:_ooo`030000oooooooo
01[oool00`1Vooooooooo`0coooo00<0I_ooooooool09_ooo`00?Oooo`0306Kooooooooo03Soool0
0`1Vooooooooo`0Yoooo00<0003oooooool06Oooo`0306Kooooooooo03Coool00`1Vooooooooo`0V
oooo000loooo00<0I_ooooooool0>_ooo`0306Kooooooooo02Soool00`000?ooooooo`0Hoooo00<0
I_ooooooool0=Oooo`0306Kooooooooo02Koool003coool00`1Vooooooooo`0koooo00<0I_oooooo
ool09oooo`80000Hoooo00<0I_ooooooool0=_ooo`0306Kooooooooo02Koool003_oool00`1Voooo
ooooo`0moooo00<0I_ooooooool09_ooo`030000oooooooo01Koool00`1Vooooooooo`0goooo00<0
I_ooooooool09_ooo`00>oooo`0306Kooooooooo03koool00`1Vooooooooo`0Aoooo0P0000Coool2
00000oooo`D00004oooo00<0003oooooool05Oooo`0306Kooooooooo03Soool00`1Vooooooooo`0V
oooo000joooo00<0I_ooooooool0@?ooo`0306Kooooooooo00ooool010000?ooooooo`0000[oool0
0`000?ooooooo`04oooo00<0003oooooool05?ooo`0306Kooooooooo03Woool00`1Vooooooooo`0V
oooo000ioooo00<0I_ooooooool0@_ooo`0306Kooooooooo00koool010000?ooooooo`0000[oool0
0`000?ooooooo`04oooo0P0001Coool00`1Vooooooooo`0joooo00<0I_ooooooool09_ooo`00>Ooo
o`0306Kooooooooo04?oool206Ko2?ooo`@00002oooo00@0003oooooool0000:oooo00<0003ooooo
ool01?ooo`030000oooooooo01;oool00`1Vooooooooo`0koooo00<0I_ooooooool09_ooo`00>?oo
o`0306Kooooooooo04Koool00`1Vooooooooo`0;oooo00@0003oooooool0000:oooo00<0003ooooo
ool01?ooo`030000oooooooo017oool00`1Vooooooooo`0loooo00<0I_ooooooool09_ooo`00>?oo
o`0306Kooooooooo04Ooool00`1Vooooooooo`0;oooo0P0000[oool200001_ooo`030000oooooooo
013oool00`1Vooooooooo`0moooo00<0I_ooooooool09_ooo`00=oooo`0306Kooooooooo04Woool0
0`1Vooooooooo`0Noooo00<0003oooooool03oooo`0306Kooooooooo03koool00`1Vooooooooo`0V
oooo000foooo00<0I_ooooooool0Boooo`0306Kooooooooo01goool200003oooo`0306Kooooooooo
03ooool00`1Vooooooooo`0Voooo000foooo00<0I_ooooooool0C?ooo`0306Kooooooooo01coool0
0`000?ooooooo`0=oooo00<0I_ooooooool0@?ooo`0306Kooooooooo02Koool003Goool00`1Voooo
ooooo`1>oooo0P1Voacoool00`000?ooooooo`0;oooo0P1Vod?oool00`1Vooooooooo`0Voooo000d
oooo00<0I_ooooooool0DOooo`80I_lJoooo00<0003oooooool02Oooo`80I_m5oooo00<0I_oooooo
ool09_ooo`00<oooo`0306Kooooooooo05Coool00`1Vooooooooo`0Goooo00<0003oooooool01ooo
o`80I_m7oooo00<0I_ooooooool09_ooo`00<oooo`0306Kooooooooo05Goool206Ko5oooo`800006
oooo0P1VodWoool00`1Vooooooooo`0Voooo000boooo00<0I_ooooooool0F?ooo`80I_lEoooo00<0
003oooooool00oooo`80I_m;oooo00<0I_ooooooool09_ooo`00<Oooo`0306Kooooooooo05_oool2
06Ko4oooo`030000oooooooo00;oool00`1Vooooooooo`1;oooo00<0I_ooooooool09_ooo`00;ooo
o`80I_mPoooo0P1Voa7oool00`000?ooooooo`0206KoC_ooo`0306Kooooooooo02Koool002Woool3
00000_ooo`0306Kooooooooo02?oool300009?ooo`@0000Doooo0`1Vo`koool00`00001Vo`1Vo`0T
oooo100002Ooool300009oooo`00:Oooo`050000oooooooo000006Ko02Ooool00`000?ooooooo`0S
oooo00<0003oooooool06?ooo`D0I_l6oooo0`1Vo`80000Uoooo00<0003oooooool0:Oooo`030000
oooooooo02Koool002Woool010000?ooo`1Vo`0002Goool500009Oooo`030000oooooooo01coool6
06Ko0oooo`030000oooooooo02Goool00`000?ooooooo`0Uoooo1@0002Ooool002?oool400000_oo
o`<0000Poooo100000;oool010000?ooooooo`0001ooool400001?ooo`030000oooooooo02Coool0
0`000?ooooooo`0Voooo00<0003oooooool09?ooo`040000oooooooo0000:?ooo`009oooo`80I_l0
0oooo`000?ooo`0Woooo00<0003oool000009Oooo`040000oooooooo00009Oooo`030000oooooooo
02Coool010000?ooooooo`0002Koool00`000?ooo`00000Xoooo000Toooo0`1Vo`?oool300009ooo
o`80000Voooo0P0002Koool00`000?ooooooo`0Uoooo0P0002Soool20000:?ooo`008_ooo`80I_n0
oooo0P00057oool00`1Vooooooooo`0Voooo000Ooooo0`1Voh;oool00`000?ooooooo`1@oooo00<0
I_ooooooool09_ooo`006oooo`@0I_n5oooo00<0003oooooool0D?ooo`0306Kooooooooo02Koool0
01Koool506KoROooo`030000oooooooo053oool00`1Vooooooooo`0Voooo000Coooo0`1Vohkoool0
0`000?ooooooo`1@oooo00<0I_ooooooool09_ooo`003Oooool0000600003_ooo`004oooo`030000
oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oool00000300000Dco`000`0003?o03?o0008<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`0003?o03?o0008<ol000<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`08oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003ooooo
ool01oooo`030000oooooooo01;oool002Soool00`000?ooooooo`0Voooo00<0003oooooool08Ooo
o`H0000Y<ol000<0003oooooool09_ooo`030000oooooooo02Koool00`000?ooooooo`0Woooo001j
oooo0`0002Lco`000`000?ooooooo`1?oooo00?o09Woooooool09oooo`00OOooo`80000U<ol000<0
003oooooool0Coooo`03o`2Ioooooooo02Ooool007ooool00`0003?o03?o000R<ol00P00053oool0
0ol0VOooooooo`0Woooo0020oooo00<0000co`0co`008C?o00030000oooooooo04ooool00ol0VOoo
ooooo`0Woooo0021oooo0P00024co`000`000?ooooooo`1?oooo00?o09Woooooool09oooo`00Pooo
o`030000<ol0<ol001hco`000`000?ooooooo`1?oooo00?o09Woooooool09oooo`00Poooo`030000
<ol0<ol001hco`000`000?ooooooo`1?oooo00?o09Woooooool09oooo`00Q?ooo`030000<ol0<ol0
01dco`020000D?ooo`03o`2Ioooooooo02Ooool008Goool00`0003?o03?o000L<ol000<0003ooooo
ool0Coooo`03o`2Ioooooooo02Ooool008Koool00`0003?o03?o000K<ol000<0003oooooool0Cooo
o`03o`2Ioooooooo02Ooool008Koool00`0003?o03?o000K<ol000<0003oooooool0Coooo`03o`2I
oooooooo02Ooool008OooolM<ol0O?ooo`00R?oooa`co`1loooo0028oooo73?o07coool008SooolL
<ol0O?ooo`00ROoooa/co`1loooo001ooooo00<0003oooooool01ooooaDco`000`0003?o03?o0003
<ol0O?ooo`00O_ooo`030000oooooooo00Soool00`0003?o03?o000C<ol000<0000co`0co`000S?o
07coool007koool00`000?ooooooo`02oooo0P0000Coool00`0003?o03?o0007<ol00P0000@co`02
000013?o00030000<ol0<ol0008co`1loooo001noooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`0003?o03?o0005<ol000@0000co`0co`000009<ol000<0000co`0co`000S?o
07coool007goool00`000?ooooooo`02oooo00<0003oooooool01_ooo`Xco`000`0003?o03?o0008
<ol000@0000co`0co`0co`1loooo001noooo00<0003oooooool01@0000Goool8<ol00P0000Xco`00
0`0003?o03?o0002<ol0O?ooo`00O_ooo`050000oooooooooooo000000Woool7<ol000<0000co`0c
o`002C?o00030000<ol0<ol0008co`1loooo001ooooo00<0003oooooool02_ooo`Lco`03000023?o
00030000<ol0<ol000<co`1loooo002<oooo63?o07coool008cooolH<ol0O?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
.2 1 0 r
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
.47015 .62411 L
.47512 .6346 L
.48444 .66014 L
.48965 .67871 L
.49447 .69932 L
.49972 .72635 L
.50537 .76197 L
.51041 .80076 L
.51502 .84337 L
.52407 .95233 L
.52887 1.02779 L
.53412 1.12849 L
.53956 1.25823 L
.54469 1.41066 L
.54963 1.59321 L
.55499 1.84183 L
.55944 2.10113 L
.56434 2.45844 L
.56964 2.96114 L
.57235 3.27835 L
.57525 3.67709 L
.57665 3.89402 L
.57797 4.1172 L
.57915 4.3336 L
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
.97619 .57049 L
.02381 .57049 L
F
0 g
.02381 .57049 m
.03279 .57049 L
.04262 .57049 L
.04758 .57049 L
.05288 .57049 L
.06244 .57049 L
.06788 .57049 L
.07379 .57049 L
.07899 .57049 L
.08451 .57049 L
.08947 .57049 L
.09494 .57049 L
.10458 .57049 L
.10978 .57049 L
.11472 .57049 L
.12399 .57049 L
.13397 .57049 L
.13962 .57049 L
.14487 .57049 L
.14994 .57049 L
.15543 .57049 L
.16539 .57049 L
.17508 .57049 L
.184 .57049 L
.19373 .5705 L
.20282 .5705 L
.21279 .5705 L
.21839 .5705 L
.22348 .5705 L
.2334 .5705 L
.24257 .57051 L
.25264 .57052 L
.25772 .57052 L
.26333 .57053 L
.27342 .57054 L
.28268 .57056 L
.29284 .57059 L
.29795 .57061 L
.30353 .57063 L
.31381 .5707 L
.32314 .57078 L
.32831 .57083 L
.33392 .57091 L
.34409 .57109 L
.35356 .57133 L
.35894 .5715 L
.36397 .5717 L
.37411 .57223 L
.37981 .57262 L
.38501 .57306 L
Mistroke
.39488 .57414 L
.40404 .57554 L
.41408 .57772 L
.41969 .57932 L
.42477 .58108 L
.43482 .58564 L
.44406 .59156 L
.4542 .60077 L
.4593 .60684 L
.46489 .6149 L
Mfstroke
.46489 .6149 m
.46668 .61803 L
s
.58043 .61803 m
.58045 .57049 L
.58167 .57049 L
.58297 .57049 L
.5853 .57049 L
.62302 .57049 L
.66319 .57049 L
.70184 .57049 L
.74295 .57049 L
.78254 .57049 L
.82062 .57049 L
.86115 .57049 L
.90016 .57049 L
.94163 .57049 L
.97619 .57049 L
s
1 0 .6 r
.02381 .57049 m
.06244 .57049 L
.10458 .57049 L
.14415 .57049 L
.18221 .57049 L
.22272 .57049 L
.26171 .57049 L
.30316 .57049 L
.34309 .57049 L
.3815 .57049 L
.42237 .57049 L
.46172 .57049 L
.49955 .57049 L
.53984 .57049 L
.57861 .57049 L
.61984 .57049 L
.65954 .57049 L
.69774 .57049 L
.73838 .57049 L
.77751 .57049 L
.81909 .57049 L
.85916 .57049 L
.89771 .57049 L
.91765 .57049 L
.92769 .57049 L
.93044 .57049 L
.93339 .57049 L
.93482 .57049 L
.93553 .57049 L
.93618 .57049 L
s
.93618 .57049 m
.93618 .61803 L
s
0 .4 1 r
.02381 .55691 m
.04262 .5515 L
.06244 .54345 L
.07286 .53794 L
.08255 .5318 L
.09388 .52315 L
.10458 .5132 L
.125 .48806 L
.14357 .45571 L
.16355 .40664 L
.18199 .34291 L
.20071 .25276 L
.21136 .18637 L
.21653 .14928 L
.21905 .12994 L
.22015 .12124 L
.22134 .11164 L
.22257 .10564 L
.22374 .1099 L
.2263 .11918 L
.23172 .13838 L
.24158 .1719 L
.26011 .2296 L
.30111 .33376 L
.3406 .407 L
.37857 .45748 L
.39808 .47739 L
.419 .49501 L
.43881 .5087 L
.46036 .52076 L
.4793 .52926 L
.5002 .53665 L
.51998 .54181 L
.53081 .54387 L
.53567 .54461 L
.54098 .54527 L
.54345 .54552 L
.54608 .54575 L
.54835 .54591 L
.55082 .54605 L
.55227 .54611 L
.55291 .54614 L
.55361 .54616 L
.55489 .54619 L
.55558 .5462 L
.55624 .5462 L
.55748 .54621 L
.55862 .5462 L
.55992 .54617 L
.56117 .54614 L
Mistroke
.56234 .54609 L
.56339 .54603 L
.56576 .54587 L
.56796 .54567 L
.57002 .54542 L
.57466 .54466 L
.57727 .54409 L
.57967 .54346 L
.60013 .53708 L
.61921 .52986 L
.65724 .51086 L
.67763 .49754 L
.6962 .48308 L
.73609 .44294 L
.77448 .39008 L
.81531 .31577 L
.85463 .22685 L
.89243 .13237 L
.91345 .083 L
.92264 .06411 L
.9275 .05517 L
.93017 .05063 L
.93269 .04662 L
.93388 .0448 L
.93515 .04296 L
.93581 .04202 L
.93654 .57049 L
.93782 .57049 L
.94248 .57049 L
.95157 .57049 L
.97143 .57049 L
.97619 .57049 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.570493 0.950822 [
[.10317 .55799 -6 -9 ]
[.10317 .55799 6 0 ]
[.2619 .55799 -6 -9 ]
[.2619 .55799 6 0 ]
[.42063 .55799 -6 -9 ]
[.42063 .55799 6 0 ]
[.7381 .55799 -3 -9 ]
[.7381 .55799 3 0 ]
[.89683 .55799 -3 -9 ]
[.89683 .55799 3 0 ]
[.56687 .09508 -24 -4.5 ]
[.56687 .09508 0 4.5 ]
[.56687 .19016 -24 -4.5 ]
[.56687 .19016 0 4.5 ]
[.56687 .28525 -24 -4.5 ]
[.56687 .28525 0 4.5 ]
[.56687 .38033 -24 -4.5 ]
[.56687 .38033 0 4.5 ]
[.56687 .47541 -24 -4.5 ]
[.56687 .47541 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .57049 m
.10317 .57674 L
s
[(-6)] .10317 .55799 0 1 Mshowa
.2619 .57049 m
.2619 .57674 L
s
[(-4)] .2619 .55799 0 1 Mshowa
.42063 .57049 m
.42063 .57674 L
s
[(-2)] .42063 .55799 0 1 Mshowa
.7381 .57049 m
.7381 .57674 L
s
[(2)] .7381 .55799 0 1 Mshowa
.89683 .57049 m
.89683 .57674 L
s
[(4)] .89683 .55799 0 1 Mshowa
.125 Mabswid
.14286 .57049 m
.14286 .57424 L
s
.18254 .57049 m
.18254 .57424 L
s
.22222 .57049 m
.22222 .57424 L
s
.30159 .57049 m
.30159 .57424 L
s
.34127 .57049 m
.34127 .57424 L
s
.38095 .57049 m
.38095 .57424 L
s
.46032 .57049 m
.46032 .57424 L
s
.5 .57049 m
.5 .57424 L
s
.53968 .57049 m
.53968 .57424 L
s
.61905 .57049 m
.61905 .57424 L
s
.65873 .57049 m
.65873 .57424 L
s
.69841 .57049 m
.69841 .57424 L
s
.77778 .57049 m
.77778 .57424 L
s
.81746 .57049 m
.81746 .57424 L
s
.85714 .57049 m
.85714 .57424 L
s
.06349 .57049 m
.06349 .57424 L
s
.02381 .57049 m
.02381 .57424 L
s
.93651 .57049 m
.93651 .57424 L
s
.97619 .57049 m
.97619 .57424 L
s
.25 Mabswid
0 .57049 m
1 .57049 L
s
.57937 .09508 m
.58562 .09508 L
s
[(-0.5)] .56687 .09508 1 0 Mshowa
.57937 .19016 m
.58562 .19016 L
s
[(-0.4)] .56687 .19016 1 0 Mshowa
.57937 .28525 m
.58562 .28525 L
s
[(-0.3)] .56687 .28525 1 0 Mshowa
.57937 .38033 m
.58562 .38033 L
s
[(-0.2)] .56687 .38033 1 0 Mshowa
.57937 .47541 m
.58562 .47541 L
s
[(-0.1)] .56687 .47541 1 0 Mshowa
.125 Mabswid
.57937 .01902 m
.58312 .01902 L
s
.57937 .03803 m
.58312 .03803 L
s
.57937 .05705 m
.58312 .05705 L
s
.57937 .07607 m
.58312 .07607 L
s
.57937 .1141 m
.58312 .1141 L
s
.57937 .13312 m
.58312 .13312 L
s
.57937 .15213 m
.58312 .15213 L
s
.57937 .17115 m
.58312 .17115 L
s
.57937 .20918 m
.58312 .20918 L
s
.57937 .2282 m
.58312 .2282 L
s
.57937 .24721 m
.58312 .24721 L
s
.57937 .26623 m
.58312 .26623 L
s
.57937 .30426 m
.58312 .30426 L
s
.57937 .32328 m
.58312 .32328 L
s
.57937 .3423 m
.58312 .3423 L
s
.57937 .36131 m
.58312 .36131 L
s
.57937 .39935 m
.58312 .39935 L
s
.57937 .41836 m
.58312 .41836 L
s
.57937 .43738 m
.58312 .43738 L
s
.57937 .45639 m
.58312 .45639 L
s
.57937 .49443 m
.58312 .49443 L
s
.57937 .51344 m
.58312 .51344 L
s
.57937 .53246 m
.58312 .53246 L
s
.57937 .55148 m
.58312 .55148 L
s
.57937 .58951 m
.58312 .58951 L
s
.57937 .60853 m
.58312 .60853 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oY?ooo`030000
oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?oo
o`030000oooooooo07Woool00:Coool00`000?ooooooo`1ioooo002Toooo0P0007[oool00:Coool0
0`000?ooooooo`1ioooo002Toooo00<0003oooooool0NOooo`00Y?ooo`030000oooooooo07Woool0
0:Coool20000N_ooo`00Y?ooo`030000oooooooo07Woool00:Coool00`000?ooooooo`1Ioooo0P1V
oakoool00:Coool00`000?ooooooo`1Ioooo0P1Voakoool00:Coool00`000?ooooooo`1Hoooo00<0
I_ooool0I_l07_ooo`00Y?ooo`80001Hoooo00@0I_ooooooool0I_lNoooo002Toooo00<0003ooooo
ool0E_ooo`0506Kooooooooooooo06Ko01koool00:Coool00`000?ooooooo`1Foooo00D0I_oooooo
ooooool0I_l07_ooo`00Y?ooo`030000oooooooo05Koool01@1Vooooooooooooo`1Vo`0Noooo002T
oooo00<0003oooooool0EOooo`0306Kooooooooo00;oool00`1Vooooooooo`0Loooo002Toooo0P00
05Koool00`1Vooooooooo`02oooo00<0I_ooooooool07?ooo`00Y?ooo`030000oooooooo05Coool0
0`1Vooooooooo`03oooo00<0I_ooooooool07?ooo`00Y?ooo`030000oooooooo05Coool00`1Voooo
ooooo`03oooo00<0I_ooooooool07?ooo`00T?ooo`800004oooo0P0000Coool200001_ooo`030000
oooooooo05Coool00`1Vooooooooo`03oooo00<0I_ooooooool07?ooo`00Soooo`040000oooooooo
00002?ooo`040000oooooooo00001Oooo`030000oooooooo05?oool00`1Vooooooooo`04oooo00<0
I_ooooooool07?ooo`00Soooo`040000oooooooo00002oooo`030000oooooooo00?oool20000E?oo
o`0306Kooooooooo00Coool00`1Vooooooooo`0Loooo0029oooo100000;oool010000?ooooooo`00
00Woool200001_ooo`030000oooooooo05;oool00`1Vooooooooo`05oooo00<0I_ooooooool07?oo
o`00Soooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`1Boooo00<0
I_ooooooool01Oooo`0306Kooooooooo01coool004Ooool00`1Vooooooooo`16oooo0P0000[oool3
00001Oooo`030000oooooooo057oool00`1Vooooooooo`06oooo00<0I_ooooooool07?ooo`00A_oo
o`80I_mLoooo00<0003oooooool0DOooo`0306Kooooooooo00Koool00`1Vooooooooo`0Loooo0016
oooo0P1Voecoool20000DOooo`0306Kooooooooo00Ooool00`1Vooooooooo`0Loooo0016oooo00<0
I_ooool0I_l0Foooo`030000oooooooo053oool00`1Vooooooooo`07oooo00<0I_ooooooool07?oo
o`00A_ooo`0306Kooooo06Ko05_oool00`000?ooooooo`1?oooo00<0I_ooooooool02?ooo`0306Ko
oooooooo01coool004Koool00`1Vooooo`1Vo`1Koooo00<0003oooooool0Coooo`0306Kooooooooo
00Soool00`1Vooooooooo`0Loooo0016oooo00<0I_ooool0I_l0Foooo`030000oooooooo04koool0
0`1Vooooooooo`09oooo00<0I_ooooooool07?ooo`00A_ooo`0406Kooooooooo06KoF_ooo`80001?
oooo00<0I_ooooooool02Oooo`0306Kooooooooo01coool004Koool0101Vooooooooo`1Voe[oool0
0`000?ooooooo`1>oooo00<0I_ooooooool02Oooo`0306Kooooooooo01coool004Goool01@1Voooo
ooooooooo`1Vo`1Joooo00<0003oooooool0COooo`0306Kooooooooo00[oool00`1Vooooooooo`0L
oooo0015oooo00D0I_ooooooooooool0I_l0F_ooo`030000oooooooo04goool00`1Vooooooooo`0:
oooo00<0I_ooooooool07?ooo`00AOooo`0306Kooooooooo00;oool00`1Vooooooooo`1Goooo00<0
003oooooool0C?ooo`0306Kooooooooo00_oool00`1Vooooooooo`0Loooo0015oooo00<0I_oooooo
ool00_ooo`0306Kooooooooo05Ooool20000COooo`0306Kooooooooo00_oool00`1Vooooooooo`0L
oooo0015oooo00<0I_ooooooool00_ooo`0306Kooooooooo05Ooool00`000?ooooooo`1<oooo00<0
I_ooooooool02oooo`0306Kooooooooo01coool004Goool00`1Vooooooooo`03oooo00<0I_oooooo
ool0E_ooo`030000oooooooo04_oool00`1Vooooooooo`0<oooo00<0I_ooooooool07?ooo`00AOoo
o`0306Kooooooooo00?oool00`1Vooooooooo`1Foooo00<0003oooooool0Boooo`0306Kooooooooo
00coool00`1Vooooooooo`0Loooo0014oooo00<0I_ooooooool01Oooo`0306Kooooooooo05Goool0
0`000?ooooooo`1:oooo00<0I_ooooooool03Oooo`0306Kooooooooo01coool004Coool00`1Voooo
ooooo`05oooo00<0I_ooooooool0EOooo`80001;oooo00<0I_ooooooool03Oooo`0306Kooooooooo
01coool004Coool00`1Vooooooooo`05oooo00<0I_ooooooool0EOooo`030000oooooooo04[oool0
0`1Vooooooooo`0=oooo00<0I_ooooooool07?ooo`00A?ooo`0306Kooooooooo00Koool00`1Voooo
ooooo`1Doooo00<0003oooooool0BOooo`0306Kooooooooo00koool00`1Vooooooooo`0Loooo0014
oooo00<0I_ooooooool01_ooo`0306Kooooooooo043oool200001?ooo`800005oooo0`0000Coool0
0`000?ooooooo`19oooo00<0I_ooooooool03_ooo`0306Kooooooooo01coool004Coool00`1Voooo
ooooo`06oooo00<0I_ooooooool0?oooo`040000oooooooo00002oooo`030000oooooooo00?oool0
0`000?ooooooo`18oooo00<0I_ooooooool03oooo`0306Kooooooooo01coool004Coool00`1Voooo
ooooo`06oooo00<0I_ooooooool0?oooo`040000oooooooo00002?ooo`D00004oooo0P0004Woool0
0`1Vooooooooo`0?oooo00<0I_ooooooool07?ooo`00A?ooo`0306Kooooooooo00Ooool00`1Voooo
ooooo`0hoooo100000;oool010000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?oo
ooooo`18oooo00<0I_ooooooool03oooo`0306Kooooooooo01coool004?oool00`1Vooooooooo`08
oooo00<0I_ooooooool0?_ooo`040000oooooooo00002Oooo`030000oooo000000Goool00`000?oo
ooooo`17oooo00<0I_ooooooool04?ooo`0306Kooooooooo01coool004?oool00`1Vooooooooo`08
oooo00<0I_ooooooool0?oooo`80000;oooo0P0000Goool00`000?ooooooo`17oooo00<0I_oooooo
ool04?ooo`0306Kooooooooo01coool004?oool00`1Vooooooooo`08oooo00<0I_ooooooool0Dooo
o`030000oooooooo04Koool00`1Vooooooooo`0Aoooo00<0I_ooooooool07?ooo`00@oooo`0306Ko
oooooooo00Woool00`1Vooooooooo`1Boooo0P0004Ooool00`1Vooooooooo`0Aoooo00<0I_oooooo
ool07?ooo`00@oooo`0306Kooooooooo00Woool00`1Vooooooooo`1Boooo00<0003oooooool0A_oo
o`0306Kooooooooo017oool00`1Vooooooooo`0Loooo0013oooo00<0I_ooooooool02Oooo`0306Ko
oooooooo05;oool00`000?ooooooo`15oooo00<0I_ooooooool04_ooo`0306Kooooooooo01coool0
04;oool00`1Vooooooooo`0:oooo00<0I_ooooooool0D_ooo`030000oooooooo04Goool00`1Voooo
ooooo`0Boooo00<0I_ooooooool07?ooo`00@_ooo`0306Kooooooooo00_oool00`1Vooooooooo`1A
oooo00<0003oooooool0A?ooo`0306Kooooooooo01?oool00`1Vooooooooo`0Loooo0012oooo00<0
I_ooooooool02oooo`0306Kooooooooo057oool20000AOooo`0306Kooooooooo01?oool00`1Voooo
ooooo`0Loooo0012oooo00<0I_ooooooool02oooo`0306Kooooooooo057oool00`000?ooooooo`14
oooo00<0I_ooooooool04oooo`0306Kooooooooo01coool004;oool00`1Vooooooooo`0<oooo00<0
I_ooooooool0D?ooo`030000oooooooo04?oool00`1Vooooooooo`0Doooo00<0I_ooooooool07?oo
o`00@_ooo`0306Kooooooooo00coool00`1Vooooooooo`1@oooo00<0003oooooool0@oooo`0306Ko
oooooooo01Coool00`1Vooooooooo`0Loooo0011oooo00<0I_ooooooool03_ooo`0306Kooooooooo
04ooool00`000?ooooooo`12oooo00<0I_ooooooool05Oooo`0306Kooooooooo01coool0047oool0
0`1Vooooooooo`0>oooo00<0I_ooooooool0Coooo`800013oooo00<0I_ooooooool05Oooo`0306Ko
oooooooo01coool0047oool00`1Vooooooooo`0>oooo00<0I_ooooooool0Coooo`030000oooooooo
047oool00`1Vooooooooo`0Foooo00<0I_ooooooool07?ooo`00@Oooo`0306Kooooooooo00ooool0
0`1Vooooooooo`1>oooo00<0003oooooool0@Oooo`0306Kooooooooo01Koool00`1Vooooooooo`0L
oooo0011oooo00<0I_ooooooool03oooo`0306Kooooooooo04koool00`000?ooooooo`11oooo00<0
I_ooooooool05_ooo`0306Kooooooooo01coool0043oool00`1Vooooooooo`0Aoooo00<0I_oooooo
ool0COooo`030000oooooooo043oool00`1Vooooooooo`0Goooo00<0I_ooooooool07?ooo`00@?oo
o`0306Kooooooooo017oool00`1Vooooooooo`1=oooo0P00047oool00`1Vooooooooo`0Goooo00<0
I_ooooooool07?ooo`00@?ooo`0306Kooooooooo017oool00`1Vooooooooo`1=oooo00<0003ooooo
ool0?oooo`0306Kooooooooo01Soool00`1Vooooooooo`0Loooo0010oooo00<0I_ooooooool04_oo
o`0306Kooooooooo04coool00`000?ooooooo`0ooooo00<0I_ooooooool06?ooo`0306Kooooooooo
01coool0043oool00`1Vooooooooo`0Boooo00<0I_ooooooool0>?ooo`800004oooo0P0000Coool2
00001_ooo`030000oooooooo03koool00`1Vooooooooo`0Ioooo00<0I_ooooooool07?ooo`00?ooo
o`0306Kooooooooo01?oool00`1Vooooooooo`0goooo00@0003oooooool00008oooo00@0003ooooo
ool00005oooo00<0003oooooool0?_ooo`0306Kooooooooo01Woool00`1Vooooooooo`0Loooo000o
oooo00<0I_ooooooool05?ooo`0306Kooooooooo03Koool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo0P0003koool00`1Vooooooooo`0Joooo00<0I_ooooooool07?ooo`00?oooo`0306Ko
oooooooo01Coool00`1Vooooooooo`0`oooo100000;oool010000?ooooooo`0000_oool00`000?oo
ooooo`03oooo00<0003oooooool0?Oooo`0306Kooooooooo01[oool00`1Vooooooooo`0Loooo000o
oooo00<0I_ooooooool05Oooo`0306Kooooooooo03Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000Goool00`000?ooooooo`0moooo00<0I_ooooooool06_ooo`0306Kooooooooo01coool0
03koool00`1Vooooooooo`0Foooo00<0I_ooooooool0=_ooo`80000:oooo0P0000Koool00`000?oo
ooooo`0loooo00<0I_ooooooool06oooo`0306Kooooooooo01coool003koool00`1Vooooooooo`0F
oooo00<0I_ooooooool0B_ooo`030000oooooooo03coool00`1Vooooooooo`0Koooo00<0I_oooooo
ool07?ooo`00?_ooo`0306Kooooooooo01Ooool00`1Vooooooooo`19oooo0P0003coool00`1Voooo
ooooo`0Loooo00<0I_ooooooool07?ooo`00?_ooo`0306Kooooooooo01Ooool00`1Vooooooooo`19
oooo00<0003oooooool0>oooo`0306Kooooooooo01coool00`1Vooooooooo`0Loooo000noooo00<0
I_ooooooool06?ooo`0306Kooooooooo04Soool00`000?ooooooo`0joooo00<0I_ooooooool07Ooo
o`0306Kooooooooo01coool003goool00`1Vooooooooo`0Ioooo00<0I_ooooooool0B?ooo`030000
oooooooo03[oool00`1Vooooooooo`0Moooo00<0I_ooooooool07?ooo`00?Oooo`0306Kooooooooo
01Woool00`1Vooooooooo`18oooo00<0003oooooool0>Oooo`0306Kooooooooo01koool00`1Voooo
ooooo`0Loooo000moooo00<0I_ooooooool06_ooo`0306Kooooooooo04Ooool20000>_ooo`0306Ko
oooooooo01koool00`1Vooooooooo`0Loooo000moooo00<0I_ooooooool06_ooo`0306Kooooooooo
04Ooool00`000?ooooooo`0hoooo00<0I_ooooooool07oooo`0306Kooooooooo01coool003goool0
0`1Vooooooooo`0Koooo00<0I_ooooooool0A_ooo`030000oooooooo03Soool00`1Vooooooooo`0O
oooo00<0I_ooooooool07?ooo`00??ooo`0306Kooooooooo01coool00`1Vooooooooo`16oooo00<0
003oooooool0=oooo`0306Kooooooooo023oool00`1Vooooooooo`0Loooo000loooo00<0I_oooooo
ool07Oooo`0306Kooooooooo04Goool00`000?ooooooo`0goooo00<0I_ooooooool08?ooo`0306Ko
oooooooo01coool003coool00`1Vooooooooo`0Moooo00<0I_ooooooool0AOooo`80000goooo00<0
I_ooooooool08Oooo`0306Kooooooooo01coool003coool00`1Vooooooooo`0Noooo00<0I_oooooo
ool0A?ooo`030000oooooooo03Koool00`1Vooooooooo`0Qoooo00<0I_ooooooool07?ooo`00>ooo
o`0306Kooooooooo01ooool00`1Vooooooooo`14oooo00<0003oooooool0=Oooo`0306Kooooooooo
02;oool00`1Vooooooooo`0Loooo000koooo00<0I_ooooooool08?ooo`0306Kooooooooo04?oool0
0`000?ooooooo`0eoooo00<0I_ooooooool08_ooo`0306Kooooooooo01coool003_oool00`1Voooo
ooooo`0Poooo00<0I_ooooooool0@oooo`030000oooooooo03Coool00`1Vooooooooo`0Soooo00<0
I_ooooooool07?ooo`00>oooo`0306Kooooooooo027oool00`1Vooooooooo`12oooo0P0003Goool0
0`1Vooooooooo`0Soooo00<0I_ooooooool07?ooo`00>_ooo`0306Kooooooooo02;oool00`1Voooo
ooooo`12oooo00<0003oooooool0<oooo`0306Kooooooooo02Coool00`1Vooooooooo`0Loooo000j
oooo00<0I_ooooooool08oooo`0306Kooooooooo047oool00`000?ooooooo`0coooo00<0I_oooooo
ool09?ooo`0306Kooooooooo01coool003[oool00`1Vooooooooo`0Soooo00<0I_ooooooool0;Ooo
o`800004oooo0P0000?oool400001Oooo`030000oooooooo03;oool00`1Vooooooooo`0Uoooo00<0
I_ooooooool07?ooo`00>Oooo`0306Kooooooooo02Goool00`1Vooooooooo`0[oooo00@0003ooooo
ool00008oooo00<0003oooooool01_ooo`030000oooooooo03;oool00`1Vooooooooo`0Uoooo00<0
I_ooooooool07?ooo`00>Oooo`0306Kooooooooo02Goool00`1Vooooooooo`0[oooo00@0003ooooo
ool00009oooo00<0003oooooool01Oooo`80000boooo00<0I_ooooooool09_ooo`0306Kooooooooo
01coool003Woool00`1Vooooooooo`0Voooo00<0I_ooooooool09?ooo`@00002oooo00@0003ooooo
ool0000:oooo00<0003oooooool01?ooo`030000oooooooo037oool00`1Vooooooooo`0Voooo00<0
I_ooooooool07?ooo`00>?ooo`0306Kooooooooo02Ooool00`1Vooooooooo`0Zoooo00@0003ooooo
ool00008oooo00@0003oooooool00005oooo00<0003oooooool0<?ooo`0306Kooooooooo02Ooool0
0`1Vooooooooo`0Loooo000hoooo00<0I_ooooooool0:?ooo`0306Kooooooooo02[oool200002_oo
o`800006oooo00<0003oooooool0;oooo`0306Kooooooooo02Soool00`1Vooooooooo`0Loooo000h
oooo00<0I_ooooooool0:?ooo`0306Kooooooooo03koool00`000?ooooooo`0_oooo00<0I_oooooo
ool0:?ooo`0306Kooooooooo01coool003Soool00`1Vooooooooo`0Yoooo00<0I_ooooooool0?Ooo
o`80000_oooo00<0I_ooooooool0:Oooo`0306Kooooooooo01coool003Ooool00`1Vooooooooo`0Z
oooo00<0I_ooooooool0?Oooo`030000oooooooo02goool00`1Vooooooooo`0Zoooo00<0I_oooooo
ool07?ooo`00=oooo`0306Kooooooooo02_oool00`1Vooooooooo`0loooo00<0003oooooool0;?oo
o`0306Kooooooooo02_oool00`1Vooooooooo`0Loooo000goooo00<0I_ooooooool0;?ooo`0306Ko
oooooooo03_oool00`000?ooooooo`0/oooo00<0I_ooooooool0:oooo`0306Kooooooooo01coool0
03Koool00`1Vooooooooo`0^oooo00<0I_ooooooool0>_ooo`030000oooooooo02_oool00`1Voooo
ooooo`0/oooo00<0I_ooooooool07?ooo`00=_ooo`0306Kooooooooo02koool00`1Vooooooooo`0j
oooo0P0002_oool00`1Vooooooooo`0]oooo00<0I_ooooooool07?ooo`00=Oooo`0306Kooooooooo
033oool00`1Vooooooooo`0ioooo00<0003oooooool0:_ooo`0306Kooooooooo02goool00`1Voooo
ooooo`0Loooo000eoooo00<0I_ooooooool0<Oooo`0306Kooooooooo03Soool00`000?ooooooo`0Y
oooo00<0I_ooooooool0;_ooo`0306Kooooooooo01coool003Coool00`1Vooooooooo`0coooo00<0
I_ooooooool0=oooo`030000oooooooo02Soool00`1Vooooooooo`0_oooo00<0I_ooooooool07?oo
o`00=?ooo`0306Kooooooooo03?oool00`1Vooooooooo`0goooo00<0003oooooool09oooo`0306Ko
oooooooo033oool00`1Vooooooooo`0Loooo000doooo00<0I_ooooooool0=?ooo`0306Kooooooooo
03Koool20000:?ooo`0306Kooooooooo033oool00`1Vooooooooo`0Loooo000coooo00<0I_oooooo
ool0=_ooo`0306Kooooooooo03Goool00`000?ooooooo`0Voooo00<0I_ooooooool0<Oooo`0306Ko
oooooooo01coool003?oool00`1Vooooooooo`0goooo00<0I_ooooooool0=?ooo`030000oooooooo
02Goool00`1Vooooooooo`0boooo00<0I_ooooooool07?ooo`00<_ooo`0306Kooooooooo03Soool0
0`1Vooooooooo`0doooo00<0003oooooool09?ooo`0306Kooooooooo03?oool00`1Vooooooooo`0L
oooo000boooo00<0I_ooooooool0>Oooo`0306Kooooooooo03?oool00`000?ooooooo`0Soooo00<0
I_ooooooool0=?ooo`0306Kooooooooo01coool0037oool00`1Vooooooooo`0koooo00<0I_oooooo
ool0<_ooo`80000Soooo00<0I_ooooooool0=Oooo`0306Kooooooooo01coool0037oool00`1Voooo
ooooo`0loooo00<0I_ooooooool0<Oooo`030000oooooooo023oool206Ko>?ooo`0306Kooooooooo
01coool0033oool00`1Vooooooooo`0noooo00<0I_ooooooool07?ooo`800004oooo0P0000?oool5
00001?ooo`030000oooooooo01ooool00`1Vooooooooo`0hoooo00<0I_ooooooool07?ooo`00<?oo
o`0306Kooooooooo03ooool00`1Vooooooooo`0Joooo00@0003oooooool0000:oooo00<0003ooooo
ool01?ooo`030000oooooooo01koool00`1Vooooooooo`0ioooo00<0I_ooooooool07?ooo`00;ooo
o`0306Kooooooooo047oool00`1Vooooooooo`0Ioooo00@0003oooooool0000:oooo00<0003ooooo
ool01?ooo`80000Noooo00<0I_ooooooool0>_ooo`0306Kooooooooo01coool002ooool00`1Voooo
ooooo`12oooo00<0I_ooooooool04_ooo`@00002oooo00@0003oooooool0000:oooo00<0003ooooo
ool01?ooo`030000oooooooo01coool00`1Vooooooooo`0koooo00<0I_ooooooool07?ooo`00;_oo
o`0306Kooooooooo04Coool00`1Vooooooooo`0Goooo00@0003oooooool0000:oooo00<0003ooooo
ool01?ooo`030000oooooooo01_oool00`1Vooooooooo`0loooo00<0I_ooooooool07?ooo`00;_oo
o`0306Kooooooooo04Goool00`1Vooooooooo`0Goooo0P0000[oool200001_ooo`030000oooooooo
01[oool00`1Vooooooooo`0moooo00<0I_ooooooool07?ooo`00;Oooo`0306Kooooooooo04Ooool2
06Ko:oooo`030000oooooooo01Soool206Ko@?ooo`0306Kooooooooo01coool002coool00`1Voooo
ooooo`1:oooo00<0I_ooooooool0:?ooo`80000Hoooo00<0I_ooooooool0@?ooo`0306Kooooooooo
01coool002_oool00`1Vooooooooo`1<oooo00<0I_ooooooool09oooo`030000oooooooo01Koool0
0`1Vooooooooo`11oooo00<0I_ooooooool07?ooo`00:_ooo`0306Kooooooooo04koool206Ko9ooo
o`030000oooooooo01Goool00`1Vooooooooo`12oooo00<0I_ooooooool07?ooo`00:_ooo`0306Ko
oooooooo053oool206Ko9Oooo`030000oooooooo01?oool206KoAOooo`0306Kooooooooo01coool0
02Woool00`1Vooooooooo`1Coooo00<0I_ooooooool08_ooo`030000oooooooo01;oool00`1Voooo
ooooo`15oooo00<0I_ooooooool07?ooo`00:?ooo`0306Kooooooooo05Goool206Ko8_ooo`80000B
oooo00<0I_ooooooool0A_ooo`0306Kooooooooo01coool002Ooool00`1Vooooooooo`1Hoooo0P1V
ob3oool00`000?ooooooo`0?oooo0P1VodWoool00`1Vooooooooo`0Loooo000Voooo00<0I_oooooo
ool0Foooo`80I_lNoooo00<0003oooooool03Oooo`80I_m;oooo00<0I_ooooooool07?ooo`009Ooo
o`0306Kooooooooo05koool206Ko7?ooo`030000oooooooo00_oool206KoCOooo`0306Kooooooooo
01coool002?oool206Ko1?ooo`<0000Xoooo0`0002Coool400002Oooo`80I_lJoooo00<0003ooooo
ool02Oooo`80I_lIoooo100002Ooool300002?ooo`0306Kooooooooo01coool002;oool00`1Voooo
ooooo`04oooo00@0003oooooool0000Xoooo00<0003oooooool08oooo`030000oooooooo00coool3
06Ko5oooo`800007oooo0`1Voa_oool00`000?ooooooo`0Yoooo00<0003oooooool01oooo`0306Ko
oooooooo01coool0027oool00`1Vooooooooo`05oooo00@0003oooooool0000Uoooo1@0002Goool0
0`000?ooooooo`0>oooo101Voa?oool00`000?ooooooo`04oooo0P1Voaooool00`000?ooooooo`0U
oooo1@0000Soool00`1Vooooooooo`0Loooo000Ooooo0P1Vo`;oool400000_ooo`<0000Poooo1000
00;oool010000?ooooooo`0001ooool400001?ooo`030000oooooooo017oool206Ko4Oooo`030000
oooooooo00@0I_lRoooo00<0003oooooool09?ooo`040000oooooooo00002Oooo`0306Kooooooooo
01coool001coool306Ko2oooo`030000oooooooo02Koool00`000?ooo`00000Uoooo00@0003ooooo
ool0000Doooo1@1Vo`_oool0101Vo`00001Vo`1VobCoool010000?ooooooo`0002Koool00`000?oo
o`000009oooo00<0I_ooooooool07?ooo`006_ooo`80I_l>oooo0`0002Ooool200009_ooo`80000J
oooo2`1Vo`03oooo0000oooo02Koool20000:?ooo`800009oooo00<0I_ooooooool07?ooo`005ooo
o`<0I_n:oooo0P0005_oool00`1Vooooooooo`0Loooo000Eoooo0P1Vohgoool00`000?ooooooo`1J
oooo00<0I_ooooooool07?ooo`004oooo`80I_n?oooo00<0003oooooool0F_ooo`0306Kooooooooo
01coool00:Coool00`000?ooooooo`1Joooo00<0I_ooooooool07?ooo`00Y?ooo`030000oooooooo
05[oool00`1Vooooooooo`0Loooo000=ooooo`0000H0000>oooo000Coooo00<0003oooooool01ooo
o`030000oooooooo00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?oo
o`00000<00001C?o00030000<ol0<ol000Pco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Pco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool04_ooo`00:?ooo`030000oooooooo02Koool00`000?ooooooo`0Qoooo1P0002Tco`00
0`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo00Soool00ol0VOooooooo`0L
oooo001joooo0`0002Lco`000`000?ooooooo`1Joooo00?o09Woooooool07?ooo`00OOooo`80000U
<ol000<0003oooooool0F_ooo`03o`2Ioooooooo01coool007ooool00`0003?o03?o000R<ol00P00
05_oool00ol0VOooooooo`0Loooo0020oooo00<0000co`0co`008C?o00030000oooooooo05[oool0
0ol0VOooooooo`0Loooo0021oooo0P00024co`000`000?ooooooo`1Joooo00?o09Woooooool07?oo
o`00Poooo`030000<ol0<ol001hco`000`000?ooooooo`1Joooo00?o09Woooooool07?ooo`00Pooo
o`030000<ol0<ol001hco`000`000?ooooooo`1Joooo00?o09Woooooool07?ooo`00Q?ooo`030000
<ol0<ol001dco`020000Foooo`03o`2Ioooooooo01coool008Goool00`0003?o03?o000L<ol000<0
003oooooool0F_ooo`03o`2Ioooooooo01coool008Koool00`0003?o03?o000K<ol000<0003ooooo
ool0F_ooo`03o`2Ioooooooo01coool008Koool00`0003?o03?o000K<ol000<0003oooooool0F_oo
o`03o`2Ioooooooo01coool008OooolM<ol0O?ooo`00R?oooa`co`1loooo0028oooo73?o07coool0
08SooolL<ol0O?ooo`00ROoooa/co`1loooo001loooo00<0003oooooool02_oooaPco`000`0003?o
03?o001loooo001koooo00<0003oooooool02?ooo`040000oooooooooooo63?o00030000<ol0oooo
07_oool007_oool00`000?ooooooo`02oooo0P0000Coool010000?ooooooooooo`Hco`02000013?o
00800004<ol00P0000@co`000`0003?o0?ooo`1koooo001koooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool010000?ooooooooooo`@co`00100003?o03?o000000Pco`00100003?o
03?o000000<co`000`0003?o0?ooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo
00Woool7<ol000<0000co`0co`002C?o00030000<ol0<ol0008co`000`000?ooooooo`1joooo001k
oooo00<0003oooooool01@0000Soool5<ol00P0000Xco`02000013?o00030000<ol0oooo07_oool0
07_oool01@000?ooooooooooo`00000<oooo13?o00030000<ol0<ol000Tco`000`0003?o03?o0003
<ol000<0000co`3oool0Noooo`00O?ooo`030000oooooooo00goool4<ol00`0000Tco`0300000S?o
00030000<ol0<ol007coool008cooolH<ol0O?ooo`00S?oooaPco`1loooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-7.93429, \
-0.600003, 0.0483331, 0.00403436}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-7.93429, -0.600003, 0.0483331, 0.00403436}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Animate[{FilledPlot\[IndentingNewLine][{v[x]}, \ {x, \ \(-2\), \ 
              0.5}, \ PlotRange -> {\(- .05\),  .05}, \ 
            Fills \[Rule] {Hue[ .3]}], \[IndentingNewLine]\ \ \ \ \ \ \ \
Plot[{10\ UnitStep[x - x0 - t]}, \ {x, \ \(-2\), \ 0.5}, \ 
            PlotStyle \[Rule] \ Hue[ .9], 
            PlotRange -> {\(- .05\),  .05}], \[IndentingNewLine]\ \ \ \ \ \ \ \
Plot[{g[x, t]}, {x, \ \(-2\), \ 0.5}, \ PlotStyle \[Rule] \ Hue[ .6], \ 
            PlotRange -> {\(- .05\),  .05}]}, \[IndentingNewLine]\ {t, \ \
\(-0.3\), \ 0.3,  .01}, PlotLabel \[Rule] {"\<t\>", t}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.27193 .30902 L
.27731 .30902 L
.28302 .30902 L
.28542 .30902 L
.288 .30902 L
.28876 .30902 L
.28948 .30902 L
.29013 .30902 L
s
.29013 .30902 m
.29013 .61803 L
s
0 .4 1 r
.02381 .3471 m
.06244 .35298 L
.10458 .36044 L
.14415 .3686 L
.18221 .37768 L
.22272 .38888 L
.26171 .4014 L
.27193 .40499 L
.27731 .40695 L
.28302 .40906 L
.28542 .40996 L
.288 .41094 L
.28876 .41123 L
.28948 .41151 L
.29013 .41176 L
.29083 .30902 L
.2915 .30902 L
.29221 .30902 L
.29349 .30902 L
.29474 .30902 L
.29545 .30902 L
.2961 .30902 L
.29729 .30902 L
.29856 .30902 L
.29969 .30902 L
.30075 .30902 L
.30191 .30902 L
.30316 .30902 L
.30437 .30902 L
.30507 .30902 L
.30572 .30902 L
.30703 .30902 L
.30776 .30902 L
.30844 .30902 L
.30958 .30902 L
.31082 .30902 L
.31212 .30902 L
.31333 .30902 L
.31402 .30902 L
.31477 .30902 L
.31543 .30902 L
.31613 .30902 L
.31676 .30902 L
.31746 .30902 L
.31868 .30902 L
.31942 .30902 L
.3201 .30902 L
.32089 .30902 L
.32163 .30902 L
.32295 .30902 L
Mistroke
.3237 .30902 L
.3244 .30902 L
.32566 .30902 L
.32638 .30902 L
.32703 .30902 L
.32824 .30902 L
.32951 .30902 L
.33065 .30902 L
.33172 .30902 L
.33289 .30902 L
.33414 .30902 L
.33484 .30902 L
.33548 .30902 L
.33618 .30902 L
.33693 .30902 L
.33819 .30902 L
.3389 .30902 L
.33957 .30902 L
.34081 .30902 L
.34195 .30902 L
.3432 .30902 L
.34452 .30902 L
.34576 .30902 L
.34646 .30902 L
.3471 .30902 L
.34828 .30902 L
.34953 .30902 L
.35066 .30902 L
.3517 .30902 L
.35285 .30902 L
.35409 .30902 L
.3554 .30902 L
.35614 .30902 L
.35683 .30902 L
.35809 .30902 L
.35872 .30902 L
.35943 .30902 L
.36063 .30902 L
.36194 .30902 L
.36317 .30902 L
.3643 .30902 L
.36537 .30902 L
.36651 .30902 L
.3675 .30902 L
.36857 .30902 L
.36983 .30902 L
.37102 .30902 L
.37218 .30902 L
.37325 .30902 L
.37437 .30902 L
Mistroke
.37543 .30902 L
.37658 .30902 L
.37783 .30902 L
.37913 .30902 L
.38036 .30902 L
.38147 .30902 L
.38268 .30902 L
.38332 .30902 L
.38401 .30902 L
.38523 .30902 L
.38655 .30902 L
.3873 .30902 L
.388 .30902 L
.38926 .30902 L
.39041 .30902 L
.39105 .30902 L
.39175 .30902 L
.39301 .30902 L
.39413 .30902 L
.39536 .30902 L
.39666 .30902 L
.39787 .30902 L
.399 .30902 L
.40003 .30902 L
.40117 .30902 L
.40236 .30902 L
.40368 .30902 L
.40488 .30902 L
.40554 .30902 L
.40626 .30902 L
.40756 .30902 L
.40878 .30902 L
.41007 .30902 L
.41117 .30902 L
.41239 .30902 L
.41312 .30902 L
.41381 .30902 L
.41512 .30902 L
.41584 .30902 L
.41652 .30902 L
.41726 .30902 L
.41805 .30902 L
.41874 .30902 L
.41948 .30902 L
.42018 .30902 L
.42083 .30902 L
.42205 .30902 L
.42334 .30902 L
.42457 .30902 L
.42526 .30902 L
Mistroke
.4259 .30902 L
.42708 .30902 L
.42832 .30902 L
.42944 .30902 L
.43048 .30902 L
.43162 .30902 L
.43286 .30902 L
.43416 .30902 L
.4349 .30902 L
.43558 .30902 L
.43683 .30902 L
.43753 .30902 L
.43817 .30902 L
.43937 .30902 L
.44067 .30902 L
.4419 .30902 L
.44303 .30902 L
.4441 .30902 L
.44523 .30902 L
.44631 .30902 L
.44729 .30902 L
.44844 .30902 L
.44969 .30902 L
.45087 .30902 L
.45196 .30902 L
.45308 .30902 L
.45413 .30902 L
.45528 .30902 L
.45653 .30902 L
.45776 .30902 L
.45906 .30902 L
.46017 .30902 L
.46139 .30902 L
.4627 .30902 L
.46392 .30902 L
.46456 .30902 L
.46525 .30902 L
.46598 .30902 L
.46667 .30902 L
.46792 .30902 L
.46907 .30902 L
.46971 .30902 L
.4704 .30902 L
.47165 .30902 L
.47289 .30902 L
.474 .30902 L
.47529 .30902 L
.4765 .30902 L
.47762 .30902 L
.47866 .30902 L
Mistroke
.47979 .30902 L
.48099 .30902 L
.48229 .30902 L
.48348 .30902 L
.48414 .30902 L
.48486 .30902 L
.48616 .30902 L
.48737 .30902 L
.48866 .30902 L
.48976 .30902 L
.49098 .30902 L
.49167 .30902 L
.4924 .30902 L
.4937 .30902 L
.49443 .30902 L
.4951 .30902 L
.49584 .30902 L
.49663 .30902 L
.49732 .30902 L
.49806 .30902 L
.49941 .30902 L
.50073 .30902 L
.50193 .30902 L
.50319 .30902 L
.50438 .30902 L
.50545 .30902 L
.50662 .30902 L
.50789 .30902 L
.50852 .30902 L
.50923 .30902 L
.51048 .30902 L
.51165 .30902 L
.51276 .30902 L
.51393 .30902 L
.51492 .30902 L
.51601 .30902 L
.51719 .30902 L
.51845 .30902 L
.51964 .30902 L
.52073 .30902 L
.52201 .30902 L
.52266 .30902 L
.52337 .30902 L
.52464 .30902 L
.52582 .30902 L
.52653 .30902 L
.52721 .30902 L
.52848 .30902 L
.52919 .30902 L
.52985 .30902 L
Mistroke
.53057 .30902 L
.53134 .30902 L
.53265 .30902 L
.53338 .30902 L
.53405 .30902 L
.5353 .30902 L
.53661 .30902 L
.53778 .30902 L
.53888 .30902 L
.54009 .30902 L
.54138 .30902 L
.5426 .30902 L
.54329 .30902 L
.54394 .30902 L
.54525 .30902 L
.54599 .30902 L
.54666 .30902 L
.5478 .30902 L
.54905 .30902 L
.55035 .30902 L
.55156 .30902 L
.55225 .30902 L
.553 .30902 L
.55371 .30902 L
.55436 .30902 L
.5556 .30902 L
.55691 .30902 L
.55759 .30902 L
.55831 .30902 L
.55963 .30902 L
.56262 .30902 L
.58275 .30902 L
.59232 .30902 L
.59507 .30902 L
.59573 .30902 L
.59642 .30902 L
.59766 .30902 L
.59877 .30902 L
.59999 .30902 L
.60129 .30902 L
.6025 .30902 L
.6032 .30902 L
.60395 .30902 L
.60467 .30902 L
.60533 .30902 L
.60657 .30902 L
.6079 .30902 L
.60858 .30902 L
.60922 .30902 L
.60996 .30902 L
Mistroke
.61064 .30902 L
.61139 .30902 L
.61221 .30902 L
.61297 .30902 L
.61367 .30902 L
.61432 .30902 L
.61503 .30902 L
.6163 .30902 L
.61754 .30902 L
.61868 .30902 L
.61992 .30902 L
.62063 .30902 L
.62128 .30902 L
.62196 .30902 L
.62261 .30902 L
.62335 .30902 L
.62403 .30902 L
.6252 .30902 L
.62631 .30902 L
.62752 .30902 L
.62882 .30902 L
.63012 .30902 L
.63077 .30902 L
.63148 .30902 L
.63274 .30902 L
.63392 .30902 L
.63511 .30902 L
.63624 .30902 L
.63725 .30902 L
.63834 .30902 L
.63954 .30902 L
.6408 .30902 L
.64188 .30902 L
.64307 .30902 L
.64434 .30902 L
.64505 .30902 L
.64572 .30902 L
.64694 .30902 L
.64823 .30902 L
.64901 .30902 L
.64975 .30902 L
.65041 .30902 L
.65113 .30902 L
.6518 .30902 L
.65251 .30902 L
.65378 .30902 L
.65497 .30902 L
.65625 .30902 L
.65746 .30902 L
.65856 .30902 L
Mistroke
.65985 .30902 L
.66058 .30902 L
.66125 .30902 L
.66249 .30902 L
.6638 .30902 L
.66494 .30902 L
.66619 .30902 L
.66749 .30902 L
.6687 .30902 L
.66983 .30902 L
.67087 .30902 L
.67206 .30902 L
.67318 .30902 L
.67441 .30902 L
.67571 .30902 L
.67682 .30902 L
.67803 .30902 L
.67934 .30902 L
.68008 .30902 L
.68075 .30902 L
.68205 .30902 L
.68329 .30902 L
.68445 .30902 L
.68549 .30902 L
.6867 .30902 L
.68783 .30902 L
.68889 .30902 L
.68986 .30902 L
.69092 .30902 L
.69204 .30902 L
.69318 .30902 L
.6944 .30902 L
.69555 .30902 L
.69659 .30902 L
.69782 .30902 L
.69851 .30902 L
.69916 .30902 L
.70033 .30902 L
.70158 .30902 L
.70278 .30902 L
.7041 .30902 L
.70534 .30902 L
.70649 .30902 L
.70763 .30902 L
.70867 .30902 L
.70986 .30902 L
.71099 .30902 L
.71222 .30902 L
.71352 .30902 L
.71463 .30902 L
Mistroke
.71585 .30902 L
.71716 .30902 L
.7179 .30902 L
.71857 .30902 L
.71987 .30902 L
.72111 .30902 L
.72216 .30902 L
.72332 .30902 L
.72453 .30902 L
.72566 .30902 L
.72672 .30902 L
.72769 .30902 L
.72875 .30902 L
.72987 .30902 L
.73101 .30902 L
.73207 .30902 L
.73331 .30902 L
.73443 .30902 L
.73566 .30902 L
.73636 .30902 L
.73701 .30902 L
.73817 .30902 L
.73941 .30902 L
.74062 .30902 L
.74194 .30902 L
.74318 .30902 L
.74434 .30902 L
.74546 .30902 L
.74652 .30902 L
.74774 .30902 L
.74884 .30902 L
.75008 .30902 L
.75138 .30902 L
.75249 .30902 L
.75371 .30902 L
.75503 .30902 L
.75577 .30902 L
.75644 .30902 L
.75774 .30902 L
.75898 .30902 L
.76003 .30902 L
.76119 .30902 L
.7624 .30902 L
.76354 .30902 L
.7646 .30902 L
.76557 .30902 L
.76663 .30902 L
.76775 .30902 L
.7689 .30902 L
.77012 .30902 L
Mistroke
.77127 .30902 L
.77231 .30902 L
.77354 .30902 L
.77424 .30902 L
.77487 .30902 L
.77605 .30902 L
.77729 .30902 L
.77851 .30902 L
.77919 .30902 L
.77983 .30902 L
.781 .30902 L
.78224 .30902 L
.78334 .30902 L
.78438 .30902 L
.78552 .30902 L
.78675 .30902 L
.78798 .30902 L
.78933 .30902 L
.79204 .30902 L
.7969 .30902 L
.81523 .30902 L
.85575 .30902 L
.89476 .30902 L
.93622 .30902 L
.97616 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0c
o`00;c?o00030000<ol0<ol0014co`000`1Voc?o03?o000K<ol000<0000co`0co`00;S?o00030000
<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004OooodHco`000`1Voc?o
03?o001n<ol000<0003oooooool0AOooo`004OooodHco`000`1Voc?o03?o001n<ol000<0003ooooo
ool0AOooo`004OooodHco`000`1Voc?o03?o001n<ol000<0003oooooool0AOooo`004OooodHco`00
0`1Voc?o03?o001n<ol000<0003oooooool0AOooo`004OooodHco`000`1Voc?o03?o001n<ol000<0
003oooooool0AOooo`004OooodHco`000`1Voc?o03?o001n<ol00P0004Koool0017ooom6<ol000<0
I_lco`0co`00OS?o00030000oooooooo04Goool0017oool306Ko@c?o000306Ko<ol0<ol007hco`00
0`000?ooooooo`15oooo000Aoooo0c?o00H0I_lm<ol000<0I_lco`0co`00OS?o00030000oooooooo
04Goool0017oool9<ol01@1VocPco`000`1Voc?o03?o001n<ol000<0003oooooool0AOooo`004Ooo
o`hco`0506Ko<c?o000306Ko<ol0<ol007hco`000`000?ooooooo`15oooo000Aoooo4c?o00D0I_l^
<ol000<0I_lco`0co`00OS?o00030000oooooooo04Goool0017ooolH<ol01P1VobPco`000`1Voc?o
03?o001n<ol000<0003oooooool0AOooo`004Oooo`80000L<ol01@1Vob<co`000`1Voc?o03?o001n
<ol00P0004Koool001?oool200007c?o00D0I_lN<ol000<0I_lco`0co`00OS?o00030000oooooooo
04Goool001Goool200008S?o00@0I_lJ<ol000<0I_lco`0co`00OS?o00030000oooooooo04Goool0
01Ooool2000093?o00<0I_lG<ol000<0I_lco`0co`00OS?o00030000oooooooo04Goool001Woool2
00009C?o00@0I_lC<ol000<0I_lco`0co`00OS?o00030000oooooooo04Goool001_oool200009c?o
00<0I_l@<ol000<0I_lco`0co`00OS?o00030000oooooooo04Goool001goool20000:3?o00<0I_l=
<ol000<0I_lco`0co`00OS?o00030000oooooooo04Goool001ooool00`0003?o03?o000X<ol0101V
o`Tco`000`1Voc?o03?o001n<ol000<0003oooooool0AOooo`008?ooo`030000<ol0<ol002/co`03
06Ko1S?o000306Ko<ol0<ol007hco`020000A_ooo`008Oooo`80000^<ol00P1Vo`@co`000`1Voc?o
03?o001n<ol000<0003oooooool0AOooo`008oooo`030000<ol0<ol002dco`0506KoP3?o00030000
oooooooo04Goool002Coool20000<3?o0080I_n0<ol000<0003oooooool0AOooo`009_ooo`030000
<ol0<ol002hco`000ol0VC?o03?o001n<ol000<0003oooooool0AOooo`009oooo`030000<ol0<ol0
02dco`000ol0VC?o03?o001n<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol002`co`00
0ol0VC?o03?o001U<ol00P0000@co`02000013?o00800003<ol0100000@co`000`000?ooooooo`15
oooo000Yoooo00<0000co`0co`00:c?o0003o`2I<ol0<ol006@co`00100003?o03?o000000Pco`00
100003?o03?o0000008co`000`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_ooo`030000
<ol0<ol002Xco`000ol0VC?o03?o001T<ol000@0000co`0co`000008<ol000@0000co`0co`000003
<ol000<0000co`0co`0013?o00<00015oooo000[oooo0P0002Xco`000ol0VC?o03?o001T<ol000@0
000co`0co`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o00030000oooooooo
04Goool002goool00`0003?o03?o000W<ol000?o09Tco`0co`00I3?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool002koool0
0`0003?o03?o000V<ol000?o09Tco`0co`00IC?o0080000:<ol00P0000@co`0200001C?o00030000
oooooooo04Goool002ooool00`0003?o03?o000U<ol000?o09Tco`0co`00OS?o00030000oooooooo
04Goool0033oool00`0003?o03?o000T<ol000?o09Tco`0co`00OS?o00030000oooooooo04Goool0
037oool00`0003?o03?o000S<ol000?o09Tco`0co`00OS?o00030000oooooooo04Goool003;oool0
0`0003?o03?o000R<ol000?o09Tco`0co`00OS?o00030000oooooooo04Goool003?oool00`0003?o
03?o000Q<ol000?o09Tco`0co`00OS?o00800016oooo000coooo00<0000co`0co`008C?o0003o`2I
<ol0<ol007hco`000`000?ooooooo`15oooo000doooo00<0000co`0co`0083?o0003o`2I<ol0<ol0
07hco`000`000?ooooooo`15oooo000eoooo00<0000co`0co`007c?o0003o`2I<ol0<ol007hco`00
0`000?ooooooo`15oooo000foooo00<0000co`0co`007S?o0003o`2I<ol0<ol007hco`000`000?oo
ooooo`15oooo000goooo00<0000co`0co`007C?o0003o`2I<ol0<ol007hco`000`000?ooooooo`15
oooo000hoooo00<0000co`0co`0073?o0003o`2I<ol0<ol007hco`000`000?ooooooo`15oooo000h
oooo00<0000co`0co`0073?o0003o`2I<ol0<ol007hco`000`000?ooooooo`15oooo000ioooo00<0
000co`0co`006c?o0003o`2I<ol0<ol007hco`020000A_ooo`00>_ooo`030000<ol0<ol001Xco`00
0ol0VC?o03?o001n<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol001Tco`000ol0VC?o
03?o001n<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol001Pco`000ol0VC?o03?o001n
<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol001Pco`000ol0VC?o03?o001n<ol000<0
003oooooool0AOooo`00?Oooo`030000<ol0<ol001Lco`000ol0VC?o03?o001n<ol000<0003ooooo
ool0AOooo`00?Oooo`030000<ol0<ol001Lco`000ol0VC?o03?o001n<ol000<0003oooooool0AOoo
o`00?_ooo`030000<ol0<ol001Hco`000ol0VC?o03?o001n<ol000<0003oooooool0AOooo`00?_oo
o`030000<ol0<ol001Hco`000ol0VC?o03?o001n<ol000<0003oooooool0AOooo`00?oooo`030000
<ol0<ol001Dco`000ol0VC?o03?o001n<ol00P0004Koool003ooool00`0003?o03?o000E<ol000?o
09Tco`0co`00OS?o00030000oooooooo04Goool0043oool00`0003?o03?o000D<ol000?o09Tco`0c
o`00OS?o00030000oooooooo04Goool0047oool00`0003?o03?o000C<ol000?o09Tco`0co`00OS?o
00030000oooooooo04Goool0047oool00`0003?o03?o000C<ol000?o09Tco`0co`00OS?o00030000
oooooooo04Goool004;oool00`0003?o03?o000B<ol000?o09Tco`0co`00OS?o00030000oooooooo
04Goool004;oool00`0003?o03?o000B<ol000?o09Tco`0co`00IC?o00800004<ol00P0000@co`02
00001C?o00<00003<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol0014co`000ol0VC?o
03?o001T<ol000@0000co`0co`000008<ol000@0000co`0co`000005<ol000<0000co`0co`000S?o
00030000oooooooo04Goool004?oool00`0003?o03?o000A<ol000?o09Tco`0co`00I3?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool00`0003?o
03?o000@<ol000?o09Tco`0co`00I3?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o
00040000<ol0<ol0000013?o00030000oooooooo04Goool004Coool00`0003?o03?o000@<ol000?o
09Tco`0co`00I3?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol00000
00@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`003c?o0003o`2I<ol0<ol006Dco`02
00002S?o00800005<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`003c?o
0003o`2I<ol0<ol007hco`000`000?ooooooo`15oooo0016oooo00<0000co`0co`003S?o0003o`2I
<ol0<ol007hco`000`000?ooooooo`15oooo0016oooo00<0000co`0co`003S?o0003o`2I<ol0<ol0
07hco`000`000?ooooooo`15oooo0017oooo00<0000co`0co`003C?o0003o`2I<ol0<ol007hco`00
0`000?ooooooo`15oooo0017oooo00<0000co`0co`003C?o0003o`2I<ol0<ol007hco`020000A_oo
o`00B?ooo`030000<ol0<ol000`co`000ol0VC?o03?o001n<ol000<0003oooooool0AOooo`00B?oo
o`030000<ol0<ol000`co`000ol0VC?o03?o001n<ol000<0003oooooool0AOooo`00BOooo`030000
<ol0<ol000/co`000ol0VC?o03?o001n<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol0
00/co`000ol0VC?o03?o001n<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol000Xco`00
0ol0VC?o03?o001n<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol000Xco`000ol0VC?o
03?o001n<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol000Tco`000ol0VC?o03?o001n
<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol000Tco`000ol0VC?o03?o001n<ol00P00
04Koool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;<ol0B?oo
o`00COoooh/co`18oooo001>oooo:C?o00030000<ol0<ol002Tco`000`0003?o03?o000b<ol0B?oo
o`00C_ooobPco`000`0003?o03?o0008<ol000<0000co`0co`0083?o00030000<ol0<ol0034co`18
oooo001?oooo9c?o00030000<ol0<ol0008co`02000013?o00030000<ol0<ol000hco`02000013?o
00800004<ol00P0000@co`000`0003?o03?o000a<ol0B?ooo`00CoooobLco`001@0003?o03?o03?o
00000002<ol000<0000co`0co`000S?o00030000<ol0<ol000Dco`0400000c?o00040000<ol0<ol0
000023?o00040000<ol0<ol000000c?o00030000<ol0<ol0034co`18oooo001?oooo9S?o00030000
<ol0<ol0008co`000`0003?o03?o000D<ol000@0000co`0co`00000:<ol000<0000co`0co`000c?o
00030000<ol0<ol0030co`18oooo001@oooo9S?o00030000<ol0<ol000D0000C<ol000@0000co`0c
o`00000;<ol000D0000co`0co`0co`000000<c?o04Soool0053ooolV<ol000D0000co`0co`0co`00
00005S?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0<ol0034co`18
oooo001@oooo9c?o00030000<ol0<ol001Pco`0200002S?o00800003<ol000<0000co`0co`00<S?o
04Soool0057ooon7<ol0B?ooo`00DOooohLco`18oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.29) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.27193 .30902 L
.28302 .30902 L
.2881 .30902 L
.29088 .30902 L
.29224 .30902 L
.29349 .30902 L
s
.29349 .30902 m
.29349 .61803 L
s
0 .4 1 r
.02381 .34576 m
.06244 .35144 L
.10458 .35863 L
.14415 .36651 L
.18221 .37526 L
.22272 .38606 L
.26171 .39814 L
.27193 .40161 L
.28302 .40554 L
.2881 .40739 L
.29088 .40842 L
.29224 .40893 L
.29349 .4094 L
.29462 .30902 L
.2957 .30902 L
.29684 .30902 L
.29809 .30902 L
.29936 .30902 L
.30006 .30902 L
.30072 .30902 L
.302 .30902 L
.30316 .30902 L
.30432 .30902 L
.30556 .30902 L
.30674 .30902 L
.30781 .30902 L
.30907 .30902 L
.30978 .30902 L
.31043 .30902 L
.31164 .30902 L
.31292 .30902 L
.31414 .30902 L
.31545 .30902 L
.31669 .30902 L
.31782 .30902 L
.31908 .30902 L
.31979 .30902 L
.32046 .30902 L
.32116 .30902 L
.3218 .30902 L
.32254 .30902 L
.32323 .30902 L
.3243 .30902 L
.32547 .30902 L
.3267 .30902 L
.32785 .30902 L
.3289 .30902 L
.32989 .30902 L
.33105 .30902 L
.3321 .30902 L
Mistroke
.33325 .30902 L
.33448 .30902 L
.33564 .30902 L
.33669 .30902 L
.33794 .30902 L
.33863 .30902 L
.33928 .30902 L
.34046 .30902 L
.34171 .30902 L
.34293 .30902 L
.34362 .30902 L
.34426 .30902 L
.34544 .30902 L
.34668 .30902 L
.34779 .30902 L
.34883 .30902 L
.34998 .30902 L
.35121 .30902 L
.35186 .30902 L
.35255 .30902 L
.3538 .30902 L
.3551 .30902 L
.35584 .30902 L
.35652 .30902 L
.35772 .30902 L
.35902 .30902 L
.36025 .30902 L
.36138 .30902 L
.36244 .30902 L
.36358 .30902 L
.36465 .30902 L
.36563 .30902 L
.36678 .30902 L
.36803 .30902 L
.36921 .30902 L
.3703 .30902 L
.37142 .30902 L
.37247 .30902 L
.37363 .30902 L
.37487 .30902 L
.3761 .30902 L
.3774 .30902 L
.37851 .30902 L
.37973 .30902 L
.38105 .30902 L
.38226 .30902 L
.38289 .30902 L
.38359 .30902 L
.38432 .30902 L
.385 .30902 L
Mistroke
.38626 .30902 L
.38741 .30902 L
.38804 .30902 L
.38873 .30902 L
.38999 .30902 L
.39122 .30902 L
.39233 .30902 L
.39362 .30902 L
.39483 .30902 L
.39595 .30902 L
.39698 .30902 L
.39812 .30902 L
.39932 .30902 L
.4006 .30902 L
.40181 .30902 L
.40248 .30902 L
.40321 .30902 L
.40448 .30902 L
.4057 .30902 L
.40699 .30902 L
.40809 .30902 L
.4093 .30902 L
.40999 .30902 L
.41072 .30902 L
.41202 .30902 L
.41275 .30902 L
.41342 .30902 L
.41416 .30902 L
.41496 .30902 L
.41564 .30902 L
.41639 .30902 L
.41709 .30902 L
.41773 .30902 L
.41896 .30902 L
.42026 .30902 L
.42147 .30902 L
.42279 .30902 L
.42404 .30902 L
.4252 .30902 L
.42634 .30902 L
.42738 .30902 L
.42858 .30902 L
.4297 .30902 L
.43094 .30902 L
.43225 .30902 L
.43336 .30902 L
.43458 .30902 L
.4359 .30902 L
.43662 .30902 L
.43731 .30902 L
Mistroke
.43795 .30902 L
.43864 .30902 L
.43985 .30902 L
.44098 .30902 L
.44205 .30902 L
.44321 .30902 L
.44447 .30902 L
.44578 .30902 L
.44703 .30902 L
.44815 .30902 L
.44937 .30902 L
.45053 .30902 L
.45158 .30902 L
.45279 .30902 L
.45393 .30902 L
.45499 .30902 L
.45597 .30902 L
.45704 .30902 L
.45817 .30902 L
.45938 .30902 L
.46003 .30902 L
.46071 .30902 L
.46196 .30902 L
.46312 .30902 L
.46423 .30902 L
.46527 .30902 L
.46641 .30902 L
.46764 .30902 L
.46887 .30902 L
.46957 .30902 L
.47022 .30902 L
.47153 .30902 L
.47227 .30902 L
.47294 .30902 L
.47413 .30902 L
.47543 .30902 L
.47666 .30902 L
.47779 .30902 L
.47885 .30902 L
.47998 .30902 L
.48105 .30902 L
.48203 .30902 L
.48318 .30902 L
.48443 .30902 L
.4856 .30902 L
.4867 .30902 L
.48793 .30902 L
.48909 .30902 L
.49014 .30902 L
.49126 .30902 L
Mistroke
.4925 .30902 L
.4938 .30902 L
.49491 .30902 L
.49613 .30902 L
.49743 .30902 L
.49864 .30902 L
.49927 .30902 L
.49997 .30902 L
.5007 .30902 L
.50138 .30902 L
.50263 .30902 L
.50377 .30902 L
.50503 .30902 L
.50635 .30902 L
.50747 .30902 L
.50866 .30902 L
.50969 .30902 L
.5108 .30902 L
.51211 .30902 L
.51335 .30902 L
.51455 .30902 L
.51566 .30902 L
.51686 .30902 L
.518 .30902 L
.51931 .30902 L
.52051 .30902 L
.52183 .30902 L
.52257 .30902 L
.52326 .30902 L
.52451 .30902 L
.52514 .30902 L
.52583 .30902 L
.52651 .30902 L
.52722 .30902 L
.5285 .30902 L
.52921 .30902 L
.52987 .30902 L
.53065 .30902 L
.53138 .30902 L
.5327 .30902 L
.5339 .30902 L
.53519 .30902 L
.53591 .30902 L
.53659 .30902 L
.53782 .30902 L
.53894 .30902 L
.54015 .30902 L
.54147 .30902 L
.54261 .30902 L
.54383 .30902 L
Mistroke
.54499 .30902 L
.54603 .30902 L
.54668 .30902 L
.54737 .30902 L
.54861 .30902 L
.54929 .30902 L
.54993 .30902 L
.55063 .30902 L
.55139 .30902 L
.55204 .30902 L
.55274 .30902 L
.55403 .30902 L
.55518 .30902 L
.55643 .30902 L
.55773 .30902 L
.55895 .30902 L
.55966 .30902 L
.5604 .30902 L
.56104 .30902 L
.56173 .30902 L
.56247 .30902 L
.56314 .30902 L
.56386 .30902 L
.56465 .30902 L
.56537 .30902 L
.56604 .30902 L
.56736 .30902 L
.56848 .30902 L
.5697 .30902 L
.57039 .30902 L
.57102 .30902 L
.57227 .30902 L
.57354 .30902 L
.57426 .30902 L
.57493 .30902 L
.57616 .30902 L
.57746 .30902 L
.57871 .30902 L
.57942 .30902 L
.58008 .30902 L
.58078 .30902 L
.58141 .30902 L
.58215 .30902 L
.58284 .30902 L
.58407 .30902 L
.58521 .30902 L
.58646 .30902 L
.58709 .30902 L
.58778 .30902 L
.58852 .30902 L
Mistroke
.58923 .30902 L
.58986 .30902 L
.59055 .30902 L
.5913 .30902 L
.59209 .30902 L
.59285 .30902 L
.59353 .30902 L
.59418 .30902 L
.59486 .30902 L
.59561 .30902 L
.59631 .30902 L
.59755 .30902 L
.59826 .30902 L
.59892 .30902 L
.60017 .30902 L
.60083 .30902 L
.60154 .30902 L
.60282 .30902 L
.60401 .30902 L
.60866 .30902 L
.60982 .30902 L
.61105 .30902 L
.61169 .30902 L
.61239 .30902 L
.61362 .30902 L
.61433 .30902 L
.61509 .30902 L
.6158 .30902 L
.61645 .30902 L
.61711 .30902 L
.61782 .30902 L
.61911 .30902 L
.62031 .30902 L
.62141 .30902 L
.62271 .30902 L
.62395 .30902 L
.62522 .30902 L
.6264 .30902 L
.62769 .30902 L
.62842 .30902 L
.62907 .30902 L
.63026 .30902 L
.63135 .30902 L
.63255 .30902 L
.63381 .30902 L
.63491 .30902 L
.63594 .30902 L
.63707 .30902 L
.63827 .30902 L
.63895 .30902 L
Mistroke
.63966 .30902 L
.64095 .30902 L
.64162 .30902 L
.64233 .30902 L
.64312 .30902 L
.64386 .30902 L
.64521 .30902 L
.64594 .30902 L
.64662 .30902 L
.64783 .30902 L
.64915 .30902 L
.65044 .30902 L
.65166 .30902 L
.65276 .30902 L
.65395 .30902 L
.65524 .30902 L
.65589 .30902 L
.65661 .30902 L
.65788 .30902 L
.65906 .30902 L
.66032 .30902 L
.66102 .30902 L
.66165 .30902 L
.66289 .30902 L
.66405 .30902 L
.66476 .30902 L
.66543 .30902 L
.66612 .30902 L
.66688 .30902 L
.66814 .30902 L
.66884 .30902 L
.66948 .30902 L
.67066 .30902 L
.67193 .30902 L
.67313 .30902 L
.67424 .30902 L
.67542 .30902 L
.67673 .30902 L
.67739 .30902 L
.67809 .30902 L
.67937 .30902 L
.6806 .30902 L
.68174 .30902 L
.683 .30902 L
.6837 .30902 L
.68434 .30902 L
.6855 .30902 L
.68677 .30902 L
.68796 .30902 L
.68905 .30902 L
Mistroke
.69012 .30902 L
.69111 .30902 L
.6922 .30902 L
.69336 .30902 L
.69459 .30902 L
.69574 .30902 L
.69678 .30902 L
.69791 .30902 L
.69913 .30902 L
.70025 .30902 L
.70147 .30902 L
.70276 .30902 L
.70389 .30902 L
.70493 .30902 L
.70608 .30902 L
.70731 .30902 L
.70801 .30902 L
.70865 .30902 L
.70936 .30902 L
.71011 .30902 L
.71136 .30902 L
.71208 .30902 L
.71275 .30902 L
.71399 .30902 L
.71513 .30902 L
.71644 .30902 L
.71769 .30902 L
.71837 .30902 L
.71901 .30902 L
.72021 .30902 L
.7215 .30902 L
.72223 .30902 L
.7229 .30902 L
.72402 .30902 L
.72525 .30902 L
.72654 .30902 L
.72774 .30902 L
.72842 .30902 L
.72916 .30902 L
.72986 .30902 L
.7305 .30902 L
.73173 .30902 L
.73303 .30902 L
.7337 .30902 L
.73442 .30902 L
.73572 .30902 L
.73648 .30902 L
.73727 .30902 L
.73795 .30902 L
.73869 .30902 L
Mistroke
.73934 .30902 L
.74002 .30902 L
.74124 .30902 L
.74255 .30902 L
.7433 .30902 L
.74399 .30902 L
.74525 .30902 L
.7464 .30902 L
.74704 .30902 L
.74773 .30902 L
.74899 .30902 L
.75011 .30902 L
.75134 .30902 L
.75263 .30902 L
.75384 .30902 L
.75497 .30902 L
.75601 .30902 L
.75714 .30902 L
.75834 .30902 L
.75965 .30902 L
.76084 .30902 L
.7615 .30902 L
.76222 .30902 L
.76352 .30902 L
.76474 .30902 L
.76603 .30902 L
.76713 .30902 L
.76834 .30902 L
.76907 .30902 L
.76977 .30902 L
.77107 .30902 L
.7718 .30902 L
.77247 .30902 L
.77321 .30902 L
.774 .30902 L
.77469 .30902 L
.77543 .30902 L
.77614 .30902 L
.77678 .30902 L
.77801 .30902 L
.7793 .30902 L
.78052 .30902 L
.78121 .30902 L
.78185 .30902 L
.78302 .30902 L
.78426 .30902 L
.78537 .30902 L
.78641 .30902 L
.78756 .30902 L
.78879 .30902 L
Mistroke
.79895 .30902 L
.81729 .30902 L
.85844 .30902 L
.89808 .30902 L
.93621 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.29) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`00001Voc?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0c
o`00;c?o00030000<ol0<ol0018co`000`1Voc?o03?o000J<ol000<0000co`0co`00;S?o00030000
<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004OooodLco`000`1Voc?o
03?o001m<ol000<0003oooooool0AOooo`004OooodLco`000`1Voc?o03?o001m<ol000<0003ooooo
ool0AOooo`004OooodLco`000`1Voc?o03?o001m<ol000<0003oooooool0AOooo`004OooodLco`00
0`1Voc?o03?o001m<ol000<0003oooooool0AOooo`004OooodLco`000`1Voc?o03?o001m<ol000<0
003oooooool0AOooo`004OooodLco`000`1Voc?o03?o001m<ol00P0004Koool0017ooom7<ol000<0
I_lco`0co`00OC?o00030000oooooooo04Goool0017oool606Ko@C?o000306Ko<ol0<ol007dco`00
0`000?ooooooo`15oooo000Aoooo1S?o00P0I_li<ol000<0I_lco`0co`00OC?o00030000oooooooo
04Goool0017oool><ol01@1Voc@co`000`1Voc?o03?o001m<ol000<0003oooooool0AOooo`004Ooo
oa<co`0506Ko;c?o000306Ko<ol0<ol007dco`000`000?ooooooo`15oooo000Aoooo63?o00H0I_lY
<ol000<0I_lco`0co`00OC?o00030000oooooooo04Goool0017ooolN<ol01@1Vob@co`000`1Voc?o
03?o001m<ol000<0003oooooool0AOooo`004Oooo`80000Q<ol01@1Voalco`000`1Voc?o03?o001m
<ol00P0004Koool001?oool2000093?o00@0I_lK<ol000<0I_lco`0co`00OC?o00030000oooooooo
04Goool001Goool200009S?o00<0I_lH<ol000<0I_lco`0co`00OC?o00030000oooooooo04Goool0
01Ooool200009c?o00@0I_lD<ol000<0I_lco`0co`00OC?o00030000oooooooo04Goool001Woool2
0000:C?o00<0I_lA<ol000<0I_lco`0co`00OC?o00030000oooooooo04Goool001_oool20000:S?o
00<0I_l><ol000<0I_lco`0co`00OC?o00030000oooooooo04Goool001goool20000:c?o00@0I_l:
<ol000<0I_lco`0co`00OC?o00030000oooooooo04Goool001ooool00`0003?o03?o000/<ol00`1V
o`Lco`000`1Voc?o03?o001m<ol000<0003oooooool0AOooo`008?ooo`030000<ol0<ol002hco`03
06Ko13?o000306Ko<ol0<ol007dco`020000A_ooo`008Oooo`80000a<ol00P1Vo`8co`000`1Voc?o
03?o001m<ol000<0003oooooool0AOooo`008oooo`030000<ol0<ol0030co`0306KoOc?o00030000
oooooooo04Goool002Coool20000<S?o0003o`2I<ol0<ol007dco`000`000?ooooooo`15oooo000V
oooo00<0000co`0co`00;c?o0003o`2I<ol0<ol007dco`000`000?ooooooo`15oooo000Woooo00<0
000co`0co`00;S?o0003o`2I<ol0<ol007dco`000`000?ooooooo`15oooo000Xoooo00<0000co`0c
o`00;C?o0003o`2I<ol0<ol006@co`02000013?o00800004<ol00P0000<co`04000013?o00030000
oooooooo04Goool002Woool00`0003?o03?o000/<ol000?o09Tco`0co`00Hc?o00040000<ol0<ol0
000023?o00040000<ol0<ol000000S?o00030000<ol0<ol000Dco`000`000?ooooooo`15oooo000Z
oooo00<0000co`0co`00:c?o0003o`2I<ol0<ol006<co`00100003?o03?o000000Pco`00100003?o
03?o000000<co`000`0003?o03?o0004<ol00`0004Goool002_oool20000:c?o0003o`2I<ol0<ol0
06<co`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`0003?o03?o0003<ol000<0
003oooooool0AOooo`00;Oooo`030000<ol0<ol002Pco`000ol0VC?o03?o001S<ol000@0000co`0c
o`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000004<ol000<0003oooooool0AOoo
o`00;_ooo`030000<ol0<ol002Lco`000ol0VC?o03?o001T<ol00P0000Xco`02000013?o00800005
<ol000<0003oooooool0AOooo`00;oooo`030000<ol0<ol002Hco`000ol0VC?o03?o001m<ol000<0
003oooooool0AOooo`00<?ooo`030000<ol0<ol002Dco`000ol0VC?o03?o001m<ol000<0003ooooo
ool0AOooo`00<Oooo`030000<ol0<ol002@co`000ol0VC?o03?o001m<ol000<0003oooooool0AOoo
o`00<_ooo`030000<ol0<ol002<co`000ol0VC?o03?o001m<ol000<0003oooooool0AOooo`00<ooo
o`030000<ol0<ol0028co`000ol0VC?o03?o001m<ol00P0004Koool003?oool00`0003?o03?o000R
<ol000?o09Tco`0co`00OC?o00030000oooooooo04Goool003Coool00`0003?o03?o000Q<ol000?o
09Tco`0co`00OC?o00030000oooooooo04Goool003Goool00`0003?o03?o000P<ol000?o09Tco`0c
o`00OC?o00030000oooooooo04Goool003Koool00`0003?o03?o000O<ol000?o09Tco`0co`00OC?o
00030000oooooooo04Goool003Ooool00`0003?o03?o000N<ol000?o09Tco`0co`00OC?o00030000
oooooooo04Goool003Soool00`0003?o03?o000M<ol000?o09Tco`0co`00OC?o00030000oooooooo
04Goool003Soool00`0003?o03?o000M<ol000?o09Tco`0co`00OC?o00030000oooooooo04Goool0
03Woool00`0003?o03?o000L<ol000?o09Tco`0co`00OC?o00800016oooo000joooo00<0000co`0c
o`006c?o0003o`2I<ol0<ol007dco`000`000?ooooooo`15oooo000koooo00<0000co`0co`006S?o
0003o`2I<ol0<ol007dco`000`000?ooooooo`15oooo000loooo00<0000co`0co`006C?o0003o`2I
<ol0<ol007dco`000`000?ooooooo`15oooo000loooo00<0000co`0co`006C?o0003o`2I<ol0<ol0
07dco`000`000?ooooooo`15oooo000moooo00<0000co`0co`0063?o0003o`2I<ol0<ol007dco`00
0`000?ooooooo`15oooo000moooo00<0000co`0co`0063?o0003o`2I<ol0<ol007dco`000`000?oo
ooooo`15oooo000noooo00<0000co`0co`005c?o0003o`2I<ol0<ol007dco`000`000?ooooooo`15
oooo000noooo00<0000co`0co`005c?o0003o`2I<ol0<ol007dco`000`000?ooooooo`15oooo000o
oooo00<0000co`0co`005S?o0003o`2I<ol0<ol007dco`020000A_ooo`00?oooo`030000<ol0<ol0
01Hco`000ol0VC?o03?o001m<ol000<0003oooooool0AOooo`00@?ooo`030000<ol0<ol001Dco`00
0ol0VC?o03?o001m<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol001@co`000ol0VC?o
03?o001m<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol001@co`000ol0VC?o03?o001m
<ol000<0003oooooool0AOooo`00@_ooo`030000<ol0<ol001<co`000ol0VC?o03?o001m<ol000<0
003oooooool0AOooo`00@_ooo`030000<ol0<ol001<co`000ol0VC?o03?o001T<ol00P0000@co`02
000013?o00800005<ol00`0000<co`000`000?ooooooo`15oooo0013oooo00<0000co`0co`004S?o
0003o`2I<ol0<ol006<co`00100003?o03?o000000Pco`00100003?o03?o000000Dco`000`0003?o
03?o0002<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol0018co`000ol0VC?o03?o001S
<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol01@0000<co`030000AOooo`00A?oo
o`030000<ol0<ol0014co`000ol0VC?o03?o001S<ol000@0000co`0co`000008<ol000@0000co`0c
o`000002<ol000@0000co`0co`000004<ol000<0003oooooool0AOooo`00A?ooo`030000<ol0<ol0
014co`000ol0VC?o03?o001S<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0
000co`00000013?o00030000oooooooo04Goool004Goool00`0003?o03?o000@<ol000?o09Tco`0c
o`00I3?o0080000:<ol00P0000Dco`02000013?o00030000oooooooo04Goool004Goool00`0003?o
03?o000@<ol000?o09Tco`0co`00OC?o00030000oooooooo04Goool004Koool00`0003?o03?o000?
<ol000?o09Tco`0co`00OC?o00030000oooooooo04Goool004Koool00`0003?o03?o000?<ol000?o
09Tco`0co`00OC?o00030000oooooooo04Goool004Ooool00`0003?o03?o000><ol000?o09Tco`0c
o`00OC?o00030000oooooooo04Goool004Ooool00`0003?o03?o000><ol000?o09Tco`0co`00OC?o
00800016oooo0018oooo00<0000co`0co`003C?o0003o`2I<ol0<ol007dco`000`000?ooooooo`15
oooo0018oooo00<0000co`0co`003C?o0003o`2I<ol0<ol007dco`000`000?ooooooo`15oooo0019
oooo00<0000co`0co`0033?o0003o`2I<ol0<ol007dco`000`000?ooooooo`15oooo0019oooo00<0
000co`0co`0033?o0003o`2I<ol0<ol007dco`000`000?ooooooo`15oooo001:oooo00<0000co`0c
o`002c?o0003o`2I<ol0<ol007dco`000`000?ooooooo`15oooo001:oooo00<0000co`0co`002c?o
0003o`2I<ol0<ol007dco`000`000?ooooooo`15oooo001;oooo00<0000co`0co`002S?o0003o`2I
<ol0<ol007dco`000`000?ooooooo`15oooo001;oooo00<0000co`0co`002S?o0003o`2I<ol0<ol0
07dco`020000A_ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00COoo
oh/co`18oooo001=ooooRc?o04Soool004kooolV<ol000<0000co`0co`00;c?o00030000<ol0<ol0
02lco`18oooo001>oooo9C?o00030000<ol0<ol000Pco`000`0003?o03?o000V<ol000<0000co`0c
o`00;S?o04Soool004oooolT<ol000<0000co`0co`000S?o00800004<ol000<0000co`0co`003S?o
00800004<ol00P0000<co`0400000S?o00<00004<ol000<0000co`0co`00;S?o04Soool004oooolT
<ol000D0000co`0co`0co`0000000S?o00030000<ol0<ol0008co`000`0003?o03?o0005<ol01000
00<co`00100003?o03?o000000Pco`000`0003?o03?o0005<ol000<0000co`0co`000S?o00030000
<ol0<ol002hco`18oooo001?oooo8c?o00030000<ol0<ol0008co`000`0003?o03?o000D<ol000@0
000co`0co`000009<ol000<0000co`0co`000c?o00<00004<ol000<0000co`0co`00;C?o04Soool0
053ooolS<ol000<0000co`0co`001@0001<co`00100003?o03?o000000Xco`001@0003?o03?o03?o
00000002<ol000D0000co`0co`0co`000000<3?o04Soool0053ooolS<ol000D0000co`0co`0co`00
00005S?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol000000c?o
00030000<ol0<ol002hco`18oooo001@oooo93?o00030000<ol0<ol001Pco`0200002S?o00800004
<ol00`00008co`000`0003?o03?o000_<ol0B?ooo`00DOooohLco`18oooo001AooooQc?o04Soool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.27193 .30902 L
.28302 .30902 L
.2881 .30902 L
.29349 .30902 L
.2957 .30902 L
.29693 .30902 L
.29809 .30902 L
s
.29809 .30902 m
.29809 .61803 L
s
0 .4 1 r
.02381 .34443 m
.06244 .3499 L
.10458 .35683 L
.14415 .36442 L
.18221 .37286 L
.22272 .38327 L
.26171 .39491 L
.27193 .39825 L
.28302 .40203 L
.2881 .40382 L
.29349 .40575 L
.2957 .40656 L
.29693 .40701 L
.29809 .40743 L
.29874 .30902 L
.29945 .30902 L
.3007 .30902 L
.30198 .30902 L
.30316 .30902 L
.30444 .30902 L
.30509 .30902 L
.3058 .30902 L
.30706 .30902 L
.30823 .30902 L
.30894 .30902 L
.30962 .30902 L
.31088 .30902 L
.31159 .30902 L
.31224 .30902 L
.31296 .30902 L
.31372 .30902 L
.3149 .30902 L
.31616 .30902 L
.31736 .30902 L
.31845 .30902 L
.31967 .30902 L
.32036 .30902 L
.321 .30902 L
.32229 .30902 L
.32302 .30902 L
.32368 .30902 L
.32484 .30902 L
.32607 .30902 L
.32712 .30902 L
.32827 .30902 L
.32951 .30902 L
.33021 .30902 L
.33084 .30902 L
.33208 .30902 L
.33325 .30902 L
Mistroke
.33434 .30902 L
.33549 .30902 L
.33658 .30902 L
.33757 .30902 L
.33874 .30902 L
.34 .30902 L
.34119 .30902 L
.34228 .30902 L
.34355 .30902 L
.34475 .30902 L
.34583 .30902 L
.347 .30902 L
.34827 .30902 L
.34891 .30902 L
.34962 .30902 L
.35087 .30902 L
.35205 .30902 L
.35316 .30902 L
.35433 .30902 L
.35534 .30902 L
.35643 .30902 L
.35761 .30902 L
.35887 .30902 L
.36007 .30902 L
.36115 .30902 L
.36244 .30902 L
.36315 .30902 L
.36381 .30902 L
.36498 .30902 L
.36626 .30902 L
.36697 .30902 L
.36765 .30902 L
.36893 .30902 L
.36964 .30902 L
.3703 .30902 L
.37102 .30902 L
.37179 .30902 L
.37297 .30902 L
.37425 .30902 L
.37545 .30902 L
.37656 .30902 L
.37778 .30902 L
.37848 .30902 L
.37912 .30902 L
.38043 .30902 L
.38116 .30902 L
.38182 .30902 L
.38301 .30902 L
.38413 .30902 L
.38535 .30902 L
Mistroke
.38666 .30902 L
.38732 .30902 L
.38804 .30902 L
.38934 .30902 L
.39061 .30902 L
.39179 .30902 L
.39299 .30902 L
.39413 .30902 L
.39514 .30902 L
.39624 .30902 L
.39743 .30902 L
.3987 .30902 L
.39989 .30902 L
.40099 .30902 L
.40228 .30902 L
.4035 .30902 L
.40482 .30902 L
.40556 .30902 L
.40625 .30902 L
.40754 .30902 L
.40827 .30902 L
.40895 .30902 L
.40967 .30902 L
.41033 .30902 L
.41105 .30902 L
.41182 .30902 L
.41302 .30902 L
.41413 .30902 L
.41482 .30902 L
.41546 .30902 L
.41667 .30902 L
.41794 .30902 L
.41912 .30902 L
.42041 .30902 L
.42106 .30902 L
.42177 .30902 L
.42298 .30902 L
.42427 .30902 L
.42501 .30902 L
.42568 .30902 L
.42699 .30902 L
.42822 .30902 L
.42891 .30902 L
.42955 .30902 L
.43071 .30902 L
.43195 .30902 L
.43306 .30902 L
.43424 .30902 L
.43536 .30902 L
.43638 .30902 L
Mistroke
.43758 .30902 L
.43888 .30902 L
.4401 .30902 L
.44124 .30902 L
.44244 .30902 L
.44373 .30902 L
.44495 .30902 L
.44606 .30902 L
.44736 .30902 L
.4481 .30902 L
.44879 .30902 L
.45004 .30902 L
.45074 .30902 L
.45138 .30902 L
.45205 .30902 L
.45276 .30902 L
.45404 .30902 L
.45475 .30902 L
.45541 .30902 L
.45618 .30902 L
.45692 .30902 L
.45823 .30902 L
.45943 .30902 L
.46073 .30902 L
.46146 .30902 L
.46213 .30902 L
.46331 .30902 L
.46455 .30902 L
.46562 .30902 L
.46676 .30902 L
.468 .30902 L
.46915 .30902 L
.46985 .30902 L
.47051 .30902 L
.47175 .30902 L
.47285 .30902 L
.47401 .30902 L
.475 .30902 L
.47609 .30902 L
.47726 .30902 L
.47852 .30902 L
.4797 .30902 L
.48079 .30902 L
.48206 .30902 L
.48277 .30902 L
.48341 .30902 L
.48466 .30902 L
.48584 .30902 L
.48652 .30902 L
.48722 .30902 L
Mistroke
.48849 .30902 L
.4892 .30902 L
.48986 .30902 L
.49058 .30902 L
.49135 .30902 L
.49265 .30902 L
.49338 .30902 L
.49405 .30902 L
.49529 .30902 L
.49661 .30902 L
.49888 .30902 L
.50017 .30902 L
.50139 .30902 L
.50257 .30902 L
.50383 .30902 L
.50492 .30902 L
.5061 .30902 L
.50682 .30902 L
.50748 .30902 L
.50879 .30902 L
.50998 .30902 L
.51124 .30902 L
.51247 .30902 L
.51379 .30902 L
.51504 .30902 L
.51618 .30902 L
.51687 .30902 L
.51751 .30902 L
.51821 .30902 L
.51896 .30902 L
.52022 .30902 L
.52093 .30902 L
.5216 .30902 L
.52268 .30902 L
.52386 .30902 L
.5251 .30902 L
.52624 .30902 L
.52732 .30902 L
.5283 .30902 L
.52944 .30902 L
.53051 .30902 L
.53167 .30902 L
.5329 .30902 L
.53395 .30902 L
.53511 .30902 L
.53636 .30902 L
.53706 .30902 L
.5377 .30902 L
.53894 .30902 L
.54012 .30902 L
Mistroke
.54136 .30902 L
.54206 .30902 L
.54271 .30902 L
.54389 .30902 L
.54515 .30902 L
.54627 .30902 L
.54732 .30902 L
.54847 .30902 L
.54971 .30902 L
.55102 .30902 L
.55176 .30902 L
.55245 .30902 L
.55371 .30902 L
.55435 .30902 L
.55505 .30902 L
.55626 .30902 L
.55757 .30902 L
.5588 .30902 L
.55993 .30902 L
.561 .30902 L
.56214 .30902 L
.56322 .30902 L
.56421 .30902 L
.56536 .30902 L
.56661 .30902 L
.5678 .30902 L
.56889 .30902 L
.57001 .30902 L
.57107 .30902 L
.57222 .30902 L
.57347 .30902 L
.57477 .30902 L
.576 .30902 L
.57721 .30902 L
.57832 .30902 L
.57957 .30902 L
.58022 .30902 L
.58092 .30902 L
.58208 .30902 L
.58336 .30902 L
.5845 .30902 L
.58573 .30902 L
.58688 .30902 L
.58793 .30902 L
.58924 .30902 L
.59045 .30902 L
.59109 .30902 L
.59178 .30902 L
.59251 .30902 L
.59319 .30902 L
Mistroke
.59444 .30902 L
.59559 .30902 L
.59691 .30902 L
.59817 .30902 L
.59932 .30902 L
.60037 .30902 L
.60158 .30902 L
.60273 .30902 L
.60372 .30902 L
.60476 .30902 L
.60591 .30902 L
.60696 .30902 L
.6081 .30902 L
.60933 .30902 L
.61049 .30902 L
.61154 .30902 L
.61278 .30902 L
.61348 .30902 L
.61412 .30902 L
.61531 .30902 L
.61657 .30902 L
.6177 .30902 L
.61895 .30902 L
.62024 .30902 L
.62145 .30902 L
.62258 .30902 L
.62361 .30902 L
.62474 .30902 L
.62593 .30902 L
.62722 .30902 L
.62842 .30902 L
.62909 .30902 L
.62981 .30902 L
.63112 .30902 L
.63234 .30902 L
.63345 .30902 L
.63477 .30902 L
.63602 .30902 L
.63717 .30902 L
.63822 .30902 L
.63942 .30902 L
.64055 .30902 L
.64161 .30902 L
.64258 .30902 L
.64364 .30902 L
.64476 .30902 L
.6459 .30902 L
.64711 .30902 L
.64826 .30902 L
.64931 .30902 L
Mistroke
.65054 .30902 L
.65123 .30902 L
.65187 .30902 L
.65305 .30902 L
.65429 .30902 L
.65553 .30902 L
.65668 .30902 L
.65788 .30902 L
.65919 .30902 L
.66033 .30902 L
.66136 .30902 L
.66255 .30902 L
.66368 .30902 L
.66491 .30902 L
.6662 .30902 L
.66731 .30902 L
.66853 .30902 L
.66984 .30902 L
.67058 .30902 L
.67125 .30902 L
.67248 .30902 L
.67379 .30902 L
.67501 .30902 L
.67612 .30902 L
.67724 .30902 L
.67828 .30902 L
.67949 .30902 L
.6808 .30902 L
.68195 .30902 L
.68317 .30902 L
.68423 .30902 L
.68537 .30902 L
.68644 .30902 L
.68742 .30902 L
.68857 .30902 L
.68981 .30902 L
.69099 .30902 L
.69207 .30902 L
.69332 .30902 L
.6945 .30902 L
.69557 .30902 L
.69673 .30902 L
.69799 .30902 L
.69868 .30902 L
.69933 .30902 L
.70059 .30902 L
.70174 .30902 L
.70284 .30902 L
.704 .30902 L
.705 .30902 L
Mistroke
.70609 .30902 L
.70726 .30902 L
.70852 .30902 L
.70971 .30902 L
.71079 .30902 L
.71207 .30902 L
.71272 .30902 L
.71343 .30902 L
.71469 .30902 L
.71587 .30902 L
.71654 .30902 L
.71725 .30902 L
.71852 .30902 L
.71918 .30902 L
.71989 .30902 L
.72066 .30902 L
.72139 .30902 L
.73142 .30902 L
.73639 .30902 L
.7377 .30902 L
.73844 .30902 L
.73911 .30902 L
.74042 .30902 L
.74166 .30902 L
.74297 .30902 L
.74372 .30902 L
.74441 .30902 L
.74518 .30902 L
.74587 .30902 L
.74668 .30902 L
.74744 .30902 L
.74808 .30902 L
.74877 .30902 L
.75 .30902 L
.75131 .30902 L
.75206 .30902 L
.75276 .30902 L
.75402 .30902 L
.75468 .30902 L
.75538 .30902 L
.75667 .30902 L
.75785 .30902 L
.75899 .30902 L
.76006 .30902 L
.76123 .30902 L
.76249 .30902 L
.76376 .30902 L
.76448 .30902 L
.76514 .30902 L
.76585 .30902 L
Mistroke
.76649 .30902 L
.76723 .30902 L
.76793 .30902 L
.76918 .30902 L
.77032 .30902 L
.77158 .30902 L
.77222 .30902 L
.77291 .30902 L
.77421 .30902 L
.77542 .30902 L
.77674 .30902 L
.7774 .30902 L
.77814 .30902 L
.77937 .30902 L
.78006 .30902 L
.7807 .30902 L
.78187 .30902 L
.7831 .30902 L
.78421 .30902 L
.7854 .30902 L
.78652 .30902 L
.78754 .30902 L
.79239 .30902 L
.8133 .30902 L
.85324 .30902 L
.89167 .30902 L
.93256 .30902 L
.97192 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o001Vo`07<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0c
o`00;c?o00030000<ol0<ol001<co`000`1Voc?o03?o000I<ol000<0000co`0co`00;S?o00030000
<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004OooodPco`000`1Voc?o
03?o001l<ol000<0003oooooool0AOooo`004OooodPco`000`1Voc?o03?o001l<ol000<0003ooooo
ool0AOooo`004OooodPco`000`1Voc?o03?o001l<ol000<0003oooooool0AOooo`004OooodPco`00
0`1Voc?o03?o001l<ol000<0003oooooool0AOooo`004OooodPco`000`1Voc?o03?o001l<ol000<0
003oooooool0AOooo`004OooodPco`000`1Voc?o03?o001l<ol00P0004Koool0017oool306KoAC?o
000306Ko<ol0<ol007`co`000`000?ooooooo`15oooo000Aoooo0c?o00H0I_lo<ol000<0I_lco`0c
o`00O3?o00030000oooooooo04Goool0017oool9<ol01@1VocXco`000`1Voc?o03?o001l<ol000<0
003oooooool0AOooo`004Oooo`hco`0506Ko=C?o000306Ko<ol0<ol007`co`000`000?ooooooo`15
oooo000Aoooo4c?o00D0I_l`<ol000<0I_lco`0co`00O3?o00030000oooooooo04Goool0017ooolH
<ol01P1VobXco`000`1Voc?o03?o001l<ol000<0003oooooool0AOooo`004Ooooahco`0506Ko9C?o
000306Ko<ol0<ol007`co`000`000?ooooooo`15oooo000Aoooo0P00024co`0506Ko83?o000306Ko
<ol0<ol007`co`020000A_ooo`004oooo`80000T<ol01@1Voa/co`000`1Voc?o03?o001l<ol000<0
003oooooool0AOooo`005Oooo`80000W<ol01@1VoaHco`000`1Voc?o03?o001l<ol000<0003ooooo
ool0AOooo`005oooo`80000Z<ol0101Voa8co`000`1Voc?o03?o001l<ol000<0003oooooool0AOoo
o`006Oooo`80000/<ol00P1Voa0co`000`1Voc?o03?o001l<ol000<0003oooooool0AOooo`006ooo
o`80000/<ol00`1Vo`dco`000`1Voc?o03?o001l<ol000<0003oooooool0AOooo`007Oooo`80000]
<ol00P1Vo`/co`000`1Voc?o03?o001l<ol000<0003oooooool0AOooo`007oooo`030000<ol0<ol0
02`co`0606Ko1C?o000306Ko<ol0<ol007`co`000`000?ooooooo`15oooo000Poooo00<0000co`0c
o`00<C?o0080I_l3<ol000<0I_lco`0co`00O3?o00800016oooo000Qoooo0P0003<co`0406KoOS?o
00030000oooooooo04Goool002?oool00`0003?o03?o000b<ol00P1Voghco`000`000?ooooooo`15
oooo000Toooo0P0003<co`000ol0VC?o03?o001l<ol000<0003oooooool0AOooo`009_ooo`030000
<ol0<ol0030co`000ol0VC?o03?o001l<ol000<0003oooooool0AOooo`009oooo`030000<ol0<ol0
02lco`000ol0VC?o03?o001l<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol002hco`00
0ol0VC?o03?o001S<ol00P0000@co`02000013?o00800003<ol0100000@co`000`000?ooooooo`15
oooo000Yoooo00<0000co`0co`00;C?o0003o`2I<ol0<ol0068co`00100003?o03?o000000Pco`00
100003?o03?o0000008co`000`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_ooo`030000
<ol0<ol002`co`000ol0VC?o03?o001R<ol000@0000co`0co`000008<ol000@0000co`0co`000003
<ol000<0000co`0co`0013?o00<00015oooo000[oooo0P0002`co`000ol0VC?o03?o001R<ol000@0
000co`0co`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o00030000oooooooo
04Goool002goool00`0003?o03?o000Y<ol000?o09Tco`0co`00HS?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool002koool0
0`0003?o03?o000X<ol000?o09Tco`0co`00Hc?o0080000:<ol00P0000@co`0200001C?o00030000
oooooooo04Goool002ooool00`0003?o03?o000W<ol000?o09Tco`0co`00O3?o00030000oooooooo
04Goool0033oool00`0003?o03?o000V<ol000?o09Tco`0co`00O3?o00030000oooooooo04Goool0
037oool00`0003?o03?o000U<ol000?o09Tco`0co`00O3?o00030000oooooooo04Goool003;oool0
0`0003?o03?o000T<ol000?o09Tco`0co`00O3?o00030000oooooooo04Goool003?oool00`0003?o
03?o000S<ol000?o09Tco`0co`00O3?o00800016oooo000coooo00<0000co`0co`008c?o0003o`2I
<ol0<ol007`co`000`000?ooooooo`15oooo000doooo00<0000co`0co`008S?o0003o`2I<ol0<ol0
07`co`000`000?ooooooo`15oooo000eoooo00<0000co`0co`008C?o0003o`2I<ol0<ol007`co`00
0`000?ooooooo`15oooo000foooo00<0000co`0co`0083?o0003o`2I<ol0<ol007`co`000`000?oo
ooooo`15oooo000goooo00<0000co`0co`007c?o0003o`2I<ol0<ol007`co`000`000?ooooooo`15
oooo000hoooo00<0000co`0co`007S?o0003o`2I<ol0<ol007`co`000`000?ooooooo`15oooo000h
oooo00<0000co`0co`007S?o0003o`2I<ol0<ol007`co`000`000?ooooooo`15oooo000ioooo00<0
000co`0co`007C?o0003o`2I<ol0<ol007`co`020000A_ooo`00>_ooo`030000<ol0<ol001`co`00
0ol0VC?o03?o001l<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol001/co`000ol0VC?o
03?o001l<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol001Xco`000ol0VC?o03?o001l
<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol001Xco`000ol0VC?o03?o001l<ol000<0
003oooooool0AOooo`00?Oooo`030000<ol0<ol001Tco`000ol0VC?o03?o001l<ol000<0003ooooo
ool0AOooo`00?Oooo`030000<ol0<ol001Tco`000ol0VC?o03?o001l<ol000<0003oooooool0AOoo
o`00?_ooo`030000<ol0<ol001Pco`000ol0VC?o03?o001l<ol000<0003oooooool0AOooo`00?_oo
o`030000<ol0<ol001Pco`000ol0VC?o03?o001l<ol000<0003oooooool0AOooo`00?oooo`030000
<ol0<ol001Lco`000ol0VC?o03?o001l<ol00P0004Koool003ooool00`0003?o03?o000G<ol000?o
09Tco`0co`00O3?o00030000oooooooo04Goool0043oool00`0003?o03?o000F<ol000?o09Tco`0c
o`00O3?o00030000oooooooo04Goool0047oool00`0003?o03?o000E<ol000?o09Tco`0co`00O3?o
00030000oooooooo04Goool0047oool00`0003?o03?o000E<ol000?o09Tco`0co`00O3?o00030000
oooooooo04Goool004;oool00`0003?o03?o000D<ol000?o09Tco`0co`00O3?o00030000oooooooo
04Goool004;oool00`0003?o03?o000D<ol000?o09Tco`0co`00Hc?o00800004<ol00P0000@co`02
00001C?o00<00003<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol001<co`000ol0VC?o
03?o001R<ol000@0000co`0co`000008<ol000@0000co`0co`000005<ol000<0000co`0co`000S?o
00030000oooooooo04Goool004?oool00`0003?o03?o000C<ol000?o09Tco`0co`00HS?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool00`0003?o
03?o000B<ol000?o09Tco`0co`00HS?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o
00040000<ol0<ol0000013?o00030000oooooooo04Goool004Coool00`0003?o03?o000B<ol000?o
09Tco`0co`00HS?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol00000
00@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`004C?o0003o`2I<ol0<ol006<co`02
00002S?o00800005<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`004C?o
0003o`2I<ol0<ol007`co`000`000?ooooooo`15oooo0016oooo00<0000co`0co`0043?o0003o`2I
<ol0<ol007`co`000`000?ooooooo`15oooo0016oooo00<0000co`0co`0043?o0003o`2I<ol0<ol0
07`co`000`000?ooooooo`15oooo0017oooo00<0000co`0co`003c?o0003o`2I<ol0<ol007`co`00
0`000?ooooooo`15oooo0017oooo00<0000co`0co`003c?o0003o`2I<ol0<ol007`co`020000A_oo
o`00B?ooo`030000<ol0<ol000hco`000ol0VC?o03?o001l<ol000<0003oooooool0AOooo`00B?oo
o`030000<ol0<ol000hco`000ol0VC?o03?o001l<ol000<0003oooooool0AOooo`00BOooo`030000
<ol0<ol000dco`000ol0VC?o03?o001l<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol0
00dco`000ol0VC?o03?o001l<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol000`co`00
0ol0VC?o03?o001l<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol000`co`000ol0VC?o
03?o001l<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol000/co`000ol0VC?o03?o001l
<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol000/co`000ol0VC?o03?o001l<ol00P00
04Koool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;<ol0B?oo
o`00COoooh/co`18oooo001>oooo9S?o00030000<ol0<ol002lco`000`0003?o03?o000_<ol0B?oo
o`00C_ooobDco`000`0003?o03?o0008<ol000<0000co`0co`009S?o00030000<ol0<ol002hco`18
oooo001?oooo93?o00030000<ol0<ol0008co`02000013?o00030000<ol0<ol000hco`02000013?o
00800003<ol0100000<co`02000013?o00030000<ol0<ol002hco`18oooo001?oooo93?o00050000
<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0000co`0co`001C?o00@00003<ol000@0
000co`0co`000008<ol000<0000co`0co`000c?o00040000<ol0<ol000000c?o00030000<ol0<ol0
02hco`18oooo001?oooo8c?o00030000<ol0<ol0008co`000`0003?o03?o000D<ol000@0000co`0c
o`000009<ol000<0000co`0co`000S?o00040000<ol0<ol0000013?o00030000<ol0<ol002dco`18
oooo001@oooo8c?o00030000<ol0<ol000D0000C<ol000@0000co`0co`00000:<ol000<0000co`0c
o`000S?o00800004<ol000<0000co`0co`00;S?o04Soool0053ooolS<ol000D0000co`0co`0co`00
00005S?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol000000c?o
00030000<ol0<ol002hco`18oooo001@oooo93?o00030000<ol0<ol001Pco`0200002S?o00800004
<ol00P0000<co`000`0003?o03?o000_<ol0B?ooo`00DOooohLco`18oooo001AooooQc?o04Soool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.27) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.27193 .30902 L
.28302 .30902 L
.2881 .30902 L
.29349 .30902 L
.29809 .30902 L
.29935 .30902 L
.30004 .30902 L
.3007 .30902 L
s
.3007 .30902 m
.30071 .61803 L
s
0 .4 1 r
.02381 .3431 m
.06244 .34837 L
.10458 .35504 L
.14415 .36234 L
.18221 .37047 L
.22272 .38049 L
.26171 .39169 L
.27193 .39491 L
.28302 .39855 L
.2881 .40027 L
.29349 .40213 L
.29809 .40375 L
.29935 .4042 L
.30004 .40444 L
.3007 .40468 L
.30198 .30902 L
.30316 .30902 L
.30553 .30902 L
.30618 .30902 L
.30686 .30902 L
.30809 .30902 L
.30924 .30902 L
.31031 .30902 L
.31148 .30902 L
.31274 .30902 L
.31343 .30902 L
.31418 .30902 L
.31489 .30902 L
.31555 .30902 L
.31678 .30902 L
.3181 .30902 L
.31929 .30902 L
.32041 .30902 L
.32164 .30902 L
.32296 .30902 L
.32412 .30902 L
.32519 .30902 L
.32637 .30902 L
.32763 .30902 L
.32827 .30902 L
.32896 .30902 L
.33021 .30902 L
.33143 .30902 L
.33255 .30902 L
.3336 .30902 L
.33459 .30902 L
.33567 .30902 L
.33683 .30902 L
.33804 .30902 L
.33919 .30902 L
Mistroke
.34022 .30902 L
.34135 .30902 L
.342 .30902 L
.34268 .30902 L
.34391 .30902 L
.34523 .30902 L
.34598 .30902 L
.34668 .30902 L
.34795 .30902 L
.3491 .30902 L
.34974 .30902 L
.35043 .30902 L
.35169 .30902 L
.35282 .30902 L
.35406 .30902 L
.35526 .30902 L
.35656 .30902 L
.35777 .30902 L
.35888 .30902 L
.35994 .30902 L
.36106 .30902 L
.36238 .30902 L
.36358 .30902 L
.36486 .30902 L
.36559 .30902 L
.36626 .30902 L
.36747 .30902 L
.36875 .30902 L
.36986 .30902 L
.37109 .30902 L
.37182 .30902 L
.37252 .30902 L
.37382 .30902 L
.37455 .30902 L
.37523 .30902 L
.37597 .30902 L
.37675 .30902 L
.37805 .30902 L
.37927 .30902 L
.37996 .30902 L
.3806 .30902 L
.38131 .30902 L
.38205 .30902 L
.38328 .30902 L
.38397 .30902 L
.38461 .30902 L
.38579 .30902 L
.38704 .30902 L
.38815 .30902 L
.3892 .30902 L
Mistroke
.39034 .30902 L
.39157 .30902 L
.39288 .30902 L
.39362 .30902 L
.3943 .30902 L
.39556 .30902 L
.39626 .30902 L
.3969 .30902 L
.3981 .30902 L
.3994 .30902 L
.40063 .30902 L
.40176 .30902 L
.40283 .30902 L
.40397 .30902 L
.40504 .30902 L
.40602 .30902 L
.40717 .30902 L
.40842 .30902 L
.4096 .30902 L
.41069 .30902 L
.41181 .30902 L
.41287 .30902 L
.41402 .30902 L
.41527 .30902 L
.4165 .30902 L
.4178 .30902 L
.41891 .30902 L
.42012 .30902 L
.42136 .30902 L
.42266 .30902 L
.42334 .30902 L
.42409 .30902 L
.42541 .30902 L
.42666 .30902 L
.42736 .30902 L
.42799 .30902 L
.42923 .30902 L
.43041 .30902 L
.43153 .30902 L
.43273 .30902 L
.43386 .30902 L
.43488 .30902 L
.43608 .30902 L
.43739 .30902 L
.43853 .30902 L
.43975 .30902 L
.44106 .30902 L
.44228 .30902 L
.44303 .30902 L
.44374 .30902 L
Mistroke
.44437 .30902 L
.44506 .30902 L
.44574 .30902 L
.44648 .30902 L
.4472 .30902 L
.44798 .30902 L
.4487 .30902 L
.44937 .30902 L
.45067 .30902 L
.45195 .30902 L
.45313 .30902 L
.45443 .30902 L
.45515 .30902 L
.45581 .30902 L
.45702 .30902 L
.45833 .30902 L
.45957 .30902 L
.4607 .30902 L
.46196 .30902 L
.46316 .30902 L
.46423 .30902 L
.4654 .30902 L
.46667 .30902 L
.46731 .30902 L
.46801 .30902 L
.46926 .30902 L
.47043 .30902 L
.47154 .30902 L
.47271 .30902 L
.47371 .30902 L
.4748 .30902 L
.47598 .30902 L
.47725 .30902 L
.47844 .30902 L
.47952 .30902 L
.48081 .30902 L
.48146 .30902 L
.48217 .30902 L
.48343 .30902 L
.48462 .30902 L
.48533 .30902 L
.48601 .30902 L
.48728 .30902 L
.48799 .30902 L
.48865 .30902 L
.48937 .30902 L
.49014 .30902 L
.49145 .30902 L
.49218 .30902 L
.49286 .30902 L
Mistroke
.4941 .30902 L
.49541 .30902 L
.49659 .30902 L
.49768 .30902 L
.49889 .30902 L
.50018 .30902 L
.5014 .30902 L
.5021 .30902 L
.50275 .30902 L
.50406 .30902 L
.5048 .30902 L
.50548 .30902 L
.50662 .30902 L
.50786 .30902 L
.50916 .30902 L
.51037 .30902 L
.51107 .30902 L
.51182 .30902 L
.51253 .30902 L
.51318 .30902 L
.51442 .30902 L
.51573 .30902 L
.51641 .30902 L
.51714 .30902 L
.51845 .30902 L
.51926 .30902 L
.52002 .30902 L
.5207 .30902 L
.52145 .30902 L
.52269 .30902 L
.52385 .30902 L
.52513 .30902 L
.52585 .30902 L
.52651 .30902 L
.52776 .30902 L
.52847 .30902 L
.52914 .30902 L
.52983 .30902 L
.53047 .30902 L
.53121 .30902 L
.5319 .30902 L
.53431 .30902 L
.535 .30902 L
.53566 .30902 L
.5369 .30902 L
.53806 .30902 L
.53914 .30902 L
.54032 .30902 L
.54158 .30902 L
.54283 .30902 L
Mistroke
.544 .30902 L
.54505 .30902 L
.54619 .30902 L
.54748 .30902 L
.54813 .30902 L
.54884 .30902 L
.5501 .30902 L
.55128 .30902 L
.55192 .30902 L
.55261 .30902 L
.55387 .30902 L
.5551 .30902 L
.55624 .30902 L
.55747 .30902 L
.55816 .30902 L
.55882 .30902 L
.56014 .30902 L
.56088 .30902 L
.56156 .30902 L
.56263 .30902 L
.56378 .30902 L
.56487 .30902 L
.56585 .30902 L
.56701 .30902 L
.56826 .30902 L
.56945 .30902 L
.57054 .30902 L
.57167 .30902 L
.57273 .30902 L
.57389 .30902 L
.57514 .30902 L
.57644 .30902 L
.57768 .30902 L
.57879 .30902 L
.58 .30902 L
.58065 .30902 L
.58134 .30902 L
.58256 .30902 L
.58389 .30902 L
.58463 .30902 L
.58533 .30902 L
.5866 .30902 L
.58776 .30902 L
.58839 .30902 L
.58909 .30902 L
.59035 .30902 L
.59147 .30902 L
.59271 .30902 L
.59401 .30902 L
.59522 .30902 L
Mistroke
.59635 .30902 L
.59739 .30902 L
.59858 .30902 L
.59972 .30902 L
.60104 .30902 L
.60223 .30902 L
.6029 .30902 L
.60362 .30902 L
.60492 .30902 L
.60614 .30902 L
.60743 .30902 L
.60854 .30902 L
.60975 .30902 L
.61042 .30902 L
.61115 .30902 L
.61184 .30902 L
.61248 .30902 L
.61323 .30902 L
.61402 .30902 L
.61468 .30902 L
.61541 .30902 L
.61673 .30902 L
.61747 .30902 L
.61814 .30902 L
.61939 .30902 L
.62071 .30902 L
.62194 .30902 L
.62263 .30902 L
.62327 .30902 L
.62445 .30902 L
.6257 .30902 L
.62682 .30902 L
.62786 .30902 L
.62901 .30902 L
.63024 .30902 L
.63154 .30902 L
.63228 .30902 L
.63297 .30902 L
.63422 .30902 L
.63493 .30902 L
.63556 .30902 L
.63677 .30902 L
.63807 .30902 L
.63929 .30902 L
.64043 .30902 L
.6415 .30902 L
.64265 .30902 L
.64508 .30902 L
.6464 .30902 L
.64765 .30902 L
Mistroke
.64877 .30902 L
.64999 .30902 L
.65105 .30902 L
.65221 .30902 L
.65343 .30902 L
.65456 .30902 L
.65563 .30902 L
.6566 .30902 L
.65765 .30902 L
.65879 .30902 L
.66007 .30902 L
.66128 .30902 L
.66245 .30902 L
.66354 .30902 L
.66471 .30902 L
.666 .30902 L
.66665 .30902 L
.66735 .30902 L
.66861 .30902 L
.66978 .30902 L
.67105 .30902 L
.67226 .30902 L
.67338 .30902 L
.67449 .30902 L
.67549 .30902 L
.67665 .30902 L
.67773 .30902 L
.67894 .30902 L
.68026 .30902 L
.68093 .30902 L
.68164 .30902 L
.68292 .30902 L
.68421 .30902 L
.68542 .30902 L
.68651 .30902 L
.68769 .30902 L
.68898 .30902 L
.68972 .30902 L
.6904 .30902 L
.69113 .30902 L
.69179 .30902 L
.69255 .30902 L
.69328 .30902 L
.69456 .30902 L
.69575 .30902 L
.69705 .30902 L
.69778 .30902 L
.69844 .30902 L
.69964 .30902 L
.70076 .30902 L
Mistroke
.70199 .30902 L
.70331 .30902 L
.70398 .30902 L
.7047 .30902 L
.70601 .30902 L
.70717 .30902 L
.70846 .30902 L
.70966 .30902 L
.71079 .30902 L
.71197 .30902 L
.71325 .30902 L
.71438 .30902 L
.71556 .30902 L
.71658 .30902 L
.71768 .30902 L
.71836 .30902 L
.71909 .30902 L
.71978 .30902 L
.72042 .30902 L
.72162 .30902 L
.7229 .30902 L
.72356 .30902 L
.72427 .30902 L
.72555 .30902 L
.72633 .30902 L
.72708 .30902 L
.72781 .30902 L
.72847 .30902 L
.72968 .30902 L
.73096 .30902 L
.73215 .30902 L
.73327 .30902 L
.73458 .30902 L
.73579 .30902 L
.73711 .30902 L
.73777 .30902 L
.7385 .30902 L
.73981 .30902 L
.74102 .30902 L
.74165 .30902 L
.74235 .30902 L
.74308 .30902 L
.74376 .30902 L
.74501 .30902 L
.74615 .30902 L
.74741 .30902 L
.74873 .30902 L
.75805 .30902 L
.76289 .30902 L
.76554 .30902 L
Mistroke
.76805 .30902 L
.76947 .30902 L
.77028 .30902 L
.77102 .30902 L
.77233 .30902 L
.77299 .30902 L
.77371 .30902 L
.77502 .30902 L
.77576 .30902 L
.77643 .30902 L
.77774 .30902 L
.77897 .30902 L
.78011 .30902 L
.78133 .30902 L
.78249 .30902 L
.78355 .30902 L
.78473 .30902 L
.78602 .30902 L
.78666 .30902 L
.78736 .30902 L
.78861 .30902 L
.79886 .30902 L
.81727 .30902 L
.85873 .30902 L
.89867 .30902 L
.9371 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.27) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00100003?o03?o001Vo`Hco`00
0`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo01?oool0017oool00`0003?o
03?o000_<ol000<0000co`0co`0053?o000306Ko<ol0<ol001Pco`000`0003?o03?o000^<ol000<0
000co`0co`00;c?o00030000oooooooo02ooool00`000?ooooooo`0Coooo000AooooBC?o000306Ko
<ol0<ol007/co`000`000?ooooooo`15oooo000AooooBC?o000306Ko<ol0<ol007/co`000`000?oo
ooooo`15oooo000AooooBC?o000306Ko<ol0<ol007/co`000`000?ooooooo`15oooo000AooooBC?o
000306Ko<ol0<ol007/co`000`000?ooooooo`15oooo000AooooBC?o000306Ko<ol0<ol007/co`00
0`000?ooooooo`15oooo000AooooBC?o000306Ko<ol0<ol007/co`020000A_ooo`004Oooo`H0I_m3
<ol000<0I_lco`0co`00Nc?o00030000oooooooo04Goool0017oool6<ol0201Voc/co`000`1Voc?o
03?o001k<ol000<0003oooooool0AOooo`004Oooo`hco`0506Ko=S?o000306Ko<ol0<ol007/co`00
0`000?ooooooo`15oooo000Aoooo4c?o00D0I_la<ol000<0I_lco`0co`00Nc?o00030000oooooooo
04Goool0017ooolH<ol01P1Vob/co`000`1Voc?o03?o001k<ol000<0003oooooool0AOooo`004Ooo
oahco`0506Ko9S?o000306Ko<ol0<ol007/co`000`000?ooooooo`15oooo000Aoooo8c?o00D0I_lQ
<ol000<0I_lco`0co`00Nc?o00030000oooooooo04Goool0017oool200009S?o00@0I_lM<ol000<0
I_lco`0co`00Nc?o00800016oooo000Coooo0P0002Pco`0306Ko6S?o000306Ko<ol0<ol007/co`00
0`000?ooooooo`15oooo000Eoooo0P0002Tco`0406Ko5S?o000306Ko<ol0<ol007/co`000`000?oo
ooooo`15oooo000Goooo0P0002/co`0306Ko4c?o000306Ko<ol0<ol007/co`000`000?ooooooo`15
oooo000Ioooo0P0002`co`0306Ko43?o000306Ko<ol0<ol007/co`000`000?ooooooo`15oooo000K
oooo0P0002dco`0406Ko33?o000306Ko<ol0<ol007/co`000`000?ooooooo`15oooo000Moooo0P00
02lco`0306Ko2C?o000306Ko<ol0<ol007/co`000`000?ooooooo`15oooo000Ooooo00<0000co`0c
o`00;c?o00D0I_l4<ol000<0I_lco`0co`00Nc?o00030000oooooooo04Goool0023oool00`0003?o
03?o000c<ol00`1Vo`03<ol006Ko<ol007`co`020000A_ooo`008Oooo`80000f<ol00P1Vogdco`00
0`000?ooooooo`15oooo000Soooo00<0000co`0co`00=3?o0003o`2I<ol0<ol007/co`000`000?oo
ooooo`15oooo000Toooo0P0003@co`000ol0VC?o03?o001k<ol000<0003oooooool0AOooo`009_oo
o`030000<ol0<ol0034co`000ol0VC?o03?o001k<ol000<0003oooooool0AOooo`009oooo`030000
<ol0<ol0030co`000ol0VC?o03?o001k<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol0
02lco`000ol0VC?o03?o001R<ol00P0000@co`02000013?o00800003<ol0100000@co`000`000?oo
ooooo`15oooo000Yoooo00<0000co`0co`00;S?o0003o`2I<ol0<ol0064co`00100003?o03?o0000
00Pco`00100003?o03?o0000008co`000`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_oo
o`030000<ol0<ol002dco`000ol0VC?o03?o001Q<ol000@0000co`0co`000008<ol000@0000co`0c
o`000003<ol000<0000co`0co`0013?o00<00015oooo000[oooo0P0002dco`000ol0VC?o03?o001Q
<ol000@0000co`0co`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o00030000
oooooooo04Goool002goool00`0003?o03?o000Z<ol000?o09Tco`0co`00HC?o00040000<ol0<ol0
000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool0
02koool00`0003?o03?o000Y<ol000?o09Tco`0co`00HS?o0080000:<ol00P0000@co`0200001C?o
00030000oooooooo04Goool002ooool00`0003?o03?o000X<ol000?o09Tco`0co`00Nc?o00030000
oooooooo04Goool0033oool00`0003?o03?o000W<ol000?o09Tco`0co`00Nc?o00030000oooooooo
04Goool0037oool00`0003?o03?o000V<ol000?o09Tco`0co`00Nc?o00030000oooooooo04Goool0
03;oool00`0003?o03?o000U<ol000?o09Tco`0co`00Nc?o00030000oooooooo04Goool003?oool0
0`0003?o03?o000T<ol000?o09Tco`0co`00Nc?o00800016oooo000coooo00<0000co`0co`0093?o
0003o`2I<ol0<ol007/co`000`000?ooooooo`15oooo000doooo00<0000co`0co`008c?o0003o`2I
<ol0<ol007/co`000`000?ooooooo`15oooo000eoooo00<0000co`0co`008S?o0003o`2I<ol0<ol0
07/co`000`000?ooooooo`15oooo000foooo00<0000co`0co`008C?o0003o`2I<ol0<ol007/co`00
0`000?ooooooo`15oooo000goooo00<0000co`0co`0083?o0003o`2I<ol0<ol007/co`000`000?oo
ooooo`15oooo000hoooo00<0000co`0co`007c?o0003o`2I<ol0<ol007/co`000`000?ooooooo`15
oooo000hoooo00<0000co`0co`007c?o0003o`2I<ol0<ol007/co`000`000?ooooooo`15oooo000i
oooo00<0000co`0co`007S?o0003o`2I<ol0<ol007/co`020000A_ooo`00>_ooo`030000<ol0<ol0
01dco`000ol0VC?o03?o001k<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol001`co`00
0ol0VC?o03?o001k<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol001/co`000ol0VC?o
03?o001k<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol001/co`000ol0VC?o03?o001k
<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol001Xco`000ol0VC?o03?o001k<ol000<0
003oooooool0AOooo`00?Oooo`030000<ol0<ol001Xco`000ol0VC?o03?o001k<ol000<0003ooooo
ool0AOooo`00?_ooo`030000<ol0<ol001Tco`000ol0VC?o03?o001k<ol000<0003oooooool0AOoo
o`00?_ooo`030000<ol0<ol001Tco`000ol0VC?o03?o001k<ol000<0003oooooool0AOooo`00?ooo
o`030000<ol0<ol001Pco`000ol0VC?o03?o001k<ol00P0004Koool003ooool00`0003?o03?o000H
<ol000?o09Tco`0co`00Nc?o00030000oooooooo04Goool0043oool00`0003?o03?o000G<ol000?o
09Tco`0co`00Nc?o00030000oooooooo04Goool0047oool00`0003?o03?o000F<ol000?o09Tco`0c
o`00Nc?o00030000oooooooo04Goool0047oool00`0003?o03?o000F<ol000?o09Tco`0co`00Nc?o
00030000oooooooo04Goool004;oool00`0003?o03?o000E<ol000?o09Tco`0co`00Nc?o00030000
oooooooo04Goool004;oool00`0003?o03?o000E<ol000?o09Tco`0co`00HS?o00800004<ol00P00
00@co`0200001C?o00<00003<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol001@co`00
0ol0VC?o03?o001Q<ol000@0000co`0co`000008<ol000@0000co`0co`000005<ol000<0000co`0c
o`000S?o00030000oooooooo04Goool004?oool00`0003?o03?o000D<ol000?o09Tco`0co`00HC?o
00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool0
0`0003?o03?o000C<ol000?o09Tco`0co`00HC?o00040000<ol0<ol0000023?o00040000<ol0<ol0
00000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool004Coool00`0003?o03?o000C
<ol000?o09Tco`0co`00HC?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000
<ol0000000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`004S?o0003o`2I<ol0<ol0
068co`0200002S?o00800005<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0c
o`004S?o0003o`2I<ol0<ol007/co`000`000?ooooooo`15oooo0016oooo00<0000co`0co`004C?o
0003o`2I<ol0<ol007/co`000`000?ooooooo`15oooo0016oooo00<0000co`0co`004C?o0003o`2I
<ol0<ol007/co`000`000?ooooooo`15oooo0017oooo00<0000co`0co`0043?o0003o`2I<ol0<ol0
07/co`000`000?ooooooo`15oooo0017oooo00<0000co`0co`0043?o0003o`2I<ol0<ol007/co`02
0000A_ooo`00B?ooo`030000<ol0<ol000lco`000ol0VC?o03?o001k<ol000<0003oooooool0AOoo
o`00B?ooo`030000<ol0<ol000lco`000ol0VC?o03?o001k<ol000<0003oooooool0AOooo`00BOoo
o`030000<ol0<ol000hco`000ol0VC?o03?o001k<ol000<0003oooooool0AOooo`00BOooo`030000
<ol0<ol000hco`000ol0VC?o03?o001k<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol0
00dco`000ol0VC?o03?o001k<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol000dco`00
0ol0VC?o03?o001k<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol000`co`000ol0VC?o
03?o001k<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol000`co`000ol0VC?o03?o001k
<ol00P0004Koool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;
<ol0B?ooo`00COoooh/co`18oooo001>oooo9S?o00030000<ol0<ol002lco`000`0003?o03?o000_
<ol0B?ooo`00C_ooobDco`000`0003?o03?o0008<ol000<0000co`0co`009S?o00030000<ol0<ol0
02hco`18oooo001?oooo93?o00030000<ol0<ol0008co`02000013?o00030000<ol0<ol000hco`02
000013?o00800003<ol0100000@co`000`0003?o03?o0002<ol000<0000co`0co`00;S?o04Soool0
04oooolT<ol000D0000co`0co`0co`0000000S?o00030000<ol0<ol0008co`000`0003?o03?o0005
<ol0100000<co`00100003?o03?o000000Pco`000`0003?o03?o0005<ol000<0000co`0co`000S?o
00030000<ol0<ol002hco`18oooo001?oooo8c?o00030000<ol0<ol0008co`000`0003?o03?o000D
<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol000<co`000`0003?o
03?o000]<ol0B?ooo`00D?ooob<co`000`0003?o03?o000500004c?o00040000<ol0<ol000002S?o
00030000<ol0<ol000@co`001@0003?o03?o03?o0000000`<ol0B?ooo`00D?ooob<co`001@0003?o
03?o03?o0000000F<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0000co`0c
o`000003<ol000<0000co`0co`00;S?o04Soool0053ooolT<ol000<0000co`0co`0063?o0080000:
<ol00P0000<co`0400000S?o00030000<ol0<ol002lco`18oooo001AooooQc?o04Soool0057ooon7
<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.29779 .30902 L
.30059 .30902 L
.30316 .30902 L
.30432 .30902 L
.3056 .30902 L
s
.3056 .30902 m
.3056 .61803 L
s
0 .4 1 r
.02381 .34178 m
.06244 .34684 L
.10458 .35326 L
.14415 .36028 L
.18221 .36809 L
.22272 .37772 L
.26171 .38849 L
.28158 .39462 L
.29205 .39804 L
.29779 .39998 L
.30059 .40094 L
.30316 .40182 L
.30432 .40223 L
.3056 .40268 L
.3068 .30902 L
.30791 .30902 L
.30921 .30902 L
.31039 .30902 L
.31105 .30902 L
.31175 .30902 L
.31304 .30902 L
.31435 .30902 L
.31509 .30902 L
.31579 .30902 L
.31657 .30902 L
.31731 .30902 L
.31798 .30902 L
.3187 .30902 L
.32001 .30902 L
.32122 .30902 L
.32253 .30902 L
.32319 .30902 L
.32392 .30902 L
.32513 .30902 L
.3264 .30902 L
.32749 .30902 L
.32867 .30902 L
.32996 .30902 L
.33068 .30902 L
.33133 .30902 L
.3326 .30902 L
.3338 .30902 L
.33493 .30902 L
.33612 .30902 L
.33714 .30902 L
.33826 .30902 L
.33946 .30902 L
.34075 .30902 L
.34197 .30902 L
.34309 .30902 L
Mistroke
.34438 .30902 L
.34559 .30902 L
.34669 .30902 L
.34787 .30902 L
.34916 .30902 L
.34981 .30902 L
.35052 .30902 L
.35178 .30902 L
.35296 .30902 L
.35414 .30902 L
.35527 .30902 L
.35628 .30902 L
.35738 .30902 L
.35857 .30902 L
.35984 .30902 L
.36094 .30902 L
.36211 .30902 L
.36339 .30902 L
.36456 .30902 L
.36582 .30902 L
.36654 .30902 L
.3672 .30902 L
.36841 .30902 L
.36951 .30902 L
.37078 .30902 L
.37197 .30902 L
.37329 .30902 L
.37396 .30902 L
.37469 .30902 L
.37598 .30902 L
.37719 .30902 L
.37793 .30902 L
.37862 .30902 L
.37992 .30902 L
.3806 .30902 L
.38132 .30902 L
.38211 .30902 L
.38285 .30902 L
.38398 .30902 L
.38522 .30902 L
.38652 .30902 L
.38772 .30902 L
.38886 .30902 L
.38989 .30902 L
.39108 .30902 L
.3922 .30902 L
.39342 .30902 L
.39472 .30902 L
.39582 .30902 L
.39704 .30902 L
Mistroke
.39835 .30902 L
.39908 .30902 L
.39975 .30902 L
.40106 .30902 L
.40229 .30902 L
.40344 .30902 L
.40449 .30902 L
.40569 .30902 L
.40683 .30902 L
.40788 .30902 L
.40885 .30902 L
.40991 .30902 L
.41103 .30902 L
.41323 .30902 L
.41446 .30902 L
.41558 .30902 L
.41621 .30902 L
.4169 .30902 L
.41816 .30902 L
.41941 .30902 L
.42056 .30902 L
.42174 .30902 L
.42298 .30902 L
.42404 .30902 L
.4252 .30902 L
.42646 .30902 L
.42716 .30902 L
.42779 .30902 L
.42905 .30902 L
.4302 .30902 L
.43129 .30902 L
.43243 .30902 L
.43359 .30902 L
.43485 .30902 L
.43595 .30902 L
.43712 .30902 L
.43823 .30902 L
.43924 .30902 L
.44052 .30902 L
.44123 .30902 L
.44187 .30902 L
.44314 .30902 L
.4443 .30902 L
.44497 .30902 L
.44567 .30902 L
.44637 .30902 L
.44715 .30902 L
.44781 .30902 L
.44853 .30902 L
.44982 .30902 L
Mistroke
.45103 .30902 L
.45233 .30902 L
.45356 .30902 L
.45469 .30902 L
.45595 .30902 L
.45714 .30902 L
.45844 .30902 L
.45917 .30902 L
.45985 .30902 L
.46054 .30902 L
.4612 .30902 L
.46242 .30902 L
.46373 .30902 L
.46448 .30902 L
.46516 .30902 L
.46629 .30902 L
.46754 .30902 L
.46884 .30902 L
.47006 .30902 L
.47075 .30902 L
.4715 .30902 L
.47216 .30902 L
.47286 .30902 L
.47349 .30902 L
.47418 .30902 L
.47541 .30902 L
.47615 .30902 L
.47683 .30902 L
.47757 .30902 L
.47837 .30902 L
.47907 .30902 L
.47972 .30902 L
.48041 .30902 L
.48115 .30902 L
.4818 .30902 L
.4825 .30902 L
.48375 .30902 L
.48444 .30902 L
.48509 .30902 L
.48581 .30902 L
.48657 .30902 L
.48723 .30902 L
.48794 .30902 L
.48925 .30902 L
.49052 .30902 L
.4917 .30902 L
.49295 .30902 L
.49413 .30902 L
.49519 .30902 L
.49634 .30902 L
Mistroke
.49759 .30902 L
.49822 .30902 L
.49892 .30902 L
.50014 .30902 L
.50128 .30902 L
.50255 .30902 L
.50319 .30902 L
.50389 .30902 L
.50514 .30902 L
.5063 .30902 L
.51176 .30902 L
.51693 .30902 L
.51919 .30902 L
.52047 .30902 L
.52167 .30902 L
.52277 .30902 L
.52377 .30902 L
.52493 .30902 L
.52602 .30902 L
.52717 .30902 L
.52822 .30902 L
.52938 .30902 L
.53061 .30902 L
.53175 .30902 L
.53298 .30902 L
.53413 .30902 L
.53519 .30902 L
.53643 .30902 L
.53713 .30902 L
.53778 .30902 L
.54023 .30902 L
.54497 .30902 L
.54612 .30902 L
.54735 .30902 L
.54806 .30902 L
.5487 .30902 L
.54996 .30902 L
.55066 .30902 L
.55131 .30902 L
.55202 .30902 L
.55277 .30902 L
.55403 .30902 L
.55475 .30902 L
.55543 .30902 L
.55669 .30902 L
.55785 .30902 L
.55849 .30902 L
.55918 .30902 L
.56045 .30902 L
.56174 .30902 L
Mistroke
.56295 .30902 L
.56404 .30902 L
.56522 .30902 L
.56651 .30902 L
.56716 .30902 L
.56787 .30902 L
.56913 .30902 L
.57031 .30902 L
.57149 .30902 L
.57262 .30902 L
.57362 .30902 L
.57472 .30902 L
.57591 .30902 L
.57718 .30902 L
.57826 .30902 L
.57945 .30902 L
.58059 .30902 L
.58183 .30902 L
.58313 .30902 L
.58434 .30902 L
.58547 .30902 L
.5865 .30902 L
.58769 .30902 L
.58881 .30902 L
.59004 .30902 L
.59133 .30902 L
.59244 .30902 L
.59366 .30902 L
.59496 .30902 L
.5957 .30902 L
.59637 .30902 L
.59767 .30902 L
.5989 .30902 L
.60006 .30902 L
.6011 .30902 L
.6023 .30902 L
.60344 .30902 L
.60449 .30902 L
.60546 .30902 L
.60652 .30902 L
.60764 .30902 L
.60877 .30902 L
.60999 .30902 L
.61104 .30902 L
.61218 .30902 L
.61288 .30902 L
.61352 .30902 L
.61479 .30902 L
.61594 .30902 L
.61716 .30902 L
Mistroke
.61836 .30902 L
.61967 .30902 L
.62091 .30902 L
.62207 .30902 L
.62321 .30902 L
.62424 .30902 L
.62543 .30902 L
.62656 .30902 L
.62779 .30902 L
.62909 .30902 L
.6302 .30902 L
.63142 .30902 L
.63209 .30902 L
.63283 .30902 L
.63352 .30902 L
.63417 .30902 L
.63538 .30902 L
.63668 .30902 L
.63779 .30902 L
.63884 .30902 L
.64 .30902 L
.64124 .30902 L
.64248 .30902 L
.64379 .30902 L
.64491 .30902 L
.64613 .30902 L
.64729 .30902 L
.64835 .30902 L
.64956 .30902 L
.65071 .30902 L
.65177 .30902 L
.65275 .30902 L
.65383 .30902 L
.65497 .30902 L
.65618 .30902 L
.6575 .30902 L
.65874 .30902 L
.65989 .30902 L
.66104 .30902 L
.66207 .30902 L
.66327 .30902 L
.66439 .30902 L
.66563 .30902 L
.66693 .30902 L
.66804 .30902 L
.66926 .30902 L
.67058 .30902 L
.67131 .30902 L
.67199 .30902 L
.67329 .30902 L
Mistroke
.67453 .30902 L
.67558 .30902 L
.67674 .30902 L
.67787 .30902 L
.67908 .30902 L
.68022 .30902 L
.68126 .30902 L
.68225 .30902 L
.6833 .30902 L
.68444 .30902 L
.68566 .30902 L
.68681 .30902 L
.68785 .30902 L
.68908 .30902 L
.68978 .30902 L
.69042 .30902 L
.69159 .30902 L
.69283 .30902 L
.69405 .30902 L
.69537 .30902 L
.69662 .30902 L
.69777 .30902 L
.69892 .30902 L
.69996 .30902 L
.70116 .30902 L
.70228 .30902 L
.70352 .30902 L
.70483 .30902 L
.70594 .30902 L
.70716 .30902 L
.70848 .30902 L
.70922 .30902 L
.70989 .30902 L
.71119 .30902 L
.71243 .30902 L
.71348 .30902 L
.71464 .30902 L
.71578 .30902 L
.717 .30902 L
.71813 .30902 L
.71917 .30902 L
.72022 .30902 L
.72121 .30902 L
.72236 .30902 L
.72358 .30902 L
.72473 .30902 L
.72577 .30902 L
.727 .30902 L
.7277 .30902 L
.72833 .30902 L
Mistroke
.72951 .30902 L
.73075 .30902 L
.73197 .30902 L
.73266 .30902 L
.73329 .30902 L
.73446 .30902 L
.7357 .30902 L
.73681 .30902 L
.73785 .30902 L
.73899 .30902 L
.74022 .30902 L
.74146 .30902 L
.74216 .30902 L
.7428 .30902 L
.74349 .30902 L
.74421 .30902 L
.74552 .30902 L
.74672 .30902 L
.74802 .30902 L
.74925 .30902 L
.75038 .30902 L
.75144 .30902 L
.75257 .30902 L
.75364 .30902 L
.75462 .30902 L
.75577 .30902 L
.75701 .30902 L
.75819 .30902 L
.75929 .30902 L
.76052 .30902 L
.76168 .30902 L
.76273 .30902 L
.76385 .30902 L
.76509 .30902 L
.76639 .30902 L
.7675 .30902 L
.76871 .30902 L
.77002 .30902 L
.77123 .30902 L
.77187 .30902 L
.77256 .30902 L
.77329 .30902 L
.77397 .30902 L
.77522 .30902 L
.77637 .30902 L
.77762 .30902 L
.77894 .30902 L
.78006 .30902 L
.78125 .30902 L
.78238 .30902 L
Mistroke
.7834 .30902 L
.7846 .30902 L
.7859 .30902 L
.78713 .30902 L
.78826 .30902 L
.80919 .30902 L
.84864 .30902 L
.88657 .30902 L
.92696 .30902 L
.96583 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`001@0003?o03?o03?o001Vo`05
<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0
000co`0co`00;c?o00030000<ol0<ol001Dco`000`1Voc?o03?o000G<ol000<0000co`0co`00;S?o
00030000<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004OooodXco`00
0`1Voc?o03?o001j<ol000<0003oooooool0AOooo`004OooodXco`000`1Voc?o03?o001j<ol000<0
003oooooool0AOooo`004OooodXco`000`1Voc?o03?o001j<ol000<0003oooooool0AOooo`004Ooo
odXco`000`1Voc?o03?o001j<ol000<0003oooooool0AOooo`004OooodXco`000`1Voc?o03?o001j
<ol000<0003oooooool0AOooo`004OooodXco`000`1Voc?o03?o001j<ol00P0004Koool0017oool6
06KoA3?o000306Ko<ol0<ol007Xco`000`000?ooooooo`15oooo000Aoooo1S?o00P0I_ll<ol000<0
I_lco`0co`00NS?o00030000oooooooo04Goool0017oool><ol01@1VocLco`000`1Voc?o03?o001j
<ol000<0003oooooool0AOooo`004Ooooa<co`0806Ko;c?o000306Ko<ol0<ol007Xco`000`000?oo
ooooo`15oooo000Aoooo6c?o00L0I_lX<ol000<0I_lco`0co`00NS?o00030000oooooooo04Goool0
017ooolR<ol00`1VobDco`000`1Voc?o03?o001j<ol000<0003oooooool0AOooo`004OooobDco`04
06Ko8C?o000306Ko<ol0<ol007Xco`000`000?ooooooo`15oooo000Aoooo0P0002Lco`0406Ko7C?o
000306Ko<ol0<ol007Xco`020000A_ooo`004oooo`80000Y<ol01@1VoaPco`000`1Voc?o03?o001j
<ol000<0003oooooool0AOooo`005Oooo`80000/<ol0101Voa@co`000`1Voc?o03?o001j<ol000<0
003oooooool0AOooo`005oooo`80000^<ol00`1Voa4co`000`1Voc?o03?o001j<ol000<0003ooooo
ool0AOooo`006Oooo`80000_<ol0101Vo`dco`000`1Voc?o03?o001j<ol000<0003oooooool0AOoo
o`006oooo`80000a<ol0101Vo`Tco`000`1Voc?o03?o001j<ol000<0003oooooool0AOooo`007Ooo
o`80000c<ol0101Vo`Dco`000`1Voc?o03?o001j<ol000<0003oooooool0AOooo`007oooo`030000
<ol0<ol003@co`0206Ko0c?o000306Ko<ol0<ol007Xco`000`000?ooooooo`15oooo000Poooo00<0
000co`0co`00=C?o00@0I_ml<ol00P0004Koool0027oool20000>3?o000306Ko<ol0<ol007Xco`00
0`000?ooooooo`15oooo000Soooo00<0000co`0co`00=C?o0003o`2I<ol0<ol007Xco`000`000?oo
ooooo`15oooo000Toooo0P0003Dco`000ol0VC?o03?o001j<ol000<0003oooooool0AOooo`009_oo
o`030000<ol0<ol0038co`000ol0VC?o03?o001j<ol000<0003oooooool0AOooo`009oooo`030000
<ol0<ol0034co`000ol0VC?o03?o001j<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol0
030co`000ol0VC?o03?o001Q<ol00P0000@co`02000013?o00800003<ol0100000@co`000`000?oo
ooooo`15oooo000Yoooo00<0000co`0co`00;c?o0003o`2I<ol0<ol0060co`00100003?o03?o0000
00Pco`00100003?o03?o0000008co`000`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_oo
o`030000<ol0<ol002hco`000ol0VC?o03?o001P<ol000@0000co`0co`000008<ol000@0000co`0c
o`000003<ol000<0000co`0co`0013?o00<00015oooo000[oooo0P0002hco`000ol0VC?o03?o001P
<ol000@0000co`0co`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o00030000
oooooooo04Goool002goool00`0003?o03?o000[<ol000?o09Tco`0co`00H3?o00040000<ol0<ol0
000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool0
02koool00`0003?o03?o000Z<ol000?o09Tco`0co`00HC?o0080000:<ol00P0000@co`0200001C?o
00030000oooooooo04Goool002ooool00`0003?o03?o000Y<ol000?o09Tco`0co`00NS?o00030000
oooooooo04Goool0033oool00`0003?o03?o000X<ol000?o09Tco`0co`00NS?o00030000oooooooo
04Goool0037oool00`0003?o03?o000W<ol000?o09Tco`0co`00NS?o00030000oooooooo04Goool0
03;oool00`0003?o03?o000V<ol000?o09Tco`0co`00NS?o00030000oooooooo04Goool003?oool0
0`0003?o03?o000U<ol000?o09Tco`0co`00NS?o00800016oooo000coooo00<0000co`0co`009C?o
0003o`2I<ol0<ol007Xco`000`000?ooooooo`15oooo000doooo00<0000co`0co`0093?o0003o`2I
<ol0<ol007Xco`000`000?ooooooo`15oooo000eoooo00<0000co`0co`008c?o0003o`2I<ol0<ol0
07Xco`000`000?ooooooo`15oooo000foooo00<0000co`0co`008S?o0003o`2I<ol0<ol007Xco`00
0`000?ooooooo`15oooo000goooo00<0000co`0co`008C?o0003o`2I<ol0<ol007Xco`000`000?oo
ooooo`15oooo000hoooo00<0000co`0co`0083?o0003o`2I<ol0<ol007Xco`000`000?ooooooo`15
oooo000hoooo00<0000co`0co`0083?o0003o`2I<ol0<ol007Xco`000`000?ooooooo`15oooo000i
oooo00<0000co`0co`007c?o0003o`2I<ol0<ol007Xco`020000A_ooo`00>_ooo`030000<ol0<ol0
01hco`000ol0VC?o03?o001j<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol001dco`00
0ol0VC?o03?o001j<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol001`co`000ol0VC?o
03?o001j<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol001`co`000ol0VC?o03?o001j
<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol001/co`000ol0VC?o03?o001j<ol000<0
003oooooool0AOooo`00?Oooo`030000<ol0<ol001/co`000ol0VC?o03?o001j<ol000<0003ooooo
ool0AOooo`00?_ooo`030000<ol0<ol001Xco`000ol0VC?o03?o001j<ol000<0003oooooool0AOoo
o`00?_ooo`030000<ol0<ol001Xco`000ol0VC?o03?o001j<ol000<0003oooooool0AOooo`00?ooo
o`030000<ol0<ol001Tco`000ol0VC?o03?o001j<ol00P0004Koool003ooool00`0003?o03?o000I
<ol000?o09Tco`0co`00NS?o00030000oooooooo04Goool0043oool00`0003?o03?o000H<ol000?o
09Tco`0co`00NS?o00030000oooooooo04Goool0047oool00`0003?o03?o000G<ol000?o09Tco`0c
o`00NS?o00030000oooooooo04Goool0047oool00`0003?o03?o000G<ol000?o09Tco`0co`00NS?o
00030000oooooooo04Goool004;oool00`0003?o03?o000F<ol000?o09Tco`0co`00NS?o00030000
oooooooo04Goool004;oool00`0003?o03?o000F<ol000?o09Tco`0co`00HC?o00800004<ol00P00
00@co`0200001C?o00<00003<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol001Dco`00
0ol0VC?o03?o001P<ol000@0000co`0co`000008<ol000@0000co`0co`000005<ol000<0000co`0c
o`000S?o00030000oooooooo04Goool004?oool00`0003?o03?o000E<ol000?o09Tco`0co`00H3?o
00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool0
0`0003?o03?o000D<ol000?o09Tco`0co`00H3?o00040000<ol0<ol0000023?o00040000<ol0<ol0
00000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool004Coool00`0003?o03?o000D
<ol000?o09Tco`0co`00H3?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000
<ol0000000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`004c?o0003o`2I<ol0<ol0
064co`0200002S?o00800005<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0c
o`004c?o0003o`2I<ol0<ol007Xco`000`000?ooooooo`15oooo0016oooo00<0000co`0co`004S?o
0003o`2I<ol0<ol007Xco`000`000?ooooooo`15oooo0016oooo00<0000co`0co`004S?o0003o`2I
<ol0<ol007Xco`000`000?ooooooo`15oooo0017oooo00<0000co`0co`004C?o0003o`2I<ol0<ol0
07Xco`000`000?ooooooo`15oooo0017oooo00<0000co`0co`004C?o0003o`2I<ol0<ol007Xco`02
0000A_ooo`00B?ooo`030000<ol0<ol0010co`000ol0VC?o03?o001j<ol000<0003oooooool0AOoo
o`00B?ooo`030000<ol0<ol0010co`000ol0VC?o03?o001j<ol000<0003oooooool0AOooo`00BOoo
o`030000<ol0<ol000lco`000ol0VC?o03?o001j<ol000<0003oooooool0AOooo`00BOooo`030000
<ol0<ol000lco`000ol0VC?o03?o001j<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol0
00hco`000ol0VC?o03?o001j<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol000hco`00
0ol0VC?o03?o001j<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol000dco`000ol0VC?o
03?o001j<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol000dco`000ol0VC?o03?o001j
<ol00P0004Koool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;
<ol0B?ooo`00COoooh/co`18oooo001>oooo9S?o00030000<ol0<ol002lco`000`0003?o03?o000_
<ol0B?ooo`00C_ooobDco`000`0003?o03?o0008<ol000<0000co`0co`009S?o00030000<ol0<ol0
02hco`18oooo001?oooo93?o00030000<ol0<ol0008co`02000013?o00030000<ol0<ol000hco`02
000013?o00800003<ol01000008co`03000013?o00030000<ol0<ol002hco`18oooo001?oooo93?o
00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0000co`0co`001C?o00@00003
<ol000@0000co`0co`000008<ol000<0000co`0co`000c?o00040000<ol0<ol000000c?o00030000
<ol0<ol002hco`18oooo001?oooo8c?o00030000<ol0<ol0008co`000`0003?o03?o000D<ol000@0
000co`0co`000009<ol000<0000co`0co`000S?o00040000<ol0<ol0000013?o00030000<ol0<ol0
02dco`18oooo001@oooo8c?o00030000<ol0<ol000D0000C<ol000@0000co`0co`00000:<ol000@0
000co`0co`0co`03000013?o00030000<ol0<ol002hco`18oooo001@oooo8c?o00050000<ol0<ol0
<ol0000001Hco`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o0003
<ol000<0000co`0co`00;S?o04Soool0053ooolT<ol000<0000co`0co`0063?o0080000:<ol00P00
00@co`0300000S?o00030000<ol0<ol002lco`18oooo001AooooQc?o04Soool0057ooon7<ol0B?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.29779 .30902 L
.30316 .30902 L
.3056 .30902 L
.30791 .30902 L
.30919 .30902 L
s
.30919 .30902 m
.3092 .61803 L
s
0 .4 1 r
.02381 .34047 m
.06244 .34533 L
.10458 .35149 L
.14415 .35822 L
.18221 .36572 L
.22272 .37496 L
.26171 .3853 L
.28158 .39119 L
.29205 .39448 L
.29779 .39633 L
.30316 .39811 L
.3056 .39892 L
.30791 .39971 L
.30919 .40014 L
.30992 .30902 L
.31059 .30902 L
.31177 .30902 L
.31304 .30902 L
.31377 .30902 L
.31445 .30902 L
.31519 .30902 L
.31597 .30902 L
.31729 .30902 L
.31804 .30902 L
.31874 .30902 L
.32005 .30902 L
.32124 .30902 L
.3219 .30902 L
.32261 .30902 L
.32392 .30902 L
.3251 .30902 L
.32621 .30902 L
.32743 .30902 L
.32874 .30902 L
.33005 .30902 L
.3307 .30902 L
.33142 .30902 L
.33269 .30902 L
.33387 .30902 L
.33507 .30902 L
.33621 .30902 L
.33722 .30902 L
.33833 .30902 L
.3396 .30902 L
.34081 .30902 L
.3419 .30902 L
.34309 .30902 L
.34431 .30902 L
.34544 .30902 L
.34677 .30902 L
Mistroke
.34797 .30902 L
.34912 .30902 L
.35019 .30902 L
.35132 .30902 L
.35255 .30902 L
.35321 .30902 L
.35392 .30902 L
.35519 .30902 L
.35589 .30902 L
.35652 .30902 L
.35727 .30902 L
.35798 .30902 L
.35922 .30902 L
.36037 .30902 L
.36162 .30902 L
.36226 .30902 L
.36296 .30902 L
.3636 .30902 L
.36429 .30902 L
.36502 .30902 L
.36569 .30902 L
.3669 .30902 L
.36819 .30902 L
.36892 .30902 L
.36971 .30902 L
.37046 .30902 L
.37114 .30902 L
.37244 .30902 L
.3731 .30902 L
.37382 .30902 L
.3745 .30902 L
.37515 .30902 L
.37636 .30902 L
.37767 .30902 L
.3784 .30902 L
.37909 .30902 L
.38022 .30902 L
.38147 .30902 L
.38278 .30902 L
.384 .30902 L
.38514 .30902 L
.38635 .30902 L
.38704 .30902 L
.38769 .30902 L
.38891 .30902 L
.39022 .30902 L
.39087 .30902 L
.3916 .30902 L
.39288 .30902 L
.39408 .30902 L
Mistroke
.3952 .30902 L
.39622 .30902 L
.3974 .30902 L
.39852 .30902 L
.39971 .30902 L
.40082 .30902 L
.40203 .30902 L
.40333 .30902 L
.40401 .30902 L
.40474 .30902 L
.40603 .30902 L
.40676 .30902 L
.40743 .30902 L
.40817 .30902 L
.40896 .30902 L
.40964 .30902 L
.41039 .30902 L
.41109 .30902 L
.41173 .30902 L
.41296 .30902 L
.41426 .30902 L
.41543 .30902 L
.41669 .30902 L
.41789 .30902 L
.41898 .30902 L
.42019 .30902 L
.42087 .30902 L
.42151 .30902 L
.4228 .30902 L
.42352 .30902 L
.42417 .30902 L
.42537 .30902 L
.42649 .30902 L
.42771 .30902 L
.42903 .30902 L
.42969 .30902 L
.43041 .30902 L
.43171 .30902 L
.43299 .30902 L
.43417 .30902 L
.43537 .30902 L
.43651 .30902 L
.43753 .30902 L
.43863 .30902 L
.43983 .30902 L
.4411 .30902 L
.44219 .30902 L
.44337 .30902 L
.44405 .30902 L
.44477 .30902 L
Mistroke
.44546 .30902 L
.4461 .30902 L
.4473 .30902 L
.44858 .30902 L
.44923 .30902 L
.44994 .30902 L
.45122 .30902 L
.45201 .30902 L
.45275 .30902 L
.45341 .30902 L
.45414 .30902 L
.45544 .30902 L
.45666 .30902 L
.45734 .30902 L
.45807 .30902 L
.45934 .30902 L
.46057 .30902 L
.46186 .30902 L
.46296 .30902 L
.46418 .30902 L
.46548 .30902 L
.46668 .30902 L
.46731 .30902 L
.46801 .30902 L
.46873 .30902 L
.46941 .30902 L
.47058 .30902 L
.4718 .30902 L
.47244 .30902 L
.47314 .30902 L
.47438 .30902 L
.4756 .30902 L
.4767 .30902 L
.47798 .30902 L
.47919 .30902 L
.48031 .30902 L
.48134 .30902 L
.48248 .30902 L
.48368 .30902 L
.48497 .30902 L
.48616 .30902 L
.48681 .30902 L
.48752 .30902 L
.48882 .30902 L
.49003 .30902 L
.49132 .30902 L
.49252 .30902 L
.49363 .30902 L
.49433 .30902 L
.49506 .30902 L
Mistroke
.49579 .30902 L
.49659 .30902 L
.49729 .30902 L
.49804 .30902 L
.49874 .30902 L
.49938 .30902 L
.50066 .30902 L
.50134 .30902 L
.50206 .30902 L
.50337 .30902 L
.50459 .30902 L
.50583 .30902 L
.50698 .30902 L
.50818 .30902 L
.50949 .30902 L
.51063 .30902 L
.51166 .30902 L
.51285 .30902 L
.51398 .30902 L
.51521 .30902 L
.5165 .30902 L
.51761 .30902 L
.51883 .30902 L
.52409 .30902 L
.52643 .30902 L
.52865 .30902 L
.52987 .30902 L
.53057 .30902 L
.53121 .30902 L
.53234 .30902 L
.53354 .30902 L
.53458 .30902 L
.53571 .30902 L
.53677 .30902 L
.53774 .30902 L
.53882 .30902 L
.54 .30902 L
.54123 .30902 L
.54238 .30902 L
.54365 .30902 L
.54435 .30902 L
.545 .30902 L
.54615 .30902 L
.54741 .30902 L
.54812 .30902 L
.54879 .30902 L
.55005 .30902 L
.55075 .30902 L
.5514 .30902 L
.55212 .30902 L
Mistroke
.55288 .30902 L
.55417 .30902 L
.55489 .30902 L
.55556 .30902 L
.55676 .30902 L
.55808 .30902 L
.55927 .30902 L
.56038 .30902 L
.56155 .30902 L
.5628 .30902 L
.56396 .30902 L
.56519 .30902 L
.56583 .30902 L
.56654 .30902 L
.56779 .30902 L
.56897 .30902 L
.57023 .30902 L
.57143 .30902 L
.57252 .30902 L
.57359 .30902 L
.57458 .30902 L
.57567 .30902 L
.57684 .30902 L
.57806 .30902 L
.57922 .30902 L
.58025 .30902 L
.58138 .30902 L
.58261 .30902 L
.58374 .30902 L
.58504 .30902 L
.58627 .30902 L
.58741 .30902 L
.58846 .30902 L
.58962 .30902 L
.59085 .30902 L
.59151 .30902 L
.5922 .30902 L
.59296 .30902 L
.59366 .30902 L
.59493 .30902 L
.59565 .30902 L
.59631 .30902 L
.59756 .30902 L
.5987 .30902 L
.60002 .30902 L
.60126 .30902 L
.60247 .30902 L
.60316 .30902 L
.60381 .30902 L
.60511 .30902 L
Mistroke
.60577 .30902 L
.6065 .30902 L
.6078 .30902 L
.60903 .30902 L
.61023 .30902 L
.61135 .30902 L
.61204 .30902 L
.61279 .30902 L
.6141 .30902 L
.61484 .30902 L
.61562 .30902 L
.61629 .30902 L
.61703 .30902 L
.61835 .30902 L
.61908 .30902 L
.61976 .30902 L
.62107 .30902 L
.62231 .30902 L
.62344 .30902 L
.62467 .30902 L
.62583 .30902 L
.62689 .30902 L
.62806 .30902 L
.62935 .30902 L
.63 .30902 L
.6307 .30902 L
.63195 .30902 L
.63259 .30902 L
.63327 .30902 L
.63402 .30902 L
.63471 .30902 L
.63595 .30902 L
.63666 .30902 L
.63732 .30902 L
.63854 .30902 L
.63967 .30902 L
.64096 .30902 L
.6422 .30902 L
.64336 .30902 L
.64441 .30902 L
.64562 .30902 L
.64677 .30902 L
.64783 .30902 L
.6488 .30902 L
.64987 .30902 L
.651 .30902 L
.65214 .30902 L
.65322 .30902 L
.65446 .30902 L
.65559 .30902 L
Mistroke
.65683 .30902 L
.65753 .30902 L
.65819 .30902 L
.65936 .30902 L
.66061 .30902 L
.66175 .30902 L
.663 .30902 L
.6643 .30902 L
.66551 .30902 L
.66665 .30902 L
.66768 .30902 L
.66887 .30902 L
.66999 .30902 L
.67122 .30902 L
.67252 .30902 L
.67363 .30902 L
.67485 .30902 L
.67616 .30902 L
.67689 .30902 L
.67756 .30902 L
.67887 .30902 L
.6801 .30902 L
.68126 .30902 L
.6823 .30902 L
.68351 .30902 L
.68465 .30902 L
.6857 .30902 L
.68667 .30902 L
.68773 .30902 L
.68886 .30902 L
.68999 .30902 L
.69121 .30902 L
.69236 .30902 L
.6934 .30902 L
.69463 .30902 L
.69533 .30902 L
.69597 .30902 L
.69714 .30902 L
.69839 .30902 L
.69959 .30902 L
.70091 .30902 L
.70215 .30902 L
.7033 .30902 L
.70442 .30902 L
.70548 .30902 L
.70669 .30902 L
.7078 .30902 L
.70903 .30902 L
.71033 .30902 L
.71144 .30902 L
Mistroke
.71266 .30902 L
.71397 .30902 L
.71471 .30902 L
.71538 .30902 L
.71668 .30902 L
.71792 .30902 L
.71897 .30902 L
.72013 .30902 L
.72134 .30902 L
.72247 .30902 L
.72353 .30902 L
.7245 .30902 L
.72556 .30902 L
.72668 .30902 L
.72783 .30902 L
.72904 .30902 L
.73019 .30902 L
.73124 .30902 L
.73247 .30902 L
.73316 .30902 L
.7338 .30902 L
.73498 .30902 L
.73622 .30902 L
.73743 .30902 L
.73875 .30902 L
.73999 .30902 L
.74115 .30902 L
.74229 .30902 L
.74333 .30902 L
.74453 .30902 L
.74565 .30902 L
.74689 .30902 L
.74819 .30902 L
.75053 .30902 L
.75174 .30902 L
.75304 .30902 L
.75378 .30902 L
.75446 .30902 L
.75514 .30902 L
.75579 .30902 L
.75684 .30902 L
.758 .30902 L
.75922 .30902 L
.76035 .30902 L
.76141 .30902 L
.76238 .30902 L
.76345 .30902 L
.76457 .30902 L
.76571 .30902 L
.76693 .30902 L
Mistroke
.76808 .30902 L
.76912 .30902 L
.77035 .30902 L
.77105 .30902 L
.77169 .30902 L
.77286 .30902 L
.7741 .30902 L
.77532 .30902 L
.776 .30902 L
.77664 .30902 L
.77781 .30902 L
.77905 .30902 L
.78015 .30902 L
.78119 .30902 L
.78233 .30902 L
.78356 .30902 L
.78479 .30902 L
.78549 .30902 L
.78614 .30902 L
.78745 .30902 L
.78885 .30902 L
.79371 .30902 L
.81204 .30902 L
.8535 .30902 L
.89344 .30902 L
.93187 .30902 L
.97275 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0002<ol000<0
I_lco`0co`000S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool04ooo
o`004Oooo`030000<ol0<ol002lco`000`0003?o03?o000F<ol000<0I_lco`0co`005S?o00030000
<ol0<ol002hco`000`0003?o03?o000_<ol000<0003oooooool0;oooo`030000oooooooo01?oool0
017ooom;<ol000<0I_lco`0co`00NC?o00030000oooooooo04Goool0017ooom;<ol000<0I_lco`0c
o`00NC?o00030000oooooooo04Goool0017ooom;<ol000<0I_lco`0co`00NC?o00030000oooooooo
04Goool0017ooom;<ol000<0I_lco`0co`00NC?o00030000oooooooo04Goool0017ooom;<ol000<0
I_lco`0co`00NC?o00030000oooooooo04Goool0017oool306KoB3?o000306Ko<ol0<ol007Tco`02
0000A_ooo`004Oooo`<co`0606Ko@S?o000306Ko<ol0<ol007Tco`000`000?ooooooo`15oooo000A
oooo2C?o00L0I_lk<ol000<0I_lco`0co`00NC?o00030000oooooooo04Goool0017oool@<ol0201V
oc<co`000`1Voc?o03?o001i<ol000<0003oooooool0AOooo`004OoooaPco`0606Ko;C?o000306Ko
<ol0<ol007Tco`000`000?ooooooo`15oooo000Aoooo7S?o00D0I_lX<ol000<0I_lco`0co`00NC?o
00030000oooooooo04Goool0017ooolS<ol01@1Vob<co`000`1Voc?o03?o001i<ol000<0003ooooo
ool0AOooo`004OooobPco`0506Ko7S?o000306Ko<ol0<ol007Tco`000`000?ooooooo`15oooo000A
oooo0P0002/co`0506Ko6C?o000306Ko<ol0<ol007Tco`020000A_ooo`004oooo`80000^<ol0101V
oaDco`000`1Voc?o03?o001i<ol000<0003oooooool0AOooo`005Oooo`80000`<ol00`1Voa8co`00
0`1Voc?o03?o001i<ol000<0003oooooool0AOooo`005oooo`80000a<ol0101Vo`hco`000`1Voc?o
03?o001i<ol000<0003oooooool0AOooo`006Oooo`80000c<ol00`1Vo`/co`000`1Voc?o03?o001i
<ol000<0003oooooool0AOooo`006oooo`80000d<ol00`1Vo`Pco`000`1Voc?o03?o001i<ol000<0
003oooooool0AOooo`007Oooo`80000e<ol0101Vo`@co`000`1Voc?o03?o001i<ol000<0003ooooo
ool0AOooo`007oooo`030000<ol0<ol003Hco`0306Ko00<co`00I_lco`00NS?o00030000oooooooo
04Goool0023oool00`0003?o03?o000h<ol00P1Vog/co`020000A_ooo`008Oooo`80000i<ol000?o
09Tco`0co`00NC?o00030000oooooooo04Goool002?oool00`0003?o03?o000f<ol000?o09Tco`0c
o`00NC?o00030000oooooooo04Goool002Coool20000=S?o0003o`2I<ol0<ol007Tco`000`000?oo
ooooo`15oooo000Voooo00<0000co`0co`00<c?o0003o`2I<ol0<ol007Tco`000`000?ooooooo`15
oooo000Woooo00<0000co`0co`00<S?o0003o`2I<ol0<ol007Tco`000`000?ooooooo`15oooo000X
oooo00<0000co`0co`00<C?o0003o`2I<ol0<ol0060co`02000013?o00800004<ol00P0000<co`04
000013?o00030000oooooooo04Goool002Woool00`0003?o03?o000`<ol000?o09Tco`0co`00Gc?o
00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00030000<ol0<ol000Dco`000`000?oo
ooooo`15oooo000Zoooo00<0000co`0co`00;c?o0003o`2I<ol0<ol005lco`00100003?o03?o0000
00Pco`00100003?o03?o000000<co`000`0003?o03?o0004<ol00`0004Goool002_oool20000;c?o
0003o`2I<ol0<ol005lco`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`0003?o
03?o0003<ol000<0003oooooool0AOooo`00;Oooo`030000<ol0<ol002`co`000ol0VC?o03?o001O
<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000004<ol000<0
003oooooool0AOooo`00;_ooo`030000<ol0<ol002/co`000ol0VC?o03?o001P<ol00P0000Xco`02
000013?o00800005<ol000<0003oooooool0AOooo`00;oooo`030000<ol0<ol002Xco`000ol0VC?o
03?o001i<ol000<0003oooooool0AOooo`00<?ooo`030000<ol0<ol002Tco`000ol0VC?o03?o001i
<ol000<0003oooooool0AOooo`00<Oooo`030000<ol0<ol002Pco`000ol0VC?o03?o001i<ol000<0
003oooooool0AOooo`00<_ooo`030000<ol0<ol002Lco`000ol0VC?o03?o001i<ol000<0003ooooo
ool0AOooo`00<oooo`030000<ol0<ol002Hco`000ol0VC?o03?o001i<ol00P0004Koool003?oool0
0`0003?o03?o000V<ol000?o09Tco`0co`00NC?o00030000oooooooo04Goool003Coool00`0003?o
03?o000U<ol000?o09Tco`0co`00NC?o00030000oooooooo04Goool003Goool00`0003?o03?o000T
<ol000?o09Tco`0co`00NC?o00030000oooooooo04Goool003Koool00`0003?o03?o000S<ol000?o
09Tco`0co`00NC?o00030000oooooooo04Goool003Ooool00`0003?o03?o000R<ol000?o09Tco`0c
o`00NC?o00030000oooooooo04Goool003Soool00`0003?o03?o000Q<ol000?o09Tco`0co`00NC?o
00030000oooooooo04Goool003Soool00`0003?o03?o000Q<ol000?o09Tco`0co`00NC?o00030000
oooooooo04Goool003Woool00`0003?o03?o000P<ol000?o09Tco`0co`00NC?o00800016oooo000j
oooo00<0000co`0co`007c?o0003o`2I<ol0<ol007Tco`000`000?ooooooo`15oooo000koooo00<0
000co`0co`007S?o0003o`2I<ol0<ol007Tco`000`000?ooooooo`15oooo000loooo00<0000co`0c
o`007C?o0003o`2I<ol0<ol007Tco`000`000?ooooooo`15oooo000loooo00<0000co`0co`007C?o
0003o`2I<ol0<ol007Tco`000`000?ooooooo`15oooo000moooo00<0000co`0co`0073?o0003o`2I
<ol0<ol007Tco`000`000?ooooooo`15oooo000moooo00<0000co`0co`0073?o0003o`2I<ol0<ol0
07Tco`000`000?ooooooo`15oooo000noooo00<0000co`0co`006c?o0003o`2I<ol0<ol007Tco`00
0`000?ooooooo`15oooo000noooo00<0000co`0co`006c?o0003o`2I<ol0<ol007Tco`000`000?oo
ooooo`15oooo000ooooo00<0000co`0co`006S?o0003o`2I<ol0<ol007Tco`020000A_ooo`00?ooo
o`030000<ol0<ol001Xco`000ol0VC?o03?o001i<ol000<0003oooooool0AOooo`00@?ooo`030000
<ol0<ol001Tco`000ol0VC?o03?o001i<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol0
01Pco`000ol0VC?o03?o001i<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol001Pco`00
0ol0VC?o03?o001i<ol000<0003oooooool0AOooo`00@_ooo`030000<ol0<ol001Lco`000ol0VC?o
03?o001i<ol000<0003oooooool0AOooo`00@_ooo`030000<ol0<ol001Lco`000ol0VC?o03?o001P
<ol00P0000@co`02000013?o00800005<ol00`0000<co`000`000?ooooooo`15oooo0013oooo00<0
000co`0co`005S?o0003o`2I<ol0<ol005lco`00100003?o03?o000000Pco`00100003?o03?o0000
00Dco`000`0003?o03?o0002<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol001Hco`00
0ol0VC?o03?o001O<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol01@0000<co`03
0000AOooo`00A?ooo`030000<ol0<ol001Dco`000ol0VC?o03?o001O<ol000@0000co`0co`000008
<ol000@0000co`0co`000002<ol000@0000co`0co`000004<ol000<0003oooooool0AOooo`00A?oo
o`030000<ol0<ol001Dco`000ol0VC?o03?o001O<ol000@0000co`0co`000008<ol000@0000co`0c
o`000003<ol000<0000co`00000013?o00030000oooooooo04Goool004Goool00`0003?o03?o000D
<ol000?o09Tco`0co`00H3?o0080000:<ol00P0000Dco`02000013?o00030000oooooooo04Goool0
04Goool00`0003?o03?o000D<ol000?o09Tco`0co`00NC?o00030000oooooooo04Goool004Koool0
0`0003?o03?o000C<ol000?o09Tco`0co`00NC?o00030000oooooooo04Goool004Koool00`0003?o
03?o000C<ol000?o09Tco`0co`00NC?o00030000oooooooo04Goool004Ooool00`0003?o03?o000B
<ol000?o09Tco`0co`00NC?o00030000oooooooo04Goool004Ooool00`0003?o03?o000B<ol000?o
09Tco`0co`00NC?o00800016oooo0018oooo00<0000co`0co`004C?o0003o`2I<ol0<ol007Tco`00
0`000?ooooooo`15oooo0018oooo00<0000co`0co`004C?o0003o`2I<ol0<ol007Tco`000`000?oo
ooooo`15oooo0019oooo00<0000co`0co`0043?o0003o`2I<ol0<ol007Tco`000`000?ooooooo`15
oooo0019oooo00<0000co`0co`0043?o0003o`2I<ol0<ol007Tco`000`000?ooooooo`15oooo001:
oooo00<0000co`0co`003c?o0003o`2I<ol0<ol007Tco`000`000?ooooooo`15oooo001:oooo00<0
000co`0co`003c?o0003o`2I<ol0<ol007Tco`000`000?ooooooo`15oooo001;oooo00<0000co`0c
o`003S?o0003o`2I<ol0<ol007Tco`000`000?ooooooo`15oooo001;oooo00<0000co`0co`003S?o
0003o`2I<ol0<ol007Tco`020000A_ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004cooon<
<ol0B?ooo`00COoooh/co`18oooo001=ooooRc?o04Soool004kooolV<ol000<0000co`0co`00;c?o
00030000<ol0<ol002lco`18oooo001>oooo9C?o00030000<ol0<ol000Pco`000`0003?o03?o000V
<ol000<0000co`0co`00;S?o04Soool004oooolT<ol000<0000co`0co`000S?o00800004<ol000<0
000co`0co`003S?o00800004<ol00P0000<co`0400000c?o00800004<ol000<0000co`0co`00;S?o
04Soool004oooolT<ol000D0000co`0co`0co`0000000S?o00030000<ol0<ol0008co`000`0003?o
03?o0005<ol0100000<co`00100003?o03?o000000Pco`000`0003?o03?o0003<ol000@0000co`0c
o`000003<ol000<0000co`0co`00;S?o04Soool004oooolS<ol000<0000co`0co`000S?o00030000
<ol0<ol001@co`00100003?o03?o000000Tco`000`0003?o03?o0005<ol000<0000co`0co`000S?o
00030000<ol0<ol002dco`18oooo001@oooo8c?o00030000<ol0<ol000D0000C<ol000@0000co`0c
o`00000:<ol000<0000co`0co`000S?o00800004<ol000<0000co`0co`00;S?o04Soool0053ooolS
<ol000D0000co`0co`0co`0000005S?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o
00030000<ol0<ol000<co`000`0003?o03?o000^<ol0B?ooo`00D?ooob@co`000`0003?o03?o000H
<ol00P0000Xco`02000013?o00<00002<ol000<0000co`0co`00;c?o04Soool0057ooon7<ol0B?oo
o`00DOooohLco`18oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.30316 .30902 L
.30791 .30902 L
.31054 .30902 L
.31183 .30902 L
.31304 .30902 L
s
.31304 .30902 m
.31304 .61803 L
s
0 .4 1 r
.02381 .33916 m
.06244 .34382 L
.10458 .34972 L
.14415 .35618 L
.18221 .36336 L
.22272 .37222 L
.26171 .38213 L
.28158 .38778 L
.29205 .39092 L
.30316 .3944 L
.30791 .39594 L
.31054 .3968 L
.31183 .39723 L
.31304 .39763 L
.31371 .30902 L
.31444 .30902 L
.31524 .30902 L
.31597 .30902 L
.31663 .30902 L
.31735 .30902 L
.31865 .30902 L
.31929 .30902 L
.31999 .30902 L
.32071 .30902 L
.32139 .30902 L
.32261 .30902 L
.32392 .30902 L
.3252 .30902 L
.32638 .30902 L
.32768 .30902 L
.32835 .30902 L
.32907 .30902 L
.33026 .30902 L
.33138 .30902 L
.33203 .30902 L
.33272 .30902 L
.33394 .30902 L
.33504 .30902 L
.33621 .30902 L
.33731 .30902 L
.33831 .30902 L
.33949 .30902 L
.34077 .30902 L
.34197 .30902 L
.34309 .30902 L
.34434 .30902 L
.34553 .30902 L
.34659 .30902 L
.34776 .30902 L
.34902 .30902 L
Mistroke
.34971 .30902 L
.35036 .30902 L
.35163 .30902 L
.35278 .30902 L
.35388 .30902 L
.35505 .30902 L
.35605 .30902 L
.35714 .30902 L
.35832 .30902 L
.35958 .30902 L
.36077 .30902 L
.36185 .30902 L
.36313 .30902 L
.36378 .30902 L
.36449 .30902 L
.36575 .30902 L
.36693 .30902 L
.36761 .30902 L
.36832 .30902 L
.36959 .30902 L
.37025 .30902 L
.37096 .30902 L
.37173 .30902 L
.37245 .30902 L
.37375 .30902 L
.37449 .30902 L
.37516 .30902 L
.3764 .30902 L
.37771 .30902 L
.37881 .30902 L
.37999 .30902 L
.38128 .30902 L
.38249 .30902 L
.3837 .30902 L
.38439 .30902 L
.38504 .30902 L
.38635 .30902 L
.38709 .30902 L
.38776 .30902 L
.3889 .30902 L
.39014 .30902 L
.39144 .30902 L
.39265 .30902 L
.39334 .30902 L
.39408 .30902 L
.39479 .30902 L
.39544 .30902 L
.39668 .30902 L
.39799 .30902 L
.39867 .30902 L
Mistroke
.39939 .30902 L
.40071 .30902 L
.40151 .30902 L
.40227 .30902 L
.40296 .30902 L
.4037 .30902 L
.40436 .30902 L
.40507 .30902 L
.40635 .30902 L
.4076 .30902 L
.40875 .30902 L
.40999 .30902 L
.41069 .30902 L
.41132 .30902 L
.41207 .30902 L
.41278 .30902 L
.41343 .30902 L
.41414 .30902 L
.41532 .30902 L
.41658 .30902 L
.41766 .30902 L
.41884 .30902 L
.42008 .30902 L
.42077 .30902 L
.42141 .30902 L
.42258 .30902 L
.42382 .30902 L
.42505 .30902 L
.42575 .30902 L
.42639 .30902 L
.42755 .30902 L
.42882 .30902 L
.42997 .30902 L
.43103 .30902 L
.43216 .30902 L
.43337 .30902 L
.43468 .30902 L
.43542 .30902 L
.43611 .30902 L
.43737 .30902 L
.43807 .30902 L
.4387 .30902 L
.43991 .30902 L
.44121 .30902 L
.44244 .30902 L
.44357 .30902 L
.44464 .30902 L
.44578 .30902 L
.44686 .30902 L
.44784 .30902 L
Mistroke
.44899 .30902 L
.45024 .30902 L
.45142 .30902 L
.45252 .30902 L
.45364 .30902 L
.45469 .30902 L
.45585 .30902 L
.45709 .30902 L
.45839 .30902 L
.45963 .30902 L
.46073 .30902 L
.46195 .30902 L
.46259 .30902 L
.46327 .30902 L
.4645 .30902 L
.46581 .30902 L
.46656 .30902 L
.46725 .30902 L
.46852 .30902 L
.46967 .30902 L
.4703 .30902 L
.471 .30902 L
.47226 .30902 L
.47338 .30902 L
.47461 .30902 L
.4759 .30902 L
.47711 .30902 L
.47824 .30902 L
.47928 .30902 L
.48041 .30902 L
.48161 .30902 L
.48292 .30902 L
.48412 .30902 L
.48478 .30902 L
.48549 .30902 L
.4868 .30902 L
.48801 .30902 L
.48931 .30902 L
.49162 .30902 L
.49292 .30902 L
.49365 .30902 L
.49432 .30902 L
.49561 .30902 L
.49684 .30902 L
.49753 .30902 L
.49826 .30902 L
.49958 .30902 L
.50039 .30902 L
.50116 .30902 L
.50184 .30902 L
Mistroke
.50258 .30902 L
.50382 .30902 L
.50496 .30902 L
.50627 .30902 L
.50751 .30902 L
.50865 .30902 L
.50971 .30902 L
.51087 .30902 L
.5121 .30902 L
.51334 .30902 L
.51403 .30902 L
.51467 .30902 L
.51584 .30902 L
.51707 .30902 L
.51773 .30902 L
.51843 .30902 L
.51969 .30902 L
.52046 .30902 L
.52119 .30902 L
.52184 .30902 L
.52255 .30902 L
.52386 .30902 L
.52509 .30902 L
.52579 .30902 L
.52643 .30902 L
.52717 .30902 L
.52788 .30902 L
.53352 .30902 L
.54362 .30902 L
.54859 .30902 L
.55102 .30902 L
.55209 .30902 L
.55325 .30902 L
.55439 .30902 L
.55559 .30902 L
.5569 .30902 L
.55812 .30902 L
.55882 .30902 L
.55948 .30902 L
.56072 .30902 L
.56141 .30902 L
.56205 .30902 L
.56275 .30902 L
.5635 .30902 L
.56464 .30902 L
.56568 .30902 L
.56688 .30902 L
.56802 .30902 L
.56907 .30902 L
.57005 .30902 L
Mistroke
.57112 .30902 L
.57226 .30902 L
.57351 .30902 L
.57417 .30902 L
.57486 .30902 L
.57614 .30902 L
.57732 .30902 L
.57845 .30902 L
.57951 .30902 L
.58066 .30902 L
.58191 .30902 L
.58313 .30902 L
.58447 .30902 L
.58578 .30902 L
.58652 .30902 L
.58719 .30902 L
.58842 .30902 L
.58972 .30902 L
.59085 .30902 L
.59208 .30902 L
.59744 .30902 L
.59812 .30902 L
.59885 .30902 L
.59964 .30902 L
.60038 .30902 L
.6017 .30902 L
.60245 .30902 L
.60315 .30902 L
.60386 .30902 L
.60453 .30902 L
.60579 .30902 L
.60649 .30902 L
.60714 .30902 L
.60785 .30902 L
.60862 .30902 L
.60926 .30902 L
.60996 .30902 L
.61122 .30902 L
.61245 .30902 L
.61358 .30902 L
.61474 .30902 L
.61583 .30902 L
.61702 .30902 L
.6183 .30902 L
.61894 .30902 L
.61964 .30902 L
.6209 .30902 L
.62214 .30902 L
.62328 .30902 L
.62452 .30902 L
Mistroke
.6257 .30902 L
.62677 .30902 L
.62793 .30902 L
.62918 .30902 L
.62988 .30902 L
.63052 .30902 L
.63178 .30902 L
.63293 .30902 L
.63402 .30902 L
.63517 .30902 L
.63632 .30902 L
.63759 .30902 L
.63869 .30902 L
.63986 .30902 L
.64097 .30902 L
.64198 .30902 L
.64326 .30902 L
.6439 .30902 L
.64461 .30902 L
.64587 .30902 L
.64705 .30902 L
.64773 .30902 L
.64844 .30902 L
.64971 .30902 L
.65041 .30902 L
.65107 .30902 L
.65179 .30902 L
.65257 .30902 L
.65378 .30902 L
.65508 .30902 L
.65631 .30902 L
.65744 .30902 L
.65862 .30902 L
.6599 .30902 L
.66062 .30902 L
.66128 .30902 L
.6626 .30902 L
.6633 .30902 L
.66395 .30902 L
.66518 .30902 L
.6665 .30902 L
.66724 .30902 L
.66792 .30902 L
.66906 .30902 L
.67031 .30902 L
.67161 .30902 L
.67283 .30902 L
.67352 .30902 L
.67427 .30902 L
.67498 .30902 L
Mistroke
.67563 .30902 L
.67687 .30902 L
.67819 .30902 L
.67887 .30902 L
.6796 .30902 L
.68092 .30902 L
.68167 .30902 L
.68248 .30902 L
.68324 .30902 L
.68393 .30902 L
.68519 .30902 L
.68638 .30902 L
.68766 .30902 L
.68838 .30902 L
.68905 .30902 L
.6897 .30902 L
.6904 .30902 L
.69167 .30902 L
.69299 .30902 L
.69375 .30902 L
.69444 .30902 L
.69567 .30902 L
.69681 .30902 L
.69806 .30902 L
.69875 .30902 L
.69938 .30902 L
.70055 .30902 L
.7018 .30902 L
.70299 .30902 L
.70407 .30902 L
.70535 .30902 L
.70655 .30902 L
.70763 .30902 L
.7088 .30902 L
.71007 .30902 L
.71072 .30902 L
.71142 .30902 L
.71268 .30902 L
.71385 .30902 L
.71502 .30902 L
.71614 .30902 L
.71714 .30902 L
.71824 .30902 L
.71942 .30902 L
.72068 .30902 L
.72188 .30902 L
.72296 .30902 L
.72425 .30902 L
.7249 .30902 L
.72562 .30902 L
Mistroke
.72689 .30902 L
.72807 .30902 L
.72879 .30902 L
.72947 .30902 L
.73074 .30902 L
.73141 .30902 L
.73212 .30902 L
.73289 .30902 L
.73361 .30902 L
.73479 .30902 L
.73607 .30902 L
.73727 .30902 L
.73838 .30902 L
.7396 .30902 L
.7403 .30902 L
.74094 .30902 L
.74225 .30902 L
.74298 .30902 L
.74364 .30902 L
.74483 .30902 L
.74595 .30902 L
.74717 .30902 L
.74849 .30902 L
.74915 .30902 L
.74986 .30902 L
.75117 .30902 L
.75244 .30902 L
.75362 .30902 L
.75483 .30902 L
.75596 .30902 L
.75698 .30902 L
.75808 .30902 L
.75926 .30902 L
.76053 .30902 L
.76173 .30902 L
.76282 .30902 L
.76412 .30902 L
.76534 .30902 L
.76666 .30902 L
.76741 .30902 L
.7681 .30902 L
.76938 .30902 L
.77011 .30902 L
.7708 .30902 L
.77152 .30902 L
.77218 .30902 L
.7729 .30902 L
.77366 .30902 L
.77485 .30902 L
.77613 .30902 L
Mistroke
.77733 .30902 L
.77842 .30902 L
.7797 .30902 L
.78043 .30902 L
.7811 .30902 L
.78232 .30902 L
.78362 .30902 L
.78483 .30902 L
.78552 .30902 L
.78616 .30902 L
.78732 .30902 L
.78856 .30902 L
.79308 .30902 L
.80323 .30902 L
.82155 .30902 L
.85927 .30902 L
.89943 .30902 L
.93808 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0003<ol000D0
I_lco`0co`0co`0000002C?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0
000co`0co`00;c?o00030000<ol0<ol001Lco`000`1Voc?o03?o000E<ol000<0000co`0co`00;S?o
00030000<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Ooood`co`00
0`1Voc?o03?o001h<ol000<0003oooooool0AOooo`004Ooood`co`000`1Voc?o03?o001h<ol000<0
003oooooool0AOooo`004Ooood`co`000`1Voc?o03?o001h<ol000<0003oooooool0AOooo`004Ooo
od`co`000`1Voc?o03?o001h<ol000<0003oooooool0AOooo`004Ooood`co`000`1Voc?o03?o001h
<ol000<0003oooooool0AOooo`004Oooo`H0I_m6<ol000<0I_lco`0co`00N3?o00800016oooo000A
oooo1S?o00P0I_ln<ol000<0I_lco`0co`00N3?o00030000oooooooo04Goool0017oool><ol01@1V
ocTco`000`1Voc?o03?o001h<ol000<0003oooooool0AOooo`004Ooooa<co`0806Ko<C?o000306Ko
<ol0<ol007Pco`000`000?ooooooo`15oooo000Aoooo6c?o00P0I_lY<ol000<0I_lco`0co`00N3?o
00030000oooooooo04Goool0017ooolS<ol01@1Vob@co`000`1Voc?o03?o001h<ol000<0003ooooo
ool0AOooo`004OooobPco`0406Ko83?o000306Ko<ol0<ol007Pco`000`000?ooooooo`15oooo000A
oooo;3?o00<0I_lM<ol000<0I_lco`0co`00N3?o00030000oooooooo04Goool0017oool20000;C?o
00@0I_lI<ol000<0I_lco`0co`00N3?o00800016oooo000Coooo0P0002lco`0406Ko5C?o000306Ko
<ol0<ol007Pco`000`000?ooooooo`15oooo000Eoooo0P00034co`0506Ko43?o000306Ko<ol0<ol0
07Pco`000`000?ooooooo`15oooo000Goooo0P0003@co`0406Ko33?o000306Ko<ol0<ol007Pco`00
0`000?ooooooo`15oooo000Ioooo0P0003Hco`0306Ko2C?o000306Ko<ol0<ol007Pco`000`000?oo
ooooo`15oooo000Koooo0P0003Lco`0506Ko13?o000306Ko<ol0<ol007Pco`000`000?ooooooo`15
oooo000Moooo0P0003Xco`0206Ko0S?o000306Ko<ol0<ol007Pco`000`000?ooooooo`15oooo000O
oooo00<0000co`0co`00>C?o00<0I_mj<ol000<0003oooooool0AOooo`008?ooo`030000<ol0<ol0
03Xco`000ol0VC?o03?o001h<ol00P0004Koool0027oool20000>S?o0003o`2I<ol0<ol007Pco`00
0`000?ooooooo`15oooo000Soooo00<0000co`0co`00=c?o0003o`2I<ol0<ol007Pco`000`000?oo
ooooo`15oooo000Toooo0P0003Lco`000ol0VC?o03?o001h<ol000<0003oooooool0AOooo`009_oo
o`030000<ol0<ol003@co`000ol0VC?o03?o001h<ol000<0003oooooool0AOooo`009oooo`030000
<ol0<ol003<co`000ol0VC?o03?o001h<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol0
038co`000ol0VC?o03?o001O<ol00P0000@co`02000013?o00800003<ol0100000@co`000`000?oo
ooooo`15oooo000Yoooo00<0000co`0co`00<C?o0003o`2I<ol0<ol005hco`00100003?o03?o0000
00Pco`00100003?o03?o0000008co`000`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_oo
o`030000<ol0<ol0030co`000ol0VC?o03?o001N<ol000@0000co`0co`000008<ol000@0000co`0c
o`000003<ol000<0000co`0co`0013?o00<00015oooo000[oooo0P00030co`000ol0VC?o03?o001N
<ol000@0000co`0co`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o00030000
oooooooo04Goool002goool00`0003?o03?o000]<ol000?o09Tco`0co`00GS?o00040000<ol0<ol0
000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool0
02koool00`0003?o03?o000/<ol000?o09Tco`0co`00Gc?o0080000:<ol00P0000@co`0200001C?o
00030000oooooooo04Goool002ooool00`0003?o03?o000[<ol000?o09Tco`0co`00N3?o00030000
oooooooo04Goool0033oool00`0003?o03?o000Z<ol000?o09Tco`0co`00N3?o00030000oooooooo
04Goool0037oool00`0003?o03?o000Y<ol000?o09Tco`0co`00N3?o00030000oooooooo04Goool0
03;oool00`0003?o03?o000X<ol000?o09Tco`0co`00N3?o00030000oooooooo04Goool003?oool0
0`0003?o03?o000W<ol000?o09Tco`0co`00N3?o00800016oooo000coooo00<0000co`0co`009c?o
0003o`2I<ol0<ol007Pco`000`000?ooooooo`15oooo000doooo00<0000co`0co`009S?o0003o`2I
<ol0<ol007Pco`000`000?ooooooo`15oooo000eoooo00<0000co`0co`009C?o0003o`2I<ol0<ol0
07Pco`000`000?ooooooo`15oooo000foooo00<0000co`0co`0093?o0003o`2I<ol0<ol007Pco`00
0`000?ooooooo`15oooo000goooo00<0000co`0co`008c?o0003o`2I<ol0<ol007Pco`000`000?oo
ooooo`15oooo000hoooo00<0000co`0co`008S?o0003o`2I<ol0<ol007Pco`000`000?ooooooo`15
oooo000hoooo00<0000co`0co`008S?o0003o`2I<ol0<ol007Pco`000`000?ooooooo`15oooo000i
oooo00<0000co`0co`008C?o0003o`2I<ol0<ol007Pco`020000A_ooo`00>_ooo`030000<ol0<ol0
020co`000ol0VC?o03?o001h<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol001lco`00
0ol0VC?o03?o001h<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol001hco`000ol0VC?o
03?o001h<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol001hco`000ol0VC?o03?o001h
<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol001dco`000ol0VC?o03?o001h<ol000<0
003oooooool0AOooo`00?Oooo`030000<ol0<ol001dco`000ol0VC?o03?o001h<ol000<0003ooooo
ool0AOooo`00?_ooo`030000<ol0<ol001`co`000ol0VC?o03?o001h<ol000<0003oooooool0AOoo
o`00?_ooo`030000<ol0<ol001`co`000ol0VC?o03?o001h<ol000<0003oooooool0AOooo`00?ooo
o`030000<ol0<ol001/co`000ol0VC?o03?o001h<ol00P0004Koool003ooool00`0003?o03?o000K
<ol000?o09Tco`0co`00N3?o00030000oooooooo04Goool0043oool00`0003?o03?o000J<ol000?o
09Tco`0co`00N3?o00030000oooooooo04Goool0047oool00`0003?o03?o000I<ol000?o09Tco`0c
o`00N3?o00030000oooooooo04Goool0047oool00`0003?o03?o000I<ol000?o09Tco`0co`00N3?o
00030000oooooooo04Goool004;oool00`0003?o03?o000H<ol000?o09Tco`0co`00N3?o00030000
oooooooo04Goool004;oool00`0003?o03?o000H<ol000?o09Tco`0co`00Gc?o00800004<ol00P00
00@co`0200001C?o00<00003<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol001Lco`00
0ol0VC?o03?o001N<ol000@0000co`0co`000008<ol000@0000co`0co`000005<ol000<0000co`0c
o`000S?o00030000oooooooo04Goool004?oool00`0003?o03?o000G<ol000?o09Tco`0co`00GS?o
00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool0
0`0003?o03?o000F<ol000?o09Tco`0co`00GS?o00040000<ol0<ol0000023?o00040000<ol0<ol0
00000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool004Coool00`0003?o03?o000F
<ol000?o09Tco`0co`00GS?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000
<ol0000000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`005C?o0003o`2I<ol0<ol0
05lco`0200002S?o00800005<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0c
o`005C?o0003o`2I<ol0<ol007Pco`000`000?ooooooo`15oooo0016oooo00<0000co`0co`0053?o
0003o`2I<ol0<ol007Pco`000`000?ooooooo`15oooo0016oooo00<0000co`0co`0053?o0003o`2I
<ol0<ol007Pco`000`000?ooooooo`15oooo0017oooo00<0000co`0co`004c?o0003o`2I<ol0<ol0
07Pco`000`000?ooooooo`15oooo0017oooo00<0000co`0co`004c?o0003o`2I<ol0<ol007Pco`02
0000A_ooo`00B?ooo`030000<ol0<ol0018co`000ol0VC?o03?o001h<ol000<0003oooooool0AOoo
o`00B?ooo`030000<ol0<ol0018co`000ol0VC?o03?o001h<ol000<0003oooooool0AOooo`00BOoo
o`030000<ol0<ol0014co`000ol0VC?o03?o001h<ol000<0003oooooool0AOooo`00BOooo`030000
<ol0<ol0014co`000ol0VC?o03?o001h<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol0
010co`000ol0VC?o03?o001h<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol0010co`00
0ol0VC?o03?o001h<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol000lco`000ol0VC?o
03?o001h<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol000lco`000ol0VC?o03?o001h
<ol00P0004Koool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;
<ol0B?ooo`00COoooh/co`18oooo001>oooo9S?o00030000<ol0<ol002lco`000`0003?o03?o000_
<ol0B?ooo`00C_ooobDco`000`0003?o03?o0008<ol000<0000co`0co`009S?o00030000<ol0<ol0
02hco`18oooo001?oooo93?o00030000<ol0<ol0008co`02000013?o00030000<ol0<ol000hco`02
000013?o00800003<ol0100000@co`0300000S?o00030000<ol0<ol002hco`18oooo001?oooo93?o
00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0000co`0co`001C?o00@00003
<ol000@0000co`0co`000008<ol000<0000co`0co`001S?o00050000<ol0<ol0<ol00000030co`18
oooo001?oooo8c?o00030000<ol0<ol0008co`000`0003?o03?o000D<ol000@0000co`0co`000009
<ol000<0000co`0co`000S?o00D00003<ol000<0000co`0co`00;C?o04Soool0053ooolS<ol000<0
000co`0co`001@0001<co`00100003?o03?o000000Xco`001@0003?o03?o03?o00000002<ol000D0
000co`0co`0co`000000<3?o04Soool0053ooolS<ol000D0000co`0co`0co`0000005S?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0000000<co`000`0003?o03?o000^
<ol0B?ooo`00D?ooob@co`000`0003?o03?o000H<ol00P0000Xco`0200001C?o00800002<ol000<0
000co`0co`00;c?o04Soool0057ooon7<ol0B?ooo`00DOooohLco`18oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.23) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.30316 .30902 L
.30791 .30902 L
.31304 .30902 L
.31454 .30902 L
.31528 .30902 L
.31597 .30902 L
s
.31597 .30902 m
.31598 .61803 L
s
0 .4 1 r
.02381 .33786 m
.06244 .34231 L
.10458 .34796 L
.14415 .35414 L
.18221 .36102 L
.22272 .3695 L
.26171 .37898 L
.28158 .38438 L
.29205 .38739 L
.30316 .39072 L
.30791 .39219 L
.31304 .3938 L
.31454 .39428 L
.31528 .39452 L
.31597 .39474 L
.31725 .30902 L
.31793 .30902 L
.31865 .30902 L
.31934 .30902 L
.32008 .30902 L
.32077 .30902 L
.32141 .30902 L
.32263 .30902 L
.32392 .30902 L
.32511 .30902 L
.3262 .30902 L
.32745 .30902 L
.32864 .30902 L
.32974 .30902 L
.33076 .30902 L
.33187 .30902 L
.33305 .30902 L
.33424 .30902 L
.33551 .30902 L
.33672 .30902 L
.33782 .30902 L
.33905 .30902 L
.33974 .30902 L
.34039 .30902 L
.34169 .30902 L
.34241 .30902 L
.34309 .30902 L
.34432 .30902 L
.34497 .30902 L
.34567 .30902 L
.34641 .30902 L
.34711 .30902 L
.34841 .30902 L
.34964 .30902 L
.35079 .30902 L
Mistroke
.35143 .30902 L
.35212 .30902 L
.35333 .30902 L
.35403 .30902 L
.35476 .30902 L
.35608 .30902 L
.3573 .30902 L
.358 .30902 L
.35864 .30902 L
.35939 .30902 L
.3601 .30902 L
.36074 .30902 L
.36144 .30902 L
.36219 .30902 L
.36299 .30902 L
.36368 .30902 L
.36443 .30902 L
.36571 .30902 L
.36635 .30902 L
.36705 .30902 L
.36829 .30902 L
.36944 .30902 L
.37014 .30902 L
.37081 .30902 L
.37205 .30902 L
.37274 .30902 L
.37338 .30902 L
.37409 .30902 L
.37483 .30902 L
.37599 .30902 L
.37723 .30902 L
.37841 .30902 L
.37948 .30902 L
.38073 .30902 L
.38144 .30902 L
.3821 .30902 L
.3833 .30902 L
.38458 .30902 L
.38572 .30902 L
.38696 .30902 L
.38825 .30902 L
.38946 .30902 L
.39059 .30902 L
.39162 .30902 L
.39281 .30902 L
.39394 .30902 L
.39516 .30902 L
.39645 .30902 L
.39756 .30902 L
.39878 .30902 L
Mistroke
.40008 .30902 L
.40082 .30902 L
.40149 .30902 L
.40279 .30902 L
.40403 .30902 L
.40516 .30902 L
.40622 .30902 L
.40745 .30902 L
.40856 .30902 L
.40961 .30902 L
.41058 .30902 L
.41165 .30902 L
.41277 .30902 L
.4139 .30902 L
.41512 .30902 L
.41627 .30902 L
.41731 .30902 L
.41854 .30902 L
.41923 .30902 L
.41988 .30902 L
.42105 .30902 L
.4223 .30902 L
.42344 .30902 L
.42469 .30902 L
.42599 .30902 L
.4272 .30902 L
.42833 .30902 L
.42936 .30902 L
.43056 .30902 L
.43168 .30902 L
.43291 .30902 L
.43421 .30902 L
.43531 .30902 L
.43653 .30902 L
.43784 .30902 L
.43858 .30902 L
.43925 .30902 L
.44055 .30902 L
.44179 .30902 L
.44294 .30902 L
.44399 .30902 L
.44519 .30902 L
.44633 .30902 L
.44738 .30902 L
.44835 .30902 L
.44942 .30902 L
.45054 .30902 L
.45168 .30902 L
.45289 .30902 L
.45404 .30902 L
Mistroke
.45509 .30902 L
.45632 .30902 L
.45701 .30902 L
.45765 .30902 L
.45882 .30902 L
.46007 .30902 L
.46128 .30902 L
.46259 .30902 L
.46383 .30902 L
.46498 .30902 L
.46612 .30902 L
.46716 .30902 L
.46835 .30902 L
.46948 .30902 L
.47071 .30902 L
.47201 .30902 L
.47312 .30902 L
.47434 .30902 L
.47565 .30902 L
.47639 .30902 L
.47706 .30902 L
.47836 .30902 L
.4796 .30902 L
.48065 .30902 L
.4818 .30902 L
.48301 .30902 L
.48415 .30902 L
.4852 .30902 L
.48617 .30902 L
.48724 .30902 L
.48836 .30902 L
.4895 .30902 L
.49072 .30902 L
.49187 .30902 L
.49291 .30902 L
.49414 .30902 L
.49484 .30902 L
.49547 .30902 L
.49665 .30902 L
.49789 .30902 L
.4991 .30902 L
.50042 .30902 L
.50167 .30902 L
.50282 .30902 L
.50397 .30902 L
.505 .30902 L
.5062 .30902 L
.50732 .30902 L
.50856 .30902 L
.50986 .30902 L
Mistroke
.51098 .30902 L
.5122 .30902 L
.51351 .30902 L
.51425 .30902 L
.51492 .30902 L
.51622 .30902 L
.51746 .30902 L
.51851 .30902 L
.51967 .30902 L
.52088 .30902 L
.52202 .30902 L
.52308 .30902 L
.52405 .30902 L
.52511 .30902 L
.52623 .30902 L
.52738 .30902 L
.5286 .30902 L
.52975 .30902 L
.53079 .30902 L
.53193 .30902 L
.53316 .30902 L
.53387 .30902 L
.53451 .30902 L
.53577 .30902 L
.53696 .30902 L
.53826 .30902 L
.53949 .30902 L
.54063 .30902 L
.54181 .30902 L
.54312 .30902 L
.54378 .30902 L
.54449 .30902 L
.54577 .30902 L
.54689 .30902 L
.54811 .30902 L
.55057 .30902 L
.55284 .30902 L
.55498 .30902 L
.55629 .30902 L
.55703 .30902 L
.55771 .30902 L
.55891 .30902 L
.56019 .30902 L
.56085 .30902 L
.56156 .30902 L
.56284 .30902 L
.56362 .30902 L
.56436 .30902 L
.56503 .30902 L
.56576 .30902 L
Mistroke
.56708 .30902 L
.56828 .30902 L
.56894 .30902 L
.56966 .30902 L
.57096 .30902 L
.57218 .30902 L
.57348 .30902 L
.57458 .30902 L
.57579 .30902 L
.5771 .30902 L
.5783 .30902 L
.57893 .30902 L
.57963 .30902 L
.58035 .30902 L
.58103 .30902 L
.58228 .30902 L
.58342 .30902 L
.58468 .30902 L
.586 .30902 L
.58711 .30902 L
.5883 .30902 L
.58943 .30902 L
.59045 .30902 L
.59165 .30902 L
.59295 .30902 L
.59417 .30902 L
.59531 .30902 L
.59651 .30902 L
.59781 .30902 L
.59903 .30902 L
.60015 .30902 L
.60145 .30902 L
.60219 .30902 L
.60288 .30902 L
.60413 .30902 L
.60483 .30902 L
.60547 .30902 L
.60614 .30902 L
.60686 .30902 L
.60813 .30902 L
.6088 .30902 L
.60951 .30902 L
.61028 .30902 L
.61101 .30902 L
.61168 .30902 L
.61241 .30902 L
.6131 .30902 L
.61374 .30902 L
.61494 .30902 L
.61622 .30902 L
Mistroke
.61743 .30902 L
.61874 .30902 L
.61998 .30902 L
.62113 .30902 L
.62227 .30902 L
.6233 .30902 L
.6245 .30902 L
.62562 .30902 L
.62685 .30902 L
.62815 .30902 L
.62926 .30902 L
.63048 .30902 L
.63179 .30902 L
.63253 .30902 L
.6332 .30902 L
.6345 .30902 L
.63574 .30902 L
.63679 .30902 L
.63794 .30902 L
.63915 .30902 L
.64029 .30902 L
.64134 .30902 L
.64231 .30902 L
.64338 .30902 L
.6445 .30902 L
.64564 .30902 L
.64686 .30902 L
.64801 .30902 L
.64905 .30902 L
.65028 .30902 L
.65097 .30902 L
.65161 .30902 L
.65279 .30902 L
.65403 .30902 L
.65524 .30902 L
.65656 .30902 L
.6578 .30902 L
.65896 .30902 L
.6601 .30902 L
.66114 .30902 L
.66233 .30902 L
.66346 .30902 L
.66583 .30902 L
.66712 .30902 L
.66833 .30902 L
.66963 .30902 L
.67033 .30902 L
.67107 .30902 L
.67239 .30902 L
.67359 .30902 L
Mistroke
.67472 .30902 L
.67593 .30902 L
.67696 .30902 L
.6781 .30902 L
.67931 .30902 L
.68062 .30902 L
.68186 .30902 L
.68299 .30902 L
.68407 .30902 L
.68507 .30902 L
.68616 .30902 L
.68733 .30902 L
.68856 .30902 L
.68972 .30902 L
.69077 .30902 L
.6919 .30902 L
.69311 .30902 L
.69426 .30902 L
.69489 .30902 L
.69558 .30902 L
.69679 .30902 L
.69795 .30902 L
.69917 .30902 L
.70033 .30902 L
.70137 .30902 L
.70263 .30902 L
.70326 .30902 L
.70396 .30902 L
.70471 .30902 L
.70541 .30902 L
.70605 .30902 L
.70674 .30902 L
.7074 .30902 L
.7081 .30902 L
.70939 .30902 L
.71064 .30902 L
.71179 .30902 L
.713 .30902 L
.7143 .30902 L
.71553 .30902 L
.71665 .30902 L
.71797 .30902 L
.71866 .30902 L
.7194 .30902 L
.72011 .30902 L
.72075 .30902 L
.72201 .30902 L
.72269 .30902 L
.72341 .30902 L
.72469 .30902 L
Mistroke
.7254 .30902 L
.72607 .30902 L
.7268 .30902 L
.72759 .30902 L
.72826 .30902 L
.729 .30902 L
.72969 .30902 L
.73034 .30902 L
.73155 .30902 L
.73284 .30902 L
.73398 .30902 L
.73522 .30902 L
.73652 .30902 L
.73773 .30902 L
.73886 .30902 L
.7399 .30902 L
.74109 .30902 L
.74221 .30902 L
.74343 .30902 L
.74473 .30902 L
.74584 .30902 L
.74706 .30902 L
.74836 .30902 L
.7491 .30902 L
.74977 .30902 L
.75107 .30902 L
.75231 .30902 L
.75346 .30902 L
.75451 .30902 L
.75571 .30902 L
.75685 .30902 L
.7579 .30902 L
.75887 .30902 L
.75992 .30902 L
.76105 .30902 L
.7622 .30902 L
.76327 .30902 L
.76454 .30902 L
.76569 .30902 L
.7669 .30902 L
.76821 .30902 L
.76945 .30902 L
.77059 .30902 L
.77177 .30902 L
.77301 .30902 L
.77408 .30902 L
.77524 .30902 L
.77649 .30902 L
.77719 .30902 L
.77783 .30902 L
Mistroke
.77907 .30902 L
.78024 .30902 L
.78134 .30902 L
.7825 .30902 L
.78349 .30902 L
.78458 .30902 L
.78576 .30902 L
.78701 .30902 L
.78929 .30902 L
.8099 .30902 L
.85123 .30902 L
.89103 .30902 L
.92933 .30902 L
.97007 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.23) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0004<ol000@0
I_lco`0co`000009<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo01?oool0017oool00`0003?o
03?o000_<ol000<0000co`0co`0063?o000306Ko<ol0<ol001@co`000`0003?o03?o000^<ol000<0
000co`0co`00;c?o00030000oooooooo02ooool00`000?ooooooo`0Coooo000AooooCC?o000306Ko
<ol0<ol007Lco`000`000?ooooooo`15oooo000AooooCC?o000306Ko<ol0<ol007Lco`000`000?oo
ooooo`15oooo000AooooCC?o000306Ko<ol0<ol007Lco`000`000?ooooooo`15oooo000AooooCC?o
000306Ko<ol0<ol007Lco`000`000?ooooooo`15oooo000AooooCC?o000306Ko<ol0<ol007Lco`00
0`000?ooooooo`15oooo000Aoooo1P1VodLco`000`1Voc?o03?o001g<ol00P0004Koool0017oool6
<ol02P1Vocdco`000`1Voc?o03?o001g<ol000<0003oooooool0AOooo`004Ooooa0co`0806Ko=C?o
000306Ko<ol0<ol007Lco`000`000?ooooooo`15oooo000Aoooo63?o00H0I_l_<ol000<0I_lco`0c
o`00Mc?o00030000oooooooo04Goool0017ooolN<ol01@1VobXco`000`1Voc?o03?o001g<ol000<0
003oooooool0AOooo`004Oooob<co`0506Ko9C?o000306Ko<ol0<ol007Lco`000`000?ooooooo`15
oooo000Aoooo:3?o00D0I_lP<ol000<0I_lco`0co`00Mc?o00030000oooooooo04Goool0017oool]
<ol01@1Voa/co`000`1Voc?o03?o001g<ol000<0003oooooool0AOooo`004Oooo`80000`<ol01@1V
oaHco`000`1Voc?o03?o001g<ol00P0004Koool001?oool20000<c?o00D0I_lA<ol000<0I_lco`0c
o`00Mc?o00030000oooooooo04Goool001Goool20000=S?o00@0I_l=<ol000<0I_lco`0co`00Mc?o
00030000oooooooo04Goool001Ooool20000>3?o00<0I_l:<ol000<0I_lco`0co`00Mc?o00030000
oooooooo04Goool001Woool20000>C?o0080I_l8<ol000<0I_lco`0co`00Mc?o00030000oooooooo
04Goool001_oool20000>C?o00D0I_l3<ol000<0I_lco`0co`00Mc?o00030000oooooooo04Goool0
01goool20000?3?o00@0I_mi<ol000<0003oooooool0AOooo`007oooo`030000<ol0<ol003`co`00
0ol0VC?o03?o001g<ol000<0003oooooool0AOooo`008?ooo`030000<ol0<ol003/co`000ol0VC?o
03?o001g<ol00P0004Koool0027oool20000>c?o0003o`2I<ol0<ol007Lco`000`000?ooooooo`15
oooo000Soooo00<0000co`0co`00>3?o0003o`2I<ol0<ol007Lco`000`000?ooooooo`15oooo000T
oooo0P0003Pco`000ol0VC?o03?o001g<ol000<0003oooooool0AOooo`009_ooo`030000<ol0<ol0
03Dco`000ol0VC?o03?o001g<ol000<0003oooooool0AOooo`009oooo`030000<ol0<ol003@co`00
0ol0VC?o03?o001g<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol003<co`000ol0VC?o
03?o001N<ol00P0000@co`02000013?o00800003<ol0100000@co`000`000?ooooooo`15oooo000Y
oooo00<0000co`0co`00<S?o0003o`2I<ol0<ol005dco`00100003?o03?o000000Pco`00100003?o
03?o0000008co`000`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_ooo`030000<ol0<ol0
034co`000ol0VC?o03?o001M<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0
000co`0co`0013?o00<00015oooo000[oooo0P00034co`000ol0VC?o03?o001M<ol000@0000co`0c
o`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o00030000oooooooo04Goool0
02goool00`0003?o03?o000^<ol000?o09Tco`0co`00GC?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool002koool00`0003?o
03?o000]<ol000?o09Tco`0co`00GS?o0080000:<ol00P0000@co`0200001C?o00030000oooooooo
04Goool002ooool00`0003?o03?o000/<ol000?o09Tco`0co`00Mc?o00030000oooooooo04Goool0
033oool00`0003?o03?o000[<ol000?o09Tco`0co`00Mc?o00030000oooooooo04Goool0037oool0
0`0003?o03?o000Z<ol000?o09Tco`0co`00Mc?o00030000oooooooo04Goool003;oool00`0003?o
03?o000Y<ol000?o09Tco`0co`00Mc?o00030000oooooooo04Goool003?oool00`0003?o03?o000X
<ol000?o09Tco`0co`00Mc?o00800016oooo000coooo00<0000co`0co`00:3?o0003o`2I<ol0<ol0
07Lco`000`000?ooooooo`15oooo000doooo00<0000co`0co`009c?o0003o`2I<ol0<ol007Lco`00
0`000?ooooooo`15oooo000eoooo00<0000co`0co`009S?o0003o`2I<ol0<ol007Lco`000`000?oo
ooooo`15oooo000foooo00<0000co`0co`009C?o0003o`2I<ol0<ol007Lco`000`000?ooooooo`15
oooo000goooo00<0000co`0co`0093?o0003o`2I<ol0<ol007Lco`000`000?ooooooo`15oooo000h
oooo00<0000co`0co`008c?o0003o`2I<ol0<ol007Lco`000`000?ooooooo`15oooo000hoooo00<0
000co`0co`008c?o0003o`2I<ol0<ol007Lco`000`000?ooooooo`15oooo000ioooo00<0000co`0c
o`008S?o0003o`2I<ol0<ol007Lco`020000A_ooo`00>_ooo`030000<ol0<ol0024co`000ol0VC?o
03?o001g<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol0020co`000ol0VC?o03?o001g
<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol001lco`000ol0VC?o03?o001g<ol000<0
003oooooool0AOooo`00??ooo`030000<ol0<ol001lco`000ol0VC?o03?o001g<ol000<0003ooooo
ool0AOooo`00?Oooo`030000<ol0<ol001hco`000ol0VC?o03?o001g<ol000<0003oooooool0AOoo
o`00?Oooo`030000<ol0<ol001hco`000ol0VC?o03?o001g<ol000<0003oooooool0AOooo`00?_oo
o`030000<ol0<ol001dco`000ol0VC?o03?o001g<ol000<0003oooooool0AOooo`00?_ooo`030000
<ol0<ol001dco`000ol0VC?o03?o001g<ol000<0003oooooool0AOooo`00?oooo`030000<ol0<ol0
01`co`000ol0VC?o03?o001g<ol00P0004Koool003ooool00`0003?o03?o000L<ol000?o09Tco`0c
o`00Mc?o00030000oooooooo04Goool0043oool00`0003?o03?o000K<ol000?o09Tco`0co`00Mc?o
00030000oooooooo04Goool0047oool00`0003?o03?o000J<ol000?o09Tco`0co`00Mc?o00030000
oooooooo04Goool0047oool00`0003?o03?o000J<ol000?o09Tco`0co`00Mc?o00030000oooooooo
04Goool004;oool00`0003?o03?o000I<ol000?o09Tco`0co`00Mc?o00030000oooooooo04Goool0
04;oool00`0003?o03?o000I<ol000?o09Tco`0co`00GS?o00800004<ol00P0000@co`0200001C?o
00<00003<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol001Pco`000ol0VC?o03?o001M
<ol000@0000co`0co`000008<ol000@0000co`0co`000005<ol000<0000co`0co`000S?o00030000
oooooooo04Goool004?oool00`0003?o03?o000H<ol000?o09Tco`0co`00GC?o00040000<ol0<ol0
000023?o00040000<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool00`0003?o03?o000G
<ol000?o09Tco`0co`00GC?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000
<ol0<ol0000013?o00030000oooooooo04Goool004Coool00`0003?o03?o000G<ol000?o09Tco`0c
o`00GC?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0000000@co`00
0`000?ooooooo`15oooo0015oooo00<0000co`0co`005S?o0003o`2I<ol0<ol005hco`0200002S?o
00800005<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`005S?o0003o`2I
<ol0<ol007Lco`000`000?ooooooo`15oooo0016oooo00<0000co`0co`005C?o0003o`2I<ol0<ol0
07Lco`000`000?ooooooo`15oooo0016oooo00<0000co`0co`005C?o0003o`2I<ol0<ol007Lco`00
0`000?ooooooo`15oooo0017oooo00<0000co`0co`0053?o0003o`2I<ol0<ol007Lco`000`000?oo
ooooo`15oooo0017oooo00<0000co`0co`0053?o0003o`2I<ol0<ol007Lco`020000A_ooo`00B?oo
o`030000<ol0<ol001<co`000ol0VC?o03?o001g<ol000<0003oooooool0AOooo`00B?ooo`030000
<ol0<ol001<co`000ol0VC?o03?o001g<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol0
018co`000ol0VC?o03?o001g<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol0018co`00
0ol0VC?o03?o001g<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol0014co`000ol0VC?o
03?o001g<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol0014co`000ol0VC?o03?o001g
<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol0010co`000ol0VC?o03?o001g<ol000<0
003oooooool0AOooo`00Boooo`030000<ol0<ol0010co`000ol0VC?o03?o001g<ol00P0004Koool0
04cooon<<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;<ol0B?ooo`00COoo
oh/co`18oooo001>oooo9S?o00030000<ol0<ol002lco`000`0003?o03?o000_<ol0B?ooo`00C_oo
obDco`000`0003?o03?o0008<ol000<0000co`0co`009S?o00030000<ol0<ol002hco`18oooo001?
oooo93?o00030000<ol0<ol0008co`02000013?o00030000<ol0<ol000hco`02000013?o00800003
<ol0100000<co`02000013?o00030000<ol0<ol002hco`18oooo001?oooo93?o00050000<ol0<ol0
<ol00000008co`000`0003?o03?o0002<ol000<0000co`0co`001C?o00@00003<ol000@0000co`0c
o`000008<ol000<0000co`0co`000c?o00040000<ol0<ol000000c?o00030000<ol0<ol002hco`18
oooo001?oooo8c?o00030000<ol0<ol0008co`000`0003?o03?o000D<ol000@0000co`0co`000009
<ol000<0000co`0co`0013?o00030000<ol0<ol000<co`000`0003?o03?o000]<ol0B?ooo`00D?oo
ob<co`000`0003?o03?o000500004c?o00040000<ol0<ol000002S?o00030000<ol0<ol000@co`00
1@0003?o03?o03?o0000000`<ol0B?ooo`00D?ooob<co`001@0003?o03?o03?o0000000F<ol000@0
000co`0co`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000003<ol000<0000co`0c
o`00;S?o04Soool0053ooolT<ol000<0000co`0co`0063?o0080000:<ol00P0000@co`0200000c?o
00030000<ol0<ol002lco`18oooo001AooooQc?o04Soool0057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.29205 .30902 L
.30316 .30902 L
.31304 .30902 L
.31574 .30902 L
.31723 .30902 L
.31865 .30902 L
.31997 .30902 L
.32071 .30902 L
s
.32071 .30902 m
.32072 .61803 L
s
0 .4 1 r
.02381 .33656 m
.06244 .34082 L
.10458 .34622 L
.14415 .35212 L
.18221 .35868 L
.22272 .36678 L
.26171 .37584 L
.28158 .38099 L
.29205 .38387 L
.30316 .38705 L
.31304 .38999 L
.31574 .39082 L
.31723 .39128 L
.31865 .39172 L
.31997 .39213 L
.32071 .39236 L
.3214 .30902 L
.32262 .30902 L
.32392 .30902 L
.32521 .30902 L
.3264 .30902 L
.32771 .30902 L
.32838 .30902 L
.32909 .30902 L
.3303 .30902 L
.33142 .30902 L
.3321 .30902 L
.33275 .30902 L
.33397 .30902 L
.33507 .30902 L
.33624 .30902 L
.33724 .30902 L
.33834 .30902 L
.33951 .30902 L
.34079 .30902 L
.34199 .30902 L
.34309 .30902 L
.34436 .30902 L
.34557 .30902 L
.34665 .30902 L
.34782 .30902 L
.3491 .30902 L
.34975 .30902 L
.35046 .30902 L
.35171 .30902 L
.35289 .30902 L
.35407 .30902 L
.35519 .30902 L
.35619 .30902 L
.35729 .30902 L
Mistroke
.35847 .30902 L
.35974 .30902 L
.36093 .30902 L
.36201 .30902 L
.36331 .30902 L
.36396 .30902 L
.36468 .30902 L
.36595 .30902 L
.36714 .30902 L
.36786 .30902 L
.36854 .30902 L
.36981 .30902 L
.37052 .30902 L
.37118 .30902 L
.37191 .30902 L
.37267 .30902 L
.37386 .30902 L
.37514 .30902 L
.37634 .30902 L
.37745 .30902 L
.37809 .30902 L
.37878 .30902 L
.38001 .30902 L
.3813 .30902 L
.38204 .30902 L
.38271 .30902 L
.38391 .30902 L
.38503 .30902 L
.38626 .30902 L
.38757 .30902 L
.38823 .30902 L
.38895 .30902 L
.39026 .30902 L
.39154 .30902 L
.39272 .30902 L
.39381 .30902 L
.39484 .30902 L
.39606 .30902 L
.39718 .30902 L
.3983 .30902 L
.39947 .30902 L
.40064 .30902 L
.40193 .30902 L
.40261 .30902 L
.40333 .30902 L
.40402 .30902 L
.40466 .30902 L
.40586 .30902 L
.40714 .30902 L
.4078 .30902 L
Mistroke
.40851 .30902 L
.40979 .30902 L
.41057 .30902 L
.41132 .30902 L
.41198 .30902 L
.41271 .30902 L
.41403 .30902 L
.41523 .30902 L
.41589 .30902 L
.41661 .30902 L
.41791 .30902 L
.41914 .30902 L
.42043 .30902 L
.42153 .30902 L
.42274 .30902 L
.42405 .30902 L
.42527 .30902 L
.42654 .30902 L
.42722 .30902 L
.42795 .30902 L
.4287 .30902 L
.42949 .30902 L
.43016 .30902 L
.43089 .30902 L
.43157 .30902 L
.4323 .30902 L
.43361 .30902 L
.43431 .30902 L
.43494 .30902 L
.43565 .30902 L
.43639 .30902 L
.43763 .30902 L
.43834 .30902 L
.43901 .30902 L
.44024 .30902 L
.44137 .30902 L
.44267 .30902 L
.4439 .30902 L
.44512 .30902 L
.44622 .30902 L
.4475 .30902 L
.44869 .30902 L
.44981 .30902 L
.45083 .30902 L
.45195 .30902 L
.45313 .30902 L
.45433 .30902 L
.45562 .30902 L
.45683 .30902 L
.45793 .30902 L
Mistroke
.45923 .30902 L
.45996 .30902 L
.46063 .30902 L
.46187 .30902 L
.46319 .30902 L
.46442 .30902 L
.46559 .30902 L
.46664 .30902 L
.46779 .30902 L
.46904 .30902 L
.46973 .30902 L
.47036 .30902 L
.47159 .30902 L
.47275 .30902 L
.47384 .30902 L
.47499 .30902 L
.47597 .30902 L
.47705 .30902 L
.47821 .30902 L
.47946 .30902 L
.48064 .30902 L
.48171 .30902 L
.48297 .30902 L
.48361 .30902 L
.48432 .30902 L
.48556 .30902 L
.48673 .30902 L
.48739 .30902 L
.4881 .30902 L
.48935 .30902 L
.49005 .30902 L
.49071 .30902 L
.49142 .30902 L
.49219 .30902 L
.49347 .30902 L
.49419 .30902 L
.49486 .30902 L
.49609 .30902 L
.49739 .30902 L
.49855 .30902 L
.49964 .30902 L
.50083 .30902 L
.50212 .30902 L
.5028 .30902 L
.50345 .30902 L
.50466 .30902 L
.50596 .30902 L
.5067 .30902 L
.50737 .30902 L
.5085 .30902 L
Mistroke
.50974 .30902 L
.51103 .30902 L
.51224 .30902 L
.51293 .30902 L
.51367 .30902 L
.51438 .30902 L
.51503 .30902 L
.51626 .30902 L
.51757 .30902 L
.51825 .30902 L
.51897 .30902 L
.52029 .30902 L
.52105 .30902 L
.52185 .30902 L
.52253 .30902 L
.52328 .30902 L
.52393 .30902 L
.52464 .30902 L
.52592 .30902 L
.52707 .30902 L
.52832 .30902 L
.52902 .30902 L
.52968 .30902 L
.53037 .30902 L
.53112 .30902 L
.53181 .30902 L
.53247 .30902 L
.5337 .30902 L
.53486 .30902 L
.5361 .30902 L
.53716 .30902 L
.53833 .30902 L
.53958 .30902 L
.54029 .30902 L
.54093 .30902 L
.54213 .30902 L
.54338 .30902 L
.54461 .30902 L
.54526 .30902 L
.54594 .30902 L
.5472 .30902 L
.54837 .30902 L
.54948 .30902 L
.55053 .30902 L
.55167 .30902 L
.5529 .30902 L
.55421 .30902 L
.55495 .30902 L
.55563 .30902 L
.55689 .30902 L
Mistroke
.55759 .30902 L
.55822 .30902 L
.55943 .30902 L
.56073 .30902 L
.56196 .30902 L
.56309 .30902 L
.56415 .30902 L
.56529 .30902 L
.56636 .30902 L
.56734 .30902 L
.56849 .30902 L
.56974 .30902 L
.57092 .30902 L
.57202 .30902 L
.57314 .30902 L
.57419 .30902 L
.57534 .30902 L
.57659 .30902 L
.57782 .30902 L
.57912 .30902 L
.58023 .30902 L
.58144 .30902 L
.58276 .30902 L
.58398 .30902 L
.58462 .30902 L
.58532 .30902 L
.58673 .30902 L
.58798 .30902 L
.58867 .30902 L
.58931 .30902 L
.59055 .30902 L
.59172 .30902 L
.59285 .30902 L
.59404 .30902 L
.59517 .30902 L
.59619 .30902 L
.5974 .30902 L
.5987 .30902 L
.59993 .30902 L
.60106 .30902 L
.60228 .30902 L
.60358 .30902 L
.60481 .30902 L
.60593 .30902 L
.60724 .30902 L
.60798 .30902 L
.60867 .30902 L
.60931 .30902 L
.61 .30902 L
.61126 .30902 L
Mistroke
.61255 .30902 L
.61374 .30902 L
.61441 .30902 L
.61514 .30902 L
.61583 .30902 L
.61648 .30902 L
.6172 .30902 L
.61788 .30902 L
.61916 .30902 L
.61982 .30902 L
.62053 .30902 L
.6213 .30902 L
.62201 .30902 L
.62323 .30902 L
.62392 .30902 L
.62455 .30902 L
.62572 .30902 L
.62696 .30902 L
.62807 .30902 L
.62911 .30902 L
.63025 .30902 L
.63148 .30902 L
.63271 .30902 L
.63341 .30902 L
.63406 .30902 L
.63537 .30902 L
.63611 .30902 L
.63677 .30902 L
.63797 .30902 L
.63927 .30902 L
.6405 .30902 L
.64163 .30902 L
.64269 .30902 L
.64382 .30902 L
.64489 .30902 L
.64587 .30902 L
.64701 .30902 L
.64826 .30902 L
.64944 .30902 L
.65053 .30902 L
.65177 .30902 L
.65293 .30902 L
.65397 .30902 L
.6551 .30902 L
.65633 .30902 L
.65763 .30902 L
.65874 .30902 L
.65996 .30902 L
.66127 .30902 L
.66248 .30902 L
Mistroke
.66311 .30902 L
.6638 .30902 L
.66453 .30902 L
.66521 .30902 L
.66646 .30902 L
.6676 .30902 L
.66886 .30902 L
.67018 .30902 L
.67129 .30902 L
.67233 .30902 L
.67353 .30902 L
.67463 .30902 L
.67584 .30902 L
.67715 .30902 L
.67837 .30902 L
.67949 .30902 L
.68474 .30902 L
.68966 .30902 L
.69092 .30902 L
.69213 .30902 L
.69279 .30902 L
.69351 .30902 L
.69478 .30902 L
.6962 .30902 L
.69699 .30902 L
.6977 .30902 L
.69837 .30902 L
.6991 .30902 L
.70041 .30902 L
.70166 .30902 L
.7028 .30902 L
.70411 .30902 L
.70535 .30902 L
.7065 .30902 L
.70756 .30902 L
.70872 .30902 L
.70996 .30902 L
.71119 .30902 L
.71189 .30902 L
.71252 .30902 L
.71376 .30902 L
.71493 .30902 L
.71559 .30902 L
.71629 .30902 L
.71755 .30902 L
.71832 .30902 L
.71905 .30902 L
.7197 .30902 L
.72041 .30902 L
.72173 .30902 L
Mistroke
.72296 .30902 L
.72366 .30902 L
.7243 .30902 L
.72505 .30902 L
.72575 .30902 L
.72643 .30902 L
.72715 .30902 L
.72845 .30902 L
.72912 .30902 L
.72985 .30902 L
.73064 .30902 L
.73139 .30902 L
.73262 .30902 L
.73331 .30902 L
.73396 .30902 L
.73527 .30902 L
.736 .30902 L
.73666 .30902 L
.73785 .30902 L
.73915 .30902 L
.74037 .30902 L
.74149 .30902 L
.74275 .30902 L
.74394 .30902 L
.745 .30902 L
.74617 .30902 L
.74743 .30902 L
.74813 .30902 L
.74877 .30902 L
.75002 .30902 L
.75119 .30902 L
.75229 .30902 L
.75346 .30902 L
.75445 .30902 L
.75555 .30902 L
.75672 .30902 L
.75798 .30902 L
.75917 .30902 L
.76025 .30902 L
.76154 .30902 L
.76218 .30902 L
.7629 .30902 L
.76416 .30902 L
.76534 .30902 L
.76601 .30902 L
.76673 .30902 L
.768 .30902 L
.76871 .30902 L
.76938 .30902 L
.77016 .30902 L
Mistroke
.77086 .30902 L
.77205 .30902 L
.77334 .30902 L
.77455 .30902 L
.77565 .30902 L
.77687 .30902 L
.77756 .30902 L
.7782 .30902 L
.7795 .30902 L
.78023 .30902 L
.78089 .30902 L
.78208 .30902 L
.78337 .30902 L
.78458 .30902 L
.78569 .30902 L
.78687 .30902 L
.78811 .30902 L
.79079 .30902 L
.79995 .30902 L
.8207 .30902 L
.85877 .30902 L
.8993 .30902 L
.93831 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0005<ol000<0
I_lco`0000002C?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0c
o`00;c?o00030000<ol0<ol001Tco`000`1Voc?o03?o000C<ol000<0000co`0co`00;S?o00030000
<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Oooodhco`000`1Voc?o
03?o001f<ol000<0003oooooool0AOooo`004Oooodhco`000`1Voc?o03?o001f<ol000<0003ooooo
ool0AOooo`004Oooodhco`000`1Voc?o03?o001f<ol000<0003oooooool0AOooo`004Oooodhco`00
0`1Voc?o03?o001f<ol000<0003oooooool0AOooo`004Oooo`H0I_m8<ol000<0I_lco`0co`00MS?o
00030000oooooooo04Goool0017oool6<ol0201Vod0co`000`1Voc?o03?o001f<ol00P0004Koool0
017oool><ol01@1Voc/co`000`1Voc?o03?o001f<ol000<0003oooooool0AOooo`004Ooooa<co`08
06Ko<c?o000306Ko<ol0<ol007Hco`000`000?ooooooo`15oooo000Aoooo6c?o00P0I_l[<ol000<0
I_lco`0co`00MS?o00030000oooooooo04Goool0017ooolS<ol01@1VobHco`000`1Voc?o03?o001f
<ol000<0003oooooool0AOooo`004OooobPco`0506Ko8C?o000306Ko<ol0<ol007Hco`000`000?oo
ooooo`15oooo000Aoooo;C?o00D0I_lL<ol000<0I_lco`0co`00MS?o00030000oooooooo04Goool0
017ooolb<ol0101VoaPco`000`1Voc?o03?o001f<ol000<0003oooooool0AOooo`004Oooo`80000d
<ol00`1VoaDco`000`1Voc?o03?o001f<ol00P0004Koool001?oool20000=C?o00@0I_lA<ol000<0
I_lco`0co`00MS?o00030000oooooooo04Goool001Goool20000=c?o00@0I_l=<ol000<0I_lco`0c
o`00MS?o00030000oooooooo04Goool001Ooool20000>C?o00@0I_l9<ol000<0I_lco`0co`00MS?o
00030000oooooooo04Goool001Woool20000>c?o00H0I_l3<ol000<0I_lco`0co`00MS?o00030000
oooooooo04Goool001_oool20000?c?o00@0I_mh<ol000<0003oooooool0AOooo`007Oooo`80000o
<ol00P1VogPco`000`000?ooooooo`15oooo000Ooooo00<0000co`0co`00?C?o0003o`2I<ol0<ol0
07Hco`000`000?ooooooo`15oooo000Poooo00<0000co`0co`00?3?o0003o`2I<ol0<ol007Hco`02
0000A_ooo`008Oooo`80000l<ol000?o09Tco`0co`00MS?o00030000oooooooo04Goool002?oool0
0`0003?o03?o000i<ol000?o09Tco`0co`00MS?o00030000oooooooo04Goool002Coool20000>C?o
0003o`2I<ol0<ol007Hco`000`000?ooooooo`15oooo000Voooo00<0000co`0co`00=S?o0003o`2I
<ol0<ol007Hco`000`000?ooooooo`15oooo000Woooo00<0000co`0co`00=C?o0003o`2I<ol0<ol0
07Hco`000`000?ooooooo`15oooo000Xoooo00<0000co`0co`00=3?o0003o`2I<ol0<ol005dco`02
000013?o00800004<ol00P0000<co`04000013?o00030000oooooooo04Goool002Woool00`0003?o
03?o000c<ol000?o09Tco`0co`00G3?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o
00030000<ol0<ol000Dco`000`000?ooooooo`15oooo000Zoooo00<0000co`0co`00<S?o0003o`2I
<ol0<ol005`co`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o0004
<ol00`0004Goool002_oool20000<S?o0003o`2I<ol0<ol005`co`00100003?o03?o000000Pco`00
100003?o03?o000000@co`000`0003?o03?o0003<ol000<0003oooooool0AOooo`00;Oooo`030000
<ol0<ol002lco`000ol0VC?o03?o001L<ol000@0000co`0co`000008<ol000@0000co`0co`000002
<ol000@0000co`0co`000004<ol000<0003oooooool0AOooo`00;_ooo`030000<ol0<ol002hco`00
0ol0VC?o03?o001M<ol00P0000Xco`02000013?o00800005<ol000<0003oooooool0AOooo`00;ooo
o`030000<ol0<ol002dco`000ol0VC?o03?o001f<ol000<0003oooooool0AOooo`00<?ooo`030000
<ol0<ol002`co`000ol0VC?o03?o001f<ol000<0003oooooool0AOooo`00<Oooo`030000<ol0<ol0
02/co`000ol0VC?o03?o001f<ol000<0003oooooool0AOooo`00<_ooo`030000<ol0<ol002Xco`00
0ol0VC?o03?o001f<ol000<0003oooooool0AOooo`00<oooo`030000<ol0<ol002Tco`000ol0VC?o
03?o001f<ol00P0004Koool003?oool00`0003?o03?o000Y<ol000?o09Tco`0co`00MS?o00030000
oooooooo04Goool003Coool00`0003?o03?o000X<ol000?o09Tco`0co`00MS?o00030000oooooooo
04Goool003Goool00`0003?o03?o000W<ol000?o09Tco`0co`00MS?o00030000oooooooo04Goool0
03Koool00`0003?o03?o000V<ol000?o09Tco`0co`00MS?o00030000oooooooo04Goool003Ooool0
0`0003?o03?o000U<ol000?o09Tco`0co`00MS?o00030000oooooooo04Goool003Soool00`0003?o
03?o000T<ol000?o09Tco`0co`00MS?o00030000oooooooo04Goool003Soool00`0003?o03?o000T
<ol000?o09Tco`0co`00MS?o00030000oooooooo04Goool003Woool00`0003?o03?o000S<ol000?o
09Tco`0co`00MS?o00800016oooo000joooo00<0000co`0co`008S?o0003o`2I<ol0<ol007Hco`00
0`000?ooooooo`15oooo000koooo00<0000co`0co`008C?o0003o`2I<ol0<ol007Hco`000`000?oo
ooooo`15oooo000loooo00<0000co`0co`0083?o0003o`2I<ol0<ol007Hco`000`000?ooooooo`15
oooo000loooo00<0000co`0co`0083?o0003o`2I<ol0<ol007Hco`000`000?ooooooo`15oooo000m
oooo00<0000co`0co`007c?o0003o`2I<ol0<ol007Hco`000`000?ooooooo`15oooo000moooo00<0
000co`0co`007c?o0003o`2I<ol0<ol007Hco`000`000?ooooooo`15oooo000noooo00<0000co`0c
o`007S?o0003o`2I<ol0<ol007Hco`000`000?ooooooo`15oooo000noooo00<0000co`0co`007S?o
0003o`2I<ol0<ol007Hco`000`000?ooooooo`15oooo000ooooo00<0000co`0co`007C?o0003o`2I
<ol0<ol007Hco`020000A_ooo`00?oooo`030000<ol0<ol001dco`000ol0VC?o03?o001f<ol000<0
003oooooool0AOooo`00@?ooo`030000<ol0<ol001`co`000ol0VC?o03?o001f<ol000<0003ooooo
ool0AOooo`00@Oooo`030000<ol0<ol001/co`000ol0VC?o03?o001f<ol000<0003oooooool0AOoo
o`00@Oooo`030000<ol0<ol001/co`000ol0VC?o03?o001f<ol000<0003oooooool0AOooo`00@_oo
o`030000<ol0<ol001Xco`000ol0VC?o03?o001f<ol000<0003oooooool0AOooo`00@_ooo`030000
<ol0<ol001Xco`000ol0VC?o03?o001M<ol00P0000@co`02000013?o00800005<ol00`0000<co`00
0`000?ooooooo`15oooo0013oooo00<0000co`0co`006C?o0003o`2I<ol0<ol005`co`00100003?o
03?o000000Pco`00100003?o03?o000000Dco`000`0003?o03?o0002<ol000<0003oooooool0AOoo
o`00@oooo`030000<ol0<ol001Tco`000ol0VC?o03?o001L<ol000@0000co`0co`000008<ol000@0
000co`0co`000002<ol01@0000<co`030000AOooo`00A?ooo`030000<ol0<ol001Pco`000ol0VC?o
03?o001L<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000004
<ol000<0003oooooool0AOooo`00A?ooo`030000<ol0<ol001Pco`000ol0VC?o03?o001L<ol000@0
000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`00000013?o00030000oooooooo
04Goool004Goool00`0003?o03?o000G<ol000?o09Tco`0co`00GC?o0080000:<ol00P0000Dco`02
000013?o00030000oooooooo04Goool004Goool00`0003?o03?o000G<ol000?o09Tco`0co`00MS?o
00030000oooooooo04Goool004Koool00`0003?o03?o000F<ol000?o09Tco`0co`00MS?o00030000
oooooooo04Goool004Koool00`0003?o03?o000F<ol000?o09Tco`0co`00MS?o00030000oooooooo
04Goool004Ooool00`0003?o03?o000E<ol000?o09Tco`0co`00MS?o00030000oooooooo04Goool0
04Ooool00`0003?o03?o000E<ol000?o09Tco`0co`00MS?o00800016oooo0018oooo00<0000co`0c
o`0053?o0003o`2I<ol0<ol007Hco`000`000?ooooooo`15oooo0018oooo00<0000co`0co`0053?o
0003o`2I<ol0<ol007Hco`000`000?ooooooo`15oooo0019oooo00<0000co`0co`004c?o0003o`2I
<ol0<ol007Hco`000`000?ooooooo`15oooo0019oooo00<0000co`0co`004c?o0003o`2I<ol0<ol0
07Hco`000`000?ooooooo`15oooo001:oooo00<0000co`0co`004S?o0003o`2I<ol0<ol007Hco`00
0`000?ooooooo`15oooo001:oooo00<0000co`0co`004S?o0003o`2I<ol0<ol007Hco`000`000?oo
ooooo`15oooo001;oooo00<0000co`0co`004C?o0003o`2I<ol0<ol007Hco`000`000?ooooooo`15
oooo001;oooo00<0000co`0co`004C?o0003o`2I<ol0<ol007Hco`020000A_ooo`00C?oooh`co`18
oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00COoooh/co`18oooo001=ooooRc?o04Soool0
04kooolV<ol000<0000co`0co`00;c?o00030000<ol0<ol002lco`18oooo001>oooo9C?o00030000
<ol0<ol000Pco`000`0003?o03?o000V<ol000<0000co`0co`00;S?o04Soool004oooolT<ol000<0
000co`0co`000S?o00800004<ol000<0000co`0co`003S?o00800004<ol00P0000<co`0400000S?o
00@00003<ol000<0000co`0co`00;S?o04Soool004oooolT<ol000D0000co`0co`0co`0000000S?o
00030000<ol0<ol0008co`000`0003?o03?o0005<ol0100000<co`00100003?o03?o000000Pco`00
0`0003?o03?o0003<ol000<0000co`0co`0013?o00030000<ol0<ol002hco`18oooo001?oooo8c?o
00030000<ol0<ol0008co`000`0003?o03?o000D<ol000@0000co`0co`000009<ol000<0000co`0c
o`000c?o00030000<ol0<ol000@co`000`0003?o03?o000]<ol0B?ooo`00D?ooob<co`000`0003?o
03?o000500004c?o00040000<ol0<ol000002S?o00030000<ol0<ol000<co`000`0003?o03?o0002
<ol000<0000co`0co`00;S?o04Soool0053ooolS<ol000D0000co`0co`0co`0000005S?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol000000c?o00030000<ol0<ol0
02hco`18oooo001@oooo93?o00030000<ol0<ol001Pco`0200002S?o00800004<ol00P0000<co`00
0`0003?o03?o000_<ol0B?ooo`00DOooohLco`18oooo001AooooQc?o04Soool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.21) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.31875 .30902 L
.32145 .30902 L
.32263 .30902 L
.32392 .30902 L
s
.32392 .30902 m
.32392 .61803 L
s
0 .4 1 r
.02381 .33528 m
.06244 .33933 L
.10458 .34447 L
.14415 .3501 L
.18221 .35636 L
.22272 .36408 L
.26171 .37271 L
.28158 .37762 L
.30316 .3834 L
.31323 .38626 L
.31875 .38788 L
.32145 .38868 L
.32263 .38903 L
.32392 .38942 L
.32509 .30902 L
.32617 .30902 L
.32721 .30902 L
.32831 .30902 L
.32959 .30902 L
.33079 .30902 L
.33187 .30902 L
.33304 .30902 L
.33425 .30902 L
.33558 .30902 L
.33625 .30902 L
.33697 .30902 L
.33827 .30902 L
.33956 .30902 L
.34079 .30902 L
.34189 .30902 L
.34309 .30902 L
.3443 .30902 L
.34542 .30902 L
.34664 .30902 L
.34793 .30902 L
.34906 .30902 L
.35011 .30902 L
.35126 .30902 L
.35248 .30902 L
.35318 .30902 L
.35383 .30902 L
.35453 .30902 L
.35528 .30902 L
.35654 .30902 L
.35725 .30902 L
.35792 .30902 L
.35916 .30902 L
.3603 .30902 L
.36161 .30902 L
.36286 .30902 L
Mistroke
.36354 .30902 L
.36419 .30902 L
.36539 .30902 L
.36668 .30902 L
.36741 .30902 L
.36807 .30902 L
.3692 .30902 L
.37043 .30902 L
.37171 .30902 L
.37291 .30902 L
.37359 .30902 L
.37433 .30902 L
.37568 .30902 L
.3782 .30902 L
.37963 .30902 L
.38041 .30902 L
.38115 .30902 L
.38244 .30902 L
.38313 .30902 L
.38387 .30902 L
.38513 .30902 L
.38627 .30902 L
.3876 .30902 L
.38884 .30902 L
.39 .30902 L
.39106 .30902 L
.39223 .30902 L
.39346 .30902 L
.39471 .30902 L
.39541 .30902 L
.39605 .30902 L
.39728 .30902 L
.39846 .30902 L
.39912 .30902 L
.39982 .30902 L
.40109 .30902 L
.40179 .30902 L
.40245 .30902 L
.40317 .30902 L
.40395 .30902 L
.40459 .30902 L
.40527 .30902 L
.40651 .30902 L
.40726 .30902 L
.40797 .30902 L
.40861 .30902 L
.40931 .30902 L
.41004 .30902 L
.41073 .30902 L
.41145 .30902 L
Mistroke
.41225 .30902 L
.41355 .30902 L
.41429 .30902 L
.41496 .30902 L
.41624 .30902 L
.41743 .30902 L
.41874 .30902 L
.41947 .30902 L
.42014 .30902 L
.42136 .30902 L
.42267 .30902 L
.42392 .30902 L
.42506 .30902 L
.42632 .30902 L
.42752 .30902 L
.4286 .30902 L
.42976 .30902 L
.43103 .30902 L
.43168 .30902 L
.43238 .30902 L
.43363 .30902 L
.4348 .30902 L
.43592 .30902 L
.43709 .30902 L
.43809 .30902 L
.43918 .30902 L
.44036 .30902 L
.44163 .30902 L
.44282 .30902 L
.4439 .30902 L
.44519 .30902 L
.44584 .30902 L
.44655 .30902 L
.44782 .30902 L
.449 .30902 L
.44972 .30902 L
.4504 .30902 L
.45167 .30902 L
.45238 .30902 L
.45304 .30902 L
.45376 .30902 L
.45453 .30902 L
.45584 .30902 L
.45657 .30902 L
.45725 .30902 L
.45849 .30902 L
.4598 .30902 L
.46098 .30902 L
.46207 .30902 L
.46457 .30902 L
Mistroke
.46584 .30902 L
.46648 .30902 L
.46718 .30902 L
.46843 .30902 L
.4696 .30902 L
.4703 .30902 L
.47097 .30902 L
.47223 .30902 L
.47288 .30902 L
.47358 .30902 L
.47434 .30902 L
.47506 .30902 L
.47634 .30902 L
.47707 .30902 L
.47773 .30902 L
.47896 .30902 L
.48026 .30902 L
.48142 .30902 L
.48251 .30902 L
.4837 .30902 L
.48497 .30902 L
.48621 .30902 L
.48736 .30902 L
.48862 .30902 L
.48926 .30902 L
.48996 .30902 L
.49113 .30902 L
.4924 .30902 L
.49359 .30902 L
.49469 .30902 L
.49576 .30902 L
.49675 .30902 L
.49784 .30902 L
.499 .30902 L
.50023 .30902 L
.50138 .30902 L
.50242 .30902 L
.50355 .30902 L
.50478 .30902 L
.5059 .30902 L
.5072 .30902 L
.50843 .30902 L
.50957 .30902 L
.51062 .30902 L
.51178 .30902 L
.51301 .30902 L
.51371 .30902 L
.51436 .30902 L
.51507 .30902 L
.51582 .30902 L
Mistroke
.51708 .30902 L
.5178 .30902 L
.51847 .30902 L
.51972 .30902 L
.52086 .30902 L
.52217 .30902 L
.52341 .30902 L
.52462 .30902 L
.52532 .30902 L
.52596 .30902 L
.52663 .30902 L
.52735 .30902 L
.52865 .30902 L
.52978 .30902 L
.53101 .30902 L
.5323 .30902 L
.5335 .30902 L
.53418 .30902 L
.53493 .30902 L
.53563 .30902 L
.53628 .30902 L
.5375 .30902 L
.5388 .30902 L
.5401 .30902 L
.54083 .30902 L
.54149 .30902 L
.54228 .30902 L
.54302 .30902 L
.54371 .30902 L
.54445 .30902 L
.54567 .30902 L
.54678 .30902 L
.548 .30902 L
.54929 .30902 L
.55041 .30902 L
.55146 .30902 L
.5526 .30902 L
.55383 .30902 L
.55453 .30902 L
.55517 .30902 L
.55587 .30902 L
.55662 .30902 L
.55788 .30902 L
.55859 .30902 L
.55926 .30902 L
.5605 .30902 L
.56164 .30902 L
.56298 .30902 L
.5642 .30902 L
.56549 .30902 L
Mistroke
.5662 .30902 L
.56686 .30902 L
.56806 .30902 L
.56934 .30902 L
.57002 .30902 L
.57077 .30902 L
.57154 .30902 L
.57227 .30902 L
.57357 .30902 L
.5743 .30902 L
.57496 .30902 L
.57618 .30902 L
.57748 .30902 L
.57815 .30902 L
.5789 .30902 L
.58021 .30902 L
.58145 .30902 L
.58214 .30902 L
.58278 .30902 L
.58396 .30902 L
.58519 .30902 L
.58643 .30902 L
.58712 .30902 L
.58777 .30902 L
.58895 .30902 L
.59019 .30902 L
.59131 .30902 L
.59236 .30902 L
.59351 .30902 L
.59474 .30902 L
.59605 .30902 L
.59679 .30902 L
.59747 .30902 L
.59873 .30902 L
.59943 .30902 L
.60007 .30902 L
.60128 .30902 L
.60258 .30902 L
.60381 .30902 L
.60494 .30902 L
.606 .30902 L
.60715 .30902 L
.60822 .30902 L
.6092 .30902 L
.61035 .30902 L
.61161 .30902 L
.61278 .30902 L
.61388 .30902 L
.61501 .30902 L
.61626 .30902 L
Mistroke
.61747 .30902 L
.61878 .30902 L
.61999 .30902 L
.62114 .30902 L
.62218 .30902 L
.62331 .30902 L
.62395 .30902 L
.62463 .30902 L
.62585 .30902 L
.62717 .30902 L
.62792 .30902 L
.62861 .30902 L
.62987 .30902 L
.63102 .30902 L
.63166 .30902 L
.63235 .30902 L
.63361 .30902 L
.63473 .30902 L
.63597 .30902 L
.63726 .30902 L
.63847 .30902 L
.6396 .30902 L
.64063 .30902 L
.64185 .30902 L
.64296 .30902 L
.64418 .30902 L
.64549 .30902 L
.6467 .30902 L
.64784 .30902 L
.64848 .30902 L
.64917 .30902 L
.6504 .30902 L
.65172 .30902 L
.65247 .30902 L
.65317 .30902 L
.65384 .30902 L
.65456 .30902 L
.65588 .30902 L
.65716 .30902 L
.65836 .30902 L
.65909 .30902 L
.65977 .30902 L
.66105 .30902 L
.66177 .30902 L
.66244 .30902 L
.66316 .30902 L
.66393 .30902 L
.66515 .30902 L
.66584 .30902 L
.66648 .30902 L
Mistroke
.66765 .30902 L
.66889 .30902 L
.66996 .30902 L
.67107 .30902 L
.6723 .30902 L
.67342 .30902 L
.67461 .30902 L
.67591 .30902 L
.67713 .30902 L
.67825 .30902 L
.67895 .30902 L
.67961 .30902 L
.68083 .30902 L
.68216 .30902 L
.6829 .30902 L
.68359 .30902 L
.68465 .30902 L
.68578 .30902 L
.68685 .30902 L
.68783 .30902 L
.68901 .30902 L
.69025 .30902 L
.69143 .30902 L
.6925 .30902 L
.69369 .30902 L
.69481 .30902 L
.69603 .30902 L
.69734 .30902 L
.6985 .30902 L
.69973 .30902 L
.70078 .30902 L
.70193 .30902 L
.72313 .30902 L
.728 .30902 L
.72919 .30902 L
.73046 .30902 L
.73119 .30902 L
.73186 .30902 L
.73317 .30902 L
.73434 .30902 L
.73544 .30902 L
.73664 .30902 L
.73792 .30902 L
.73914 .30902 L
.74028 .30902 L
.74132 .30902 L
.74243 .30902 L
.74359 .30902 L
.74486 .30902 L
.74551 .30902 L
Mistroke
.74619 .30902 L
.74744 .30902 L
.74867 .30902 L
.74984 .30902 L
.75204 .30902 L
.7533 .30902 L
.75393 .30902 L
.75464 .30902 L
.75587 .30902 L
.75704 .30902 L
.7577 .30902 L
.7584 .30902 L
.75965 .30902 L
.76035 .30902 L
.761 .30902 L
.76177 .30902 L
.76247 .30902 L
.76366 .30902 L
.76494 .30902 L
.76607 .30902 L
.76727 .30902 L
.76834 .30902 L
.76935 .30902 L
.77045 .30902 L
.77163 .30902 L
.77289 .30902 L
.7736 .30902 L
.77426 .30902 L
.77546 .30902 L
.77675 .30902 L
.77801 .30902 L
.7792 .30902 L
.78027 .30902 L
.78142 .30902 L
.78267 .30902 L
.7838 .30902 L
.78511 .30902 L
.78635 .30902 L
.7875 .30902 L
.78855 .30902 L
.79095 .30902 L
.80139 .30902 L
.82247 .30902 L
.86178 .30902 L
.89958 .30902 L
.93983 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.21) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0
I_l0000co`0023?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0c
o`00;c?o00030000<ol0<ol001Xco`000`1Voc?o03?o000B<ol000<0000co`0co`00;S?o00030000
<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Oooodlco`000`1Voc?o
03?o001e<ol000<0003oooooool0AOooo`004Oooodlco`000`1Voc?o03?o001e<ol000<0003ooooo
ool0AOooo`004Oooodlco`000`1Voc?o03?o001e<ol000<0003oooooool0AOooo`004Oooodlco`00
0`1Voc?o03?o001e<ol000<0003oooooool0AOooo`004Oooo`H0I_m9<ol000<0I_lco`0co`00MC?o
00030000oooooooo04Goool0017oool6<ol02P1Voclco`000`1Voc?o03?o001e<ol00P0004Koool0
017oool@<ol0201VocLco`000`1Voc?o03?o001e<ol000<0003oooooool0AOooo`004OoooaPco`06
06Ko<C?o000306Ko<ol0<ol007Dco`000`000?ooooooo`15oooo000Aoooo7S?o00L0I_lZ<ol000<0
I_lco`0co`00MC?o00030000oooooooo04Goool0017ooolU<ol0201Vob8co`000`1Voc?o03?o001e
<ol000<0003oooooool0AOooo`004Oooobdco`0506Ko7C?o000306Ko<ol0<ol007Dco`000`000?oo
ooooo`15oooo000Aoooo<S?o00@0I_lI<ol000<0I_lco`0co`00MC?o00030000oooooooo04Goool0
017ooolf<ol00`1VoaHco`000`1Voc?o03?o001e<ol000<0003oooooool0AOooo`004Oooo`80000g
<ol0101Voa8co`000`1Voc?o03?o001e<ol00P0004Koool001?oool20000>C?o00@0I_l><ol000<0
I_lco`0co`00MC?o00030000oooooooo04Goool001Goool20000>c?o00D0I_l9<ol000<0I_lco`0c
o`00MC?o00030000oooooooo04Goool001Ooool20000?S?o0080I_l7<ol000<0I_lco`0co`00MC?o
00030000oooooooo04Goool001Woool20000?S?o00D0I_l2<ol000<0I_lco`0co`00MC?o00030000
oooooooo04Goool001_oool20000@C?o00<0I_mg<ol000<0003oooooool0AOooo`007Oooo`800011
<ol000?o09Tco`0co`00MC?o00030000oooooooo04Goool001ooool00`0003?o03?o000n<ol000?o
09Tco`0co`00MC?o00030000oooooooo04Goool0023oool00`0003?o03?o000m<ol000?o09Tco`0c
o`00MC?o00800016oooo000Qoooo0P0003dco`000ol0VC?o03?o001e<ol000<0003oooooool0AOoo
o`008oooo`030000<ol0<ol003Xco`000ol0VC?o03?o001e<ol000<0003oooooool0AOooo`009?oo
o`80000j<ol000?o09Tco`0co`00MC?o00030000oooooooo04Goool002Koool00`0003?o03?o000g
<ol000?o09Tco`0co`00MC?o00030000oooooooo04Goool002Ooool00`0003?o03?o000f<ol000?o
09Tco`0co`00MC?o00030000oooooooo04Goool002Soool00`0003?o03?o000e<ol000?o09Tco`0c
o`00G3?o00800004<ol00P0000@co`0200000c?o00@00004<ol000<0003oooooool0AOooo`00:Ooo
o`030000<ol0<ol003@co`000ol0VC?o03?o001K<ol000@0000co`0co`000008<ol000@0000co`0c
o`000002<ol000<0000co`0co`001C?o00030000oooooooo04Goool002[oool00`0003?o03?o000c
<ol000?o09Tco`0co`00Fc?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000
<ol0<ol000@co`030000AOooo`00:oooo`80000c<ol000?o09Tco`0co`00Fc?o00040000<ol0<ol0
000023?o00040000<ol0<ol0000013?o00030000<ol0<ol000<co`000`000?ooooooo`15oooo000]
oooo00<0000co`0co`00<3?o0003o`2I<ol0<ol005/co`00100003?o03?o000000Pco`00100003?o
03?o0000008co`00100003?o03?o000000@co`000`000?ooooooo`15oooo000^oooo00<0000co`0c
o`00;c?o0003o`2I<ol0<ol005`co`0200002S?o00800004<ol00P0000Dco`000`000?ooooooo`15
oooo000_oooo00<0000co`0co`00;S?o0003o`2I<ol0<ol007Dco`000`000?ooooooo`15oooo000`
oooo00<0000co`0co`00;C?o0003o`2I<ol0<ol007Dco`000`000?ooooooo`15oooo000aoooo00<0
000co`0co`00;3?o0003o`2I<ol0<ol007Dco`000`000?ooooooo`15oooo000boooo00<0000co`0c
o`00:c?o0003o`2I<ol0<ol007Dco`000`000?ooooooo`15oooo000coooo00<0000co`0co`00:S?o
0003o`2I<ol0<ol007Dco`020000A_ooo`00<oooo`030000<ol0<ol002Xco`000ol0VC?o03?o001e
<ol000<0003oooooool0AOooo`00=?ooo`030000<ol0<ol002Tco`000ol0VC?o03?o001e<ol000<0
003oooooool0AOooo`00=Oooo`030000<ol0<ol002Pco`000ol0VC?o03?o001e<ol000<0003ooooo
ool0AOooo`00=_ooo`030000<ol0<ol002Lco`000ol0VC?o03?o001e<ol000<0003oooooool0AOoo
o`00=oooo`030000<ol0<ol002Hco`000ol0VC?o03?o001e<ol000<0003oooooool0AOooo`00>?oo
o`030000<ol0<ol002Dco`000ol0VC?o03?o001e<ol000<0003oooooool0AOooo`00>?ooo`030000
<ol0<ol002Dco`000ol0VC?o03?o001e<ol000<0003oooooool0AOooo`00>Oooo`030000<ol0<ol0
02@co`000ol0VC?o03?o001e<ol00P0004Koool003[oool00`0003?o03?o000S<ol000?o09Tco`0c
o`00MC?o00030000oooooooo04Goool003_oool00`0003?o03?o000R<ol000?o09Tco`0co`00MC?o
00030000oooooooo04Goool003coool00`0003?o03?o000Q<ol000?o09Tco`0co`00MC?o00030000
oooooooo04Goool003coool00`0003?o03?o000Q<ol000?o09Tco`0co`00MC?o00030000oooooooo
04Goool003goool00`0003?o03?o000P<ol000?o09Tco`0co`00MC?o00030000oooooooo04Goool0
03goool00`0003?o03?o000P<ol000?o09Tco`0co`00MC?o00030000oooooooo04Goool003koool0
0`0003?o03?o000O<ol000?o09Tco`0co`00MC?o00030000oooooooo04Goool003koool00`0003?o
03?o000O<ol000?o09Tco`0co`00MC?o00030000oooooooo04Goool003ooool00`0003?o03?o000N
<ol000?o09Tco`0co`00MC?o00800016oooo000ooooo00<0000co`0co`007S?o0003o`2I<ol0<ol0
07Dco`000`000?ooooooo`15oooo0010oooo00<0000co`0co`007C?o0003o`2I<ol0<ol007Dco`00
0`000?ooooooo`15oooo0011oooo00<0000co`0co`0073?o0003o`2I<ol0<ol007Dco`000`000?oo
ooooo`15oooo0011oooo00<0000co`0co`0073?o0003o`2I<ol0<ol007Dco`000`000?ooooooo`15
oooo0012oooo00<0000co`0co`006c?o0003o`2I<ol0<ol007Dco`000`000?ooooooo`15oooo0012
oooo00<0000co`0co`006c?o0003o`2I<ol0<ol005`co`02000013?o00800004<ol00P0000Dco`03
00000c?o00030000oooooooo04Goool004?oool00`0003?o03?o000J<ol000?o09Tco`0co`00Fc?o
00040000<ol0<ol0000023?o00040000<ol0<ol000001C?o00030000<ol0<ol0008co`000`000?oo
ooooo`15oooo0013oooo00<0000co`0co`006S?o0003o`2I<ol0<ol005/co`00100003?o03?o0000
00Pco`00100003?o03?o0000008co`0500000c?o00<00015oooo0014oooo00<0000co`0co`006C?o
0003o`2I<ol0<ol005/co`00100003?o03?o000000Pco`00100003?o03?o0000008co`00100003?o
03?o000000@co`000`000?ooooooo`15oooo0014oooo00<0000co`0co`006C?o0003o`2I<ol0<ol0
05/co`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o00000004<ol000<0
003oooooool0AOooo`00AOooo`030000<ol0<ol001Pco`000ol0VC?o03?o001L<ol00P0000Xco`02
00001C?o00800004<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol001Pco`000ol0VC?o
03?o001e<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol001Lco`000ol0VC?o03?o001e
<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol001Lco`000ol0VC?o03?o001e<ol000<0
003oooooool0AOooo`00Aoooo`030000<ol0<ol001Hco`000ol0VC?o03?o001e<ol000<0003ooooo
ool0AOooo`00Aoooo`030000<ol0<ol001Hco`000ol0VC?o03?o001e<ol00P0004Koool004Soool0
0`0003?o03?o000E<ol000?o09Tco`0co`00MC?o00030000oooooooo04Goool004Soool00`0003?o
03?o000E<ol000?o09Tco`0co`00MC?o00030000oooooooo04Goool004Woool00`0003?o03?o000D
<ol000?o09Tco`0co`00MC?o00030000oooooooo04Goool004Woool00`0003?o03?o000D<ol000?o
09Tco`0co`00MC?o00030000oooooooo04Goool004[oool00`0003?o03?o000C<ol000?o09Tco`0c
o`00MC?o00030000oooooooo04Goool004[oool00`0003?o03?o000C<ol000?o09Tco`0co`00MC?o
00030000oooooooo04Goool004_oool00`0003?o03?o000B<ol000?o09Tco`0co`00MC?o00030000
oooooooo04Goool004_oool00`0003?o03?o000B<ol000?o09Tco`0co`00MC?o00800016oooo001<
ooooS3?o04Soool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001=ooooRc?o04Soool004gooon;
<ol0B?ooo`00C_ooobHco`000`0003?o03?o000_<ol000<0000co`0co`00;c?o04Soool004kooolU
<ol000<0000co`0co`0023?o00030000<ol0<ol002Hco`000`0003?o03?o000^<ol0B?ooo`00Cooo
ob@co`000`0003?o03?o0002<ol00P0000@co`000`0003?o03?o000><ol00P0000@co`0200000c?o
00@00002<ol01@00008co`000`0003?o03?o000^<ol0B?ooo`00Coooob@co`001@0003?o03?o03?o
00000002<ol000<0000co`0co`000S?o00030000<ol0<ol000Dco`0400000c?o00040000<ol0<ol0
000023?o00030000<ol0<ol000Dco`000`0003?o03?o0002<ol000<0000co`0co`00;S?o04Soool0
04oooolS<ol000<0000co`0co`000S?o00030000<ol0<ol001@co`00100003?o03?o000000Tco`00
0`0003?o03?o0004<ol000<0000co`0co`000c?o00030000<ol0<ol002dco`18oooo001@oooo8c?o
00030000<ol0<ol000D0000C<ol000@0000co`0co`00000:<ol000<0000co`0co`000c?o00030000
<ol0<ol0008co`000`0003?o03?o000^<ol0B?ooo`00D?ooob<co`001@0003?o03?o03?o0000000F
<ol000@0000co`0co`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000S?o00030000
<ol0<ol002hco`18oooo001@oooo93?o00030000<ol0<ol001Pco`0200002S?o00800004<ol00P00
00<co`000`0003?o03?o000_<ol0B?ooo`00DOooohLco`18oooo001AooooQc?o04Soool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.31875 .30902 L
.32392 .30902 L
.32617 .30902 L
.32728 .30902 L
.32831 .30902 L
s
.32831 .30902 m
.32832 .61803 L
s
0 .4 1 r
.02381 .33399 m
.06244 .33785 L
.10458 .34274 L
.14415 .34809 L
.18221 .35404 L
.22272 .36138 L
.26171 .36959 L
.28158 .37427 L
.30316 .37976 L
.31323 .38248 L
.31875 .38402 L
.32392 .38549 L
.32617 .38614 L
.32728 .38646 L
.32831 .38676 L
.32949 .30902 L
.33078 .30902 L
.33187 .30902 L
.33304 .30902 L
.33434 .30902 L
.33508 .30902 L
.33575 .30902 L
.33699 .30902 L
.33831 .30902 L
.33949 .30902 L
.34059 .30902 L
.34179 .30902 L
.34309 .30902 L
.3443 .30902 L
.345 .30902 L
.34565 .30902 L
.34632 .30902 L
.34705 .30902 L
.34837 .30902 L
.34951 .30902 L
.35075 .30902 L
.35205 .30902 L
.35326 .30902 L
.35395 .30902 L
.3547 .30902 L
.35536 .30902 L
.35606 .30902 L
.35669 .30902 L
.35739 .30902 L
.35861 .30902 L
.35935 .30902 L
.36003 .30902 L
.36082 .30902 L
.36156 .30902 L
.36288 .30902 L
Mistroke
.36363 .30902 L
.36433 .30902 L
.36559 .30902 L
.3663 .30902 L
.36696 .30902 L
.36817 .30902 L
.36944 .30902 L
.37058 .30902 L
.37165 .30902 L
.37282 .30902 L
.37407 .30902 L
.37477 .30902 L
.37541 .30902 L
.37611 .30902 L
.37686 .30902 L
.37812 .30902 L
.37883 .30902 L
.3795 .30902 L
.38074 .30902 L
.38188 .30902 L
.38313 .30902 L
.38445 .30902 L
.38569 .30902 L
.38639 .30902 L
.38703 .30902 L
.38821 .30902 L
.38946 .30902 L
.39059 .30902 L
.39163 .30902 L
.39278 .30902 L
.39402 .30902 L
.39533 .30902 L
.39602 .30902 L
.39676 .30902 L
.3974 .30902 L
.39811 .30902 L
.39936 .30902 L
.40056 .30902 L
.40187 .30902 L
.4031 .30902 L
.40423 .30902 L
.4053 .30902 L
.40644 .30902 L
.40752 .30902 L
.4085 .30902 L
.40965 .30902 L
.4109 .30902 L
.41209 .30902 L
.41318 .30902 L
.41423 .30902 L
Mistroke
.41536 .30902 L
.4166 .30902 L
.41776 .30902 L
.41905 .30902 L
.42029 .30902 L
.4214 .30902 L
.42261 .30902 L
.42325 .30902 L
.42394 .30902 L
.42516 .30902 L
.42648 .30902 L
.42724 .30902 L
.42793 .30902 L
.42918 .30902 L
.42987 .30902 L
.43052 .30902 L
.43168 .30902 L
.43293 .30902 L
.43406 .30902 L
.43529 .30902 L
.43659 .30902 L
.4378 .30902 L
.43893 .30902 L
.43996 .30902 L
.4411 .30902 L
.44229 .30902 L
.44361 .30902 L
.44481 .30902 L
.44547 .30902 L
.44619 .30902 L
.44749 .30902 L
.44871 .30902 L
.45 .30902 L
.4511 .30902 L
.45232 .30902 L
.45305 .30902 L
.45374 .30902 L
.45505 .30902 L
.45577 .30902 L
.45645 .30902 L
.45719 .30902 L
.45798 .30902 L
.45867 .30902 L
.45941 .30902 L
.46011 .30902 L
.46076 .30902 L
.46198 .30902 L
.46327 .30902 L
.4645 .30902 L
.46519 .30902 L
Mistroke
.46583 .30902 L
.46701 .30902 L
.46825 .30902 L
.46937 .30902 L
.47041 .30902 L
.47155 .30902 L
.47279 .30902 L
.47409 .30902 L
.47482 .30902 L
.47551 .30902 L
.47676 .30902 L
.47746 .30902 L
.4781 .30902 L
.4793 .30902 L
.4806 .30902 L
.48183 .30902 L
.48296 .30902 L
.48403 .30902 L
.48516 .30902 L
.48624 .30902 L
.48722 .30902 L
.48837 .30902 L
.48962 .30902 L
.49079 .30902 L
.49189 .30902 L
.49301 .30902 L
.49406 .30902 L
.49521 .30902 L
.49646 .30902 L
.49769 .30902 L
.49899 .30902 L
.5001 .30902 L
.50132 .30902 L
.50263 .30902 L
.50385 .30902 L
.50454 .30902 L
.50518 .30902 L
.50586 .30902 L
.5066 .30902 L
.50785 .30902 L
.509 .30902 L
.50963 .30902 L
.51033 .30902 L
.51158 .30902 L
.51281 .30902 L
.51393 .30902 L
.51522 .30902 L
.51643 .30902 L
.51755 .30902 L
.51859 .30902 L
Mistroke
.51972 .30902 L
.52092 .30902 L
.52222 .30902 L
.52341 .30902 L
.5247 .30902 L
.52542 .30902 L
.52609 .30902 L
.52729 .30902 L
.52856 .30902 L
.52968 .30902 L
.53091 .30902 L
.5316 .30902 L
.53233 .30902 L
.53363 .30902 L
.53437 .30902 L
.53515 .30902 L
.53589 .30902 L
.53656 .30902 L
.53787 .30902 L
.5391 .30902 L
.53979 .30902 L
.54043 .30902 L
.54112 .30902 L
.54186 .30902 L
.54308 .30902 L
.5444 .30902 L
.54565 .30902 L
.54681 .30902 L
.54785 .30902 L
.54899 .30902 L
.55019 .30902 L
.55132 .30902 L
.55256 .30902 L
.55387 .30902 L
.55498 .30902 L
.5562 .30902 L
.55752 .30902 L
.55824 .30902 L
.55893 .30902 L
.55957 .30902 L
.56026 .30902 L
.56147 .30902 L
.56261 .30902 L
.56367 .30902 L
.56484 .30902 L
.56609 .30902 L
.56741 .30902 L
.56865 .30902 L
.56977 .30902 L
.571 .30902 L
Mistroke
.57216 .30902 L
.5732 .30902 L
.57442 .30902 L
.57556 .30902 L
.57662 .30902 L
.57759 .30902 L
.57979 .30902 L
.60022 .30902 L
.60141 .30902 L
.60267 .30902 L
.60333 .30902 L
.60406 .30902 L
.60534 .30902 L
.60655 .30902 L
.60784 .30902 L
.60907 .30902 L
.61019 .30902 L
.61129 .30902 L
.61231 .30902 L
.61343 .30902 L
.61462 .30902 L
.61588 .30902 L
.61707 .30902 L
.61813 .30902 L
.61929 .30902 L
.62044 .30902 L
.62168 .30902 L
.62285 .30902 L
.62392 .30902 L
.62504 .30902 L
.62626 .30902 L
.62757 .30902 L
.62883 .30902 L
.63104 .30902 L
.63225 .30902 L
.63339 .30902 L
.63446 .30902 L
.63561 .30902 L
.63666 .30902 L
.63762 .30902 L
.63876 .30902 L
.63998 .30902 L
.64113 .30902 L
.64218 .30902 L
.64341 .30902 L
.64411 .30902 L
.64475 .30902 L
.64593 .30902 L
.64718 .30902 L
.64837 .30902 L
Mistroke
.64966 .30902 L
.65087 .30902 L
.65198 .30902 L
.65327 .30902 L
.65401 .30902 L
.65469 .30902 L
.65594 .30902 L
.65663 .30902 L
.65727 .30902 L
.65847 .30902 L
.65959 .30902 L
.66081 .30902 L
.66213 .30902 L
.66279 .30902 L
.66351 .30902 L
.66482 .30902 L
.6661 .30902 L
.66728 .30902 L
.66837 .30902 L
.6694 .30902 L
.67062 .30902 L
.67175 .30902 L
.67286 .30902 L
.67403 .30902 L
.6753 .30902 L
.67649 .30902 L
.6778 .30902 L
.67898 .30902 L
.68026 .30902 L
.68098 .30902 L
.68164 .30902 L
.68284 .30902 L
.68397 .30902 L
.68514 .30902 L
.68643 .30902 L
.6871 .30902 L
.68784 .30902 L
.68853 .30902 L
.68917 .30902 L
.69038 .30902 L
.69167 .30902 L
.69241 .30902 L
.6932 .30902 L
.69394 .30902 L
.69463 .30902 L
.69593 .30902 L
.69659 .30902 L
.69731 .30902 L
.69862 .30902 L
.69982 .30902 L
Mistroke
.70045 .30902 L
.70115 .30902 L
.70188 .30902 L
.70256 .30902 L
.70381 .30902 L
.70495 .30902 L
.70621 .30902 L
.70753 .30902 L
.70864 .30902 L
.70983 .30902 L
.71096 .30902 L
.71198 .30902 L
.71318 .30902 L
.71448 .30902 L
.71571 .30902 L
.71684 .30902 L
.71805 .30902 L
.71934 .30902 L
.72056 .30902 L
.72168 .30902 L
.72299 .30902 L
.72373 .30902 L
.72441 .30902 L
.72567 .30902 L
.72637 .30902 L
.727 .30902 L
.72768 .30902 L
.72839 .30902 L
.72967 .30902 L
.73038 .30902 L
.73104 .30902 L
.73177 .30902 L
.73255 .30902 L
.73322 .30902 L
.73395 .30902 L
.73464 .30902 L
.73528 .30902 L
.73648 .30902 L
.73776 .30902 L
.73896 .30902 L
.74028 .30902 L
.74152 .30902 L
.74267 .30902 L
.74381 .30902 L
.74485 .30902 L
.74598 .30902 L
.74717 .30902 L
.74847 .30902 L
.74967 .30902 L
.75096 .30902 L
Mistroke
.7517 .30902 L
.75238 .30902 L
.75362 .30902 L
.75475 .30902 L
.75606 .30902 L
.75729 .30902 L
.75834 .30902 L
.7595 .30902 L
.76071 .30902 L
.76184 .30902 L
.7629 .30902 L
.76387 .30902 L
.76493 .30902 L
.76606 .30902 L
.7672 .30902 L
.76841 .30902 L
.76956 .30902 L
.77061 .30902 L
.77184 .30902 L
.77253 .30902 L
.77317 .30902 L
.77435 .30902 L
.77559 .30902 L
.7768 .30902 L
.77812 .30902 L
.77936 .30902 L
.78052 .30902 L
.78166 .30902 L
.7827 .30902 L
.7839 .30902 L
.78502 .30902 L
.78626 .30902 L
.78756 .30902 L
.7899 .30902 L
.79516 .30902 L
.81347 .30902 L
.85149 .30902 L
.89196 .30902 L
.93092 .30902 L
.97233 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0c
o`00;c?o00030000<ol0<ol001/co`000`1Voc?o03?o000A<ol000<0000co`0co`00;S?o00030000
<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Ooooe0co`000`1Voc?o
03?o001d<ol000<0003oooooool0AOooo`004Ooooe0co`000`1Voc?o03?o001d<ol000<0003ooooo
ool0AOooo`004Ooooe0co`000`1Voc?o03?o001d<ol000<0003oooooool0AOooo`004Ooooe0co`00
0`1Voc?o03?o001d<ol000<0003oooooool0AOooo`004Oooo`H0I_m:<ol000<0I_lco`0co`00M3?o
00030000oooooooo04Goool0017oool6<ol02P1Vod0co`000`1Voc?o03?o001d<ol00P0004Koool0
017oool@<ol02`1VocDco`000`1Voc?o03?o001d<ol000<0003oooooool0AOooo`004Ooooa/co`08
06Ko;C?o000306Ko<ol0<ol007@co`000`000?ooooooo`15oooo000Aoooo8c?o00D0I_lX<ol000<0
I_lco`0co`00M3?o00030000oooooooo04Goool0017ooolX<ol01@1Vob<co`000`1Voc?o03?o001d
<ol000<0003oooooool0AOooo`004Oooobdco`0506Ko7S?o000306Ko<ol0<ol007@co`000`000?oo
ooooo`15oooo000Aoooo<S?o00D0I_lI<ol000<0I_lco`0co`00M3?o00030000oooooooo04Goool0
017ooolg<ol01@1Voa@co`000`1Voc?o03?o001d<ol000<0003oooooool0AOooo`004Oooo`80000j
<ol01@1Vo`lco`000`1Voc?o03?o001d<ol00P0004Koool001?oool20000?C?o00D0I_l:<ol000<0
I_lco`0co`00M3?o00030000oooooooo04Goool001Goool20000@3?o0080I_l8<ol000<0I_lco`0c
o`00M3?o00030000oooooooo04Goool001Ooool20000@3?o00D0I_l3<ol000<0I_lco`0co`00M3?o
00030000oooooooo04Goool001Woool20000@c?o00@0I_mf<ol000<0003oooooool0AOooo`006ooo
o`800014<ol000?o09Tco`0co`00M3?o00030000oooooooo04Goool001goool20000@S?o0003o`2I
<ol0<ol007@co`000`000?ooooooo`15oooo000Ooooo00<0000co`0co`00?c?o0003o`2I<ol0<ol0
07@co`000`000?ooooooo`15oooo000Poooo00<0000co`0co`00?S?o0003o`2I<ol0<ol007@co`02
0000A_ooo`008Oooo`80000n<ol000?o09Tco`0co`00M3?o00030000oooooooo04Goool002?oool0
0`0003?o03?o000k<ol000?o09Tco`0co`00M3?o00030000oooooooo04Goool002Coool20000>c?o
0003o`2I<ol0<ol007@co`000`000?ooooooo`15oooo000Voooo00<0000co`0co`00>3?o0003o`2I
<ol0<ol007@co`000`000?ooooooo`15oooo000Woooo00<0000co`0co`00=c?o0003o`2I<ol0<ol0
07@co`000`000?ooooooo`15oooo000Xoooo00<0000co`0co`00=S?o0003o`2I<ol0<ol005/co`02
000013?o00800004<ol00P0000<co`04000013?o00030000oooooooo04Goool002Woool00`0003?o
03?o000e<ol000?o09Tco`0co`00FS?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o
00030000<ol0<ol000Dco`000`000?ooooooo`15oooo000Zoooo00<0000co`0co`00=3?o0003o`2I
<ol0<ol005Xco`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o0004
<ol00`0004Goool002_oool20000=3?o0003o`2I<ol0<ol005Xco`00100003?o03?o000000Pco`00
100003?o03?o000000@co`000`0003?o03?o0003<ol000<0003oooooool0AOooo`00;Oooo`030000
<ol0<ol0034co`000ol0VC?o03?o001J<ol000@0000co`0co`000008<ol000@0000co`0co`000002
<ol000@0000co`0co`000004<ol000<0003oooooool0AOooo`00;_ooo`030000<ol0<ol0030co`00
0ol0VC?o03?o001K<ol00P0000Xco`02000013?o00800005<ol000<0003oooooool0AOooo`00;ooo
o`030000<ol0<ol002lco`000ol0VC?o03?o001d<ol000<0003oooooool0AOooo`00<?ooo`030000
<ol0<ol002hco`000ol0VC?o03?o001d<ol000<0003oooooool0AOooo`00<Oooo`030000<ol0<ol0
02dco`000ol0VC?o03?o001d<ol000<0003oooooool0AOooo`00<_ooo`030000<ol0<ol002`co`00
0ol0VC?o03?o001d<ol000<0003oooooool0AOooo`00<oooo`030000<ol0<ol002/co`000ol0VC?o
03?o001d<ol00P0004Koool003?oool00`0003?o03?o000[<ol000?o09Tco`0co`00M3?o00030000
oooooooo04Goool003Coool00`0003?o03?o000Z<ol000?o09Tco`0co`00M3?o00030000oooooooo
04Goool003Goool00`0003?o03?o000Y<ol000?o09Tco`0co`00M3?o00030000oooooooo04Goool0
03Koool00`0003?o03?o000X<ol000?o09Tco`0co`00M3?o00030000oooooooo04Goool003Ooool0
0`0003?o03?o000W<ol000?o09Tco`0co`00M3?o00030000oooooooo04Goool003Soool00`0003?o
03?o000V<ol000?o09Tco`0co`00M3?o00030000oooooooo04Goool003Soool00`0003?o03?o000V
<ol000?o09Tco`0co`00M3?o00030000oooooooo04Goool003Woool00`0003?o03?o000U<ol000?o
09Tco`0co`00M3?o00800016oooo000joooo00<0000co`0co`0093?o0003o`2I<ol0<ol007@co`00
0`000?ooooooo`15oooo000koooo00<0000co`0co`008c?o0003o`2I<ol0<ol007@co`000`000?oo
ooooo`15oooo000loooo00<0000co`0co`008S?o0003o`2I<ol0<ol007@co`000`000?ooooooo`15
oooo000loooo00<0000co`0co`008S?o0003o`2I<ol0<ol007@co`000`000?ooooooo`15oooo000m
oooo00<0000co`0co`008C?o0003o`2I<ol0<ol007@co`000`000?ooooooo`15oooo000moooo00<0
000co`0co`008C?o0003o`2I<ol0<ol007@co`000`000?ooooooo`15oooo000noooo00<0000co`0c
o`0083?o0003o`2I<ol0<ol007@co`000`000?ooooooo`15oooo000noooo00<0000co`0co`0083?o
0003o`2I<ol0<ol007@co`000`000?ooooooo`15oooo000ooooo00<0000co`0co`007c?o0003o`2I
<ol0<ol007@co`020000A_ooo`00?oooo`030000<ol0<ol001lco`000ol0VC?o03?o001d<ol000<0
003oooooool0AOooo`00@?ooo`030000<ol0<ol001hco`000ol0VC?o03?o001d<ol000<0003ooooo
ool0AOooo`00@Oooo`030000<ol0<ol001dco`000ol0VC?o03?o001d<ol000<0003oooooool0AOoo
o`00@Oooo`030000<ol0<ol001dco`000ol0VC?o03?o001d<ol000<0003oooooool0AOooo`00@_oo
o`030000<ol0<ol001`co`000ol0VC?o03?o001d<ol000<0003oooooool0AOooo`00@_ooo`030000
<ol0<ol001`co`000ol0VC?o03?o001K<ol00P0000@co`02000013?o00800005<ol00`0000<co`00
0`000?ooooooo`15oooo0013oooo00<0000co`0co`006c?o0003o`2I<ol0<ol005Xco`00100003?o
03?o000000Pco`00100003?o03?o000000Dco`000`0003?o03?o0002<ol000<0003oooooool0AOoo
o`00@oooo`030000<ol0<ol001/co`000ol0VC?o03?o001J<ol000@0000co`0co`000008<ol000@0
000co`0co`000002<ol01@0000<co`030000AOooo`00A?ooo`030000<ol0<ol001Xco`000ol0VC?o
03?o001J<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000004
<ol000<0003oooooool0AOooo`00A?ooo`030000<ol0<ol001Xco`000ol0VC?o03?o001J<ol000@0
000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`00000013?o00030000oooooooo
04Goool004Goool00`0003?o03?o000I<ol000?o09Tco`0co`00Fc?o0080000:<ol00P0000Dco`02
000013?o00030000oooooooo04Goool004Goool00`0003?o03?o000I<ol000?o09Tco`0co`00M3?o
00030000oooooooo04Goool004Koool00`0003?o03?o000H<ol000?o09Tco`0co`00M3?o00030000
oooooooo04Goool004Koool00`0003?o03?o000H<ol000?o09Tco`0co`00M3?o00030000oooooooo
04Goool004Ooool00`0003?o03?o000G<ol000?o09Tco`0co`00M3?o00030000oooooooo04Goool0
04Ooool00`0003?o03?o000G<ol000?o09Tco`0co`00M3?o00800016oooo0018oooo00<0000co`0c
o`005S?o0003o`2I<ol0<ol007@co`000`000?ooooooo`15oooo0018oooo00<0000co`0co`005S?o
0003o`2I<ol0<ol007@co`000`000?ooooooo`15oooo0019oooo00<0000co`0co`005C?o0003o`2I
<ol0<ol007@co`000`000?ooooooo`15oooo0019oooo00<0000co`0co`005C?o0003o`2I<ol0<ol0
07@co`000`000?ooooooo`15oooo001:oooo00<0000co`0co`0053?o0003o`2I<ol0<ol007@co`00
0`000?ooooooo`15oooo001:oooo00<0000co`0co`0053?o0003o`2I<ol0<ol007@co`000`000?oo
ooooo`15oooo001;oooo00<0000co`0co`004c?o0003o`2I<ol0<ol007@co`000`000?ooooooo`15
oooo001;oooo00<0000co`0co`004c?o0003o`2I<ol0<ol007@co`020000A_ooo`00C?oooh`co`18
oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00COoooh/co`18oooo001=ooooRc?o04Soool0
04kooolY<ol000<0000co`0co`00:C?o00030000<ol0<ol0038co`18oooo001>oooo:3?o00030000
<ol0<ol000Pco`000`0003?o03?o000P<ol000<0000co`0co`00<C?o04Soool004oooolW<ol000<0
000co`0co`000S?o00800004<ol000<0000co`0co`003S?o00800004<ol00P0000<co`0400000c?o
00030000<ol0<ol0034co`18oooo001?oooo9c?o00050000<ol0<ol0<ol00000008co`000`0003?o
03?o0002<ol000<0000co`0co`001C?o00@00003<ol000@0000co`0co`000008<ol000<0000co`0c
o`0013?o00030000<ol0<ol0034co`18oooo001?oooo9S?o00030000<ol0<ol0008co`000`0003?o
03?o000D<ol000@0000co`0co`000009<ol000<0000co`0co`0013?o00030000<ol0<ol0030co`18
oooo001@oooo9S?o00030000<ol0<ol000D0000C<ol000@0000co`0co`00000:<ol000<0000co`0c
o`000S?o00030000<ol0<ol0034co`18oooo001@oooo9S?o00050000<ol0<ol0<ol0000001Hco`00
100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o000a<ol0B?ooo`00D?oo
obLco`000`0003?o03?o000H<ol00P0000Xco`0200000c?o00030000<ol0<ol0038co`18oooo001A
ooooQc?o04Soool0057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.19) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.31875 .30902 L
.32392 .30902 L
.32831 .30902 L
.32958 .30902 L
.33078 .30902 L
.33186 .30902 L
s
.33186 .30902 m
.33187 .61803 L
s
0 .4 1 r
.02381 .33271 m
.06244 .33637 L
.10458 .34101 L
.14415 .34609 L
.18221 .35173 L
.22272 .3587 L
.26171 .36649 L
.28158 .37093 L
.30316 .37613 L
.31323 .37872 L
.31875 .38018 L
.32392 .38157 L
.32831 .38278 L
.32958 .38313 L
.33078 .38346 L
.33186 .38377 L
.33304 .30902 L
.33436 .30902 L
.33556 .30902 L
.33825 .30902 L
.33946 .30902 L
.34075 .30902 L
.34197 .30902 L
.34309 .30902 L
.34428 .30902 L
.34541 .30902 L
.34663 .30902 L
.34732 .30902 L
.34796 .30902 L
.34915 .30902 L
.35046 .30902 L
.35111 .30902 L
.35182 .30902 L
.35311 .30902 L
.35423 .30902 L
.35545 .30902 L
.35673 .30902 L
.35792 .30902 L
.35904 .30902 L
.36005 .30902 L
.36123 .30902 L
.36233 .30902 L
.36353 .30902 L
.36486 .30902 L
.36552 .30902 L
.36624 .30902 L
.36753 .30902 L
.36881 .30902 L
.37003 .30902 L
.37113 .30902 L
Mistroke
.37232 .30902 L
.37306 .30902 L
.37375 .30902 L
.37504 .30902 L
.37577 .30902 L
.37644 .30902 L
.37717 .30902 L
.37794 .30902 L
.37922 .30902 L
.37995 .30902 L
.38062 .30902 L
.38185 .30902 L
.38315 .30902 L
.38437 .30902 L
.38552 .30902 L
.38677 .30902 L
.38748 .30902 L
.38813 .30902 L
.38918 .30902 L
.39033 .30902 L
.39154 .30902 L
.39265 .30902 L
.39329 .30902 L
.39398 .30902 L
.39524 .30902 L
.39645 .30902 L
.39758 .30902 L
.39879 .30902 L
.39948 .30902 L
.40013 .30902 L
.40143 .30902 L
.40216 .30902 L
.40283 .30902 L
.40396 .30902 L
.40517 .30902 L
.4062 .30902 L
.40734 .30902 L
.40856 .30902 L
.40987 .30902 L
.41111 .30902 L
.41225 .30902 L
.41332 .30902 L
.41432 .30902 L
.41542 .30902 L
.41659 .30902 L
.41765 .30902 L
.41877 .30902 L
.42001 .30902 L
.42118 .30902 L
.42187 .30902 L
Mistroke
.42252 .30902 L
.42376 .30902 L
.42507 .30902 L
.42581 .30902 L
.42649 .30902 L
.42774 .30902 L
.42887 .30902 L
.43017 .30902 L
.4314 .30902 L
.43205 .30902 L
.43274 .30902 L
.43399 .30902 L
.4353 .30902 L
.43605 .30902 L
.43673 .30902 L
.43747 .30902 L
.43827 .30902 L
.43903 .30902 L
.43974 .30902 L
.44037 .30902 L
.44107 .30902 L
.44181 .30902 L
.4425 .30902 L
.44367 .30902 L
.44496 .30902 L
.44561 .30902 L
.44631 .30902 L
.44756 .30902 L
.44881 .30902 L
.44999 .30902 L
.45105 .30902 L
.45219 .30902 L
.45345 .30902 L
.45417 .30902 L
.45483 .30902 L
.45554 .30902 L
.45618 .30902 L
.45693 .30902 L
.45763 .30902 L
.45887 .30902 L
.46003 .30902 L
.46129 .30902 L
.462 .30902 L
.46264 .30902 L
.46385 .30902 L
.46498 .30902 L
.46621 .30902 L
.46691 .30902 L
.46754 .30902 L
.46881 .30902 L
Mistroke
.46953 .30902 L
.47019 .30902 L
.47141 .30902 L
.4727 .30902 L
.47379 .30902 L
.47497 .30902 L
.47608 .30902 L
.4771 .30902 L
.47828 .30902 L
.47958 .30902 L
.4808 .30902 L
.48194 .30902 L
.48325 .30902 L
.48399 .30902 L
.48466 .30902 L
.48591 .30902 L
.48723 .30902 L
.48833 .30902 L
.48952 .30902 L
.49081 .30902 L
.49203 .30902 L
.49274 .30902 L
.49341 .30902 L
.49414 .30902 L
.49491 .30902 L
.49621 .30902 L
.49695 .30902 L
.49765 .30902 L
.49894 .30902 L
.50012 .30902 L
.50141 .30902 L
.50207 .30902 L
.50278 .30902 L
.5041 .30902 L
.50531 .30902 L
.50595 .30902 L
.50665 .30902 L
.50738 .30902 L
.50806 .30902 L
.50932 .30902 L
.51046 .30902 L
.5111 .30902 L
.51179 .30902 L
.51305 .30902 L
.51428 .30902 L
.51539 .30902 L
.51668 .30902 L
.51789 .30902 L
.51892 .30902 L
.52003 .30902 L
Mistroke
.52125 .30902 L
.52238 .30902 L
.52307 .30902 L
.52372 .30902 L
.52493 .30902 L
.52763 .30902 L
.52875 .30902 L
.52994 .30902 L
.53124 .30902 L
.53245 .30902 L
.53373 .30902 L
.53446 .30902 L
.53512 .30902 L
.53634 .30902 L
.53762 .30902 L
.53831 .30902 L
.53904 .30902 L
.54035 .30902 L
.54115 .30902 L
.54191 .30902 L
.54259 .30902 L
.54333 .30902 L
.54456 .30902 L
.54569 .30902 L
.547 .30902 L
.54823 .30902 L
.54937 .30902 L
.55042 .30902 L
.55158 .30902 L
.55281 .30902 L
.55404 .30902 L
.55473 .30902 L
.55536 .30902 L
.55653 .30902 L
.55776 .30902 L
.55841 .30902 L
.55912 .30902 L
.56041 .30902 L
.56118 .30902 L
.56189 .30902 L
.56254 .30902 L
.56323 .30902 L
.56451 .30902 L
.56571 .30902 L
.56702 .30902 L
.5677 .30902 L
.56844 .30902 L
.56973 .30902 L
.57097 .30902 L
.57217 .30902 L
Mistroke
.57328 .30902 L
.57397 .30902 L
.57472 .30902 L
.57543 .30902 L
.57608 .30902 L
.57731 .30902 L
.57861 .30902 L
.57929 .30902 L
.58001 .30902 L
.58132 .30902 L
.58211 .30902 L
.58287 .30902 L
.58355 .30902 L
.58429 .30902 L
.5855 .30902 L
.58662 .30902 L
.58785 .30902 L
.58914 .30902 L
.59026 .30902 L
.59131 .30902 L
.59246 .30902 L
.59369 .30902 L
.59439 .30902 L
.59503 .30902 L
.59574 .30902 L
.59649 .30902 L
.59774 .30902 L
.59846 .30902 L
.59913 .30902 L
.60037 .30902 L
.60151 .30902 L
.60282 .30902 L
.60407 .30902 L
.60475 .30902 L
.60539 .30902 L
.60659 .30902 L
.60789 .30902 L
.60862 .30902 L
.60928 .30902 L
.61041 .30902 L
.61164 .30902 L
.61292 .30902 L
.61412 .30902 L
.6148 .30902 L
.61554 .30902 L
.61624 .30902 L
.61689 .30902 L
.61811 .30902 L
.61941 .30902 L
.62008 .30902 L
Mistroke
.6208 .30902 L
.62211 .30902 L
.6229 .30902 L
.62366 .30902 L
.62434 .30902 L
.62508 .30902 L
.62572 .30902 L
.6264 .30902 L
.62762 .30902 L
.62894 .30902 L
.62968 .30902 L
.63038 .30902 L
.63164 .30902 L
.63279 .30902 L
.63343 .30902 L
.63412 .30902 L
.63538 .30902 L
.6365 .30902 L
.63774 .30902 L
.63903 .30902 L
.64024 .30902 L
.64129 .30902 L
.6424 .30902 L
.64362 .30902 L
.64473 .30902 L
.64604 .30902 L
.64724 .30902 L
.6479 .30902 L
.64861 .30902 L
.64992 .30902 L
.65113 .30902 L
.65243 .30902 L
.65353 .30902 L
.65474 .30902 L
.65541 .30902 L
.65614 .30902 L
.65683 .30902 L
.65747 .30902 L
.65821 .30902 L
.659 .30902 L
.65973 .30902 L
.6604 .30902 L
.66171 .30902 L
.66245 .30902 L
.66313 .30902 L
.66438 .30902 L
.6657 .30902 L
.66692 .30902 L
.66761 .30902 L
.66825 .30902 L
Mistroke
.66942 .30902 L
.67066 .30902 L
.67177 .30902 L
.67282 .30902 L
.67396 .30902 L
.67519 .30902 L
.67642 .30902 L
.67712 .30902 L
.67777 .30902 L
.67909 .30902 L
.67983 .30902 L
.68049 .30902 L
.6817 .30902 L
.683 .30902 L
.68422 .30902 L
.68536 .30902 L
.68641 .30902 L
.68755 .30902 L
.68862 .30902 L
.6896 .30902 L
.69075 .30902 L
.692 .30902 L
.69318 .30902 L
.69427 .30902 L
.6955 .30902 L
.69667 .30902 L
.69771 .30902 L
.69884 .30902 L
.70007 .30902 L
.70137 .30902 L
.70248 .30902 L
.7037 .30902 L
.70501 .30902 L
.70622 .30902 L
.70685 .30902 L
.70755 .30902 L
.70828 .30902 L
.70896 .30902 L
.71022 .30902 L
.71136 .30902 L
.71199 .30902 L
.71268 .30902 L
.71394 .30902 L
.71517 .30902 L
.71628 .30902 L
.71757 .30902 L
.71878 .30902 L
.7199 .30902 L
.72093 .30902 L
.72207 .30902 L
Mistroke
.72327 .30902 L
.72454 .30902 L
.72576 .30902 L
.72642 .30902 L
.72715 .30902 L
.72843 .30902 L
.72964 .30902 L
.73093 .30902 L
.73203 .30902 L
.73325 .30902 L
.73394 .30902 L
.73466 .30902 L
.73596 .30902 L
.73664 .30902 L
.73736 .30902 L
.73816 .30902 L
.7389 .30902 L
.73958 .30902 L
.74033 .30902 L
.74103 .30902 L
.74167 .30902 L
.7429 .30902 L
.7442 .30902 L
.74541 .30902 L
.74673 .30902 L
.74798 .30902 L
.74913 .30902 L
.75145 .30902 L
.75259 .30902 L
.75363 .30902 L
.75487 .30902 L
.75552 .30902 L
.75621 .30902 L
.75732 .30902 L
.75854 .30902 L
.75985 .30902 L
.76058 .30902 L
.76125 .30902 L
.76255 .30902 L
.76377 .30902 L
.76483 .30902 L
.76582 .30902 L
.76684 .30902 L
.76797 .30902 L
.76911 .30902 L
.77032 .30902 L
.77145 .30902 L
.77248 .30902 L
.77371 .30902 L
.7744 .30902 L
Mistroke
.77503 .30902 L
.7762 .30902 L
.77744 .30902 L
.7786 .30902 L
.77984 .30902 L
.78101 .30902 L
.78208 .30902 L
.78322 .30902 L
.78445 .30902 L
.78562 .30902 L
.78669 .30902 L
.78786 .30902 L
.78915 .30902 L
.79176 .30902 L
.80203 .30902 L
.82046 .30902 L
.86063 .30902 L
.89928 .30902 L
.94038 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.19) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
0000I_lco`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0c
o`00;c?o00030000<ol0<ol001`co`000`1Voc?o03?o000@<ol000<0000co`0co`00;S?o00030000
<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Ooooe4co`000`1Voc?o
03?o001c<ol000<0003oooooool0AOooo`004Ooooe4co`000`1Voc?o03?o001c<ol000<0003ooooo
ool0AOooo`004Ooooe4co`000`1Voc?o03?o001c<ol000<0003oooooool0AOooo`004Oooo`H0I_m;
<ol000<0I_lco`0co`00Lc?o00030000oooooooo04Goool0017oool6<ol02P1Vod4co`000`1Voc?o
03?o001c<ol000<0003oooooool0AOooo`004Ooooa0co`0806Ko>C?o000306Ko<ol0<ol007<co`02
0000A_ooo`004OoooaPco`0606Ko<c?o000306Ko<ol0<ol007<co`000`000?ooooooo`15oooo000A
oooo7S?o00L0I_l/<ol000<0I_lco`0co`00Lc?o00030000oooooooo04Goool0017ooolU<ol0201V
ob@co`000`1Voc?o03?o001c<ol000<0003oooooool0AOooo`004Oooobdco`0506Ko7c?o000306Ko
<ol0<ol007<co`000`000?ooooooo`15oooo000Aoooo<S?o00D0I_lJ<ol000<0I_lco`0co`00Lc?o
00030000oooooooo04Goool0017ooolg<ol01@1VoaDco`000`1Voc?o03?o001c<ol000<0003ooooo
ool0AOooo`004Ooooc`co`0506Ko43?o000306Ko<ol0<ol007<co`000`000?ooooooo`15oooo000A
oooo0P0003lco`0506Ko2c?o000306Ko<ol0<ol007<co`020000A_ooo`004oooo`800012<ol00P1V
o`Tco`000`1Voc?o03?o001c<ol000<0003oooooool0AOooo`005Oooo`800012<ol01@1Vo`@co`00
0`1Voc?o03?o001c<ol000<0003oooooool0AOooo`005oooo`800015<ol01@1VogDco`000`000?oo
ooooo`15oooo000Ioooo0P0004Hco`0206KoMC?o00030000oooooooo04Goool001_oool20000AC?o
0003o`2I<ol0<ol007<co`000`000?ooooooo`15oooo000Moooo0P0004<co`000ol0VC?o03?o001c
<ol000<0003oooooool0AOooo`007oooo`030000<ol0<ol0040co`000ol0VC?o03?o001c<ol000<0
003oooooool0AOooo`008?ooo`030000<ol0<ol003lco`000ol0VC?o03?o001c<ol00P0004Koool0
027oool20000?c?o0003o`2I<ol0<ol007<co`000`000?ooooooo`15oooo000Soooo00<0000co`0c
o`00?3?o0003o`2I<ol0<ol007<co`000`000?ooooooo`15oooo000Toooo0P0003`co`000ol0VC?o
03?o001c<ol000<0003oooooool0AOooo`009_ooo`030000<ol0<ol003Tco`000ol0VC?o03?o001c
<ol000<0003oooooool0AOooo`009oooo`030000<ol0<ol003Pco`000ol0VC?o03?o001c<ol000<0
003oooooool0AOooo`00:?ooo`030000<ol0<ol003Lco`000ol0VC?o03?o001J<ol00P0000@co`02
000013?o00800003<ol0100000@co`000`000?ooooooo`15oooo000Yoooo00<0000co`0co`00=S?o
0003o`2I<ol0<ol005Tco`00100003?o03?o000000Pco`00100003?o03?o0000008co`000`0003?o
03?o0005<ol000<0003oooooool0AOooo`00:_ooo`030000<ol0<ol003Dco`000ol0VC?o03?o001I
<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00<00015
oooo000[oooo0P0003Dco`000ol0VC?o03?o001I<ol000@0000co`0co`000008<ol000@0000co`0c
o`000004<ol000<0000co`0co`000c?o00030000oooooooo04Goool002goool00`0003?o03?o000b
<ol000?o09Tco`0co`00FC?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000
<ol0<ol0000013?o00030000oooooooo04Goool002koool00`0003?o03?o000a<ol000?o09Tco`0c
o`00FS?o0080000:<ol00P0000@co`0200001C?o00030000oooooooo04Goool002ooool00`0003?o
03?o000`<ol000?o09Tco`0co`00Lc?o00030000oooooooo04Goool0033oool00`0003?o03?o000_
<ol000?o09Tco`0co`00Lc?o00030000oooooooo04Goool0037oool00`0003?o03?o000^<ol000?o
09Tco`0co`00Lc?o00030000oooooooo04Goool003;oool00`0003?o03?o000]<ol000?o09Tco`0c
o`00Lc?o00030000oooooooo04Goool003?oool00`0003?o03?o000/<ol000?o09Tco`0co`00Lc?o
00800016oooo000coooo00<0000co`0co`00;3?o0003o`2I<ol0<ol007<co`000`000?ooooooo`15
oooo000doooo00<0000co`0co`00:c?o0003o`2I<ol0<ol007<co`000`000?ooooooo`15oooo000e
oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol007<co`000`000?ooooooo`15oooo000foooo00<0
000co`0co`00:C?o0003o`2I<ol0<ol007<co`000`000?ooooooo`15oooo000goooo00<0000co`0c
o`00:3?o0003o`2I<ol0<ol007<co`000`000?ooooooo`15oooo000hoooo00<0000co`0co`009c?o
0003o`2I<ol0<ol007<co`000`000?ooooooo`15oooo000hoooo00<0000co`0co`009c?o0003o`2I
<ol0<ol007<co`000`000?ooooooo`15oooo000ioooo00<0000co`0co`009S?o0003o`2I<ol0<ol0
07<co`020000A_ooo`00>_ooo`030000<ol0<ol002Dco`000ol0VC?o03?o001c<ol000<0003ooooo
ool0AOooo`00>oooo`030000<ol0<ol002@co`000ol0VC?o03?o001c<ol000<0003oooooool0AOoo
o`00??ooo`030000<ol0<ol002<co`000ol0VC?o03?o001c<ol000<0003oooooool0AOooo`00??oo
o`030000<ol0<ol002<co`000ol0VC?o03?o001c<ol000<0003oooooool0AOooo`00?Oooo`030000
<ol0<ol0028co`000ol0VC?o03?o001c<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol0
028co`000ol0VC?o03?o001c<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol0024co`00
0ol0VC?o03?o001c<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol0024co`000ol0VC?o
03?o001c<ol000<0003oooooool0AOooo`00?oooo`030000<ol0<ol0020co`000ol0VC?o03?o001c
<ol00P0004Koool003ooool00`0003?o03?o000P<ol000?o09Tco`0co`00Lc?o00030000oooooooo
04Goool0043oool00`0003?o03?o000O<ol000?o09Tco`0co`00Lc?o00030000oooooooo04Goool0
047oool00`0003?o03?o000N<ol000?o09Tco`0co`00Lc?o00030000oooooooo04Goool0047oool0
0`0003?o03?o000N<ol000?o09Tco`0co`00Lc?o00030000oooooooo04Goool004;oool00`0003?o
03?o000M<ol000?o09Tco`0co`00Lc?o00030000oooooooo04Goool004;oool00`0003?o03?o000M
<ol000?o09Tco`0co`00FS?o00800004<ol00P0000@co`0200001C?o00<00003<ol000<0003ooooo
ool0AOooo`00@oooo`030000<ol0<ol001`co`000ol0VC?o03?o001I<ol000@0000co`0co`000008
<ol000@0000co`0co`000005<ol000<0000co`0co`000S?o00030000oooooooo04Goool004?oool0
0`0003?o03?o000L<ol000?o09Tco`0co`00FC?o00040000<ol0<ol0000023?o00040000<ol0<ol0
00000S?o00D00003<ol00`0004Goool004Coool00`0003?o03?o000K<ol000?o09Tco`0co`00FC?o
00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000
oooooooo04Goool004Coool00`0003?o03?o000K<ol000?o09Tco`0co`00FC?o00040000<ol0<ol0
000023?o00040000<ol0<ol000000c?o00030000<ol0000000@co`000`000?ooooooo`15oooo0015
oooo00<0000co`0co`006S?o0003o`2I<ol0<ol005Xco`0200002S?o00800005<ol00P0000@co`00
0`000?ooooooo`15oooo0015oooo00<0000co`0co`006S?o0003o`2I<ol0<ol007<co`000`000?oo
ooooo`15oooo0016oooo00<0000co`0co`006C?o0003o`2I<ol0<ol007<co`000`000?ooooooo`15
oooo0016oooo00<0000co`0co`006C?o0003o`2I<ol0<ol007<co`000`000?ooooooo`15oooo0017
oooo00<0000co`0co`0063?o0003o`2I<ol0<ol007<co`000`000?ooooooo`15oooo0017oooo00<0
000co`0co`0063?o0003o`2I<ol0<ol007<co`020000A_ooo`00B?ooo`030000<ol0<ol001Lco`00
0ol0VC?o03?o001c<ol000<0003oooooool0AOooo`00B?ooo`030000<ol0<ol001Lco`000ol0VC?o
03?o001c<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol001Hco`000ol0VC?o03?o001c
<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol001Hco`000ol0VC?o03?o001c<ol000<0
003oooooool0AOooo`00B_ooo`030000<ol0<ol001Dco`000ol0VC?o03?o001c<ol000<0003ooooo
ool0AOooo`00B_ooo`030000<ol0<ol001Dco`000ol0VC?o03?o001c<ol000<0003oooooool0AOoo
o`00Boooo`030000<ol0<ol001@co`000ol0VC?o03?o001c<ol000<0003oooooool0AOooo`00Booo
o`030000<ol0<ol001@co`000ol0VC?o03?o001c<ol00P0004Koool004cooon<<ol0B?ooo`00C?oo
oh`co`18oooo001<ooooS3?o04Soool004gooon;<ol0B?ooo`00COoooh/co`18oooo001>oooo9S?o
00030000<ol0<ol002lco`000`0003?o03?o000_<ol0B?ooo`00C_ooobDco`000`0003?o03?o0008
<ol000<0000co`0co`009S?o00030000<ol0<ol002hco`18oooo001?oooo93?o00030000<ol0<ol0
008co`02000013?o00030000<ol0<ol000hco`02000013?o00800003<ol01@000004<ol000000000
000013?o00030000<ol0<ol002hco`18oooo001?oooo93?o00050000<ol0<ol0<ol00000008co`00
0`0003?o03?o0002<ol000<0000co`0co`001C?o00@00003<ol000@0000co`0co`00000:<ol000<0
000co`0co`000c?o00030000<ol0<ol0008co`000`0003?o03?o000^<ol0B?ooo`00Coooob<co`00
0`0003?o03?o0002<ol000<0000co`0co`0053?o00040000<ol0<ol000002S?o00030000<ol0<ol0
008co`03000013?o00030000<ol0<ol002dco`18oooo001@oooo8c?o00030000<ol0<ol000D0000C
<ol000@0000co`0co`00000:<ol000D0000co`0co`0co`0000000S?o00050000<ol0<ol0<ol00000
030co`18oooo001@oooo8c?o00050000<ol0<ol0<ol0000001Hco`00100003?o03?o000000Xco`00
1@0003?o03?o03?o00000002<ol000D0000co`0co`0co`000000<3?o04Soool0053ooolT<ol000<0
000co`0co`0063?o0080000:<ol00P0000@co`0300000S?o00030000<ol0<ol002lco`18oooo001A
ooooQc?o04Soool0057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.32392 .30902 L
.32831 .30902 L
.33304 .30902 L
.33443 .30902 L
.33575 .30902 L
s
.33575 .30902 m
.33575 .61803 L
s
0 .4 1 r
.02381 .33144 m
.06244 .3349 L
.10458 .33929 L
.14415 .34409 L
.18221 .34944 L
.22272 .35603 L
.26171 .3634 L
.28158 .3676 L
.30316 .37252 L
.31323 .37497 L
.32392 .37767 L
.32831 .37881 L
.33304 .38006 L
.33443 .38043 L
.33575 .38079 L
.33693 .30902 L
.33823 .30902 L
.33945 .30902 L
.34075 .30902 L
.34197 .30902 L
.34309 .30902 L
.34429 .30902 L
.34541 .30902 L
.34609 .30902 L
.34674 .30902 L
.34796 .30902 L
.34915 .30902 L
.35044 .30902 L
.35112 .30902 L
.35183 .30902 L
.35311 .30902 L
.3542 .30902 L
.35537 .30902 L
.35648 .30902 L
.35749 .30902 L
.35862 .30902 L
.35985 .30902 L
.36114 .30902 L
.36233 .30902 L
.36363 .30902 L
.36437 .30902 L
.36504 .30902 L
.36629 .30902 L
.36761 .30902 L
.36878 .30902 L
.36989 .30902 L
.3711 .30902 L
.3724 .30902 L
.37311 .30902 L
.37378 .30902 L
Mistroke
.37451 .30902 L
.37528 .30902 L
.37602 .30902 L
.37672 .30902 L
.37802 .30902 L
.3793 .30902 L
.38049 .30902 L
.38178 .30902 L
.38244 .30902 L
.38315 .30902 L
.38446 .30902 L
.38567 .30902 L
.3863 .30902 L
.387 .30902 L
.38773 .30902 L
.38841 .30902 L
.38966 .30902 L
.3908 .30902 L
.39206 .30902 L
.39338 .30902 L
.3945 .30902 L
.39569 .30902 L
.39682 .30902 L
.39784 .30902 L
.39904 .30902 L
.40034 .30902 L
.40157 .30902 L
.4027 .30902 L
.40391 .30902 L
.40521 .30902 L
.40643 .30902 L
.40755 .30902 L
.40886 .30902 L
.4096 .30902 L
.41028 .30902 L
.41154 .30902 L
.41217 .30902 L
.41287 .30902 L
.41355 .30902 L
.41426 .30902 L
.41554 .30902 L
.41625 .30902 L
.41691 .30902 L
.41764 .30902 L
.41842 .30902 L
.41909 .30902 L
.41982 .30902 L
.42051 .30902 L
.42115 .30902 L
.42235 .30902 L
Mistroke
.42363 .30902 L
.42483 .30902 L
.42615 .30902 L
.42739 .30902 L
.42855 .30902 L
.42969 .30902 L
.43073 .30902 L
.43192 .30902 L
.43305 .30902 L
.43428 .30902 L
.43558 .30902 L
.4367 .30902 L
.43792 .30902 L
.43923 .30902 L
.43997 .30902 L
.44064 .30902 L
.44194 .30902 L
.44318 .30902 L
.44423 .30902 L
.44539 .30902 L
.4466 .30902 L
.44773 .30902 L
.44879 .30902 L
.44976 .30902 L
.45083 .30902 L
.45195 .30902 L
.45309 .30902 L
.45431 .30902 L
.45546 .30902 L
.4565 .30902 L
.45773 .30902 L
.45843 .30902 L
.45907 .30902 L
.46022 .30902 L
.46148 .30902 L
.46274 .30902 L
.46393 .30902 L
.46509 .30902 L
.46616 .30902 L
.46744 .30902 L
.4686 .30902 L
.46925 .30902 L
.46995 .30902 L
.47119 .30902 L
.47226 .30902 L
.47344 .30902 L
.47469 .30902 L
.47586 .30902 L
.47698 .30902 L
.47799 .30902 L
Mistroke
.47916 .30902 L
.48026 .30902 L
.48145 .30902 L
.48276 .30902 L
.48342 .30902 L
.48413 .30902 L
.48541 .30902 L
.48668 .30902 L
.48789 .30902 L
.48897 .30902 L
.49016 .30902 L
.49089 .30902 L
.49157 .30902 L
.49286 .30902 L
.49357 .30902 L
.49424 .30902 L
.49496 .30902 L
.49573 .30902 L
.49701 .30902 L
.4982 .30902 L
.49951 .30902 L
.50023 .30902 L
.50091 .30902 L
.50214 .30902 L
.5028 .30902 L
.5035 .30902 L
.50476 .30902 L
.50591 .30902 L
.50717 .30902 L
.50789 .30902 L
.50856 .30902 L
.50927 .30902 L
.50991 .30902 L
.51065 .30902 L
.51135 .30902 L
.51255 .30902 L
.51382 .30902 L
.51491 .30902 L
.5161 .30902 L
.51738 .30902 L
.5181 .30902 L
.51876 .30902 L
.52004 .30902 L
.52125 .30902 L
.5224 .30902 L
.52348 .30902 L
.52472 .30902 L
.52585 .30902 L
.52692 .30902 L
.52791 .30902 L
Mistroke
.52899 .30902 L
.53012 .30902 L
.53128 .30902 L
.53251 .30902 L
.53368 .30902 L
.53474 .30902 L
.53599 .30902 L
.53669 .30902 L
.53734 .30902 L
.53854 .30902 L
.5398 .30902 L
.54094 .30902 L
.54219 .30902 L
.54349 .30902 L
.5447 .30902 L
.54584 .30902 L
.54687 .30902 L
.54807 .30902 L
.54919 .30902 L
.55042 .30902 L
.55172 .30902 L
.55283 .30902 L
.55405 .30902 L
.55472 .30902 L
.55546 .30902 L
.55615 .30902 L
.55679 .30902 L
.55801 .30902 L
.5593 .30902 L
.56042 .30902 L
.56147 .30902 L
.56262 .30902 L
.56386 .30902 L
.56511 .30902 L
.56641 .30902 L
.56753 .30902 L
.56876 .30902 L
.56991 .30902 L
.57097 .30902 L
.57218 .30902 L
.57333 .30902 L
.57439 .30902 L
.57538 .30902 L
.57645 .30902 L
.57759 .30902 L
.5788 .30902 L
.58011 .30902 L
.58136 .30902 L
.58251 .30902 L
.58365 .30902 L
Mistroke
.58469 .30902 L
.58588 .30902 L
.58701 .30902 L
.58824 .30902 L
.58954 .30902 L
.59065 .30902 L
.59187 .30902 L
.59319 .30902 L
.59392 .30902 L
.59459 .30902 L
.5959 .30902 L
.59713 .30902 L
.59818 .30902 L
.59934 .30902 L
.60055 .30902 L
.60169 .30902 L
.60275 .30902 L
.60372 .30902 L
.60478 .30902 L
.6059 .30902 L
.60704 .30902 L
.60826 .30902 L
.60941 .30902 L
.61045 .30902 L
.61168 .30902 L
.61238 .30902 L
.61302 .30902 L
.61419 .30902 L
.61544 .30902 L
.61665 .30902 L
.61797 .30902 L
.61921 .30902 L
.62037 .30902 L
.62151 .30902 L
.62255 .30902 L
.62368 .30902 L
.62488 .30902 L
.62618 .30902 L
.62739 .30902 L
.62868 .30902 L
.62942 .30902 L
.6301 .30902 L
.63134 .30902 L
.63247 .30902 L
.63378 .30902 L
.63502 .30902 L
.63607 .30902 L
.63723 .30902 L
.63844 .30902 L
.63958 .30902 L
Mistroke
.64064 .30902 L
.64161 .30902 L
.64273 .30902 L
.64379 .30902 L
.64494 .30902 L
.64616 .30902 L
.64731 .30902 L
.64835 .30902 L
.64958 .30902 L
.65023 .30902 L
.65091 .30902 L
.65217 .30902 L
.65333 .30902 L
.65455 .30902 L
.65523 .30902 L
.65587 .30902 L
.65704 .30902 L
.65828 .30902 L
.65939 .30902 L
.66043 .30902 L
.66157 .30902 L
.6628 .30902 L
.66403 .30902 L
.66473 .30902 L
.66536 .30902 L
.66658 .30902 L
.66774 .30902 L
.66893 .30902 L
.67023 .30902 L
.67092 .30902 L
.67164 .30902 L
.67295 .30902 L
.67408 .30902 L
.6753 .30902 L
.67645 .30902 L
.6775 .30902 L
.67873 .30902 L
.67942 .30902 L
.68007 .30902 L
.68125 .30902 L
.68251 .30902 L
.68365 .30902 L
.68488 .30902 L
.68604 .30902 L
.68711 .30902 L
.68808 .30902 L
.68914 .30902 L
.69024 .30902 L
.69128 .30902 L
.69254 .30902 L
Mistroke
.69318 .30902 L
.69388 .30902 L
.69513 .30902 L
.69629 .30902 L
.69696 .30902 L
.69766 .30902 L
.69892 .30902 L
.69962 .30902 L
.70028 .30902 L
.70105 .30902 L
.70174 .30902 L
.70292 .30902 L
.7042 .30902 L
.70538 .30902 L
.70648 .30902 L
.70767 .30902 L
.70899 .30902 L
.70965 .30902 L
.71037 .30902 L
.71165 .30902 L
.71281 .30902 L
.71403 .30902 L
.71474 .30902 L
.71538 .30902 L
.71663 .30902 L
.71774 .30902 L
.7189 .30902 L
.72018 .30902 L
.72135 .30902 L
.72248 .30902 L
.72353 .30902 L
.72469 .30902 L
.72592 .30902 L
.72708 .30902 L
.72817 .30902 L
.72915 .30902 L
.73021 .30902 L
.73144 .30902 L
.73256 .30902 L
.73386 .30902 L
.73509 .30902 L
.73622 .30902 L
.73727 .30902 L
.73842 .30902 L
.73965 .30902 L
.74035 .30902 L
.741 .30902 L
.74171 .30902 L
.74246 .30902 L
.74372 .30902 L
Mistroke
.74443 .30902 L
.7451 .30902 L
.74635 .30902 L
.74749 .30902 L
.7488 .30902 L
.75005 .30902 L
.75125 .30902 L
.75194 .30902 L
.75258 .30902 L
.75388 .30902 L
.75461 .30902 L
.75528 .30902 L
.7564 .30902 L
.75764 .30902 L
.75892 .30902 L
.76012 .30902 L
.7608 .30902 L
.76155 .30902 L
.76225 .30902 L
.76289 .30902 L
.76412 .30902 L
.76542 .30902 L
.76609 .30902 L
.76681 .30902 L
.76811 .30902 L
.76891 .30902 L
.76966 .30902 L
.77034 .30902 L
.77108 .30902 L
.77172 .30902 L
.77241 .30902 L
.77364 .30902 L
.77496 .30902 L
.77571 .30902 L
.7764 .30902 L
.77767 .30902 L
.77883 .30902 L
.77946 .30902 L
.78016 .30902 L
.78142 .30902 L
.78254 .30902 L
.78378 .30902 L
.78507 .30902 L
.78629 .30902 L
.78742 .30902 L
.78845 .30902 L
.79078 .30902 L
.81177 .30902 L
.85144 .30902 L
.8896 .30902 L
Mistroke
.9302 .30902 L
.9693 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`00I_l01c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0c
o`00;c?o00030000<ol0<ol001dco`000`1Voc?o03?o000?<ol000<0000co`0co`00;S?o00030000
<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Ooooe8co`000`1Voc?o
03?o001b<ol000<0003oooooool0AOooo`004Ooooe8co`000`1Voc?o03?o001b<ol000<0003ooooo
ool0AOooo`004Ooooe8co`000`1Voc?o03?o001b<ol000<0003oooooool0AOooo`004Oooo`H0I_m<
<ol000<0I_lco`0co`00LS?o00030000oooooooo04Goool0017oool6<ol02P1Vod8co`000`1Voc?o
03?o001b<ol000<0003oooooool0AOooo`004Ooooa0co`0;06Ko=c?o000306Ko<ol0<ol0078co`02
0000A_ooo`004Ooooa/co`0806Ko;c?o000306Ko<ol0<ol0078co`000`000?ooooooo`15oooo000A
oooo8c?o00D0I_lZ<ol000<0I_lco`0co`00LS?o00030000oooooooo04Goool0017ooolX<ol01`1V
ob<co`000`1Voc?o03?o001b<ol000<0003oooooool0AOooo`004Ooooblco`0806Ko6c?o000306Ko
<ol0<ol0078co`000`000?ooooooo`15oooo000Aoooo=c?o00D0I_lF<ol000<0I_lco`0co`00LS?o
00030000oooooooo04Goool0017oooll<ol01@1Voa4co`000`1Voc?o03?o001b<ol000<0003ooooo
ool0AOooo`004Ooood4co`0506Ko33?o000306Ko<ol0<ol0078co`000`000?ooooooo`15oooo000A
oooo0P0004@co`0206Ko2S?o000306Ko<ol0<ol0078co`020000A_ooo`004oooo`800014<ol01P1V
o`@co`000`1Voc?o03?o001b<ol000<0003oooooool0AOooo`005Oooo`800018<ol00`1Vo`03<ol0
06Ko<ol007<co`000`000?ooooooo`15oooo000Goooo0P0004Tco`0206KoM3?o00030000oooooooo
04Goool001Woool20000B3?o0003o`2I<ol0<ol0078co`000`000?ooooooo`15oooo000Koooo0P00
04Hco`000ol0VC?o03?o001b<ol000<0003oooooool0AOooo`007Oooo`800014<ol000?o09Tco`0c
o`00LS?o00030000oooooooo04Goool001ooool00`0003?o03?o0011<ol000?o09Tco`0co`00LS?o
00030000oooooooo04Goool0023oool00`0003?o03?o0010<ol000?o09Tco`0co`00LS?o00800016
oooo000Qoooo0P00040co`000ol0VC?o03?o001b<ol000<0003oooooool0AOooo`008oooo`030000
<ol0<ol003dco`000ol0VC?o03?o001b<ol000<0003oooooool0AOooo`009?ooo`80000m<ol000?o
09Tco`0co`00LS?o00030000oooooooo04Goool002Koool00`0003?o03?o000j<ol000?o09Tco`0c
o`00LS?o00030000oooooooo04Goool002Ooool00`0003?o03?o000i<ol000?o09Tco`0co`00LS?o
00030000oooooooo04Goool002Soool00`0003?o03?o000h<ol000?o09Tco`0co`00FC?o00800004
<ol00P0000@co`0200000c?o00@00004<ol000<0003oooooool0AOooo`00:Oooo`030000<ol0<ol0
03Lco`000ol0VC?o03?o001H<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000<0
000co`0co`001C?o00030000oooooooo04Goool002[oool00`0003?o03?o000f<ol000?o09Tco`0c
o`00F3?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0<ol000@co`03
0000AOooo`00:oooo`80000f<ol000?o09Tco`0co`00F3?o00040000<ol0<ol0000023?o00040000
<ol0<ol0000013?o00030000<ol0<ol000<co`000`000?ooooooo`15oooo000]oooo00<0000co`0c
o`00<c?o0003o`2I<ol0<ol005Pco`00100003?o03?o000000Pco`00100003?o03?o0000008co`00
100003?o03?o000000@co`000`000?ooooooo`15oooo000^oooo00<0000co`0co`00<S?o0003o`2I
<ol0<ol005Tco`0200002S?o00800004<ol00P0000Dco`000`000?ooooooo`15oooo000_oooo00<0
000co`0co`00<C?o0003o`2I<ol0<ol0078co`000`000?ooooooo`15oooo000`oooo00<0000co`0c
o`00<3?o0003o`2I<ol0<ol0078co`000`000?ooooooo`15oooo000aoooo00<0000co`0co`00;c?o
0003o`2I<ol0<ol0078co`000`000?ooooooo`15oooo000boooo00<0000co`0co`00;S?o0003o`2I
<ol0<ol0078co`000`000?ooooooo`15oooo000coooo00<0000co`0co`00;C?o0003o`2I<ol0<ol0
078co`020000A_ooo`00<oooo`030000<ol0<ol002dco`000ol0VC?o03?o001b<ol000<0003ooooo
ool0AOooo`00=?ooo`030000<ol0<ol002`co`000ol0VC?o03?o001b<ol000<0003oooooool0AOoo
o`00=Oooo`030000<ol0<ol002/co`000ol0VC?o03?o001b<ol000<0003oooooool0AOooo`00=_oo
o`030000<ol0<ol002Xco`000ol0VC?o03?o001b<ol000<0003oooooool0AOooo`00=oooo`030000
<ol0<ol002Tco`000ol0VC?o03?o001b<ol000<0003oooooool0AOooo`00>?ooo`030000<ol0<ol0
02Pco`000ol0VC?o03?o001b<ol000<0003oooooool0AOooo`00>?ooo`030000<ol0<ol002Pco`00
0ol0VC?o03?o001b<ol000<0003oooooool0AOooo`00>Oooo`030000<ol0<ol002Lco`000ol0VC?o
03?o001b<ol00P0004Koool003[oool00`0003?o03?o000V<ol000?o09Tco`0co`00LS?o00030000
oooooooo04Goool003_oool00`0003?o03?o000U<ol000?o09Tco`0co`00LS?o00030000oooooooo
04Goool003coool00`0003?o03?o000T<ol000?o09Tco`0co`00LS?o00030000oooooooo04Goool0
03coool00`0003?o03?o000T<ol000?o09Tco`0co`00LS?o00030000oooooooo04Goool003goool0
0`0003?o03?o000S<ol000?o09Tco`0co`00LS?o00030000oooooooo04Goool003goool00`0003?o
03?o000S<ol000?o09Tco`0co`00LS?o00030000oooooooo04Goool003koool00`0003?o03?o000R
<ol000?o09Tco`0co`00LS?o00030000oooooooo04Goool003koool00`0003?o03?o000R<ol000?o
09Tco`0co`00LS?o00030000oooooooo04Goool003ooool00`0003?o03?o000Q<ol000?o09Tco`0c
o`00LS?o00800016oooo000ooooo00<0000co`0co`008C?o0003o`2I<ol0<ol0078co`000`000?oo
ooooo`15oooo0010oooo00<0000co`0co`0083?o0003o`2I<ol0<ol0078co`000`000?ooooooo`15
oooo0011oooo00<0000co`0co`007c?o0003o`2I<ol0<ol0078co`000`000?ooooooo`15oooo0011
oooo00<0000co`0co`007c?o0003o`2I<ol0<ol0078co`000`000?ooooooo`15oooo0012oooo00<0
000co`0co`007S?o0003o`2I<ol0<ol0078co`000`000?ooooooo`15oooo0012oooo00<0000co`0c
o`007S?o0003o`2I<ol0<ol005Tco`02000013?o00800004<ol00P0000Dco`0300000c?o00030000
oooooooo04Goool004?oool00`0003?o03?o000M<ol000?o09Tco`0co`00F3?o00040000<ol0<ol0
000023?o00040000<ol0<ol000001C?o00030000<ol0<ol0008co`000`000?ooooooo`15oooo0013
oooo00<0000co`0co`007C?o0003o`2I<ol0<ol005Pco`00100003?o03?o000000Pco`00100003?o
03?o0000008co`0500000c?o00<00015oooo0014oooo00<0000co`0co`0073?o0003o`2I<ol0<ol0
05Pco`00100003?o03?o000000Pco`00100003?o03?o0000008co`00100003?o03?o000000@co`00
0`000?ooooooo`15oooo0014oooo00<0000co`0co`0073?o0003o`2I<ol0<ol005Pco`00100003?o
03?o000000Pco`00100003?o03?o000000<co`000`0003?o00000004<ol000<0003oooooool0AOoo
o`00AOooo`030000<ol0<ol001/co`000ol0VC?o03?o001I<ol00P0000Xco`0200001C?o00800004
<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol001/co`000ol0VC?o03?o001b<ol000<0
003oooooool0AOooo`00A_ooo`030000<ol0<ol001Xco`000ol0VC?o03?o001b<ol000<0003ooooo
ool0AOooo`00A_ooo`030000<ol0<ol001Xco`000ol0VC?o03?o001b<ol000<0003oooooool0AOoo
o`00Aoooo`030000<ol0<ol001Tco`000ol0VC?o03?o001b<ol000<0003oooooool0AOooo`00Aooo
o`030000<ol0<ol001Tco`000ol0VC?o03?o001b<ol00P0004Koool004Soool00`0003?o03?o000H
<ol000?o09Tco`0co`00LS?o00030000oooooooo04Goool004Soool00`0003?o03?o000H<ol000?o
09Tco`0co`00LS?o00030000oooooooo04Goool004Woool00`0003?o03?o000G<ol000?o09Tco`0c
o`00LS?o00030000oooooooo04Goool004Woool00`0003?o03?o000G<ol000?o09Tco`0co`00LS?o
00030000oooooooo04Goool004[oool00`0003?o03?o000F<ol000?o09Tco`0co`00LS?o00030000
oooooooo04Goool004[oool00`0003?o03?o000F<ol000?o09Tco`0co`00LS?o00030000oooooooo
04Goool004_oool00`0003?o03?o000E<ol000?o09Tco`0co`00LS?o00030000oooooooo04Goool0
04_oool00`0003?o03?o000E<ol000?o09Tco`0co`00LS?o00800016oooo001<ooooS3?o04Soool0
04cooon<<ol0B?ooo`00C?oooh`co`18oooo001=ooooRc?o04Soool004gooon;<ol0B?ooo`00C_oo
obHco`000`0003?o03?o000_<ol000<0000co`0co`00;c?o04Soool004kooolU<ol000<0000co`0c
o`0023?o00030000<ol0<ol002Hco`000`0003?o03?o000^<ol0B?ooo`00Coooob@co`000`0003?o
03?o0002<ol00P0000@co`000`0003?o03?o000><ol00P0000@co`0200000c?o00D00002<ol00P00
00@co`000`0003?o03?o000^<ol0B?ooo`00Coooob@co`001@0003?o03?o03?o00000002<ol000<0
000co`0co`000S?o00030000<ol0<ol000Dco`0400000c?o00040000<ol0<ol000002S?o00050000
<ol0<ol0<ol00000008co`001@0003?o03?o03?o0000000`<ol0B?ooo`00Coooob<co`000`0003?o
03?o0002<ol000<0000co`0co`0053?o00040000<ol0<ol000002S?o00050000<ol0<ol0<ol00000
008co`000`0003?o03?o0002<ol000<0000co`0co`00;C?o04Soool0053ooolS<ol000<0000co`0c
o`001@0001<co`00100003?o03?o000000Xco`000`0003?o03?o0002<ol00P0000@co`000`0003?o
03?o000^<ol0B?ooo`00D?ooob<co`001@0003?o03?o03?o0000000F<ol000@0000co`0co`00000:
<ol000D0000co`0co`0co`0000000S?o00050000<ol0<ol0<ol00000030co`18oooo001@oooo93?o
00030000<ol0<ol001Pco`0200002S?o00800004<ol00P0000<co`000`0003?o03?o000_<ol0B?oo
o`00DOooohLco`18oooo001AooooQc?o04Soool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.17) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.32392 .30902 L
.33304 .30902 L
.33554 .30902 L
.33692 .30902 L
.33823 .30902 L
.33944 .30902 L
s
.33944 .30902 m
.33944 .61803 L
s
0 .4 1 r
.02381 .33017 m
.06244 .33343 L
.10458 .33758 L
.14415 .34211 L
.18221 .34715 L
.22272 .35336 L
.26171 .36032 L
.28158 .36428 L
.30316 .36893 L
.31323 .37123 L
.32392 .37378 L
.33304 .37603 L
.33554 .37667 L
.33692 .37702 L
.33823 .37735 L
.33944 .37767 L
.34013 .30902 L
.34076 .30902 L
.34189 .30902 L
.34309 .30902 L
.34433 .30902 L
.34503 .30902 L
.34569 .30902 L
.34638 .30902 L
.34702 .30902 L
.34775 .30902 L
.34844 .30902 L
.34967 .30902 L
.3508 .30902 L
.35205 .30902 L
.35274 .30902 L
.35337 .30902 L
.35468 .30902 L
.35537 .30902 L
.3561 .30902 L
.35732 .30902 L
.35801 .30902 L
.35866 .30902 L
.35942 .30902 L
.36014 .30902 L
.36078 .30902 L
.36148 .30902 L
.36224 .30902 L
.36305 .30902 L
.36374 .30902 L
.3645 .30902 L
.36514 .30902 L
.36584 .30902 L
.36712 .30902 L
.36837 .30902 L
Mistroke
.36952 .30902 L
.37023 .30902 L
.37089 .30902 L
.37213 .30902 L
.37283 .30902 L
.37347 .30902 L
.37418 .30902 L
.37492 .30902 L
.37608 .30902 L
.37732 .30902 L
.3785 .30902 L
.37957 .30902 L
.38082 .30902 L
.38153 .30902 L
.38219 .30902 L
.38339 .30902 L
.38467 .30902 L
.38581 .30902 L
.38706 .30902 L
.38836 .30902 L
.38957 .30902 L
.39071 .30902 L
.39174 .30902 L
.39294 .30902 L
.39406 .30902 L
.39529 .30902 L
.39659 .30902 L
.3977 .30902 L
.39892 .30902 L
.40023 .30902 L
.40097 .30902 L
.40164 .30902 L
.40294 .30902 L
.40418 .30902 L
.40531 .30902 L
.40638 .30902 L
.40749 .30902 L
.40872 .30902 L
.40971 .30902 L
.41075 .30902 L
.41189 .30902 L
.41294 .30902 L
.41407 .30902 L
.41529 .30902 L
.41644 .30902 L
.41749 .30902 L
.41872 .30902 L
.41941 .30902 L
.42005 .30902 L
.42122 .30902 L
Mistroke
.42247 .30902 L
.42368 .30902 L
.42499 .30902 L
.42624 .30902 L
.42739 .30902 L
.42853 .30902 L
.42957 .30902 L
.43077 .30902 L
.43189 .30902 L
.43312 .30902 L
.43443 .30902 L
.43554 .30902 L
.43676 .30902 L
.43807 .30902 L
.43881 .30902 L
.43948 .30902 L
.44078 .30902 L
.44202 .30902 L
.44307 .30902 L
.44423 .30902 L
.44544 .30902 L
.44658 .30902 L
.44756 .30902 L
.4486 .30902 L
.44974 .30902 L
.45079 .30902 L
.45193 .30902 L
.45315 .30902 L
.4543 .30902 L
.45534 .30902 L
.45657 .30902 L
.45727 .30902 L
.45791 .30902 L
.45908 .30902 L
.46033 .30902 L
.46154 .30902 L
.46286 .30902 L
.46411 .30902 L
.46526 .30902 L
.46641 .30902 L
.46745 .30902 L
.46864 .30902 L
.46977 .30902 L
.47101 .30902 L
.47231 .30902 L
.47343 .30902 L
.47465 .30902 L
.47597 .30902 L
.4767 .30902 L
.47737 .30902 L
Mistroke
.47868 .30902 L
.47991 .30902 L
.48097 .30902 L
.48213 .30902 L
.48334 .30902 L
.48448 .30902 L
.48554 .30902 L
.48651 .30902 L
.48763 .30902 L
.4887 .30902 L
.48984 .30902 L
.49106 .30902 L
.49221 .30902 L
.49326 .30902 L
.49449 .30902 L
.49518 .30902 L
.49582 .30902 L
.49699 .30902 L
.49823 .30902 L
.49945 .30902 L
.50014 .30902 L
.50078 .30902 L
.50194 .30902 L
.50319 .30902 L
.50429 .30902 L
.50533 .30902 L
.50647 .30902 L
.5077 .30902 L
.50894 .30902 L
.50963 .30902 L
.51028 .30902 L
.5116 .30902 L
.51233 .30902 L
.513 .30902 L
.5142 .30902 L
.5155 .30902 L
.51672 .30902 L
.51786 .30902 L
.51892 .30902 L
.52007 .30902 L
.52133 .30902 L
.52249 .30902 L
.5237 .30902 L
.52501 .30902 L
.52625 .30902 L
.5274 .30902 L
.52855 .30902 L
.52963 .30902 L
.5306 .30902 L
.53166 .30902 L
Mistroke
.53281 .30902 L
.53402 .30902 L
.53506 .30902 L
.53619 .30902 L
.5375 .30902 L
.53871 .30902 L
.53934 .30902 L
.54004 .30902 L
.54145 .30902 L
.54268 .30902 L
.54337 .30902 L
.54401 .30902 L
.54518 .30902 L
.54642 .30902 L
.54753 .30902 L
.54872 .30902 L
.54985 .30902 L
.55087 .30902 L
.55207 .30902 L
.55337 .30902 L
.5546 .30902 L
.55573 .30902 L
.55694 .30902 L
.55824 .30902 L
.55946 .30902 L
.56058 .30902 L
.56188 .30902 L
.56257 .30902 L
.56331 .30902 L
.56395 .30902 L
.56465 .30902 L
.5659 .30902 L
.56658 .30902 L
.56729 .30902 L
.56857 .30902 L
.56928 .30902 L
.56994 .30902 L
.57067 .30902 L
.57144 .30902 L
.57212 .30902 L
.57285 .30902 L
.57354 .30902 L
.57417 .30902 L
.57538 .30902 L
.57666 .30902 L
.57786 .30902 L
.57918 .30902 L
.58042 .30902 L
.58157 .30902 L
.58271 .30902 L
Mistroke
.58375 .30902 L
.58495 .30902 L
.58607 .30902 L
.5873 .30902 L
.5886 .30902 L
.58972 .30902 L
.59094 .30902 L
.59225 .30902 L
.59299 .30902 L
.59366 .30902 L
.59496 .30902 L
.5962 .30902 L
.59725 .30902 L
.5984 .30902 L
.59961 .30902 L
.60075 .30902 L
.60174 .30902 L
.60278 .30902 L
.60392 .30902 L
.60496 .30902 L
.6061 .30902 L
.60732 .30902 L
.60847 .30902 L
.60952 .30902 L
.61075 .30902 L
.61144 .30902 L
.61208 .30902 L
.61326 .30902 L
.6145 .30902 L
.61571 .30902 L
.61703 .30902 L
.61828 .30902 L
.61943 .30902 L
.62058 .30902 L
.62162 .30902 L
.62281 .30902 L
.62394 .30902 L
.62518 .30902 L
.62648 .30902 L
.62759 .30902 L
.62881 .30902 L
.63013 .30902 L
.63087 .30902 L
.63154 .30902 L
.63284 .30902 L
.63408 .30902 L
.63513 .30902 L
.63629 .30902 L
.63751 .30902 L
.63864 .30902 L
Mistroke
.6397 .30902 L
.64067 .30902 L
.64179 .30902 L
.64286 .30902 L
.644 .30902 L
.64522 .30902 L
.64637 .30902 L
.64742 .30902 L
.64865 .30902 L
.64934 .30902 L
.64998 .30902 L
.65113 .30902 L
.65239 .30902 L
.65365 .30902 L
.65485 .30902 L
.65601 .30902 L
.65708 .30902 L
.65824 .30902 L
.65952 .30902 L
.66088 .30902 L
.66212 .30902 L
.66321 .30902 L
.66437 .30902 L
.66553 .30902 L
.6668 .30902 L
.6679 .30902 L
.66908 .30902 L
.67019 .30902 L
.6712 .30902 L
.67249 .30902 L
.67314 .30902 L
.67385 .30902 L
.67511 .30902 L
.6763 .30902 L
.67701 .30902 L
.67769 .30902 L
.67896 .30902 L
.67967 .30902 L
.68033 .30902 L
.68105 .30902 L
.68182 .30902 L
.69186 .30902 L
.69311 .30902 L
.69381 .30902 L
.69445 .30902 L
.69569 .30902 L
.69687 .30902 L
.69808 .30902 L
.69939 .30902 L
.70009 .30902 L
Mistroke
.70083 .30902 L
.70146 .30902 L
.70216 .30902 L
.70286 .30902 L
.7036 .30902 L
.70441 .30902 L
.70515 .30902 L
.70584 .30902 L
.70649 .30902 L
.7072 .30902 L
.70796 .30902 L
.70865 .30902 L
.70939 .30902 L
.71005 .30902 L
.71075 .30902 L
.71207 .30902 L
.71329 .30902 L
.71454 .30902 L
.71568 .30902 L
.717 .30902 L
.71826 .30902 L
.71941 .30902 L
.72048 .30902 L
.72165 .30902 L
.7229 .30902 L
.72362 .30902 L
.72428 .30902 L
.725 .30902 L
.72576 .30902 L
.72704 .30902 L
.72777 .30902 L
.72845 .30902 L
.72972 .30902 L
.73087 .30902 L
.73151 .30902 L
.73221 .30902 L
.73347 .30902 L
.73834 .30902 L
.73946 .30902 L
.74068 .30902 L
.74183 .30902 L
.7429 .30902 L
.74417 .30902 L
.74488 .30902 L
.74552 .30902 L
.74675 .30902 L
.74791 .30902 L
.74857 .30902 L
.74926 .30902 L
.7505 .30902 L
Mistroke
.75119 .30902 L
.75183 .30902 L
.75254 .30902 L
.7533 .30902 L
.75398 .30902 L
.7547 .30902 L
.756 .30902 L
.75673 .30902 L
.7574 .30902 L
.75815 .30902 L
.75895 .30902 L
.7596 .30902 L
.76031 .30902 L
.76105 .30902 L
.76174 .30902 L
.76306 .30902 L
.7643 .30902 L
.76552 .30902 L
.76684 .30902 L
.76804 .30902 L
.76915 .30902 L
.77035 .30902 L
.77166 .30902 L
.77233 .30902 L
.77304 .30902 L
.77433 .30902 L
.77502 .30902 L
.77566 .30902 L
.77687 .30902 L
.77818 .30902 L
.77891 .30902 L
.77958 .30902 L
.78071 .30902 L
.78195 .30902 L
.78325 .30902 L
.78446 .30902 L
.78514 .30902 L
.78589 .30902 L
.7866 .30902 L
.78725 .30902 L
.78979 .30902 L
.7955 .30902 L
.8156 .30902 L
.85491 .30902 L
.89271 .30902 L
.93296 .30902 L
.9717 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.17) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000@0
000co`0co`00I_l6<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo01?oool0017oool00`0003?o
03?o000_<ol000<0000co`0co`007S?o000306Ko<ol0<ol000hco`000`0003?o03?o000^<ol000<0
000co`0co`00;c?o00030000oooooooo02ooool00`000?ooooooo`0Coooo000AooooDc?o000306Ko
<ol0<ol0074co`000`000?ooooooo`15oooo000AooooDc?o000306Ko<ol0<ol0074co`000`000?oo
ooooo`15oooo000AooooDc?o000306Ko<ol0<ol0074co`000`000?ooooooo`15oooo000Aoooo3P1V
odDco`000`1Voc?o03?o001a<ol000<0003oooooool0AOooo`004Oooo`hco`0506Ko@3?o000306Ko
<ol0<ol0074co`000`000?ooooooo`15oooo000Aoooo4c?o00P0I_lh<ol000<0I_lco`0co`00LC?o
00800016oooo000Aoooo6c?o00X0I_l^<ol000<0I_lco`0co`00LC?o00030000oooooooo04Goool0
017ooolU<ol0201VobHco`000`1Voc?o03?o001a<ol000<0003oooooool0AOooo`004Oooobdco`05
06Ko8C?o000306Ko<ol0<ol0074co`000`000?ooooooo`15oooo000Aoooo<S?o00L0I_lJ<ol000<0
I_lco`0co`00LC?o00030000oooooooo04Goool0017oooli<ol01`1Voa<co`000`1Voc?o03?o001a
<ol000<0003oooooool0AOooo`004Ooood0co`0306Ko43?o000306Ko<ol0<ol0074co`000`000?oo
ooooo`15oooo000Aoooo@c?o00@0I_l<<ol000<0I_lco`0co`00LC?o00030000oooooooo04Goool0
017oool20000AC?o00L0I_l5<ol000<0I_lco`0co`00LC?o00800016oooo000Coooo0P0004Xco`02
06Ko0c?o000306Ko<ol0<ol0074co`000`000?ooooooo`15oooo000Eoooo0P0004Xco`0406KoLc?o
00030000oooooooo04Goool001Ooool20000Bc?o0003o`2I<ol0<ol0074co`000`000?ooooooo`15
oooo000Ioooo0P0004Tco`000ol0VC?o03?o001a<ol000<0003oooooool0AOooo`006oooo`800017
<ol000?o09Tco`0co`00LC?o00030000oooooooo04Goool001goool20000AC?o0003o`2I<ol0<ol0
074co`000`000?ooooooo`15oooo000Ooooo00<0000co`0co`00@S?o0003o`2I<ol0<ol0074co`00
0`000?ooooooo`15oooo000Poooo00<0000co`0co`00@C?o0003o`2I<ol0<ol0074co`020000A_oo
o`008Oooo`800011<ol000?o09Tco`0co`00LC?o00030000oooooooo04Goool002?oool00`0003?o
03?o000n<ol000?o09Tco`0co`00LC?o00030000oooooooo04Goool002Coool20000?S?o0003o`2I
<ol0<ol0074co`000`000?ooooooo`15oooo000Voooo00<0000co`0co`00>c?o0003o`2I<ol0<ol0
074co`000`000?ooooooo`15oooo000Woooo00<0000co`0co`00>S?o0003o`2I<ol0<ol0074co`00
0`000?ooooooo`15oooo000Xoooo00<0000co`0co`00>C?o0003o`2I<ol0<ol005Pco`02000013?o
00800004<ol00P0000<co`04000013?o00030000oooooooo04Goool002Woool00`0003?o03?o000h
<ol000?o09Tco`0co`00Ec?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00030000
<ol0<ol000Dco`000`000?ooooooo`15oooo000Zoooo00<0000co`0co`00=c?o0003o`2I<ol0<ol0
05Lco`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o0004<ol00`00
04Goool002_oool20000=c?o0003o`2I<ol0<ol005Lco`00100003?o03?o000000Pco`00100003?o
03?o000000@co`000`0003?o03?o0003<ol000<0003oooooool0AOooo`00;Oooo`030000<ol0<ol0
03@co`000ol0VC?o03?o001G<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0
000co`0co`000004<ol000<0003oooooool0AOooo`00;_ooo`030000<ol0<ol003<co`000ol0VC?o
03?o001H<ol00P0000Xco`02000013?o00800005<ol000<0003oooooool0AOooo`00;oooo`030000
<ol0<ol0038co`000ol0VC?o03?o001a<ol000<0003oooooool0AOooo`00<?ooo`030000<ol0<ol0
034co`000ol0VC?o03?o001a<ol000<0003oooooool0AOooo`00<Oooo`030000<ol0<ol0030co`00
0ol0VC?o03?o001a<ol000<0003oooooool0AOooo`00<_ooo`030000<ol0<ol002lco`000ol0VC?o
03?o001a<ol000<0003oooooool0AOooo`00<oooo`030000<ol0<ol002hco`000ol0VC?o03?o001a
<ol00P0004Koool003?oool00`0003?o03?o000^<ol000?o09Tco`0co`00LC?o00030000oooooooo
04Goool003Coool00`0003?o03?o000]<ol000?o09Tco`0co`00LC?o00030000oooooooo04Goool0
03Goool00`0003?o03?o000/<ol000?o09Tco`0co`00LC?o00030000oooooooo04Goool003Koool0
0`0003?o03?o000[<ol000?o09Tco`0co`00LC?o00030000oooooooo04Goool003Ooool00`0003?o
03?o000Z<ol000?o09Tco`0co`00LC?o00030000oooooooo04Goool003Soool00`0003?o03?o000Y
<ol000?o09Tco`0co`00LC?o00030000oooooooo04Goool003Soool00`0003?o03?o000Y<ol000?o
09Tco`0co`00LC?o00030000oooooooo04Goool003Woool00`0003?o03?o000X<ol000?o09Tco`0c
o`00LC?o00800016oooo000joooo00<0000co`0co`009c?o0003o`2I<ol0<ol0074co`000`000?oo
ooooo`15oooo000koooo00<0000co`0co`009S?o0003o`2I<ol0<ol0074co`000`000?ooooooo`15
oooo000loooo00<0000co`0co`009C?o0003o`2I<ol0<ol0074co`000`000?ooooooo`15oooo000l
oooo00<0000co`0co`009C?o0003o`2I<ol0<ol0074co`000`000?ooooooo`15oooo000moooo00<0
000co`0co`0093?o0003o`2I<ol0<ol0074co`000`000?ooooooo`15oooo000moooo00<0000co`0c
o`0093?o0003o`2I<ol0<ol0074co`000`000?ooooooo`15oooo000noooo00<0000co`0co`008c?o
0003o`2I<ol0<ol0074co`000`000?ooooooo`15oooo000noooo00<0000co`0co`008c?o0003o`2I
<ol0<ol0074co`000`000?ooooooo`15oooo000ooooo00<0000co`0co`008S?o0003o`2I<ol0<ol0
074co`020000A_ooo`00?oooo`030000<ol0<ol0028co`000ol0VC?o03?o001a<ol000<0003ooooo
ool0AOooo`00@?ooo`030000<ol0<ol0024co`000ol0VC?o03?o001a<ol000<0003oooooool0AOoo
o`00@Oooo`030000<ol0<ol0020co`000ol0VC?o03?o001a<ol000<0003oooooool0AOooo`00@Ooo
o`030000<ol0<ol0020co`000ol0VC?o03?o001a<ol000<0003oooooool0AOooo`00@_ooo`030000
<ol0<ol001lco`000ol0VC?o03?o001a<ol000<0003oooooool0AOooo`00@_ooo`030000<ol0<ol0
01lco`000ol0VC?o03?o001H<ol00P0000@co`02000013?o00800005<ol00`0000<co`000`000?oo
ooooo`15oooo0013oooo00<0000co`0co`007S?o0003o`2I<ol0<ol005Lco`00100003?o03?o0000
00Pco`00100003?o03?o000000Dco`000`0003?o03?o0002<ol000<0003oooooool0AOooo`00@ooo
o`030000<ol0<ol001hco`000ol0VC?o03?o001G<ol000@0000co`0co`000008<ol000@0000co`0c
o`000002<ol01@0000<co`030000AOooo`00A?ooo`030000<ol0<ol001dco`000ol0VC?o03?o001G
<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000004<ol000<0
003oooooool0AOooo`00A?ooo`030000<ol0<ol001dco`000ol0VC?o03?o001G<ol000@0000co`0c
o`000008<ol000@0000co`0co`000003<ol000<0000co`00000013?o00030000oooooooo04Goool0
04Goool00`0003?o03?o000L<ol000?o09Tco`0co`00F3?o0080000:<ol00P0000Dco`02000013?o
00030000oooooooo04Goool004Goool00`0003?o03?o000L<ol000?o09Tco`0co`00LC?o00030000
oooooooo04Goool004Koool00`0003?o03?o000K<ol000?o09Tco`0co`00LC?o00030000oooooooo
04Goool004Koool00`0003?o03?o000K<ol000?o09Tco`0co`00LC?o00030000oooooooo04Goool0
04Ooool00`0003?o03?o000J<ol000?o09Tco`0co`00LC?o00030000oooooooo04Goool004Ooool0
0`0003?o03?o000J<ol000?o09Tco`0co`00LC?o00800016oooo0018oooo00<0000co`0co`006C?o
0003o`2I<ol0<ol0074co`000`000?ooooooo`15oooo0018oooo00<0000co`0co`006C?o0003o`2I
<ol0<ol0074co`000`000?ooooooo`15oooo0019oooo00<0000co`0co`0063?o0003o`2I<ol0<ol0
074co`000`000?ooooooo`15oooo0019oooo00<0000co`0co`0063?o0003o`2I<ol0<ol0074co`00
0`000?ooooooo`15oooo001:oooo00<0000co`0co`005c?o0003o`2I<ol0<ol0074co`000`000?oo
ooooo`15oooo001:oooo00<0000co`0co`005c?o0003o`2I<ol0<ol0074co`000`000?ooooooo`15
oooo001;oooo00<0000co`0co`005S?o0003o`2I<ol0<ol0074co`000`000?ooooooo`15oooo001;
oooo00<0000co`0co`005S?o0003o`2I<ol0<ol0074co`020000A_ooo`00C?oooh`co`18oooo001<
ooooS3?o04Soool004cooon<<ol0B?ooo`00COoooh/co`18oooo001=ooooRc?o04Soool004kooolV
<ol000<0000co`0co`00;c?o00030000<ol0<ol002lco`18oooo001>oooo9C?o00030000<ol0<ol0
00Pco`000`0003?o03?o000V<ol000<0000co`0co`00;S?o04Soool004oooolT<ol000<0000co`0c
o`000S?o00800004<ol000<0000co`0co`003S?o00800004<ol00P0000<co`0500000c?o00030000
<ol0<ol0008co`000`0003?o03?o000^<ol0B?ooo`00Coooob@co`001@0003?o03?o03?o00000002
<ol000<0000co`0co`000S?o00030000<ol0<ol000Dco`0400000c?o00040000<ol0<ol000002S?o
00030000<ol0<ol000<co`000`0003?o03?o0002<ol000<0000co`0co`00;S?o04Soool004oooolS
<ol000<0000co`0co`000S?o00030000<ol0<ol001@co`00100003?o03?o000000Xco`000`0003?o
03?o0003<ol000<0000co`0co`000c?o00030000<ol0<ol002dco`18oooo001@oooo8c?o00030000
<ol0<ol000D0000C<ol000@0000co`0co`00000:<ol000<0000co`0co`0013?o00050000<ol0<ol0
<ol00000030co`18oooo001@oooo8c?o00050000<ol0<ol0<ol0000001Hco`00100003?o03?o0000
00Xco`001@0003?o03?o03?o00000002<ol000D0000co`0co`0co`000000<3?o04Soool0053ooolT
<ol000<0000co`0co`0063?o0080000:<ol00P0000<co`0400000S?o00030000<ol0<ol002lco`18
oooo001AooooQc?o04Soool0057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.33304 .30902 L
.33788 .30902 L
.34055 .30902 L
.34186 .30902 L
.34309 .30902 L
s
.34309 .30902 m
.34309 .61803 L
s
0 .4 1 r
.02381 .3289 m
.06244 .33197 L
.10458 .33587 L
.14415 .34013 L
.18221 .34486 L
.22272 .35071 L
.26171 .35725 L
.30316 .36534 L
.32392 .3699 L
.33304 .37202 L
.33788 .37318 L
.34055 .37383 L
.34186 .37415 L
.34309 .37445 L
.34425 .30902 L
.34549 .30902 L
.3462 .30902 L
.34686 .30902 L
.34811 .30902 L
.34926 .30902 L
.35032 .30902 L
.35148 .30902 L
.35271 .30902 L
.35379 .30902 L
.35494 .30902 L
.35602 .30902 L
.35701 .30902 L
.35817 .30902 L
.35944 .30902 L
.36063 .30902 L
.36173 .30902 L
.36286 .30902 L
.36408 .30902 L
.36523 .30902 L
.36629 .30902 L
.36746 .30902 L
.36874 .30902 L
.36938 .30902 L
.37007 .30902 L
.37132 .30902 L
.37263 .30902 L
.37338 .30902 L
.37406 .30902 L
.37532 .30902 L
.37595 .30902 L
.37665 .30902 L
.37786 .30902 L
.37916 .30902 L
.38038 .30902 L
.3815 .30902 L
Mistroke
.38261 .30902 L
.38378 .30902 L
.38507 .30902 L
.38625 .30902 L
.38735 .30902 L
.38838 .30902 L
.38951 .30902 L
.39071 .30902 L
.39138 .30902 L
.3921 .30902 L
.39341 .30902 L
.39468 .30902 L
.39586 .30902 L
.39694 .30902 L
.39812 .30902 L
.39936 .30902 L
.40052 .30902 L
.40184 .30902 L
.4025 .30902 L
.40323 .30902 L
.40451 .30902 L
.4057 .30902 L
.40643 .30902 L
.40712 .30902 L
.4084 .30902 L
.40912 .30902 L
.40979 .30902 L
.41051 .30902 L
.41128 .30902 L
.41247 .30902 L
.41374 .30902 L
.41494 .30902 L
.41604 .30902 L
.41732 .30902 L
.41805 .30902 L
.41872 .30902 L
.41995 .30902 L
.42126 .30902 L
.42239 .30902 L
.42364 .30902 L
.42493 .30902 L
.42614 .30902 L
.42727 .30902 L
.4283 .30902 L
.42949 .30902 L
.43061 .30902 L
.43184 .30902 L
.43313 .30902 L
.43424 .30902 L
.43545 .30902 L
Mistroke
.43676 .30902 L
.4375 .30902 L
.43817 .30902 L
.43947 .30902 L
.44071 .30902 L
.44186 .30902 L
.4429 .30902 L
.44411 .30902 L
.44524 .30902 L
.44629 .30902 L
.44726 .30902 L
.44832 .30902 L
.44944 .30902 L
.45058 .30902 L
.4518 .30902 L
.45294 .30902 L
.45399 .30902 L
.45522 .30902 L
.45591 .30902 L
.45655 .30902 L
.45773 .30902 L
.45898 .30902 L
.46021 .30902 L
.46136 .30902 L
.46256 .30902 L
.46387 .30902 L
.46501 .30902 L
.46604 .30902 L
.46723 .30902 L
.46836 .30902 L
.46958 .30902 L
.47088 .30902 L
.47199 .30902 L
.47321 .30902 L
.47452 .30902 L
.47525 .30902 L
.47592 .30902 L
.47723 .30902 L
.47846 .30902 L
.4796 .30902 L
.48066 .30902 L
.48189 .30902 L
.48301 .30902 L
.48406 .30902 L
.48503 .30902 L
.48609 .30902 L
.48721 .30902 L
.48835 .30902 L
.48957 .30902 L
.49072 .30902 L
Mistroke
.49176 .30902 L
.49299 .30902 L
.49369 .30902 L
.49433 .30902 L
.4955 .30902 L
.49675 .30902 L
.49795 .30902 L
.49927 .30902 L
.50051 .30902 L
.50166 .30902 L
.5028 .30902 L
.50383 .30902 L
.50503 .30902 L
.50615 .30902 L
.50738 .30902 L
.50869 .30902 L
.5098 .30902 L
.51101 .30902 L
.51233 .30902 L
.51306 .30902 L
.51373 .30902 L
.51504 .30902 L
.51627 .30902 L
.51732 .30902 L
.51848 .30902 L
.51969 .30902 L
.52083 .30902 L
.52188 .30902 L
.52285 .30902 L
.52392 .30902 L
.52504 .30902 L
.52618 .30902 L
.5274 .30902 L
.52854 .30902 L
.52959 .30902 L
.53082 .30902 L
.53151 .30902 L
.53215 .30902 L
.53333 .30902 L
.53457 .30902 L
.53578 .30902 L
.5371 .30902 L
.53834 .30902 L
.5395 .30902 L
.54064 .30902 L
.54168 .30902 L
.54288 .30902 L
.544 .30902 L
.54524 .30902 L
.54654 .30902 L
Mistroke
.54765 .30902 L
.54887 .30902 L
.55019 .30902 L
.55093 .30902 L
.5516 .30902 L
.5529 .30902 L
.55414 .30902 L
.55519 .30902 L
.55635 .30902 L
.55756 .30902 L
.5587 .30902 L
.56075 .30902 L
.56178 .30902 L
.56291 .30902 L
.56415 .30902 L
.56531 .30902 L
.56637 .30902 L
.5675 .30902 L
.56814 .30902 L
.56884 .30902 L
.57009 .30902 L
.57132 .30902 L
.57245 .30902 L
.5737 .30902 L
.5749 .30902 L
.57597 .30902 L
.57713 .30902 L
.5784 .30902 L
.57904 .30902 L
.57974 .30902 L
.58099 .30902 L
.58216 .30902 L
.58327 .30902 L
.58444 .30902 L
.58543 .30902 L
.58653 .30902 L
.58771 .30902 L
.58897 .30902 L
.59016 .30902 L
.59124 .30902 L
.59252 .30902 L
.59317 .30902 L
.59389 .30902 L
.59515 .30902 L
.59633 .30902 L
.59704 .30902 L
.59772 .30902 L
.59899 .30902 L
.5997 .30902 L
.60036 .30902 L
Mistroke
.60108 .30902 L
.60186 .30902 L
.60316 .30902 L
.60389 .30902 L
.60457 .30902 L
.60581 .30902 L
.60712 .30902 L
.6083 .30902 L
.60939 .30902 L
.6106 .30902 L
.61189 .30902 L
.61311 .30902 L
.6138 .30902 L
.61445 .30902 L
.61576 .30902 L
.6165 .30902 L
.61718 .30902 L
.61831 .30902 L
.61956 .30902 L
.62086 .30902 L
.62207 .30902 L
.62276 .30902 L
.62351 .30902 L
.62422 .30902 L
.62487 .30902 L
.62611 .30902 L
.62742 .30902 L
.6281 .30902 L
.62883 .30902 L
.63014 .30902 L
.63089 .30902 L
.6317 .30902 L
.63244 .30902 L
.63314 .30902 L
.63379 .30902 L
.63449 .30902 L
.63572 .30902 L
.63643 .30902 L
.63718 .30902 L
.63783 .30902 L
.63853 .30902 L
.63981 .30902 L
.64053 .30902 L
.64118 .30902 L
.64245 .30902 L
.64365 .30902 L
.64481 .30902 L
.64605 .30902 L
.6471 .30902 L
.64826 .30902 L
Mistroke
.6495 .30902 L
.6502 .30902 L
.65084 .30902 L
.65208 .30902 L
.65326 .30902 L
.6545 .30902 L
.6552 .30902 L
.65584 .30902 L
.65703 .30902 L
.65828 .30902 L
.6594 .30902 L
.66045 .30902 L
.6616 .30902 L
.66283 .30902 L
.66415 .30902 L
.66489 .30902 L
.66557 .30902 L
.66683 .30902 L
.66747 .30902 L
.66817 .30902 L
.66938 .30902 L
.67069 .30902 L
.67192 .30902 L
.67305 .30902 L
.67411 .30902 L
.67526 .30902 L
.67634 .30902 L
.67732 .30902 L
.67847 .30902 L
.67972 .30902 L
.6809 .30902 L
.682 .30902 L
.68313 .30902 L
.68438 .30902 L
.68559 .30902 L
.6869 .30902 L
.68811 .30902 L
.68927 .30902 L
.6903 .30902 L
.69143 .30902 L
.69207 .30902 L
.69276 .30902 L
.69398 .30902 L
.6953 .30902 L
.69606 .30902 L
.69675 .30902 L
.698 .30902 L
.69869 .30902 L
.69934 .30902 L
.7005 .30902 L
Mistroke
.70176 .30902 L
.71112 .30902 L
.71641 .30902 L
.71769 .30902 L
.71841 .30902 L
.71908 .30902 L
.71982 .30902 L
.7206 .30902 L
.72128 .30902 L
.72202 .30902 L
.7227 .30902 L
.72334 .30902 L
.72455 .30902 L
.72584 .30902 L
.72657 .30902 L
.72724 .30902 L
.72837 .30902 L
.7296 .30902 L
.73089 .30902 L
.7321 .30902 L
.73335 .30902 L
.73405 .30902 L
.73469 .30902 L
.73592 .30902 L
.73709 .30902 L
.73775 .30902 L
.73845 .30902 L
.7397 .30902 L
.7404 .30902 L
.74105 .30902 L
.74176 .30902 L
.74252 .30902 L
.7438 .30902 L
.74452 .30902 L
.74518 .30902 L
.7464 .30902 L
.7477 .30902 L
.74994 .30902 L
.75121 .30902 L
.75241 .30902 L
.75355 .30902 L
.7548 .30902 L
.75598 .30902 L
.75707 .30902 L
.75816 .30902 L
.75914 .30902 L
.76027 .30902 L
.76134 .30902 L
.76251 .30902 L
.76374 .30902 L
Mistroke
.7648 .30902 L
.76596 .30902 L
.7672 .30902 L
.76789 .30902 L
.76854 .30902 L
.7698 .30902 L
.77095 .30902 L
.77209 .30902 L
.77332 .30902 L
.77448 .30902 L
.77554 .30902 L
.77672 .30902 L
.77801 .30902 L
.77866 .30902 L
.77935 .30902 L
.7806 .30902 L
.78129 .30902 L
.78193 .30902 L
.78263 .30902 L
.78337 .30902 L
.78461 .30902 L
.78531 .30902 L
.78597 .30902 L
.7872 .30902 L
.78833 .30902 L
.79086 .30902 L
.80928 .30902 L
.84903 .30902 L
.88727 .30902 L
.92797 .30902 L
.96714 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000D0
000co`0co`0co`00I_l01C?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0
000co`0co`00;c?o00030000<ol0<ol001lco`000`1Voc?o03?o000=<ol000<0000co`0co`00;S?o
00030000<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Ooooe@co`00
0`1Voc?o03?o001`<ol000<0003oooooool0AOooo`004Ooooe@co`000`1Voc?o03?o001`<ol000<0
003oooooool0AOooo`004Oooo`H0I_m><ol000<0I_lco`0co`00L3?o00030000oooooooo04Goool0
017oool6<ol02P1Vod@co`000`1Voc?o03?o001`<ol000<0003oooooool0AOooo`004Ooooa0co`0;
06Ko>C?o000306Ko<ol0<ol0070co`000`000?ooooooo`15oooo000Aoooo6c?o00X0I_l_<ol000<0
I_lco`0co`00L3?o00800016oooo000Aoooo9C?o00P0I_lW<ol000<0I_lco`0co`00L3?o00030000
oooooooo04Goool0017oool]<ol01@1Vob8co`000`1Voc?o03?o001`<ol000<0003oooooool0AOoo
o`004Ooooc8co`0506Ko7C?o000306Ko<ol0<ol0070co`000`000?ooooooo`15oooo000Aoooo=c?o
00D0I_lH<ol000<0I_lco`0co`00L3?o00030000oooooooo04Goool0017oooll<ol01@1Voa<co`00
0`1Voc?o03?o001`<ol000<0003oooooool0AOooo`004Ooood4co`0606Ko3C?o000306Ko<ol0<ol0
070co`000`000?ooooooo`15oooo000AooooAc?o00D0I_l8<ol000<0I_lco`0co`00L3?o00030000
oooooooo04Goool0017oool20000BS?o00@0I_l4<ol000<0I_lco`0co`00L3?o00800016oooo000C
oooo0P0004`co`0506KoLS?o00030000oooooooo04Goool001Goool20000CS?o0003o`2I<ol0<ol0
070co`000`000?ooooooo`15oooo000Goooo0P0004`co`000ol0VC?o03?o001`<ol000<0003ooooo
ool0AOooo`006Oooo`80001:<ol000?o09Tco`0co`00L3?o00030000oooooooo04Goool001_oool2
0000B3?o0003o`2I<ol0<ol0070co`000`000?ooooooo`15oooo000Moooo0P0004Hco`000ol0VC?o
03?o001`<ol000<0003oooooool0AOooo`007oooo`030000<ol0<ol004<co`000ol0VC?o03?o001`
<ol000<0003oooooool0AOooo`008?ooo`030000<ol0<ol0048co`000ol0VC?o03?o001`<ol00P00
04Koool0027oool20000@S?o0003o`2I<ol0<ol0070co`000`000?ooooooo`15oooo000Soooo00<0
000co`0co`00?c?o0003o`2I<ol0<ol0070co`000`000?ooooooo`15oooo000Toooo0P0003lco`00
0ol0VC?o03?o001`<ol000<0003oooooool0AOooo`009_ooo`030000<ol0<ol003`co`000ol0VC?o
03?o001`<ol000<0003oooooool0AOooo`009oooo`030000<ol0<ol003/co`000ol0VC?o03?o001`
<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol003Xco`000ol0VC?o03?o001G<ol00P00
00@co`02000013?o00800003<ol0100000@co`000`000?ooooooo`15oooo000Yoooo00<0000co`0c
o`00>C?o0003o`2I<ol0<ol005Hco`00100003?o03?o000000Pco`00100003?o03?o0000008co`00
0`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_ooo`030000<ol0<ol003Pco`000ol0VC?o
03?o001F<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o
00<00015oooo000[oooo0P0003Pco`000ol0VC?o03?o001F<ol000@0000co`0co`000008<ol000@0
000co`0co`000004<ol000<0000co`0co`000c?o00030000oooooooo04Goool002goool00`0003?o
03?o000e<ol000?o09Tco`0co`00ES?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o
00040000<ol0<ol0000013?o00030000oooooooo04Goool002koool00`0003?o03?o000d<ol000?o
09Tco`0co`00Ec?o0080000:<ol00P0000@co`0200001C?o00030000oooooooo04Goool002ooool0
0`0003?o03?o000c<ol000?o09Tco`0co`00L3?o00030000oooooooo04Goool0033oool00`0003?o
03?o000b<ol000?o09Tco`0co`00L3?o00030000oooooooo04Goool0037oool00`0003?o03?o000a
<ol000?o09Tco`0co`00L3?o00030000oooooooo04Goool003;oool00`0003?o03?o000`<ol000?o
09Tco`0co`00L3?o00030000oooooooo04Goool003?oool00`0003?o03?o000_<ol000?o09Tco`0c
o`00L3?o00800016oooo000coooo00<0000co`0co`00;c?o0003o`2I<ol0<ol0070co`000`000?oo
ooooo`15oooo000doooo00<0000co`0co`00;S?o0003o`2I<ol0<ol0070co`000`000?ooooooo`15
oooo000eoooo00<0000co`0co`00;C?o0003o`2I<ol0<ol0070co`000`000?ooooooo`15oooo000f
oooo00<0000co`0co`00;3?o0003o`2I<ol0<ol0070co`000`000?ooooooo`15oooo000goooo00<0
000co`0co`00:c?o0003o`2I<ol0<ol0070co`000`000?ooooooo`15oooo000hoooo00<0000co`0c
o`00:S?o0003o`2I<ol0<ol0070co`000`000?ooooooo`15oooo000hoooo00<0000co`0co`00:S?o
0003o`2I<ol0<ol0070co`000`000?ooooooo`15oooo000ioooo00<0000co`0co`00:C?o0003o`2I
<ol0<ol0070co`020000A_ooo`00>_ooo`030000<ol0<ol002Pco`000ol0VC?o03?o001`<ol000<0
003oooooool0AOooo`00>oooo`030000<ol0<ol002Lco`000ol0VC?o03?o001`<ol000<0003ooooo
ool0AOooo`00??ooo`030000<ol0<ol002Hco`000ol0VC?o03?o001`<ol000<0003oooooool0AOoo
o`00??ooo`030000<ol0<ol002Hco`000ol0VC?o03?o001`<ol000<0003oooooool0AOooo`00?Ooo
o`030000<ol0<ol002Dco`000ol0VC?o03?o001`<ol000<0003oooooool0AOooo`00?Oooo`030000
<ol0<ol002Dco`000ol0VC?o03?o001`<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol0
02@co`000ol0VC?o03?o001`<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol002@co`00
0ol0VC?o03?o001`<ol000<0003oooooool0AOooo`00?oooo`030000<ol0<ol002<co`000ol0VC?o
03?o001`<ol00P0004Koool003ooool00`0003?o03?o000S<ol000?o09Tco`0co`00L3?o00030000
oooooooo04Goool0043oool00`0003?o03?o000R<ol000?o09Tco`0co`00L3?o00030000oooooooo
04Goool0047oool00`0003?o03?o000Q<ol000?o09Tco`0co`00L3?o00030000oooooooo04Goool0
047oool00`0003?o03?o000Q<ol000?o09Tco`0co`00L3?o00030000oooooooo04Goool004;oool0
0`0003?o03?o000P<ol000?o09Tco`0co`00L3?o00030000oooooooo04Goool004;oool00`0003?o
03?o000P<ol000?o09Tco`0co`00Ec?o00800004<ol00P0000@co`0200001C?o00<00003<ol000<0
003oooooool0AOooo`00@oooo`030000<ol0<ol001lco`000ol0VC?o03?o001F<ol000@0000co`0c
o`000008<ol000@0000co`0co`000005<ol000<0000co`0co`000S?o00030000oooooooo04Goool0
04?oool00`0003?o03?o000O<ol000?o09Tco`0co`00ES?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool00`0003?o03?o000N<ol000?o09Tco`0c
o`00ES?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o
00030000oooooooo04Goool004Coool00`0003?o03?o000N<ol000?o09Tco`0co`00ES?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0000000@co`000`000?ooooooo`15
oooo0015oooo00<0000co`0co`007C?o0003o`2I<ol0<ol005Lco`0200002S?o00800005<ol00P00
00@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`007C?o0003o`2I<ol0<ol0070co`00
0`000?ooooooo`15oooo0016oooo00<0000co`0co`0073?o0003o`2I<ol0<ol0070co`000`000?oo
ooooo`15oooo0016oooo00<0000co`0co`0073?o0003o`2I<ol0<ol0070co`000`000?ooooooo`15
oooo0017oooo00<0000co`0co`006c?o0003o`2I<ol0<ol0070co`000`000?ooooooo`15oooo0017
oooo00<0000co`0co`006c?o0003o`2I<ol0<ol0070co`020000A_ooo`00B?ooo`030000<ol0<ol0
01Xco`000ol0VC?o03?o001`<ol000<0003oooooool0AOooo`00B?ooo`030000<ol0<ol001Xco`00
0ol0VC?o03?o001`<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol001Tco`000ol0VC?o
03?o001`<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol001Tco`000ol0VC?o03?o001`
<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol001Pco`000ol0VC?o03?o001`<ol000<0
003oooooool0AOooo`00B_ooo`030000<ol0<ol001Pco`000ol0VC?o03?o001`<ol000<0003ooooo
ool0AOooo`00Boooo`030000<ol0<ol001Lco`000ol0VC?o03?o001`<ol000<0003oooooool0AOoo
o`00Boooo`030000<ol0<ol001Lco`000ol0VC?o03?o001`<ol00P0004Koool004cooon<<ol0B?oo
o`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;<ol0B?ooo`00COoooh/co`18oooo001>
oooo9S?o00030000<ol0<ol002lco`000`0003?o03?o000_<ol0B?ooo`00C_ooobDco`000`0003?o
03?o0008<ol000<0000co`0co`009S?o00030000<ol0<ol002hco`18oooo001?oooo93?o00030000
<ol0<ol0008co`02000013?o00030000<ol0<ol000hco`02000013?o00800003<ol01@000004<ol0
00000000000013?o00030000<ol0<ol002hco`18oooo001?oooo93?o00050000<ol0<ol0<ol00000
008co`000`0003?o03?o0002<ol000<0000co`0co`001C?o00@00003<ol000@0000co`0co`00000:
<ol000D0000co`0co`0co`0000000S?o00050000<ol0<ol0<ol00000030co`18oooo001?oooo8c?o
00030000<ol0<ol0008co`000`0003?o03?o000D<ol000@0000co`0co`00000:<ol000D0000co`0c
o`0co`0000000S?o00030000<ol0<ol0008co`000`0003?o03?o000]<ol0B?ooo`00D?ooob<co`00
0`0003?o03?o000500004c?o00040000<ol0<ol000002S?o00040000<ol0<ol0<ol00`0000@co`00
0`0003?o03?o000^<ol0B?ooo`00D?ooob<co`001@0003?o03?o03?o0000000F<ol000@0000co`0c
o`00000:<ol000<0000co`0co`000S?o00030000<ol0<ol000<co`000`0003?o03?o000^<ol0B?oo
o`00D?ooob@co`000`0003?o03?o000H<ol00P0000Xco`02000013?o00<00002<ol000<0000co`0c
o`00;c?o04Soool0057ooon7<ol0B?ooo`00DOooohLco`18oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.33304 .30902 L
.33788 .30902 L
.34055 .30902 L
.34309 .30902 L
.34549 .30902 L
.34615 .30902 L
.34685 .30902 L
s
.34685 .30902 m
.34686 .61803 L
s
0 .4 1 r
.02381 .32764 m
.06244 .33052 L
.10458 .33416 L
.14415 .33815 L
.18221 .34259 L
.22272 .34806 L
.26171 .35419 L
.30316 .36177 L
.32392 .36604 L
.33304 .36802 L
.33788 .36911 L
.34055 .36971 L
.34309 .3703 L
.34549 .37085 L
.34615 .37101 L
.34685 .37117 L
.34811 .30902 L
.34935 .30902 L
.35053 .30902 L
.35158 .30902 L
.35271 .30902 L
.35389 .30902 L
.355 .30902 L
.35615 .30902 L
.35741 .30902 L
.3585 .30902 L
.3595 .30902 L
.36064 .30902 L
.36173 .30902 L
.36287 .30902 L
.36412 .30902 L
.36542 .30902 L
.36665 .30902 L
.3678 .30902 L
.36887 .30902 L
.36998 .30902 L
.3712 .30902 L
.37245 .30902 L
.37315 .30902 L
.37379 .30902 L
.375 .30902 L
.37616 .30902 L
.3768 .30902 L
.37749 .30902 L
.37872 .30902 L
.3794 .30902 L
.38004 .30902 L
.38075 .30902 L
.3815 .30902 L
.38219 .30902 L
Mistroke
.38284 .30902 L
.38405 .30902 L
.38535 .30902 L
.38608 .30902 L
.38676 .30902 L
.38789 .30902 L
.38913 .30902 L
.39042 .30902 L
.39163 .30902 L
.39232 .30902 L
.39306 .30902 L
.39377 .30902 L
.39442 .30902 L
.39565 .30902 L
.39696 .30902 L
.39764 .30902 L
.39837 .30902 L
.39968 .30902 L
.40043 .30902 L
.40123 .30902 L
.40199 .30902 L
.40267 .30902 L
.40393 .30902 L
.40512 .30902 L
.4064 .30902 L
.40712 .30902 L
.40779 .30902 L
.40903 .30902 L
.40974 .30902 L
.4104 .30902 L
.4111 .30902 L
.41174 .30902 L
.41247 .30902 L
.41317 .30902 L
.41432 .30902 L
.41556 .30902 L
.41661 .30902 L
.41777 .30902 L
.41901 .30902 L
.41971 .30902 L
.42035 .30902 L
.42153 .30902 L
.42278 .30902 L
.42392 .30902 L
.42513 .30902 L
.42576 .30902 L
.42645 .30902 L
.42768 .30902 L
.42883 .30902 L
.43007 .30902 L
Mistroke
.43124 .30902 L
.4323 .30902 L
.43361 .30902 L
.43435 .30902 L
.43504 .30902 L
.4363 .30902 L
.437 .30902 L
.43764 .30902 L
.43884 .30902 L
.44014 .30902 L
.44137 .30902 L
.44249 .30902 L
.44356 .30902 L
.4447 .30902 L
.44577 .30902 L
.44675 .30902 L
.4479 .30902 L
.44915 .30902 L
.45033 .30902 L
.45142 .30902 L
.45254 .30902 L
.4536 .30902 L
.45475 .30902 L
.456 .30902 L
.45723 .30902 L
.45853 .30902 L
.45974 .30902 L
.46085 .30902 L
.46209 .30902 L
.46274 .30902 L
.46343 .30902 L
.46459 .30902 L
.46586 .30902 L
.46699 .30902 L
.46821 .30902 L
.46936 .30902 L
.47041 .30902 L
.47171 .30902 L
.47291 .30902 L
.47423 .30902 L
.47497 .30902 L
.47564 .30902 L
.47687 .30902 L
.47756 .30902 L
.4782 .30902 L
.47937 .30902 L
.48061 .30902 L
.48176 .30902 L
.4828 .30902 L
.48401 .30902 L
Mistroke
.48515 .30902 L
.4862 .30902 L
.48717 .30902 L
.48824 .30902 L
.48938 .30902 L
.49395 .30902 L
.4952 .30902 L
.49589 .30902 L
.49654 .30902 L
.49782 .30902 L
.49898 .30902 L
.50022 .30902 L
.50157 .30902 L
.50284 .30902 L
.504 .30902 L
.50506 .30902 L
.50622 .30902 L
.50743 .30902 L
.50856 .30902 L
.50919 .30902 L
.50988 .30902 L
.51114 .30902 L
.51236 .30902 L
.51349 .30902 L
.51481 .30902 L
.51605 .30902 L
.51735 .30902 L
.51803 .30902 L
.51878 .30902 L
.51993 .30902 L
.52101 .30902 L
.52219 .30902 L
.52345 .30902 L
.52408 .30902 L
.52477 .30902 L
.52602 .30902 L
.52724 .30902 L
.52837 .30902 L
.52942 .30902 L
.5304 .30902 L
.53148 .30902 L
.53264 .30902 L
.53385 .30902 L
.535 .30902 L
.53603 .30902 L
.53716 .30902 L
.53781 .30902 L
.53849 .30902 L
.53972 .30902 L
.54104 .30902 L
Mistroke
.54179 .30902 L
.54249 .30902 L
.54375 .30902 L
.54491 .30902 L
.54555 .30902 L
.54624 .30902 L
.5475 .30902 L
.54862 .30902 L
.54986 .30902 L
.55115 .30902 L
.55237 .30902 L
.5535 .30902 L
.55453 .30902 L
.55567 .30902 L
.55686 .30902 L
.55818 .30902 L
.55938 .30902 L
.56004 .30902 L
.56076 .30902 L
.56206 .30902 L
.56328 .30902 L
.56457 .30902 L
.56568 .30902 L
.56689 .30902 L
.56762 .30902 L
.56832 .30902 L
.56962 .30902 L
.5703 .30902 L
.57102 .30902 L
.57182 .30902 L
.57255 .30902 L
.57385 .30902 L
.57507 .30902 L
.57641 .30902 L
.57715 .30902 L
.57785 .30902 L
.57912 .30902 L
.58027 .30902 L
.58135 .30902 L
.58253 .30902 L
.58382 .30902 L
.58453 .30902 L
.58519 .30902 L
.58637 .30902 L
.58766 .30902 L
.58829 .30902 L
.58899 .30902 L
.59026 .30902 L
.59149 .30902 L
.59264 .30902 L
Mistroke
.59334 .30902 L
.594 .30902 L
.59523 .30902 L
.59592 .30902 L
.59656 .30902 L
.59726 .30902 L
.59799 .30902 L
.59915 .30902 L
.6002 .30902 L
.60141 .30902 L
.60256 .30902 L
.60354 .30902 L
.60459 .30902 L
.60575 .30902 L
.60681 .30902 L
.60795 .30902 L
.60918 .30902 L
.61035 .30902 L
.61141 .30902 L
.61259 .30902 L
.61389 .30902 L
.61454 .30902 L
.61523 .30902 L
.61649 .30902 L
.61772 .30902 L
.61843 .30902 L
.61908 .30902 L
.61976 .30902 L
.6205 .30902 L
.62118 .30902 L
.62182 .30902 L
.62304 .30902 L
.62417 .30902 L
.62541 .30902 L
.62674 .30902 L
.62749 .30902 L
.62818 .30902 L
.62894 .30902 L
.62974 .30902 L
.63044 .30902 L
.63109 .30902 L
.6318 .30902 L
.63256 .30902 L
.63324 .30902 L
.63398 .30902 L
.63468 .30902 L
.63533 .30902 L
.63655 .30902 L
.63784 .30902 L
.63908 .30902 L
Mistroke
.64022 .30902 L
.64154 .30902 L
.64279 .30902 L
.64394 .30902 L
.64501 .30902 L
.64618 .30902 L
.64743 .30902 L
.64814 .30902 L
.6488 .30902 L
.64952 .30902 L
.65028 .30902 L
.65156 .30902 L
.65229 .30902 L
.65297 .30902 L
.65423 .30902 L
.65493 .30902 L
.65558 .30902 L
.65673 .30902 L
.65799 .30902 L
.65925 .30902 L
.6604 .30902 L
.66166 .30902 L
.66299 .30902 L
.66364 .30902 L
.66434 .30902 L
.66559 .30902 L
.66636 .30902 L
.66708 .30902 L
.66772 .30902 L
.66843 .30902 L
.66963 .30902 L
.6709 .30902 L
.67208 .30902 L
.67318 .30902 L
.67445 .30902 L
.67566 .30902 L
.67633 .30902 L
.67705 .30902 L
.67833 .30902 L
.67959 .30902 L
.68077 .30902 L
.68184 .30902 L
.68299 .30902 L
.68424 .30902 L
.68488 .30902 L
.68557 .30902 L
.6868 .30902 L
.68795 .30902 L
.68911 .30902 L
.69021 .30902 L
Mistroke
.69119 .30902 L
.69226 .30902 L
.69342 .30902 L
.69466 .30902 L
.69571 .30902 L
.69688 .30902 L
.6981 .30902 L
.69923 .30902 L
.70048 .30902 L
.70117 .30902 L
.7018 .30902 L
.70308 .30902 L
.7038 .30902 L
.70447 .30902 L
.70569 .30902 L
.70699 .30902 L
.70808 .30902 L
.70926 .30902 L
.71029 .30902 L
.7114 .30902 L
.7127 .30902 L
.71393 .30902 L
.71513 .30902 L
.71625 .30902 L
.71756 .30902 L
.7183 .30902 L
.71898 .30902 L
.72023 .30902 L
.72155 .30902 L
.72274 .30902 L
.72384 .30902 L
.72506 .30902 L
.72635 .30902 L
.72708 .30902 L
.72774 .30902 L
.72847 .30902 L
.72925 .30902 L
.73055 .30902 L
.73129 .30902 L
.73199 .30902 L
.73327 .30902 L
.73445 .30902 L
.7351 .30902 L
.73581 .30902 L
.73711 .30902 L
.73966 .30902 L
.74036 .30902 L
.7411 .30902 L
.74242 .30902 L
.74365 .30902 L
Mistroke
.74481 .30902 L
.74607 .30902 L
.74678 .30902 L
.74742 .30902 L
.74862 .30902 L
.74972 .30902 L
.75094 .30902 L
.75223 .30902 L
.75334 .30902 L
.75439 .30902 L
.75554 .30902 L
.75678 .30902 L
.7581 .30902 L
.75932 .30902 L
.76003 .30902 L
.76067 .30902 L
.76141 .30902 L
.76211 .30902 L
.76279 .30902 L
.76351 .30902 L
.7648 .30902 L
.76552 .30902 L
.76619 .30902 L
.76693 .30902 L
.76772 .30902 L
.769 .30902 L
.76973 .30902 L
.77041 .30902 L
.77164 .30902 L
.77296 .30902 L
.77425 .30902 L
.77547 .30902 L
.77666 .30902 L
.77775 .30902 L
.77892 .30902 L
.78017 .30902 L
.78132 .30902 L
.78242 .30902 L
.78369 .30902 L
.78487 .30902 L
.78616 .30902 L
.78682 .30902 L
.78754 .30902 L
.79786 .30902 L
.81635 .30902 L
.8566 .30902 L
.89533 .30902 L
.93652 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`000S?o000306Ko<ol0<ol0008co`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool04ooo
o`004Oooo`030000<ol0<ol002lco`000`0003?o03?o000P<ol000<0I_lco`0co`0033?o00030000
<ol0<ol002hco`000`0003?o03?o000_<ol000<0003oooooool0;oooo`030000oooooooo01?oool0
017ooomE<ol000<0I_lco`0co`00Kc?o00030000oooooooo04Goool0017ooomE<ol000<0I_lco`0c
o`00Kc?o00030000oooooooo04Goool0017oool606KoCc?o000306Ko<ol0<ol006lco`000`000?oo
ooooo`15oooo000Aoooo1S?o00X0I_m5<ol000<0I_lco`0co`00Kc?o00030000oooooooo04Goool0
017oool@<ol02`1VocXco`000`1Voc?o03?o001_<ol000<0003oooooool0AOooo`004Ooooa/co`0:
06Ko<3?o000306Ko<ol0<ol006lco`020000A_ooo`004OooobDco`0:06Ko9S?o000306Ko<ol0<ol0
06lco`000`000?ooooooo`15oooo000Aoooo;c?o00P0I_lN<ol000<0I_lco`0co`00Kc?o00030000
oooooooo04Goool0017ooolg<ol01@1VoaTco`000`1Voc?o03?o001_<ol000<0003oooooool0AOoo
o`004Ooooc`co`0506Ko53?o000306Ko<ol0<ol006lco`000`000?ooooooo`15oooo000Aoooo@C?o
00H0I_l><ol000<0I_lco`0co`00Kc?o00030000oooooooo04Goool0017ooom7<ol01@1Vo`Tco`00
0`1Voc?o03?o001_<ol000<0003oooooool0AOooo`004Ooood`co`0406Ko1C?o000306Ko<ol0<ol0
06lco`000`000?ooooooo`15oooo000Aoooo0P0004hco`0606KoLC?o00800016oooo000Coooo0P00
054co`000ol0VC?o03?o001_<ol000<0003oooooool0AOooo`005Oooo`80001?<ol000?o09Tco`0c
o`00Kc?o00030000oooooooo04Goool001Ooool20000CC?o0003o`2I<ol0<ol006lco`000`000?oo
ooooo`15oooo000Ioooo0P0004/co`000ol0VC?o03?o001_<ol000<0003oooooool0AOooo`006ooo
o`800019<ol000?o09Tco`0co`00Kc?o00030000oooooooo04Goool001goool20000Ac?o0003o`2I
<ol0<ol006lco`000`000?ooooooo`15oooo000Ooooo00<0000co`0co`00A3?o0003o`2I<ol0<ol0
06lco`000`000?ooooooo`15oooo000Poooo00<0000co`0co`00@c?o0003o`2I<ol0<ol006lco`02
0000A_ooo`008Oooo`800013<ol000?o09Tco`0co`00Kc?o00030000oooooooo04Goool002?oool0
0`0003?o03?o0010<ol000?o09Tco`0co`00Kc?o00030000oooooooo04Goool002Coool20000@3?o
0003o`2I<ol0<ol006lco`000`000?ooooooo`15oooo000Voooo00<0000co`0co`00?C?o0003o`2I
<ol0<ol006lco`000`000?ooooooo`15oooo000Woooo00<0000co`0co`00?3?o0003o`2I<ol0<ol0
06lco`000`000?ooooooo`15oooo000Xoooo00<0000co`0co`00>c?o0003o`2I<ol0<ol005Hco`02
000013?o00800004<ol00P0000<co`04000013?o00030000oooooooo04Goool002Woool00`0003?o
03?o000j<ol000?o09Tco`0co`00EC?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o
00030000<ol0<ol000Dco`000`000?ooooooo`15oooo000Zoooo00<0000co`0co`00>C?o0003o`2I
<ol0<ol005Dco`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o0004
<ol00`0004Goool002_oool20000>C?o0003o`2I<ol0<ol005Dco`00100003?o03?o000000Pco`00
100003?o03?o000000@co`000`0003?o03?o0003<ol000<0003oooooool0AOooo`00;Oooo`030000
<ol0<ol003Hco`000ol0VC?o03?o001E<ol000@0000co`0co`000008<ol000@0000co`0co`000002
<ol000@0000co`0co`000004<ol000<0003oooooool0AOooo`00;_ooo`030000<ol0<ol003Dco`00
0ol0VC?o03?o001F<ol00P0000Xco`02000013?o00800005<ol000<0003oooooool0AOooo`00;ooo
o`030000<ol0<ol003@co`000ol0VC?o03?o001_<ol000<0003oooooool0AOooo`00<?ooo`030000
<ol0<ol003<co`000ol0VC?o03?o001_<ol000<0003oooooool0AOooo`00<Oooo`030000<ol0<ol0
038co`000ol0VC?o03?o001_<ol000<0003oooooool0AOooo`00<_ooo`030000<ol0<ol0034co`00
0ol0VC?o03?o001_<ol000<0003oooooool0AOooo`00<oooo`030000<ol0<ol0030co`000ol0VC?o
03?o001_<ol00P0004Koool003?oool00`0003?o03?o000`<ol000?o09Tco`0co`00Kc?o00030000
oooooooo04Goool003Coool00`0003?o03?o000_<ol000?o09Tco`0co`00Kc?o00030000oooooooo
04Goool003Goool00`0003?o03?o000^<ol000?o09Tco`0co`00Kc?o00030000oooooooo04Goool0
03Koool00`0003?o03?o000]<ol000?o09Tco`0co`00Kc?o00030000oooooooo04Goool003Ooool0
0`0003?o03?o000/<ol000?o09Tco`0co`00Kc?o00030000oooooooo04Goool003Soool00`0003?o
03?o000[<ol000?o09Tco`0co`00Kc?o00030000oooooooo04Goool003Soool00`0003?o03?o000[
<ol000?o09Tco`0co`00Kc?o00030000oooooooo04Goool003Woool00`0003?o03?o000Z<ol000?o
09Tco`0co`00Kc?o00800016oooo000joooo00<0000co`0co`00:C?o0003o`2I<ol0<ol006lco`00
0`000?ooooooo`15oooo000koooo00<0000co`0co`00:3?o0003o`2I<ol0<ol006lco`000`000?oo
ooooo`15oooo000loooo00<0000co`0co`009c?o0003o`2I<ol0<ol006lco`000`000?ooooooo`15
oooo000loooo00<0000co`0co`009c?o0003o`2I<ol0<ol006lco`000`000?ooooooo`15oooo000m
oooo00<0000co`0co`009S?o0003o`2I<ol0<ol006lco`000`000?ooooooo`15oooo000moooo00<0
000co`0co`009S?o0003o`2I<ol0<ol006lco`000`000?ooooooo`15oooo000noooo00<0000co`0c
o`009C?o0003o`2I<ol0<ol006lco`000`000?ooooooo`15oooo000noooo00<0000co`0co`009C?o
0003o`2I<ol0<ol006lco`000`000?ooooooo`15oooo000ooooo00<0000co`0co`0093?o0003o`2I
<ol0<ol006lco`020000A_ooo`00?oooo`030000<ol0<ol002@co`000ol0VC?o03?o001_<ol000<0
003oooooool0AOooo`00@?ooo`030000<ol0<ol002<co`000ol0VC?o03?o001_<ol000<0003ooooo
ool0AOooo`00@Oooo`030000<ol0<ol0028co`000ol0VC?o03?o001_<ol000<0003oooooool0AOoo
o`00@Oooo`030000<ol0<ol0028co`000ol0VC?o03?o001_<ol000<0003oooooool0AOooo`00@_oo
o`030000<ol0<ol0024co`000ol0VC?o03?o001_<ol000<0003oooooool0AOooo`00@_ooo`030000
<ol0<ol0024co`000ol0VC?o03?o001F<ol00P0000@co`02000013?o00800005<ol00`0000<co`00
0`000?ooooooo`15oooo0013oooo00<0000co`0co`0083?o0003o`2I<ol0<ol005Dco`00100003?o
03?o000000Pco`00100003?o03?o000000Dco`000`0003?o03?o0002<ol000<0003oooooool0AOoo
o`00@oooo`030000<ol0<ol0020co`000ol0VC?o03?o001E<ol000@0000co`0co`000008<ol000@0
000co`0co`000002<ol01@0000<co`030000AOooo`00A?ooo`030000<ol0<ol001lco`000ol0VC?o
03?o001E<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000004
<ol000<0003oooooool0AOooo`00A?ooo`030000<ol0<ol001lco`000ol0VC?o03?o001E<ol000@0
000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`00000013?o00030000oooooooo
04Goool004Goool00`0003?o03?o000N<ol000?o09Tco`0co`00ES?o0080000:<ol00P0000Dco`02
000013?o00030000oooooooo04Goool004Goool00`0003?o03?o000N<ol000?o09Tco`0co`00Kc?o
00030000oooooooo04Goool004Koool00`0003?o03?o000M<ol000?o09Tco`0co`00Kc?o00030000
oooooooo04Goool004Koool00`0003?o03?o000M<ol000?o09Tco`0co`00Kc?o00030000oooooooo
04Goool004Ooool00`0003?o03?o000L<ol000?o09Tco`0co`00Kc?o00030000oooooooo04Goool0
04Ooool00`0003?o03?o000L<ol000?o09Tco`0co`00Kc?o00800016oooo0018oooo00<0000co`0c
o`006c?o0003o`2I<ol0<ol006lco`000`000?ooooooo`15oooo0018oooo00<0000co`0co`006c?o
0003o`2I<ol0<ol006lco`000`000?ooooooo`15oooo0019oooo00<0000co`0co`006S?o0003o`2I
<ol0<ol006lco`000`000?ooooooo`15oooo0019oooo00<0000co`0co`006S?o0003o`2I<ol0<ol0
06lco`000`000?ooooooo`15oooo001:oooo00<0000co`0co`006C?o0003o`2I<ol0<ol006lco`00
0`000?ooooooo`15oooo001:oooo00<0000co`0co`006C?o0003o`2I<ol0<ol006lco`000`000?oo
ooooo`15oooo001;oooo00<0000co`0co`0063?o0003o`2I<ol0<ol006lco`000`000?ooooooo`15
oooo001;oooo00<0000co`0co`0063?o0003o`2I<ol0<ol006lco`020000A_ooo`00C?oooh`co`18
oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00COoooh/co`18oooo001=ooooRc?o04Soool0
04kooolV<ol000<0000co`0co`00;c?o00030000<ol0<ol002lco`18oooo001>oooo9C?o00030000
<ol0<ol000Pco`000`0003?o03?o000V<ol000<0000co`0co`00;S?o04Soool004oooolT<ol000<0
000co`0co`000S?o00800004<ol000<0000co`0co`003S?o00800004<ol00P0000<co`0500000S?o
00800004<ol000<0000co`0co`00;S?o04Soool004oooolT<ol000D0000co`0co`0co`0000000S?o
00030000<ol0<ol0008co`000`0003?o03?o0005<ol0100000<co`00100003?o03?o000000Xco`00
1@0003?o03?o03?o00000002<ol000D0000co`0co`0co`000000<3?o04Soool004oooolS<ol000<0
000co`0co`000S?o00030000<ol0<ol001@co`00100003?o03?o000000Xco`000`0003?o03?o0004
<ol000<0000co`0co`000S?o00030000<ol0<ol002dco`18oooo001@oooo8c?o00030000<ol0<ol0
00D0000C<ol000@0000co`0co`00000:<ol000<0000co`0co`000S?o00800004<ol000<0000co`0c
o`00;S?o04Soool0053ooolS<ol000D0000co`0co`0co`0000005S?o00040000<ol0<ol000002S?o
00030000<ol0<ol0008co`000`0003?o03?o0003<ol000<0000co`0co`00;S?o04Soool0053ooolT
<ol000<0000co`0co`0063?o0080000:<ol00P0000@co`0300000S?o00030000<ol0<ol002lco`18
oooo001AooooQc?o04Soool0057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.33304 .30902 L
.33788 .30902 L
.34309 .30902 L
.34566 .30902 L
.34811 .30902 L
.34918 .30902 L
.35031 .30902 L
s
.35031 .30902 m
.35032 .61803 L
s
0 .4 1 r
.02381 .32638 m
.06244 .32906 L
.10458 .33246 L
.14415 .33618 L
.18221 .34032 L
.22272 .34543 L
.26171 .35113 L
.30316 .3582 L
.32392 .36219 L
.33304 .36404 L
.33788 .36505 L
.34309 .36616 L
.34566 .36671 L
.34811 .36725 L
.34918 .36748 L
.35031 .36773 L
.35156 .30902 L
.35271 .30902 L
.35388 .30902 L
.35515 .30902 L
.35634 .30902 L
.35744 .30902 L
.35844 .30902 L
.35953 .30902 L
.36067 .30902 L
.36173 .30902 L
.36296 .30902 L
.36365 .30902 L
.36429 .30902 L
.36547 .30902 L
.36672 .30902 L
.36784 .30902 L
.36888 .30902 L
.37003 .30902 L
.37127 .30902 L
.37251 .30902 L
.37322 .30902 L
.37387 .30902 L
.37456 .30902 L
.37519 .30902 L
.37592 .30902 L
.37661 .30902 L
.37783 .30902 L
.37895 .30902 L
.38019 .30902 L
.3815 .30902 L
.38271 .30902 L
.38403 .30902 L
.38527 .30902 L
.38643 .30902 L
Mistroke
.38758 .30902 L
.38861 .30902 L
.38981 .30902 L
.39094 .30902 L
.39217 .30902 L
.39348 .30902 L
.39459 .30902 L
.39581 .30902 L
.39712 .30902 L
.39785 .30902 L
.39853 .30902 L
.39917 .30902 L
.39986 .30902 L
.40107 .30902 L
.40221 .30902 L
.40327 .30902 L
.40444 .30902 L
.40569 .30902 L
.40694 .30902 L
.40825 .30902 L
.40937 .30902 L
.41059 .30902 L
.41175 .30902 L
.4128 .30902 L
.41401 .30902 L
.41515 .30902 L
.41621 .30902 L
.41718 .30902 L
.41825 .30902 L
.41939 .30902 L
.4206 .30902 L
.42129 .30902 L
.42193 .30902 L
.42309 .30902 L
.42433 .30902 L
.42544 .30902 L
.42648 .30902 L
.42762 .30902 L
.42885 .30902 L
.43008 .30902 L
.43078 .30902 L
.43143 .30902 L
.43274 .30902 L
.43347 .30902 L
.43414 .30902 L
.43534 .30902 L
.43664 .30902 L
.43787 .30902 L
.439 .30902 L
.44005 .30902 L
Mistroke
.44119 .30902 L
.44226 .30902 L
.44324 .30902 L
.44438 .30902 L
.44563 .30902 L
.4468 .30902 L
.4479 .30902 L
.44913 .30902 L
.45029 .30902 L
.45134 .30902 L
.45246 .30902 L
.45369 .30902 L
.455 .30902 L
.45611 .30902 L
.45733 .30902 L
.45863 .30902 L
.45984 .30902 L
.46047 .30902 L
.46117 .30902 L
.46189 .30902 L
.46257 .30902 L
.46382 .30902 L
.46496 .30902 L
.46622 .30902 L
.46754 .30902 L
.46866 .30902 L
.46985 .30902 L
.47097 .30902 L
.47199 .30902 L
.47319 .30902 L
.47449 .30902 L
.47572 .30902 L
.47685 .30902 L
.47918 .30902 L
.48047 .30902 L
.48169 .30902 L
.48238 .30902 L
.48313 .30902 L
.48444 .30902 L
.48701 .30902 L
.49256 .30902 L
.49388 .30902 L
.49455 .30902 L
.49527 .30902 L
.49657 .30902 L
.49777 .30902 L
.49901 .30902 L
.50018 .30902 L
.50082 .30902 L
.50152 .30902 L
Mistroke
.50275 .30902 L
.50345 .30902 L
.50411 .30902 L
.50479 .30902 L
.50554 .30902 L
.50679 .30902 L
.50749 .30902 L
.50813 .30902 L
.50932 .30902 L
.51042 .30902 L
.51163 .30902 L
.51293 .30902 L
.51416 .30902 L
.51532 .30902 L
.51637 .30902 L
.5175 .30902 L
.51881 .30902 L
.52003 .30902 L
.52073 .30902 L
.52137 .30902 L
.52211 .30902 L
.52281 .30902 L
.52349 .30902 L
.52421 .30902 L
.5255 .30902 L
.52622 .30902 L
.52689 .30902 L
.52763 .30902 L
.52843 .30902 L
.52965 .30902 L
.53034 .30902 L
.53098 .30902 L
.53228 .30902 L
.53301 .30902 L
.53367 .30902 L
.53486 .30902 L
.53615 .30902 L
.53737 .30902 L
.53849 .30902 L
.53974 .30902 L
.54093 .30902 L
.54199 .30902 L
.54316 .30902 L
.54442 .30902 L
.54512 .30902 L
.54576 .30902 L
.547 .30902 L
.54818 .30902 L
.54928 .30902 L
.55045 .30902 L
Mistroke
.55144 .30902 L
.55253 .30902 L
.55371 .30902 L
.55497 .30902 L
.55616 .30902 L
.55724 .30902 L
.55852 .30902 L
.55917 .30902 L
.55988 .30902 L
.56114 .30902 L
.56232 .30902 L
.563 .30902 L
.56371 .30902 L
.56498 .30902 L
.56569 .30902 L
.56635 .30902 L
.56707 .30902 L
.56784 .30902 L
.56914 .30902 L
.56988 .30902 L
.57055 .30902 L
.57179 .30902 L
.5731 .30902 L
.57428 .30902 L
.57538 .30902 L
.57658 .30902 L
.57788 .30902 L
.57909 .30902 L
.57978 .30902 L
.58043 .30902 L
.58174 .30902 L
.58247 .30902 L
.58315 .30902 L
.58428 .30902 L
.58552 .30902 L
.58682 .30902 L
.58803 .30902 L
.58872 .30902 L
.58947 .30902 L
.59017 .30902 L
.59083 .30902 L
.59206 .30902 L
.59337 .30902 L
.59405 .30902 L
.59477 .30902 L
.59609 .30902 L
.59689 .30902 L
.59765 .30902 L
.59834 .30902 L
.59908 .30902 L
Mistroke
.59974 .30902 L
.60045 .30902 L
.60173 .30902 L
.60298 .30902 L
.60413 .30902 L
.60538 .30902 L
.60609 .30902 L
.60675 .30902 L
.60745 .30902 L
.60808 .30902 L
.60882 .30902 L
.60951 .30902 L
.61068 .30902 L
.61192 .30902 L
.61298 .30902 L
.61415 .30902 L
.61532 .30902 L
.61656 .30902 L
.61728 .30902 L
.61793 .30902 L
.61919 .30902 L
.62041 .30902 L
.62173 .30902 L
.62297 .30902 L
.62411 .30902 L
.62531 .30902 L
.62663 .30902 L
.62729 .30902 L
.628 .30902 L
.62929 .30902 L
.63855 .30902 L
.63984 .30902 L
.64057 .30902 L
.64122 .30902 L
.642 .30902 L
.64274 .30902 L
.64341 .30902 L
.64414 .30902 L
.64478 .30902 L
.64549 .30902 L
.64622 .30902 L
.64691 .30902 L
.64813 .30902 L
.64945 .30902 L
.65073 .30902 L
.65146 .30902 L
.65213 .30902 L
.65336 .30902 L
.65466 .30902 L
.65583 .30902 L
Mistroke
.65692 .30902 L
.65812 .30902 L
.65941 .30902 L
.66009 .30902 L
.66073 .30902 L
.66194 .30902 L
.66323 .30902 L
.66396 .30902 L
.66464 .30902 L
.66576 .30902 L
.667 .30902 L
.66829 .30902 L
.6695 .30902 L
.67018 .30902 L
.67093 .30902 L
.67163 .30902 L
.67228 .30902 L
.67351 .30902 L
.67482 .30902 L
.67549 .30902 L
.67621 .30902 L
.67753 .30902 L
.67829 .30902 L
.67909 .30902 L
.67977 .30902 L
.68052 .30902 L
.69104 .30902 L
.69346 .30902 L
.69478 .30902 L
.69602 .30902 L
.69707 .30902 L
.6982 .30902 L
.69946 .30902 L
.70061 .30902 L
.70179 .30902 L
.70308 .30902 L
.70431 .30902 L
.70544 .30902 L
.70675 .30902 L
.70798 .30902 L
.70866 .30902 L
.7094 .30902 L
.71068 .30902 L
.71183 .30902 L
.71309 .30902 L
.71441 .30902 L
.71564 .30902 L
.71679 .30902 L
.71784 .30902 L
.71905 .30902 L
Mistroke
.7202 .30902 L
.7214 .30902 L
.72208 .30902 L
.72273 .30902 L
.72402 .30902 L
.72541 .30902 L
.72664 .30902 L
.72793 .30902 L
.72903 .30902 L
.73023 .30902 L
.73097 .30902 L
.73167 .30902 L
.73297 .30902 L
.7337 .30902 L
.73437 .30902 L
.73511 .30902 L
.73589 .30902 L
.73718 .30902 L
.73839 .30902 L
.73907 .30902 L
.73972 .30902 L
.74046 .30902 L
.74114 .30902 L
.74239 .30902 L
.7431 .30902 L
.74375 .30902 L
.74494 .30902 L
.74619 .30902 L
.74732 .30902 L
.74838 .30902 L
.74953 .30902 L
.75077 .30902 L
.75209 .30902 L
.75283 .30902 L
.75352 .30902 L
.75479 .30902 L
.75543 .30902 L
.75613 .30902 L
.75734 .30902 L
.75865 .30902 L
.75988 .30902 L
.76101 .30902 L
.76214 .30902 L
.76335 .30902 L
.76449 .30902 L
.76552 .30902 L
.76674 .30902 L
.76805 .30902 L
.7693 .30902 L
.77044 .30902 L
Mistroke
.77152 .30902 L
.77252 .30902 L
.77372 .30902 L
.77481 .30902 L
.77595 .30902 L
.77703 .30902 L
.77817 .30902 L
.77941 .30902 L
.78063 .30902 L
.78175 .30902 L
.78426 .30902 L
.7854 .30902 L
.78662 .30902 L
.78777 .30902 L
.78881 .30902 L
.79122 .30902 L
.79386 .30902 L
.79919 .30902 L
.82019 .30902 L
.86017 .30902 L
.89863 .30902 L
.93954 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`000c?o000506Ko<ol0<ol0<ol0000000Tco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0
000co`0co`00;c?o00030000<ol0<ol0024co`000`1Voc?o03?o000;<ol000<0000co`0co`00;S?o
00030000<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004OoooeHco`00
0`1Voc?o03?o001^<ol000<0003oooooool0AOooo`004OoooeHco`000`1Voc?o03?o001^<ol000<0
003oooooool0AOooo`004Ooooa00I_m6<ol000<0I_lco`0co`00KS?o00030000oooooooo04Goool0
017oool@<ol02`1Voc/co`000`1Voc?o03?o001^<ol000<0003oooooool0AOooo`004Ooooa/co`0:
06Ko<C?o000306Ko<ol0<ol006hco`000`000?ooooooo`15oooo000Aoooo9C?o00P0I_lY<ol000<0
I_lco`0co`00KS?o00800016oooo000Aoooo;C?o00D0I_lT<ol000<0I_lco`0co`00KS?o00030000
oooooooo04Goool0017ooolb<ol01`1Voadco`000`1Voc?o03?o001^<ol000<0003oooooool0AOoo
o`004OooocTco`0806Ko5C?o000306Ko<ol0<ol006hco`000`000?ooooooo`15oooo000Aoooo@C?o
00H0I_l?<ol000<0I_lco`0co`00KS?o00030000oooooooo04Goool0017ooom7<ol01@1Vo`Xco`00
0`1Voc?o03?o001^<ol000<0003oooooool0AOooo`004Ooood`co`0606Ko13?o000306Ko<ol0<ol0
06hco`000`000?ooooooo`15oooo000AooooDS?o00D0I_m`<ol000<0003oooooool0AOooo`004Ooo
o`80001D<ol000?o09Tco`0co`00KS?o00800016oooo000Coooo0P00058co`000ol0VC?o03?o001^
<ol000<0003oooooool0AOooo`005Oooo`80001@<ol000?o09Tco`0co`00KS?o00030000oooooooo
04Goool001Ooool20000CS?o0003o`2I<ol0<ol006hco`000`000?ooooooo`15oooo000Ioooo0P00
04`co`000ol0VC?o03?o001^<ol000<0003oooooool0AOooo`006oooo`80001:<ol000?o09Tco`0c
o`00KS?o00030000oooooooo04Goool001goool20000B3?o0003o`2I<ol0<ol006hco`000`000?oo
ooooo`15oooo000Ooooo00<0000co`0co`00AC?o0003o`2I<ol0<ol006hco`000`000?ooooooo`15
oooo000Poooo00<0000co`0co`00A3?o0003o`2I<ol0<ol006hco`020000A_ooo`008Oooo`800014
<ol000?o09Tco`0co`00KS?o00030000oooooooo04Goool002?oool00`0003?o03?o0011<ol000?o
09Tco`0co`00KS?o00030000oooooooo04Goool002Coool20000@C?o0003o`2I<ol0<ol006hco`00
0`000?ooooooo`15oooo000Voooo00<0000co`0co`00?S?o0003o`2I<ol0<ol006hco`000`000?oo
ooooo`15oooo000Woooo00<0000co`0co`00?C?o0003o`2I<ol0<ol006hco`000`000?ooooooo`15
oooo000Xoooo00<0000co`0co`00?3?o0003o`2I<ol0<ol005Dco`02000013?o00800004<ol00P00
00<co`04000013?o00030000oooooooo04Goool002Woool00`0003?o03?o000k<ol000?o09Tco`0c
o`00E3?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00030000<ol0<ol000Dco`00
0`000?ooooooo`15oooo000Zoooo00<0000co`0co`00>S?o0003o`2I<ol0<ol005@co`00100003?o
03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o0004<ol00`0004Goool002_oool2
0000>S?o0003o`2I<ol0<ol005@co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o0003<ol000<0003oooooool0AOooo`00;Oooo`030000<ol0<ol003Lco`000ol0VC?o
03?o001D<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000004
<ol000<0003oooooool0AOooo`00;_ooo`030000<ol0<ol003Hco`000ol0VC?o03?o001E<ol00P00
00Xco`02000013?o00800005<ol000<0003oooooool0AOooo`00;oooo`030000<ol0<ol003Dco`00
0ol0VC?o03?o001^<ol000<0003oooooool0AOooo`00<?ooo`030000<ol0<ol003@co`000ol0VC?o
03?o001^<ol000<0003oooooool0AOooo`00<Oooo`030000<ol0<ol003<co`000ol0VC?o03?o001^
<ol000<0003oooooool0AOooo`00<_ooo`030000<ol0<ol0038co`000ol0VC?o03?o001^<ol000<0
003oooooool0AOooo`00<oooo`030000<ol0<ol0034co`000ol0VC?o03?o001^<ol00P0004Koool0
03?oool00`0003?o03?o000a<ol000?o09Tco`0co`00KS?o00030000oooooooo04Goool003Coool0
0`0003?o03?o000`<ol000?o09Tco`0co`00KS?o00030000oooooooo04Goool003Goool00`0003?o
03?o000_<ol000?o09Tco`0co`00KS?o00030000oooooooo04Goool003Koool00`0003?o03?o000^
<ol000?o09Tco`0co`00KS?o00030000oooooooo04Goool003Ooool00`0003?o03?o000]<ol000?o
09Tco`0co`00KS?o00030000oooooooo04Goool003Soool00`0003?o03?o000/<ol000?o09Tco`0c
o`00KS?o00030000oooooooo04Goool003Soool00`0003?o03?o000/<ol000?o09Tco`0co`00KS?o
00030000oooooooo04Goool003Woool00`0003?o03?o000[<ol000?o09Tco`0co`00KS?o00800016
oooo000joooo00<0000co`0co`00:S?o0003o`2I<ol0<ol006hco`000`000?ooooooo`15oooo000k
oooo00<0000co`0co`00:C?o0003o`2I<ol0<ol006hco`000`000?ooooooo`15oooo000loooo00<0
000co`0co`00:3?o0003o`2I<ol0<ol006hco`000`000?ooooooo`15oooo000loooo00<0000co`0c
o`00:3?o0003o`2I<ol0<ol006hco`000`000?ooooooo`15oooo000moooo00<0000co`0co`009c?o
0003o`2I<ol0<ol006hco`000`000?ooooooo`15oooo000moooo00<0000co`0co`009c?o0003o`2I
<ol0<ol006hco`000`000?ooooooo`15oooo000noooo00<0000co`0co`009S?o0003o`2I<ol0<ol0
06hco`000`000?ooooooo`15oooo000noooo00<0000co`0co`009S?o0003o`2I<ol0<ol006hco`00
0`000?ooooooo`15oooo000ooooo00<0000co`0co`009C?o0003o`2I<ol0<ol006hco`020000A_oo
o`00?oooo`030000<ol0<ol002Dco`000ol0VC?o03?o001^<ol000<0003oooooool0AOooo`00@?oo
o`030000<ol0<ol002@co`000ol0VC?o03?o001^<ol000<0003oooooool0AOooo`00@Oooo`030000
<ol0<ol002<co`000ol0VC?o03?o001^<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol0
02<co`000ol0VC?o03?o001^<ol000<0003oooooool0AOooo`00@_ooo`030000<ol0<ol0028co`00
0ol0VC?o03?o001^<ol000<0003oooooool0AOooo`00@_ooo`030000<ol0<ol0028co`000ol0VC?o
03?o001E<ol00P0000@co`02000013?o00800005<ol00`0000<co`000`000?ooooooo`15oooo0013
oooo00<0000co`0co`008C?o0003o`2I<ol0<ol005@co`00100003?o03?o000000Pco`00100003?o
03?o000000Dco`000`0003?o03?o0002<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol0
024co`000ol0VC?o03?o001D<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol01@00
00<co`030000AOooo`00A?ooo`030000<ol0<ol0020co`000ol0VC?o03?o001D<ol000@0000co`0c
o`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000004<ol000<0003oooooool0AOoo
o`00A?ooo`030000<ol0<ol0020co`000ol0VC?o03?o001D<ol000@0000co`0co`000008<ol000@0
000co`0co`000003<ol000<0000co`00000013?o00030000oooooooo04Goool004Goool00`0003?o
03?o000O<ol000?o09Tco`0co`00EC?o0080000:<ol00P0000Dco`02000013?o00030000oooooooo
04Goool004Goool00`0003?o03?o000O<ol000?o09Tco`0co`00KS?o00030000oooooooo04Goool0
04Koool00`0003?o03?o000N<ol000?o09Tco`0co`00KS?o00030000oooooooo04Goool004Koool0
0`0003?o03?o000N<ol000?o09Tco`0co`00KS?o00030000oooooooo04Goool004Ooool00`0003?o
03?o000M<ol000?o09Tco`0co`00KS?o00030000oooooooo04Goool004Ooool00`0003?o03?o000M
<ol000?o09Tco`0co`00KS?o00800016oooo0018oooo00<0000co`0co`0073?o0003o`2I<ol0<ol0
06hco`000`000?ooooooo`15oooo0018oooo00<0000co`0co`0073?o0003o`2I<ol0<ol006hco`00
0`000?ooooooo`15oooo0019oooo00<0000co`0co`006c?o0003o`2I<ol0<ol006hco`000`000?oo
ooooo`15oooo0019oooo00<0000co`0co`006c?o0003o`2I<ol0<ol006hco`000`000?ooooooo`15
oooo001:oooo00<0000co`0co`006S?o0003o`2I<ol0<ol006hco`000`000?ooooooo`15oooo001:
oooo00<0000co`0co`006S?o0003o`2I<ol0<ol006hco`000`000?ooooooo`15oooo001;oooo00<0
000co`0co`006C?o0003o`2I<ol0<ol006hco`000`000?ooooooo`15oooo001;oooo00<0000co`0c
o`006C?o0003o`2I<ol0<ol006hco`020000A_ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool0
04cooon<<ol0B?ooo`00COoooh/co`18oooo001=ooooRc?o04Soool004kooolV<ol000<0000co`0c
o`00;c?o00030000<ol0<ol002lco`18oooo001>oooo9C?o00030000<ol0<ol000Pco`000`0003?o
03?o000V<ol000<0000co`0co`00;S?o04Soool004oooolT<ol000<0000co`0co`000S?o00800004
<ol000<0000co`0co`003S?o00800004<ol00P0000<co`0500000c?o00<00002<ol000<0000co`0c
o`00;S?o04Soool004oooolT<ol000D0000co`0co`0co`0000000S?o00030000<ol0<ol0008co`00
0`0003?o03?o0005<ol0100000<co`00100003?o03?o000000Xco`000`0003?o03?o0004<ol000D0
000co`0co`0co`000000<3?o04Soool004oooolS<ol000<0000co`0co`000S?o00030000<ol0<ol0
01@co`00100003?o03?o000000Xco`00100003?o03?o03?o00D00003<ol000<0000co`0co`00;C?o
04Soool0053ooolS<ol000<0000co`0co`001@0001<co`00100003?o03?o000000Xco`001@0003?o
03?o03?o00000002<ol000D0000co`0co`0co`000000<3?o04Soool0053ooolS<ol000D0000co`0c
o`0co`0000005S?o00040000<ol0<ol000002S?o00030000<ol0<ol0008co`000`0003?o00000003
<ol000<0000co`0co`00;S?o04Soool0053ooolT<ol000<0000co`0co`0063?o0080000:<ol00P00
00Dco`0200000S?o00030000<ol0<ol002lco`18oooo001AooooQc?o04Soool0057ooon7<ol0B?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.13) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.33304 .30902 L
.34309 .30902 L
.34772 .30902 L
.35028 .30902 L
.35271 .30902 L
.3538 .30902 L
.35496 .30902 L
s
.35496 .30902 m
.35497 .61803 L
s
0 .4 1 r
.02381 .32513 m
.06244 .32761 L
.10458 .33077 L
.14415 .33422 L
.18221 .33806 L
.22272 .3428 L
.26171 .34809 L
.30316 .35465 L
.32392 .35834 L
.33304 .36006 L
.34309 .36203 L
.34772 .36296 L
.35028 .36348 L
.35271 .36398 L
.3538 .36421 L
.35496 .36445 L
.35624 .30902 L
.35742 .30902 L
.35859 .30902 L
.35968 .30902 L
.36067 .30902 L
.36173 .30902 L
.36297 .30902 L
.36412 .30902 L
.36538 .30902 L
.36609 .30902 L
.36674 .30902 L
.36804 .30902 L
.36877 .30902 L
.36945 .30902 L
.3707 .30902 L
.37133 .30902 L
.37203 .30902 L
.37325 .30902 L
.37438 .30902 L
.37561 .30902 L
.37691 .30902 L
.37805 .30902 L
.3791 .30902 L
.38026 .30902 L
.3815 .30902 L
.38273 .30902 L
.38343 .30902 L
.38409 .30902 L
.38541 .30902 L
.38683 .30902 L
.38815 .30902 L
.3894 .30902 L
.39052 .30902 L
.39174 .30902 L
Mistroke
.3925 .30902 L
.39321 .30902 L
.39384 .30902 L
.39453 .30902 L
.39529 .30902 L
.39608 .30902 L
.39676 .30902 L
.3975 .30902 L
.3982 .30902 L
.39884 .30902 L
.39957 .30902 L
.40027 .30902 L
.4015 .30902 L
.4022 .30902 L
.40284 .30902 L
.404 .30902 L
.40525 .30902 L
.40642 .30902 L
.4075 .30902 L
.40869 .30902 L
.41 .30902 L
.41065 .30902 L
.41136 .30902 L
.41262 .30902 L
.41332 .30902 L
.41397 .30902 L
.41467 .30902 L
.41542 .30902 L
.41668 .30902 L
.41739 .30902 L
.41806 .30902 L
.41931 .30902 L
.42044 .30902 L
.42175 .30902 L
.423 .30902 L
.42413 .30902 L
.42536 .30902 L
.42651 .30902 L
.42758 .30902 L
.43004 .30902 L
.43128 .30902 L
.43198 .30902 L
.43263 .30902 L
.43327 .30902 L
.43397 .30902 L
.43523 .30902 L
.43645 .30902 L
.43759 .30902 L
.43881 .30902 L
.43951 .30902 L
Mistroke
.44016 .30902 L
.44084 .30902 L
.44156 .30902 L
.44288 .30902 L
.44402 .30902 L
.44522 .30902 L
.44636 .30902 L
.4474 .30902 L
.44862 .30902 L
.44993 .30902 L
.45118 .30902 L
.45232 .30902 L
.4534 .30902 L
.4544 .30902 L
.45551 .30902 L
.45669 .30902 L
.45792 .30902 L
.4591 .30902 L
.46015 .30902 L
.46129 .30902 L
.46251 .30902 L
.46363 .30902 L
.46483 .30902 L
.46615 .30902 L
.4673 .30902 L
.46837 .30902 L
.4695 .30902 L
.4707 .30902 L
.4714 .30902 L
.47205 .30902 L
.47275 .30902 L
.4735 .30902 L
.47476 .30902 L
.47547 .30902 L
.47614 .30902 L
.47739 .30902 L
.47853 .30902 L
.47922 .30902 L
.47987 .30902 L
.48108 .30902 L
.48238 .30902 L
.48304 .30902 L
.48376 .30902 L
.48506 .30902 L
.48624 .30902 L
.48755 .30902 L
.48829 .30902 L
.48898 .30902 L
.48971 .30902 L
.49037 .30902 L
Mistroke
.49114 .30902 L
.49187 .30902 L
.4931 .30902 L
.49442 .30902 L
.49554 .30902 L
.49677 .30902 L
.49746 .30902 L
.49809 .30902 L
.49883 .30902 L
.49952 .30902 L
.50075 .30902 L
.50145 .30902 L
.5021 .30902 L
.50338 .30902 L
.50403 .30902 L
.50474 .30902 L
.50599 .30902 L
.50717 .30902 L
.50782 .30902 L
.50853 .30902 L
.50982 .30902 L
.51059 .30902 L
.5113 .30902 L
.51196 .30902 L
.51266 .30902 L
.51383 .30902 L
.5151 .30902 L
.51629 .30902 L
.51739 .30902 L
.5186 .30902 L
.51929 .30902 L
.51993 .30902 L
.52122 .30902 L
.52261 .30902 L
.52387 .30902 L
.52503 .30902 L
.52614 .30902 L
.52732 .30902 L
.52837 .30902 L
.52936 .30902 L
.53044 .30902 L
.5316 .30902 L
.53283 .30902 L
.53353 .30902 L
.53418 .30902 L
.53536 .30902 L
.53662 .30902 L
.53786 .30902 L
.53903 .30902 L
.54008 .30902 L
Mistroke
.54121 .30902 L
.56118 .30902 L
.56604 .30902 L
.56732 .30902 L
.56804 .30902 L
.56871 .30902 L
.56993 .30902 L
.57123 .30902 L
.57197 .30902 L
.57265 .30902 L
.57341 .30902 L
.57422 .30902 L
.57491 .30902 L
.57564 .30902 L
.57694 .30902 L
.57825 .30902 L
.57948 .30902 L
.58018 .30902 L
.58082 .30902 L
.58156 .30902 L
.58226 .30902 L
.58341 .30902 L
.58466 .30902 L
.58583 .30902 L
.5869 .30902 L
.58815 .30902 L
.58886 .30902 L
.58952 .30902 L
.59072 .30902 L
.592 .30902 L
.59321 .30902 L
.59452 .30902 L
.59576 .30902 L
.59689 .30902 L
.59815 .30902 L
.59886 .30902 L
.59953 .30902 L
.60023 .30902 L
.60087 .30902 L
.6016 .30902 L
.6023 .30902 L
.60336 .30902 L
.60454 .30902 L
.60576 .30902 L
.6069 .30902 L
.60797 .30902 L
.60895 .30902 L
.61002 .30902 L
.61115 .30902 L
.61238 .30902 L
Mistroke
.61351 .30902 L
.6142 .30902 L
.61486 .30902 L
.61608 .30902 L
.61725 .30902 L
.61833 .30902 L
.61951 .30902 L
.62076 .30902 L
.62198 .30902 L
.62263 .30902 L
.62331 .30902 L
.62456 .30902 L
.62572 .30902 L
.62676 .30902 L
.62787 .30902 L
.6291 .30902 L
.63024 .30902 L
.63148 .30902 L
.63218 .30902 L
.63283 .30902 L
.63414 .30902 L
.63488 .30902 L
.63555 .30902 L
.63675 .30902 L
.63805 .30902 L
.63927 .30902 L
.64041 .30902 L
.64146 .30902 L
.6426 .30902 L
.64367 .30902 L
.64465 .30902 L
.64579 .30902 L
.64704 .30902 L
.64822 .30902 L
.64931 .30902 L
.65055 .30902 L
.65171 .30902 L
.65275 .30902 L
.65388 .30902 L
.65511 .30902 L
.65641 .30902 L
.65753 .30902 L
.65874 .30902 L
.66005 .30902 L
.66126 .30902 L
.66257 .30902 L
.66326 .30902 L
.664 .30902 L
.66525 .30902 L
.66642 .30902 L
Mistroke
.6671 .30902 L
.66775 .30902 L
.66898 .30902 L
.67009 .30902 L
.67129 .30902 L
.67241 .30902 L
.67343 .30902 L
.67463 .30902 L
.67594 .30902 L
.67716 .30902 L
.6783 .30902 L
.67951 .30902 L
.6808 .30902 L
.68203 .30902 L
.68314 .30902 L
.68445 .30902 L
.68519 .30902 L
.68588 .30902 L
.68714 .30902 L
.68777 .30902 L
.68847 .30902 L
.68915 .30902 L
.68986 .30902 L
.69114 .30902 L
.69185 .30902 L
.69251 .30902 L
.69324 .30902 L
.69402 .30902 L
.69469 .30902 L
.69542 .30902 L
.69611 .30902 L
.69675 .30902 L
.69795 .30902 L
.69923 .30902 L
.70043 .30902 L
.70175 .30902 L
.703 .30902 L
.70415 .30902 L
.70865 .30902 L
.70997 .30902 L
.71071 .30902 L
.71139 .30902 L
.71264 .30902 L
.71327 .30902 L
.71397 .30902 L
.71517 .30902 L
.71646 .30902 L
.71767 .30902 L
.71878 .30902 L
.71992 .30902 L
Mistroke
.72096 .30902 L
.72211 .30902 L
.72334 .30902 L
.72439 .30902 L
.72539 .30902 L
.72647 .30902 L
.72765 .30902 L
.72889 .30902 L
.73005 .30902 L
.73125 .30902 L
.73257 .30902 L
.7337 .30902 L
.73476 .30902 L
.73598 .30902 L
.73709 .30902 L
.73824 .30902 L
.73949 .30902 L
.74066 .30902 L
.74173 .30902 L
.74298 .30902 L
.74369 .30902 L
.74434 .30902 L
.74554 .30902 L
.74682 .30902 L
.74752 .30902 L
.74816 .30902 L
.74887 .30902 L
.74961 .30902 L
.75086 .30902 L
.75157 .30902 L
.75223 .30902 L
.75347 .30902 L
.75459 .30902 L
.75589 .30902 L
.75712 .30902 L
.75819 .30902 L
.75936 .30902 L
.76058 .30902 L
.76173 .30902 L
.76279 .30902 L
.76377 .30902 L
.7649 .30902 L
.76597 .30902 L
.76713 .30902 L
.76836 .30902 L
.76952 .30902 L
.77057 .30902 L
.77181 .30902 L
.77246 .30902 L
.77315 .30902 L
Mistroke
.77442 .30902 L
.77558 .30902 L
.81355 .30902 L
.85397 .30902 L
.89287 .30902 L
.93423 .30902 L
.97407 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.13) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`0013?o000406Ko<ol0<ol000002C?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo01?oool0017oool00`0003?o
03?o000_<ol000<0000co`0co`008S?o000306Ko<ol0<ol000Xco`000`0003?o03?o000^<ol000<0
000co`0co`00;c?o00030000oooooooo02ooool00`000?ooooooo`0Coooo000AooooEc?o000306Ko
<ol0<ol006dco`000`000?ooooooo`15oooo000Aoooo1P1Voe4co`000`1Voc?o03?o001]<ol000<0
003oooooool0AOooo`004Oooo`Hco`0:06KoAc?o000306Ko<ol0<ol006dco`000`000?ooooooo`15
oooo000Aoooo43?o00/0I_ll<ol000<0I_lco`0co`00KC?o00030000oooooooo04Goool0017ooolK
<ol02P1Voc8co`000`1Voc?o03?o001]<ol000<0003oooooool0AOooo`004OooobDco`0:06Ko:3?o
000306Ko<ol0<ol006dco`020000A_ooo`004Ooooblco`0:06Ko7S?o000306Ko<ol0<ol006dco`00
0`000?ooooooo`15oooo000Aoooo>C?o00P0I_lF<ol000<0I_lco`0co`00KC?o00030000oooooooo
04Goool0017ooom1<ol01P1Voa0co`000`1Voc?o03?o001]<ol000<0003oooooool0AOooo`004Ooo
odLco`0506Ko2c?o000306Ko<ol0<ol006dco`000`000?ooooooo`15oooo000AooooC3?o00L0I_l4
<ol000<0I_lco`0co`00KC?o00030000oooooooo04Goool0017ooomC<ol01@1Voflco`000`000?oo
ooooo`15oooo000AooooES?o0080I_m_<ol000<0003oooooool0AOooo`004Oooo`80001E<ol000?o
09Tco`0co`00KC?o00800016oooo000Coooo0P0005<co`000ol0VC?o03?o001]<ol000<0003ooooo
ool0AOooo`005Oooo`80001A<ol000?o09Tco`0co`00KC?o00030000oooooooo04Goool001Ooool2
0000Cc?o0003o`2I<ol0<ol006dco`000`000?ooooooo`15oooo000Ioooo0P0004dco`000ol0VC?o
03?o001]<ol000<0003oooooool0AOooo`006oooo`80001;<ol000?o09Tco`0co`00KC?o00030000
oooooooo04Goool001goool20000BC?o0003o`2I<ol0<ol006dco`000`000?ooooooo`15oooo000O
oooo00<0000co`0co`00AS?o0003o`2I<ol0<ol006dco`000`000?ooooooo`15oooo000Poooo00<0
000co`0co`00AC?o0003o`2I<ol0<ol006dco`020000A_ooo`008Oooo`800015<ol000?o09Tco`0c
o`00KC?o00030000oooooooo04Goool002?oool00`0003?o03?o0012<ol000?o09Tco`0co`00KC?o
00030000oooooooo04Goool002Coool20000@S?o0003o`2I<ol0<ol006dco`000`000?ooooooo`15
oooo000Voooo00<0000co`0co`00?c?o0003o`2I<ol0<ol006dco`000`000?ooooooo`15oooo000W
oooo00<0000co`0co`00?S?o0003o`2I<ol0<ol006dco`000`000?ooooooo`15oooo000Xoooo00<0
000co`0co`00?C?o0003o`2I<ol0<ol005@co`02000013?o00800004<ol00P0000<co`04000013?o
00030000oooooooo04Goool002Woool00`0003?o03?o000l<ol000?o09Tco`0co`00Dc?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000S?o00030000<ol0<ol000Dco`000`000?ooooooo`15
oooo000Zoooo00<0000co`0co`00>c?o0003o`2I<ol0<ol005<co`00100003?o03?o000000Pco`00
100003?o03?o000000<co`000`0003?o03?o0004<ol00`0004Goool002_oool20000>c?o0003o`2I
<ol0<ol005<co`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`0003?o03?o0003
<ol000<0003oooooool0AOooo`00;Oooo`030000<ol0<ol003Pco`000ol0VC?o03?o001C<ol000@0
000co`0co`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000004<ol000<0003ooooo
ool0AOooo`00;_ooo`030000<ol0<ol003Lco`000ol0VC?o03?o001D<ol00P0000Xco`02000013?o
00800005<ol000<0003oooooool0AOooo`00;oooo`030000<ol0<ol003Hco`000ol0VC?o03?o001]
<ol000<0003oooooool0AOooo`00<?ooo`030000<ol0<ol003Dco`000ol0VC?o03?o001]<ol000<0
003oooooool0AOooo`00<Oooo`030000<ol0<ol003@co`000ol0VC?o03?o001]<ol000<0003ooooo
ool0AOooo`00<_ooo`030000<ol0<ol003<co`000ol0VC?o03?o001]<ol000<0003oooooool0AOoo
o`00<oooo`030000<ol0<ol0038co`000ol0VC?o03?o001]<ol00P0004Koool003?oool00`0003?o
03?o000b<ol000?o09Tco`0co`00KC?o00030000oooooooo04Goool003Coool00`0003?o03?o000a
<ol000?o09Tco`0co`00KC?o00030000oooooooo04Goool003Goool00`0003?o03?o000`<ol000?o
09Tco`0co`00KC?o00030000oooooooo04Goool003Koool00`0003?o03?o000_<ol000?o09Tco`0c
o`00KC?o00030000oooooooo04Goool003Ooool00`0003?o03?o000^<ol000?o09Tco`0co`00KC?o
00030000oooooooo04Goool003Soool00`0003?o03?o000]<ol000?o09Tco`0co`00KC?o00030000
oooooooo04Goool003Soool00`0003?o03?o000]<ol000?o09Tco`0co`00KC?o00030000oooooooo
04Goool003Woool00`0003?o03?o000/<ol000?o09Tco`0co`00KC?o00800016oooo000joooo00<0
000co`0co`00:c?o0003o`2I<ol0<ol006dco`000`000?ooooooo`15oooo000koooo00<0000co`0c
o`00:S?o0003o`2I<ol0<ol006dco`000`000?ooooooo`15oooo000loooo00<0000co`0co`00:C?o
0003o`2I<ol0<ol006dco`000`000?ooooooo`15oooo000loooo00<0000co`0co`00:C?o0003o`2I
<ol0<ol006dco`000`000?ooooooo`15oooo000moooo00<0000co`0co`00:3?o0003o`2I<ol0<ol0
06dco`000`000?ooooooo`15oooo000moooo00<0000co`0co`00:3?o0003o`2I<ol0<ol006dco`00
0`000?ooooooo`15oooo000noooo00<0000co`0co`009c?o0003o`2I<ol0<ol006dco`000`000?oo
ooooo`15oooo000noooo00<0000co`0co`009c?o0003o`2I<ol0<ol006dco`000`000?ooooooo`15
oooo000ooooo00<0000co`0co`009S?o0003o`2I<ol0<ol006dco`020000A_ooo`00?oooo`030000
<ol0<ol002Hco`000ol0VC?o03?o001]<ol000<0003oooooool0AOooo`00@?ooo`030000<ol0<ol0
02Dco`000ol0VC?o03?o001]<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol002@co`00
0ol0VC?o03?o001]<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol002@co`000ol0VC?o
03?o001]<ol000<0003oooooool0AOooo`00@_ooo`030000<ol0<ol002<co`000ol0VC?o03?o001]
<ol000<0003oooooool0AOooo`00@_ooo`030000<ol0<ol002<co`000ol0VC?o03?o001D<ol00P00
00@co`02000013?o00800005<ol00`0000<co`000`000?ooooooo`15oooo0013oooo00<0000co`0c
o`008S?o0003o`2I<ol0<ol005<co`00100003?o03?o000000Pco`00100003?o03?o000000Dco`00
0`0003?o03?o0002<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol0028co`000ol0VC?o
03?o001C<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol01@0000<co`030000AOoo
o`00A?ooo`030000<ol0<ol0024co`000ol0VC?o03?o001C<ol000@0000co`0co`000008<ol000@0
000co`0co`000002<ol000@0000co`0co`000004<ol000<0003oooooool0AOooo`00A?ooo`030000
<ol0<ol0024co`000ol0VC?o03?o001C<ol000@0000co`0co`000008<ol000@0000co`0co`000003
<ol000<0000co`00000013?o00030000oooooooo04Goool004Goool00`0003?o03?o000P<ol000?o
09Tco`0co`00E3?o0080000:<ol00P0000Dco`02000013?o00030000oooooooo04Goool004Goool0
0`0003?o03?o000P<ol000?o09Tco`0co`00KC?o00030000oooooooo04Goool004Koool00`0003?o
03?o000O<ol000?o09Tco`0co`00KC?o00030000oooooooo04Goool004Koool00`0003?o03?o000O
<ol000?o09Tco`0co`00KC?o00030000oooooooo04Goool004Ooool00`0003?o03?o000N<ol000?o
09Tco`0co`00KC?o00030000oooooooo04Goool004Ooool00`0003?o03?o000N<ol000?o09Tco`0c
o`00KC?o00800016oooo0018oooo00<0000co`0co`007C?o0003o`2I<ol0<ol006dco`000`000?oo
ooooo`15oooo0018oooo00<0000co`0co`007C?o0003o`2I<ol0<ol006dco`000`000?ooooooo`15
oooo0019oooo00<0000co`0co`0073?o0003o`2I<ol0<ol006dco`000`000?ooooooo`15oooo0019
oooo00<0000co`0co`0073?o0003o`2I<ol0<ol006dco`000`000?ooooooo`15oooo001:oooo00<0
000co`0co`006c?o0003o`2I<ol0<ol006dco`000`000?ooooooo`15oooo001:oooo00<0000co`0c
o`006c?o0003o`2I<ol0<ol006dco`000`000?ooooooo`15oooo001;oooo00<0000co`0co`006S?o
0003o`2I<ol0<ol006dco`000`000?ooooooo`15oooo001;oooo00<0000co`0co`006S?o0003o`2I
<ol0<ol006dco`020000A_ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004cooon<<ol0B?oo
o`00COoooh/co`18oooo001=ooooRc?o04Soool004kooolV<ol000<0000co`0co`00;c?o00030000
<ol0<ol002lco`18oooo001>oooo9C?o00030000<ol0<ol000Pco`000`0003?o03?o000V<ol000<0
000co`0co`00;S?o04Soool004oooolT<ol000<0000co`0co`000S?o00800004<ol000<0000co`0c
o`003S?o00800004<ol00P0000<co`0500000S?o00800004<ol000<0000co`0co`00;S?o04Soool0
04oooolT<ol000D0000co`0co`0co`0000000S?o00030000<ol0<ol0008co`000`0003?o03?o0005
<ol0100000<co`00100003?o03?o000000Xco`001@0003?o03?o03?o00000002<ol000D0000co`0c
o`0co`000000<3?o04Soool004oooolS<ol000<0000co`0co`000S?o00030000<ol0<ol001@co`00
100003?o03?o000000Xco`000`0003?o03?o0003<ol000<0000co`0co`000c?o00030000<ol0<ol0
02dco`18oooo001@oooo8c?o00030000<ol0<ol000D0000C<ol000@0000co`0co`00000:<ol000<0
000co`0co`0013?o00050000<ol0<ol0<ol00000030co`18oooo001@oooo8c?o00050000<ol0<ol0
<ol0000001Hco`00100003?o03?o000000Xco`001@0003?o03?o03?o00000002<ol000D0000co`0c
o`0co`000000<3?o04Soool0053ooolT<ol000<0000co`0co`0063?o0080000:<ol00P0000@co`02
00000c?o00030000<ol0<ol002lco`18oooo001AooooQc?o04Soool0057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.33304 .30902 L
.34309 .30902 L
.34772 .30902 L
.35271 .30902 L
.35513 .30902 L
.35632 .30902 L
.35742 .30902 L
.35842 .30902 L
s
.35842 .30902 m
.35842 .61803 L
s
0 .4 1 r
.02381 .32387 m
.06244 .32617 L
.10458 .32908 L
.14415 .33226 L
.18221 .3358 L
.22272 .34017 L
.26171 .34506 L
.30316 .3511 L
.32392 .35451 L
.33304 .3561 L
.34309 .35791 L
.34772 .35877 L
.35271 .35971 L
.35513 .36017 L
.35632 .3604 L
.35742 .36062 L
.35842 .36081 L
.35948 .30902 L
.36066 .30902 L
.36173 .30902 L
.36297 .30902 L
.36428 .30902 L
.3654 .30902 L
.36662 .30902 L
.36794 .30902 L
.36868 .30902 L
.36936 .30902 L
.37067 .30902 L
.37191 .30902 L
.37307 .30902 L
.3743 .30902 L
.37535 .30902 L
.3765 .30902 L
.37774 .30902 L
.37844 .30902 L
.37908 .30902 L
.38026 .30902 L
.3815 .30902 L
.38273 .30902 L
.38343 .30902 L
.38407 .30902 L
.38525 .30902 L
.3865 .30902 L
.38762 .30902 L
.38866 .30902 L
.38981 .30902 L
.39104 .30902 L
.39235 .30902 L
.39309 .30902 L
.39378 .30902 L
Mistroke
.39503 .30902 L
.39574 .30902 L
.39637 .30902 L
.39758 .30902 L
.39888 .30902 L
.40011 .30902 L
.40124 .30902 L
.40231 .30902 L
.40345 .30902 L
.40452 .30902 L
.4055 .30902 L
.40666 .30902 L
.40791 .30902 L
.40909 .30902 L
.41018 .30902 L
.4113 .30902 L
.41235 .30902 L
.41351 .30902 L
.41475 .30902 L
.41599 .30902 L
.41729 .30902 L
.4184 .30902 L
.41961 .30902 L
.42025 .30902 L
.42093 .30902 L
.42215 .30902 L
.42491 .30902 L
.42616 .30902 L
.42686 .30902 L
.42749 .30902 L
.42873 .30902 L
.42991 .30902 L
.43102 .30902 L
.43204 .30902 L
.43317 .30902 L
.43436 .30902 L
.43556 .30902 L
.43669 .30902 L
.43792 .30902 L
.43926 .30902 L
.44057 .30902 L
.4418 .30902 L
.44249 .30902 L
.44314 .30902 L
.4439 .30902 L
.44458 .30902 L
.44526 .30902 L
.44598 .30902 L
.44727 .30902 L
.44799 .30902 L
Mistroke
.44866 .30902 L
.4494 .30902 L
.45019 .30902 L
.45147 .30902 L
.4522 .30902 L
.45288 .30902 L
.45411 .30902 L
.45543 .30902 L
.45672 .30902 L
.45794 .30902 L
.45904 .30902 L
.46022 .30902 L
.46146 .30902 L
.4626 .30902 L
.4639 .30902 L
.46514 .30902 L
.46629 .30902 L
.46734 .30902 L
.46974 .30902 L
.4747 .30902 L
.47598 .30902 L
.47663 .30902 L
.47733 .30902 L
.4781 .30902 L
.47882 .30902 L
.47947 .30902 L
.48017 .30902 L
.48086 .30902 L
.4816 .30902 L
.48229 .30902 L
.48294 .30902 L
.48416 .30902 L
.48545 .30902 L
.48666 .30902 L
.4878 .30902 L
.48905 .30902 L
.48975 .30902 L
.49039 .30902 L
.49168 .30902 L
.49241 .30902 L
.49306 .30902 L
.49383 .30902 L
.49456 .30902 L
.49524 .30902 L
.49596 .30902 L
.49727 .30902 L
.49851 .30902 L
.4992 .30902 L
.49994 .30902 L
.50124 .30902 L
Mistroke
.50249 .30902 L
.50381 .30902 L
.50494 .30902 L
.50618 .30902 L
.50733 .30902 L
.50856 .30902 L
.50971 .30902 L
.51078 .30902 L
.51143 .30902 L
.51212 .30902 L
.51289 .30902 L
.51358 .30902 L
.51424 .30902 L
.51495 .30902 L
.51624 .30902 L
.51751 .30902 L
.51814 .30902 L
.51884 .30902 L
.52008 .30902 L
.52124 .30902 L
.52254 .30902 L
.52328 .30902 L
.52397 .30902 L
.52522 .30902 L
.52586 .30902 L
.52656 .30902 L
.52776 .30902 L
.52906 .30902 L
.53029 .30902 L
.53141 .30902 L
.53272 .30902 L
.53395 .30902 L
.53529 .30902 L
.53604 .30902 L
.53672 .30902 L
.53744 .30902 L
.5381 .30902 L
.53883 .30902 L
.5396 .30902 L
.5409 .30902 L
.54163 .30902 L
.54232 .30902 L
.54357 .30902 L
.54426 .30902 L
.5449 .30902 L
.54616 .30902 L
.54729 .30902 L
.54796 .30902 L
.54865 .30902 L
.5499 .30902 L
Mistroke
.5506 .30902 L
.55125 .30902 L
.55196 .30902 L
.55272 .30902 L
.55399 .30902 L
.55471 .30902 L
.55538 .30902 L
.55659 .30902 L
.55789 .30902 L
.55904 .30902 L
.56013 .30902 L
.56132 .30902 L
.5626 .30902 L
.56376 .30902 L
.56485 .30902 L
.56604 .30902 L
.56731 .30902 L
.56865 .30902 L
.56991 .30902 L
.57104 .30902 L
.57227 .30902 L
.57334 .30902 L
.57451 .30902 L
.57574 .30902 L
.57688 .30902 L
.57795 .30902 L
.57893 .30902 L
.58006 .30902 L
.58113 .30902 L
.58227 .30902 L
.58349 .30902 L
.58465 .30902 L
.58571 .30902 L
.58688 .30902 L
.58817 .30902 L
.58882 .30902 L
.58951 .30902 L
.59076 .30902 L
.59209 .30902 L
.59283 .30902 L
.59352 .30902 L
.59476 .30902 L
.59547 .30902 L
.59613 .30902 L
.59727 .30902 L
.5985 .30902 L
.59981 .30902 L
.60101 .30902 L
.60214 .30902 L
.60335 .30902 L
Mistroke
.60449 .30902 L
.60552 .30902 L
.60674 .30902 L
.60806 .30902 L
.6093 .30902 L
.61045 .30902 L
.61152 .30902 L
.61253 .30902 L
.61363 .30902 L
.61481 .30902 L
.61605 .30902 L
.61722 .30902 L
.61827 .30902 L
.61942 .30902 L
.62063 .30902 L
.62175 .30902 L
.62298 .30902 L
.62427 .30902 L
.62532 .30902 L
.62644 .30902 L
.62767 .30902 L
.62882 .30902 L
.62952 .30902 L
.63016 .30902 L
.63087 .30902 L
.63162 .30902 L
.63287 .30902 L
.63359 .30902 L
.63426 .30902 L
.6355 .30902 L
.63664 .30902 L
.63795 .30902 L
.6392 .30902 L
.63988 .30902 L
.64052 .30902 L
.64172 .30902 L
.64302 .30902 L
.64374 .30902 L
.64441 .30902 L
.64554 .30902 L
.64677 .30902 L
.64805 .30902 L
.64925 .30902 L
.64993 .30902 L
.65067 .30902 L
.65137 .30902 L
.65202 .30902 L
.65324 .30902 L
.65454 .30902 L
.65521 .30902 L
Mistroke
.65593 .30902 L
.65724 .30902 L
.65803 .30902 L
.65879 .30902 L
.65946 .30902 L
.66021 .30902 L
.66085 .30902 L
.66153 .30902 L
.66275 .30902 L
.66407 .30902 L
.66482 .30902 L
.66551 .30902 L
.66676 .30902 L
.66744 .30902 L
.6681 .30902 L
.66925 .30902 L
.67051 .30902 L
.67163 .30902 L
.67286 .30902 L
.67415 .30902 L
.67537 .30902 L
.67649 .30902 L
.67753 .30902 L
.67866 .30902 L
.67986 .30902 L
.68117 .30902 L
.68237 .30902 L
.68303 .30902 L
.68374 .30902 L
.68504 .30902 L
.68626 .30902 L
.68755 .30902 L
.68866 .30902 L
.68987 .30902 L
.6906 .30902 L
.69129 .30902 L
.6926 .30902 L
.69332 .30902 L
.694 .30902 L
.69474 .30902 L
.69553 .30902 L
.69622 .30902 L
.69696 .30902 L
.69766 .30902 L
.69831 .30902 L
.69953 .30902 L
.70083 .30902 L
.70205 .30902 L
.70274 .30902 L
.70338 .30902 L
Mistroke
.70455 .30902 L
.70579 .30902 L
.7069 .30902 L
.70794 .30902 L
.70909 .30902 L
.71032 .30902 L
.71155 .30902 L
.71225 .30902 L
.7129 .30902 L
.71422 .30902 L
.71496 .30902 L
.71562 .30902 L
.71682 .30902 L
.71813 .30902 L
.71935 .30902 L
.72049 .30902 L
.72154 .30902 L
.72268 .30902 L
.72375 .30902 L
.72473 .30902 L
.72588 .30902 L
.72713 .30902 L
.7283 .30902 L
.7294 .30902 L
.73063 .30902 L
.7318 .30902 L
.73284 .30902 L
.73397 .30902 L
.7352 .30902 L
.7365 .30902 L
.73761 .30902 L
.73883 .30902 L
.74014 .30902 L
.74135 .30902 L
.74198 .30902 L
.74268 .30902 L
.74341 .30902 L
.74409 .30902 L
.74534 .30902 L
.74649 .30902 L
.74712 .30902 L
.74781 .30902 L
.74907 .30902 L
.75028 .30902 L
.75141 .30902 L
.75272 .30902 L
.75391 .30902 L
.75503 .30902 L
.75606 .30902 L
.7572 .30902 L
Mistroke
.75839 .30902 L
.7597 .30902 L
.76089 .30902 L
.76154 .30902 L
.76226 .30902 L
.76356 .30902 L
.76477 .30902 L
.76606 .30902 L
.76716 .30902 L
.76837 .30902 L
.76906 .30902 L
.7697 .30902 L
.77036 .30902 L
.77109 .30902 L
.77183 .30902 L
.77262 .30902 L
.77335 .30902 L
.77402 .30902 L
.77471 .30902 L
.77545 .30902 L
.77611 .30902 L
.7768 .30902 L
.77801 .30902 L
.77869 .30902 L
.77933 .30902 L
.78058 .30902 L
.78128 .30902 L
.78191 .30902 L
.78315 .30902 L
.78431 .30902 L
.78497 .30902 L
.78567 .30902 L
.78692 .30902 L
.78761 .30902 L
.78826 .30902 L
.78973 .30902 L
.79961 .30902 L
.81815 .30902 L
.85711 .30902 L
.89851 .30902 L
.93841 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001C?o000306Ko<ol0000000Tco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0c
o`00;c?o00030000<ol0<ol002<co`000`1Voc?o03?o0009<ol000<0000co`0co`00;S?o00030000
<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004OoooePco`000`1Voc?o
03?o001/<ol000<0003oooooool0AOooo`004Oooo`H0I_mB<ol000<0I_lco`0co`00K3?o00030000
oooooooo04Goool0017oool6<ol05@1Vocdco`000`1Voc?o03?o001/<ol000<0003oooooool0AOoo
o`004Ooooa/co`0:06Ko<c?o000306Ko<ol0<ol006`co`000`000?ooooooo`15oooo000Aoooo9C?o
00X0I_lY<ol000<0I_lco`0co`00K3?o00030000oooooooo04Goool0017oool_<ol0201Vob4co`00
0`1Voc?o03?o001/<ol00P0004Koool0017ooolg<ol01@1Voa`co`000`1Voc?o03?o001/<ol000<0
003oooooool0AOooo`004Ooooc`co`0806Ko53?o000306Ko<ol0<ol006`co`000`000?ooooooo`15
oooo000AooooA3?o00P0I_l<<ol000<0I_lco`0co`00K3?o00030000oooooooo04Goool0017ooom<
<ol01`1Vo`Dco`000`1Voc?o03?o001/<ol000<0003oooooool0AOooo`004Ooooe<co`0606KoKS?o
00030000oooooooo04Goool0017ooomG<ol00P1Vofhco`000`000?ooooooo`15oooo000AooooF3?o
0003o`2I<ol0<ol006`co`000`000?ooooooo`15oooo000Aoooo0P0005Hco`000ol0VC?o03?o001/
<ol00P0004Koool001?oool20000E3?o0003o`2I<ol0<ol006`co`000`000?ooooooo`15oooo000E
oooo0P00058co`000ol0VC?o03?o001/<ol000<0003oooooool0AOooo`005oooo`80001@<ol000?o
09Tco`0co`00K3?o00030000oooooooo04Goool001Woool20000CS?o0003o`2I<ol0<ol006`co`00
0`000?ooooooo`15oooo000Koooo0P0004`co`000ol0VC?o03?o001/<ol000<0003oooooool0AOoo
o`007Oooo`80001:<ol000?o09Tco`0co`00K3?o00030000oooooooo04Goool001ooool00`0003?o
03?o0017<ol000?o09Tco`0co`00K3?o00030000oooooooo04Goool0023oool00`0003?o03?o0016
<ol000?o09Tco`0co`00K3?o00800016oooo000Qoooo0P0004Hco`000ol0VC?o03?o001/<ol000<0
003oooooool0AOooo`008oooo`030000<ol0<ol004<co`000ol0VC?o03?o001/<ol000<0003ooooo
ool0AOooo`009?ooo`800013<ol000?o09Tco`0co`00K3?o00030000oooooooo04Goool002Koool0
0`0003?o03?o0010<ol000?o09Tco`0co`00K3?o00030000oooooooo04Goool002Ooool00`0003?o
03?o000o<ol000?o09Tco`0co`00K3?o00030000oooooooo04Goool002Soool00`0003?o03?o000n
<ol000?o09Tco`0co`00Dc?o00800004<ol00P0000@co`0200000c?o00@00004<ol000<0003ooooo
ool0AOooo`00:Oooo`030000<ol0<ol003dco`000ol0VC?o03?o001B<ol000@0000co`0co`000008
<ol000@0000co`0co`000002<ol000<0000co`0co`001C?o00030000oooooooo04Goool002[oool0
0`0003?o03?o000l<ol000?o09Tco`0co`00DS?o00040000<ol0<ol0000023?o00040000<ol0<ol0
00000c?o00030000<ol0<ol000@co`030000AOooo`00:oooo`80000l<ol000?o09Tco`0co`00DS?o
00040000<ol0<ol0000023?o00040000<ol0<ol0000013?o00030000<ol0<ol000<co`000`000?oo
ooooo`15oooo000]oooo00<0000co`0co`00>C?o0003o`2I<ol0<ol0058co`00100003?o03?o0000
00Pco`00100003?o03?o0000008co`00100003?o03?o000000@co`000`000?ooooooo`15oooo000^
oooo00<0000co`0co`00>3?o0003o`2I<ol0<ol005<co`0200002S?o00800004<ol00P0000Dco`00
0`000?ooooooo`15oooo000_oooo00<0000co`0co`00=c?o0003o`2I<ol0<ol006`co`000`000?oo
ooooo`15oooo000`oooo00<0000co`0co`00=S?o0003o`2I<ol0<ol006`co`000`000?ooooooo`15
oooo000aoooo00<0000co`0co`00=C?o0003o`2I<ol0<ol006`co`000`000?ooooooo`15oooo000b
oooo00<0000co`0co`00=3?o0003o`2I<ol0<ol006`co`000`000?ooooooo`15oooo000coooo00<0
000co`0co`00<c?o0003o`2I<ol0<ol006`co`020000A_ooo`00<oooo`030000<ol0<ol003<co`00
0ol0VC?o03?o001/<ol000<0003oooooool0AOooo`00=?ooo`030000<ol0<ol0038co`000ol0VC?o
03?o001/<ol000<0003oooooool0AOooo`00=Oooo`030000<ol0<ol0034co`000ol0VC?o03?o001/
<ol000<0003oooooool0AOooo`00=_ooo`030000<ol0<ol0030co`000ol0VC?o03?o001/<ol000<0
003oooooool0AOooo`00=oooo`030000<ol0<ol002lco`000ol0VC?o03?o001/<ol000<0003ooooo
ool0AOooo`00>?ooo`030000<ol0<ol002hco`000ol0VC?o03?o001/<ol000<0003oooooool0AOoo
o`00>?ooo`030000<ol0<ol002hco`000ol0VC?o03?o001/<ol000<0003oooooool0AOooo`00>Ooo
o`030000<ol0<ol002dco`000ol0VC?o03?o001/<ol00P0004Koool003[oool00`0003?o03?o000/
<ol000?o09Tco`0co`00K3?o00030000oooooooo04Goool003_oool00`0003?o03?o000[<ol000?o
09Tco`0co`00K3?o00030000oooooooo04Goool003coool00`0003?o03?o000Z<ol000?o09Tco`0c
o`00K3?o00030000oooooooo04Goool003coool00`0003?o03?o000Z<ol000?o09Tco`0co`00K3?o
00030000oooooooo04Goool003goool00`0003?o03?o000Y<ol000?o09Tco`0co`00K3?o00030000
oooooooo04Goool003goool00`0003?o03?o000Y<ol000?o09Tco`0co`00K3?o00030000oooooooo
04Goool003koool00`0003?o03?o000X<ol000?o09Tco`0co`00K3?o00030000oooooooo04Goool0
03koool00`0003?o03?o000X<ol000?o09Tco`0co`00K3?o00030000oooooooo04Goool003ooool0
0`0003?o03?o000W<ol000?o09Tco`0co`00K3?o00800016oooo000ooooo00<0000co`0co`009c?o
0003o`2I<ol0<ol006`co`000`000?ooooooo`15oooo0010oooo00<0000co`0co`009S?o0003o`2I
<ol0<ol006`co`000`000?ooooooo`15oooo0011oooo00<0000co`0co`009C?o0003o`2I<ol0<ol0
06`co`000`000?ooooooo`15oooo0011oooo00<0000co`0co`009C?o0003o`2I<ol0<ol006`co`00
0`000?ooooooo`15oooo0012oooo00<0000co`0co`0093?o0003o`2I<ol0<ol006`co`000`000?oo
ooooo`15oooo0012oooo00<0000co`0co`0093?o0003o`2I<ol0<ol005<co`02000013?o00800004
<ol00P0000Dco`0300000c?o00030000oooooooo04Goool004?oool00`0003?o03?o000S<ol000?o
09Tco`0co`00DS?o00040000<ol0<ol0000023?o00040000<ol0<ol000001C?o00030000<ol0<ol0
008co`000`000?ooooooo`15oooo0013oooo00<0000co`0co`008c?o0003o`2I<ol0<ol0058co`00
100003?o03?o000000Pco`00100003?o03?o0000008co`0500000c?o00<00015oooo0014oooo00<0
000co`0co`008S?o0003o`2I<ol0<ol0058co`00100003?o03?o000000Pco`00100003?o03?o0000
008co`00100003?o03?o000000@co`000`000?ooooooo`15oooo0014oooo00<0000co`0co`008S?o
0003o`2I<ol0<ol0058co`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o
00000004<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol0024co`000ol0VC?o03?o001C
<ol00P0000Xco`0200001C?o00800004<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol0
024co`000ol0VC?o03?o001/<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol0020co`00
0ol0VC?o03?o001/<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol0020co`000ol0VC?o
03?o001/<ol000<0003oooooool0AOooo`00Aoooo`030000<ol0<ol001lco`000ol0VC?o03?o001/
<ol000<0003oooooool0AOooo`00Aoooo`030000<ol0<ol001lco`000ol0VC?o03?o001/<ol00P00
04Koool004Soool00`0003?o03?o000N<ol000?o09Tco`0co`00K3?o00030000oooooooo04Goool0
04Soool00`0003?o03?o000N<ol000?o09Tco`0co`00K3?o00030000oooooooo04Goool004Woool0
0`0003?o03?o000M<ol000?o09Tco`0co`00K3?o00030000oooooooo04Goool004Woool00`0003?o
03?o000M<ol000?o09Tco`0co`00K3?o00030000oooooooo04Goool004[oool00`0003?o03?o000L
<ol000?o09Tco`0co`00K3?o00030000oooooooo04Goool004[oool00`0003?o03?o000L<ol000?o
09Tco`0co`00K3?o00030000oooooooo04Goool004_oool00`0003?o03?o000K<ol000?o09Tco`0c
o`00K3?o00030000oooooooo04Goool004_oool00`0003?o03?o000K<ol000?o09Tco`0co`00K3?o
00800016oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001=ooooRc?o
04Soool004gooon;<ol0B?ooo`00C_ooobHco`000`0003?o03?o000_<ol000<0000co`0co`00;c?o
04Soool004kooolU<ol000<0000co`0co`0023?o00030000<ol0<ol002Hco`000`0003?o03?o000^
<ol0B?ooo`00Coooob@co`000`0003?o03?o0002<ol00P0000@co`000`0003?o03?o000><ol00P00
00@co`0200000c?o00D000000c?o00000000000200000c?o00030000<ol0<ol002hco`18oooo001?
oooo93?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0000co`0co`001C?o
00@00003<ol000@0000co`0co`00000:<ol000D0000co`0co`0co`0000001S?o00030000<ol0<ol0
02hco`18oooo001?oooo8c?o00030000<ol0<ol0008co`000`0003?o03?o000D<ol000@0000co`0c
o`00000:<ol000<0000co`0co`000S?o00030000<ol0<ol000@co`000`0003?o03?o000]<ol0B?oo
o`00D?ooob<co`000`0003?o03?o000500004c?o00040000<ol0<ol000002S?o00030000<ol0<ol0
00<co`000`0003?o03?o0002<ol000<0000co`0co`00;S?o04Soool0053ooolS<ol000D0000co`0c
o`0co`0000005S?o00040000<ol0<ol000002S?o00050000<ol0<ol0<ol00000008co`001@0003?o
03?o03?o0000000`<ol0B?ooo`00D?ooob@co`000`0003?o03?o000H<ol00P0000Xco`02000013?o
00800003<ol000<0000co`0co`00;c?o04Soool0057ooon7<ol0B?ooo`00DOooohLco`18oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.11) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.35271 .30902 L
.35742 .30902 L
.35948 .30902 L
.36057 .30902 L
.36173 .30902 L
s
.36173 .30902 m
.36174 .61803 L
s
0 .4 1 r
.02381 .32263 m
.06244 .32473 L
.10458 .32739 L
.14415 .33031 L
.18221 .33355 L
.22272 .33755 L
.26171 .34203 L
.30316 .34757 L
.32392 .35069 L
.34309 .3538 L
.35271 .35545 L
.35742 .35628 L
.35948 .35665 L
.36057 .35685 L
.36173 .35706 L
.36294 .30902 L
.36405 .30902 L
.36521 .30902 L
.36626 .30902 L
.36747 .30902 L
.36877 .30902 L
.37001 .30902 L
.37114 .30902 L
.37238 .30902 L
.37354 .30902 L
.37481 .30902 L
.37553 .30902 L
.37618 .30902 L
.37749 .30902 L
.37823 .30902 L
.37891 .30902 L
.38017 .30902 L
.3808 .30902 L
.3815 .30902 L
.38272 .30902 L
.38385 .30902 L
.38509 .30902 L
.38578 .30902 L
.38642 .30902 L
.38769 .30902 L
.38908 .30902 L
.39039 .30902 L
.39159 .30902 L
.3927 .30902 L
.39373 .30902 L
.39487 .30902 L
.39609 .30902 L
.39736 .30902 L
.39857 .30902 L
.39966 .30902 L
Mistroke
.40085 .30902 L
.40153 .30902 L
.40226 .30902 L
.40296 .30902 L
.4036 .30902 L
.40481 .30902 L
.40609 .30902 L
.40675 .30902 L
.40747 .30902 L
.40875 .30902 L
.40953 .30902 L
.41028 .30902 L
.41094 .30902 L
.41167 .30902 L
.41287 .30902 L
.41356 .30902 L
.4142 .30902 L
.41487 .30902 L
.41558 .30902 L
.41688 .30902 L
.41801 .30902 L
.41923 .30902 L
.42043 .30902 L
.4217 .30902 L
.42233 .30902 L
.42303 .30902 L
.42425 .30902 L
.42494 .30902 L
.42567 .30902 L
.42637 .30902 L
.427 .30902 L
.42823 .30902 L
.42893 .30902 L
.42957 .30902 L
.43075 .30902 L
.432 .30902 L
.43311 .30902 L
.43429 .30902 L
.43542 .30902 L
.43645 .30902 L
.43759 .30902 L
.43883 .30902 L
.44014 .30902 L
.44135 .30902 L
.44266 .30902 L
.4434 .30902 L
.44408 .30902 L
.44533 .30902 L
.44596 .30902 L
.44666 .30902 L
Mistroke
.44786 .30902 L
.44915 .30902 L
.45036 .30902 L
.45148 .30902 L
.45215 .30902 L
.45287 .30902 L
.45366 .30902 L
.45438 .30902 L
.45507 .30902 L
.4558 .30902 L
.4565 .30902 L
.45714 .30902 L
.45834 .30902 L
.45966 .30902 L
.46032 .30902 L
.46103 .30902 L
.46232 .30902 L
.46354 .30902 L
.46423 .30902 L
.46488 .30902 L
.46619 .30902 L
.46693 .30902 L
.46761 .30902 L
.46884 .30902 L
.46999 .30902 L
.47119 .30902 L
.4725 .30902 L
.47393 .30902 L
.47474 .30902 L
.47548 .30902 L
.47683 .30902 L
.47754 .30902 L
.4783 .30902 L
.47899 .30902 L
.47962 .30902 L
.48086 .30902 L
.48153 .30902 L
.48225 .30902 L
.48357 .30902 L
.48486 .30902 L
.48602 .30902 L
.48666 .30902 L
.48736 .30902 L
.48862 .30902 L
.48981 .30902 L
.49106 .30902 L
.49213 .30902 L
.4933 .30902 L
.494 .30902 L
.49466 .30902 L
Mistroke
.4959 .30902 L
.49655 .30902 L
.49724 .30902 L
.49799 .30902 L
.49868 .30902 L
.49991 .30902 L
.50107 .30902 L
.50233 .30902 L
.50305 .30902 L
.5037 .30902 L
.50498 .30902 L
.50619 .30902 L
.50729 .30902 L
.50846 .30902 L
.50973 .30902 L
.5109 .30902 L
.51215 .30902 L
.51287 .30902 L
.51354 .30902 L
.51472 .30902 L
.51584 .30902 L
.51685 .30902 L
.51794 .30902 L
.51914 .30902 L
.5204 .30902 L
.52148 .30902 L
.52267 .30902 L
.52398 .30902 L
.52464 .30902 L
.52535 .30902 L
.52663 .30902 L
.52781 .30902 L
.52854 .30902 L
.52922 .30902 L
.53049 .30902 L
.53121 .30902 L
.53187 .30902 L
.53336 .30902 L
.53457 .30902 L
.53588 .30902 L
.53711 .30902 L
.53823 .30902 L
.53949 .30902 L
.54069 .30902 L
.54198 .30902 L
.54271 .30902 L
.54339 .30902 L
.54468 .30902 L
.54533 .30902 L
.54604 .30902 L
Mistroke
.54731 .30902 L
.54848 .30902 L
.54919 .30902 L
.54996 .30902 L
.55069 .30902 L
.55136 .30902 L
.55263 .30902 L
.55327 .30902 L
.55398 .30902 L
.55518 .30902 L
.55646 .30902 L
.55768 .30902 L
.55879 .30902 L
.55999 .30902 L
.5613 .30902 L
.56197 .30902 L
.56267 .30902 L
.56395 .30902 L
.5652 .30902 L
.56636 .30902 L
.56763 .30902 L
.56827 .30902 L
.56897 .30902 L
.57015 .30902 L
.57142 .30902 L
.57261 .30902 L
.5737 .30902 L
.57483 .30902 L
.57588 .30902 L
.57703 .30902 L
.57825 .30902 L
.57931 .30902 L
.5803 .30902 L
.58139 .30902 L
.58256 .30902 L
.58381 .30902 L
.58495 .30902 L
.58627 .30902 L
.58751 .30902 L
.58866 .30902 L
.58972 .30902 L
.59088 .30902 L
.59211 .30902 L
.59335 .30902 L
.59405 .30902 L
.59468 .30902 L
.59592 .30902 L
.59709 .30902 L
.59775 .30902 L
.59845 .30902 L
Mistroke
.59971 .30902 L
.60048 .30902 L
.60121 .30902 L
.60186 .30902 L
.60257 .30902 L
.60389 .30902 L
.60512 .30902 L
.60582 .30902 L
.60647 .30902 L
.60722 .30902 L
.60791 .30902 L
.60858 .30902 L
.6093 .30902 L
.61002 .30902 L
.61081 .30902 L
.61149 .30902 L
.61222 .30902 L
.61292 .30902 L
.61355 .30902 L
.61477 .30902 L
.6159 .30902 L
.61715 .30902 L
.61784 .30902 L
.61848 .30902 L
.61967 .30902 L
.62094 .30902 L
.62168 .30902 L
.62235 .30902 L
.62366 .30902 L
.62485 .30902 L
.62615 .30902 L
.62737 .30902 L
.62851 .30902 L
.62981 .30902 L
.631 .30902 L
.63165 .30902 L
.63236 .30902 L
.63364 .30902 L
.63476 .30902 L
.63598 .30902 L
.63725 .30902 L
.63844 .30902 L
.63955 .30902 L
.64057 .30902 L
.64174 .30902 L
.64285 .30902 L
.64404 .30902 L
.64536 .30902 L
.64603 .30902 L
.64674 .30902 L
Mistroke
.64803 .30902 L
.64931 .30902 L
.65053 .30902 L
.65162 .30902 L
.65282 .30902 L
.65355 .30902 L
.65424 .30902 L
.65553 .30902 L
.65626 .30902 L
.65693 .30902 L
.6577 .30902 L
.65843 .30902 L
.65964 .30902 L
.66028 .30902 L
.66097 .30902 L
.66169 .30902 L
.66237 .30902 L
.66365 .30902 L
.66862 .30902 L
.67105 .30902 L
.67212 .30902 L
.67329 .30902 L
.67443 .30902 L
.67563 .30902 L
.67694 .30902 L
.67816 .30902 L
.67886 .30902 L
.67952 .30902 L
.68076 .30902 L
.68145 .30902 L
.68209 .30902 L
.68279 .30902 L
.68354 .30902 L
.68466 .30902 L
.68572 .30902 L
.68695 .30902 L
.68807 .30902 L
.68912 .30902 L
.69009 .30902 L
.69116 .30902 L
.6923 .30902 L
.69356 .30902 L
.69426 .30902 L
.69491 .30902 L
.69611 .30902 L
.69737 .30902 L
.6985 .30902 L
.69955 .30902 L
.70071 .30902 L
.70195 .30902 L
Mistroke
.70317 .30902 L
.70387 .30902 L
.70452 .30902 L
.70583 .30902 L
.70657 .30902 L
.70725 .30902 L
.70838 .30902 L
.70963 .30902 L
.71093 .30902 L
.71214 .30902 L
.71283 .30902 L
.71358 .30902 L
.71429 .30902 L
.71495 .30902 L
.71619 .30902 L
.7175 .30902 L
.71881 .30902 L
.71955 .30902 L
.72022 .30902 L
.72101 .30902 L
.72177 .30902 L
.72246 .30902 L
.72321 .30902 L
.72387 .30902 L
.72458 .30902 L
.72587 .30902 L
.72828 .30902 L
.73366 .30902 L
.74334 .30902 L
.76334 .30902 L
.76454 .30902 L
.76584 .30902 L
.76707 .30902 L
.7682 .30902 L
.76952 .30902 L
.77092 .30902 L
.7721 .30902 L
.7734 .30902 L
.77414 .30902 L
.77482 .30902 L
.7756 .30902 L
.77635 .30902 L
.77767 .30902 L
.77841 .30902 L
.77911 .30902 L
.7798 .30902 L
.78046 .30902 L
.78168 .30902 L
.783 .30902 L
.78374 .30902 L
Mistroke
.78442 .30902 L
.78569 .30902 L
.78688 .30902 L
.78795 .30902 L
.78912 .30902 L
.79416 .30902 L
.80324 .30902 L
.82391 .30902 L
.86468 .30902 L
.90395 .30902 L
.94169 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.11) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001S?o000306Ko0000<ol000Pco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0c
o`00;c?o00030000<ol0<ol002@co`000`1Voc?o03?o0008<ol000<0000co`0co`00;S?o00030000
<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004OoooeTco`000`1Voc?o
03?o001[<ol000<0003oooooool0AOooo`004Ooooa00I_m9<ol000<0I_lco`0co`00Jc?o00030000
oooooooo04Goool0017oool@<ol02`1Vochco`000`1Voc?o03?o001[<ol000<0003oooooool0AOoo
o`004Ooooa/co`0:06Ko=3?o000306Ko<ol0<ol006/co`000`000?ooooooo`15oooo000Aoooo9C?o
00X0I_lZ<ol000<0I_lco`0co`00Jc?o00030000oooooooo04Goool0017oool_<ol02P1Vob0co`00
0`1Voc?o03?o001[<ol00P0004Koool0017oooli<ol02`1VoaDco`000`1Voc?o03?o001[<ol000<0
003oooooool0AOooo`004Ooood@co`0806Ko3C?o000306Ko<ol0<ol006/co`000`000?ooooooo`15
oooo000AooooC3?o00H0I_l7<ol000<0I_lco`0co`00Jc?o00030000oooooooo04Goool0017ooomB
<ol01P1Vo`03<ol006Ko<ol006`co`000`000?ooooooo`15oooo000AooooF3?o0080I_m]<ol000<0
003oooooool0AOooo`004OoooeTco`000ol0VC?o03?o001[<ol000<0003oooooool0AOooo`004Ooo
oeTco`000ol0VC?o03?o001[<ol000<0003oooooool0AOooo`004Oooo`80001G<ol000?o09Tco`0c
o`00Jc?o00800016oooo000Coooo0P0005Dco`000ol0VC?o03?o001[<ol000<0003oooooool0AOoo
o`005Oooo`80001C<ol000?o09Tco`0co`00Jc?o00030000oooooooo04Goool001Ooool20000DC?o
0003o`2I<ol0<ol006/co`000`000?ooooooo`15oooo000Ioooo0P0004lco`000ol0VC?o03?o001[
<ol000<0003oooooool0AOooo`006oooo`80001=<ol000?o09Tco`0co`00Jc?o00030000oooooooo
04Goool001goool20000Bc?o0003o`2I<ol0<ol006/co`000`000?ooooooo`15oooo000Ooooo00<0
000co`0co`00B3?o0003o`2I<ol0<ol006/co`000`000?ooooooo`15oooo000Poooo00<0000co`0c
o`00Ac?o0003o`2I<ol0<ol006/co`020000A_ooo`008Oooo`800017<ol000?o09Tco`0co`00Jc?o
00030000oooooooo04Goool002?oool00`0003?o03?o0014<ol000?o09Tco`0co`00Jc?o00030000
oooooooo04Goool002Coool20000A3?o0003o`2I<ol0<ol006/co`000`000?ooooooo`15oooo000V
oooo00<0000co`0co`00@C?o0003o`2I<ol0<ol006/co`000`000?ooooooo`15oooo000Woooo00<0
000co`0co`00@3?o0003o`2I<ol0<ol006/co`000`000?ooooooo`15oooo000Xoooo00<0000co`0c
o`00?c?o0003o`2I<ol0<ol0058co`02000013?o00800004<ol00P0000<co`04000013?o00030000
oooooooo04Goool002Woool00`0003?o03?o000n<ol000?o09Tco`0co`00DC?o00040000<ol0<ol0
000023?o00040000<ol0<ol000000S?o00030000<ol0<ol000Dco`000`000?ooooooo`15oooo000Z
oooo00<0000co`0co`00?C?o0003o`2I<ol0<ol0054co`00100003?o03?o000000Pco`00100003?o
03?o000000<co`000`0003?o03?o0004<ol00`0004Goool002_oool20000?C?o0003o`2I<ol0<ol0
054co`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`0003?o03?o0003<ol000<0
003oooooool0AOooo`00;Oooo`030000<ol0<ol003Xco`000ol0VC?o03?o001A<ol000@0000co`0c
o`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000004<ol000<0003oooooool0AOoo
o`00;_ooo`030000<ol0<ol003Tco`000ol0VC?o03?o001B<ol00P0000Xco`02000013?o00800005
<ol000<0003oooooool0AOooo`00;oooo`030000<ol0<ol003Pco`000ol0VC?o03?o001[<ol000<0
003oooooool0AOooo`00<?ooo`030000<ol0<ol003Lco`000ol0VC?o03?o001[<ol000<0003ooooo
ool0AOooo`00<Oooo`030000<ol0<ol003Hco`000ol0VC?o03?o001[<ol000<0003oooooool0AOoo
o`00<_ooo`030000<ol0<ol003Dco`000ol0VC?o03?o001[<ol000<0003oooooool0AOooo`00<ooo
o`030000<ol0<ol003@co`000ol0VC?o03?o001[<ol00P0004Koool003?oool00`0003?o03?o000d
<ol000?o09Tco`0co`00Jc?o00030000oooooooo04Goool003Coool00`0003?o03?o000c<ol000?o
09Tco`0co`00Jc?o00030000oooooooo04Goool003Goool00`0003?o03?o000b<ol000?o09Tco`0c
o`00Jc?o00030000oooooooo04Goool003Koool00`0003?o03?o000a<ol000?o09Tco`0co`00Jc?o
00030000oooooooo04Goool003Ooool00`0003?o03?o000`<ol000?o09Tco`0co`00Jc?o00030000
oooooooo04Goool003Soool00`0003?o03?o000_<ol000?o09Tco`0co`00Jc?o00030000oooooooo
04Goool003Soool00`0003?o03?o000_<ol000?o09Tco`0co`00Jc?o00030000oooooooo04Goool0
03Woool00`0003?o03?o000^<ol000?o09Tco`0co`00Jc?o00800016oooo000joooo00<0000co`0c
o`00;C?o0003o`2I<ol0<ol006/co`000`000?ooooooo`15oooo000koooo00<0000co`0co`00;3?o
0003o`2I<ol0<ol006/co`000`000?ooooooo`15oooo000loooo00<0000co`0co`00:c?o0003o`2I
<ol0<ol006/co`000`000?ooooooo`15oooo000loooo00<0000co`0co`00:c?o0003o`2I<ol0<ol0
06/co`000`000?ooooooo`15oooo000moooo00<0000co`0co`00:S?o0003o`2I<ol0<ol006/co`00
0`000?ooooooo`15oooo000moooo00<0000co`0co`00:S?o0003o`2I<ol0<ol006/co`000`000?oo
ooooo`15oooo000noooo00<0000co`0co`00:C?o0003o`2I<ol0<ol006/co`000`000?ooooooo`15
oooo000noooo00<0000co`0co`00:C?o0003o`2I<ol0<ol006/co`000`000?ooooooo`15oooo000o
oooo00<0000co`0co`00:3?o0003o`2I<ol0<ol006/co`020000A_ooo`00?oooo`030000<ol0<ol0
02Pco`000ol0VC?o03?o001[<ol000<0003oooooool0AOooo`00@?ooo`030000<ol0<ol002Lco`00
0ol0VC?o03?o001[<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol002Hco`000ol0VC?o
03?o001[<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol002Hco`000ol0VC?o03?o001[
<ol000<0003oooooool0AOooo`00@_ooo`030000<ol0<ol002Dco`000ol0VC?o03?o001[<ol000<0
003oooooool0AOooo`00@_ooo`030000<ol0<ol002Dco`000ol0VC?o03?o001B<ol00P0000@co`02
000013?o00800005<ol00`0000<co`000`000?ooooooo`15oooo0013oooo00<0000co`0co`0093?o
0003o`2I<ol0<ol0054co`00100003?o03?o000000Pco`00100003?o03?o000000Dco`000`0003?o
03?o0002<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol002@co`000ol0VC?o03?o001A
<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol01@0000<co`030000AOooo`00A?oo
o`030000<ol0<ol002<co`000ol0VC?o03?o001A<ol000@0000co`0co`000008<ol000@0000co`0c
o`000002<ol000@0000co`0co`000004<ol000<0003oooooool0AOooo`00A?ooo`030000<ol0<ol0
02<co`000ol0VC?o03?o001A<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0
000co`00000013?o00030000oooooooo04Goool004Goool00`0003?o03?o000R<ol000?o09Tco`0c
o`00DS?o0080000:<ol00P0000Dco`02000013?o00030000oooooooo04Goool004Goool00`0003?o
03?o000R<ol000?o09Tco`0co`00Jc?o00030000oooooooo04Goool004Koool00`0003?o03?o000Q
<ol000?o09Tco`0co`00Jc?o00030000oooooooo04Goool004Koool00`0003?o03?o000Q<ol000?o
09Tco`0co`00Jc?o00030000oooooooo04Goool004Ooool00`0003?o03?o000P<ol000?o09Tco`0c
o`00Jc?o00030000oooooooo04Goool004Ooool00`0003?o03?o000P<ol000?o09Tco`0co`00Jc?o
00800016oooo0018oooo00<0000co`0co`007c?o0003o`2I<ol0<ol006/co`000`000?ooooooo`15
oooo0018oooo00<0000co`0co`007c?o0003o`2I<ol0<ol006/co`000`000?ooooooo`15oooo0019
oooo00<0000co`0co`007S?o0003o`2I<ol0<ol006/co`000`000?ooooooo`15oooo0019oooo00<0
000co`0co`007S?o0003o`2I<ol0<ol006/co`000`000?ooooooo`15oooo001:oooo00<0000co`0c
o`007C?o0003o`2I<ol0<ol006/co`000`000?ooooooo`15oooo001:oooo00<0000co`0co`007C?o
0003o`2I<ol0<ol006/co`000`000?ooooooo`15oooo001;oooo00<0000co`0co`0073?o0003o`2I
<ol0<ol006/co`000`000?ooooooo`15oooo001;oooo00<0000co`0co`0073?o0003o`2I<ol0<ol0
06/co`020000A_ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00COoo
oh/co`18oooo001=ooooRc?o04Soool004kooolV<ol000<0000co`0co`00;c?o00030000<ol0<ol0
02lco`18oooo001>oooo9C?o00030000<ol0<ol000Pco`000`0003?o03?o000V<ol000<0000co`0c
o`00;S?o04Soool004oooolT<ol000<0000co`0co`000S?o00800004<ol000<0000co`0co`003S?o
00800004<ol00P0000<co`05000000<co`00000000000`00008co`000`0003?o03?o000^<ol0B?oo
o`00Coooob@co`001@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o00030000<ol0<ol0
00Dco`0400000c?o00040000<ol0<ol000002S?o00030000<ol0<ol000<co`000`0003?o03?o0002
<ol000<0000co`0co`00;S?o04Soool004oooolS<ol000<0000co`0co`000S?o00030000<ol0<ol0
01@co`00100003?o03?o000000Xco`000`0003?o03?o0003<ol000<0000co`0co`000c?o00030000
<ol0<ol002dco`18oooo001@oooo8c?o00030000<ol0<ol000D0000C<ol000@0000co`0co`00000:
<ol000<0000co`0co`000c?o00030000<ol0<ol0008co`000`0003?o03?o000^<ol0B?ooo`00D?oo
ob<co`001@0003?o03?o03?o0000000F<ol000@0000co`0co`00000:<ol000<0000co`0co`000c?o
00030000<ol0<ol0008co`000`0003?o03?o000^<ol0B?ooo`00D?ooob@co`000`0003?o03?o000H
<ol00P0000Xco`02000013?o00800003<ol000<0000co`0co`00;c?o04Soool0057ooon7<ol0B?oo
o`00DOooohLco`18oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.35271 .30902 L
.36173 .30902 L
.36405 .30902 L
.3652 .30902 L
.36626 .30902 L
s
.36626 .30902 m
.36627 .61803 L
s
0 .4 1 r
.02381 .32138 m
.06244 .32329 L
.10458 .32571 L
.14415 .32836 L
.18221 .33131 L
.22272 .33494 L
.26171 .339 L
.30316 .34404 L
.32392 .34687 L
.34309 .3497 L
.35271 .3512 L
.36173 .35266 L
.36405 .35304 L
.3652 .35323 L
.36626 .35341 L
.36748 .30902 L
.36812 .30902 L
.36881 .30902 L
.37003 .30902 L
.37114 .30902 L
.37179 .30902 L
.37247 .30902 L
.3737 .30902 L
.37502 .30902 L
.37578 .30902 L
.37647 .30902 L
.37773 .30902 L
.37842 .30902 L
.37907 .30902 L
.3815 .30902 L
.41983 .30902 L
.42222 .30902 L
.42352 .30902 L
.42474 .30902 L
.42606 .30902 L
.42675 .30902 L
.4275 .30902 L
.42818 .30902 L
.42882 .30902 L
.43003 .30902 L
.43119 .30902 L
.43242 .30902 L
.43347 .30902 L
.43462 .30902 L
.43586 .30902 L
.43656 .30902 L
.4372 .30902 L
.4396 .30902 L
.44087 .30902 L
.44205 .30902 L
Mistroke
.44335 .30902 L
.44401 .30902 L
.44473 .30902 L
.44604 .30902 L
.44728 .30902 L
.44848 .30902 L
.44959 .30902 L
.45023 .30902 L
.45091 .30902 L
.45215 .30902 L
.4529 .30902 L
.45362 .30902 L
.45426 .30902 L
.45495 .30902 L
.45563 .30902 L
.45638 .30902 L
.45716 .30902 L
.45789 .30902 L
.4592 .30902 L
.45994 .30902 L
.46061 .30902 L
.46189 .30902 L
.4631 .30902 L
.46419 .30902 L
.46537 .30902 L
.46665 .30902 L
.4673 .30902 L
.46801 .30902 L
.46927 .30902 L
.47044 .30902 L
.47162 .30902 L
.47274 .30902 L
.47375 .30902 L
.47485 .30902 L
.47604 .30902 L
.4773 .30902 L
.47838 .30902 L
.47957 .30902 L
.48088 .30902 L
.48153 .30902 L
.48225 .30902 L
.48352 .30902 L
.48471 .30902 L
.48761 .30902 L
.48888 .30902 L
.48959 .30902 L
.49025 .30902 L
.49146 .30902 L
.49275 .30902 L
.49387 .30902 L
Mistroke
.4951 .30902 L
.49639 .30902 L
.49712 .30902 L
.49778 .30902 L
.49907 .30902 L
.50029 .30902 L
.50153 .30902 L
.50223 .30902 L
.50288 .30902 L
.50407 .30902 L
.50532 .30902 L
.50645 .30902 L
.5075 .30902 L
.50865 .30902 L
.50988 .30902 L
.5112 .30902 L
.51194 .30902 L
.51263 .30902 L
.51389 .30902 L
.51453 .30902 L
.51523 .30902 L
.51644 .30902 L
.51775 .30902 L
.51898 .30902 L
.52011 .30902 L
.52118 .30902 L
.52233 .30902 L
.52332 .30902 L
.52439 .30902 L
.52565 .30902 L
.52684 .30902 L
.52799 .30902 L
.52907 .30902 L
.53021 .30902 L
.53145 .30902 L
.53267 .30902 L
.53398 .30902 L
.53519 .30902 L
.53634 .30902 L
.53737 .30902 L
.5385 .30902 L
.53915 .30902 L
.53984 .30902 L
.54107 .30902 L
.54239 .30902 L
.54314 .30902 L
.54384 .30902 L
.54511 .30902 L
.54626 .30902 L
.5469 .30902 L
Mistroke
.54759 .30902 L
.54885 .30902 L
.54996 .30902 L
.551 .30902 L
.55221 .30902 L
.55331 .30902 L
.55453 .30902 L
.55521 .30902 L
.55585 .30902 L
.557 .30902 L
.55823 .30902 L
.55891 .30902 L
.55966 .30902 L
.56036 .30902 L
.561 .30902 L
.56223 .30902 L
.56352 .30902 L
.56419 .30902 L
.56491 .30902 L
.5662 .30902 L
.56699 .30902 L
.56774 .30902 L
.56841 .30902 L
.56914 .30902 L
.57035 .30902 L
.57103 .30902 L
.57168 .30902 L
.57297 .30902 L
.5737 .30902 L
.57437 .30902 L
.5755 .30902 L
.57673 .30902 L
.57802 .30902 L
.57922 .30902 L
.58049 .30902 L
.58114 .30902 L
.58184 .30902 L
.58309 .30902 L
.58426 .30902 L
.58497 .30902 L
.58564 .30902 L
.5869 .30902 L
.5876 .30902 L
.58826 .30902 L
.58897 .30902 L
.58973 .30902 L
.59102 .30902 L
.59175 .30902 L
.59242 .30902 L
.59362 .30902 L
Mistroke
.59495 .30902 L
.59613 .30902 L
.59724 .30902 L
.5984 .30902 L
.59967 .30902 L
.60092 .30902 L
.60208 .30902 L
.60319 .30902 L
.60436 .30902 L
.60541 .30902 L
.6064 .30902 L
.60748 .30902 L
.60864 .30902 L
.60981 .30902 L
.61108 .30902 L
.61173 .30902 L
.61242 .30902 L
.61366 .30902 L
.6149 .30902 L
.61606 .30902 L
.61711 .30902 L
.61825 .30902 L
.61949 .30902 L
.62061 .30902 L
.62192 .30902 L
.62315 .30902 L
.62429 .30902 L
.62535 .30902 L
.62773 .30902 L
.62897 .30902 L
.63013 .30902 L
.63141 .30902 L
.63213 .30902 L
.63278 .30902 L
.63403 .30902 L
.63474 .30902 L
.6354 .30902 L
.63608 .30902 L
.63673 .30902 L
.63748 .30902 L
.63816 .30902 L
.63937 .30902 L
.64006 .30902 L
.6407 .30902 L
.64201 .30902 L
.64341 .30902 L
.6447 .30902 L
.64594 .30902 L
.64704 .30902 L
.64825 .30902 L
Mistroke
.649 .30902 L
.64969 .30902 L
.651 .30902 L
.65174 .30902 L
.65241 .30902 L
.65315 .30902 L
.65393 .30902 L
.65524 .30902 L
.65645 .30902 L
.65715 .30902 L
.65778 .30902 L
.65851 .30902 L
.65921 .30902 L
.66035 .30902 L
.66158 .30902 L
.66264 .30902 L
.6638 .30902 L
.66509 .30902 L
.66579 .30902 L
.66644 .30902 L
.66762 .30902 L
.66887 .30902 L
.66956 .30902 L
.67019 .30902 L
.67089 .30902 L
.67163 .30902 L
.67228 .30902 L
.67298 .30902 L
.67424 .30902 L
.67546 .30902 L
.67657 .30902 L
.67788 .30902 L
.67912 .30902 L
.68029 .30902 L
.68134 .30902 L
.68256 .30902 L
.6837 .30902 L
.68477 .30902 L
.68576 .30902 L
.6868 .30902 L
.68794 .30902 L
.6891 .30902 L
.69035 .30902 L
.6915 .30902 L
.69256 .30902 L
.69379 .30902 L
.69448 .30902 L
.69512 .30902 L
.6963 .30902 L
.69755 .30902 L
Mistroke
.69875 .30902 L
.70006 .30902 L
.7013 .30902 L
.70245 .30902 L
.70359 .30902 L
.70463 .30902 L
.70582 .30902 L
.70695 .30902 L
.70818 .30902 L
.70947 .30902 L
.71058 .30902 L
.7118 .30902 L
.71312 .30902 L
.71385 .30902 L
.71452 .30902 L
.71583 .30902 L
.71706 .30902 L
.71811 .30902 L
.71927 .30902 L
.72048 .30902 L
.72161 .30902 L
.72267 .30902 L
.72364 .30902 L
.7247 .30902 L
.72582 .30902 L
.72696 .30902 L
.72818 .30902 L
.72933 .30902 L
.73037 .30902 L
.7316 .30902 L
.7323 .30902 L
.73294 .30902 L
.73411 .30902 L
.73536 .30902 L
.73656 .30902 L
.73788 .30902 L
.73904 .30902 L
.74028 .30902 L
.74151 .30902 L
.74261 .30902 L
.74373 .30902 L
.74478 .30902 L
.74602 .30902 L
.74732 .30902 L
.74843 .30902 L
.74965 .30902 L
.75096 .30902 L
.75169 .30902 L
.75237 .30902 L
.75301 .30902 L
Mistroke
.7537 .30902 L
.75491 .30902 L
.75597 .30902 L
.75711 .30902 L
.75835 .30902 L
.75953 .30902 L
.76077 .30902 L
.76208 .30902 L
.7632 .30902 L
.76442 .30902 L
.76558 .30902 L
.76663 .30902 L
.76784 .30902 L
.76898 .30902 L
.77004 .30902 L
.77102 .30902 L
.77209 .30902 L
.77322 .30902 L
.77443 .30902 L
.77575 .30902 L
.777 .30902 L
.77816 .30902 L
.77931 .30902 L
.78034 .30902 L
.78154 .30902 L
.78267 .30902 L
.78391 .30902 L
.78521 .30902 L
.78633 .30902 L
.78755 .30902 L
.79281 .30902 L
.81113 .30902 L
.85164 .30902 L
.89063 .30902 L
.93207 .30902 L
.97199 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0c
o`00;c?o00030000<ol0<ol002Dco`000`1Voc?o03?o0007<ol000<0000co`0co`00;S?o00030000
<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Oooo`H0I_mD<ol000<0
I_lco`0co`00JS?o00030000oooooooo04Goool0017oool6<ol05@1Voclco`000`1Voc?o03?o001Z
<ol000<0003oooooool0AOooo`004Ooooa/co`0:06Ko=C?o000306Ko<ol0<ol006Xco`000`000?oo
ooooo`15oooo000Aoooo9C?o00X0I_l[<ol000<0I_lco`0co`00JS?o00030000oooooooo04Goool0
017oool_<ol02P1Vob4co`000`1Voc?o03?o001Z<ol000<0003oooooool0AOooo`004OooocTco`0;
06Ko5S?o000306Ko<ol0<ol006Xco`020000A_ooo`004Ooood@co`0806Ko3S?o000306Ko<ol0<ol0
06Xco`000`000?ooooooo`15oooo000AooooC3?o00H0I_l8<ol000<0I_lco`0co`00JS?o00030000
oooooooo04Goool0017ooomB<ol02@1Vof`co`000`000?ooooooo`15oooo000AooooFC?o0080I_m/
<ol000<0003oooooool0AOooo`004OoooeXco`000ol0VC?o03?o001Z<ol000<0003oooooool0AOoo
o`004OoooeXco`000ol0VC?o03?o001Z<ol000<0003oooooool0AOooo`004OoooeXco`000ol0VC?o
03?o001Z<ol000<0003oooooool0AOooo`004Oooo`80001H<ol000?o09Tco`0co`00JS?o00800016
oooo000Coooo0P0005Hco`000ol0VC?o03?o001Z<ol000<0003oooooool0AOooo`005Oooo`80001D
<ol000?o09Tco`0co`00JS?o00030000oooooooo04Goool001Ooool20000DS?o0003o`2I<ol0<ol0
06Xco`000`000?ooooooo`15oooo000Ioooo0P00050co`000ol0VC?o03?o001Z<ol000<0003ooooo
ool0AOooo`006oooo`80001><ol000?o09Tco`0co`00JS?o00030000oooooooo04Goool001goool2
0000C3?o0003o`2I<ol0<ol006Xco`000`000?ooooooo`15oooo000Ooooo00<0000co`0co`00BC?o
0003o`2I<ol0<ol006Xco`000`000?ooooooo`15oooo000Poooo00<0000co`0co`00B3?o0003o`2I
<ol0<ol006Xco`020000A_ooo`008Oooo`800018<ol000?o09Tco`0co`00JS?o00030000oooooooo
04Goool002?oool00`0003?o03?o0015<ol000?o09Tco`0co`00JS?o00030000oooooooo04Goool0
02Coool20000AC?o0003o`2I<ol0<ol006Xco`000`000?ooooooo`15oooo000Voooo00<0000co`0c
o`00@S?o0003o`2I<ol0<ol006Xco`000`000?ooooooo`15oooo000Woooo00<0000co`0co`00@C?o
0003o`2I<ol0<ol006Xco`000`000?ooooooo`15oooo000Xoooo00<0000co`0co`00@3?o0003o`2I
<ol0<ol0054co`02000013?o00800004<ol00P0000<co`04000013?o00030000oooooooo04Goool0
02Woool00`0003?o03?o000o<ol000?o09Tco`0co`00D3?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000S?o00030000<ol0<ol000Dco`000`000?ooooooo`15oooo000Zoooo00<0000co`0c
o`00?S?o0003o`2I<ol0<ol0050co`00100003?o03?o000000Pco`00100003?o03?o000000<co`00
0`0003?o03?o0004<ol00`0004Goool002_oool20000?S?o0003o`2I<ol0<ol0050co`00100003?o
03?o000000Pco`00100003?o03?o000000@co`000`0003?o03?o0003<ol000<0003oooooool0AOoo
o`00;Oooo`030000<ol0<ol003/co`000ol0VC?o03?o001@<ol000@0000co`0co`000008<ol000@0
000co`0co`000002<ol000@0000co`0co`000004<ol000<0003oooooool0AOooo`00;_ooo`030000
<ol0<ol003Xco`000ol0VC?o03?o001A<ol00P0000Xco`02000013?o00800005<ol000<0003ooooo
ool0AOooo`00;oooo`030000<ol0<ol003Tco`000ol0VC?o03?o001Z<ol000<0003oooooool0AOoo
o`00<?ooo`030000<ol0<ol003Pco`000ol0VC?o03?o001Z<ol000<0003oooooool0AOooo`00<Ooo
o`030000<ol0<ol003Lco`000ol0VC?o03?o001Z<ol000<0003oooooool0AOooo`00<_ooo`030000
<ol0<ol003Hco`000ol0VC?o03?o001Z<ol000<0003oooooool0AOooo`00<oooo`030000<ol0<ol0
03Dco`000ol0VC?o03?o001Z<ol00P0004Koool003?oool00`0003?o03?o000e<ol000?o09Tco`0c
o`00JS?o00030000oooooooo04Goool003Coool00`0003?o03?o000d<ol000?o09Tco`0co`00JS?o
00030000oooooooo04Goool003Goool00`0003?o03?o000c<ol000?o09Tco`0co`00JS?o00030000
oooooooo04Goool003Koool00`0003?o03?o000b<ol000?o09Tco`0co`00JS?o00030000oooooooo
04Goool003Ooool00`0003?o03?o000a<ol000?o09Tco`0co`00JS?o00030000oooooooo04Goool0
03Soool00`0003?o03?o000`<ol000?o09Tco`0co`00JS?o00030000oooooooo04Goool003Soool0
0`0003?o03?o000`<ol000?o09Tco`0co`00JS?o00030000oooooooo04Goool003Woool00`0003?o
03?o000_<ol000?o09Tco`0co`00JS?o00800016oooo000joooo00<0000co`0co`00;S?o0003o`2I
<ol0<ol006Xco`000`000?ooooooo`15oooo000koooo00<0000co`0co`00;C?o0003o`2I<ol0<ol0
06Xco`000`000?ooooooo`15oooo000loooo00<0000co`0co`00;3?o0003o`2I<ol0<ol006Xco`00
0`000?ooooooo`15oooo000loooo00<0000co`0co`00;3?o0003o`2I<ol0<ol006Xco`000`000?oo
ooooo`15oooo000moooo00<0000co`0co`00:c?o0003o`2I<ol0<ol006Xco`000`000?ooooooo`15
oooo000moooo00<0000co`0co`00:c?o0003o`2I<ol0<ol006Xco`000`000?ooooooo`15oooo000n
oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol006Xco`000`000?ooooooo`15oooo000noooo00<0
000co`0co`00:S?o0003o`2I<ol0<ol006Xco`000`000?ooooooo`15oooo000ooooo00<0000co`0c
o`00:C?o0003o`2I<ol0<ol006Xco`020000A_ooo`00?oooo`030000<ol0<ol002Tco`000ol0VC?o
03?o001Z<ol000<0003oooooool0AOooo`00@?ooo`030000<ol0<ol002Pco`000ol0VC?o03?o001Z
<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol002Lco`000ol0VC?o03?o001Z<ol000<0
003oooooool0AOooo`00@Oooo`030000<ol0<ol002Lco`000ol0VC?o03?o001Z<ol000<0003ooooo
ool0AOooo`00@_ooo`030000<ol0<ol002Hco`000ol0VC?o03?o001Z<ol000<0003oooooool0AOoo
o`00@_ooo`030000<ol0<ol002Hco`000ol0VC?o03?o001A<ol00P0000@co`02000013?o00800005
<ol00`0000<co`000`000?ooooooo`15oooo0013oooo00<0000co`0co`009C?o0003o`2I<ol0<ol0
050co`00100003?o03?o000000Pco`00100003?o03?o000000Dco`000`0003?o03?o0002<ol000<0
003oooooool0AOooo`00@oooo`030000<ol0<ol002Dco`000ol0VC?o03?o001@<ol000@0000co`0c
o`000008<ol000@0000co`0co`000002<ol01@0000<co`030000AOooo`00A?ooo`030000<ol0<ol0
02@co`000ol0VC?o03?o001@<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0
000co`0co`000004<ol000<0003oooooool0AOooo`00A?ooo`030000<ol0<ol002@co`000ol0VC?o
03?o001@<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`00000013?o
00030000oooooooo04Goool004Goool00`0003?o03?o000S<ol000?o09Tco`0co`00DC?o0080000:
<ol00P0000Dco`02000013?o00030000oooooooo04Goool004Goool00`0003?o03?o000S<ol000?o
09Tco`0co`00JS?o00030000oooooooo04Goool004Koool00`0003?o03?o000R<ol000?o09Tco`0c
o`00JS?o00030000oooooooo04Goool004Koool00`0003?o03?o000R<ol000?o09Tco`0co`00JS?o
00030000oooooooo04Goool004Ooool00`0003?o03?o000Q<ol000?o09Tco`0co`00JS?o00030000
oooooooo04Goool004Ooool00`0003?o03?o000Q<ol000?o09Tco`0co`00JS?o00800016oooo0018
oooo00<0000co`0co`0083?o0003o`2I<ol0<ol006Xco`000`000?ooooooo`15oooo0018oooo00<0
000co`0co`0083?o0003o`2I<ol0<ol006Xco`000`000?ooooooo`15oooo0019oooo00<0000co`0c
o`007c?o0003o`2I<ol0<ol006Xco`000`000?ooooooo`15oooo0019oooo00<0000co`0co`007c?o
0003o`2I<ol0<ol006Xco`000`000?ooooooo`15oooo001:oooo00<0000co`0co`007S?o0003o`2I
<ol0<ol006Xco`000`000?ooooooo`15oooo001:oooo00<0000co`0co`007S?o0003o`2I<ol0<ol0
06Xco`000`000?ooooooo`15oooo001;oooo00<0000co`0co`007C?o0003o`2I<ol0<ol006Xco`00
0`000?ooooooo`15oooo001;oooo00<0000co`0co`007C?o0003o`2I<ol0<ol006Xco`020000A_oo
o`00C?oooh`co`18oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00COoooh/co`18oooo001=
ooooRc?o04Soool004kooolY<ol000<0000co`0co`00:C?o00030000<ol0<ol0038co`18oooo001>
oooo:3?o00030000<ol0<ol000Pco`000`0003?o03?o000P<ol000<0000co`0co`00<C?o04Soool0
04oooolW<ol000<0000co`0co`000S?o00800004<ol000<0000co`0co`003S?o00800004<ol00P00
00<co`0500000S?o00030000<ol0<ol0034co`18oooo001?oooo9c?o00050000<ol0<ol0<ol00000
008co`000`0003?o03?o0002<ol000<0000co`0co`001C?o00@00003<ol000@0000co`0co`00000:
<ol000<0000co`0co`000S?o00030000<ol0<ol0034co`18oooo001?oooo9S?o00030000<ol0<ol0
008co`000`0003?o03?o000D<ol000@0000co`0co`00000:<ol000<0000co`0co`000c?o00030000
<ol0<ol0030co`18oooo001@oooo9S?o00030000<ol0<ol000D0000C<ol000@0000co`0co`00000:
<ol000<0000co`0co`000S?o00030000<ol0<ol0034co`18oooo001@oooo9S?o00050000<ol0<ol0
<ol0000001Hco`00100003?o03?o000000Xco`000`0003?o03?o0002<ol000<0000co`0co`00<C?o
04Soool0053ooolW<ol000<0000co`0co`0063?o0080000:<ol00P0000<co`000`0003?o03?o000b
<ol0B?ooo`00DOooohLco`18oooo001AooooQc?o04Soool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.09) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.35271 .30902 L
.36173 .30902 L
.36626 .30902 L
.36757 .30902 L
.36881 .30902 L
.36992 .30902 L
s
.36992 .30902 m
.36993 .61803 L
s
0 .4 1 r
.02381 .32014 m
.06244 .32185 L
.10458 .32403 L
.14415 .32641 L
.18221 .32906 L
.22272 .33233 L
.26171 .33599 L
.30316 .34052 L
.32392 .34307 L
.34309 .34561 L
.35271 .34696 L
.36173 .34827 L
.36626 .34894 L
.36757 .34914 L
.36881 .34933 L
.36992 .3495 L
.37114 .30902 L
.37184 .30902 L
.3725 .30902 L
.37374 .30902 L
.37443 .30902 L
.37507 .30902 L
.37577 .30902 L
.37651 .30902 L
.37774 .30902 L
.37889 .30902 L
.38015 .30902 L
.38086 .30902 L
.3815 .30902 L
.38268 .30902 L
.38378 .30902 L
.385 .30902 L
.38631 .30902 L
.3876 .30902 L
.38826 .30902 L
.38897 .30902 L
.39024 .30902 L
.39141 .30902 L
.39261 .30902 L
.39374 .30902 L
.39475 .30902 L
.39585 .30902 L
.39704 .30902 L
.39831 .30902 L
.39939 .30902 L
.40058 .30902 L
.40125 .30902 L
.40197 .30902 L
.40329 .30902 L
.40457 .30902 L
Mistroke
.40575 .30902 L
.40648 .30902 L
.40717 .30902 L
.40845 .30902 L
.40916 .30902 L
.40982 .30902 L
.41055 .30902 L
.41131 .30902 L
.4125 .30902 L
.41362 .30902 L
.41492 .30902 L
.4161 .30902 L
.4174 .30902 L
.41813 .30902 L
.41881 .30902 L
.42004 .30902 L
.42134 .30902 L
.42249 .30902 L
.42374 .30902 L
.42504 .30902 L
.42625 .30902 L
.42739 .30902 L
.42842 .30902 L
.42961 .30902 L
.43074 .30902 L
.43197 .30902 L
.43327 .30902 L
.43438 .30902 L
.4356 .30902 L
.43691 .30902 L
.43764 .30902 L
.43831 .30902 L
.43955 .30902 L
.44085 .30902 L
.44196 .30902 L
.44319 .30902 L
.4443 .30902 L
.44535 .30902 L
.44658 .30902 L
.4477 .30902 L
.44894 .30902 L
.45024 .30902 L
.45131 .30902 L
.45245 .30902 L
.45352 .30902 L
.45449 .30902 L
.45564 .30902 L
.45689 .30902 L
.45806 .30902 L
.45915 .30902 L
Mistroke
.4604 .30902 L
.46158 .30902 L
.46265 .30902 L
.46381 .30902 L
.46507 .30902 L
.46577 .30902 L
.46641 .30902 L
.46765 .30902 L
.46883 .30902 L
.46993 .30902 L
.47109 .30902 L
.47209 .30902 L
.47318 .30902 L
.47436 .30902 L
.47561 .30902 L
.4768 .30902 L
.47789 .30902 L
.47917 .30902 L
.47981 .30902 L
.48053 .30902 L
.48178 .30902 L
.48296 .30902 L
.48364 .30902 L
.48435 .30902 L
.48562 .30902 L
.48633 .30902 L
.48699 .30902 L
.48771 .30902 L
.48848 .30902 L
.48978 .30902 L
.49051 .30902 L
.49119 .30902 L
.49243 .30902 L
.49374 .30902 L
.49492 .30902 L
.49602 .30902 L
.49722 .30902 L
.49852 .30902 L
.49921 .30902 L
.49986 .30902 L
.50107 .30902 L
.50378 .30902 L
.50501 .30902 L
.50616 .30902 L
.50735 .30902 L
.50866 .30902 L
.50936 .30902 L
.51 .30902 L
.51073 .30902 L
.51143 .30902 L
Mistroke
.51265 .30902 L
.51334 .30902 L
.51397 .30902 L
.51466 .30902 L
.5153 .30902 L
.516 .30902 L
.51676 .30902 L
.5175 .30902 L
.51829 .30902 L
.51903 .30902 L
.51971 .30902 L
.52034 .30902 L
.52103 .30902 L
.52228 .30902 L
.52299 .30902 L
.52374 .30902 L
.52438 .30902 L
.52509 .30902 L
.52637 .30902 L
.52708 .30902 L
.52774 .30902 L
.529 .30902 L
.53021 .30902 L
.53981 .30902 L
.54202 .30902 L
.54318 .30902 L
.5444 .30902 L
.54505 .30902 L
.54576 .30902 L
.54701 .30902 L
.54828 .30902 L
.54946 .30902 L
.5501 .30902 L
.5508 .30902 L
.55206 .30902 L
.55329 .30902 L
.55442 .30902 L
.55564 .30902 L
.55634 .30902 L
.55699 .30902 L
.5583 .30902 L
.55904 .30902 L
.55971 .30902 L
.56085 .30902 L
.56206 .30902 L
.5632 .30902 L
.56423 .30902 L
.56545 .30902 L
.56677 .30902 L
.56802 .30902 L
Mistroke
.56916 .30902 L
.57024 .30902 L
.57124 .30902 L
.57235 .30902 L
.57353 .30902 L
.57476 .30902 L
.57594 .30902 L
.57699 .30902 L
.57813 .30902 L
.57935 .30902 L
.58047 .30902 L
.58299 .30902 L
.58414 .30902 L
.58521 .30902 L
.58633 .30902 L
.58755 .30902 L
.5882 .30902 L
.58891 .30902 L
.59018 .30902 L
.59132 .30902 L
.59257 .30902 L
.59328 .30902 L
.59393 .30902 L
.59462 .30902 L
.59537 .30902 L
.59661 .30902 L
.59724 .30902 L
.59794 .30902 L
.59866 .30902 L
.59934 .30902 L
.60064 .30902 L
.60137 .30902 L
.60205 .30902 L
.60279 .30902 L
.60358 .30902 L
.6049 .30902 L
.60613 .30902 L
.60684 .30902 L
.60748 .30902 L
.60822 .30902 L
.60892 .30902 L
.61014 .30902 L
.61143 .30902 L
.61252 .30902 L
.61373 .30902 L
.61503 .30902 L
.61576 .30902 L
.61643 .30902 L
.61772 .30902 L
.61895 .30902 L
Mistroke
.6202 .30902 L
.6209 .30902 L
.62154 .30902 L
.62273 .30902 L
.62398 .30902 L
.62511 .30902 L
.62616 .30902 L
.62731 .30902 L
.62854 .30902 L
.62986 .30902 L
.6306 .30902 L
.63129 .30902 L
.63255 .30902 L
.63389 .30902 L
.63501 .30902 L
.63621 .30902 L
.63753 .30902 L
.63877 .30902 L
.63992 .30902 L
.641 .30902 L
.64218 .30902 L
.64344 .30902 L
.64408 .30902 L
.64477 .30902 L
.64602 .30902 L
.64724 .30902 L
.64836 .30902 L
.64941 .30902 L
.65039 .30902 L
.65147 .30902 L
.65263 .30902 L
.65384 .30902 L
.655 .30902 L
.65603 .30902 L
.65715 .30902 L
.69786 .30902 L
.73705 .30902 L
.7383 .30902 L
.73901 .30902 L
.73965 .30902 L
.74089 .30902 L
.74207 .30902 L
.74328 .30902 L
.7446 .30902 L
.74529 .30902 L
.74604 .30902 L
.74667 .30902 L
.74736 .30902 L
.74812 .30902 L
.74881 .30902 L
Mistroke
.7496 .30902 L
.75036 .30902 L
.75106 .30902 L
.75171 .30902 L
.75242 .30902 L
.75317 .30902 L
.75386 .30902 L
.75461 .30902 L
.75532 .30902 L
.75597 .30902 L
.7572 .30902 L
.75851 .30902 L
.75976 .30902 L
.76091 .30902 L
.76223 .30902 L
.76348 .30902 L
.76464 .30902 L
.7657 .30902 L
.76688 .30902 L
.76813 .30902 L
.76937 .30902 L
.77007 .30902 L
.77071 .30902 L
.7719 .30902 L
.77315 .30902 L
.77381 .30902 L
.77452 .30902 L
.77579 .30902 L
.77657 .30902 L
.77731 .30902 L
.77797 .30902 L
.77869 .30902 L
.77992 .30902 L
.78104 .30902 L
.78234 .30902 L
.78357 .30902 L
.78463 .30902 L
.78576 .30902 L
.787 .30902 L
.78814 .30902 L
.79855 .30902 L
.81959 .30902 L
.86119 .30902 L
.90129 .30902 L
.93987 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.09) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o0003000006Ko<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0c
o`00;c?o00030000<ol0<ol002Hco`000`1Voc?o03?o0006<ol000<0000co`0co`00;S?o00030000
<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Ooooa00I_m;<ol000<0
I_lco`0co`00JC?o00030000oooooooo04Goool0017oool@<ol02`1Vod0co`000`1Voc?o03?o001Y
<ol000<0003oooooool0AOooo`004Ooooa/co`0D06Ko;3?o000306Ko<ol0<ol006Tco`000`000?oo
ooooo`15oooo000Aoooo;c?o00X0I_lR<ol000<0I_lco`0co`00JC?o00030000oooooooo04Goool0
017oooli<ol02`1VoaLco`000`1Voc?o03?o001Y<ol000<0003oooooool0AOooo`004Ooood@co`08
06Ko3c?o000306Ko<ol0<ol006Tco`020000A_ooo`004Ooood`co`0606Ko2C?o000306Ko<ol0<ol0
06Tco`000`000?ooooooo`15oooo000AooooDS?o00P0I_l00c?o001Voc?o001Z<ol000<0003ooooo
ool0AOooo`004OoooeXco`0206KoJc?o00030000oooooooo04Goool0017ooomK<ol000?o09Tco`0c
o`00JC?o00030000oooooooo04Goool0017ooomK<ol000?o09Tco`0co`00JC?o00030000oooooooo
04Goool0017ooomK<ol000?o09Tco`0co`00JC?o00030000oooooooo04Goool0017ooomK<ol000?o
09Tco`0co`00JC?o00030000oooooooo04Goool0017oool20000FC?o0003o`2I<ol0<ol006Tco`02
0000A_ooo`004oooo`80001G<ol000?o09Tco`0co`00JC?o00030000oooooooo04Goool001Goool2
0000EC?o0003o`2I<ol0<ol006Tco`000`000?ooooooo`15oooo000Goooo0P0005<co`000ol0VC?o
03?o001Y<ol000<0003oooooool0AOooo`006Oooo`80001A<ol000?o09Tco`0co`00JC?o00030000
oooooooo04Goool001_oool20000Cc?o0003o`2I<ol0<ol006Tco`000`000?ooooooo`15oooo000M
oooo0P0004dco`000ol0VC?o03?o001Y<ol000<0003oooooool0AOooo`007oooo`030000<ol0<ol0
04Xco`000ol0VC?o03?o001Y<ol000<0003oooooool0AOooo`008?ooo`030000<ol0<ol004Tco`00
0ol0VC?o03?o001Y<ol00P0004Koool0027oool20000BC?o0003o`2I<ol0<ol006Tco`000`000?oo
ooooo`15oooo000Soooo00<0000co`0co`00AS?o0003o`2I<ol0<ol006Tco`000`000?ooooooo`15
oooo000Toooo0P0004Hco`000ol0VC?o03?o001Y<ol000<0003oooooool0AOooo`009_ooo`030000
<ol0<ol004<co`000ol0VC?o03?o001Y<ol000<0003oooooool0AOooo`009oooo`030000<ol0<ol0
048co`000ol0VC?o03?o001Y<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol0044co`00
0ol0VC?o03?o001@<ol00P0000@co`02000013?o00800003<ol0100000@co`000`000?ooooooo`15
oooo000Yoooo00<0000co`0co`00@3?o0003o`2I<ol0<ol004lco`00100003?o03?o000000Pco`00
100003?o03?o0000008co`000`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_ooo`030000
<ol0<ol003lco`000ol0VC?o03?o001?<ol000@0000co`0co`000008<ol000@0000co`0co`000003
<ol000<0000co`0co`0013?o00<00015oooo000[oooo0P0003lco`000ol0VC?o03?o001?<ol000@0
000co`0co`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o00030000oooooooo
04Goool002goool00`0003?o03?o000l<ol000?o09Tco`0co`00Cc?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool002koool0
0`0003?o03?o000k<ol000?o09Tco`0co`00D3?o0080000:<ol00P0000@co`0200001C?o00030000
oooooooo04Goool002ooool00`0003?o03?o000j<ol000?o09Tco`0co`00JC?o00030000oooooooo
04Goool0033oool00`0003?o03?o000i<ol000?o09Tco`0co`00JC?o00030000oooooooo04Goool0
037oool00`0003?o03?o000h<ol000?o09Tco`0co`00JC?o00030000oooooooo04Goool003;oool0
0`0003?o03?o000g<ol000?o09Tco`0co`00JC?o00030000oooooooo04Goool003?oool00`0003?o
03?o000f<ol000?o09Tco`0co`00JC?o00800016oooo000coooo00<0000co`0co`00=S?o0003o`2I
<ol0<ol006Tco`000`000?ooooooo`15oooo000doooo00<0000co`0co`00=C?o0003o`2I<ol0<ol0
06Tco`000`000?ooooooo`15oooo000eoooo00<0000co`0co`00=3?o0003o`2I<ol0<ol006Tco`00
0`000?ooooooo`15oooo000foooo00<0000co`0co`00<c?o0003o`2I<ol0<ol006Tco`000`000?oo
ooooo`15oooo000goooo00<0000co`0co`00<S?o0003o`2I<ol0<ol006Tco`000`000?ooooooo`15
oooo000hoooo00<0000co`0co`00<C?o0003o`2I<ol0<ol006Tco`000`000?ooooooo`15oooo000h
oooo00<0000co`0co`00<C?o0003o`2I<ol0<ol006Tco`000`000?ooooooo`15oooo000ioooo00<0
000co`0co`00<3?o0003o`2I<ol0<ol006Tco`020000A_ooo`00>_ooo`030000<ol0<ol002lco`00
0ol0VC?o03?o001Y<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol002hco`000ol0VC?o
03?o001Y<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol002dco`000ol0VC?o03?o001Y
<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol002dco`000ol0VC?o03?o001Y<ol000<0
003oooooool0AOooo`00?Oooo`030000<ol0<ol002`co`000ol0VC?o03?o001Y<ol000<0003ooooo
ool0AOooo`00?Oooo`030000<ol0<ol002`co`000ol0VC?o03?o001Y<ol000<0003oooooool0AOoo
o`00?_ooo`030000<ol0<ol002/co`000ol0VC?o03?o001Y<ol000<0003oooooool0AOooo`00?_oo
o`030000<ol0<ol002/co`000ol0VC?o03?o001Y<ol000<0003oooooool0AOooo`00?oooo`030000
<ol0<ol002Xco`000ol0VC?o03?o001Y<ol00P0004Koool003ooool00`0003?o03?o000Z<ol000?o
09Tco`0co`00JC?o00030000oooooooo04Goool0043oool00`0003?o03?o000Y<ol000?o09Tco`0c
o`00JC?o00030000oooooooo04Goool0047oool00`0003?o03?o000X<ol000?o09Tco`0co`00JC?o
00030000oooooooo04Goool0047oool00`0003?o03?o000X<ol000?o09Tco`0co`00JC?o00030000
oooooooo04Goool004;oool00`0003?o03?o000W<ol000?o09Tco`0co`00JC?o00030000oooooooo
04Goool004;oool00`0003?o03?o000W<ol000?o09Tco`0co`00D3?o00800004<ol00P0000@co`02
00001C?o00<00003<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol002Hco`000ol0VC?o
03?o001?<ol000@0000co`0co`000008<ol000@0000co`0co`000005<ol000<0000co`0co`000S?o
00030000oooooooo04Goool004?oool00`0003?o03?o000V<ol000?o09Tco`0co`00Cc?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool00`0003?o
03?o000U<ol000?o09Tco`0co`00Cc?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o
00040000<ol0<ol0000013?o00030000oooooooo04Goool004Coool00`0003?o03?o000U<ol000?o
09Tco`0co`00Cc?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol00000
00@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`0093?o0003o`2I<ol0<ol0050co`02
00002S?o00800005<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`0093?o
0003o`2I<ol0<ol006Tco`000`000?ooooooo`15oooo0016oooo00<0000co`0co`008c?o0003o`2I
<ol0<ol006Tco`000`000?ooooooo`15oooo0016oooo00<0000co`0co`008c?o0003o`2I<ol0<ol0
06Tco`000`000?ooooooo`15oooo0017oooo00<0000co`0co`008S?o0003o`2I<ol0<ol006Tco`00
0`000?ooooooo`15oooo0017oooo00<0000co`0co`008S?o0003o`2I<ol0<ol006Tco`020000A_oo
o`00B?ooo`030000<ol0<ol0024co`000ol0VC?o03?o001Y<ol000<0003oooooool0AOooo`00B?oo
o`030000<ol0<ol0024co`000ol0VC?o03?o001Y<ol000<0003oooooool0AOooo`00BOooo`030000
<ol0<ol0020co`000ol0VC?o03?o001Y<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol0
020co`000ol0VC?o03?o001Y<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol001lco`00
0ol0VC?o03?o001Y<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol001lco`000ol0VC?o
03?o001Y<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol001hco`000ol0VC?o03?o001Y
<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol001hco`000ol0VC?o03?o001Y<ol00P00
04Koool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;<ol0B?oo
o`00COoooh/co`18oooo001>oooo9S?o00030000<ol0<ol002lco`000`0003?o03?o000_<ol0B?oo
o`00C_ooobDco`000`0003?o03?o0008<ol000<0000co`0co`009S?o00030000<ol0<ol002hco`18
oooo001?oooo93?o00030000<ol0<ol0008co`02000013?o00030000<ol0<ol000hco`02000013?o
00800004<ol00P0000<co`03000013?o00030000<ol0<ol002hco`18oooo001?oooo93?o00050000
<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0000co`0co`001C?o00@00003<ol000@0
000co`0co`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000S?o00030000<ol0<ol0
02hco`18oooo001?oooo8c?o00030000<ol0<ol0008co`000`0003?o03?o000D<ol000@0000co`0c
o`000008<ol000@0000co`0co`000003<ol00`0000@co`000`0003?o03?o000]<ol0B?ooo`00D?oo
ob<co`000`0003?o03?o000500004c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o
00040000<ol0<ol000000c?o00030000<ol0<ol002hco`18oooo001@oooo8c?o00050000<ol0<ol0
<ol0000001Hco`00100003?o03?o000000Pco`00100003?o03?o0000008co`00100003?o03?o0000
00<co`000`0003?o03?o000^<ol0B?ooo`00D?ooob@co`000`0003?o03?o000H<ol00P0000Xco`02
000013?o00<00002<ol000<0000co`0co`00;c?o04Soool0057ooon7<ol0B?ooo`00DOooohLco`18
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.36173 .30902 L
.36626 .30902 L
.37114 .30902 L
.37257 .30902 L
.37328 .30902 L
.37393 .30902 L
s
.37393 .30902 m
.37394 .61803 L
s
0 .4 1 r
.02381 .3189 m
.06244 .32042 L
.10458 .32236 L
.14415 .32447 L
.18221 .32683 L
.22272 .32973 L
.26171 .33298 L
.30316 .337 L
.32392 .33927 L
.34309 .34152 L
.36173 .34389 L
.36626 .34449 L
.37114 .34515 L
.37257 .34534 L
.37328 .34544 L
.37393 .34553 L
.37515 .30902 L
.3758 .30902 L
.37649 .30902 L
.37714 .30902 L
.37784 .30902 L
.37912 .30902 L
.38036 .30902 L
.3815 .30902 L
.38276 .30902 L
.38396 .30902 L
.38503 .30902 L
.3862 .30902 L
.38747 .30902 L
.38816 .30902 L
.38881 .30902 L
.38996 .30902 L
.39123 .30902 L
.39235 .30902 L
.39352 .30902 L
.39452 .30902 L
.39561 .30902 L
.39679 .30902 L
.39805 .30902 L
.39924 .30902 L
.40032 .30902 L
.40161 .30902 L
.40226 .30902 L
.40298 .30902 L
.40424 .30902 L
.40542 .30902 L
.40614 .30902 L
.40682 .30902 L
.40809 .30902 L
.40946 .30902 L
Mistroke
.41023 .30902 L
.41095 .30902 L
.41227 .30902 L
.4135 .30902 L
.41461 .30902 L
.41581 .30902 L
.41712 .30902 L
.41778 .30902 L
.41851 .30902 L
.41979 .30902 L
.42099 .30902 L
.42225 .30902 L
.42289 .30902 L
.4236 .30902 L
.42484 .30902 L
.42601 .30902 L
.42668 .30902 L
.42738 .30902 L
.42864 .30902 L
.42934 .30902 L
.43001 .30902 L
.43077 .30902 L
.43147 .30902 L
.43264 .30902 L
.43392 .30902 L
.43511 .30902 L
.4362 .30902 L
.4374 .30902 L
.43872 .30902 L
.43938 .30902 L
.44009 .30902 L
.44138 .30902 L
.44262 .30902 L
.44376 .30902 L
.44502 .30902 L
.44566 .30902 L
.44636 .30902 L
.44753 .30902 L
.4488 .30902 L
.44999 .30902 L
.45109 .30902 L
.45215 .30902 L
.45315 .30902 L
.45424 .30902 L
.4554 .30902 L
.45663 .30902 L
.45778 .30902 L
.45882 .30902 L
.45995 .30902 L
.46118 .30902 L
Mistroke
.4623 .30902 L
.4636 .30902 L
.46483 .30902 L
.46596 .30902 L
.46701 .30902 L
.46817 .30902 L
.4694 .30902 L
.4701 .30902 L
.47075 .30902 L
.47146 .30902 L
.47221 .30902 L
.47347 .30902 L
.47419 .30902 L
.47485 .30902 L
.4761 .30902 L
.47724 .30902 L
.47856 .30902 L
.4798 .30902 L
.48101 .30902 L
.48169 .30902 L
.48234 .30902 L
.48364 .30902 L
.48437 .30902 L
.48504 .30902 L
.48616 .30902 L
.48739 .30902 L
.48868 .30902 L
.48988 .30902 L
.49056 .30902 L
.49131 .30902 L
.49201 .30902 L
.49265 .30902 L
.49388 .30902 L
.49518 .30902 L
.49585 .30902 L
.49657 .30902 L
.49787 .30902 L
.49867 .30902 L
.49942 .30902 L
.5001 .30902 L
.50083 .30902 L
.50148 .30902 L
.50217 .30902 L
.5034 .30902 L
.50472 .30902 L
.50547 .30902 L
.50617 .30902 L
.50744 .30902 L
.50859 .30902 L
.50923 .30902 L
Mistroke
.50993 .30902 L
.51119 .30902 L
.51231 .30902 L
.51355 .30902 L
.51485 .30902 L
.51606 .30902 L
.51719 .30902 L
.51823 .30902 L
.51942 .30902 L
.52056 .30902 L
.52188 .30902 L
.52308 .30902 L
.52374 .30902 L
.52446 .30902 L
.52576 .30902 L
.52699 .30902 L
.52828 .30902 L
.52938 .30902 L
.53059 .30902 L
.53133 .30902 L
.53202 .30902 L
.53333 .30902 L
.53406 .30902 L
.53473 .30902 L
.53547 .30902 L
.53626 .30902 L
.53756 .30902 L
.53878 .30902 L
.53947 .30902 L
.54011 .30902 L
.54081 .30902 L
.54155 .30902 L
.54278 .30902 L
.54348 .30902 L
.54412 .30902 L
.5453 .30902 L
.54655 .30902 L
.54767 .30902 L
.54871 .30902 L
.54986 .30902 L
.55109 .30902 L
.5524 .30902 L
.55314 .30902 L
.55382 .30902 L
.55642 .30902 L
.56128 .30902 L
.56587 .30902 L
.56696 .30902 L
.56811 .30902 L
.5691 .30902 L
Mistroke
.57018 .30902 L
.57133 .30902 L
.57257 .30902 L
.57326 .30902 L
.5739 .30902 L
.57515 .30902 L
.57625 .30902 L
.57746 .30902 L
.5786 .30902 L
.57965 .30902 L
.58083 .30902 L
.58207 .30902 L
.58313 .30902 L
.58429 .30902 L
.58555 .30902 L
.58625 .30902 L
.58688 .30902 L
.58812 .30902 L
.58929 .30902 L
.59039 .30902 L
.59155 .30902 L
.59255 .30902 L
.59364 .30902 L
.59481 .30902 L
.59607 .30902 L
.59726 .30902 L
.59834 .30902 L
.59961 .30902 L
.60026 .30902 L
.60097 .30902 L
.60224 .30902 L
.60341 .30902 L
.60407 .30902 L
.60477 .30902 L
.60548 .30902 L
.60625 .30902 L
.60692 .30902 L
.60763 .30902 L
.60892 .30902 L
.61022 .30902 L
.61095 .30902 L
.61162 .30902 L
.61286 .30902 L
.61417 .30902 L
.61535 .30902 L
.61645 .30902 L
.61766 .30902 L
.61895 .30902 L
.62016 .30902 L
.62147 .30902 L
Mistroke
.62271 .30902 L
.62385 .30902 L
.62454 .30902 L
.62518 .30902 L
.62585 .30902 L
.62658 .30902 L
.62778 .30902 L
.62906 .30902 L
.6298 .30902 L
.6306 .30902 L
.63136 .30902 L
.63206 .30902 L
.63478 .30902 L
.64009 .30902 L
.64127 .30902 L
.64251 .30902 L
.64316 .30902 L
.64387 .30902 L
.64512 .30902 L
.6463 .30902 L
.64756 .30902 L
.64875 .30902 L
.64984 .30902 L
.65105 .30902 L
.65237 .30902 L
.65361 .30902 L
.65476 .30902 L
.65601 .30902 L
.65673 .30902 L
.65739 .30902 L
.6581 .30902 L
.65874 .30902 L
.65948 .30902 L
.66019 .30902 L
.66144 .30902 L
.66214 .30902 L
.66279 .30902 L
.66398 .30902 L
.66523 .30902 L
.66741 .30902 L
.66865 .30902 L
.6698 .30902 L
.67044 .30902 L
.67113 .30902 L
.67239 .30902 L
.67361 .30902 L
.67475 .30902 L
.67597 .30902 L
.67666 .30902 L
.67731 .30902 L
Mistroke
.67862 .30902 L
.67936 .30902 L
.68004 .30902 L
.68117 .30902 L
.68237 .30902 L
.68351 .30902 L
.68454 .30902 L
.68569 .30902 L
.68691 .30902 L
.68754 .30902 L
.68824 .30902 L
.68947 .30902 L
.69062 .30902 L
.69186 .30902 L
.69302 .30902 L
.69409 .30902 L
.69516 .30902 L
.69632 .30902 L
.69742 .30902 L
.69844 .30902 L
.69963 .30902 L
.70089 .30902 L
.70209 .30902 L
.70318 .30902 L
.7044 .30902 L
.70556 .30902 L
.70681 .30902 L
.70752 .30902 L
.70817 .30902 L
.70944 .30902 L
.71016 .30902 L
.71083 .30902 L
.71154 .30902 L
.71219 .30902 L
.71294 .30902 L
.71365 .30902 L
.7149 .30902 L
.71605 .30902 L
.71732 .30902 L
.71803 .30902 L
.71867 .30902 L
.71986 .30902 L
.72112 .30902 L
.7222 .30902 L
.72338 .30902 L
.72465 .30902 L
.72536 .30902 L
.72601 .30902 L
.72727 .30902 L
.72846 .30902 L
Mistroke
.72958 .30902 L
.73076 .30902 L
.73177 .30902 L
.73288 .30902 L
.73407 .30902 L
.73536 .30902 L
.73657 .30902 L
.73768 .30902 L
.73883 .30902 L
.73988 .30902 L
.74109 .30902 L
.74223 .30902 L
.74329 .30902 L
.74426 .30902 L
.74533 .30902 L
.74646 .30902 L
.7476 .30902 L
.74883 .30902 L
.74998 .30902 L
.75104 .30902 L
.75227 .30902 L
.75297 .30902 L
.75362 .30902 L
.7548 .30902 L
.75606 .30902 L
.7613 .30902 L
.76255 .30902 L
.76386 .30902 L
.76499 .30902 L
.76622 .30902 L
.76732 .30902 L
.76851 .30902 L
.76962 .30902 L
.77064 .30902 L
.77181 .30902 L
.77309 .30902 L
.77429 .30902 L
.77541 .30902 L
.77665 .30902 L
.77784 .30902 L
.77891 .30902 L
.78006 .30902 L
.7813 .30902 L
.78246 .30902 L
.78316 .30902 L
.78383 .30902 L
.78507 .30902 L
.79413 .30902 L
.81475 .30902 L
.8533 .30902 L
Mistroke
.8943 .30902 L
.93378 .30902 L
.97175 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol006Ko00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0c
o`00;c?o00030000<ol0<ol002Lco`000`1Voc?o03?o0005<ol000<0000co`0co`00;S?o00030000
<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Ooooa00I_m<<ol000<0
I_lco`0co`00J3?o00030000oooooooo04Goool0017oool@<ol05@1VocLco`000`1Voc?o03?o001X
<ol000<0003oooooool0AOooo`004OooobDco`0:06Ko;C?o000306Ko<ol0<ol006Pco`000`000?oo
ooooo`15oooo000Aoooo;c?o01D0I_lH<ol000<0I_lco`0co`00J3?o00030000oooooooo04Goool0
017ooom4<ol0201Voa0co`000`1Voc?o03?o001X<ol000<0003oooooool0AOooo`004Ooood`co`06
06Ko2S?o000306Ko<ol0<ol006Pco`020000A_ooo`004Ooooe8co`0906Ko00<co`00I_lco`00JC?o
00030000oooooooo04Goool0017ooomK<ol00P1VofXco`000`000?ooooooo`15oooo000AooooG3?o
0003o`2I<ol0<ol006Pco`000`000?ooooooo`15oooo000AooooG3?o0003o`2I<ol0<ol006Pco`00
0`000?ooooooo`15oooo000AooooG3?o0003o`2I<ol0<ol006Pco`000`000?ooooooo`15oooo000A
ooooG3?o0003o`2I<ol0<ol006Pco`000`000?ooooooo`15oooo000AooooG3?o0003o`2I<ol0<ol0
06Pco`000`000?ooooooo`15oooo000Aoooo0P0005Xco`000ol0VC?o03?o001X<ol00P0004Koool0
01?oool20000F3?o0003o`2I<ol0<ol006Pco`000`000?ooooooo`15oooo000Eoooo0P0005Hco`00
0ol0VC?o03?o001X<ol000<0003oooooool0AOooo`005oooo`80001D<ol000?o09Tco`0co`00J3?o
00030000oooooooo04Goool001Woool20000DS?o0003o`2I<ol0<ol006Pco`000`000?ooooooo`15
oooo000Koooo0P00050co`000ol0VC?o03?o001X<ol000<0003oooooool0AOooo`007Oooo`80001>
<ol000?o09Tco`0co`00J3?o00030000oooooooo04Goool001ooool00`0003?o03?o001;<ol000?o
09Tco`0co`00J3?o00030000oooooooo04Goool0023oool00`0003?o03?o001:<ol000?o09Tco`0c
o`00J3?o00800016oooo000Qoooo0P0004Xco`000ol0VC?o03?o001X<ol000<0003oooooool0AOoo
o`008oooo`030000<ol0<ol004Lco`000ol0VC?o03?o001X<ol000<0003oooooool0AOooo`009?oo
o`800017<ol000?o09Tco`0co`00J3?o00030000oooooooo04Goool002Koool00`0003?o03?o0014
<ol000?o09Tco`0co`00J3?o00030000oooooooo04Goool002Ooool00`0003?o03?o0013<ol000?o
09Tco`0co`00J3?o00030000oooooooo04Goool002Soool00`0003?o03?o0012<ol000?o09Tco`0c
o`00Cc?o00800004<ol00P0000@co`0200000c?o00@00004<ol000<0003oooooool0AOooo`00:Ooo
o`030000<ol0<ol0044co`000ol0VC?o03?o001><ol000@0000co`0co`000008<ol000@0000co`0c
o`000002<ol000<0000co`0co`001C?o00030000oooooooo04Goool002[oool00`0003?o03?o0010
<ol000?o09Tco`0co`00CS?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000
<ol0<ol000@co`030000AOooo`00:oooo`800010<ol000?o09Tco`0co`00CS?o00040000<ol0<ol0
000023?o00040000<ol0<ol0000013?o00030000<ol0<ol000<co`000`000?ooooooo`15oooo000]
oooo00<0000co`0co`00?C?o0003o`2I<ol0<ol004hco`00100003?o03?o000000Pco`00100003?o
03?o0000008co`00100003?o03?o000000@co`000`000?ooooooo`15oooo000^oooo00<0000co`0c
o`00?3?o0003o`2I<ol0<ol004lco`0200002S?o00800004<ol00P0000Dco`000`000?ooooooo`15
oooo000_oooo00<0000co`0co`00>c?o0003o`2I<ol0<ol006Pco`000`000?ooooooo`15oooo000`
oooo00<0000co`0co`00>S?o0003o`2I<ol0<ol006Pco`000`000?ooooooo`15oooo000aoooo00<0
000co`0co`00>C?o0003o`2I<ol0<ol006Pco`000`000?ooooooo`15oooo000boooo00<0000co`0c
o`00>3?o0003o`2I<ol0<ol006Pco`000`000?ooooooo`15oooo000coooo00<0000co`0co`00=c?o
0003o`2I<ol0<ol006Pco`020000A_ooo`00<oooo`030000<ol0<ol003Lco`000ol0VC?o03?o001X
<ol000<0003oooooool0AOooo`00=?ooo`030000<ol0<ol003Hco`000ol0VC?o03?o001X<ol000<0
003oooooool0AOooo`00=Oooo`030000<ol0<ol003Dco`000ol0VC?o03?o001X<ol000<0003ooooo
ool0AOooo`00=_ooo`030000<ol0<ol003@co`000ol0VC?o03?o001X<ol000<0003oooooool0AOoo
o`00=oooo`030000<ol0<ol003<co`000ol0VC?o03?o001X<ol000<0003oooooool0AOooo`00>?oo
o`030000<ol0<ol0038co`000ol0VC?o03?o001X<ol000<0003oooooool0AOooo`00>?ooo`030000
<ol0<ol0038co`000ol0VC?o03?o001X<ol000<0003oooooool0AOooo`00>Oooo`030000<ol0<ol0
034co`000ol0VC?o03?o001X<ol00P0004Koool003[oool00`0003?o03?o000`<ol000?o09Tco`0c
o`00J3?o00030000oooooooo04Goool003_oool00`0003?o03?o000_<ol000?o09Tco`0co`00J3?o
00030000oooooooo04Goool003coool00`0003?o03?o000^<ol000?o09Tco`0co`00J3?o00030000
oooooooo04Goool003coool00`0003?o03?o000^<ol000?o09Tco`0co`00J3?o00030000oooooooo
04Goool003goool00`0003?o03?o000]<ol000?o09Tco`0co`00J3?o00030000oooooooo04Goool0
03goool00`0003?o03?o000]<ol000?o09Tco`0co`00J3?o00030000oooooooo04Goool003koool0
0`0003?o03?o000/<ol000?o09Tco`0co`00J3?o00030000oooooooo04Goool003koool00`0003?o
03?o000/<ol000?o09Tco`0co`00J3?o00030000oooooooo04Goool003ooool00`0003?o03?o000[
<ol000?o09Tco`0co`00J3?o00800016oooo000ooooo00<0000co`0co`00:c?o0003o`2I<ol0<ol0
06Pco`000`000?ooooooo`15oooo0010oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol006Pco`00
0`000?ooooooo`15oooo0011oooo00<0000co`0co`00:C?o0003o`2I<ol0<ol006Pco`000`000?oo
ooooo`15oooo0011oooo00<0000co`0co`00:C?o0003o`2I<ol0<ol006Pco`000`000?ooooooo`15
oooo0012oooo00<0000co`0co`00:3?o0003o`2I<ol0<ol006Pco`000`000?ooooooo`15oooo0012
oooo00<0000co`0co`00:3?o0003o`2I<ol0<ol004lco`02000013?o00800004<ol00P0000Dco`03
00000c?o00030000oooooooo04Goool004?oool00`0003?o03?o000W<ol000?o09Tco`0co`00CS?o
00040000<ol0<ol0000023?o00040000<ol0<ol000001C?o00030000<ol0<ol0008co`000`000?oo
ooooo`15oooo0013oooo00<0000co`0co`009c?o0003o`2I<ol0<ol004hco`00100003?o03?o0000
00Pco`00100003?o03?o0000008co`0500000c?o00<00015oooo0014oooo00<0000co`0co`009S?o
0003o`2I<ol0<ol004hco`00100003?o03?o000000Pco`00100003?o03?o0000008co`00100003?o
03?o000000@co`000`000?ooooooo`15oooo0014oooo00<0000co`0co`009S?o0003o`2I<ol0<ol0
04hco`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o00000004<ol000<0
003oooooool0AOooo`00AOooo`030000<ol0<ol002Dco`000ol0VC?o03?o001?<ol00P0000Xco`02
00001C?o00800004<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol002Dco`000ol0VC?o
03?o001X<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol002@co`000ol0VC?o03?o001X
<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol002@co`000ol0VC?o03?o001X<ol000<0
003oooooool0AOooo`00Aoooo`030000<ol0<ol002<co`000ol0VC?o03?o001X<ol000<0003ooooo
ool0AOooo`00Aoooo`030000<ol0<ol002<co`000ol0VC?o03?o001X<ol00P0004Koool004Soool0
0`0003?o03?o000R<ol000?o09Tco`0co`00J3?o00030000oooooooo04Goool004Soool00`0003?o
03?o000R<ol000?o09Tco`0co`00J3?o00030000oooooooo04Goool004Woool00`0003?o03?o000Q
<ol000?o09Tco`0co`00J3?o00030000oooooooo04Goool004Woool00`0003?o03?o000Q<ol000?o
09Tco`0co`00J3?o00030000oooooooo04Goool004[oool00`0003?o03?o000P<ol000?o09Tco`0c
o`00J3?o00030000oooooooo04Goool004[oool00`0003?o03?o000P<ol000?o09Tco`0co`00J3?o
00030000oooooooo04Goool004_oool00`0003?o03?o000O<ol000?o09Tco`0co`00J3?o00030000
oooooooo04Goool004_oool00`0003?o03?o000O<ol000?o09Tco`0co`00J3?o00800016oooo001<
ooooS3?o04Soool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001=ooooRc?o04Soool004gooon;
<ol0B?ooo`00C_ooobHco`000`0003?o03?o000_<ol000<0000co`0co`00;c?o04Soool004kooolU
<ol000<0000co`0co`0023?o00030000<ol0<ol002Hco`000`0003?o03?o000^<ol0B?ooo`00Cooo
ob@co`000`0003?o03?o0002<ol00P0000@co`000`0003?o03?o000><ol00P0000@co`02000013?o
00800004<ol00P0000@co`000`0003?o03?o000^<ol0B?ooo`00Coooob@co`001@0003?o03?o03?o
00000002<ol000<0000co`0co`000S?o00030000<ol0<ol000Dco`0400000c?o00040000<ol0<ol0
000023?o00040000<ol0<ol000000S?o00040000<ol0<ol000000c?o00030000<ol0<ol002hco`18
oooo001?oooo8c?o00030000<ol0<ol0008co`000`0003?o03?o000D<ol000@0000co`0co`000008
<ol000@0000co`0co`000002<ol000@0000co`0co`000004<ol000<0000co`0co`00;C?o04Soool0
053ooolS<ol000<0000co`0co`001@0001<co`00100003?o03?o000000Pco`00100003?o03?o0000
00<co`02000013?o00030000<ol0<ol002hco`18oooo001@oooo8c?o00050000<ol0<ol0<ol00000
01Hco`00100003?o03?o000000Pco`00100003?o03?o0000008co`00100003?o03?o000000<co`00
0`0003?o03?o000^<ol0B?ooo`00D?ooob@co`000`0003?o03?o000H<ol00P0000Xco`02000013?o
00800003<ol000<0000co`0co`00;c?o04Soool0057ooon7<ol0B?ooo`00DOooohLco`18oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.07) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.32392 .30902 L
.34309 .30902 L
.36173 .30902 L
.37114 .30902 L
.37372 .30902 L
.37514 .30902 L
.37649 .30902 L
.37774 .30902 L
s
.37774 .30902 m
.37774 .61803 L
s
0 .4 1 r
.02381 .31766 m
.06244 .31899 L
.10458 .32068 L
.14415 .32253 L
.18221 .32459 L
.22272 .32713 L
.26171 .32997 L
.30316 .33349 L
.32392 .33547 L
.34309 .33745 L
.36173 .33951 L
.37114 .34061 L
.37372 .34092 L
.37514 .34109 L
.37649 .34126 L
.37774 .34141 L
.37845 .30902 L
.3791 .30902 L
.38026 .30902 L
.3815 .30902 L
.38274 .30902 L
.38345 .30902 L
.3841 .30902 L
.3848 .30902 L
.38543 .30902 L
.38616 .30902 L
.38686 .30902 L
.38808 .30902 L
.38922 .30902 L
.39046 .30902 L
.39109 .30902 L
.39178 .30902 L
.39248 .30902 L
.39313 .30902 L
.39381 .30902 L
.39455 .30902 L
.3953 .30902 L
.3961 .30902 L
.39685 .30902 L
.39752 .30902 L
.39821 .30902 L
.39885 .30902 L
.39954 .30902 L
.40029 .30902 L
.40157 .30902 L
.40226 .30902 L
.40291 .30902 L
.40416 .30902 L
.40486 .30902 L
.40552 .30902 L
Mistroke
.40672 .30902 L
.40799 .30902 L
.40925 .30902 L
.41043 .30902 L
.41149 .30902 L
.41263 .30902 L
.4139 .30902 L
.41462 .30902 L
.41528 .30902 L
.41598 .30902 L
.41673 .30902 L
.41742 .30902 L
.41808 .30902 L
.41933 .30902 L
.42048 .30902 L
.42174 .30902 L
.42238 .30902 L
.42308 .30902 L
.4243 .30902 L
.42544 .30902 L
.42668 .30902 L
.42738 .30902 L
.42801 .30902 L
.4293 .30902 L
.43002 .30902 L
.43068 .30902 L
.43191 .30902 L
.4332 .30902 L
.4343 .30902 L
.43548 .30902 L
.4366 .30902 L
.43762 .30902 L
.43881 .30902 L
.44011 .30902 L
.44133 .30902 L
.44247 .30902 L
.44366 .30902 L
.44494 .30902 L
.44616 .30902 L
.44727 .30902 L
.44851 .30902 L
.44921 .30902 L
.44986 .30902 L
.45117 .30902 L
.45191 .30902 L
.45258 .30902 L
.45325 .30902 L
.45396 .30902 L
.45523 .30902 L
.45594 .30902 L
Mistroke
.4566 .30902 L
.45733 .30902 L
.45811 .30902 L
.45878 .30902 L
.45951 .30902 L
.4602 .30902 L
.46084 .30902 L
.46205 .30902 L
.46334 .30902 L
.46458 .30902 L
.46529 .30902 L
.46595 .30902 L
.46664 .30902 L
.46728 .30902 L
.46801 .30902 L
.4687 .30902 L
.46993 .30902 L
.47106 .30902 L
.47363 .30902 L
.47487 .30902 L
.47556 .30902 L
.4762 .30902 L
.47691 .30902 L
.47766 .30902 L
.47831 .30902 L
.47903 .30902 L
.47978 .30902 L
.48047 .30902 L
.482 .30902 L
.48268 .30902 L
.48342 .30902 L
.48407 .30902 L
.48476 .30902 L
.48602 .30902 L
.48719 .30902 L
.48791 .30902 L
.48859 .30902 L
.48986 .30902 L
.49051 .30902 L
.49121 .30902 L
.49245 .30902 L
.49321 .30902 L
.49393 .30902 L
.49457 .30902 L
.49526 .30902 L
.49643 .30902 L
.49772 .30902 L
.49837 .30902 L
.49906 .30902 L
.50031 .30902 L
Mistroke
.50155 .30902 L
.50273 .30902 L
.50379 .30902 L
.50494 .30902 L
.50616 .30902 L
.50728 .30902 L
.50858 .30902 L
.50981 .30902 L
.51094 .30902 L
.51199 .30902 L
.51314 .30902 L
.51437 .30902 L
.51507 .30902 L
.51572 .30902 L
.51642 .30902 L
.51718 .30902 L
.51846 .30902 L
.51917 .30902 L
.51982 .30902 L
.52107 .30902 L
.52221 .30902 L
.52352 .30902 L
.52477 .30902 L
.52597 .30902 L
.52666 .30902 L
.5273 .30902 L
.5286 .30902 L
.52933 .30902 L
.53 .30902 L
.53112 .30902 L
.53235 .30902 L
.53364 .30902 L
.53484 .30902 L
.53552 .30902 L
.53626 .30902 L
.53696 .30902 L
.53761 .30902 L
.53884 .30902 L
.54013 .30902 L
.5408 .30902 L
.54152 .30902 L
.54283 .30902 L
.54362 .30902 L
.54438 .30902 L
.54505 .30902 L
.54579 .30902 L
.54644 .30902 L
.54713 .30902 L
.54835 .30902 L
.54967 .30902 L
Mistroke
.55042 .30902 L
.55112 .30902 L
.55239 .30902 L
.55354 .30902 L
.55418 .30902 L
.55487 .30902 L
.55613 .30902 L
.55725 .30902 L
.55849 .30902 L
.55979 .30902 L
.561 .30902 L
.56213 .30902 L
.56316 .30902 L
.5643 .30902 L
.5655 .30902 L
.56681 .30902 L
.56801 .30902 L
.56867 .30902 L
.56939 .30902 L
.57069 .30902 L
.57191 .30902 L
.57321 .30902 L
.57442 .30902 L
.57552 .30902 L
.57682 .30902 L
.57754 .30902 L
.57822 .30902 L
.57943 .30902 L
.58074 .30902 L
.58143 .30902 L
.58219 .30902 L
.58298 .30902 L
.58372 .30902 L
.58441 .30902 L
.58505 .30902 L
.58574 .30902 L
.58648 .30902 L
.58771 .30902 L
.5884 .30902 L
.58904 .30902 L
.59022 .30902 L
.59147 .30902 L
.59258 .30902 L
.59362 .30902 L
.59477 .30902 L
.596 .30902 L
.59731 .30902 L
.59799 .30902 L
.59873 .30902 L
.59943 .30902 L
Mistroke
.60007 .30902 L
.60132 .30902 L
.60252 .30902 L
.60383 .30902 L
.60506 .30902 L
.60619 .30902 L
.60725 .30902 L
.60839 .30902 L
.61044 .30902 L
.6117 .30902 L
.61289 .30902 L
.61395 .30902 L
.61511 .30902 L
.61624 .30902 L
.61749 .30902 L
.61879 .30902 L
.62001 .30902 L
.62115 .30902 L
.62219 .30902 L
.62334 .30902 L
.62454 .30902 L
.62578 .30902 L
.62647 .30902 L
.62712 .30902 L
.6283 .30902 L
.62955 .30902 L
.63174 .30902 L
.63294 .30902 L
.63409 .30902 L
.6354 .30902 L
.6366 .30902 L
.63772 .30902 L
.63895 .30902 L
.63965 .30902 L
.64029 .30902 L
.64103 .30902 L
.64172 .30902 L
.64296 .30902 L
.64365 .30902 L
.64429 .30902 L
.64536 .30902 L
.6465 .30902 L
.64757 .30902 L
.64855 .30902 L
.64971 .30902 L
.65096 .30902 L
.65214 .30902 L
.65323 .30902 L
.65435 .30902 L
.65541 .30902 L
Mistroke
.65656 .30902 L
.6578 .30902 L
.6591 .30902 L
.66034 .30902 L
.66145 .30902 L
.66266 .30902 L
.6633 .30902 L
.66398 .30902 L
.66521 .30902 L
.66652 .30902 L
.66727 .30902 L
.66796 .30902 L
.66922 .30902 L
.67038 .30902 L
.67101 .30902 L
.6717 .30902 L
.67296 .30902 L
.67408 .30902 L
.67532 .30902 L
.67661 .30902 L
.67782 .30902 L
.67895 .30902 L
.67998 .30902 L
.68112 .30902 L
.68231 .30902 L
.68363 .30902 L
.68482 .30902 L
.68548 .30902 L
.6862 .30902 L
.6875 .30902 L
.68872 .30902 L
.69001 .30902 L
.69111 .30902 L
.69232 .30902 L
.69305 .30902 L
.69375 .30902 L
.69505 .30902 L
.69578 .30902 L
.69645 .30902 L
.69719 .30902 L
.69798 .30902 L
.69867 .30902 L
.69941 .30902 L
.70007 .30902 L
.70076 .30902 L
.70207 .30902 L
.70328 .30902 L
.7045 .30902 L
.70519 .30902 L
.70583 .30902 L
Mistroke
.707 .30902 L
.70825 .30902 L
.70936 .30902 L
.7104 .30902 L
.71154 .30902 L
.71277 .30902 L
.71401 .30902 L
.71471 .30902 L
.71536 .30902 L
.71667 .30902 L
.71741 .30902 L
.71808 .30902 L
.71928 .30902 L
.72058 .30902 L
.72181 .30902 L
.72294 .30902 L
.724 .30902 L
.72513 .30902 L
.7262 .30902 L
.72718 .30902 L
.72833 .30902 L
.72958 .30902 L
.73185 .30902 L
.73309 .30902 L
.73422 .30902 L
.73552 .30902 L
.73674 .30902 L
.73788 .30902 L
.73892 .30902 L
.74007 .30902 L
.74128 .30902 L
.74251 .30902 L
.7432 .30902 L
.74384 .30902 L
.74501 .30902 L
.74626 .30902 L
.74737 .30902 L
.74842 .30902 L
.74956 .30902 L
.7508 .30902 L
.75601 .30902 L
.75726 .30902 L
.75796 .30902 L
.75859 .30902 L
.75982 .30902 L
.76098 .30902 L
.76212 .30902 L
.76318 .30902 L
.76434 .30902 L
.76556 .30902 L
Mistroke
.76679 .30902 L
.76794 .30902 L
.76921 .30902 L
.76991 .30902 L
.77056 .30902 L
.77168 .30902 L
.77272 .30902 L
.77385 .30902 L
.77506 .30902 L
.77611 .30902 L
.77709 .30902 L
.77817 .30902 L
.77933 .30902 L
.78059 .30902 L
.78173 .30902 L
.78304 .30902 L
.78429 .30902 L
.78544 .30902 L
.7865 .30902 L
.78766 .30902 L
.7889 .30902 L
.79937 .30902 L
.82047 .30902 L
.85835 .30902 L
.89868 .30902 L
.9375 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.07) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00040000<ol0<ol006Ko1S?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo01?oool0017oool00`00001V
o`1Vo`0306Ko;3?o00030000<ol0<ol002Pco`000`1Voc?o03?o0004<ol000<0000co`0co`00;S?o
00030000<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Oooo`Hco`0E
06Ko@S?o000306Ko<ol0<ol006Lco`000`000?ooooooo`15oooo000Aoooo6c?o01@0I_l^<ol000<0
I_lco`0co`00Ic?o00030000oooooooo04Goool0017oool_<ol02P1Vob@co`000`1Voc?o03?o001W
<ol000<0003oooooool0AOooo`004OooocTco`0C06Ko4C?o000306Ko<ol0<ol006Lco`000`000?oo
ooooo`15oooo000AooooC3?o00H0I_l;<ol000<0I_lco`0co`00Ic?o00030000oooooooo04Goool0
017ooomB<ol0301VofTco`020000A_ooo`004Ooooe`co`0206KoJC?o00030000oooooooo04Goool0
017ooomM<ol000?o09Tco`0co`00Ic?o00030000oooooooo04Goool0017ooomM<ol000?o09Tco`0c
o`00Ic?o00030000oooooooo04Goool0017ooomM<ol000?o09Tco`0co`00Ic?o00030000oooooooo
04Goool0017ooomM<ol000?o09Tco`0co`00Ic?o00030000oooooooo04Goool0017ooomM<ol000?o
09Tco`0co`00Ic?o00030000oooooooo04Goool0017ooomM<ol000?o09Tco`0co`00Ic?o00030000
oooooooo04Goool0017oool20000Fc?o0003o`2I<ol0<ol006Lco`020000A_ooo`004oooo`80001I
<ol000?o09Tco`0co`00Ic?o00030000oooooooo04Goool001Goool20000Ec?o0003o`2I<ol0<ol0
06Lco`000`000?ooooooo`15oooo000Goooo0P0005Dco`000ol0VC?o03?o001W<ol000<0003ooooo
ool0AOooo`006Oooo`80001C<ol000?o09Tco`0co`00Ic?o00030000oooooooo04Goool001_oool2
0000DC?o0003o`2I<ol0<ol006Lco`000`000?ooooooo`15oooo000Moooo0P0004lco`000ol0VC?o
03?o001W<ol000<0003oooooool0AOooo`007oooo`030000<ol0<ol004`co`000ol0VC?o03?o001W
<ol000<0003oooooool0AOooo`008?ooo`030000<ol0<ol004/co`000ol0VC?o03?o001W<ol00P00
04Koool0027oool20000Bc?o0003o`2I<ol0<ol006Lco`000`000?ooooooo`15oooo000Soooo00<0
000co`0co`00B3?o0003o`2I<ol0<ol006Lco`000`000?ooooooo`15oooo000Toooo0P0004Pco`00
0ol0VC?o03?o001W<ol000<0003oooooool0AOooo`009_ooo`030000<ol0<ol004Dco`000ol0VC?o
03?o001W<ol000<0003oooooool0AOooo`009oooo`030000<ol0<ol004@co`000ol0VC?o03?o001W
<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol004<co`000ol0VC?o03?o001><ol00P00
00@co`02000013?o00800003<ol0100000@co`000`000?ooooooo`15oooo000Yoooo00<0000co`0c
o`00@S?o0003o`2I<ol0<ol004dco`00100003?o03?o000000Pco`00100003?o03?o0000008co`00
0`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_ooo`030000<ol0<ol0044co`000ol0VC?o
03?o001=<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o
00<00015oooo000[oooo0P00044co`000ol0VC?o03?o001=<ol000@0000co`0co`000008<ol000@0
000co`0co`000004<ol000<0000co`0co`000c?o00030000oooooooo04Goool002goool00`0003?o
03?o000n<ol000?o09Tco`0co`00CC?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o
00040000<ol0<ol0000013?o00030000oooooooo04Goool002koool00`0003?o03?o000m<ol000?o
09Tco`0co`00CS?o0080000:<ol00P0000@co`0200001C?o00030000oooooooo04Goool002ooool0
0`0003?o03?o000l<ol000?o09Tco`0co`00Ic?o00030000oooooooo04Goool0033oool00`0003?o
03?o000k<ol000?o09Tco`0co`00Ic?o00030000oooooooo04Goool0037oool00`0003?o03?o000j
<ol000?o09Tco`0co`00Ic?o00030000oooooooo04Goool003;oool00`0003?o03?o000i<ol000?o
09Tco`0co`00Ic?o00030000oooooooo04Goool003?oool00`0003?o03?o000h<ol000?o09Tco`0c
o`00Ic?o00800016oooo000coooo00<0000co`0co`00>3?o0003o`2I<ol0<ol006Lco`000`000?oo
ooooo`15oooo000doooo00<0000co`0co`00=c?o0003o`2I<ol0<ol006Lco`000`000?ooooooo`15
oooo000eoooo00<0000co`0co`00=S?o0003o`2I<ol0<ol006Lco`000`000?ooooooo`15oooo000f
oooo00<0000co`0co`00=C?o0003o`2I<ol0<ol006Lco`000`000?ooooooo`15oooo000goooo00<0
000co`0co`00=3?o0003o`2I<ol0<ol006Lco`000`000?ooooooo`15oooo000hoooo00<0000co`0c
o`00<c?o0003o`2I<ol0<ol006Lco`000`000?ooooooo`15oooo000hoooo00<0000co`0co`00<c?o
0003o`2I<ol0<ol006Lco`000`000?ooooooo`15oooo000ioooo00<0000co`0co`00<S?o0003o`2I
<ol0<ol006Lco`020000A_ooo`00>_ooo`030000<ol0<ol0034co`000ol0VC?o03?o001W<ol000<0
003oooooool0AOooo`00>oooo`030000<ol0<ol0030co`000ol0VC?o03?o001W<ol000<0003ooooo
ool0AOooo`00??ooo`030000<ol0<ol002lco`000ol0VC?o03?o001W<ol000<0003oooooool0AOoo
o`00??ooo`030000<ol0<ol002lco`000ol0VC?o03?o001W<ol000<0003oooooool0AOooo`00?Ooo
o`030000<ol0<ol002hco`000ol0VC?o03?o001W<ol000<0003oooooool0AOooo`00?Oooo`030000
<ol0<ol002hco`000ol0VC?o03?o001W<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol0
02dco`000ol0VC?o03?o001W<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol002dco`00
0ol0VC?o03?o001W<ol000<0003oooooool0AOooo`00?oooo`030000<ol0<ol002`co`000ol0VC?o
03?o001W<ol00P0004Koool003ooool00`0003?o03?o000/<ol000?o09Tco`0co`00Ic?o00030000
oooooooo04Goool0043oool00`0003?o03?o000[<ol000?o09Tco`0co`00Ic?o00030000oooooooo
04Goool0047oool00`0003?o03?o000Z<ol000?o09Tco`0co`00Ic?o00030000oooooooo04Goool0
047oool00`0003?o03?o000Z<ol000?o09Tco`0co`00Ic?o00030000oooooooo04Goool004;oool0
0`0003?o03?o000Y<ol000?o09Tco`0co`00Ic?o00030000oooooooo04Goool004;oool00`0003?o
03?o000Y<ol000?o09Tco`0co`00CS?o00800004<ol00P0000@co`0200001C?o00<00003<ol000<0
003oooooool0AOooo`00@oooo`030000<ol0<ol002Pco`000ol0VC?o03?o001=<ol000@0000co`0c
o`000008<ol000@0000co`0co`000005<ol000<0000co`0co`000S?o00030000oooooooo04Goool0
04?oool00`0003?o03?o000X<ol000?o09Tco`0co`00CC?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool00`0003?o03?o000W<ol000?o09Tco`0c
o`00CC?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o
00030000oooooooo04Goool004Coool00`0003?o03?o000W<ol000?o09Tco`0co`00CC?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0000000@co`000`000?ooooooo`15
oooo0015oooo00<0000co`0co`009S?o0003o`2I<ol0<ol004hco`0200002S?o00800005<ol00P00
00@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`009S?o0003o`2I<ol0<ol006Lco`00
0`000?ooooooo`15oooo0016oooo00<0000co`0co`009C?o0003o`2I<ol0<ol006Lco`000`000?oo
ooooo`15oooo0016oooo00<0000co`0co`009C?o0003o`2I<ol0<ol006Lco`000`000?ooooooo`15
oooo0017oooo00<0000co`0co`0093?o0003o`2I<ol0<ol006Lco`000`000?ooooooo`15oooo0017
oooo00<0000co`0co`0093?o0003o`2I<ol0<ol006Lco`020000A_ooo`00B?ooo`030000<ol0<ol0
02<co`000ol0VC?o03?o001W<ol000<0003oooooool0AOooo`00B?ooo`030000<ol0<ol002<co`00
0ol0VC?o03?o001W<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol0028co`000ol0VC?o
03?o001W<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol0028co`000ol0VC?o03?o001W
<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol0024co`000ol0VC?o03?o001W<ol000<0
003oooooool0AOooo`00B_ooo`030000<ol0<ol0024co`000ol0VC?o03?o001W<ol000<0003ooooo
ool0AOooo`00Boooo`030000<ol0<ol0020co`000ol0VC?o03?o001W<ol000<0003oooooool0AOoo
o`00Boooo`030000<ol0<ol0020co`000ol0VC?o03?o001W<ol00P0004Koool004cooon<<ol0B?oo
o`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;<ol0B?ooo`00COoooh/co`18oooo001>
oooo9S?o00030000<ol0<ol002lco`000`0003?o03?o000_<ol0B?ooo`00C_ooobDco`000`0003?o
03?o0008<ol000<0000co`0co`009S?o00030000<ol0<ol002hco`18oooo001?oooo93?o00030000
<ol0<ol0008co`02000013?o00030000<ol0<ol000hco`02000013?o00800004<ol00P0000Dco`00
0`0003?o03?o0002<ol000<0000co`0co`00;S?o04Soool004oooolT<ol000D0000co`0co`0co`00
00000S?o00030000<ol0<ol0008co`000`0003?o03?o0005<ol0100000<co`00100003?o03?o0000
00Pco`00100003?o03?o000000@co`000`0003?o03?o0002<ol000<0000co`0co`00;S?o04Soool0
04oooolS<ol000<0000co`0co`000S?o00030000<ol0<ol001@co`00100003?o03?o000000Pco`00
100003?o03?o000000@co`000`0003?o03?o0003<ol000<0000co`0co`00;C?o04Soool0053ooolS
<ol000<0000co`0co`001@0001<co`00100003?o03?o000000Pco`00100003?o03?o000000Dco`00
1@0003?o03?o03?o0000000`<ol0B?ooo`00D?ooob<co`001@0003?o03?o03?o0000000F<ol000@0
000co`0co`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000003<ol000<0000co`0c
o`00;S?o04Soool0053ooolT<ol000<0000co`0co`0063?o0080000:<ol00P0000<co`0400000S?o
00030000<ol0<ol002lco`18oooo001AooooQc?o04Soool0057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.36136 .30902 L
.37176 .30902 L
.37685 .30902 L
.37926 .30902 L
.38043 .30902 L
.3815 .30902 L
s
.3815 .30902 m
.3815 .61803 L
s
0 .4 1 r
.02381 .31642 m
.06244 .31756 L
.10458 .31901 L
.14415 .3206 L
.18221 .32236 L
.22272 .32454 L
.26171 .32697 L
.30316 .32998 L
.34309 .33337 L
.36136 .33511 L
.37176 .33615 L
.37685 .33668 L
.37926 .33693 L
.38043 .33706 L
.3815 .33717 L
.38263 .30902 L
.38384 .30902 L
.38507 .30902 L
.38572 .30902 L
.3864 .30902 L
.38765 .30902 L
.3888 .30902 L
.38987 .30902 L
.39106 .30902 L
.39175 .30902 L
.3924 .30902 L
.39362 .30902 L
.39494 .30902 L
.39568 .30902 L
.39637 .30902 L
.39752 .30902 L
.39878 .30902 L
.4001 .30902 L
.40134 .30902 L
.40256 .30902 L
.40326 .30902 L
.40391 .30902 L
.40522 .30902 L
.40595 .30902 L
.40662 .30902 L
.40781 .30902 L
.40911 .30902 L
.41033 .30902 L
.41146 .30902 L
.41276 .30902 L
.41398 .30902 L
.41468 .30902 L
.41532 .30902 L
.41606 .30902 L
.41676 .30902 L
Mistroke
.41743 .30902 L
.41815 .30902 L
.41944 .30902 L
.42023 .30902 L
.42098 .30902 L
.42164 .30902 L
.42237 .30902 L
.42361 .30902 L
.42475 .30902 L
.42606 .30902 L
.4273 .30902 L
.42844 .30902 L
.4295 .30902 L
.43066 .30902 L
.4319 .30902 L
.43313 .30902 L
.43383 .30902 L
.43446 .30902 L
.43563 .30902 L
.43687 .30902 L
.43752 .30902 L
.43822 .30902 L
.43948 .30902 L
.44026 .30902 L
.44098 .30902 L
.44164 .30902 L
.44234 .30902 L
.44366 .30902 L
.44488 .30902 L
.44559 .30902 L
.44623 .30902 L
.44697 .30902 L
.44768 .30902 L
.44836 .30902 L
.44908 .30902 L
.45038 .30902 L
.4511 .30902 L
.45177 .30902 L
.45251 .30902 L
.45332 .30902 L
.45455 .30902 L
.45585 .30902 L
.45706 .30902 L
.45818 .30902 L
.45886 .30902 L
.4595 .30902 L
.46071 .30902 L
.46201 .30902 L
.46274 .30902 L
.46342 .30902 L
Mistroke
.46467 .30902 L
.46586 .30902 L
.46692 .30902 L
.46808 .30902 L
.46934 .30902 L
.47005 .30902 L
.47069 .30902 L
.47193 .30902 L
.4731 .30902 L
.4742 .30902 L
.47537 .30902 L
.47636 .30902 L
.47745 .30902 L
.47863 .30902 L
.47989 .30902 L
.48108 .30902 L
.48216 .30902 L
.48344 .30902 L
.48409 .30902 L
.4848 .30902 L
.48606 .30902 L
.48724 .30902 L
.48791 .30902 L
.48862 .30902 L
.4899 .30902 L
.4906 .30902 L
.49126 .30902 L
.49198 .30902 L
.49276 .30902 L
.49407 .30902 L
.4953 .30902 L
.4965 .30902 L
.49761 .30902 L
.49881 .30902 L
.50013 .30902 L
.50079 .30902 L
.5015 .30902 L
.50279 .30902 L
.50348 .30902 L
.50413 .30902 L
.50534 .30902 L
.50665 .30902 L
.50738 .30902 L
.50806 .30902 L
.50919 .30902 L
.51043 .30902 L
.51173 .30902 L
.51293 .30902 L
.51362 .30902 L
.51437 .30902 L
Mistroke
.51508 .30902 L
.51573 .30902 L
.51696 .30902 L
.51827 .30902 L
.51895 .30902 L
.51967 .30902 L
.52099 .30902 L
.52179 .30902 L
.52255 .30902 L
.52324 .30902 L
.52398 .30902 L
.52464 .30902 L
.52534 .30902 L
.52663 .30902 L
.52788 .30902 L
.52903 .30902 L
.53027 .30902 L
.53098 .30902 L
.53164 .30902 L
.53234 .30902 L
.53298 .30902 L
.53371 .30902 L
.53441 .30902 L
.53557 .30902 L
.53681 .30902 L
.53787 .30902 L
.53904 .30902 L
.5403 .30902 L
.541 .30902 L
.54165 .30902 L
.54284 .30902 L
.54409 .30902 L
.55363 .30902 L
.55887 .30902 L
.56012 .30902 L
.56075 .30902 L
.56145 .30902 L
.56267 .30902 L
.56382 .30902 L
.56496 .30902 L
.56605 .30902 L
.56729 .30902 L
.56844 .30902 L
.56968 .30902 L
.57083 .30902 L
.57344 .30902 L
.58218 .30902 L
.58336 .30902 L
.58447 .30902 L
.58576 .30902 L
Mistroke
.58692 .30902 L
.58802 .30902 L
.58904 .30902 L
.59134 .30902 L
.5925 .30902 L
.59358 .30902 L
.59471 .30902 L
.59595 .30902 L
.59722 .30902 L
.59839 .30902 L
.59967 .30902 L
.60031 .30902 L
.60101 .30902 L
.60173 .30902 L
.6024 .30902 L
.60367 .30902 L
.60438 .30902 L
.60503 .30902 L
.60575 .30902 L
.6065 .30902 L
.60776 .30902 L
.60894 .30902 L
.61023 .30902 L
.61095 .30902 L
.61161 .30902 L
.61285 .30902 L
.614 .30902 L
.61527 .30902 L
.61591 .30902 L
.61661 .30902 L
.61779 .30902 L
.61906 .30902 L
.62025 .30902 L
.62135 .30902 L
.6226 .30902 L
.6233 .30902 L
.62393 .30902 L
.62517 .30902 L
.62634 .30902 L
.627 .30902 L
.6277 .30902 L
.62895 .30902 L
.62965 .30902 L
.63031 .30902 L
.63102 .30902 L
.63179 .30902 L
.63252 .30902 L
.6332 .30902 L
.63395 .30902 L
.63474 .30902 L
Mistroke
.6355 .30902 L
.63621 .30902 L
.63685 .30902 L
.63754 .30902 L
.63817 .30902 L
.63887 .30902 L
.6396 .30902 L
.64028 .30902 L
.64149 .30902 L
.6428 .30902 L
.64345 .30902 L
.64415 .30902 L
.64539 .30902 L
.64609 .30902 L
.64674 .30902 L
.64745 .30902 L
.64822 .30902 L
.64952 .30902 L
.65023 .30902 L
.6509 .30902 L
.65207 .30902 L
.65335 .30902 L
.65461 .30902 L
.65579 .30902 L
.65685 .30902 L
.65801 .30902 L
.65924 .30902 L
.6604 .30902 L
.66105 .30902 L
.66175 .30902 L
.66298 .30902 L
.66421 .30902 L
.66551 .30902 L
.66665 .30902 L
.66787 .30902 L
.66911 .30902 L
.67027 .30902 L
.6714 .30902 L
.67244 .30902 L
.6737 .30902 L
.67486 .30902 L
.67614 .30902 L
.67686 .30902 L
.67751 .30902 L
.67883 .30902 L
.67957 .30902 L
.68026 .30902 L
.68152 .30902 L
.68216 .30902 L
.68286 .30902 L
Mistroke
.68414 .30902 L
.68486 .30902 L
.68554 .30902 L
.68677 .30902 L
.68809 .30902 L
.68888 .30902 L
.68963 .30902 L
.6903 .30902 L
.69103 .30902 L
.69171 .30902 L
.69243 .30902 L
.69372 .30902 L
.69493 .30902 L
.69623 .30902 L
.69745 .30902 L
.69857 .30902 L
.69988 .30902 L
.70062 .30902 L
.70131 .30902 L
.70257 .30902 L
.7032 .30902 L
.7039 .30902 L
.70512 .30902 L
.70625 .30902 L
.70749 .30902 L
.70818 .30902 L
.70881 .30902 L
.71009 .30902 L
.71081 .30902 L
.71147 .30902 L
.71269 .30902 L
.71398 .30902 L
.71508 .30902 L
.71626 .30902 L
.71737 .30902 L
.71839 .30902 L
.71957 .30902 L
.72087 .30902 L
.7221 .30902 L
.72323 .30902 L
.72454 .30902 L
.72528 .30902 L
.72596 .30902 L
.72718 .30902 L
.72788 .30902 L
.72853 .30902 L
.72965 .30902 L
.73086 .30902 L
.73215 .30902 L
.73333 .30902 L
Mistroke
.73399 .30902 L
.7347 .30902 L
.73597 .30902 L
.73663 .30902 L
.73734 .30902 L
.73812 .30902 L
.73885 .30902 L
.73949 .30902 L
.74018 .30902 L
.74086 .30902 L
.74158 .30902 L
.74288 .30902 L
.74408 .30902 L
.74532 .30902 L
.74602 .30902 L
.74667 .30902 L
.74737 .30902 L
.748 .30902 L
.74873 .30902 L
.74942 .30902 L
.75064 .30902 L
.75177 .30902 L
.75302 .30902 L
.75434 .30902 L
.75734 .30902 L
.76017 .30902 L
.76141 .30902 L
.76271 .30902 L
.76414 .30902 L
.76545 .30902 L
.76669 .30902 L
.76785 .30902 L
.7685 .30902 L
.7692 .30902 L
.77043 .30902 L
.7716 .30902 L
.77284 .30902 L
.7739 .30902 L
.77507 .30902 L
.77571 .30902 L
.77641 .30902 L
.77769 .30902 L
.77845 .30902 L
.77916 .30902 L
.77981 .30902 L
.78051 .30902 L
.78117 .30902 L
.78189 .30902 L
.78318 .30902 L
.78444 .30902 L
Mistroke
.78561 .30902 L
.78687 .30902 L
.78806 .30902 L
.7903 .30902 L
.79534 .30902 L
.80443 .30902 L
.82509 .30902 L
.86341 .30902 L
.90419 .30902 L
.94345 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00050000<ol0<ol0<ol006Ko00Dco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0
0000I_l0I_l03@1Vob8co`000`0003?o03?o000Y<ol000<0I_lco`0co`000c?o00030000<ol0<ol0
02hco`000`0003?o03?o000_<ol000<0003oooooool0;oooo`030000oooooooo01?oool0017oool@
<ol05@1VocTco`000`1Voc?o03?o001V<ol000<0003oooooool0AOooo`004OooobDco`0D06Ko9C?o
000306Ko<ol0<ol006Hco`000`000?ooooooo`15oooo000Aoooo>C?o00/0I_lJ<ol000<0I_lco`0c
o`00IS?o00030000oooooooo04Goool0017ooom4<ol04P1Vo`Pco`000`1Voc?o03?o001V<ol000<0
003oooooool0AOooo`004OoooeHco`0906KoJ3?o00030000oooooooo04Goool0017ooomN<ol000?o
09Tco`0co`00IS?o00800016oooo000AooooGS?o0003o`2I<ol0<ol006Hco`000`000?ooooooo`15
oooo000AooooGS?o0003o`2I<ol0<ol006Hco`000`000?ooooooo`15oooo000AooooGS?o0003o`2I
<ol0<ol006Hco`000`000?ooooooo`15oooo000AooooGS?o0003o`2I<ol0<ol006Hco`000`000?oo
ooooo`15oooo000AooooGS?o0003o`2I<ol0<ol006Hco`000`000?ooooooo`15oooo000AooooGS?o
0003o`2I<ol0<ol006Hco`000`000?ooooooo`15oooo000AooooGS?o0003o`2I<ol0<ol006Hco`00
0`000?ooooooo`15oooo000Aoooo0P0005`co`000ol0VC?o03?o001V<ol00P0004Koool001?oool2
0000FS?o0003o`2I<ol0<ol006Hco`000`000?ooooooo`15oooo000Eoooo0P0005Pco`000ol0VC?o
03?o001V<ol000<0003oooooool0AOooo`005oooo`80001F<ol000?o09Tco`0co`00IS?o00030000
oooooooo04Goool001Woool20000E3?o0003o`2I<ol0<ol006Hco`000`000?ooooooo`15oooo000K
oooo0P00058co`000ol0VC?o03?o001V<ol000<0003oooooool0AOooo`007Oooo`80001@<ol000?o
09Tco`0co`00IS?o00030000oooooooo04Goool001ooool00`0003?o03?o001=<ol000?o09Tco`0c
o`00IS?o00030000oooooooo04Goool0023oool00`0003?o03?o001<<ol000?o09Tco`0co`00IS?o
00800016oooo000Qoooo0P0004`co`000ol0VC?o03?o001V<ol000<0003oooooool0AOooo`008ooo
o`030000<ol0<ol004Tco`000ol0VC?o03?o001V<ol000<0003oooooool0AOooo`009?ooo`800019
<ol000?o09Tco`0co`00IS?o00030000oooooooo04Goool002Koool00`0003?o03?o0016<ol000?o
09Tco`0co`00IS?o00030000oooooooo04Goool002Ooool00`0003?o03?o0015<ol000?o09Tco`0c
o`00IS?o00030000oooooooo04Goool002Soool00`0003?o03?o0014<ol000?o09Tco`0co`00CC?o
00800004<ol00P0000@co`0200000c?o00@00004<ol000<0003oooooool0AOooo`00:Oooo`030000
<ol0<ol004<co`000ol0VC?o03?o001<<ol000@0000co`0co`000008<ol000@0000co`0co`000002
<ol000<0000co`0co`001C?o00030000oooooooo04Goool002[oool00`0003?o03?o0012<ol000?o
09Tco`0co`00C3?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0<ol0
00@co`030000AOooo`00:oooo`800012<ol000?o09Tco`0co`00C3?o00040000<ol0<ol0000023?o
00040000<ol0<ol0000013?o00030000<ol0<ol000<co`000`000?ooooooo`15oooo000]oooo00<0
000co`0co`00?c?o0003o`2I<ol0<ol004`co`00100003?o03?o000000Pco`00100003?o03?o0000
008co`00100003?o03?o000000@co`000`000?ooooooo`15oooo000^oooo00<0000co`0co`00?S?o
0003o`2I<ol0<ol004dco`0200002S?o00800004<ol00P0000Dco`000`000?ooooooo`15oooo000_
oooo00<0000co`0co`00?C?o0003o`2I<ol0<ol006Hco`000`000?ooooooo`15oooo000`oooo00<0
000co`0co`00?3?o0003o`2I<ol0<ol006Hco`000`000?ooooooo`15oooo000aoooo00<0000co`0c
o`00>c?o0003o`2I<ol0<ol006Hco`000`000?ooooooo`15oooo000boooo00<0000co`0co`00>S?o
0003o`2I<ol0<ol006Hco`000`000?ooooooo`15oooo000coooo00<0000co`0co`00>C?o0003o`2I
<ol0<ol006Hco`020000A_ooo`00<oooo`030000<ol0<ol003Tco`000ol0VC?o03?o001V<ol000<0
003oooooool0AOooo`00=?ooo`030000<ol0<ol003Pco`000ol0VC?o03?o001V<ol000<0003ooooo
ool0AOooo`00=Oooo`030000<ol0<ol003Lco`000ol0VC?o03?o001V<ol000<0003oooooool0AOoo
o`00=_ooo`030000<ol0<ol003Hco`000ol0VC?o03?o001V<ol000<0003oooooool0AOooo`00=ooo
o`030000<ol0<ol003Dco`000ol0VC?o03?o001V<ol000<0003oooooool0AOooo`00>?ooo`030000
<ol0<ol003@co`000ol0VC?o03?o001V<ol000<0003oooooool0AOooo`00>?ooo`030000<ol0<ol0
03@co`000ol0VC?o03?o001V<ol000<0003oooooool0AOooo`00>Oooo`030000<ol0<ol003<co`00
0ol0VC?o03?o001V<ol00P0004Koool003[oool00`0003?o03?o000b<ol000?o09Tco`0co`00IS?o
00030000oooooooo04Goool003_oool00`0003?o03?o000a<ol000?o09Tco`0co`00IS?o00030000
oooooooo04Goool003coool00`0003?o03?o000`<ol000?o09Tco`0co`00IS?o00030000oooooooo
04Goool003coool00`0003?o03?o000`<ol000?o09Tco`0co`00IS?o00030000oooooooo04Goool0
03goool00`0003?o03?o000_<ol000?o09Tco`0co`00IS?o00030000oooooooo04Goool003goool0
0`0003?o03?o000_<ol000?o09Tco`0co`00IS?o00030000oooooooo04Goool003koool00`0003?o
03?o000^<ol000?o09Tco`0co`00IS?o00030000oooooooo04Goool003koool00`0003?o03?o000^
<ol000?o09Tco`0co`00IS?o00030000oooooooo04Goool003ooool00`0003?o03?o000]<ol000?o
09Tco`0co`00IS?o00800016oooo000ooooo00<0000co`0co`00;C?o0003o`2I<ol0<ol006Hco`00
0`000?ooooooo`15oooo0010oooo00<0000co`0co`00;3?o0003o`2I<ol0<ol006Hco`000`000?oo
ooooo`15oooo0011oooo00<0000co`0co`00:c?o0003o`2I<ol0<ol006Hco`000`000?ooooooo`15
oooo0011oooo00<0000co`0co`00:c?o0003o`2I<ol0<ol006Hco`000`000?ooooooo`15oooo0012
oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol006Hco`000`000?ooooooo`15oooo0012oooo00<0
000co`0co`00:S?o0003o`2I<ol0<ol004dco`02000013?o00800004<ol00P0000Dco`0300000c?o
00030000oooooooo04Goool004?oool00`0003?o03?o000Y<ol000?o09Tco`0co`00C3?o00040000
<ol0<ol0000023?o00040000<ol0<ol000001C?o00030000<ol0<ol0008co`000`000?ooooooo`15
oooo0013oooo00<0000co`0co`00:C?o0003o`2I<ol0<ol004`co`00100003?o03?o000000Pco`00
100003?o03?o0000008co`0500000c?o00<00015oooo0014oooo00<0000co`0co`00:3?o0003o`2I
<ol0<ol004`co`00100003?o03?o000000Pco`00100003?o03?o0000008co`00100003?o03?o0000
00@co`000`000?ooooooo`15oooo0014oooo00<0000co`0co`00:3?o0003o`2I<ol0<ol004`co`00
100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o00000004<ol000<0003ooooo
ool0AOooo`00AOooo`030000<ol0<ol002Lco`000ol0VC?o03?o001=<ol00P0000Xco`0200001C?o
00800004<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol002Lco`000ol0VC?o03?o001V
<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol002Hco`000ol0VC?o03?o001V<ol000<0
003oooooool0AOooo`00A_ooo`030000<ol0<ol002Hco`000ol0VC?o03?o001V<ol000<0003ooooo
ool0AOooo`00Aoooo`030000<ol0<ol002Dco`000ol0VC?o03?o001V<ol000<0003oooooool0AOoo
o`00Aoooo`030000<ol0<ol002Dco`000ol0VC?o03?o001V<ol00P0004Koool004Soool00`0003?o
03?o000T<ol000?o09Tco`0co`00IS?o00030000oooooooo04Goool004Soool00`0003?o03?o000T
<ol000?o09Tco`0co`00IS?o00030000oooooooo04Goool004Woool00`0003?o03?o000S<ol000?o
09Tco`0co`00IS?o00030000oooooooo04Goool004Woool00`0003?o03?o000S<ol000?o09Tco`0c
o`00IS?o00030000oooooooo04Goool004[oool00`0003?o03?o000R<ol000?o09Tco`0co`00IS?o
00030000oooooooo04Goool004[oool00`0003?o03?o000R<ol000?o09Tco`0co`00IS?o00030000
oooooooo04Goool004_oool00`0003?o03?o000Q<ol000?o09Tco`0co`00IS?o00030000oooooooo
04Goool004_oool00`0003?o03?o000Q<ol000?o09Tco`0co`00IS?o00800016oooo001<ooooS3?o
04Soool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001=ooooRc?o04Soool004gooon;<ol0B?oo
o`00C_ooobHco`000`0003?o03?o000_<ol000<0000co`0co`00;c?o04Soool004kooolU<ol000<0
000co`0co`0023?o00030000<ol0<ol002Hco`000`0003?o03?o000^<ol0B?ooo`00Coooob@co`00
0`0003?o03?o0002<ol00P0000@co`000`0003?o03?o000><ol00P0000@co`02000013?o00800003
<ol00`0000@co`000`0003?o03?o000^<ol0B?ooo`00Coooob@co`001@0003?o03?o03?o00000002
<ol000<0000co`0co`000S?o00030000<ol0<ol000Dco`0400000c?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000S?o00040000<ol0<ol000000c?o00030000<ol0<ol002hco`18oooo001?
oooo8c?o00030000<ol0<ol0008co`000`0003?o03?o000D<ol000@0000co`0co`000008<ol000@0
000co`0co`000002<ol000@0000co`0co`000004<ol000<0000co`0co`00;C?o04Soool0053ooolS
<ol000<0000co`0co`001@0001<co`00100003?o03?o000000Pco`00100003?o03?o0000008co`03
000013?o00030000<ol0<ol002hco`18oooo001@oooo8c?o00050000<ol0<ol0<ol0000001Hco`00
100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o0003<ol000<0000co`0c
o`00;S?o04Soool0053ooolT<ol000<0000co`0co`0063?o0080000:<ol00P0000@co`0300000S?o
00030000<ol0<ol002lco`18oooo001AooooQc?o04Soool0057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.36136 .30902 L
.37176 .30902 L
.37685 .30902 L
.3815 .30902 L
.38384 .30902 L
.38448 .30902 L
.38517 .30902 L
s
.38517 .30902 m
.38517 .61803 L
s
0 .4 1 r
.02381 .31518 m
.06244 .31614 L
.10458 .31734 L
.14415 .31866 L
.18221 .32013 L
.22272 .32195 L
.26171 .32397 L
.30316 .32648 L
.34309 .32931 L
.36136 .33075 L
.37176 .33162 L
.37685 .33206 L
.3815 .33247 L
.38384 .33268 L
.38448 .33273 L
.38517 .33279 L
.3864 .30902 L
.38766 .30902 L
.38884 .30902 L
.38991 .30902 L
.39106 .30902 L
.3923 .30902 L
.393 .30902 L
.39366 .30902 L
.39435 .30902 L
.39499 .30902 L
.39572 .30902 L
.39641 .30902 L
.39764 .30902 L
.39877 .30902 L
.40001 .30902 L
.40134 .30902 L
.40263 .30902 L
.40382 .30902 L
.40512 .30902 L
.40578 .30902 L
.40649 .30902 L
.4077 .30902 L
.409 .30902 L
.41022 .30902 L
.41133 .30902 L
.41202 .30902 L
.41275 .30902 L
.41406 .30902 L
.41478 .30902 L
.41546 .30902 L
.41621 .30902 L
.41701 .30902 L
.41769 .30902 L
.41844 .30902 L
Mistroke
.41915 .30902 L
.41981 .30902 L
.42105 .30902 L
.42237 .30902 L
.42361 .30902 L
.42432 .30902 L
.42498 .30902 L
.42568 .30902 L
.42631 .30902 L
.42705 .30902 L
.42774 .30902 L
.42897 .30902 L
.43011 .30902 L
.43135 .30902 L
.43198 .30902 L
.43268 .30902 L
.43338 .30902 L
.43412 .30902 L
.43476 .30902 L
.43545 .30902 L
.43619 .30902 L
.43699 .30902 L
.43774 .30902 L
.43843 .30902 L
.43912 .30902 L
.43976 .30902 L
.44046 .30902 L
.4412 .30902 L
.44245 .30902 L
.44316 .30902 L
.44382 .30902 L
.44507 .30902 L
.44578 .30902 L
.44643 .30902 L
.44763 .30902 L
.44891 .30902 L
.45005 .30902 L
.45112 .30902 L
.45229 .30902 L
.45355 .30902 L
.45621 .30902 L
.45765 .30902 L
.45836 .30902 L
.459 .30902 L
.46015 .30902 L
.46139 .30902 L
.46203 .30902 L
.46273 .30902 L
.464 .30902 L
.46523 .30902 L
Mistroke
.46635 .30902 L
.46765 .30902 L
.46888 .30902 L
.47001 .30902 L
.47107 .30902 L
.47222 .30902 L
.47345 .30902 L
.47415 .30902 L
.4748 .30902 L
.47551 .30902 L
.47626 .30902 L
.47752 .30902 L
.47824 .30902 L
.47891 .30902 L
.48016 .30902 L
.48129 .30902 L
.48261 .30902 L
.48385 .30902 L
.48506 .30902 L
.48575 .30902 L
.48639 .30902 L
.48769 .30902 L
.48842 .30902 L
.48909 .30902 L
.49021 .30902 L
.49145 .30902 L
.49273 .30902 L
.49393 .30902 L
.50489 .30902 L
.50616 .30902 L
.50734 .30902 L
.50858 .30902 L
.50924 .30902 L
.50994 .30902 L
.51071 .30902 L
.51143 .30902 L
.51208 .30902 L
.51279 .30902 L
.51542 .30902 L
.51792 .30902 L
.51858 .30902 L
.51929 .30902 L
.52058 .30902 L
.52189 .30902 L
.52309 .30902 L
.52419 .30902 L
.52536 .30902 L
.52652 .30902 L
.52758 .30902 L
.5288 .30902 L
Mistroke
.52995 .30902 L
.53102 .30902 L
.532 .30902 L
.53308 .30902 L
.53423 .30902 L
.53539 .30902 L
.53648 .30902 L
.53777 .30902 L
.53895 .30902 L
.54017 .30902 L
.54087 .30902 L
.54151 .30902 L
.54269 .30902 L
.54395 .30902 L
.54519 .30902 L
.5459 .30902 L
.54655 .30902 L
.5493 .30902 L
.55168 .30902 L
.55237 .30902 L
.55301 .30902 L
.55423 .30902 L
.55487 .30902 L
.55557 .30902 L
.55631 .30902 L
.557 .30902 L
.55823 .30902 L
.55892 .30902 L
.55956 .30902 L
.56026 .30902 L
.56091 .30902 L
.56162 .30902 L
.56238 .30902 L
.56318 .30902 L
.56394 .30902 L
.56535 .30902 L
.56652 .30902 L
.5678 .30902 L
.56844 .30902 L
.56914 .30902 L
.57039 .30902 L
.57163 .30902 L
.57281 .30902 L
.57387 .30902 L
.57503 .30902 L
.57574 .30902 L
.57641 .30902 L
.57767 .30902 L
.57832 .30902 L
.57901 .30902 L
Mistroke
.57977 .30902 L
.58047 .30902 L
.58172 .30902 L
.58288 .30902 L
.58416 .30902 L
.58481 .30902 L
.58552 .30902 L
.58617 .30902 L
.58687 .30902 L
.58813 .30902 L
.58939 .30902 L
.59054 .30902 L
.59181 .30902 L
.59253 .30902 L
.5932 .30902 L
.59391 .30902 L
.59455 .30902 L
.59529 .30902 L
.59599 .30902 L
.59831 .30902 L
.59957 .30902 L
.60075 .30902 L
.60203 .30902 L
.60271 .30902 L
.60343 .30902 L
.60473 .30902 L
.6059 .30902 L
.60705 .30902 L
.60827 .30902 L
.60931 .30902 L
.61047 .30902 L
.6117 .30902 L
.61239 .30902 L
.61303 .30902 L
.61427 .30902 L
.61543 .30902 L
.61645 .30902 L
.61753 .30902 L
.61874 .30902 L
.61983 .30902 L
.62098 .30902 L
.62222 .30902 L
.62339 .30902 L
.62447 .30902 L
.62572 .30902 L
.6269 .30902 L
.62797 .30902 L
.62913 .30902 L
.63039 .30902 L
.63109 .30902 L
Mistroke
.63173 .30902 L
.63297 .30902 L
.63414 .30902 L
.63524 .30902 L
.63641 .30902 L
.6374 .30902 L
.63849 .30902 L
.63967 .30902 L
.64093 .30902 L
.64212 .30902 L
.6432 .30902 L
.64448 .30902 L
.64512 .30902 L
.64584 .30902 L
.6471 .30902 L
.64828 .30902 L
.64895 .30902 L
.64966 .30902 L
.65093 .30902 L
.65164 .30902 L
.65232 .30902 L
.65309 .30902 L
.65379 .30902 L
.65499 .30902 L
.65628 .30902 L
.65748 .30902 L
.65859 .30902 L
.6598 .30902 L
.66049 .30902 L
.66113 .30902 L
.66243 .30902 L
.66316 .30902 L
.66383 .30902 L
.66512 .30902 L
.66634 .30902 L
.66743 .30902 L
.66861 .30902 L
.6699 .30902 L
.67061 .30902 L
.67127 .30902 L
.67243 .30902 L
.6737 .30902 L
.67489 .30902 L
.67602 .30902 L
.67703 .30902 L
.67812 .30902 L
.67932 .30902 L
.68058 .30902 L
.68167 .30902 L
.68286 .30902 L
Mistroke
.68352 .30902 L
.68424 .30902 L
.68555 .30902 L
.68683 .30902 L
.68801 .30902 L
.68874 .30902 L
.68942 .30902 L
.6907 .30902 L
.69356 .30902 L
.69478 .30902 L
.69607 .30902 L
.69717 .30902 L
.69838 .30902 L
.69968 .30902 L
.70041 .30902 L
.70108 .30902 L
.70237 .30902 L
.7036 .30902 L
.70473 .30902 L
.70596 .30902 L
.70712 .30902 L
.70818 .30902 L
.70935 .30902 L
.71064 .30902 L
.71134 .30902 L
.712 .30902 L
.71324 .30902 L
.71447 .30902 L
.71516 .30902 L
.7158 .30902 L
.71644 .30902 L
.71714 .30902 L
.71786 .30902 L
.71855 .30902 L
.71979 .30902 L
.72093 .30902 L
.72224 .30902 L
.72349 .30902 L
.72465 .30902 L
.7257 .30902 L
.72691 .30902 L
.72806 .30902 L
.72912 .30902 L
.73009 .30902 L
.73229 .30902 L
.7419 .30902 L
.74306 .30902 L
.74432 .30902 L
.74551 .30902 L
.74661 .30902 L
Mistroke
.74789 .30902 L
.74853 .30902 L
.74925 .30902 L
.75049 .30902 L
.75165 .30902 L
.75276 .30902 L
.75394 .30902 L
.75494 .30902 L
.75603 .30902 L
.75721 .30902 L
.75847 .30902 L
.75966 .30902 L
.76075 .30902 L
.76204 .30902 L
.76269 .30902 L
.7634 .30902 L
.76467 .30902 L
.76585 .30902 L
.76657 .30902 L
.76725 .30902 L
.76852 .30902 L
.76923 .30902 L
.76989 .30902 L
.77061 .30902 L
.77138 .30902 L
.77269 .30902 L
.77342 .30902 L
.7741 .30902 L
.77665 .30902 L
.77793 .30902 L
.77915 .30902 L
.78023 .30902 L
.78142 .30902 L
.78261 .30902 L
.78387 .30902 L
.78495 .30902 L
.78614 .30902 L
.7874 .30902 L
.78875 .30902 L
.79119 .30902 L
.8003 .30902 L
.82098 .30902 L
.8622 .30902 L
.90191 .30902 L
.9401 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol0008co`000`1Voc?o03?o0002<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool04ooo
o`004Oooo`03000006Ko06Ko01P0I_lG<ol000<0000co`0co`00:S?o000306Ko<ol0<ol0008co`00
0`0003?o03?o000^<ol000<0000co`0co`00;c?o00030000oooooooo02ooool00`000?ooooooo`0C
oooo000Aoooo6c?o01h0I_lV<ol000<0I_lco`0co`00IC?o00030000oooooooo04Goool0017oooli
<ol02`1Voa/co`000`1Voc?o03?o001U<ol000<0003oooooool0AOooo`004Ooood@co`0B06Ko2C?o
000306Ko<ol0<ol006Dco`000`000?ooooooo`15oooo000AooooES?o00X0I_mW<ol000<0003ooooo
ool0AOooo`004Ooooelco`000ol0VC?o03?o001U<ol000<0003oooooool0AOooo`004Ooooelco`00
0ol0VC?o03?o001U<ol00P0004Koool0017ooomO<ol000?o09Tco`0co`00IC?o00030000oooooooo
04Goool0017ooomO<ol000?o09Tco`0co`00IC?o00030000oooooooo04Goool0017ooomO<ol000?o
09Tco`0co`00IC?o00030000oooooooo04Goool0017ooomO<ol000?o09Tco`0co`00IC?o00030000
oooooooo04Goool0017ooomO<ol000?o09Tco`0co`00IC?o00030000oooooooo04Goool0017ooomO
<ol000?o09Tco`0co`00IC?o00030000oooooooo04Goool0017ooomO<ol000?o09Tco`0co`00IC?o
00030000oooooooo04Goool0017oool20000GC?o0003o`2I<ol0<ol006Dco`020000A_ooo`004ooo
o`80001K<ol000?o09Tco`0co`00IC?o00030000oooooooo04Goool001Goool20000FC?o0003o`2I
<ol0<ol006Dco`000`000?ooooooo`15oooo000Goooo0P0005Lco`000ol0VC?o03?o001U<ol000<0
003oooooool0AOooo`006Oooo`80001E<ol000?o09Tco`0co`00IC?o00030000oooooooo04Goool0
01_oool20000Dc?o0003o`2I<ol0<ol006Dco`000`000?ooooooo`15oooo000Moooo0P00054co`00
0ol0VC?o03?o001U<ol000<0003oooooool0AOooo`007oooo`030000<ol0<ol004hco`000ol0VC?o
03?o001U<ol000<0003oooooool0AOooo`008?ooo`030000<ol0<ol004dco`000ol0VC?o03?o001U
<ol00P0004Koool0027oool20000CC?o0003o`2I<ol0<ol006Dco`000`000?ooooooo`15oooo000S
oooo00<0000co`0co`00BS?o0003o`2I<ol0<ol006Dco`000`000?ooooooo`15oooo000Toooo0P00
04Xco`000ol0VC?o03?o001U<ol000<0003oooooool0AOooo`009_ooo`030000<ol0<ol004Lco`00
0ol0VC?o03?o001U<ol000<0003oooooool0AOooo`009oooo`030000<ol0<ol004Hco`000ol0VC?o
03?o001U<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol004Dco`000ol0VC?o03?o001<
<ol00P0000@co`02000013?o00800003<ol0100000@co`000`000?ooooooo`15oooo000Yoooo00<0
000co`0co`00A3?o0003o`2I<ol0<ol004/co`00100003?o03?o000000Pco`00100003?o03?o0000
008co`000`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_ooo`030000<ol0<ol004<co`00
0ol0VC?o03?o001;<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`0c
o`0013?o00<00015oooo000[oooo0P0004<co`000ol0VC?o03?o001;<ol000@0000co`0co`000008
<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o00030000oooooooo04Goool002goool0
0`0003?o03?o0010<ol000?o09Tco`0co`00Bc?o00040000<ol0<ol0000023?o00040000<ol0<ol0
00000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool002koool00`0003?o03?o000o
<ol000?o09Tco`0co`00C3?o0080000:<ol00P0000@co`0200001C?o00030000oooooooo04Goool0
02ooool00`0003?o03?o000n<ol000?o09Tco`0co`00IC?o00030000oooooooo04Goool0033oool0
0`0003?o03?o000m<ol000?o09Tco`0co`00IC?o00030000oooooooo04Goool0037oool00`0003?o
03?o000l<ol000?o09Tco`0co`00IC?o00030000oooooooo04Goool003;oool00`0003?o03?o000k
<ol000?o09Tco`0co`00IC?o00030000oooooooo04Goool003?oool00`0003?o03?o000j<ol000?o
09Tco`0co`00IC?o00800016oooo000coooo00<0000co`0co`00>S?o0003o`2I<ol0<ol006Dco`00
0`000?ooooooo`15oooo000doooo00<0000co`0co`00>C?o0003o`2I<ol0<ol006Dco`000`000?oo
ooooo`15oooo000eoooo00<0000co`0co`00>3?o0003o`2I<ol0<ol006Dco`000`000?ooooooo`15
oooo000foooo00<0000co`0co`00=c?o0003o`2I<ol0<ol006Dco`000`000?ooooooo`15oooo000g
oooo00<0000co`0co`00=S?o0003o`2I<ol0<ol006Dco`000`000?ooooooo`15oooo000hoooo00<0
000co`0co`00=C?o0003o`2I<ol0<ol006Dco`000`000?ooooooo`15oooo000hoooo00<0000co`0c
o`00=C?o0003o`2I<ol0<ol006Dco`000`000?ooooooo`15oooo000ioooo00<0000co`0co`00=3?o
0003o`2I<ol0<ol006Dco`020000A_ooo`00>_ooo`030000<ol0<ol003<co`000ol0VC?o03?o001U
<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol0038co`000ol0VC?o03?o001U<ol000<0
003oooooool0AOooo`00??ooo`030000<ol0<ol0034co`000ol0VC?o03?o001U<ol000<0003ooooo
ool0AOooo`00??ooo`030000<ol0<ol0034co`000ol0VC?o03?o001U<ol000<0003oooooool0AOoo
o`00?Oooo`030000<ol0<ol0030co`000ol0VC?o03?o001U<ol000<0003oooooool0AOooo`00?Ooo
o`030000<ol0<ol0030co`000ol0VC?o03?o001U<ol000<0003oooooool0AOooo`00?_ooo`030000
<ol0<ol002lco`000ol0VC?o03?o001U<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol0
02lco`000ol0VC?o03?o001U<ol000<0003oooooool0AOooo`00?oooo`030000<ol0<ol002hco`00
0ol0VC?o03?o001U<ol00P0004Koool003ooool00`0003?o03?o000^<ol000?o09Tco`0co`00IC?o
00030000oooooooo04Goool0043oool00`0003?o03?o000]<ol000?o09Tco`0co`00IC?o00030000
oooooooo04Goool0047oool00`0003?o03?o000/<ol000?o09Tco`0co`00IC?o00030000oooooooo
04Goool0047oool00`0003?o03?o000/<ol000?o09Tco`0co`00IC?o00030000oooooooo04Goool0
04;oool00`0003?o03?o000[<ol000?o09Tco`0co`00IC?o00030000oooooooo04Goool004;oool0
0`0003?o03?o000[<ol000?o09Tco`0co`00C3?o00800004<ol00P0000@co`0200001C?o00<00003
<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol002Xco`000ol0VC?o03?o001;<ol000@0
000co`0co`000008<ol000@0000co`0co`000005<ol000<0000co`0co`000S?o00030000oooooooo
04Goool004?oool00`0003?o03?o000Z<ol000?o09Tco`0co`00Bc?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool00`0003?o03?o000Y<ol000?o
09Tco`0co`00Bc?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0
000013?o00030000oooooooo04Goool004Coool00`0003?o03?o000Y<ol000?o09Tco`0co`00Bc?o
00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0000000@co`000`000?oo
ooooo`15oooo0015oooo00<0000co`0co`00:3?o0003o`2I<ol0<ol004`co`0200002S?o00800005
<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`00:3?o0003o`2I<ol0<ol0
06Dco`000`000?ooooooo`15oooo0016oooo00<0000co`0co`009c?o0003o`2I<ol0<ol006Dco`00
0`000?ooooooo`15oooo0016oooo00<0000co`0co`009c?o0003o`2I<ol0<ol006Dco`000`000?oo
ooooo`15oooo0017oooo00<0000co`0co`009S?o0003o`2I<ol0<ol006Dco`000`000?ooooooo`15
oooo0017oooo00<0000co`0co`009S?o0003o`2I<ol0<ol006Dco`020000A_ooo`00B?ooo`030000
<ol0<ol002Dco`000ol0VC?o03?o001U<ol000<0003oooooool0AOooo`00B?ooo`030000<ol0<ol0
02Dco`000ol0VC?o03?o001U<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol002@co`00
0ol0VC?o03?o001U<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol002@co`000ol0VC?o
03?o001U<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol002<co`000ol0VC?o03?o001U
<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol002<co`000ol0VC?o03?o001U<ol000<0
003oooooool0AOooo`00Boooo`030000<ol0<ol0028co`000ol0VC?o03?o001U<ol000<0003ooooo
ool0AOooo`00Boooo`030000<ol0<ol0028co`000ol0VC?o03?o001U<ol00P0004Koool004cooon<
<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;<ol0B?ooo`00COoooh/co`18
oooo001>oooo9S?o00030000<ol0<ol002lco`000`0003?o03?o000_<ol0B?ooo`00C_ooobDco`00
0`0003?o03?o0008<ol000<0000co`0co`009S?o00030000<ol0<ol002hco`18oooo001?oooo93?o
00030000<ol0<ol0008co`02000013?o00030000<ol0<ol000hco`02000013?o00800004<ol00P00
00@co`02000013?o00030000<ol0<ol002hco`18oooo001?oooo93?o00050000<ol0<ol0<ol00000
008co`000`0003?o03?o0002<ol000<0000co`0co`001C?o00@00003<ol000@0000co`0co`000008
<ol000@0000co`0co`000002<ol000@0000co`0co`000003<ol000<0000co`0co`00;S?o04Soool0
04oooolS<ol000<0000co`0co`000S?o00030000<ol0<ol001@co`00100003?o03?o000000Pco`00
100003?o03?o000000Dco`000`0003?o03?o0002<ol000<0000co`0co`00;C?o04Soool0053ooolS
<ol000<0000co`0co`001@0001<co`00100003?o03?o000000Pco`00100003?o03?o000000<co`02
000013?o00030000<ol0<ol002hco`18oooo001@oooo8c?o00050000<ol0<ol0<ol0000001Hco`00
100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o0003<ol000<0000co`0c
o`00;S?o04Soool0053ooolT<ol000<0000co`0co`0063?o0080000:<ol00P0000@co`0300000S?o
00030000<ol0<ol002lco`18oooo001AooooQc?o04Soool0057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.36136 .30902 L
.37176 .30902 L
.37685 .30902 L
.3815 .30902 L
.38384 .30902 L
.3864 .30902 L
.38757 .30902 L
.38881 .30902 L
s
.38881 .30902 m
.38882 .61803 L
s
0 .4 1 r
.02381 .31395 m
.06244 .31471 L
.10458 .31568 L
.14415 .31673 L
.18221 .31791 L
.22272 .31936 L
.26171 .32098 L
.30316 .32299 L
.34309 .32524 L
.36136 .3264 L
.37176 .3271 L
.37685 .32745 L
.3815 .32777 L
.38384 .32794 L
.3864 .32812 L
.38757 .32821 L
.38881 .3283 L
.38999 .30902 L
.39106 .30902 L
.3917 .30902 L
.39238 .30902 L
.3936 .30902 L
.39491 .30902 L
.39565 .30902 L
.39635 .30902 L
.39876 .30902 L
.39945 .30902 L
.40011 .30902 L
.40134 .30902 L
.40254 .30902 L
.40323 .30902 L
.40387 .30902 L
.40517 .30902 L
.4059 .30902 L
.40657 .30902 L
.40769 .30902 L
.40893 .30902 L
.41021 .30902 L
.41141 .30902 L
.41209 .30902 L
.41284 .30902 L
.41354 .30902 L
.41418 .30902 L
.41541 .30902 L
.41671 .30902 L
.41738 .30902 L
.4181 .30902 L
.4194 .30902 L
.4202 .30902 L
.42095 .30902 L
Mistroke
.42163 .30902 L
.42237 .30902 L
.42302 .30902 L
.4237 .30902 L
.42493 .30902 L
.42625 .30902 L
.427 .30902 L
.4277 .30902 L
.42896 .30902 L
.43012 .30902 L
.43076 .30902 L
.43145 .30902 L
.43271 .30902 L
.43393 .30902 L
.43507 .30902 L
.43626 .30902 L
.43758 .30902 L
.43871 .30902 L
.43975 .30902 L
.44088 .30902 L
.44208 .30902 L
.4434 .30902 L
.44459 .30902 L
.44526 .30902 L
.44597 .30902 L
.44728 .30902 L
.4485 .30902 L
.44979 .30902 L
.45089 .30902 L
.45211 .30902 L
.45284 .30902 L
.45354 .30902 L
.45484 .30902 L
.45557 .30902 L
.45624 .30902 L
.45698 .30902 L
.45777 .30902 L
.45907 .30902 L
.46029 .30902 L
.46098 .30902 L
.46162 .30902 L
.46232 .30902 L
.46306 .30902 L
.46429 .30902 L
.46499 .30902 L
.46563 .30902 L
.46678 .30902 L
.46805 .30902 L
.46919 .30902 L
.47026 .30902 L
Mistroke
.47138 .30902 L
.47259 .30902 L
.4739 .30902 L
.47464 .30902 L
.47532 .30902 L
.47658 .30902 L
.47728 .30902 L
.47791 .30902 L
.47912 .30902 L
.48042 .30902 L
.48165 .30902 L
.48278 .30902 L
.48384 .30902 L
.48498 .30902 L
.48606 .30902 L
.48704 .30902 L
.48819 .30902 L
.48944 .30902 L
.49062 .30902 L
.49171 .30902 L
.49283 .30902 L
.49388 .30902 L
.49504 .30902 L
.49628 .30902 L
.49752 .30902 L
.49882 .30902 L
.49993 .30902 L
.50114 .30902 L
.50246 .30902 L
.50368 .30902 L
.50437 .30902 L
.50502 .30902 L
.50569 .30902 L
.50643 .30902 L
.50769 .30902 L
.50884 .30902 L
.50947 .30902 L
.51017 .30902 L
.51142 .30902 L
.51266 .30902 L
.51377 .30902 L
.51506 .30902 L
.51627 .30902 L
.5174 .30902 L
.51843 .30902 L
.51957 .30902 L
.52076 .30902 L
.52207 .30902 L
.52327 .30902 L
.52392 .30902 L
Mistroke
.52464 .30902 L
.52594 .30902 L
.52705 .30902 L
.52824 .30902 L
.52954 .30902 L
.53076 .30902 L
.5315 .30902 L
.53221 .30902 L
.53353 .30902 L
.53426 .30902 L
.53493 .30902 L
.53567 .30902 L
.53646 .30902 L
.53714 .30902 L
.53788 .30902 L
.53858 .30902 L
.53922 .30902 L
.54043 .30902 L
.54172 .30902 L
.54294 .30902 L
.54363 .30902 L
.54426 .30902 L
.54543 .30902 L
.54667 .30902 L
.54882 .30902 L
.55004 .30902 L
.55119 .30902 L
.55243 .30902 L
.55374 .30902 L
.55486 .30902 L
.55608 .30902 L
.5574 .30902 L
.55814 .30902 L
.55881 .30902 L
.56012 .30902 L
.56135 .30902 L
.5625 .30902 L
.56357 .30902 L
.56469 .30902 L
.56592 .30902 L
.56699 .30902 L
.56796 .30902 L
.56908 .30902 L
.57014 .30902 L
.57129 .30902 L
.57251 .30902 L
.57366 .30902 L
.57471 .30902 L
.57594 .30902 L
.57663 .30902 L
Mistroke
.57727 .30902 L
.57844 .30902 L
.57968 .30902 L
.5809 .30902 L
.58159 .30902 L
.58223 .30902 L
.58341 .30902 L
.58465 .30902 L
.58576 .30902 L
.5868 .30902 L
.58795 .30902 L
.58918 .30902 L
.59041 .30902 L
.59111 .30902 L
.59176 .30902 L
.59308 .30902 L
.59449 .30902 L
.5958 .30902 L
.59703 .30902 L
.59815 .30902 L
.59935 .30902 L
.60049 .30902 L
.60156 .30902 L
.60273 .30902 L
.60399 .30902 L
.60531 .30902 L
.60655 .30902 L
.60768 .30902 L
.6089 .30902 L
.61004 .30902 L
.61111 .30902 L
.61223 .30902 L
.61346 .30902 L
.61452 .30902 L
.6155 .30902 L
.61657 .30902 L
.61769 .30902 L
.61892 .30902 L
.61961 .30902 L
.62026 .30902 L
.62143 .30902 L
.62268 .30902 L
.62379 .30902 L
.62484 .30902 L
.62597 .30902 L
.62721 .30902 L
.62853 .30902 L
.62978 .30902 L
.63099 .30902 L
.63212 .30902 L
Mistroke
.63281 .30902 L
.63346 .30902 L
.63468 .30902 L
.63598 .30902 L
.63672 .30902 L
.6374 .30902 L
.63846 .30902 L
.6396 .30902 L
.64068 .30902 L
.64166 .30902 L
.6428 .30902 L
.64405 .30902 L
.64523 .30902 L
.64633 .30902 L
.64745 .30902 L
.6485 .30902 L
.64965 .30902 L
.6509 .30902 L
.65576 .30902 L
.66526 .30902 L
.66648 .30902 L
.66776 .30902 L
.66844 .30902 L
.66918 .30902 L
.67048 .30902 L
.67171 .30902 L
.67303 .30902 L
.67427 .30902 L
.67541 .30902 L
.67615 .30902 L
.67684 .30902 L
.6776 .30902 L
.6784 .30902 L
.67917 .30902 L
.67989 .30902 L
.68054 .30902 L
.68124 .30902 L
.68189 .30902 L
.68259 .30902 L
.68332 .30902 L
.68401 .30902 L
.68523 .30902 L
.68654 .30902 L
.68724 .30902 L
.68788 .30902 L
.68858 .30902 L
.68933 .30902 L
.68999 .30902 L
.69069 .30902 L
.69197 .30902 L
Mistroke
.69319 .30902 L
.69431 .30902 L
.69495 .30902 L
.69564 .30902 L
.6969 .30902 L
.6981 .30902 L
.69936 .30902 L
.70002 .30902 L
.70075 .30902 L
.70202 .30902 L
.70322 .30902 L
.70451 .30902 L
.70573 .30902 L
.70684 .30902 L
.70755 .30902 L
.70821 .30902 L
.70893 .30902 L
.7097 .30902 L
.71098 .30902 L
.71172 .30902 L
.7124 .30902 L
.71366 .30902 L
.71431 .30902 L
.71501 .30902 L
.71617 .30902 L
.71745 .30902 L
.71874 .30902 L
.71995 .30902 L
.72104 .30902 L
.72223 .30902 L
.72352 .30902 L
.72417 .30902 L
.72488 .30902 L
.72615 .30902 L
.72733 .30902 L
.72842 .30902 L
.72961 .30902 L
.73073 .30902 L
.73177 .30902 L
.73297 .30902 L
.73426 .30902 L
.73545 .30902 L
.73653 .30902 L
.73774 .30902 L
.73886 .30902 L
.7401 .30902 L
.74142 .30902 L
.74208 .30902 L
.7428 .30902 L
.74411 .30902 L
Mistroke
.74539 .30902 L
.74657 .30902 L
.74769 .30902 L
.74886 .30902 L
.75015 .30902 L
.75133 .30902 L
.75244 .30902 L
.75347 .30902 L
.7546 .30902 L
.7558 .30902 L
.7571 .30902 L
.75832 .30902 L
.75942 .30902 L
.76061 .30902 L
.76124 .30902 L
.76195 .30902 L
.76268 .30902 L
.76336 .30902 L
.76459 .30902 L
.7659 .30902 L
.76662 .30902 L
.76728 .30902 L
.76801 .30902 L
.76878 .30902 L
.76952 .30902 L
.77021 .30902 L
.77151 .30902 L
.77279 .30902 L
.77397 .30902 L
.77526 .30902 L
.77597 .30902 L
.77663 .30902 L
.77786 .30902 L
.7785 .30902 L
.77919 .30902 L
.78034 .30902 L
.78161 .30902 L
.78274 .30902 L
.78395 .30902 L
.7851 .30902 L
.78615 .30902 L
.78744 .30902 L
.78864 .30902 L
.79136 .30902 L
.79633 .30902 L
.81468 .30902 L
.85381 .30902 L
.89538 .30902 L
.93544 .30902 L
.97399 .30902 L
Mistroke
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`03000006Ko06Ko
00<0I_l4<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0003<ol000D0I_lco`0co`0co`0000002C?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool04oooo`004Ooo
o`030000<ol0<ol000<co`0Y06Ko0c?o00030000<ol0<ol002/co`001@1Voc?o03?o03?o0000000`
<ol000<0000co`0co`00;c?o00030000oooooooo02ooool00`000?ooooooo`0Coooo000Aoooo;c?o
01D0I_lL<ol000<0I_lco`0co`00I3?o00030000oooooooo04Goool0017ooom4<ol04P1Vo`Xco`00
0`1Voc?o03?o001T<ol000<0003oooooool0AOooo`004OoooeHco`0;06KoIS?o00030000oooooooo
04Goool0017ooomP<ol000?o09Tco`0co`00I3?o00030000oooooooo04Goool0017ooomP<ol000?o
09Tco`0co`00I3?o00030000oooooooo04Goool0017ooomP<ol000?o09Tco`0co`00I3?o00800016
oooo000AooooH3?o0003o`2I<ol0<ol006@co`000`000?ooooooo`15oooo000AooooH3?o0003o`2I
<ol0<ol006@co`000`000?ooooooo`15oooo000AooooH3?o0003o`2I<ol0<ol006@co`000`000?oo
ooooo`15oooo000AooooH3?o0003o`2I<ol0<ol006@co`000`000?ooooooo`15oooo000AooooH3?o
0003o`2I<ol0<ol006@co`000`000?ooooooo`15oooo000AooooH3?o0003o`2I<ol0<ol006@co`00
0`000?ooooooo`15oooo000AooooH3?o0003o`2I<ol0<ol006@co`000`000?ooooooo`15oooo000A
oooo0P0005hco`000ol0VC?o03?o001T<ol00P0004Koool001?oool20000G3?o0003o`2I<ol0<ol0
06@co`000`000?ooooooo`15oooo000Eoooo0P0005Xco`000ol0VC?o03?o001T<ol000<0003ooooo
ool0AOooo`005oooo`80001H<ol000?o09Tco`0co`00I3?o00030000oooooooo04Goool001Woool2
0000ES?o0003o`2I<ol0<ol006@co`000`000?ooooooo`15oooo000Koooo0P0005@co`000ol0VC?o
03?o001T<ol000<0003oooooool0AOooo`007Oooo`80001B<ol000?o09Tco`0co`00I3?o00030000
oooooooo04Goool001ooool00`0003?o03?o001?<ol000?o09Tco`0co`00I3?o00030000oooooooo
04Goool0023oool00`0003?o03?o001><ol000?o09Tco`0co`00I3?o00800016oooo000Qoooo0P00
04hco`000ol0VC?o03?o001T<ol000<0003oooooool0AOooo`008oooo`030000<ol0<ol004/co`00
0ol0VC?o03?o001T<ol000<0003oooooool0AOooo`009?ooo`80001;<ol000?o09Tco`0co`00I3?o
00030000oooooooo04Goool002Koool00`0003?o03?o0018<ol000?o09Tco`0co`00I3?o00030000
oooooooo04Goool002Ooool00`0003?o03?o0017<ol000?o09Tco`0co`00I3?o00030000oooooooo
04Goool002Soool00`0003?o03?o0016<ol000?o09Tco`0co`00Bc?o00800004<ol00P0000@co`02
00000c?o00@00004<ol000<0003oooooool0AOooo`00:Oooo`030000<ol0<ol004Dco`000ol0VC?o
03?o001:<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000<0000co`0co`001C?o
00030000oooooooo04Goool002[oool00`0003?o03?o0014<ol000?o09Tco`0co`00BS?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0<ol000@co`030000AOooo`00:ooo
o`800014<ol000?o09Tco`0co`00BS?o00040000<ol0<ol0000023?o00040000<ol0<ol0000013?o
00030000<ol0<ol000<co`000`000?ooooooo`15oooo000]oooo00<0000co`0co`00@C?o0003o`2I
<ol0<ol004Xco`00100003?o03?o000000Pco`00100003?o03?o0000008co`00100003?o03?o0000
00@co`000`000?ooooooo`15oooo000^oooo00<0000co`0co`00@3?o0003o`2I<ol0<ol004/co`02
00002S?o00800004<ol00P0000Dco`000`000?ooooooo`15oooo000_oooo00<0000co`0co`00?c?o
0003o`2I<ol0<ol006@co`000`000?ooooooo`15oooo000`oooo00<0000co`0co`00?S?o0003o`2I
<ol0<ol006@co`000`000?ooooooo`15oooo000aoooo00<0000co`0co`00?C?o0003o`2I<ol0<ol0
06@co`000`000?ooooooo`15oooo000boooo00<0000co`0co`00?3?o0003o`2I<ol0<ol006@co`00
0`000?ooooooo`15oooo000coooo00<0000co`0co`00>c?o0003o`2I<ol0<ol006@co`020000A_oo
o`00<oooo`030000<ol0<ol003/co`000ol0VC?o03?o001T<ol000<0003oooooool0AOooo`00=?oo
o`030000<ol0<ol003Xco`000ol0VC?o03?o001T<ol000<0003oooooool0AOooo`00=Oooo`030000
<ol0<ol003Tco`000ol0VC?o03?o001T<ol000<0003oooooool0AOooo`00=_ooo`030000<ol0<ol0
03Pco`000ol0VC?o03?o001T<ol000<0003oooooool0AOooo`00=oooo`030000<ol0<ol003Lco`00
0ol0VC?o03?o001T<ol000<0003oooooool0AOooo`00>?ooo`030000<ol0<ol003Hco`000ol0VC?o
03?o001T<ol000<0003oooooool0AOooo`00>?ooo`030000<ol0<ol003Hco`000ol0VC?o03?o001T
<ol000<0003oooooool0AOooo`00>Oooo`030000<ol0<ol003Dco`000ol0VC?o03?o001T<ol00P00
04Koool003[oool00`0003?o03?o000d<ol000?o09Tco`0co`00I3?o00030000oooooooo04Goool0
03_oool00`0003?o03?o000c<ol000?o09Tco`0co`00I3?o00030000oooooooo04Goool003coool0
0`0003?o03?o000b<ol000?o09Tco`0co`00I3?o00030000oooooooo04Goool003coool00`0003?o
03?o000b<ol000?o09Tco`0co`00I3?o00030000oooooooo04Goool003goool00`0003?o03?o000a
<ol000?o09Tco`0co`00I3?o00030000oooooooo04Goool003goool00`0003?o03?o000a<ol000?o
09Tco`0co`00I3?o00030000oooooooo04Goool003koool00`0003?o03?o000`<ol000?o09Tco`0c
o`00I3?o00030000oooooooo04Goool003koool00`0003?o03?o000`<ol000?o09Tco`0co`00I3?o
00030000oooooooo04Goool003ooool00`0003?o03?o000_<ol000?o09Tco`0co`00I3?o00800016
oooo000ooooo00<0000co`0co`00;c?o0003o`2I<ol0<ol006@co`000`000?ooooooo`15oooo0010
oooo00<0000co`0co`00;S?o0003o`2I<ol0<ol006@co`000`000?ooooooo`15oooo0011oooo00<0
000co`0co`00;C?o0003o`2I<ol0<ol006@co`000`000?ooooooo`15oooo0011oooo00<0000co`0c
o`00;C?o0003o`2I<ol0<ol006@co`000`000?ooooooo`15oooo0012oooo00<0000co`0co`00;3?o
0003o`2I<ol0<ol006@co`000`000?ooooooo`15oooo0012oooo00<0000co`0co`00;3?o0003o`2I
<ol0<ol004/co`02000013?o00800004<ol00P0000Dco`0300000c?o00030000oooooooo04Goool0
04?oool00`0003?o03?o000[<ol000?o09Tco`0co`00BS?o00040000<ol0<ol0000023?o00040000
<ol0<ol000001C?o00030000<ol0<ol0008co`000`000?ooooooo`15oooo0013oooo00<0000co`0c
o`00:c?o0003o`2I<ol0<ol004Xco`00100003?o03?o000000Pco`00100003?o03?o0000008co`05
00000c?o00<00015oooo0014oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol004Xco`00100003?o
03?o000000Pco`00100003?o03?o0000008co`00100003?o03?o000000@co`000`000?ooooooo`15
oooo0014oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol004Xco`00100003?o03?o000000Pco`00
100003?o03?o000000<co`000`0003?o00000004<ol000<0003oooooool0AOooo`00AOooo`030000
<ol0<ol002Tco`000ol0VC?o03?o001;<ol00P0000Xco`0200001C?o00800004<ol000<0003ooooo
ool0AOooo`00AOooo`030000<ol0<ol002Tco`000ol0VC?o03?o001T<ol000<0003oooooool0AOoo
o`00A_ooo`030000<ol0<ol002Pco`000ol0VC?o03?o001T<ol000<0003oooooool0AOooo`00A_oo
o`030000<ol0<ol002Pco`000ol0VC?o03?o001T<ol000<0003oooooool0AOooo`00Aoooo`030000
<ol0<ol002Lco`000ol0VC?o03?o001T<ol000<0003oooooool0AOooo`00Aoooo`030000<ol0<ol0
02Lco`000ol0VC?o03?o001T<ol00P0004Koool004Soool00`0003?o03?o000V<ol000?o09Tco`0c
o`00I3?o00030000oooooooo04Goool004Soool00`0003?o03?o000V<ol000?o09Tco`0co`00I3?o
00030000oooooooo04Goool004Woool00`0003?o03?o000U<ol000?o09Tco`0co`00I3?o00030000
oooooooo04Goool004Woool00`0003?o03?o000U<ol000?o09Tco`0co`00I3?o00030000oooooooo
04Goool004[oool00`0003?o03?o000T<ol000?o09Tco`0co`00I3?o00030000oooooooo04Goool0
04[oool00`0003?o03?o000T<ol000?o09Tco`0co`00I3?o00030000oooooooo04Goool004_oool0
0`0003?o03?o000S<ol000?o09Tco`0co`00I3?o00030000oooooooo04Goool004_oool00`0003?o
03?o000S<ol000?o09Tco`0co`00I3?o00800016oooo001<ooooS3?o04Soool004cooon<<ol0B?oo
o`00C?oooh`co`18oooo001=ooooRc?o04Soool004gooon;<ol0B?ooo`00C_ooobHco`000`0003?o
03?o000_<ol000<0000co`0co`00;c?o04Soool004kooolU<ol000<0000co`0co`0023?o00030000
<ol0<ol002Hco`000`0003?o03?o000^<ol0B?ooo`00Coooob@co`000`0003?o03?o0002<ol00P00
00@co`000`0003?o03?o000><ol00P0000@co`02000013?o00800005<ol00`00008co`000`0003?o
03?o000^<ol0B?ooo`00Coooob@co`001@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o
00030000<ol0<ol000Dco`0400000c?o00040000<ol0<ol0000023?o00040000<ol0<ol000001C?o
00050000<ol0<ol0<ol00000030co`18oooo001?oooo8c?o00030000<ol0<ol0008co`000`0003?o
03?o000D<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol01@0000<co`000`0003?o
03?o000]<ol0B?ooo`00D?ooob<co`000`0003?o03?o000500004c?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000S?o00040000<ol0<ol000000c?o00030000<ol0<ol002hco`18oooo001@
oooo8c?o00050000<ol0<ol0<ol0000001Hco`00100003?o03?o000000Pco`00100003?o03?o0000
00<co`000`0003?o00000003<ol000<0000co`0co`00;S?o04Soool0053ooolT<ol000<0000co`0c
o`0063?o0080000:<ol00P0000Dco`0200000S?o00030000<ol0<ol002lco`18oooo001AooooQc?o
04Soool0057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.03) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.36136 .30902 L
.37176 .30902 L
.3815 .30902 L
.3864 .30902 L
.38881 .30902 L
.39106 .30902 L
.3923 .30902 L
.39299 .30902 L
s
.39299 .30902 m
.393 .61803 L
s
0 .4 1 r
.02381 .31271 m
.06244 .31329 L
.10458 .31401 L
.14415 .3148 L
.18221 .31568 L
.22272 .31677 L
.26171 .31799 L
.30316 .31949 L
.34309 .32118 L
.36136 .32205 L
.37176 .32257 L
.3815 .32308 L
.3864 .32334 L
.38881 .32347 L
.39106 .3236 L
.3923 .32367 L
.39299 .3237 L
.39362 .30902 L
.39432 .30902 L
.39507 .30902 L
.39577 .30902 L
.39642 .30902 L
.39756 .30902 L
.39881 .30902 L
.40012 .30902 L
.40134 .30902 L
.40264 .30902 L
.40333 .30902 L
.40406 .30902 L
.4047 .30902 L
.4054 .30902 L
.40665 .30902 L
.40785 .30902 L
.40914 .30902 L
.41036 .30902 L
.41149 .30902 L
.4128 .30902 L
.41402 .30902 L
.41472 .30902 L
.41536 .30902 L
.41609 .30902 L
.41679 .30902 L
.41746 .30902 L
.41818 .30902 L
.41946 .30902 L
.42018 .30902 L
.42085 .30902 L
.42158 .30902 L
.42237 .30902 L
.42305 .30902 L
Mistroke
.4237 .30902 L
.42491 .30902 L
.42621 .30902 L
.42695 .30902 L
.42762 .30902 L
.42875 .30902 L
.42999 .30902 L
.43129 .30902 L
.4325 .30902 L
.43318 .30902 L
.43393 .30902 L
.43464 .30902 L
.43529 .30902 L
.43652 .30902 L
.43783 .30902 L
.43851 .30902 L
.43923 .30902 L
.44055 .30902 L
.44131 .30902 L
.44211 .30902 L
.44279 .30902 L
.44354 .30902 L
.44419 .30902 L
.4449 .30902 L
.44618 .30902 L
.44743 .30902 L
.44858 .30902 L
.44983 .30902 L
.45054 .30902 L
.4512 .30902 L
.45189 .30902 L
.45253 .30902 L
.45326 .30902 L
.45396 .30902 L
.45513 .30902 L
.45637 .30902 L
.45743 .30902 L
.4586 .30902 L
.45985 .30902 L
.46055 .30902 L
.4612 .30902 L
.46239 .30902 L
.46364 .30902 L
.46487 .30902 L
.46557 .30902 L
.46621 .30902 L
.46739 .30902 L
.46863 .30902 L
.46975 .30902 L
.47079 .30902 L
Mistroke
.47194 .30902 L
.47317 .30902 L
.47448 .30902 L
.47521 .30902 L
.4759 .30902 L
.4766 .30902 L
.47726 .30902 L
.47849 .30902 L
.47972 .30902 L
.48085 .30902 L
.48206 .30902 L
.48336 .30902 L
.48442 .30902 L
.48556 .30902 L
.48664 .30902 L
.48762 .30902 L
.48877 .30902 L
.49002 .30902 L
.4912 .30902 L
.49229 .30902 L
.49341 .30902 L
.49446 .30902 L
.49562 .30902 L
.49686 .30902 L
.4981 .30902 L
.4994 .30902 L
.50051 .30902 L
.50172 .30902 L
.50304 .30902 L
.50426 .30902 L
.5049 .30902 L
.5056 .30902 L
.50633 .30902 L
.50701 .30902 L
.50827 .30902 L
.50942 .30902 L
.51005 .30902 L
.51074 .30902 L
.512 .30902 L
.51324 .30902 L
.51435 .30902 L
.51564 .30902 L
.51685 .30902 L
.51798 .30902 L
.51901 .30902 L
.52015 .30902 L
.52134 .30902 L
.52265 .30902 L
.52384 .30902 L
.5245 .30902 L
Mistroke
.52522 .30902 L
.52652 .30902 L
.52774 .30902 L
.52903 .30902 L
.53013 .30902 L
.53134 .30902 L
.53207 .30902 L
.53277 .30902 L
.53407 .30902 L
.53479 .30902 L
.53547 .30902 L
.53621 .30902 L
.537 .30902 L
.53769 .30902 L
.53843 .30902 L
.53913 .30902 L
.53978 .30902 L
.541 .30902 L
.5423 .30902 L
.54352 .30902 L
.54421 .30902 L
.54484 .30902 L
.54601 .30902 L
.54725 .30902 L
.54831 .30902 L
.54943 .30902 L
.55065 .30902 L
.55177 .30902 L
.55296 .30902 L
.55426 .30902 L
.55547 .30902 L
.5566 .30902 L
.55729 .30902 L
.55795 .30902 L
.55917 .30902 L
.5605 .30902 L
.56124 .30902 L
.56193 .30902 L
.56298 .30902 L
.56412 .30902 L
.56519 .30902 L
.56617 .30902 L
.56731 .30902 L
.56856 .30902 L
.56974 .30902 L
.57083 .30902 L
.57206 .30902 L
.57323 .30902 L
.57427 .30902 L
.5754 .30902 L
Mistroke
.57663 .30902 L
.57793 .30902 L
.57904 .30902 L
.58026 .30902 L
.58157 .30902 L
.58278 .30902 L
.58341 .30902 L
.5841 .30902 L
.58483 .30902 L
.58551 .30902 L
.58676 .30902 L
.58791 .30902 L
.58916 .30902 L
.59048 .30902 L
.5916 .30902 L
.59279 .30902 L
.59382 .30902 L
.59493 .30902 L
.59625 .30902 L
.59748 .30902 L
.59869 .30902 L
.5998 .30902 L
.60101 .30902 L
.6023 .30902 L
.60353 .30902 L
.60464 .30902 L
.60595 .30902 L
.60669 .30902 L
.60738 .30902 L
.60863 .30902 L
.60927 .30902 L
.60997 .30902 L
.61064 .30902 L
.61136 .30902 L
.61263 .30902 L
.61551 .30902 L
.61671 .30902 L
.618 .30902 L
.61874 .30902 L
.61941 .30902 L
.62072 .30902 L
.62191 .30902 L
.62302 .30902 L
.62424 .30902 L
.62556 .30902 L
.62621 .30902 L
.62693 .30902 L
.62823 .30902 L
.63068 .30902 L
.63187 .30902 L
Mistroke
.63299 .30902 L
.63428 .30902 L
.63545 .30902 L
.63656 .30902 L
.63758 .30902 L
.63869 .30902 L
.63988 .30902 L
.64117 .30902 L
.64235 .30902 L
.645 .30902 L
.64621 .30902 L
.64749 .30902 L
.64858 .30902 L
.64978 .30902 L
.65045 .30902 L
.65117 .30902 L
.65246 .30902 L
.6532 .30902 L
.65398 .30902 L
.65464 .30902 L
.65537 .30902 L
.65606 .30902 L
.6567 .30902 L
.65742 .30902 L
.65811 .30902 L
.65934 .30902 L
.66066 .30902 L
.66191 .30902 L
.66305 .30902 L
.6642 .30902 L
.66529 .30902 L
.66656 .30902 L
.66773 .30902 L
.66902 .30902 L
.66973 .30902 L
.67039 .30902 L
.67104 .30902 L
.67172 .30902 L
.67247 .30902 L
.67317 .30902 L
.67442 .30902 L
.67508 .30902 L
.67579 .30902 L
.6771 .30902 L
.67835 .30902 L
.67947 .30902 L
.68068 .30902 L
.68182 .30902 L
.68289 .30902 L
.68407 .30902 L
Mistroke
.68533 .30902 L
.68666 .30902 L
.68791 .30902 L
.68904 .30902 L
.69027 .30902 L
.69144 .30902 L
.6925 .30902 L
.69372 .30902 L
.69487 .30902 L
.69593 .30902 L
.69692 .30902 L
.69799 .30902 L
.69913 .30902 L
.70035 .30902 L
.70104 .30902 L
.70168 .30902 L
.70284 .30902 L
.70408 .30902 L
.70512 .30902 L
.70623 .30902 L
.70745 .30902 L
.7086 .30902 L
.70983 .30902 L
.71053 .30902 L
.71118 .30902 L
.71249 .30902 L
.71323 .30902 L
.7139 .30902 L
.71509 .30902 L
.71639 .30902 L
.71762 .30902 L
.71875 .30902 L
.71981 .30902 L
.72094 .30902 L
.72192 .30902 L
.72299 .30902 L
.72424 .30902 L
.72543 .30902 L
.72658 .30902 L
.72765 .30902 L
.72889 .30902 L
.73005 .30902 L
.73222 .30902 L
.73708 .30902 L
.73824 .30902 L
.73933 .30902 L
.74059 .30902 L
.74174 .30902 L
.74301 .30902 L
.74373 .30902 L
Mistroke
.74439 .30902 L
.74559 .30902 L
.74686 .30902 L
.74808 .30902 L
.74939 .30902 L
.75063 .30902 L
.75177 .30902 L
.75303 .30902 L
.75375 .30902 L
.7544 .30902 L
.7551 .30902 L
.75584 .30902 L
.75653 .30902 L
.75718 .30902 L
.75825 .30902 L
.75942 .30902 L
.76065 .30902 L
.7618 .30902 L
.76287 .30902 L
.76385 .30902 L
.76498 .30902 L
.76605 .30902 L
.76721 .30902 L
.76844 .30902 L
.7696 .30902 L
.77065 .30902 L
.77189 .30902 L
.77259 .30902 L
.77323 .30902 L
.77441 .30902 L
.77566 .30902 L
.77689 .30902 L
.77758 .30902 L
.77822 .30902 L
.7794 .30902 L
.78064 .30902 L
.78176 .30902 L
.7828 .30902 L
.78394 .30902 L
.78518 .30902 L
.78648 .30902 L
.78722 .30902 L
.7879 .30902 L
.79049 .30902 L
.79536 .30902 L
.81371 .30902 L
.85284 .30902 L
.89441 .30902 L
.93448 .30902 L
.97302 .30902 L
Mistroke
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.03) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`03000006Ko06Ko
00L0I_l00`00001Vo`1Vo`0706Ko00<00000I_l0I_l0101Vo`<co`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0004<ol000@0I_lco`0co`000009<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0
000co`0co`0063?o01L0I_l00`00001Vo`1Vo`0?06Ko7C?o000406Ko<ol0<ol00000<3?o00030000
<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Ooood@co`0B06Ko2c?o
000306Ko<ol0<ol006<co`000`000?ooooooo`15oooo000AooooES?o00`0I_mU<ol000<0003ooooo
ool0AOooo`004Oooof4co`000ol0VC?o03?o001S<ol000<0003oooooool0AOooo`004Oooof4co`00
0ol0VC?o03?o001S<ol000<0003oooooool0AOooo`004Oooof4co`000ol0VC?o03?o001S<ol000<0
003oooooool0AOooo`004Oooof4co`000ol0VC?o03?o001S<ol00P0004Koool0017ooomQ<ol000?o
09Tco`0co`00Hc?o00030000oooooooo04Goool0017ooomQ<ol000?o09Tco`0co`00Hc?o00030000
oooooooo04Goool0017ooomQ<ol000?o09Tco`0co`00Hc?o00030000oooooooo04Goool0017ooomQ
<ol000?o09Tco`0co`00Hc?o00030000oooooooo04Goool0017ooomQ<ol000?o09Tco`0co`00Hc?o
00030000oooooooo04Goool0017ooomQ<ol000?o09Tco`0co`00Hc?o00030000oooooooo04Goool0
017ooomQ<ol000?o09Tco`0co`00Hc?o00030000oooooooo04Goool0017oool20000Gc?o0003o`2I
<ol0<ol006<co`020000A_ooo`004oooo`80001M<ol000?o09Tco`0co`00Hc?o00030000oooooooo
04Goool001Goool20000Fc?o0003o`2I<ol0<ol006<co`000`000?ooooooo`15oooo000Goooo0P00
05Tco`000ol0VC?o03?o001S<ol000<0003oooooool0AOooo`006Oooo`80001G<ol000?o09Tco`0c
o`00Hc?o00030000oooooooo04Goool001_oool20000EC?o0003o`2I<ol0<ol006<co`000`000?oo
ooooo`15oooo000Moooo0P0005<co`000ol0VC?o03?o001S<ol000<0003oooooool0AOooo`007ooo
o`030000<ol0<ol0050co`000ol0VC?o03?o001S<ol000<0003oooooool0AOooo`008?ooo`030000
<ol0<ol004lco`000ol0VC?o03?o001S<ol00P0004Koool0027oool20000Cc?o0003o`2I<ol0<ol0
06<co`000`000?ooooooo`15oooo000Soooo00<0000co`0co`00C3?o0003o`2I<ol0<ol006<co`00
0`000?ooooooo`15oooo000Toooo0P0004`co`000ol0VC?o03?o001S<ol000<0003oooooool0AOoo
o`009_ooo`030000<ol0<ol004Tco`000ol0VC?o03?o001S<ol000<0003oooooool0AOooo`009ooo
o`030000<ol0<ol004Pco`000ol0VC?o03?o001S<ol000<0003oooooool0AOooo`00:?ooo`030000
<ol0<ol004Lco`000ol0VC?o03?o001:<ol00P0000@co`02000013?o00800003<ol0100000@co`00
0`000?ooooooo`15oooo000Yoooo00<0000co`0co`00AS?o0003o`2I<ol0<ol004Tco`00100003?o
03?o000000Pco`00100003?o03?o0000008co`000`0003?o03?o0005<ol000<0003oooooool0AOoo
o`00:_ooo`030000<ol0<ol004Dco`000ol0VC?o03?o0019<ol000@0000co`0co`000008<ol000@0
000co`0co`000003<ol000<0000co`0co`0013?o00<00015oooo000[oooo0P0004Dco`000ol0VC?o
03?o0019<ol000@0000co`0co`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o
00030000oooooooo04Goool002goool00`0003?o03?o0012<ol000?o09Tco`0co`00BC?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo
04Goool002koool00`0003?o03?o0011<ol000?o09Tco`0co`00BS?o0080000:<ol00P0000@co`02
00001C?o00030000oooooooo04Goool002ooool00`0003?o03?o0010<ol000?o09Tco`0co`00Hc?o
00030000oooooooo04Goool0033oool00`0003?o03?o000o<ol000?o09Tco`0co`00Hc?o00030000
oooooooo04Goool0037oool00`0003?o03?o000n<ol000?o09Tco`0co`00Hc?o00030000oooooooo
04Goool003;oool00`0003?o03?o000m<ol000?o09Tco`0co`00Hc?o00030000oooooooo04Goool0
03?oool00`0003?o03?o000l<ol000?o09Tco`0co`00Hc?o00800016oooo000coooo00<0000co`0c
o`00?3?o0003o`2I<ol0<ol006<co`000`000?ooooooo`15oooo000doooo00<0000co`0co`00>c?o
0003o`2I<ol0<ol006<co`000`000?ooooooo`15oooo000eoooo00<0000co`0co`00>S?o0003o`2I
<ol0<ol006<co`000`000?ooooooo`15oooo000foooo00<0000co`0co`00>C?o0003o`2I<ol0<ol0
06<co`000`000?ooooooo`15oooo000goooo00<0000co`0co`00>3?o0003o`2I<ol0<ol006<co`00
0`000?ooooooo`15oooo000hoooo00<0000co`0co`00=c?o0003o`2I<ol0<ol006<co`000`000?oo
ooooo`15oooo000hoooo00<0000co`0co`00=c?o0003o`2I<ol0<ol006<co`000`000?ooooooo`15
oooo000ioooo00<0000co`0co`00=S?o0003o`2I<ol0<ol006<co`020000A_ooo`00>_ooo`030000
<ol0<ol003Dco`000ol0VC?o03?o001S<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol0
03@co`000ol0VC?o03?o001S<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol003<co`00
0ol0VC?o03?o001S<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol003<co`000ol0VC?o
03?o001S<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol0038co`000ol0VC?o03?o001S
<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol0038co`000ol0VC?o03?o001S<ol000<0
003oooooool0AOooo`00?_ooo`030000<ol0<ol0034co`000ol0VC?o03?o001S<ol000<0003ooooo
ool0AOooo`00?_ooo`030000<ol0<ol0034co`000ol0VC?o03?o001S<ol000<0003oooooool0AOoo
o`00?oooo`030000<ol0<ol0030co`000ol0VC?o03?o001S<ol00P0004Koool003ooool00`0003?o
03?o000`<ol000?o09Tco`0co`00Hc?o00030000oooooooo04Goool0043oool00`0003?o03?o000_
<ol000?o09Tco`0co`00Hc?o00030000oooooooo04Goool0047oool00`0003?o03?o000^<ol000?o
09Tco`0co`00Hc?o00030000oooooooo04Goool0047oool00`0003?o03?o000^<ol000?o09Tco`0c
o`00Hc?o00030000oooooooo04Goool004;oool00`0003?o03?o000]<ol000?o09Tco`0co`00Hc?o
00030000oooooooo04Goool004;oool00`0003?o03?o000]<ol000?o09Tco`0co`00BS?o00800004
<ol00P0000@co`0200001C?o00<00003<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol0
02`co`000ol0VC?o03?o0019<ol000@0000co`0co`000008<ol000@0000co`0co`000005<ol000<0
000co`0co`000S?o00030000oooooooo04Goool004?oool00`0003?o03?o000/<ol000?o09Tco`0c
o`00BC?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00D00003<ol00`0004Goool0
04Coool00`0003?o03?o000[<ol000?o09Tco`0co`00BC?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool004Coool00`0003?o
03?o000[<ol000?o09Tco`0co`00BC?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o
00030000<ol0000000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`00:S?o0003o`2I
<ol0<ol004Xco`0200002S?o00800005<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0
000co`0co`00:S?o0003o`2I<ol0<ol006<co`000`000?ooooooo`15oooo0016oooo00<0000co`0c
o`00:C?o0003o`2I<ol0<ol006<co`000`000?ooooooo`15oooo0016oooo00<0000co`0co`00:C?o
0003o`2I<ol0<ol006<co`000`000?ooooooo`15oooo0017oooo00<0000co`0co`00:3?o0003o`2I
<ol0<ol006<co`000`000?ooooooo`15oooo0017oooo00<0000co`0co`00:3?o0003o`2I<ol0<ol0
06<co`020000A_ooo`00B?ooo`030000<ol0<ol002Lco`000ol0VC?o03?o001S<ol000<0003ooooo
ool0AOooo`00B?ooo`030000<ol0<ol002Lco`000ol0VC?o03?o001S<ol000<0003oooooool0AOoo
o`00BOooo`030000<ol0<ol002Hco`000ol0VC?o03?o001S<ol000<0003oooooool0AOooo`00BOoo
o`030000<ol0<ol002Hco`000ol0VC?o03?o001S<ol000<0003oooooool0AOooo`00B_ooo`030000
<ol0<ol002Dco`000ol0VC?o03?o001S<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol0
02Dco`000ol0VC?o03?o001S<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol002@co`00
0ol0VC?o03?o001S<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol002@co`000ol0VC?o
03?o001S<ol00P0004Koool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool0
04gooon;<ol0B?ooo`00COoooh/co`18oooo001>oooo9S?o00030000<ol0<ol002lco`000`0003?o
03?o000_<ol0B?ooo`00C_ooobDco`000`0003?o03?o0008<ol000<0000co`0co`009S?o00030000
<ol0<ol002hco`18oooo001?oooo93?o00030000<ol0<ol0008co`02000013?o00030000<ol0<ol0
00hco`02000013?o00800004<ol00P0000@co`02000013?o00030000<ol0<ol002hco`18oooo001?
oooo93?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0000co`0co`001C?o
00@00003<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000003
<ol000<0000co`0co`00;S?o04Soool004oooolS<ol000<0000co`0co`000S?o00030000<ol0<ol0
01@co`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`0003?o03?o0003<ol000<0
000co`0co`00;C?o04Soool0053ooolS<ol000<0000co`0co`001@0001<co`00100003?o03?o0000
00Pco`00100003?o03?o000000Dco`001@0003?o03?o03?o0000000`<ol0B?ooo`00D?ooob<co`00
1@0003?o03?o03?o0000000F<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0
000co`0co`000003<ol000<0000co`0co`00;S?o04Soool0053ooolT<ol000<0000co`0co`0063?o
0080000:<ol00P0000@co`0200000c?o00030000<ol0<ol002lco`18oooo001AooooQc?o04Soool0
057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.36136 .30902 L
.37176 .30902 L
.3815 .30902 L
.39106 .30902 L
.39381 .30902 L
.39516 .30902 L
.39642 .30902 L
s
.39642 .30902 m
.39643 .61803 L
s
0 .4 1 r
.02381 .31148 m
.06244 .31186 L
.10458 .31235 L
.14415 .31287 L
.18221 .31346 L
.22272 .31419 L
.26171 .315 L
.30316 .316 L
.34309 .31713 L
.36136 .31771 L
.37176 .31805 L
.3815 .31839 L
.39106 .31874 L
.39381 .31884 L
.39516 .31889 L
.39642 .31893 L
.39756 .30902 L
.39877 .30902 L
.39947 .30902 L
.40012 .30902 L
.40134 .30902 L
.40197 .30902 L
.40266 .30902 L
.40389 .30902 L
.40518 .30902 L
.40592 .30902 L
.4066 .30902 L
.40779 .30902 L
.40908 .30902 L
.41031 .30902 L
.41144 .30902 L
.41274 .30902 L
.41396 .30902 L
.41465 .30902 L
.41529 .30902 L
.416 .30902 L
.41674 .30902 L
.41741 .30902 L
.41813 .30902 L
.41942 .30902 L
.42022 .30902 L
.42097 .30902 L
.42164 .30902 L
.42237 .30902 L
.4236 .30902 L
.42472 .30902 L
.42602 .30902 L
.42726 .30902 L
.42839 .30902 L
.42944 .30902 L
Mistroke
.43059 .30902 L
.43183 .30902 L
.43254 .30902 L
.43319 .30902 L
.43448 .30902 L
.43564 .30902 L
.43687 .30902 L
.43751 .30902 L
.4382 .30902 L
.43943 .30902 L
.44019 .30902 L
.4409 .30902 L
.44154 .30902 L
.44224 .30902 L
.44354 .30902 L
.44477 .30902 L
.44547 .30902 L
.44611 .30902 L
.44681 .30902 L
.44755 .30902 L
.44885 .30902 L
.44958 .30902 L
.45024 .30902 L
.45102 .30902 L
.45176 .30902 L
.45244 .30902 L
.45318 .30902 L
.4545 .30902 L
.45574 .30902 L
.45702 .30902 L
.45771 .30902 L
.45844 .30902 L
.45974 .30902 L
.46097 .30902 L
.46208 .30902 L
.46328 .30902 L
.4645 .30902 L
.46561 .30902 L
.46683 .30902 L
.46812 .30902 L
.46925 .30902 L
.47029 .30902 L
.47144 .30902 L
.47267 .30902 L
.47332 .30902 L
.47401 .30902 L
.47476 .30902 L
.47546 .30902 L
.47672 .30902 L
.47743 .30902 L
Mistroke
.4781 .30902 L
.47934 .30902 L
.48048 .30902 L
.48179 .30902 L
.48303 .30902 L
.48372 .30902 L
.48436 .30902 L
.48556 .30902 L
.48685 .30902 L
.48758 .30902 L
.48824 .30902 L
.48946 .30902 L
.4906 .30902 L
.49178 .30902 L
.49308 .30902 L
.49376 .30902 L
.4945 .30902 L
.49515 .30902 L
.49585 .30902 L
.49716 .30902 L
.49837 .30902 L
.49966 .30902 L
.50039 .30902 L
.50106 .30902 L
.50181 .30902 L
.5026 .30902 L
.50328 .30902 L
.50403 .30902 L
.50536 .30902 L
.50657 .30902 L
.50721 .30902 L
.50791 .30902 L
.50864 .30902 L
.50933 .30902 L
.51058 .30902 L
.51173 .30902 L
.51237 .30902 L
.51306 .30902 L
.51432 .30902 L
.51555 .30902 L
.51667 .30902 L
.51796 .30902 L
.51917 .30902 L
.52029 .30902 L
.52133 .30902 L
.52246 .30902 L
.52366 .30902 L
.52497 .30902 L
.52616 .30902 L
.52682 .30902 L
Mistroke
.52754 .30902 L
.52884 .30902 L
.53005 .30902 L
.53134 .30902 L
.53245 .30902 L
.53366 .30902 L
.53439 .30902 L
.53508 .30902 L
.53638 .30902 L
.53711 .30902 L
.53778 .30902 L
.53853 .30902 L
.53932 .30902 L
.54 .30902 L
.54075 .30902 L
.54145 .30902 L
.54209 .30902 L
.54332 .30902 L
.54462 .30902 L
.54583 .30902 L
.54652 .30902 L
.54716 .30902 L
.54833 .30902 L
.54957 .30902 L
.55068 .30902 L
.55172 .30902 L
.55286 .30902 L
.55409 .30902 L
.55532 .30902 L
.55602 .30902 L
.55667 .30902 L
.55798 .30902 L
.55872 .30902 L
.55938 .30902 L
.56058 .30902 L
.56188 .30902 L
.56311 .30902 L
.56424 .30902 L
.5653 .30902 L
.56643 .30902 L
.5675 .30902 L
.56848 .30902 L
.56963 .30902 L
.57087 .30902 L
.57205 .30902 L
.57315 .30902 L
.57438 .30902 L
.57554 .30902 L
.57659 .30902 L
.57771 .30902 L
Mistroke
.57894 .30902 L
.58025 .30902 L
.58136 .30902 L
.58257 .30902 L
.58388 .30902 L
.58509 .30902 L
.58572 .30902 L
.58642 .30902 L
.58715 .30902 L
.58783 .30902 L
.58908 .30902 L
.59022 .30902 L
.5928 .30902 L
.59394 .30902 L
.59515 .30902 L
.5963 .30902 L
.59734 .30902 L
.59962 .30902 L
.6009 .30902 L
.60211 .30902 L
.60332 .30902 L
.60401 .30902 L
.60466 .30902 L
.60595 .30902 L
.60668 .30902 L
.60734 .30902 L
.60853 .30902 L
.60982 .30902 L
.61103 .30902 L
.61216 .30902 L
.61345 .30902 L
.61466 .30902 L
.61536 .30902 L
.616 .30902 L
.61743 .30902 L
.62304 .30902 L
.6242 .30902 L
.62547 .30902 L
.62666 .30902 L
.62777 .30902 L
.62905 .30902 L
.62975 .30902 L
.63041 .30902 L
.63156 .30902 L
.63282 .30902 L
.634 .30902 L
.63511 .30902 L
.63612 .30902 L
.63721 .30902 L
.63839 .30902 L
Mistroke
.63966 .30902 L
.64085 .30902 L
.64193 .30902 L
.64323 .30902 L
.64388 .30902 L
.6446 .30902 L
.64586 .30902 L
.64705 .30902 L
.64777 .30902 L
.64845 .30902 L
.64972 .30902 L
.65043 .30902 L
.65109 .30902 L
.65182 .30902 L
.65258 .30902 L
.65377 .30902 L
.65504 .30902 L
.65625 .30902 L
.65735 .30902 L
.65858 .30902 L
.65927 .30902 L
.65992 .30902 L
.66122 .30902 L
.66262 .30902 L
.66385 .30902 L
.66455 .30902 L
.66521 .30902 L
.66653 .30902 L
.66727 .30902 L
.66795 .30902 L
.66916 .30902 L
.67047 .30902 L
.67171 .30902 L
.67286 .30902 L
.67356 .30902 L
.67432 .30902 L
.67503 .30902 L
.67569 .30902 L
.67693 .30902 L
.67824 .30902 L
.67893 .30902 L
.67966 .30902 L
.68098 .30902 L
.68178 .30902 L
.68254 .30902 L
.68323 .30902 L
.68397 .30902 L
.68522 .30902 L
.68639 .30902 L
.68767 .30902 L
Mistroke
.68839 .30902 L
.68905 .30902 L
.69037 .30902 L
.69112 .30902 L
.69182 .30902 L
.69309 .30902 L
.6938 .30902 L
.69445 .30902 L
.69569 .30902 L
.69684 .30902 L
.6981 .30902 L
.69873 .30902 L
.69943 .30902 L
.7006 .30902 L
.70186 .30902 L
.70304 .30902 L
.70412 .30902 L
.7053 .30902 L
.7064 .30902 L
.70762 .30902 L
.70892 .30902 L
.71022 .30902 L
.71158 .30902 L
.71276 .30902 L
.71402 .30902 L
.71521 .30902 L
.71629 .30902 L
.71738 .30902 L
.7184 .30902 L
.7196 .30902 L
.7207 .30902 L
.72191 .30902 L
.72319 .30902 L
.72448 .30902 L
.72565 .30902 L
.7263 .30902 L
.72701 .30902 L
.72829 .30902 L
.72949 .30902 L
.73077 .30902 L
.73198 .30902 L
.73307 .30902 L
.73375 .30902 L
.73447 .30902 L
.73576 .30902 L
.73648 .30902 L
.73715 .30902 L
.73788 .30902 L
.73867 .30902 L
.73935 .30902 L
Mistroke
.74009 .30902 L
.74079 .30902 L
.74143 .30902 L
.74265 .30902 L
.74394 .30902 L
.74508 .30902 L
.74633 .30902 L
.74763 .30902 L
.74884 .30902 L
.74998 .30902 L
.75101 .30902 L
.7522 .30902 L
.75333 .30902 L
.75455 .30902 L
.75585 .30902 L
.75696 .30902 L
.75818 .30902 L
.75949 .30902 L
.76023 .30902 L
.7609 .30902 L
.7622 .30902 L
.76344 .30902 L
.76459 .30902 L
.76564 .30902 L
.76684 .30902 L
.76798 .30902 L
.76903 .30902 L
.77 .30902 L
.77107 .30902 L
.77219 .30902 L
.77333 .30902 L
.77454 .30902 L
.77569 .30902 L
.77674 .30902 L
.77797 .30902 L
.77866 .30902 L
.7793 .30902 L
.78048 .30902 L
.78172 .30902 L
.78293 .30902 L
.78424 .30902 L
.78548 .30902 L
.78664 .30902 L
.78778 .30902 L
.78881 .30902 L
.79113 .30902 L
.80125 .30902 L
.81955 .30902 L
.85961 .30902 L
.89816 .30902 L
Mistroke
.93916 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`03000006Ko06Ko
00L0I_l00`00001Vo`1Vo`0706Ko00<00000I_l0I_l01`1Vo`03000006Ko06Ko00L0I_l00`00001V
o`1Vo`0706Ko00<00000I_l0I_l0101Vo`<co`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0005<ol000<0I_lco`0000002C?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool04oooo`004Oooo`030000
<ol0<ol002lco`000`0003?o03?o0004<ol0901Vo`Dco`000`1Voc?o0000000`<ol000<0000co`0c
o`00;c?o00030000oooooooo02ooool00`000?ooooooo`0Coooo000AooooGC?o00H0I_mT<ol000<0
003oooooool0AOooo`004Oooof8co`000ol0VC?o03?o001R<ol000<0003oooooool0AOooo`004Ooo
of8co`000ol0VC?o03?o001R<ol000<0003oooooool0AOooo`004Oooof8co`000ol0VC?o03?o001R
<ol000<0003oooooool0AOooo`004Oooof8co`000ol0VC?o03?o001R<ol000<0003oooooool0AOoo
o`004Oooof8co`000ol0VC?o03?o001R<ol00P0004Koool0017ooomR<ol000?o09Tco`0co`00HS?o
00030000oooooooo04Goool0017ooomR<ol000?o09Tco`0co`00HS?o00030000oooooooo04Goool0
017ooomR<ol000?o09Tco`0co`00HS?o00030000oooooooo04Goool0017ooomR<ol000?o09Tco`0c
o`00HS?o00030000oooooooo04Goool0017ooomR<ol000?o09Tco`0co`00HS?o00030000oooooooo
04Goool0017ooomR<ol000?o09Tco`0co`00HS?o00030000oooooooo04Goool0017ooomR<ol000?o
09Tco`0co`00HS?o00030000oooooooo04Goool0017oool20000H3?o0003o`2I<ol0<ol0068co`02
0000A_ooo`004oooo`80001N<ol000?o09Tco`0co`00HS?o00030000oooooooo04Goool001Goool2
0000G3?o0003o`2I<ol0<ol0068co`000`000?ooooooo`15oooo000Goooo0P0005Xco`000ol0VC?o
03?o001R<ol000<0003oooooool0AOooo`006Oooo`80001H<ol000?o09Tco`0co`00HS?o00030000
oooooooo04Goool001_oool20000ES?o0003o`2I<ol0<ol0068co`000`000?ooooooo`15oooo000M
oooo0P0005@co`000ol0VC?o03?o001R<ol000<0003oooooool0AOooo`007oooo`030000<ol0<ol0
054co`000ol0VC?o03?o001R<ol000<0003oooooool0AOooo`008?ooo`030000<ol0<ol0050co`00
0ol0VC?o03?o001R<ol00P0004Koool0027oool20000D3?o0003o`2I<ol0<ol0068co`000`000?oo
ooooo`15oooo000Soooo00<0000co`0co`00CC?o0003o`2I<ol0<ol0068co`000`000?ooooooo`15
oooo000Toooo0P0004dco`000ol0VC?o03?o001R<ol000<0003oooooool0AOooo`009_ooo`030000
<ol0<ol004Xco`000ol0VC?o03?o001R<ol000<0003oooooool0AOooo`009oooo`030000<ol0<ol0
04Tco`000ol0VC?o03?o001R<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol004Pco`00
0ol0VC?o03?o0019<ol00P0000@co`02000013?o00800003<ol0100000@co`000`000?ooooooo`15
oooo000Yoooo00<0000co`0co`00Ac?o0003o`2I<ol0<ol004Pco`00100003?o03?o000000Pco`00
100003?o03?o0000008co`000`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_ooo`030000
<ol0<ol004Hco`000ol0VC?o03?o0018<ol000@0000co`0co`000008<ol000@0000co`0co`000003
<ol000<0000co`0co`0013?o00<00015oooo000[oooo0P0004Hco`000ol0VC?o03?o0018<ol000@0
000co`0co`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o00030000oooooooo
04Goool002goool00`0003?o03?o0013<ol000?o09Tco`0co`00B3?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool002koool0
0`0003?o03?o0012<ol000?o09Tco`0co`00BC?o0080000:<ol00P0000@co`0200001C?o00030000
oooooooo04Goool002ooool00`0003?o03?o0011<ol000?o09Tco`0co`00HS?o00030000oooooooo
04Goool0033oool00`0003?o03?o0010<ol000?o09Tco`0co`00HS?o00030000oooooooo04Goool0
037oool00`0003?o03?o000o<ol000?o09Tco`0co`00HS?o00030000oooooooo04Goool003;oool0
0`0003?o03?o000n<ol000?o09Tco`0co`00HS?o00030000oooooooo04Goool003?oool00`0003?o
03?o000m<ol000?o09Tco`0co`00HS?o00800016oooo000coooo00<0000co`0co`00?C?o0003o`2I
<ol0<ol0068co`000`000?ooooooo`15oooo000doooo00<0000co`0co`00?3?o0003o`2I<ol0<ol0
068co`000`000?ooooooo`15oooo000eoooo00<0000co`0co`00>c?o0003o`2I<ol0<ol0068co`00
0`000?ooooooo`15oooo000foooo00<0000co`0co`00>S?o0003o`2I<ol0<ol0068co`000`000?oo
ooooo`15oooo000goooo00<0000co`0co`00>C?o0003o`2I<ol0<ol0068co`000`000?ooooooo`15
oooo000hoooo00<0000co`0co`00>3?o0003o`2I<ol0<ol0068co`000`000?ooooooo`15oooo000h
oooo00<0000co`0co`00>3?o0003o`2I<ol0<ol0068co`000`000?ooooooo`15oooo000ioooo00<0
000co`0co`00=c?o0003o`2I<ol0<ol0068co`020000A_ooo`00>_ooo`030000<ol0<ol003Hco`00
0ol0VC?o03?o001R<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol003Dco`000ol0VC?o
03?o001R<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol003@co`000ol0VC?o03?o001R
<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol003@co`000ol0VC?o03?o001R<ol000<0
003oooooool0AOooo`00?Oooo`030000<ol0<ol003<co`000ol0VC?o03?o001R<ol000<0003ooooo
ool0AOooo`00?Oooo`030000<ol0<ol003<co`000ol0VC?o03?o001R<ol000<0003oooooool0AOoo
o`00?_ooo`030000<ol0<ol0038co`000ol0VC?o03?o001R<ol000<0003oooooool0AOooo`00?_oo
o`030000<ol0<ol0038co`000ol0VC?o03?o001R<ol000<0003oooooool0AOooo`00?oooo`030000
<ol0<ol0034co`000ol0VC?o03?o001R<ol00P0004Koool003ooool00`0003?o03?o000a<ol000?o
09Tco`0co`00HS?o00030000oooooooo04Goool0043oool00`0003?o03?o000`<ol000?o09Tco`0c
o`00HS?o00030000oooooooo04Goool0047oool00`0003?o03?o000_<ol000?o09Tco`0co`00HS?o
00030000oooooooo04Goool0047oool00`0003?o03?o000_<ol000?o09Tco`0co`00HS?o00030000
oooooooo04Goool004;oool00`0003?o03?o000^<ol000?o09Tco`0co`00HS?o00030000oooooooo
04Goool004;oool00`0003?o03?o000^<ol000?o09Tco`0co`00BC?o00800004<ol00P0000@co`02
00001C?o00<00003<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol002dco`000ol0VC?o
03?o0018<ol000@0000co`0co`000008<ol000@0000co`0co`000005<ol000<0000co`0co`000S?o
00030000oooooooo04Goool004?oool00`0003?o03?o000]<ol000?o09Tco`0co`00B3?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool00`0003?o
03?o000/<ol000?o09Tco`0co`00B3?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o
00040000<ol0<ol0000013?o00030000oooooooo04Goool004Coool00`0003?o03?o000/<ol000?o
09Tco`0co`00B3?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol00000
00@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`00:c?o0003o`2I<ol0<ol004Tco`02
00002S?o00800005<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`00:c?o
0003o`2I<ol0<ol0068co`000`000?ooooooo`15oooo0016oooo00<0000co`0co`00:S?o0003o`2I
<ol0<ol0068co`000`000?ooooooo`15oooo0016oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol0
068co`000`000?ooooooo`15oooo0017oooo00<0000co`0co`00:C?o0003o`2I<ol0<ol0068co`00
0`000?ooooooo`15oooo0017oooo00<0000co`0co`00:C?o0003o`2I<ol0<ol0068co`020000A_oo
o`00B?ooo`030000<ol0<ol002Pco`000ol0VC?o03?o001R<ol000<0003oooooool0AOooo`00B?oo
o`030000<ol0<ol002Pco`000ol0VC?o03?o001R<ol000<0003oooooool0AOooo`00BOooo`030000
<ol0<ol002Lco`000ol0VC?o03?o001R<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol0
02Lco`000ol0VC?o03?o001R<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol002Hco`00
0ol0VC?o03?o001R<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol002Hco`000ol0VC?o
03?o001R<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol002Dco`000ol0VC?o03?o001R
<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol002Dco`000ol0VC?o03?o001R<ol00P00
04Koool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;<ol0B?oo
o`00COoooh/co`18oooo001>oooo9S?o00030000<ol0<ol002lco`000`0003?o03?o000_<ol0B?oo
o`00C_ooobDco`000`0003?o03?o0008<ol000<0000co`0co`009S?o00030000<ol0<ol002hco`18
oooo001?oooo93?o00030000<ol0<ol0008co`02000013?o00030000<ol0<ol000hco`02000013?o
00800004<ol00P0000<co`0400000c?o00030000<ol0<ol002hco`18oooo001?oooo93?o00050000
<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0000co`0co`001C?o00@00003<ol000@0
000co`0co`000008<ol000@0000co`0co`000002<ol000<0000co`0co`0013?o00030000<ol0<ol0
02hco`18oooo001?oooo8c?o00030000<ol0<ol0008co`000`0003?o03?o000D<ol000@0000co`0c
o`000008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00030000<ol0<ol002dco`18
oooo001@oooo8c?o00030000<ol0<ol000D0000C<ol000@0000co`0co`000008<ol000@0000co`0c
o`000004<ol000<0000co`0co`000S?o00030000<ol0<ol002hco`18oooo001@oooo8c?o00050000
<ol0<ol0<ol0000001Hco`00100003?o03?o000000Pco`00100003?o03?o0000008co`00100003?o
03?o000000<co`000`0003?o03?o000^<ol0B?ooo`00D?ooob@co`000`0003?o03?o000H<ol00P00
00Xco`02000013?o00800003<ol000<0000co`0co`00;c?o04Soool0057ooon7<ol0B?ooo`00DOoo
ohLco`18oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.36136 .30902 L
.37176 .30902 L
.3815 .30902 L
.39106 .30902 L
.39381 .30902 L
.39642 .30902 L
.39877 .30902 L
.39942 .30902 L
.4001 .30902 L
s
.4001 .30902 m
.40011 .61803 L
s
0 .4 1 r
.02381 .31025 m
.06244 .31044 L
.10458 .31068 L
.14415 .31094 L
.18221 .31124 L
.22272 .3116 L
.26171 .31201 L
.30316 .31251 L
.34309 .31307 L
.36136 .31336 L
.37176 .31353 L
.3815 .3137 L
.39106 .31388 L
.39381 .31393 L
.39642 .31398 L
.39877 .31402 L
.39942 .31403 L
.4001 .31404 L
.40134 .30902 L
.40203 .30902 L
.40276 .30902 L
.40406 .30902 L
.40479 .30902 L
.40547 .30902 L
.40622 .30902 L
.40702 .30902 L
.4077 .30902 L
.40845 .30902 L
.40981 .30902 L
.41046 .30902 L
.41114 .30902 L
.41237 .30902 L
.41368 .30902 L
.41491 .30902 L
.41618 .30902 L
.41686 .30902 L
.41758 .30902 L
.41887 .30902 L
.42009 .30902 L
.42237 .30902 L
.4235 .30902 L
.4247 .30902 L
.42573 .30902 L
.42686 .30902 L
.42808 .30902 L
.42938 .30902 L
.43061 .30902 L
.43174 .30902 L
.43302 .30902 L
.43421 .30902 L
Mistroke
.43552 .30902 L
.43626 .30902 L
.43692 .30902 L
.43814 .30902 L
.43945 .30902 L
.44069 .30902 L
.44184 .30902 L
.4429 .30902 L
.44403 .30902 L
.4451 .30902 L
.44608 .30902 L
.44723 .30902 L
.44847 .30902 L
.44964 .30902 L
.45073 .30902 L
.45186 .30902 L
.4531 .30902 L
.45431 .30902 L
.45561 .30902 L
.45676 .30902 L
.45796 .30902 L
.45899 .30902 L
.46012 .30902 L
.46076 .30902 L
.46144 .30902 L
.46266 .30902 L
.46398 .30902 L
.46472 .30902 L
.46542 .30902 L
.46668 .30902 L
.46783 .30902 L
.46847 .30902 L
.46916 .30902 L
.47042 .30902 L
.47154 .30902 L
.47277 .30902 L
.47406 .30902 L
.47527 .30902 L
.47977 .30902 L
.48108 .30902 L
.48232 .30902 L
.48301 .30902 L
.48375 .30902 L
.48505 .30902 L
.48997 .30902 L
.49127 .30902 L
.49192 .30902 L
.49264 .30902 L
.49392 .30902 L
.49511 .30902 L
Mistroke
.49583 .30902 L
.49652 .30902 L
.49782 .30902 L
.49854 .30902 L
.49921 .30902 L
.49995 .30902 L
.50073 .30902 L
.50139 .30902 L
.50209 .30902 L
.50335 .30902 L
.50404 .30902 L
.5047 .30902 L
.50541 .30902 L
.50618 .30902 L
.50684 .30902 L
.50755 .30902 L
.50886 .30902 L
.51013 .30902 L
.5113 .30902 L
.51244 .30902 L
.51351 .30902 L
.51595 .30902 L
.51711 .30902 L
.51833 .30902 L
.51897 .30902 L
.51966 .30902 L
.52089 .30902 L
.53938 .30902 L
.56065 .30902 L
.57997 .30902 L
.58465 .30902 L
.58589 .30902 L
.58658 .30902 L
.58722 .30902 L
.58845 .30902 L
.58961 .30902 L
.59085 .30902 L
.59156 .30902 L
.5922 .30902 L
.59292 .30902 L
.59368 .30902 L
.5944 .30902 L
.59505 .30902 L
.59629 .30902 L
.59695 .30902 L
.59764 .30902 L
.59879 .30902 L
.60006 .30902 L
.60134 .30902 L
.60255 .30902 L
Mistroke
.60363 .30902 L
.60481 .30902 L
.60609 .30902 L
.60673 .30902 L
.60745 .30902 L
.6087 .30902 L
.60988 .30902 L
.61106 .30902 L
.61218 .30902 L
.61319 .30902 L
.61429 .30902 L
.61903 .30902 L
.62027 .30902 L
.62158 .30902 L
.62227 .30902 L
.62302 .30902 L
.62434 .30902 L
.62559 .30902 L
.62629 .30902 L
.62693 .30902 L
.62817 .30902 L
.62934 .30902 L
.63047 .30902 L
.63167 .30902 L
.63269 .30902 L
.63382 .30902 L
.63503 .30902 L
.63633 .30902 L
.63869 .30902 L
.65966 .30902 L
.6608 .30902 L
.66201 .30902 L
.66333 .30902 L
.66455 .30902 L
.66568 .30902 L
.66674 .30902 L
.66791 .30902 L
.66916 .30902 L
.66984 .30902 L
.67058 .30902 L
.67128 .30902 L
.67193 .30902 L
.67316 .30902 L
.67447 .30902 L
.67578 .30902 L
.67701 .30902 L
.67811 .30902 L
.6793 .30902 L
.68001 .30902 L
.68076 .30902 L
Mistroke
.68147 .30902 L
.68212 .30902 L
.68285 .30902 L
.68354 .30902 L
.68429 .30902 L
.6851 .30902 L
.68574 .30902 L
.68645 .30902 L
.68718 .30902 L
.68787 .30902 L
.68911 .30902 L
.6898 .30902 L
.69043 .30902 L
.69168 .30902 L
.69285 .30902 L
.69412 .30902 L
.69483 .30902 L
.69548 .30902 L
.69679 .30902 L
.69753 .30902 L
.69821 .30902 L
.69947 .30902 L
.7001 .30902 L
.70079 .30902 L
.70197 .30902 L
.70322 .30902 L
.70387 .30902 L
.70459 .30902 L
.70586 .30902 L
.70705 .30902 L
.70834 .30902 L
.70955 .30902 L
.71067 .30902 L
.71195 .30902 L
.71269 .30902 L
.71337 .30902 L
.71408 .30902 L
.71474 .30902 L
.71549 .30902 L
.71621 .30902 L
.71747 .30902 L
.71863 .30902 L
.71991 .30902 L
.72056 .30902 L
.72127 .30902 L
.72254 .30902 L
.72375 .30902 L
.72484 .30902 L
.72603 .30902 L
.72731 .30902 L
Mistroke
.72803 .30902 L
.72868 .30902 L
.72995 .30902 L
.73115 .30902 L
.73227 .30902 L
.73346 .30902 L
.73448 .30902 L
.73559 .30902 L
.73679 .30902 L
.73808 .30902 L
.7393 .30902 L
.7404 .30902 L
.74158 .30902 L
.74269 .30902 L
.7439 .30902 L
.74521 .30902 L
.74651 .30902 L
.74716 .30902 L
.74788 .30902 L
.74914 .30902 L
.75032 .30902 L
.75152 .30902 L
.75264 .30902 L
.75366 .30902 L
.75476 .30902 L
.75595 .30902 L
.75722 .30902 L
.7583 .30902 L
.75949 .30902 L
.76016 .30902 L
.76088 .30902 L
.7622 .30902 L
.76348 .30902 L
.76467 .30902 L
.76539 .30902 L
.76608 .30902 L
.76736 .30902 L
.76808 .30902 L
.76875 .30902 L
.76945 .30902 L
.77022 .30902 L
.77144 .30902 L
.77274 .30902 L
.77394 .30902 L
.77505 .30902 L
.77633 .30902 L
.77705 .30902 L
.77772 .30902 L
.77895 .30902 L
.78026 .30902 L
Mistroke
.78146 .30902 L
.78277 .30902 L
.78401 .30902 L
.78516 .30902 L
.7863 .30902 L
.78734 .30902 L
.78966 .30902 L
.79977 .30902 L
.81807 .30902 L
.85811 .30902 L
.89663 .30902 L
.93761 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0003<ol0101Vo`03000006Ko06Ko00L0I_l00`00001Vo`1Vo`0706Ko00<0
0000I_l0I_l01`1Vo`03000006Ko06Ko00L0I_l00`00001Vo`1Vo`0706Ko00<00000I_l0I_l01`1V
o`03000006Ko06Ko00L0I_l00`00001Vo`1Vo`0706Ko00<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool04oooo`004Oooo`030000
<ol0<ol002lco`000`0003?o03?o000^<ol000?o09T0000co`00;c?o00030000<ol0<ol002lco`00
0`000?ooooooo`0_oooo00<0003oooooool04oooo`004Oooof<co`000ol0VC?o03?o001Q<ol000<0
003oooooool0AOooo`004Oooof<co`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`004Ooo
of<co`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`004Oooof<co`000ol0VC?o03?o001Q
<ol000<0003oooooool0AOooo`004Oooof<co`000ol0VC?o03?o001Q<ol000<0003oooooool0AOoo
o`004Oooof<co`000ol0VC?o03?o001Q<ol00P0004Koool0017ooomS<ol000?o09Tco`0co`00HC?o
00030000oooooooo04Goool0017ooomS<ol000?o09Tco`0co`00HC?o00030000oooooooo04Goool0
017ooomS<ol000?o09Tco`0co`00HC?o00030000oooooooo04Goool0017ooomS<ol000?o09Tco`0c
o`00HC?o00030000oooooooo04Goool0017ooomS<ol000?o09Tco`0co`00HC?o00030000oooooooo
04Goool0017ooomS<ol000?o09Tco`0co`00HC?o00030000oooooooo04Goool0017ooomS<ol000?o
09Tco`0co`00HC?o00030000oooooooo04Goool0017oool20000HC?o0003o`2I<ol0<ol0064co`02
0000A_ooo`004oooo`80001O<ol000?o09Tco`0co`00HC?o00030000oooooooo04Goool001Goool2
0000GC?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo000Goooo0P0005/co`000ol0VC?o
03?o001Q<ol000<0003oooooool0AOooo`006Oooo`80001I<ol000?o09Tco`0co`00HC?o00030000
oooooooo04Goool001_oool20000Ec?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo000M
oooo0P0005Dco`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`007oooo`030000<ol0<ol0
058co`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`008?ooo`030000<ol0<ol0054co`00
0ol0VC?o03?o001Q<ol00P0004Koool0027oool20000DC?o0003o`2I<ol0<ol0064co`000`000?oo
ooooo`15oooo000Soooo00<0000co`0co`00CS?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15
oooo000Toooo0P0004hco`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`009_ooo`030000
<ol0<ol004/co`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`009oooo`030000<ol0<ol0
04Xco`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol004Tco`00
0ol0VC?o03?o0018<ol00P0000@co`02000013?o00800003<ol0100000@co`000`000?ooooooo`15
oooo000Yoooo00<0000co`0co`00B3?o0003o`2I<ol0<ol004Lco`00100003?o03?o000000Pco`00
100003?o03?o0000008co`000`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_ooo`030000
<ol0<ol004Lco`000ol0VC?o03?o0017<ol000@0000co`0co`000008<ol000@0000co`0co`000003
<ol000<0000co`0co`0013?o00<00015oooo000[oooo0P0004Lco`000ol0VC?o03?o0017<ol000@0
000co`0co`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o00030000oooooooo
04Goool002goool00`0003?o03?o0014<ol000?o09Tco`0co`00Ac?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool002koool0
0`0003?o03?o0013<ol000?o09Tco`0co`00B3?o0080000:<ol00P0000@co`0200001C?o00030000
oooooooo04Goool002ooool00`0003?o03?o0012<ol000?o09Tco`0co`00HC?o00030000oooooooo
04Goool0033oool00`0003?o03?o0011<ol000?o09Tco`0co`00HC?o00030000oooooooo04Goool0
037oool00`0003?o03?o0010<ol000?o09Tco`0co`00HC?o00030000oooooooo04Goool003;oool0
0`0003?o03?o000o<ol000?o09Tco`0co`00HC?o00030000oooooooo04Goool003?oool00`0003?o
03?o000n<ol000?o09Tco`0co`00HC?o00800016oooo000coooo00<0000co`0co`00?S?o0003o`2I
<ol0<ol0064co`000`000?ooooooo`15oooo000doooo00<0000co`0co`00?C?o0003o`2I<ol0<ol0
064co`000`000?ooooooo`15oooo000eoooo00<0000co`0co`00?3?o0003o`2I<ol0<ol0064co`00
0`000?ooooooo`15oooo000foooo00<0000co`0co`00>c?o0003o`2I<ol0<ol0064co`000`000?oo
ooooo`15oooo000goooo00<0000co`0co`00>S?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15
oooo000hoooo00<0000co`0co`00>C?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo000h
oooo00<0000co`0co`00>C?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo000ioooo00<0
000co`0co`00>3?o0003o`2I<ol0<ol0064co`020000A_ooo`00>_ooo`030000<ol0<ol003Lco`00
0ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol003Hco`000ol0VC?o
03?o001Q<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol003Dco`000ol0VC?o03?o001Q
<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol003Dco`000ol0VC?o03?o001Q<ol000<0
003oooooool0AOooo`00?Oooo`030000<ol0<ol003@co`000ol0VC?o03?o001Q<ol000<0003ooooo
ool0AOooo`00?Oooo`030000<ol0<ol003@co`000ol0VC?o03?o001Q<ol000<0003oooooool0AOoo
o`00?_ooo`030000<ol0<ol003<co`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`00?_oo
o`030000<ol0<ol003<co`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`00?oooo`030000
<ol0<ol0038co`000ol0VC?o03?o001Q<ol00P0004Koool003ooool00`0003?o03?o000b<ol000?o
09Tco`0co`00HC?o00030000oooooooo04Goool0043oool00`0003?o03?o000a<ol000?o09Tco`0c
o`00HC?o00030000oooooooo04Goool0047oool00`0003?o03?o000`<ol000?o09Tco`0co`00HC?o
00030000oooooooo04Goool0047oool00`0003?o03?o000`<ol000?o09Tco`0co`00HC?o00030000
oooooooo04Goool004;oool00`0003?o03?o000_<ol000?o09Tco`0co`00HC?o00030000oooooooo
04Goool004;oool00`0003?o03?o000_<ol000?o09Tco`0co`00B3?o00800004<ol00P0000@co`02
00001C?o00<00003<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol002hco`000ol0VC?o
03?o0017<ol000@0000co`0co`000008<ol000@0000co`0co`000005<ol000<0000co`0co`000S?o
00030000oooooooo04Goool004?oool00`0003?o03?o000^<ol000?o09Tco`0co`00Ac?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool00`0003?o
03?o000]<ol000?o09Tco`0co`00Ac?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o
00040000<ol0<ol0000013?o00030000oooooooo04Goool004Coool00`0003?o03?o000]<ol000?o
09Tco`0co`00Ac?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol00000
00@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`00;3?o0003o`2I<ol0<ol004Pco`02
00002S?o00800005<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`00;3?o
0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo0016oooo00<0000co`0co`00:c?o0003o`2I
<ol0<ol0064co`000`000?ooooooo`15oooo0016oooo00<0000co`0co`00:c?o0003o`2I<ol0<ol0
064co`000`000?ooooooo`15oooo0017oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol0064co`00
0`000?ooooooo`15oooo0017oooo00<0000co`0co`00:S?o0003o`2I<ol0<ol0064co`020000A_oo
o`00B?ooo`030000<ol0<ol002Tco`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`00B?oo
o`030000<ol0<ol002Tco`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`00BOooo`030000
<ol0<ol002Pco`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol0
02Pco`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol002Lco`00
0ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol002Lco`000ol0VC?o
03?o001Q<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol002Hco`000ol0VC?o03?o001Q
<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol002Hco`000ol0VC?o03?o001Q<ol00P00
04Koool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;<ol0B?oo
o`00COoooh/co`18oooo001>oooo9S?o00030000<ol0<ol002lco`000`0003?o03?o000_<ol0B?oo
o`00C_ooobDco`000`0003?o03?o0008<ol000<0000co`0co`009S?o00030000<ol0<ol002hco`18
oooo001?oooo93?o00030000<ol0<ol0008co`02000013?o00030000<ol0<ol000hco`02000013?o
00800004<ol00P0000<co`0500000S?o00030000<ol0<ol002hco`18oooo001?oooo93?o00050000
<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0000co`0co`001C?o00@00003<ol000@0
000co`0co`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000S?o00030000<ol0<ol0
02hco`18oooo001?oooo8c?o00030000<ol0<ol0008co`000`0003?o03?o000D<ol000@0000co`0c
o`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o00030000<ol0<ol002dco`18
oooo001@oooo8c?o00030000<ol0<ol000D0000C<ol000@0000co`0co`000008<ol000@0000co`0c
o`000004<ol000<0000co`0co`000S?o00030000<ol0<ol002hco`18oooo001@oooo8c?o00050000
<ol0<ol0<ol0000001Hco`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`0003?o
03?o0002<ol000<0000co`0co`00;S?o04Soool0053ooolT<ol000<0000co`0co`0063?o0080000:
<ol00P0000@co`0200000c?o00030000<ol0<ol002lco`18oooo001AooooQc?o04Soool0057ooon7
<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.39174 .30902 L
.39675 .30902 L
.40134 .30902 L
.40252 .30902 L
.40381 .30902 L
s
.40381 .30902 m
.40381 .61803 L
s
0 .4 1 r
.02381 .30902 m
.02499 .30902 L
.02605 .30902 L
.02729 .30902 L
.02846 .30902 L
.02954 .30902 L
.03053 .30902 L
.03163 .30902 L
.03279 .30902 L
.03395 .30902 L
.0352 .30902 L
.03638 .30902 L
.03746 .30902 L
.03873 .30902 L
.03944 .30902 L
.04011 .30902 L
.04132 .30902 L
.04262 .30902 L
.04327 .30902 L
.04396 .30902 L
.04519 .30902 L
.04583 .30902 L
.04652 .30902 L
.04727 .30902 L
.04797 .30902 L
.04862 .30902 L
.04933 .30902 L
.05061 .30902 L
.05186 .30902 L
.05302 .30902 L
.05414 .30902 L
.05519 .30902 L
.05634 .30902 L
.05759 .30902 L
.05882 .30902 L
.06012 .30902 L
.06123 .30902 L
.06244 .30902 L
.06315 .30902 L
.06381 .30902 L
.06453 .30902 L
.06529 .30902 L
.06657 .30902 L
.06729 .30902 L
.06797 .30902 L
.06924 .30902 L
.0704 .30902 L
.07103 .30902 L
.07173 .30902 L
.073 .30902 L
Mistroke
.07376 .30902 L
.07448 .30902 L
.07513 .30902 L
.07583 .30902 L
.0766 .30902 L
.0774 .30902 L
.07809 .30902 L
.07885 .30902 L
.0802 .30902 L
.08096 .30902 L
.08166 .30902 L
.0823 .30902 L
.083 .30902 L
.08427 .30902 L
.08553 .30902 L
.08671 .30902 L
.08811 .30902 L
.08939 .30902 L
.09067 .30902 L
.09131 .30902 L
.09201 .30902 L
.09272 .30902 L
.09347 .30902 L
.09418 .30902 L
.09483 .30902 L
.09608 .30902 L
.09724 .30902 L
.09851 .30902 L
.09914 .30902 L
.09985 .30902 L
.10103 .30902 L
.10229 .30902 L
.10349 .30902 L
.10458 .30902 L
.10575 .30902 L
.10686 .30902 L
.10817 .30902 L
.10938 .30902 L
.11057 .30902 L
.11183 .30902 L
.11309 .30902 L
.11381 .30902 L
.11448 .30902 L
.11567 .30902 L
.1168 .30902 L
.11781 .30902 L
.11891 .30902 L
.1201 .30902 L
.12137 .30902 L
.12245 .30902 L
Mistroke
.12364 .30902 L
.1243 .30902 L
.12502 .30902 L
.12634 .30902 L
.12763 .30902 L
.12881 .30902 L
.12952 .30902 L
.1302 .30902 L
.13091 .30902 L
.13169 .30902 L
.13236 .30902 L
.13308 .30902 L
.13436 .30902 L
.13555 .30902 L
.13683 .30902 L
.13804 .30902 L
.13914 .30902 L
.14044 .30902 L
.14116 .30902 L
.14184 .30902 L
.14308 .30902 L
.14439 .30902 L
.14553 .30902 L
.14678 .30902 L
.14808 .30902 L
.14929 .30902 L
.15042 .30902 L
.15146 .30902 L
.15265 .30902 L
.15377 .30902 L
.155 .30902 L
.1563 .30902 L
.15742 .30902 L
.15862 .30902 L
.15992 .30902 L
.16113 .30902 L
.16186 .30902 L
.16257 .30902 L
.16388 .30902 L
.16501 .30902 L
.16608 .30902 L
.16731 .30902 L
.16842 .30902 L
.17263 .30902 L
.17378 .30902 L
.17486 .30902 L
.17598 .30902 L
.17721 .30902 L
.17846 .30902 L
.17916 .30902 L
Mistroke
.17979 .30902 L
.18101 .30902 L
.18216 .30902 L
.18331 .30902 L
.18454 .30902 L
.18571 .30902 L
.18677 .30902 L
.18802 .30902 L
.18872 .30902 L
.18938 .30902 L
.19058 .30902 L
.19185 .30902 L
.19255 .30902 L
.19319 .30902 L
.19389 .30902 L
.19463 .30902 L
.19587 .30902 L
.19658 .30902 L
.19724 .30902 L
.19847 .30902 L
.1996 .30902 L
.2009 .30902 L
.20213 .30902 L
.20318 .30902 L
.20435 .30902 L
.20557 .30902 L
.20671 .30902 L
.20778 .30902 L
.20876 .30902 L
.20983 .30902 L
.21096 .30902 L
.21211 .30902 L
.21333 .30902 L
.21449 .30902 L
.21555 .30902 L
.21678 .30902 L
.21748 .30902 L
.21813 .30902 L
.21931 .30902 L
.22057 .30902 L
.22177 .30902 L
.22309 .30902 L
.22434 .30902 L
.22549 .30902 L
.22661 .30902 L
.22781 .30902 L
.22895 .30902 L
.23 .30902 L
.23125 .30902 L
.23257 .30902 L
Mistroke
.23368 .30902 L
.2349 .30902 L
.23621 .30902 L
.23694 .30902 L
.23761 .30902 L
.2389 .30902 L
.24013 .30902 L
.24118 .30902 L
.24234 .30902 L
.24355 .30902 L
.24469 .30902 L
.24575 .30902 L
.24672 .30902 L
.24778 .30902 L
.2489 .30902 L
.25005 .30902 L
.25127 .30902 L
.25242 .30902 L
.25346 .30902 L
.25469 .30902 L
.25538 .30902 L
.25602 .30902 L
.2572 .30902 L
.25844 .30902 L
.25965 .30902 L
.26098 .30902 L
.26223 .30902 L
.26338 .30902 L
.2645 .30902 L
.26571 .30902 L
.26685 .30902 L
.2679 .30902 L
.26903 .30902 L
.27023 .30902 L
.27146 .30902 L
.27216 .30902 L
.27281 .30902 L
.27349 .30902 L
.27414 .30902 L
.27534 .30902 L
.27664 .30902 L
.27737 .30902 L
.27804 .30902 L
.2791 .30902 L
.28023 .30902 L
.2813 .30902 L
.28228 .30902 L
.28342 .30902 L
.28467 .30902 L
.28585 .30902 L
Mistroke
.28694 .30902 L
.28817 .30902 L
.28933 .30902 L
.29038 .30902 L
.2915 .30902 L
.29274 .30902 L
.29404 .30902 L
.29515 .30902 L
.29637 .30902 L
.29767 .30902 L
.29888 .30902 L
.29951 .30902 L
.3002 .30902 L
.30093 .30902 L
.30161 .30902 L
.30286 .30902 L
.304 .30902 L
.30526 .30902 L
.30658 .30902 L
.30768 .30902 L
.30873 .30902 L
.30993 .30902 L
.31102 .30902 L
.31223 .30902 L
.31354 .30902 L
.31476 .30902 L
.31588 .30902 L
.31709 .30902 L
.31838 .30902 L
.31961 .30902 L
.32072 .30902 L
.32203 .30902 L
.32277 .30902 L
.32345 .30902 L
.32471 .30902 L
.32541 .30902 L
.32604 .30902 L
.32672 .30902 L
.32743 .30902 L
.32871 .30902 L
.32942 .30902 L
.33008 .30902 L
.33081 .30902 L
.33159 .30902 L
.33226 .30902 L
.33299 .30902 L
.33368 .30902 L
.33431 .30902 L
.33552 .30902 L
.3368 .30902 L
Mistroke
.33791 .30902 L
.3391 .30902 L
.34041 .30902 L
.34162 .30902 L
.34275 .30902 L
.34397 .30902 L
.34513 .30902 L
.3462 .30902 L
.34684 .30902 L
.34754 .30902 L
.34823 .30902 L
.34897 .30902 L
.35027 .30902 L
.35148 .30902 L
.35278 .30902 L
.35401 .30902 L
.35511 .30902 L
.35632 .30902 L
.35744 .30902 L
.3585 .30902 L
.35967 .30902 L
.36092 .30902 L
.36216 .30902 L
.36347 .30902 L
.36459 .30902 L
.36582 .30902 L
.36697 .30902 L
.36802 .30902 L
.36923 .30902 L
.37037 .30902 L
.37143 .30902 L
.3724 .30902 L
.37347 .30902 L
.37461 .30902 L
.37582 .30902 L
.37713 .30902 L
.37838 .30902 L
.37953 .30902 L
.38068 .30902 L
.38171 .30902 L
.38284 .30902 L
.38403 .30902 L
.38534 .30902 L
.38654 .30902 L
.38783 .30902 L
.38857 .30902 L
.38925 .30902 L
.39049 .30902 L
.39162 .30902 L
.39293 .30902 L
Mistroke
.39417 .30902 L
.39522 .30902 L
.39638 .30902 L
.39759 .30902 L
.39872 .30902 L
.39978 .30902 L
.40075 .30902 L
.40182 .30902 L
.40294 .30902 L
.40408 .30902 L
.4053 .30902 L
.40645 .30902 L
.40749 .30902 L
.40872 .30902 L
.40942 .30902 L
.41005 .30902 L
.41123 .30902 L
.41247 .30902 L
.41369 .30902 L
.41501 .30902 L
.41626 .30902 L
.41741 .30902 L
.41856 .30902 L
.4196 .30902 L
.4208 .30902 L
.42192 .30902 L
.42316 .30902 L
.42447 .30902 L
.42558 .30902 L
.4268 .30902 L
.42812 .30902 L
.42953 .30902 L
.43207 .30902 L
.43321 .30902 L
.43443 .30902 L
.43507 .30902 L
.43577 .30902 L
.437 .30902 L
.43816 .30902 L
.4394 .30902 L
.44058 .30902 L
.44166 .30902 L
.44277 .30902 L
.4438 .30902 L
.44493 .30902 L
.44613 .30902 L
.44728 .30902 L
.44836 .30902 L
.44934 .30902 L
.45039 .30902 L
Mistroke
.45163 .30902 L
.45276 .30902 L
.45406 .30902 L
.4553 .30902 L
.45644 .30902 L
.4575 .30902 L
.45866 .30902 L
.45989 .30902 L
.46112 .30902 L
.46181 .30902 L
.46245 .30902 L
.46362 .30902 L
.46485 .30902 L
.47032 .30902 L
.47152 .30902 L
.47282 .30902 L
.47405 .30902 L
.47519 .30902 L
.47651 .30902 L
.47717 .30902 L
.47791 .30902 L
.47919 .30902 L
.48038 .30902 L
.48112 .30902 L
.48182 .30902 L
.48313 .30902 L
.48386 .30902 L
.48454 .30902 L
.48529 .30902 L
.48608 .30902 L
.48677 .30902 L
.48752 .30902 L
.48822 .30902 L
.48886 .30902 L
.49009 .30902 L
.49139 .30902 L
.49261 .30902 L
.4933 .30902 L
.49394 .30902 L
.49511 .30902 L
.49636 .30902 L
.4974 .30902 L
.49851 .30902 L
.49974 .30902 L
.50089 .30902 L
.50212 .30902 L
.50282 .30902 L
.50347 .30902 L
.50479 .30902 L
.50553 .30902 L
Mistroke
.5062 .30902 L
.5074 .30902 L
.5087 .30902 L
.50993 .30902 L
.51106 .30902 L
.51212 .30902 L
.51326 .30902 L
.51433 .30902 L
.51531 .30902 L
.51646 .30902 L
.5177 .30902 L
.51888 .30902 L
.51998 .30902 L
.5211 .30902 L
.52215 .30902 L
.5233 .30902 L
.52455 .30902 L
.52578 .30902 L
.52708 .30902 L
.52819 .30902 L
.5294 .30902 L
.53072 .30902 L
.53193 .30902 L
.53257 .30902 L
.53327 .30902 L
.534 .30902 L
.53468 .30902 L
.53593 .30902 L
.53708 .30902 L
.53771 .30902 L
.5384 .30902 L
.53966 .30902 L
.54089 .30902 L
.542 .30902 L
.54329 .30902 L
.5445 .30902 L
.54562 .30902 L
.54666 .30902 L
.54779 .30902 L
.54899 .30902 L
.55029 .30902 L
.55148 .30902 L
.55214 .30902 L
.55285 .30902 L
.55415 .30902 L
.55537 .30902 L
.55666 .30902 L
.55776 .30902 L
.55897 .30902 L
.55966 .30902 L
Mistroke
.56039 .30902 L
.56169 .30902 L
.56242 .30902 L
.56309 .30902 L
.56383 .30902 L
.56462 .30902 L
.56531 .30902 L
.56605 .30902 L
.56676 .30902 L
.5674 .30902 L
.56863 .30902 L
.56993 .30902 L
.57114 .30902 L
.57246 .30902 L
.57371 .30902 L
.57486 .30902 L
.57601 .30902 L
.57705 .30902 L
.57825 .30902 L
.57937 .30902 L
.58061 .30902 L
.58191 .30902 L
.58304 .30902 L
.58425 .30902 L
.58555 .30902 L
.58676 .30902 L
.5875 .30902 L
.5882 .30902 L
.58951 .30902 L
.59057 .30902 L
.59173 .30902 L
.59294 .30902 L
.59408 .30902 L
.59514 .30902 L
.59611 .30902 L
.59723 .30902 L
.5983 .30902 L
.59944 .30902 L
.60066 .30902 L
.60181 .30902 L
.60285 .30902 L
.60408 .30902 L
.60478 .30902 L
.60542 .30902 L
.60659 .30902 L
.60783 .30902 L
.60905 .30902 L
.60974 .30902 L
.61037 .30902 L
.61154 .30902 L
Mistroke
.61278 .30902 L
.61389 .30902 L
.61493 .30902 L
.61607 .30902 L
.6173 .30902 L
.61853 .30902 L
.61923 .30902 L
.61988 .30902 L
.62119 .30902 L
.62193 .30902 L
.6226 .30902 L
.6238 .30902 L
.6251 .30902 L
.62632 .30902 L
.62746 .30902 L
.62851 .30902 L
.62965 .30902 L
.63072 .30902 L
.63169 .30902 L
.63284 .30902 L
.63409 .30902 L
.63526 .30902 L
.63636 .30902 L
.63759 .30902 L
.63875 .30902 L
.6398 .30902 L
.64092 .30902 L
.64216 .30902 L
.64346 .30902 L
.64457 .30902 L
.64579 .30902 L
.64709 .30902 L
.6483 .30902 L
.64893 .30902 L
.64963 .30902 L
.65036 .30902 L
.65104 .30902 L
.65229 .30902 L
.65343 .30902 L
.65469 .30902 L
.65601 .30902 L
.65712 .30902 L
.65832 .30902 L
.65944 .30902 L
.66046 .30902 L
.66166 .30902 L
.66296 .30902 L
.6641 .30902 L
.66532 .30902 L
.66663 .30902 L
Mistroke
.66784 .30902 L
.66859 .30902 L
.66929 .30902 L
.67061 .30902 L
.67129 .30902 L
.67201 .30902 L
.67329 .30902 L
.67401 .30902 L
.67468 .30902 L
.67542 .30902 L
.67621 .30902 L
.67743 .30902 L
.67812 .30902 L
.67876 .30902 L
.68006 .30902 L
.68078 .30902 L
.68144 .30902 L
.68263 .30902 L
.68391 .30902 L
.68513 .30902 L
.68625 .30902 L
.68749 .30902 L
.68868 .30902 L
.68974 .30902 L
.6909 .30902 L
.69216 .30902 L
.69287 .30902 L
.6935 .30902 L
.69475 .30902 L
.69592 .30902 L
.69702 .30902 L
.69818 .30902 L
.69918 .30902 L
.70027 .30902 L
.70497 .30902 L
.7256 .30902 L
.74675 .30902 L
.76603 .30902 L
.7756 .30902 L
.77625 .30902 L
.77695 .30902 L
.77822 .30902 L
.77887 .30902 L
.77954 .30902 L
.78031 .30902 L
.78101 .30902 L
.78224 .30902 L
.7834 .30902 L
.78466 .30902 L
.78537 .30902 L
Mistroke
.78601 .30902 L
.78719 .30902 L
.78844 .30902 L
.79068 .30902 L
.79575 .30902 L
.80494 .30902 L
.84283 .30902 L
.88317 .30902 L
.922 .30902 L
.96328 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Hco`000ol0V@0003?o0008<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0c
o`00;c?o00030000<ol0<ol002hco`000ol0V@0003?o000_<ol000<0000co`0co`00;c?o00030000
oooooooo02ooool00`000?ooooooo`0Coooo000AooooHc?o0003o`2I<ol0<ol0064co`000`000?oo
ooooo`15oooo000AooooHc?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo000AooooHc?o
0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo000AooooHc?o0003o`2I<ol0<ol0064co`00
0`000?ooooooo`15oooo000AooooHc?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo000A
ooooHc?o0003o`2I<ol0<ol0064co`020000A_ooo`004Oooof<co`000ol0VC?o03?o001Q<ol000<0
003oooooool0AOooo`004Oooof<co`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`004Ooo
of<co`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`004Oooof<co`000ol0VC?o03?o001Q
<ol000<0003oooooool0AOooo`004Oooof<co`000ol0VC?o03?o001Q<ol000<0003oooooool0AOoo
o`004Oooof<co`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`004Oooof<co`000ol0VC?o
03?o001Q<ol000<0003oooooool0AOooo`004Oooo`80001Q<ol000?o09Tco`0co`00HC?o00800016
oooo000Coooo0P0005lco`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`005Oooo`80001M
<ol000?o09Tco`0co`00HC?o00030000oooooooo04Goool001Ooool20000Fc?o0003o`2I<ol0<ol0
064co`000`000?ooooooo`15oooo000Ioooo0P0005Tco`000ol0VC?o03?o001Q<ol000<0003ooooo
ool0AOooo`006oooo`80001G<ol000?o09Tco`0co`00HC?o00030000oooooooo04Goool001goool2
0000EC?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo000Ooooo00<0000co`0co`00DS?o
0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo000Poooo00<0000co`0co`00DC?o0003o`2I
<ol0<ol0064co`020000A_ooo`008Oooo`80001A<ol000?o09Tco`0co`00HC?o00030000oooooooo
04Goool002?oool00`0003?o03?o001><ol000?o09Tco`0co`00HC?o00030000oooooooo04Goool0
02Coool20000CS?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo000Voooo00<0000co`0c
o`00Bc?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo000Woooo00<0000co`0co`00BS?o
0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo000Xoooo00<0000co`0co`00BC?o0003o`2I
<ol0<ol004Pco`02000013?o00800004<ol00P0000<co`04000013?o00030000oooooooo04Goool0
02Woool00`0003?o03?o0018<ol000?o09Tco`0co`00Ac?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000S?o00030000<ol0<ol000Dco`000`000?ooooooo`15oooo000Zoooo00<0000co`0c
o`00Ac?o0003o`2I<ol0<ol004Lco`00100003?o03?o000000Pco`00100003?o03?o000000<co`00
0`0003?o03?o0004<ol00`0004Goool002_oool20000Ac?o0003o`2I<ol0<ol004Lco`00100003?o
03?o000000Pco`00100003?o03?o000000@co`000`0003?o03?o0003<ol000<0003oooooool0AOoo
o`00;Oooo`030000<ol0<ol004@co`000ol0VC?o03?o0017<ol000@0000co`0co`000008<ol000@0
000co`0co`000002<ol000@0000co`0co`000004<ol000<0003oooooool0AOooo`00;_ooo`030000
<ol0<ol004<co`000ol0VC?o03?o0018<ol00P0000Xco`02000013?o00800005<ol000<0003ooooo
ool0AOooo`00;oooo`030000<ol0<ol0048co`000ol0VC?o03?o001Q<ol000<0003oooooool0AOoo
o`00<?ooo`030000<ol0<ol0044co`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`00<Ooo
o`030000<ol0<ol0040co`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`00<_ooo`030000
<ol0<ol003lco`000ol0VC?o03?o001Q<ol000<0003oooooool0AOooo`00<oooo`030000<ol0<ol0
03hco`000ol0VC?o03?o001Q<ol00P0004Koool003?oool00`0003?o03?o000n<ol000?o09Tco`0c
o`00HC?o00030000oooooooo04Goool003Coool00`0003?o03?o000m<ol000?o09Tco`0co`00HC?o
00030000oooooooo04Goool003Goool00`0003?o03?o000l<ol000?o09Tco`0co`00HC?o00030000
oooooooo04Goool003Koool00`0003?o03?o000k<ol000?o09Tco`0co`00HC?o00030000oooooooo
04Goool003Ooool00`0003?o03?o000j<ol000?o09Tco`0co`00HC?o00030000oooooooo04Goool0
03Soool00`0003?o03?o000i<ol000?o09Tco`0co`00HC?o00030000oooooooo04Goool003Soool0
0`0003?o03?o000i<ol000?o09Tco`0co`00HC?o00030000oooooooo04Goool003Woool00`0003?o
03?o000h<ol000?o09Tco`0co`00HC?o00800016oooo000joooo00<0000co`0co`00=c?o0003o`2I
<ol0<ol0064co`000`000?ooooooo`15oooo000koooo00<0000co`0co`00=S?o0003o`2I<ol0<ol0
064co`000`000?ooooooo`15oooo000loooo00<0000co`0co`00=C?o0003o`2I<ol0<ol0064co`00
0`000?ooooooo`15oooo000loooo00<0000co`0co`00=C?o0003o`2I<ol0<ol0064co`000`000?oo
ooooo`15oooo000moooo00<0000co`0co`00=3?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15
oooo000moooo00<0000co`0co`00=3?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo000n
oooo00<0000co`0co`00<c?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo000noooo00<0
000co`0co`00<c?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo000ooooo00<0000co`0c
o`00<S?o0003o`2I<ol0<ol0064co`020000A_ooo`00?oooo`030000<ol0<ol0038co`000ol0VC?o
03?o001Q<ol000<0003oooooool0AOooo`00@?ooo`030000<ol0<ol0034co`000ol0VC?o03?o001Q
<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol0030co`000ol0VC?o03?o001Q<ol000<0
003oooooool0AOooo`00@Oooo`030000<ol0<ol0030co`000ol0VC?o03?o001Q<ol000<0003ooooo
ool0AOooo`00@_ooo`030000<ol0<ol002lco`000ol0VC?o03?o001Q<ol000<0003oooooool0AOoo
o`00@_ooo`030000<ol0<ol002lco`000ol0VC?o03?o0018<ol00P0000@co`02000013?o00800005
<ol00`0000<co`000`000?ooooooo`15oooo0013oooo00<0000co`0co`00;S?o0003o`2I<ol0<ol0
04Lco`00100003?o03?o000000Pco`00100003?o03?o000000Dco`000`0003?o03?o0002<ol000<0
003oooooool0AOooo`00@oooo`030000<ol0<ol002hco`000ol0VC?o03?o0017<ol000@0000co`0c
o`000008<ol000@0000co`0co`000002<ol01@0000<co`030000AOooo`00A?ooo`030000<ol0<ol0
02dco`000ol0VC?o03?o0017<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0
000co`0co`000004<ol000<0003oooooool0AOooo`00A?ooo`030000<ol0<ol002dco`000ol0VC?o
03?o0017<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`00000013?o
00030000oooooooo04Goool004Goool00`0003?o03?o000/<ol000?o09Tco`0co`00B3?o0080000:
<ol00P0000Dco`02000013?o00030000oooooooo04Goool004Goool00`0003?o03?o000/<ol000?o
09Tco`0co`00HC?o00030000oooooooo04Goool004Koool00`0003?o03?o000[<ol000?o09Tco`0c
o`00HC?o00030000oooooooo04Goool004Koool00`0003?o03?o000[<ol000?o09Tco`0co`00HC?o
00030000oooooooo04Goool004Ooool00`0003?o03?o000Z<ol000?o09Tco`0co`00HC?o00030000
oooooooo04Goool004Ooool00`0003?o03?o000Z<ol000?o09Tco`0co`00HC?o00800016oooo0018
oooo00<0000co`0co`00:C?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo0018oooo00<0
000co`0co`00:C?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo0019oooo00<0000co`0c
o`00:3?o0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo0019oooo00<0000co`0co`00:3?o
0003o`2I<ol0<ol0064co`000`000?ooooooo`15oooo001:oooo00<0000co`0co`009c?o0003o`2I
<ol0<ol0064co`000`000?ooooooo`15oooo001:oooo00<0000co`0co`009c?o0003o`2I<ol0<ol0
064co`000`000?ooooooo`15oooo001;oooo00<0000co`0co`009S?o0003o`2I<ol0<ol0064co`00
0`000?ooooooo`15oooo001;oooo00<0000co`0co`009S?o0003o`2I<ol0<ol0064co`020000A_oo
o`00C?oooh`co`18oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00COoooh/co`18oooo001=
ooooRc?o04Soool004koool`<ol000<0000co`0co`006c?o00030000<ol0<ol003Tco`18oooo001>
oooo;c?o00030000<ol0<ol000Pco`000`0003?o03?o000B<ol000<0000co`0co`00>3?o04Soool0
04ooool^<ol000<0000co`0co`000S?o00800004<ol000<0000co`0co`001S?o00800004<ol00P00
00@co`000`0003?o03?o000h<ol0B?ooo`00Coooobhco`001@0003?o03?o03?o00000002<ol000<0
000co`0co`000S?o00030000<ol0<ol000@co`00100003?o03?o000000Tco`000`0003?o03?o000h
<ol0B?ooo`00Coooobdco`000`0003?o03?o0002<ol000<0000co`0co`0033?o00040000<ol0<ol0
00002S?o00030000<ol0<ol003Lco`18oooo001@oooo;C?o00030000<ol0<ol000D0000;<ol000@0
000co`0co`000009<ol000<0000co`0co`00>3?o04Soool0053oool]<ol000D0000co`0co`0co`00
00003S?o00040000<ol0<ol000002C?o00030000<ol0<ol003Pco`18oooo001@oooo;S?o00030000
<ol0<ol0010co`0200002C?o00030000<ol0<ol003Tco`18oooo001AooooQc?o04Soool0057ooon7
<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.39174 .30902 L
.40134 .30902 L
.40381 .30902 L
.40616 .30902 L
.40745 .30902 L
.40818 .30902 L
s
.40818 .30902 m
.40819 .61803 L
s
0 .4 1 r
.02381 .30778 m
.06244 .30759 L
.10458 .30735 L
.14415 .30709 L
.18221 .3068 L
.22272 .30643 L
.26171 .30603 L
.30316 .30553 L
.34309 .30496 L
.3815 .30433 L
.39174 .30415 L
.40134 .30397 L
.40381 .30392 L
.40616 .30387 L
.40745 .30385 L
.40818 .30383 L
.40887 .30902 L
.41006 .30902 L
.41134 .30902 L
.41209 .30902 L
.41277 .30902 L
.41353 .30902 L
.41432 .30902 L
.41502 .30902 L
.41577 .30902 L
.41648 .30902 L
.41712 .30902 L
.41841 .30902 L
.41962 .30902 L
.42094 .30902 L
.42168 .30902 L
.42237 .30902 L
.42354 .30902 L
.42478 .30902 L
.42584 .30902 L
.427 .30902 L
.42825 .30902 L
.42895 .30902 L
.42959 .30902 L
.43082 .30902 L
.43199 .30902 L
.43309 .30902 L
.43425 .30902 L
.43524 .30902 L
.43633 .30902 L
.4375 .30902 L
.43876 .30902 L
.43995 .30902 L
.44103 .30902 L
.4423 .30902 L
Mistroke
.44301 .30902 L
.44365 .30902 L
.44491 .30902 L
.44609 .30902 L
.44676 .30902 L
.44747 .30902 L
.44874 .30902 L
.44944 .30902 L
.4501 .30902 L
.45082 .30902 L
.4516 .30902 L
.45289 .30902 L
.45362 .30902 L
.4543 .30902 L
.45554 .30902 L
.45685 .30902 L
.45802 .30902 L
.45912 .30902 L
.46033 .30902 L
.46163 .30902 L
.46278 .30902 L
.46399 .30902 L
.46462 .30902 L
.46531 .30902 L
.46653 .30902 L
.46769 .30902 L
.46892 .30902 L
.47009 .30902 L
.47116 .30902 L
.47247 .30902 L
.47321 .30902 L
.47389 .30902 L
.47515 .30902 L
.47578 .30902 L
.47648 .30902 L
.47768 .30902 L
.47898 .30902 L
.4802 .30902 L
.48132 .30902 L
.48197 .30902 L
.48266 .30902 L
.48391 .30902 L
.48527 .30902 L
.48675 .30902 L
.48755 .30902 L
.48829 .30902 L
.48899 .30902 L
.48974 .30902 L
.49104 .30902 L
.49178 .30902 L
Mistroke
.49247 .30902 L
.49311 .30902 L
.4938 .30902 L
.49507 .30902 L
.49631 .30902 L
.49746 .30902 L
.49816 .30902 L
.49882 .30902 L
.50006 .30902 L
.50075 .30902 L
.50139 .30902 L
.50209 .30902 L
.50282 .30902 L
.50409 .30902 L
.5053 .30902 L
.50638 .30902 L
.50755 .30902 L
.50882 .30902 L
.50947 .30902 L
.51018 .30902 L
.51143 .30902 L
.51261 .30902 L
.51373 .30902 L
.51491 .30902 L
.51591 .30902 L
.51701 .30902 L
.51819 .30902 L
.51946 .30902 L
.52066 .30902 L
.52174 .30902 L
.52304 .30902 L
.52369 .30902 L
.52441 .30902 L
.52568 .30902 L
.52687 .30902 L
.52759 .30902 L
.52827 .30902 L
.52955 .30902 L
.53026 .30902 L
.53092 .30902 L
.53165 .30902 L
.53242 .30902 L
.53373 .30902 L
.53447 .30902 L
.53515 .30902 L
.5364 .30902 L
.53771 .30902 L
.5389 .30902 L
.54 .30902 L
.54121 .30902 L
Mistroke
.5425 .30902 L
.54373 .30902 L
.54442 .30902 L
.54508 .30902 L
.54639 .30902 L
.54713 .30902 L
.54781 .30902 L
.54901 .30902 L
.55032 .30902 L
.55156 .30902 L
.55271 .30902 L
.55341 .30902 L
.55416 .30902 L
.55487 .30902 L
.55552 .30902 L
.55676 .30902 L
.55808 .30902 L
.55876 .30902 L
.55949 .30902 L
.5608 .30902 L
.56161 .30902 L
.56237 .30902 L
.56305 .30902 L
.5638 .30902 L
.56504 .30902 L
.56621 .30902 L
.56749 .30902 L
.56821 .30902 L
.56887 .30902 L
.57012 .30902 L
.57083 .30902 L
.57149 .30902 L
.57283 .30902 L
.57357 .30902 L
.57425 .30902 L
.5755 .30902 L
.57664 .30902 L
.5779 .30902 L
.57853 .30902 L
.57923 .30902 L
.5804 .30902 L
.58166 .30902 L
.58285 .30902 L
.58393 .30902 L
.58523 .30902 L
.58644 .30902 L
.58753 .30902 L
.58871 .30902 L
.59 .30902 L
.59065 .30902 L
Mistroke
.59136 .30902 L
.59262 .30902 L
.5938 .30902 L
.59499 .30902 L
.59611 .30902 L
.59712 .30902 L
.59822 .30902 L
.59941 .30902 L
.60068 .30902 L
.60176 .30902 L
.60295 .30902 L
.60426 .30902 L
.60492 .30902 L
.60564 .30902 L
.60691 .30902 L
.6081 .30902 L
.60882 .30902 L
.60951 .30902 L
.61078 .30902 L
.6115 .30902 L
.61216 .30902 L
.61288 .30902 L
.61365 .30902 L
.61484 .30902 L
.61612 .30902 L
.61733 .30902 L
.61843 .30902 L
.61972 .30902 L
.62045 .30902 L
.62112 .30902 L
.62236 .30902 L
.62368 .30902 L
.62482 .30902 L
.62604 .30902 L
.62719 .30902 L
.62823 .30902 L
.62941 .30902 L
.63052 .30902 L
.63173 .30902 L
.63303 .30902 L
.63366 .30902 L
.63436 .30902 L
.63509 .30902 L
.63577 .30902 L
.63698 .30902 L
.63829 .30902 L
.63958 .30902 L
.64081 .30902 L
.64192 .30902 L
.64312 .30902 L
Mistroke
.64425 .30902 L
.64548 .30902 L
.64664 .30902 L
.64771 .30902 L
.64895 .30902 L
.65027 .30902 L
.65138 .30902 L
.65259 .30902 L
.65374 .30902 L
.65479 .30902 L
.656 .30902 L
.65714 .30902 L
.6582 .30902 L
.65918 .30902 L
.66025 .30902 L
.66139 .30902 L
.66253 .30902 L
.66377 .30902 L
.66507 .30902 L
.66628 .30902 L
.66741 .30902 L
.66845 .30902 L
.67076 .30902 L
.68087 .30902 L
.682 .30902 L
.68306 .30902 L
.68416 .30902 L
.68538 .30902 L
.68661 .30902 L
.68792 .30902 L
.68915 .30902 L
.69027 .30902 L
.6914 .30902 L
.69245 .30902 L
.6936 .30902 L
.69482 .30902 L
.69599 .30902 L
.69709 .30902 L
.69808 .30902 L
.69915 .30902 L
.70039 .30902 L
.70153 .30902 L
.70284 .30902 L
.70408 .30902 L
.70523 .30902 L
.70629 .30902 L
.70745 .30902 L
.70868 .30902 L
.70992 .30902 L
.71061 .30902 L
Mistroke
.71125 .30902 L
.71248 .30902 L
.71365 .30902 L
.71431 .30902 L
.71501 .30902 L
.71627 .30902 L
.71704 .30902 L
.71777 .30902 L
.71847 .30902 L
.71913 .30902 L
.72035 .30902 L
.721 .30902 L
.72169 .30902 L
.72242 .30902 L
.72311 .30902 L
.7244 .30902 L
.72561 .30902 L
.72672 .30902 L
.72795 .30902 L
.72925 .30902 L
.73054 .30902 L
.73127 .30902 L
.73194 .30902 L
.73317 .30902 L
.73446 .30902 L
.73515 .30902 L
.73588 .30902 L
.73657 .30902 L
.7372 .30902 L
.73795 .30902 L
.73875 .30902 L
.73951 .30902 L
.74021 .30902 L
.74146 .30902 L
.74265 .30902 L
.74371 .30902 L
.74488 .30902 L
.74614 .30902 L
.74684 .30902 L
.74748 .30902 L
.74872 .30902 L
.74989 .30902 L
.75099 .30902 L
.75201 .30902 L
.75308 .30902 L
.75425 .30902 L
.75543 .30902 L
.7567 .30902 L
.75788 .30902 L
.75896 .30902 L
Mistroke
.76024 .30902 L
.76088 .30902 L
.76159 .30902 L
.76285 .30902 L
.76403 .30902 L
.76471 .30902 L
.76542 .30902 L
.76669 .30902 L
.76955 .30902 L
.77085 .30902 L
.77159 .30902 L
.77226 .30902 L
.7735 .30902 L
.77481 .30902 L
.77599 .30902 L
.77709 .30902 L
.77829 .30902 L
.77959 .30902 L
.78082 .30902 L
.78151 .30902 L
.78215 .30902 L
.78333 .30902 L
.78458 .30902 L
.78582 .30902 L
.78698 .30902 L
.78915 .30902 L
.79935 .30902 L
.81772 .30902 L
.85635 .30902 L
.89744 .30902 L
.937 .30902 L
.97506 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo0011oooo=P1Vof7oool00`000?ooooooo`15oooo000;ooooo`0000L0000?oooo000Aoooo00<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000o`2I<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo01?oool0017oool0
0`0003?o03?o000_<ol000<0000co`0co`00;c?o00030000o`2I<ol002hco`000`0003?o03?o000_
<ol000<0003oooooool0;oooo`030000oooooooo01?oool0017ooomU<ol000?o09Tco`0co`00Gc?o
00030000oooooooo04Goool0017ooomU<ol000?o09Tco`0co`00Gc?o00030000oooooooo04Goool0
017ooomU<ol000?o09Tco`0co`00Gc?o00030000oooooooo04Goool0017ooomU<ol000?o09Tco`0c
o`00Gc?o00030000oooooooo04Goool0017ooomU<ol000?o09Tco`0co`00Gc?o00030000oooooooo
04Goool0017ooomU<ol000?o09Tco`0co`00Gc?o00800016oooo000AooooIC?o0003o`2I<ol0<ol0
05lco`000`000?ooooooo`15oooo000AooooIC?o0003o`2I<ol0<ol005lco`000`000?ooooooo`15
oooo000AooooIC?o0003o`2I<ol0<ol005lco`000`000?ooooooo`15oooo000AooooIC?o0003o`2I
<ol0<ol005lco`000`000?ooooooo`15oooo000AooooIC?o0003o`2I<ol0<ol005lco`000`000?oo
ooooo`15oooo000AooooIC?o0003o`2I<ol0<ol005lco`000`000?ooooooo`15oooo000AooooIC?o
0003o`2I<ol0<ol005lco`000`000?ooooooo`15oooo000Aoooo0P0006<co`000ol0VC?o03?o001O
<ol00P0004Koool001?oool20000HC?o0003o`2I<ol0<ol005lco`000`000?ooooooo`15oooo000E
oooo0P0005lco`000ol0VC?o03?o001O<ol000<0003oooooool0AOooo`005oooo`80001M<ol000?o
09Tco`0co`00Gc?o00030000oooooooo04Goool001Woool20000Fc?o0003o`2I<ol0<ol005lco`00
0`000?ooooooo`15oooo000Koooo0P0005Tco`000ol0VC?o03?o001O<ol000<0003oooooool0AOoo
o`007Oooo`80001G<ol000?o09Tco`0co`00Gc?o00030000oooooooo04Goool001ooool00`0003?o
03?o001D<ol000?o09Tco`0co`00Gc?o00030000oooooooo04Goool0023oool00`0003?o03?o001C
<ol000?o09Tco`0co`00Gc?o00800016oooo000Qoooo0P0005<co`000ol0VC?o03?o001O<ol000<0
003oooooool0AOooo`008oooo`030000<ol0<ol0050co`000ol0VC?o03?o001O<ol000<0003ooooo
ool0AOooo`009?ooo`80001@<ol000?o09Tco`0co`00Gc?o00030000oooooooo04Goool002Koool0
0`0003?o03?o001=<ol000?o09Tco`0co`00Gc?o00030000oooooooo04Goool002Ooool00`0003?o
03?o001<<ol000?o09Tco`0co`00Gc?o00030000oooooooo04Goool002Soool00`0003?o03?o001;
<ol000?o09Tco`0co`00AS?o00800004<ol00P0000@co`0200000c?o00@00004<ol000<0003ooooo
ool0AOooo`00:Oooo`030000<ol0<ol004Xco`000ol0VC?o03?o0015<ol000@0000co`0co`000008
<ol000@0000co`0co`000002<ol000<0000co`0co`001C?o00030000oooooooo04Goool002[oool0
0`0003?o03?o0019<ol000?o09Tco`0co`00AC?o00040000<ol0<ol0000023?o00040000<ol0<ol0
00000c?o00030000<ol0<ol000@co`030000AOooo`00:oooo`800019<ol000?o09Tco`0co`00AC?o
00040000<ol0<ol0000023?o00040000<ol0<ol0000013?o00030000<ol0<ol000<co`000`000?oo
ooooo`15oooo000]oooo00<0000co`0co`00AS?o0003o`2I<ol0<ol004Dco`00100003?o03?o0000
00Pco`00100003?o03?o0000008co`00100003?o03?o000000@co`000`000?ooooooo`15oooo000^
oooo00<0000co`0co`00AC?o0003o`2I<ol0<ol004Hco`0200002S?o00800004<ol00P0000Dco`00
0`000?ooooooo`15oooo000_oooo00<0000co`0co`00A3?o0003o`2I<ol0<ol005lco`000`000?oo
ooooo`15oooo000`oooo00<0000co`0co`00@c?o0003o`2I<ol0<ol005lco`000`000?ooooooo`15
oooo000aoooo00<0000co`0co`00@S?o0003o`2I<ol0<ol005lco`000`000?ooooooo`15oooo000b
oooo00<0000co`0co`00@C?o0003o`2I<ol0<ol005lco`000`000?ooooooo`15oooo000coooo00<0
000co`0co`00@3?o0003o`2I<ol0<ol005lco`020000A_ooo`00<oooo`030000<ol0<ol0040co`00
0ol0VC?o03?o001O<ol000<0003oooooool0AOooo`00=?ooo`030000<ol0<ol003lco`000ol0VC?o
03?o001O<ol000<0003oooooool0AOooo`00=Oooo`030000<ol0<ol003hco`000ol0VC?o03?o001O
<ol000<0003oooooool0AOooo`00=_ooo`030000<ol0<ol003dco`000ol0VC?o03?o001O<ol000<0
003oooooool0AOooo`00=oooo`030000<ol0<ol003`co`000ol0VC?o03?o001O<ol000<0003ooooo
ool0AOooo`00>?ooo`030000<ol0<ol003/co`000ol0VC?o03?o001O<ol000<0003oooooool0AOoo
o`00>?ooo`030000<ol0<ol003/co`000ol0VC?o03?o001O<ol000<0003oooooool0AOooo`00>Ooo
o`030000<ol0<ol003Xco`000ol0VC?o03?o001O<ol00P0004Koool003[oool00`0003?o03?o000i
<ol000?o09Tco`0co`00Gc?o00030000oooooooo04Goool003_oool00`0003?o03?o000h<ol000?o
09Tco`0co`00Gc?o00030000oooooooo04Goool003coool00`0003?o03?o000g<ol000?o09Tco`0c
o`00Gc?o00030000oooooooo04Goool003coool00`0003?o03?o000g<ol000?o09Tco`0co`00Gc?o
00030000oooooooo04Goool003goool00`0003?o03?o000f<ol000?o09Tco`0co`00Gc?o00030000
oooooooo04Goool003goool00`0003?o03?o000f<ol000?o09Tco`0co`00Gc?o00030000oooooooo
04Goool003koool00`0003?o03?o000e<ol000?o09Tco`0co`00Gc?o00030000oooooooo04Goool0
03koool00`0003?o03?o000e<ol000?o09Tco`0co`00Gc?o00030000oooooooo04Goool003ooool0
0`0003?o03?o000d<ol000?o09Tco`0co`00Gc?o00800016oooo000ooooo00<0000co`0co`00=3?o
0003o`2I<ol0<ol005lco`000`000?ooooooo`15oooo0010oooo00<0000co`0co`00<c?o0003o`2I
<ol0<ol005lco`000`000?ooooooo`15oooo0011oooo00<0000co`0co`00<S?o0003o`2I<ol0<ol0
05lco`000`000?ooooooo`15oooo0011oooo00<0000co`0co`00<S?o0003o`2I<ol0<ol005lco`00
0`000?ooooooo`15oooo0012oooo00<0000co`0co`00<C?o0003o`2I<ol0<ol005lco`000`000?oo
ooooo`15oooo0012oooo00<0000co`0co`00<C?o0003o`2I<ol0<ol004Hco`02000013?o00800004
<ol00P0000Dco`0300000c?o00030000oooooooo04Goool004?oool00`0003?o03?o000`<ol000?o
09Tco`0co`00AC?o00040000<ol0<ol0000023?o00040000<ol0<ol000001C?o00030000<ol0<ol0
008co`000`000?ooooooo`15oooo0013oooo00<0000co`0co`00<3?o0003o`2I<ol0<ol004Dco`00
100003?o03?o000000Pco`00100003?o03?o0000008co`0500000c?o00<00015oooo0014oooo00<0
000co`0co`00;c?o0003o`2I<ol0<ol004Dco`00100003?o03?o000000Pco`00100003?o03?o0000
008co`00100003?o03?o000000@co`000`000?ooooooo`15oooo0014oooo00<0000co`0co`00;c?o
0003o`2I<ol0<ol004Dco`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o
00000004<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol002hco`000ol0VC?o03?o0016
<ol00P0000Xco`0200001C?o00800004<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol0
02hco`000ol0VC?o03?o001O<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol002dco`00
0ol0VC?o03?o001O<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol002dco`000ol0VC?o
03?o001O<ol000<0003oooooool0AOooo`00Aoooo`030000<ol0<ol002`co`000ol0VC?o03?o001O
<ol000<0003oooooool0AOooo`00Aoooo`030000<ol0<ol002`co`000ol0VC?o03?o001O<ol00P00
04Koool004Soool00`0003?o03?o000[<ol000?o09Tco`0co`00Gc?o00030000oooooooo04Goool0
04Soool00`0003?o03?o000[<ol000?o09Tco`0co`00Gc?o00030000oooooooo04Goool004Woool0
0`0003?o03?o000Z<ol000?o09Tco`0co`00Gc?o00030000oooooooo04Goool004Woool00`0003?o
03?o000Z<ol000?o09Tco`0co`00Gc?o00030000oooooooo04Goool004[oool00`0003?o03?o000Y
<ol000?o09Tco`0co`00Gc?o00030000oooooooo04Goool004[oool00`0003?o03?o000Y<ol000?o
09Tco`0co`00Gc?o00030000oooooooo04Goool004_oool00`0003?o03?o000X<ol000?o09Tco`0c
o`00Gc?o00030000oooooooo04Goool004_oool00`0003?o03?o000X<ol000?o09Tco`0co`00Gc?o
00800016oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001=ooooRc?o
04Soool004gooon;<ol0B?ooo`00C_ooobXco`000`0003?o03?o000W<ol000<0000co`0co`00<c?o
04Soool004kooolY<ol000<0000co`0co`0023?o00030000<ol0<ol001hco`000`0003?o03?o000b
<ol0B?ooo`00CoooobPco`000`0003?o03?o0002<ol00P0000@co`000`0003?o03?o0006<ol00P00
00@co`02000013?o00800003<ol01@00008co`000`0003?o03?o000b<ol0B?ooo`00CoooobPco`00
1@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o00030000<ol0<ol000@co`00100003?o
03?o000000Pco`00100003?o03?o000000@co`000`0003?o03?o0002<ol000<0000co`0co`00<S?o
04Soool004oooolW<ol000<0000co`0co`000S?o00030000<ol0<ol000`co`00100003?o03?o0000
00Pco`00100003?o03?o000000@co`000`0003?o03?o0003<ol000<0000co`0co`00<C?o04Soool0
053ooolW<ol000<0000co`0co`001@0000/co`00100003?o03?o000000Pco`00100003?o03?o0000
00@co`000`0003?o03?o0002<ol000<0000co`0co`00<S?o04Soool0053ooolW<ol000D0000co`0c
o`0co`0000003S?o00040000<ol0<ol0000023?o00040000<ol0<ol0000013?o00030000<ol0<ol0
008co`000`0003?o03?o000b<ol0B?ooo`00D?ooobPco`000`0003?o03?o000@<ol00P0000Xco`02
000013?o00800003<ol000<0000co`0co`00<c?o04Soool0057ooon7<ol0B?ooo`00DOooohLco`18
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40134 .30902 L
.40616 .30902 L
.40882 .30902 L
.41013 .30902 L
.41134 .30902 L
.41203 .30902 L
s
.41203 .30902 m
.41203 .61803 L
s
0 .4 1 r
.02381 .30655 m
.06244 .30617 L
.10458 .30569 L
.14415 .30516 L
.18221 .30457 L
.22272 .30385 L
.26171 .30304 L
.30316 .30204 L
.34309 .30091 L
.3815 .29964 L
.40134 .29891 L
.40616 .29873 L
.40882 .29862 L
.41013 .29857 L
.41134 .29852 L
.41203 .2985 L
.41276 .30902 L
.41358 .30902 L
.41432 .30902 L
.41499 .30902 L
.41572 .30902 L
.41703 .30902 L
.41773 .30902 L
.41838 .30902 L
.41906 .30902 L
.41981 .30902 L
.42104 .30902 L
.42237 .30902 L
.42358 .30902 L
.42428 .30902 L
.42493 .30902 L
.42624 .30902 L
.42697 .30902 L
.42765 .30902 L
.43254 .30902 L
.43378 .30902 L
.43448 .30902 L
.43511 .30902 L
.43586 .30902 L
.43657 .30902 L
.43722 .30902 L
.43793 .30902 L
.43861 .30902 L
.43936 .30902 L
.44015 .30902 L
.44088 .30902 L
.4422 .30902 L
.44288 .30902 L
.44361 .30902 L
.44431 .30902 L
Mistroke
.44494 .30902 L
.44619 .30902 L
.44688 .30902 L
.44764 .30902 L
.44835 .30902 L
.449 .30902 L
.45019 .30902 L
.45149 .30902 L
.45215 .30902 L
.45285 .30902 L
.45412 .30902 L
.45536 .30902 L
.45606 .30902 L
.4567 .30902 L
.45789 .30902 L
.45915 .30902 L
.46027 .30902 L
.46133 .30902 L
.46248 .30902 L
.46373 .30902 L
.46499 .30902 L
.46613 .30902 L
.46746 .30902 L
.4687 .30902 L
.46986 .30902 L
.47092 .30902 L
.47209 .30902 L
.47332 .30902 L
.47457 .30902 L
.47527 .30902 L
.47591 .30902 L
.47714 .30902 L
.47832 .30902 L
.47898 .30902 L
.47968 .30902 L
.48095 .30902 L
.48165 .30902 L
.4823 .30902 L
.48303 .30902 L
.48381 .30902 L
.48637 .30902 L
.48707 .30902 L
.48782 .30902 L
.48852 .30902 L
.48917 .30902 L
.48989 .30902 L
.49056 .30902 L
.49129 .30902 L
.49207 .30902 L
.49338 .30902 L
Mistroke
.49412 .30902 L
.49482 .30902 L
.49612 .30902 L
.49736 .30902 L
.49847 .30902 L
.49968 .30902 L
.501 .30902 L
.50173 .30902 L
.5024 .30902 L
.5037 .30902 L
.50492 .30902 L
.50608 .30902 L
.50733 .30902 L
.50851 .30902 L
.50958 .30902 L
.51084 .30902 L
.51155 .30902 L
.51221 .30902 L
.51341 .30902 L
.51469 .30902 L
.51591 .30902 L
.51722 .30902 L
.51846 .30902 L
.5196 .30902 L
.52086 .30902 L
.52157 .30902 L
.52224 .30902 L
.52294 .30902 L
.52358 .30902 L
.52432 .30902 L
.52501 .30902 L
.52608 .30902 L
.52725 .30902 L
.52848 .30902 L
.52963 .30902 L
.5307 .30902 L
.53168 .30902 L
.53281 .30902 L
.53388 .30902 L
.53504 .30902 L
.53627 .30902 L
.53733 .30902 L
.53848 .30902 L
.53919 .30902 L
.53983 .30902 L
.54111 .30902 L
.54227 .30902 L
.54349 .30902 L
.54472 .30902 L
.54541 .30902 L
Mistroke
.54605 .30902 L
.54722 .30902 L
.54847 .30902 L
.54958 .30902 L
.55063 .30902 L
.55177 .30902 L
.553 .30902 L
.5543 .30902 L
.55504 .30902 L
.55573 .30902 L
.55698 .30902 L
.55768 .30902 L
.55832 .30902 L
.55952 .30902 L
.56082 .30902 L
.56205 .30902 L
.56318 .30902 L
.56424 .30902 L
.56538 .30902 L
.56646 .30902 L
.56743 .30902 L
.56858 .30902 L
.56983 .30902 L
.57101 .30902 L
.5721 .30902 L
.57322 .30902 L
.57428 .30902 L
.57543 .30902 L
.57668 .30902 L
.57791 .30902 L
.57921 .30902 L
.58032 .30902 L
.58153 .30902 L
.58285 .30902 L
.58407 .30902 L
.5847 .30902 L
.5854 .30902 L
.58613 .30902 L
.58681 .30902 L
.58807 .30902 L
.58922 .30902 L
.58985 .30902 L
.59054 .30902 L
.5918 .30902 L
.59301 .30902 L
.59415 .30902 L
.59546 .30902 L
.59664 .30902 L
.59777 .30902 L
.5988 .30902 L
Mistroke
.59994 .30902 L
.60113 .30902 L
.60244 .30902 L
.60363 .30902 L
.60429 .30902 L
.605 .30902 L
.6063 .30902 L
.60752 .30902 L
.60881 .30902 L
.61113 .30902 L
.61242 .30902 L
.61315 .30902 L
.61381 .30902 L
.61504 .30902 L
.61634 .30902 L
.61702 .30902 L
.61776 .30902 L
.61908 .30902 L
.61989 .30902 L
.62065 .30902 L
.62134 .30902 L
.62208 .30902 L
.62332 .30902 L
.62445 .30902 L
.62575 .30902 L
.62698 .30902 L
.62805 .30902 L
.62918 .30902 L
.63042 .30902 L
.63157 .30902 L
.63279 .30902 L
.63344 .30902 L
.63412 .30902 L
.63537 .30902 L
.63652 .30902 L
.63778 .30902 L
.63849 .30902 L
.63913 .30902 L
.63989 .30902 L
.64061 .30902 L
.64127 .30902 L
.64199 .30902 L
.64329 .30902 L
.64452 .30902 L
.64522 .30902 L
.64586 .30902 L
.6466 .30902 L
.6473 .30902 L
.64803 .30902 L
.64872 .30902 L
Mistroke
.64951 .30902 L
.65022 .30902 L
.65153 .30902 L
.65226 .30902 L
.65294 .30902 L
.65406 .30902 L
.65529 .30902 L
.65657 .30902 L
.65777 .30902 L
.65845 .30902 L
.6591 .30902 L
.66031 .30902 L
.66162 .30902 L
.66236 .30902 L
.66304 .30902 L
.66422 .30902 L
.66546 .30902 L
.66652 .30902 L
.66768 .30902 L
.66893 .30902 L
.67026 .30902 L
.67267 .30902 L
.68171 .30902 L
.70231 .30902 L
.70355 .30902 L
.70425 .30902 L
.70489 .30902 L
.70612 .30902 L
.70729 .30902 L
.7098 .30902 L
.71114 .30902 L
.71187 .30902 L
.71256 .30902 L
.71331 .30902 L
.714 .30902 L
.71464 .30902 L
.71533 .30902 L
.71609 .30902 L
.7169 .30902 L
.71834 .30902 L
.71957 .30902 L
.72088 .30902 L
.72164 .30902 L
.72232 .30902 L
.72301 .30902 L
.72367 .30902 L
.72483 .30902 L
.7261 .30902 L
.72675 .30902 L
.72744 .30902 L
Mistroke
.72869 .30902 L
.72993 .30902 L
.73111 .30902 L
.73217 .30902 L
.73333 .30902 L
.73404 .30902 L
.73471 .30902 L
.73596 .30902 L
.73666 .30902 L
.73731 .30902 L
.73802 .30902 L
.73877 .30902 L
.74001 .30902 L
.74117 .30902 L
.74245 .30902 L
.74317 .30902 L
.74382 .30902 L
.74501 .30902 L
.74629 .30902 L
.74751 .30902 L
.74862 .30902 L
.7498 .30902 L
.75104 .30902 L
.75232 .30902 L
.75305 .30902 L
.75372 .30902 L
.75491 .30902 L
.75604 .30902 L
.75705 .30902 L
.75815 .30902 L
.75935 .30902 L
.76061 .30902 L
.7617 .30902 L
.76289 .30902 L
.76355 .30902 L
.76427 .30902 L
.76559 .30902 L
.76687 .30902 L
.76805 .30902 L
.76878 .30902 L
.76946 .30902 L
.77074 .30902 L
.77146 .30902 L
.77212 .30902 L
.77284 .30902 L
.77361 .30902 L
.7748 .30902 L
.77608 .30902 L
.77729 .30902 L
.77839 .30902 L
Mistroke
.77968 .30902 L
.78041 .30902 L
.78109 .30902 L
.78233 .30902 L
.78364 .30902 L
.78478 .30902 L
.78603 .30902 L
.78733 .30902 L
.78854 .30902 L
.79302 .30902 L
.80313 .30902 L
.82142 .30902 L
.86049 .30902 L
.90202 .30902 L
.94203 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00L_ooo`H0I_mPoooo00<0003oooooool0AOooo`00EOoooad0I_l5
oooo00<0I_ooooooool0G_ooo`030000oooooooo04Goool0017ooom406Ko8_ooo`0306Kooooooooo
05koool00`000?ooooooo`15oooo000;ooooo`0000L0000?oooo000Aoooo00<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0o`2I00Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo01?oool0017oool00`0003?o03?o000_
<ol000<0000co`0co`00;c?o00030000<ol0o`2I02hco`000`0003?o03?o000_<ol000<0003ooooo
ool0;oooo`030000oooooooo01?oool0017ooomV<ol000?o09Tco`0co`00GS?o00030000oooooooo
04Goool0017ooomV<ol000?o09Tco`0co`00GS?o00030000oooooooo04Goool0017ooomV<ol000?o
09Tco`0co`00GS?o00030000oooooooo04Goool0017ooomV<ol000?o09Tco`0co`00GS?o00030000
oooooooo04Goool0017ooomV<ol000?o09Tco`0co`00GS?o00030000oooooooo04Goool0017ooomV
<ol000?o09Tco`0co`00GS?o00800016oooo000AooooIS?o0003o`2I<ol0<ol005hco`000`000?oo
ooooo`15oooo000AooooIS?o0003o`2I<ol0<ol005hco`000`000?ooooooo`15oooo000AooooIS?o
0003o`2I<ol0<ol005hco`000`000?ooooooo`15oooo000AooooIS?o0003o`2I<ol0<ol005hco`00
0`000?ooooooo`15oooo000AooooIS?o0003o`2I<ol0<ol005hco`000`000?ooooooo`15oooo000A
ooooIS?o0003o`2I<ol0<ol005hco`000`000?ooooooo`15oooo000AooooIS?o0003o`2I<ol0<ol0
05hco`000`000?ooooooo`15oooo000Aoooo0P0006@co`000ol0VC?o03?o001N<ol00P0004Koool0
01?oool20000HS?o0003o`2I<ol0<ol005hco`000`000?ooooooo`15oooo000Eoooo0P00060co`00
0ol0VC?o03?o001N<ol000<0003oooooool0AOooo`005oooo`80001N<ol000?o09Tco`0co`00GS?o
00030000oooooooo04Goool001Woool20000G3?o0003o`2I<ol0<ol005hco`000`000?ooooooo`15
oooo000Koooo0P0005Xco`000ol0VC?o03?o001N<ol000<0003oooooool0AOooo`007Oooo`80001H
<ol000?o09Tco`0co`00GS?o00030000oooooooo04Goool001ooool00`0003?o03?o001E<ol000?o
09Tco`0co`00GS?o00030000oooooooo04Goool0023oool00`0003?o03?o001D<ol000?o09Tco`0c
o`00GS?o00800016oooo000Qoooo0P0005@co`000ol0VC?o03?o001N<ol000<0003oooooool0AOoo
o`008oooo`030000<ol0<ol0054co`000ol0VC?o03?o001N<ol000<0003oooooool0AOooo`009?oo
o`80001A<ol000?o09Tco`0co`00GS?o00030000oooooooo04Goool002Koool00`0003?o03?o001>
<ol000?o09Tco`0co`00GS?o00030000oooooooo04Goool002Ooool00`0003?o03?o001=<ol000?o
09Tco`0co`00GS?o00030000oooooooo04Goool002Soool00`0003?o03?o001<<ol000?o09Tco`0c
o`00AC?o00800004<ol00P0000@co`0200000c?o00@00004<ol000<0003oooooool0AOooo`00:Ooo
o`030000<ol0<ol004/co`000ol0VC?o03?o0014<ol000@0000co`0co`000008<ol000@0000co`0c
o`000002<ol000<0000co`0co`001C?o00030000oooooooo04Goool002[oool00`0003?o03?o001:
<ol000?o09Tco`0co`00A3?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000
<ol0<ol000@co`030000AOooo`00:oooo`80001:<ol000?o09Tco`0co`00A3?o00040000<ol0<ol0
000023?o00040000<ol0<ol0000013?o00030000<ol0<ol000<co`000`000?ooooooo`15oooo000]
oooo00<0000co`0co`00Ac?o0003o`2I<ol0<ol004@co`00100003?o03?o000000Pco`00100003?o
03?o0000008co`00100003?o03?o000000@co`000`000?ooooooo`15oooo000^oooo00<0000co`0c
o`00AS?o0003o`2I<ol0<ol004Dco`0200002S?o00800004<ol00P0000Dco`000`000?ooooooo`15
oooo000_oooo00<0000co`0co`00AC?o0003o`2I<ol0<ol005hco`000`000?ooooooo`15oooo000`
oooo00<0000co`0co`00A3?o0003o`2I<ol0<ol005hco`000`000?ooooooo`15oooo000aoooo00<0
000co`0co`00@c?o0003o`2I<ol0<ol005hco`000`000?ooooooo`15oooo000boooo00<0000co`0c
o`00@S?o0003o`2I<ol0<ol005hco`000`000?ooooooo`15oooo000coooo00<0000co`0co`00@C?o
0003o`2I<ol0<ol005hco`020000A_ooo`00<oooo`030000<ol0<ol0044co`000ol0VC?o03?o001N
<ol000<0003oooooool0AOooo`00=?ooo`030000<ol0<ol0040co`000ol0VC?o03?o001N<ol000<0
003oooooool0AOooo`00=Oooo`030000<ol0<ol003lco`000ol0VC?o03?o001N<ol000<0003ooooo
ool0AOooo`00=_ooo`030000<ol0<ol003hco`000ol0VC?o03?o001N<ol000<0003oooooool0AOoo
o`00=oooo`030000<ol0<ol003dco`000ol0VC?o03?o001N<ol000<0003oooooool0AOooo`00>?oo
o`030000<ol0<ol003`co`000ol0VC?o03?o001N<ol000<0003oooooool0AOooo`00>?ooo`030000
<ol0<ol003`co`000ol0VC?o03?o001N<ol000<0003oooooool0AOooo`00>Oooo`030000<ol0<ol0
03/co`000ol0VC?o03?o001N<ol00P0004Koool003[oool00`0003?o03?o000j<ol000?o09Tco`0c
o`00GS?o00030000oooooooo04Goool003_oool00`0003?o03?o000i<ol000?o09Tco`0co`00GS?o
00030000oooooooo04Goool003coool00`0003?o03?o000h<ol000?o09Tco`0co`00GS?o00030000
oooooooo04Goool003coool00`0003?o03?o000h<ol000?o09Tco`0co`00GS?o00030000oooooooo
04Goool003goool00`0003?o03?o000g<ol000?o09Tco`0co`00GS?o00030000oooooooo04Goool0
03goool00`0003?o03?o000g<ol000?o09Tco`0co`00GS?o00030000oooooooo04Goool003koool0
0`0003?o03?o000f<ol000?o09Tco`0co`00GS?o00030000oooooooo04Goool003koool00`0003?o
03?o000f<ol000?o09Tco`0co`00GS?o00030000oooooooo04Goool003ooool00`0003?o03?o000e
<ol000?o09Tco`0co`00GS?o00800016oooo000ooooo00<0000co`0co`00=C?o0003o`2I<ol0<ol0
05hco`000`000?ooooooo`15oooo0010oooo00<0000co`0co`00=3?o0003o`2I<ol0<ol005hco`00
0`000?ooooooo`15oooo0011oooo00<0000co`0co`00<c?o0003o`2I<ol0<ol005hco`000`000?oo
ooooo`15oooo0011oooo00<0000co`0co`00<c?o0003o`2I<ol0<ol005hco`000`000?ooooooo`15
oooo0012oooo00<0000co`0co`00<S?o0003o`2I<ol0<ol005hco`000`000?ooooooo`15oooo0012
oooo00<0000co`0co`00<S?o0003o`2I<ol0<ol004Dco`02000013?o00800004<ol00P0000Dco`03
00000c?o00030000oooooooo04Goool004?oool00`0003?o03?o000a<ol000?o09Tco`0co`00A3?o
00040000<ol0<ol0000023?o00040000<ol0<ol000001C?o00030000<ol0<ol0008co`000`000?oo
ooooo`15oooo0013oooo00<0000co`0co`00<C?o0003o`2I<ol0<ol004@co`00100003?o03?o0000
00Pco`00100003?o03?o0000008co`0500000c?o00<00015oooo0014oooo00<0000co`0co`00<3?o
0003o`2I<ol0<ol004@co`00100003?o03?o000000Pco`00100003?o03?o0000008co`00100003?o
03?o000000@co`000`000?ooooooo`15oooo0014oooo00<0000co`0co`00<3?o0003o`2I<ol0<ol0
04@co`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o00000004<ol000<0
003oooooool0AOooo`00AOooo`030000<ol0<ol002lco`000ol0VC?o03?o0015<ol00P0000Xco`02
00001C?o00800004<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol002lco`000ol0VC?o
03?o001N<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol002hco`000ol0VC?o03?o001N
<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol002hco`000ol0VC?o03?o001N<ol000<0
003oooooool0AOooo`00Aoooo`030000<ol0<ol002dco`000ol0VC?o03?o001N<ol000<0003ooooo
ool0AOooo`00Aoooo`030000<ol0<ol002dco`000ol0VC?o03?o001N<ol00P0004Koool004Soool0
0`0003?o03?o000/<ol000?o09Tco`0co`00GS?o00030000oooooooo04Goool004Soool00`0003?o
03?o000/<ol000?o09Tco`0co`00GS?o00030000oooooooo04Goool004Woool00`0003?o03?o000[
<ol000?o09Tco`0co`00GS?o00030000oooooooo04Goool004Woool00`0003?o03?o000[<ol000?o
09Tco`0co`00GS?o00030000oooooooo04Goool004[oool00`0003?o03?o000Z<ol000?o09Tco`0c
o`00GS?o00030000oooooooo04Goool004[oool00`0003?o03?o000Z<ol000?o09Tco`0co`00GS?o
00030000oooooooo04Goool004_oool00`0003?o03?o000Y<ol000?o09Tco`0co`00GS?o00030000
oooooooo04Goool004_oool00`0003?o03?o000Y<ol000?o09Tco`0co`00GS?o00800016oooo001<
ooooS3?o04Soool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001=ooooRc?o04Soool004gooon;
<ol0B?ooo`00C_ooobXco`000`0003?o03?o000W<ol000<0000co`0co`00<c?o04Soool004kooolY
<ol000<0000co`0co`0023?o00030000<ol0<ol001hco`000`0003?o03?o000b<ol0B?ooo`00Cooo
obPco`000`0003?o03?o0002<ol00P0000@co`000`0003?o03?o0006<ol00P0000@co`02000013?o
00800003<ol0100000<co`000`0003?o03?o000b<ol0B?ooo`00CoooobPco`001@0003?o03?o03?o
00000002<ol000<0000co`0co`000S?o00030000<ol0<ol000@co`00100003?o03?o000000Pco`00
100003?o03?o0000008co`000`0003?o03?o0004<ol000<0000co`0co`00<S?o04Soool004oooolW
<ol000<0000co`0co`000S?o00030000<ol0<ol000`co`00100003?o03?o000000Pco`00100003?o
03?o000000<co`000`0003?o03?o0004<ol000<0000co`0co`00<C?o04Soool0053ooolW<ol000<0
000co`0co`001@0000/co`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`0003?o
03?o0002<ol000<0000co`0co`00<S?o04Soool0053ooolW<ol000D0000co`0co`0co`0000003S?o
00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol000000c?o00030000
<ol0<ol0038co`18oooo001@oooo:3?o00030000<ol0<ol0010co`0200002S?o00800004<ol00P00
00<co`000`0003?o03?o000c<ol0B?ooo`00DOooohLco`18oooo001AooooQc?o04Soool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.03) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40134 .30902 L
.40616 .30902 L
.41134 .30902 L
.41287 .30902 L
.41432 .30902 L
.41562 .30902 L
s
.41562 .30902 m
.41562 .61803 L
s
0 .4 1 r
.02381 .30532 m
.06244 .30475 L
.10458 .30402 L
.14415 .30323 L
.18221 .30235 L
.22272 .30126 L
.26171 .30005 L
.30316 .29854 L
.34309 .29685 L
.3815 .29495 L
.40134 .29386 L
.40616 .29358 L
.41134 .29327 L
.41287 .29318 L
.41432 .29309 L
.41562 .29302 L
.41635 .30902 L
.41703 .30902 L
.41773 .30902 L
.41839 .30902 L
.41961 .30902 L
.42094 .30902 L
.42167 .30902 L
.42237 .30902 L
.42361 .30902 L
.42474 .30902 L
.42596 .30902 L
.42664 .30902 L
.42728 .30902 L
.42834 .30902 L
.42951 .30902 L
.43073 .30902 L
.43187 .30902 L
.43315 .30902 L
.43379 .30902 L
.43449 .30902 L
.43573 .30902 L
.43689 .30902 L
.4376 .30902 L
.43826 .30902 L
.43951 .30902 L
.44021 .30902 L
.44085 .30902 L
.44156 .30902 L
.4423 .30902 L
.44361 .30902 L
.4448 .30902 L
.44546 .30902 L
.44618 .30902 L
.44749 .30902 L
Mistroke
.44871 .30902 L
.45 .30902 L
.45123 .30902 L
.45234 .30902 L
.45507 .30902 L
.45581 .30902 L
.4565 .30902 L
.45723 .30902 L
.45802 .30902 L
.45872 .30902 L
.45937 .30902 L
.46011 .30902 L
.46081 .30902 L
.46204 .30902 L
.46273 .30902 L
.46337 .30902 L
.46455 .30902 L
.4658 .30902 L
.46686 .30902 L
.46802 .30902 L
.46927 .30902 L
.46997 .30902 L
.47061 .30902 L
.47185 .30902 L
.47302 .30902 L
.47412 .30902 L
.47528 .30902 L
.47628 .30902 L
.47737 .30902 L
.47854 .30902 L
.4798 .30902 L
.48099 .30902 L
.48207 .30902 L
.48714 .30902 L
.48785 .30902 L
.48853 .30902 L
.48923 .30902 L
.49 .30902 L
.49128 .30902 L
.492 .30902 L
.49265 .30902 L
.49386 .30902 L
.49499 .30902 L
.49622 .30902 L
.49754 .30902 L
.4982 .30902 L
.49893 .30902 L
.50024 .30902 L
.50152 .30902 L
.50269 .30902 L
Mistroke
.50389 .30902 L
.50504 .30902 L
.50625 .30902 L
.50757 .30902 L
.50871 .30902 L
.50994 .30902 L
.51108 .30902 L
.51214 .30902 L
.51279 .30902 L
.51349 .30902 L
.51418 .30902 L
.51495 .30902 L
.51561 .30902 L
.51632 .30902 L
.51759 .30902 L
.51823 .30902 L
.51892 .30902 L
.52018 .30902 L
.52141 .30902 L
.52254 .30902 L
.52377 .30902 L
.52507 .30902 L
.52575 .30902 L
.5265 .30902 L
.5278 .30902 L
.52904 .30902 L
.53036 .30902 L
.53161 .30902 L
.53274 .30902 L
.53401 .30902 L
.53473 .30902 L
.53539 .30902 L
.53661 .30902 L
.53789 .30902 L
.53857 .30902 L
.53929 .30902 L
.5406 .30902 L
.5414 .30902 L
.54215 .30902 L
.54283 .30902 L
.54357 .30902 L
.54423 .30902 L
.54491 .30902 L
.54614 .30902 L
.54746 .30902 L
.54821 .30902 L
.54891 .30902 L
.55018 .30902 L
.55133 .30902 L
.55197 .30902 L
Mistroke
.55267 .30902 L
.55393 .30902 L
.55505 .30902 L
.55629 .30902 L
.55759 .30902 L
.5588 .30902 L
.55993 .30902 L
.56097 .30902 L
.56216 .30902 L
.5633 .30902 L
.56462 .30902 L
.56582 .30902 L
.56648 .30902 L
.5672 .30902 L
.5685 .30902 L
.56961 .30902 L
.57081 .30902 L
.57211 .30902 L
.57334 .30902 L
.57408 .30902 L
.57479 .30902 L
.57542 .30902 L
.57611 .30902 L
.57685 .30902 L
.57763 .30902 L
.5783 .30902 L
.57904 .30902 L
.58034 .30902 L
.58108 .30902 L
.58175 .30902 L
.58299 .30902 L
.58429 .30902 L
.58552 .30902 L
.58622 .30902 L
.58686 .30902 L
.58804 .30902 L
.58929 .30902 L
.59041 .30902 L
.59145 .30902 L
.5926 .30902 L
.59383 .30902 L
.59514 .30902 L
.59583 .30902 L
.59656 .30902 L
.59727 .30902 L
.59791 .30902 L
.59916 .30902 L
.60036 .30902 L
.60166 .30902 L
.60289 .30902 L
Mistroke
.60402 .30902 L
.60509 .30902 L
.60623 .30902 L
.60721 .30902 L
.60829 .30902 L
.60954 .30902 L
.61073 .30902 L
.61189 .30902 L
.61296 .30902 L
.61532 .30902 L
.61647 .30902 L
.61753 .30902 L
.61864 .30902 L
.61984 .30902 L
.62108 .30902 L
.62239 .30902 L
.62363 .30902 L
.62428 .30902 L
.62497 .30902 L
.62623 .30902 L
.6274 .30902 L
.62852 .30902 L
.62957 .30902 L
.63072 .30902 L
.63195 .30902 L
.63326 .30902 L
.63469 .30902 L
.63534 .30902 L
.63604 .30902 L
.63729 .30902 L
.63848 .30902 L
.6396 .30902 L
.64083 .30902 L
.64152 .30902 L
.64216 .30902 L
.64323 .30902 L
.64437 .30902 L
.64545 .30902 L
.64643 .30902 L
.64761 .30902 L
.64886 .30902 L
.64993 .30902 L
.65111 .30902 L
.65231 .30902 L
.65343 .30902 L
.65465 .30902 L
.65595 .30902 L
.65718 .30902 L
.65835 .30902 L
.65939 .30902 L
Mistroke
.66054 .30902 L
.66118 .30902 L
.66187 .30902 L
.66309 .30902 L
.66441 .30902 L
.66515 .30902 L
.66585 .30902 L
.66712 .30902 L
.66827 .30902 L
.6689 .30902 L
.6696 .30902 L
.67086 .30902 L
.67198 .30902 L
.67321 .30902 L
.67451 .30902 L
.67572 .30902 L
.67685 .30902 L
.67788 .30902 L
.67902 .30902 L
.68021 .30902 L
.68151 .30902 L
.68272 .30902 L
.6834 .30902 L
.68413 .30902 L
.6854 .30902 L
.68663 .30902 L
.68792 .30902 L
.68902 .30902 L
.69023 .30902 L
.69096 .30902 L
.69166 .30902 L
.69296 .30902 L
.69369 .30902 L
.69436 .30902 L
.69511 .30902 L
.69589 .30902 L
.70119 .30902 L
.7115 .30902 L
.71286 .30902 L
.71361 .30902 L
.71431 .30902 L
.71497 .30902 L
.71568 .30902 L
.71693 .30902 L
.71762 .30902 L
.71835 .30902 L
.71966 .30902 L
.72039 .30902 L
.72108 .30902 L
.72183 .30902 L
Mistroke
.72265 .30902 L
.72334 .30902 L
.72399 .30902 L
.7247 .30902 L
.72546 .30902 L
.72618 .30902 L
.72687 .30902 L
.72814 .30902 L
.7294 .30902 L
.73055 .30902 L
.73182 .30902 L
.73246 .30902 L
.73317 .30902 L
.73443 .30902 L
.73558 .30902 L
.73621 .30902 L
.73691 .30902 L
.73816 .30902 L
.73935 .30902 L
.7406 .30902 L
.74166 .30902 L
.74283 .30902 L
.74404 .30902 L
.74516 .30902 L
.74637 .30902 L
.74767 .30902 L
.7489 .30902 L
.75005 .30902 L
.75222 .30902 L
.75347 .30902 L
.75411 .30902 L
.75481 .30902 L
.75604 .30902 L
.75719 .30902 L
.75789 .30902 L
.75855 .30902 L
.75979 .30902 L
.76044 .30902 L
.76113 .30902 L
.76189 .30902 L
.76259 .30902 L
.76328 .30902 L
.76401 .30902 L
.76531 .30902 L
.76599 .30902 L
.76672 .30902 L
.76752 .30902 L
.76826 .30902 L
.76895 .30902 L
.7697 .30902 L
Mistroke
.77041 .30902 L
.77106 .30902 L
.77229 .30902 L
.77361 .30902 L
.77478 .30902 L
.77605 .30902 L
.77725 .30902 L
.77835 .30902 L
.77967 .30902 L
.7809 .30902 L
.78219 .30902 L
.78286 .30902 L
.78359 .30902 L
.78482 .30902 L
.78553 .30902 L
.78618 .30902 L
.78687 .30902 L
.78751 .30902 L
.78893 .30902 L
.79385 .30902 L
.80496 .30902 L
.82511 .30902 L
.8649 .30902 L
.90317 .30902 L
.9439 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.03) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0002Woool200002_ooo`<0000W
oooo00<0003oooooool0:?ooo`80000:oooo0`0000koool00=Soool00`000?ooooooo`15oooo001[
oooo3P1Voeooool00`000?ooooooo`15oooo001Eoooo5P1Vo`goool00`1Vooooooooo`1Moooo00<0
003oooooool0AOooo`00=ooooah0I_lSoooo00<0I_ooooooool0GOooo`030000oooooooo04Goool0
017ooolV06Ko@Oooo`0306Kooooooooo05goool00`000?ooooooo`15oooo000;ooooo`0000L0000?
oooo000Aoooo00<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00040000<ol0<ol0
o`2I1S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool04oooo`004Oooo`030000<ol0<ol002lco`000`0003?o03?o000_<ol000@0000co`0co`3o09T]
<ol000<0000co`0co`00;c?o00030000oooooooo02ooool00`000?ooooooo`0Coooo000AooooIc?o
0003o`2I<ol0<ol005dco`000`000?ooooooo`15oooo000AooooIc?o0003o`2I<ol0<ol005dco`00
0`000?ooooooo`15oooo000AooooIc?o0003o`2I<ol0<ol005dco`000`000?ooooooo`15oooo000A
ooooIc?o0003o`2I<ol0<ol005dco`000`000?ooooooo`15oooo000AooooIc?o0003o`2I<ol0<ol0
05dco`000`000?ooooooo`15oooo000AooooIc?o0003o`2I<ol0<ol005dco`020000A_ooo`004Ooo
ofLco`000ol0VC?o03?o001M<ol000<0003oooooool0AOooo`004OooofLco`000ol0VC?o03?o001M
<ol000<0003oooooool0AOooo`004OooofLco`000ol0VC?o03?o001M<ol000<0003oooooool0AOoo
o`004OooofLco`000ol0VC?o03?o001M<ol000<0003oooooool0AOooo`004OooofLco`000ol0VC?o
03?o001M<ol000<0003oooooool0AOooo`004OooofLco`000ol0VC?o03?o001M<ol000<0003ooooo
ool0AOooo`004OooofLco`000ol0VC?o03?o001M<ol000<0003oooooool0AOooo`004Oooo`80001U
<ol000?o09Tco`0co`00GC?o00800016oooo000Coooo0P0006<co`000ol0VC?o03?o001M<ol000<0
003oooooool0AOooo`005Oooo`80001Q<ol000?o09Tco`0co`00GC?o00030000oooooooo04Goool0
01Ooool20000Gc?o0003o`2I<ol0<ol005dco`000`000?ooooooo`15oooo000Ioooo0P0005dco`00
0ol0VC?o03?o001M<ol000<0003oooooool0AOooo`006oooo`80001K<ol000?o09Tco`0co`00GC?o
00030000oooooooo04Goool001goool20000FC?o0003o`2I<ol0<ol005dco`000`000?ooooooo`15
oooo000Ooooo00<0000co`0co`00ES?o0003o`2I<ol0<ol005dco`000`000?ooooooo`15oooo000P
oooo00<0000co`0co`00EC?o0003o`2I<ol0<ol005dco`020000A_ooo`008Oooo`80001E<ol000?o
09Tco`0co`00GC?o00030000oooooooo04Goool002?oool00`0003?o03?o001B<ol000?o09Tco`0c
o`00GC?o00030000oooooooo04Goool002Coool20000DS?o0003o`2I<ol0<ol005dco`000`000?oo
ooooo`15oooo000Voooo00<0000co`0co`00Cc?o0003o`2I<ol0<ol005dco`000`000?ooooooo`15
oooo000Woooo00<0000co`0co`00CS?o0003o`2I<ol0<ol005dco`000`000?ooooooo`15oooo000X
oooo00<0000co`0co`00CC?o0003o`2I<ol0<ol004@co`02000013?o00800004<ol00P0000<co`04
000013?o00030000oooooooo04Goool002Woool00`0003?o03?o001<<ol000?o09Tco`0co`00@c?o
00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00030000<ol0<ol000Dco`000`000?oo
ooooo`15oooo000Zoooo00<0000co`0co`00Bc?o0003o`2I<ol0<ol004<co`00100003?o03?o0000
00Pco`00100003?o03?o000000<co`000`0003?o03?o0004<ol00`0004Goool002_oool20000Bc?o
0003o`2I<ol0<ol004<co`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`0003?o
03?o0003<ol000<0003oooooool0AOooo`00;Oooo`030000<ol0<ol004Pco`000ol0VC?o03?o0013
<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000004<ol000<0
003oooooool0AOooo`00;_ooo`030000<ol0<ol004Lco`000ol0VC?o03?o0014<ol00P0000Xco`02
000013?o00800005<ol000<0003oooooool0AOooo`00;oooo`030000<ol0<ol004Hco`000ol0VC?o
03?o001M<ol000<0003oooooool0AOooo`00<?ooo`030000<ol0<ol004Dco`000ol0VC?o03?o001M
<ol000<0003oooooool0AOooo`00<Oooo`030000<ol0<ol004@co`000ol0VC?o03?o001M<ol000<0
003oooooool0AOooo`00<_ooo`030000<ol0<ol004<co`000ol0VC?o03?o001M<ol000<0003ooooo
ool0AOooo`00<oooo`030000<ol0<ol0048co`000ol0VC?o03?o001M<ol00P0004Koool003?oool0
0`0003?o03?o0012<ol000?o09Tco`0co`00GC?o00030000oooooooo04Goool003Coool00`0003?o
03?o0011<ol000?o09Tco`0co`00GC?o00030000oooooooo04Goool003Goool00`0003?o03?o0010
<ol000?o09Tco`0co`00GC?o00030000oooooooo04Goool003Koool00`0003?o03?o000o<ol000?o
09Tco`0co`00GC?o00030000oooooooo04Goool003Ooool00`0003?o03?o000n<ol000?o09Tco`0c
o`00GC?o00030000oooooooo04Goool003Soool00`0003?o03?o000m<ol000?o09Tco`0co`00GC?o
00030000oooooooo04Goool003Soool00`0003?o03?o000m<ol000?o09Tco`0co`00GC?o00030000
oooooooo04Goool003Woool00`0003?o03?o000l<ol000?o09Tco`0co`00GC?o00800016oooo000j
oooo00<0000co`0co`00>c?o0003o`2I<ol0<ol005dco`000`000?ooooooo`15oooo000koooo00<0
000co`0co`00>S?o0003o`2I<ol0<ol005dco`000`000?ooooooo`15oooo000loooo00<0000co`0c
o`00>C?o0003o`2I<ol0<ol005dco`000`000?ooooooo`15oooo000loooo00<0000co`0co`00>C?o
0003o`2I<ol0<ol005dco`000`000?ooooooo`15oooo000moooo00<0000co`0co`00>3?o0003o`2I
<ol0<ol005dco`000`000?ooooooo`15oooo000moooo00<0000co`0co`00>3?o0003o`2I<ol0<ol0
05dco`000`000?ooooooo`15oooo000noooo00<0000co`0co`00=c?o0003o`2I<ol0<ol005dco`00
0`000?ooooooo`15oooo000noooo00<0000co`0co`00=c?o0003o`2I<ol0<ol005dco`000`000?oo
ooooo`15oooo000ooooo00<0000co`0co`00=S?o0003o`2I<ol0<ol005dco`020000A_ooo`00?ooo
o`030000<ol0<ol003Hco`000ol0VC?o03?o001M<ol000<0003oooooool0AOooo`00@?ooo`030000
<ol0<ol003Dco`000ol0VC?o03?o001M<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol0
03@co`000ol0VC?o03?o001M<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol003@co`00
0ol0VC?o03?o001M<ol000<0003oooooool0AOooo`00@_ooo`030000<ol0<ol003<co`000ol0VC?o
03?o001M<ol000<0003oooooool0AOooo`00@_ooo`030000<ol0<ol003<co`000ol0VC?o03?o0014
<ol00P0000@co`02000013?o00800005<ol00`0000<co`000`000?ooooooo`15oooo0013oooo00<0
000co`0co`00<S?o0003o`2I<ol0<ol004<co`00100003?o03?o000000Pco`00100003?o03?o0000
00Dco`000`0003?o03?o0002<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol0038co`00
0ol0VC?o03?o0013<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol01@0000<co`03
0000AOooo`00A?ooo`030000<ol0<ol0034co`000ol0VC?o03?o0013<ol000@0000co`0co`000008
<ol000@0000co`0co`000002<ol000@0000co`0co`000004<ol000<0003oooooool0AOooo`00A?oo
o`030000<ol0<ol0034co`000ol0VC?o03?o0013<ol000@0000co`0co`000008<ol000@0000co`0c
o`000003<ol000<0000co`00000013?o00030000oooooooo04Goool004Goool00`0003?o03?o000`
<ol000?o09Tco`0co`00A3?o0080000:<ol00P0000Dco`02000013?o00030000oooooooo04Goool0
04Goool00`0003?o03?o000`<ol000?o09Tco`0co`00GC?o00030000oooooooo04Goool004Koool0
0`0003?o03?o000_<ol000?o09Tco`0co`00GC?o00030000oooooooo04Goool004Koool00`0003?o
03?o000_<ol000?o09Tco`0co`00GC?o00030000oooooooo04Goool004Ooool00`0003?o03?o000^
<ol000?o09Tco`0co`00GC?o00030000oooooooo04Goool004Ooool00`0003?o03?o000^<ol000?o
09Tco`0co`00GC?o00800016oooo0018oooo00<0000co`0co`00;C?o0003o`2I<ol0<ol005dco`00
0`000?ooooooo`15oooo0018oooo00<0000co`0co`00;C?o0003o`2I<ol0<ol005dco`000`000?oo
ooooo`15oooo0019oooo00<0000co`0co`00;3?o0003o`2I<ol0<ol005dco`000`000?ooooooo`15
oooo0019oooo00<0000co`0co`00;3?o0003o`2I<ol0<ol005dco`000`000?ooooooo`15oooo001:
oooo00<0000co`0co`00:c?o0003o`2I<ol0<ol005dco`000`000?ooooooo`15oooo001:oooo00<0
000co`0co`00:c?o0003o`2I<ol0<ol005dco`000`000?ooooooo`15oooo001;oooo00<0000co`0c
o`00:S?o0003o`2I<ol0<ol005dco`000`000?ooooooo`15oooo001;oooo00<0000co`0co`00:S?o
0003o`2I<ol0<ol005dco`020000A_ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004cooon<
<ol0B?ooo`00COoooh/co`18oooo001=ooooRc?o04Soool004kooolZ<ol000<0000co`0co`009c?o
00030000<ol0<ol003<co`18oooo001>oooo:C?o00030000<ol0<ol000Pco`000`0003?o03?o000N
<ol000<0000co`0co`00<S?o04Soool004oooolX<ol000<0000co`0co`000S?o00800004<ol000<0
000co`0co`001S?o00800004<ol00P0000@co`02000013?o00800004<ol000<0000co`0co`00<S?o
04Soool004oooolX<ol000D0000co`0co`0co`0000000S?o00030000<ol0<ol0008co`000`0003?o
03?o0004<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000003
<ol000<0000co`0co`00<S?o04Soool004oooolW<ol000<0000co`0co`000S?o00030000<ol0<ol0
00`co`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`0003?o03?o0003<ol000<0
000co`0co`00<C?o04Soool0053ooolW<ol000<0000co`0co`001@0000/co`00100003?o03?o0000
00Pco`00100003?o03?o000000Dco`001@0003?o03?o03?o0000000d<ol0B?ooo`00D?ooobLco`00
1@0003?o03?o03?o0000000><ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0
000co`0co`000003<ol000<0000co`0co`00<S?o04Soool0053ooolX<ol000<0000co`0co`0043?o
0080000:<ol00P0000@co`0200000c?o00030000<ol0<ol003<co`18oooo001AooooQc?o04Soool0
057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40134 .30902 L
.41134 .30902 L
.41408 .30902 L
.41703 .30902 L
.41846 .30902 L
.41917 .30902 L
.41982 .30902 L
s
.41982 .30902 m
.41982 .61803 L
s
0 .4 1 r
.02381 .30409 m
.06244 .30332 L
.10458 .30236 L
.14415 .3013 L
.18221 .30013 L
.22272 .29868 L
.26171 .29706 L
.30316 .29505 L
.34309 .29279 L
.3815 .29026 L
.40134 .2888 L
.41134 .28802 L
.41408 .2878 L
.41703 .28756 L
.41846 .28745 L
.41917 .28739 L
.41982 .28733 L
.42104 .30902 L
.42168 .30902 L
.42237 .30902 L
.42361 .30902 L
.42431 .30902 L
.42497 .30902 L
.42567 .30902 L
.4263 .30902 L
.42703 .30902 L
.42772 .30902 L
.42895 .30902 L
.43008 .30902 L
.43133 .30902 L
.43196 .30902 L
.43265 .30902 L
.43335 .30902 L
.434 .30902 L
.43467 .30902 L
.43541 .30902 L
.43616 .30902 L
.43697 .30902 L
.43771 .30902 L
.43839 .30902 L
.43908 .30902 L
.43972 .30902 L
.44042 .30902 L
.44116 .30902 L
.44241 .30902 L
.44311 .30902 L
.44378 .30902 L
.44502 .30902 L
.44573 .30902 L
.44638 .30902 L
Mistroke
.44758 .30902 L
.44886 .30902 L
.45011 .30902 L
.45129 .30902 L
.45236 .30902 L
.4535 .30902 L
.45477 .30902 L
.45548 .30902 L
.45615 .30902 L
.45686 .30902 L
.4575 .30902 L
.45824 .30902 L
.45895 .30902 L
.46019 .30902 L
.46134 .30902 L
.46261 .30902 L
.46324 .30902 L
.46395 .30902 L
.46517 .30902 L
.46631 .30902 L
.46755 .30902 L
.46825 .30902 L
.46888 .30902 L
.47016 .30902 L
.47089 .30902 L
.47155 .30902 L
.47277 .30902 L
.47407 .30902 L
.47516 .30902 L
.4762 .30902 L
.47739 .30902 L
.47848 .30902 L
.47968 .30902 L
.48099 .30902 L
.48221 .30902 L
.48333 .30902 L
.48446 .30902 L
.48565 .30902 L
.48695 .30902 L
.48814 .30902 L
.48945 .30902 L
.49019 .30902 L
.49088 .30902 L
.49212 .30902 L
.49282 .30902 L
.49345 .30902 L
.49412 .30902 L
.49483 .30902 L
.4961 .30902 L
.49681 .30902 L
Mistroke
.49747 .30902 L
.4982 .30902 L
.49898 .30902 L
.49965 .30902 L
.50038 .30902 L
.50107 .30902 L
.50171 .30902 L
.50292 .30902 L
.5042 .30902 L
.50545 .30902 L
.50616 .30902 L
.50681 .30902 L
.5075 .30902 L
.50824 .30902 L
.50892 .30902 L
.50957 .30902 L
.51079 .30902 L
.51193 .30902 L
.51318 .30902 L
.5138 .30902 L
.5145 .30902 L
.5152 .30902 L
.51585 .30902 L
.51652 .30902 L
.51726 .30902 L
.51801 .30902 L
.51882 .30902 L
.51956 .30902 L
.52024 .30902 L
.52093 .30902 L
.52157 .30902 L
.52227 .30902 L
.52301 .30902 L
.52426 .30902 L
.52497 .30902 L
.52563 .30902 L
.52688 .30902 L
.52758 .30902 L
.52824 .30902 L
.52944 .30902 L
.53072 .30902 L
.53197 .30902 L
.53315 .30902 L
.53421 .30902 L
.53536 .30902 L
.53662 .30902 L
.53734 .30902 L
.53801 .30902 L
.53872 .30902 L
.53936 .30902 L
Mistroke
.5401 .30902 L
.5408 .30902 L
.54205 .30902 L
.5432 .30902 L
.54447 .30902 L
.5451 .30902 L
.54581 .30902 L
.54709 .30902 L
.54829 .30902 L
.54902 .30902 L
.54971 .30902 L
.551 .30902 L
.55215 .30902 L
.55339 .30902 L
.55403 .30902 L
.55471 .30902 L
.55593 .30902 L
.55704 .30902 L
.55822 .30902 L
.55934 .30902 L
.56035 .30902 L
.56155 .30902 L
.56284 .30902 L
.56407 .30902 L
.56521 .30902 L
.5664 .30902 L
.56769 .30902 L
.5689 .30902 L
.57002 .30902 L
.57125 .30902 L
.57195 .30902 L
.5726 .30902 L
.57392 .30902 L
.57466 .30902 L
.57533 .30902 L
.576 .30902 L
.57671 .30902 L
.57798 .30902 L
.57869 .30902 L
.57935 .30902 L
.58008 .30902 L
.58086 .30902 L
.58153 .30902 L
.58226 .30902 L
.58295 .30902 L
.58359 .30902 L
.58479 .30902 L
.58608 .30902 L
.58733 .30902 L
.58803 .30902 L
Mistroke
.58869 .30902 L
.58939 .30902 L
.59002 .30902 L
.59076 .30902 L
.59145 .30902 L
.59268 .30902 L
.59382 .30902 L
.59506 .30902 L
.59569 .30902 L
.59639 .30902 L
.59709 .30902 L
.59783 .30902 L
.59846 .30902 L
.59915 .30902 L
.5999 .30902 L
.6007 .30902 L
.60145 .30902 L
.60213 .30902 L
.60283 .30902 L
.60346 .30902 L
.60417 .30902 L
.60491 .30902 L
.60615 .30902 L
.60686 .30902 L
.60752 .30902 L
.61252 .30902 L
.61498 .30902 L
.61606 .30902 L
.61726 .30902 L
.61852 .30902 L
.61922 .30902 L
.61987 .30902 L
.62058 .30902 L
.62124 .30902 L
.62196 .30902 L
.62272 .30902 L
.62387 .30902 L
.6251 .30902 L
.6258 .30902 L
.62645 .30902 L
.6277 .30902 L
.62889 .30902 L
.63 .30902 L
.63122 .30902 L
.63254 .30902 L
.63319 .30902 L
.63391 .30902 L
.63521 .30902 L
.63648 .30902 L
.63766 .30902 L
Mistroke
.63876 .30902 L
.63995 .30902 L
.64108 .30902 L
.64211 .30902 L
.64332 .30902 L
.6446 .30902 L
.64567 .30902 L
.64685 .30902 L
.64752 .30902 L
.64825 .30902 L
.64957 .30902 L
.65085 .30902 L
.65204 .30902 L
.65333 .30902 L
.65406 .30902 L
.65474 .30902 L
.65761 .30902 L
.66764 .30902 L
.67748 .30902 L
.67871 .30902 L
.67987 .30902 L
.68051 .30902 L
.6812 .30902 L
.68242 .30902 L
.68313 .30902 L
.68388 .30902 L
.68452 .30902 L
.68522 .30902 L
.68587 .30902 L
.68657 .30902 L
.68783 .30902 L
.68906 .30902 L
.6902 .30902 L
.69146 .30902 L
.69216 .30902 L
.69279 .30902 L
.69396 .30902 L
.69522 .30902 L
.69641 .30902 L
.6975 .30902 L
.69856 .30902 L
.69955 .30902 L
.70064 .30902 L
.7018 .30902 L
.70302 .30902 L
.70417 .30902 L
.70521 .30902 L
.70634 .30902 L
.70756 .30902 L
.70868 .30902 L
Mistroke
.70997 .30902 L
.7112 .30902 L
.71233 .30902 L
.71338 .30902 L
.71453 .30902 L
.71576 .30902 L
.72615 .30902 L
.72684 .30902 L
.72748 .30902 L
.72815 .30902 L
.72888 .30902 L
.72962 .30902 L
.73041 .30902 L
.73115 .30902 L
.73183 .30902 L
.73314 .30902 L
.73384 .30902 L
.73457 .30902 L
.73522 .30902 L
.73593 .30902 L
.73718 .30902 L
.73847 .30902 L
.73966 .30902 L
.74096 .30902 L
.74162 .30902 L
.74233 .30902 L
.74355 .30902 L
.74484 .30902 L
.74606 .30902 L
.74718 .30902 L
.74837 .30902 L
.74948 .30902 L
.7507 .30902 L
.75202 .30902 L
.75268 .30902 L
.75339 .30902 L
.7547 .30902 L
.75597 .30902 L
.75715 .30902 L
.76634 .30902 L
.76765 .30902 L
.76839 .30902 L
.76906 .30902 L
.77031 .30902 L
.77163 .30902 L
.77281 .30902 L
.77391 .30902 L
.77512 .30902 L
.77641 .30902 L
.77779 .30902 L
Mistroke
.77852 .30902 L
.77929 .30902 L
.77997 .30902 L
.78071 .30902 L
.78202 .30902 L
.78329 .30902 L
.78466 .30902 L
.78596 .30902 L
.78713 .30902 L
.78954 .30902 L
.7921 .30902 L
.79672 .30902 L
.8072 .30902 L
.8283 .30902 L
.86831 .30902 L
.90681 .30902 L
.94775 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Voooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P00000306Kooooooooo02Koool2
00002_ooo`<0000Woooo00<0003oooooool0:?ooo`80000:oooo0`0000koool006_oool?06KoG_oo
o`030000oooooooo04Goool005GooolF06Ko3_ooo`0306Kooooooooo05coool00`000?ooooooo`15
oooo0011oooo501VobCoool00`1Vooooooooo`1Loooo00<0003oooooool0AOooo`008_oooal0I_lh
oooo00<0I_ooooooool0G?ooo`030000oooooooo04Goool0017ooolA06KoEoooo`0306Kooooooooo
05coool00`000?ooooooo`15oooo000;ooooo`0000L0000?oooo000Aoooo00<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00050000<ol0<ol0<ol0o`2I00Dco`000`0003?o03?o0007
<ol000<0000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo01?oool0017oool00`0003?o
03?o000_<ol000<0000co`0co`00;c?o00050000<ol0<ol0<ol0o`2I02`co`000`0003?o03?o000_
<ol000<0003oooooool0;oooo`030000oooooooo01?oool0017ooomX<ol000?o09Tco`0co`00G3?o
00030000oooooooo04Goool0017ooomX<ol000?o09Tco`0co`00G3?o00030000oooooooo04Goool0
017ooomX<ol000?o09Tco`0co`00G3?o00030000oooooooo04Goool0017ooomX<ol000?o09Tco`0c
o`00G3?o00030000oooooooo04Goool0017ooomX<ol000?o09Tco`0co`00G3?o00030000oooooooo
04Goool0017ooomX<ol000?o09Tco`0co`00G3?o00800016oooo000AooooJ3?o0003o`2I<ol0<ol0
05`co`000`000?ooooooo`15oooo000AooooJ3?o0003o`2I<ol0<ol005`co`000`000?ooooooo`15
oooo000AooooJ3?o0003o`2I<ol0<ol005`co`000`000?ooooooo`15oooo000AooooJ3?o0003o`2I
<ol0<ol005`co`000`000?ooooooo`15oooo000AooooJ3?o0003o`2I<ol0<ol005`co`000`000?oo
ooooo`15oooo000AooooJ3?o0003o`2I<ol0<ol005`co`000`000?ooooooo`15oooo000AooooJ3?o
0003o`2I<ol0<ol005`co`000`000?ooooooo`15oooo000Aoooo0P0006Hco`000ol0VC?o03?o001L
<ol00P0004Koool001?oool20000I3?o0003o`2I<ol0<ol005`co`000`000?ooooooo`15oooo000E
oooo0P00068co`000ol0VC?o03?o001L<ol000<0003oooooool0AOooo`005oooo`80001P<ol000?o
09Tco`0co`00G3?o00030000oooooooo04Goool001Woool20000GS?o0003o`2I<ol0<ol005`co`00
0`000?ooooooo`15oooo000Koooo0P0005`co`000ol0VC?o03?o001L<ol000<0003oooooool0AOoo
o`007Oooo`80001J<ol000?o09Tco`0co`00G3?o00030000oooooooo04Goool001ooool00`0003?o
03?o001G<ol000?o09Tco`0co`00G3?o00030000oooooooo04Goool0023oool00`0003?o03?o001F
<ol000?o09Tco`0co`00G3?o00800016oooo000Qoooo0P0005Hco`000ol0VC?o03?o001L<ol000<0
003oooooool0AOooo`008oooo`030000<ol0<ol005<co`000ol0VC?o03?o001L<ol000<0003ooooo
ool0AOooo`009?ooo`80001C<ol000?o09Tco`0co`00G3?o00030000oooooooo04Goool002Koool0
0`0003?o03?o001@<ol000?o09Tco`0co`00G3?o00030000oooooooo04Goool002Ooool00`0003?o
03?o001?<ol000?o09Tco`0co`00G3?o00030000oooooooo04Goool002Soool00`0003?o03?o001>
<ol000?o09Tco`0co`00@c?o00800004<ol00P0000@co`0200000c?o00@00004<ol000<0003ooooo
ool0AOooo`00:Oooo`030000<ol0<ol004dco`000ol0VC?o03?o0012<ol000@0000co`0co`000008
<ol000@0000co`0co`000002<ol000<0000co`0co`001C?o00030000oooooooo04Goool002[oool0
0`0003?o03?o001<<ol000?o09Tco`0co`00@S?o00040000<ol0<ol0000023?o00040000<ol0<ol0
00000c?o00030000<ol0<ol000@co`030000AOooo`00:oooo`80001<<ol000?o09Tco`0co`00@S?o
00040000<ol0<ol0000023?o00040000<ol0<ol0000013?o00030000<ol0<ol000<co`000`000?oo
ooooo`15oooo000]oooo00<0000co`0co`00BC?o0003o`2I<ol0<ol0048co`00100003?o03?o0000
00Pco`00100003?o03?o0000008co`00100003?o03?o000000@co`000`000?ooooooo`15oooo000^
oooo00<0000co`0co`00B3?o0003o`2I<ol0<ol004<co`0200002S?o00800004<ol00P0000Dco`00
0`000?ooooooo`15oooo000_oooo00<0000co`0co`00Ac?o0003o`2I<ol0<ol005`co`000`000?oo
ooooo`15oooo000`oooo00<0000co`0co`00AS?o0003o`2I<ol0<ol005`co`000`000?ooooooo`15
oooo000aoooo00<0000co`0co`00AC?o0003o`2I<ol0<ol005`co`000`000?ooooooo`15oooo000b
oooo00<0000co`0co`00A3?o0003o`2I<ol0<ol005`co`000`000?ooooooo`15oooo000coooo00<0
000co`0co`00@c?o0003o`2I<ol0<ol005`co`020000A_ooo`00<oooo`030000<ol0<ol004<co`00
0ol0VC?o03?o001L<ol000<0003oooooool0AOooo`00=?ooo`030000<ol0<ol0048co`000ol0VC?o
03?o001L<ol000<0003oooooool0AOooo`00=Oooo`030000<ol0<ol0044co`000ol0VC?o03?o001L
<ol000<0003oooooool0AOooo`00=_ooo`030000<ol0<ol0040co`000ol0VC?o03?o001L<ol000<0
003oooooool0AOooo`00=oooo`030000<ol0<ol003lco`000ol0VC?o03?o001L<ol000<0003ooooo
ool0AOooo`00>?ooo`030000<ol0<ol003hco`000ol0VC?o03?o001L<ol000<0003oooooool0AOoo
o`00>?ooo`030000<ol0<ol003hco`000ol0VC?o03?o001L<ol000<0003oooooool0AOooo`00>Ooo
o`030000<ol0<ol003dco`000ol0VC?o03?o001L<ol00P0004Koool003[oool00`0003?o03?o000l
<ol000?o09Tco`0co`00G3?o00030000oooooooo04Goool003_oool00`0003?o03?o000k<ol000?o
09Tco`0co`00G3?o00030000oooooooo04Goool003coool00`0003?o03?o000j<ol000?o09Tco`0c
o`00G3?o00030000oooooooo04Goool003coool00`0003?o03?o000j<ol000?o09Tco`0co`00G3?o
00030000oooooooo04Goool003goool00`0003?o03?o000i<ol000?o09Tco`0co`00G3?o00030000
oooooooo04Goool003goool00`0003?o03?o000i<ol000?o09Tco`0co`00G3?o00030000oooooooo
04Goool003koool00`0003?o03?o000h<ol000?o09Tco`0co`00G3?o00030000oooooooo04Goool0
03koool00`0003?o03?o000h<ol000?o09Tco`0co`00G3?o00030000oooooooo04Goool003ooool0
0`0003?o03?o000g<ol000?o09Tco`0co`00G3?o00800016oooo000ooooo00<0000co`0co`00=c?o
0003o`2I<ol0<ol005`co`000`000?ooooooo`15oooo0010oooo00<0000co`0co`00=S?o0003o`2I
<ol0<ol005`co`000`000?ooooooo`15oooo0011oooo00<0000co`0co`00=C?o0003o`2I<ol0<ol0
05`co`000`000?ooooooo`15oooo0011oooo00<0000co`0co`00=C?o0003o`2I<ol0<ol005`co`00
0`000?ooooooo`15oooo0012oooo00<0000co`0co`00=3?o0003o`2I<ol0<ol005`co`000`000?oo
ooooo`15oooo0012oooo00<0000co`0co`00=3?o0003o`2I<ol0<ol004<co`02000013?o00800004
<ol00P0000Dco`0300000c?o00030000oooooooo04Goool004?oool00`0003?o03?o000c<ol000?o
09Tco`0co`00@S?o00040000<ol0<ol0000023?o00040000<ol0<ol000001C?o00030000<ol0<ol0
008co`000`000?ooooooo`15oooo0013oooo00<0000co`0co`00<c?o0003o`2I<ol0<ol0048co`00
100003?o03?o000000Pco`00100003?o03?o0000008co`0500000c?o00<00015oooo0014oooo00<0
000co`0co`00<S?o0003o`2I<ol0<ol0048co`00100003?o03?o000000Pco`00100003?o03?o0000
008co`00100003?o03?o000000@co`000`000?ooooooo`15oooo0014oooo00<0000co`0co`00<S?o
0003o`2I<ol0<ol0048co`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o
00000004<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol0034co`000ol0VC?o03?o0013
<ol00P0000Xco`0200001C?o00800004<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol0
034co`000ol0VC?o03?o001L<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol0030co`00
0ol0VC?o03?o001L<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol0030co`000ol0VC?o
03?o001L<ol000<0003oooooool0AOooo`00Aoooo`030000<ol0<ol002lco`000ol0VC?o03?o001L
<ol000<0003oooooool0AOooo`00Aoooo`030000<ol0<ol002lco`000ol0VC?o03?o001L<ol00P00
04Koool004Soool00`0003?o03?o000^<ol000?o09Tco`0co`00G3?o00030000oooooooo04Goool0
04Soool00`0003?o03?o000^<ol000?o09Tco`0co`00G3?o00030000oooooooo04Goool004Woool0
0`0003?o03?o000]<ol000?o09Tco`0co`00G3?o00030000oooooooo04Goool004Woool00`0003?o
03?o000]<ol000?o09Tco`0co`00G3?o00030000oooooooo04Goool004[oool00`0003?o03?o000/
<ol000?o09Tco`0co`00G3?o00030000oooooooo04Goool004[oool00`0003?o03?o000/<ol000?o
09Tco`0co`00G3?o00030000oooooooo04Goool004_oool00`0003?o03?o000[<ol000?o09Tco`0c
o`00G3?o00030000oooooooo04Goool004_oool00`0003?o03?o000[<ol000?o09Tco`0co`00G3?o
00800016oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001=ooooRc?o
04Soool004gooon;<ol0B?ooo`00C_ooobXco`000`0003?o03?o000W<ol000<0000co`0co`00<c?o
04Soool004kooolY<ol000<0000co`0co`0023?o00030000<ol0<ol001hco`000`0003?o03?o000b
<ol0B?ooo`00CoooobPco`000`0003?o03?o0002<ol00P0000@co`000`0003?o03?o0006<ol00P00
00@co`02000013?o00800005<ol00`00008co`000`0003?o03?o000b<ol0B?ooo`00CoooobPco`00
1@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o00030000<ol0<ol000@co`00100003?o
03?o000000Pco`00100003?o03?o000000Dco`001@0003?o03?o03?o0000000d<ol0B?ooo`00Cooo
obLco`000`0003?o03?o0002<ol000<0000co`0co`0033?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000S?o00D00003<ol000<0000co`0co`00<C?o04Soool0053ooolW<ol000<0000co`0c
o`001@0000/co`00100003?o03?o000000Pco`00100003?o03?o0000008co`00100003?o03?o0000
00<co`000`0003?o03?o000b<ol0B?ooo`00D?ooobLco`001@0003?o03?o03?o0000000><ol000@0
000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`0000000c?o00030000<ol0<ol0
038co`18oooo001@oooo:3?o00030000<ol0<ol0010co`0200002S?o00800005<ol00P00008co`00
0`0003?o03?o000c<ol0B?ooo`00DOooohLco`18oooo001AooooQc?o04Soool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.41127 .30902 L
.41696 .30902 L
.41976 .30902 L
.42113 .30902 L
.42237 .30902 L
.42363 .30902 L
s
.42363 .30902 m
.42364 .61803 L
s
0 .4 1 r
.02381 .30285 m
.06244 .3019 L
.10458 .30069 L
.14415 .29937 L
.18221 .2979 L
.22272 .29609 L
.26171 .29406 L
.30316 .29155 L
.34309 .28873 L
.3815 .28557 L
.40095 .28378 L
.41127 .28277 L
.41696 .2822 L
.41976 .28191 L
.42113 .28177 L
.42237 .28164 L
.42363 .28151 L
.42482 .30902 L
.42608 .30902 L
.42679 .30902 L
.42744 .30902 L
.43008 .30902 L
.43298 .30902 L
.43415 .30902 L
.43542 .30902 L
.43661 .30902 L
.4377 .30902 L
.43892 .30902 L
.43962 .30902 L
.44026 .30902 L
.44143 .30902 L
.44268 .30902 L
.44385 .30902 L
.44493 .30902 L
.44611 .30902 L
.44735 .30902 L
.44843 .30902 L
.44944 .30902 L
.45055 .30902 L
.45173 .30902 L
.45302 .30902 L
.45375 .30902 L
.45442 .30902 L
.45566 .30902 L
.45696 .30902 L
.45813 .30902 L
.45923 .30902 L
.46043 .30902 L
.46172 .30902 L
.46303 .30902 L
Mistroke
.46426 .30902 L
.46495 .30902 L
.46569 .30902 L
.46697 .30902 L
.46821 .30902 L
.46951 .30902 L
.47063 .30902 L
.47185 .30902 L
.47259 .30902 L
.47329 .30902 L
.47461 .30902 L
.47534 .30902 L
.47602 .30902 L
.47677 .30902 L
.47756 .30902 L
.47887 .30902 L
.4801 .30902 L
.4808 .30902 L
.48144 .30902 L
.48215 .30902 L
.48289 .30902 L
.48415 .30902 L
.4853 .30902 L
.48594 .30902 L
.48662 .30902 L
.48787 .30902 L
.48904 .30902 L
.49028 .30902 L
.49134 .30902 L
.4925 .30902 L
.4932 .30902 L
.49387 .30902 L
.49512 .30902 L
.49581 .30902 L
.49646 .30902 L
.49717 .30902 L
.49792 .30902 L
.49917 .30902 L
.50033 .30902 L
.50161 .30902 L
.50233 .30902 L
.50299 .30902 L
.50427 .30902 L
.50547 .30902 L
.50655 .30902 L
.50772 .30902 L
.509 .30902 L
.50964 .30902 L
.51035 .30902 L
.51161 .30902 L
Mistroke
.51278 .30902 L
.51396 .30902 L
.51507 .30902 L
.51608 .30902 L
.51717 .30902 L
.51836 .30902 L
.51962 .30902 L
.52081 .30902 L
.52189 .30902 L
.52319 .30902 L
.52384 .30902 L
.52456 .30902 L
.52583 .30902 L
.52701 .30902 L
.52773 .30902 L
.52841 .30902 L
.52969 .30902 L
.5304 .30902 L
.53106 .30902 L
.53178 .30902 L
.53255 .30902 L
.53374 .30902 L
.53486 .30902 L
.53551 .30902 L
.5362 .30902 L
.53742 .30902 L
.5387 .30902 L
.53989 .30902 L
.5412 .30902 L
.54186 .30902 L
.54259 .30902 L
.54324 .30902 L
.54394 .30902 L
.54522 .30902 L
.54648 .30902 L
.54764 .30902 L
.54834 .30902 L
.54899 .30902 L
.5497 .30902 L
.55045 .30902 L
.55117 .30902 L
.55185 .30902 L
.55312 .30902 L
.55433 .30902 L
.55561 .30902 L
.5567 .30902 L
.5579 .30902 L
.55919 .30902 L
.55991 .30902 L
.56057 .30902 L
Mistroke
.56185 .30902 L
.56306 .30902 L
.56413 .30902 L
.56531 .30902 L
.56654 .30902 L
.56769 .30902 L
.56877 .30902 L
.56975 .30902 L
.57089 .30902 L
.57197 .30902 L
.57313 .30902 L
.57437 .30902 L
.57554 .30902 L
.5766 .30902 L
.57785 .30902 L
.57855 .30902 L
.5792 .30902 L
.58039 .30902 L
.58165 .30902 L
.58287 .30902 L
.58356 .30902 L
.58419 .30902 L
.58536 .30902 L
.5866 .30902 L
.58771 .30902 L
.58875 .30902 L
.58989 .30902 L
.59112 .30902 L
.59235 .30902 L
.59305 .30902 L
.5937 .30902 L
.59502 .30902 L
.59575 .30902 L
.59642 .30902 L
.59762 .30902 L
.59892 .30902 L
.60015 .30902 L
.60128 .30902 L
.60233 .30902 L
.60347 .30902 L
.60454 .30902 L
.60552 .30902 L
.60666 .30902 L
.60791 .30902 L
.60909 .30902 L
.61018 .30902 L
.61475 .30902 L
.61606 .30902 L
.6173 .30902 L
.61841 .30902 L
Mistroke
.61961 .30902 L
.62084 .30902 L
.62153 .30902 L
.62217 .30902 L
.62335 .30902 L
.6246 .30902 L
.62528 .30902 L
.62593 .30902 L
.62663 .30902 L
.62739 .30902 L
.62804 .30902 L
.62872 .30902 L
.62994 .30902 L
.6311 .30902 L
.63233 .30902 L
.63349 .30902 L
.63455 .30902 L
.63579 .30902 L
.63649 .30902 L
.63714 .30902 L
.63832 .30902 L
.63958 .30902 L
.64077 .30902 L
.64205 .30902 L
.64326 .30902 L
.64437 .30902 L
.64566 .30902 L
.64639 .30902 L
.64707 .30902 L
.64831 .30902 L
.64963 .30902 L
.65093 .30902 L
.65166 .30902 L
.65233 .30902 L
.65356 .30902 L
.65487 .30902 L
.65556 .30902 L
.6563 .30902 L
.65699 .30902 L
.65763 .30902 L
.65837 .30902 L
.65918 .30902 L
.65995 .30902 L
.66065 .30902 L
.6619 .30902 L
.66309 .30902 L
.66416 .30902 L
.66531 .30902 L
.66656 .30902 L
.66771 .30902 L
Mistroke
.66842 .30902 L
.66908 .30902 L
.67032 .30902 L
.67143 .30902 L
.67259 .30902 L
.67359 .30902 L
.67468 .30902 L
.67585 .30902 L
.67711 .30902 L
.6783 .30902 L
.67938 .30902 L
.68066 .30902 L
.68131 .30902 L
.68202 .30902 L
.68328 .30902 L
.68446 .30902 L
.68575 .30902 L
.6864 .30902 L
.68711 .30902 L
.68789 .30902 L
.68861 .30902 L
.68927 .30902 L
.68998 .30902 L
.69128 .30902 L
.69201 .30902 L
.69268 .30902 L
.69392 .30902 L
.69523 .30902 L
.69633 .30902 L
.69751 .30902 L
.6988 .30902 L
.70001 .30902 L
.7007 .30902 L
.70135 .30902 L
.70256 .30902 L
.70386 .30902 L
.7046 .30902 L
.70527 .30902 L
.7064 .30902 L
.70764 .30902 L
.70894 .30902 L
.71015 .30902 L
.71083 .30902 L
.71158 .30902 L
.71229 .30902 L
.71294 .30902 L
.71417 .30902 L
.71548 .30902 L
.71616 .30902 L
.71688 .30902 L
Mistroke
.7182 .30902 L
.719 .30902 L
.71976 .30902 L
.72044 .30902 L
.72119 .30902 L
.72185 .30902 L
.72255 .30902 L
.72384 .30902 L
.72508 .30902 L
.72623 .30902 L
.72748 .30902 L
.72819 .30902 L
.72885 .30902 L
.72955 .30902 L
.73018 .30902 L
.73092 .30902 L
.73161 .30902 L
.73278 .30902 L
.73402 .30902 L
.73508 .30902 L
.73625 .30902 L
.7375 .30902 L
.73821 .30902 L
.73885 .30902 L
.74004 .30902 L
.7413 .30902 L
.74253 .30902 L
.74322 .30902 L
.74386 .30902 L
.74504 .30902 L
.74629 .30902 L
.7474 .30902 L
.74845 .30902 L
.7496 .30902 L
.75083 .30902 L
.75213 .30902 L
.75287 .30902 L
.75356 .30902 L
.75481 .30902 L
.75546 .30902 L
.75615 .30902 L
.75747 .30902 L
.7587 .30902 L
.75991 .30902 L
.76102 .30902 L
.76208 .30902 L
.76322 .30902 L
.7643 .30902 L
.76528 .30902 L
.76643 .30902 L
Mistroke
.76768 .30902 L
.76886 .30902 L
.76995 .30902 L
.77107 .30902 L
.77212 .30902 L
.77328 .30902 L
.77452 .30902 L
.77576 .30902 L
.77706 .30902 L
.77817 .30902 L
.77938 .30902 L
.7807 .30902 L
.78192 .30902 L
.78256 .30902 L
.78326 .30902 L
.78399 .30902 L
.78467 .30902 L
.78593 .30902 L
.78708 .30902 L
.78967 .30902 L
.79901 .30902 L
.81997 .30902 L
.85976 .30902 L
.89803 .30902 L
.93875 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`030000oooooooo02Koool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo00Soool200008ooo
o`@00004oooo00<0003oooooool08?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02Soool206Ko00<00000I_l0I_l09_ooo`040000oooooooo
00002Oooo`030000oooooooo02Ooool00`000?ooooooo`0Woooo00@0003oooooool00009oooo00<0
003oooooool03_ooo`004oooo`80000Zoooo0P0000[oool300007Oooo`/0I_l01Oooo`0000000?oo
o`1Vo`0Woooo0P0000[oool300009oooo`030000oooooooo02Soool200002_ooo`<0000>oooo001P
oooo2`1Vo`ooool00`1Vooooooooo`1Koooo00<0003oooooool0AOooo`00BooooaD0I_lJoooo00<0
I_ooooooool0Foooo`030000oooooooo04Goool003OooolD06Ko;oooo`0306Kooooooooo05_oool0
0`000?ooooooo`15oooo000Goooo801Vod?oool00`1Vooooooooo`1Koooo00<0003oooooool0AOoo
o`004Oooo`H0I_mSoooo00<0I_ooooooool0Foooo`030000oooooooo04Goool000_ooooo00001`00
00ooool0017oool00`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0c
o`000S?o0003o`2I<ol0<ol0008co`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Hco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool01oooo`030000oooooooo01?oool0017oool00`0003?o03?o000_<ol000<0000co`0co`00;c?o
00030000<ol0<ol0008co`000ol0VC?o03?o000Y<ol000<0000co`0co`00;c?o00030000oooooooo
02ooool00`000?ooooooo`0Coooo000AooooJC?o0003o`2I<ol0<ol005/co`000`000?ooooooo`15
oooo000AooooJC?o0003o`2I<ol0<ol005/co`000`000?ooooooo`15oooo000AooooJC?o0003o`2I
<ol0<ol005/co`000`000?ooooooo`15oooo000AooooJC?o0003o`2I<ol0<ol005/co`000`000?oo
ooooo`15oooo000AooooJC?o0003o`2I<ol0<ol005/co`000`000?ooooooo`15oooo000AooooJC?o
0003o`2I<ol0<ol005/co`020000A_ooo`004OooofTco`000ol0VC?o03?o001K<ol000<0003ooooo
ool0AOooo`004OooofTco`000ol0VC?o03?o001K<ol000<0003oooooool0AOooo`004OooofTco`00
0ol0VC?o03?o001K<ol000<0003oooooool0AOooo`004OooofTco`000ol0VC?o03?o001K<ol000<0
003oooooool0AOooo`004OooofTco`000ol0VC?o03?o001K<ol000<0003oooooool0AOooo`004Ooo
ofTco`000ol0VC?o03?o001K<ol000<0003oooooool0AOooo`004OooofTco`000ol0VC?o03?o001K
<ol000<0003oooooool0AOooo`004Oooo`80001W<ol000?o09Tco`0co`00Fc?o00800016oooo000C
oooo0P0006Dco`000ol0VC?o03?o001K<ol000<0003oooooool0AOooo`005Oooo`80001S<ol000?o
09Tco`0co`00Fc?o00030000oooooooo04Goool001Ooool20000HC?o0003o`2I<ol0<ol005/co`00
0`000?ooooooo`15oooo000Ioooo0P0005lco`000ol0VC?o03?o001K<ol000<0003oooooool0AOoo
o`006oooo`80001M<ol000?o09Tco`0co`00Fc?o00030000oooooooo04Goool001goool20000Fc?o
0003o`2I<ol0<ol005/co`000`000?ooooooo`15oooo000Ooooo00<0000co`0co`00F3?o0003o`2I
<ol0<ol005/co`000`000?ooooooo`15oooo000Poooo00<0000co`0co`00Ec?o0003o`2I<ol0<ol0
05/co`020000A_ooo`008Oooo`80001G<ol000?o09Tco`0co`00Fc?o00030000oooooooo04Goool0
02?oool00`0003?o03?o001D<ol000?o09Tco`0co`00Fc?o00030000oooooooo04Goool002Coool2
0000E3?o0003o`2I<ol0<ol005/co`000`000?ooooooo`15oooo000Voooo00<0000co`0co`00DC?o
0003o`2I<ol0<ol005/co`000`000?ooooooo`15oooo000Woooo00<0000co`0co`00D3?o0003o`2I
<ol0<ol005/co`000`000?ooooooo`15oooo000Xoooo00<0000co`0co`00Cc?o0003o`2I<ol0<ol0
048co`02000013?o00800004<ol00P0000<co`04000013?o00030000oooooooo04Goool002Woool0
0`0003?o03?o001><ol000?o09Tco`0co`00@C?o00040000<ol0<ol0000023?o00040000<ol0<ol0
00000S?o00030000<ol0<ol000Dco`000`000?ooooooo`15oooo000Zoooo00<0000co`0co`00CC?o
0003o`2I<ol0<ol0044co`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o
03?o0004<ol00`0004Goool002_oool20000CC?o0003o`2I<ol0<ol0044co`00100003?o03?o0000
00Pco`00100003?o03?o000000@co`000`0003?o03?o0003<ol000<0003oooooool0AOooo`00;Ooo
o`030000<ol0<ol004Xco`000ol0VC?o03?o0011<ol000@0000co`0co`000008<ol000@0000co`0c
o`000002<ol000@0000co`0co`000004<ol000<0003oooooool0AOooo`00;_ooo`030000<ol0<ol0
04Tco`000ol0VC?o03?o0012<ol00P0000Xco`02000013?o00800005<ol000<0003oooooool0AOoo
o`00;oooo`030000<ol0<ol004Pco`000ol0VC?o03?o001K<ol000<0003oooooool0AOooo`00<?oo
o`030000<ol0<ol004Lco`000ol0VC?o03?o001K<ol000<0003oooooool0AOooo`00<Oooo`030000
<ol0<ol004Hco`000ol0VC?o03?o001K<ol000<0003oooooool0AOooo`00<_ooo`030000<ol0<ol0
04Dco`000ol0VC?o03?o001K<ol000<0003oooooool0AOooo`00<oooo`030000<ol0<ol004@co`00
0ol0VC?o03?o001K<ol00P0004Koool003?oool00`0003?o03?o0014<ol000?o09Tco`0co`00Fc?o
00030000oooooooo04Goool003Coool00`0003?o03?o0013<ol000?o09Tco`0co`00Fc?o00030000
oooooooo04Goool003Goool00`0003?o03?o0012<ol000?o09Tco`0co`00Fc?o00030000oooooooo
04Goool003Koool00`0003?o03?o0011<ol000?o09Tco`0co`00Fc?o00030000oooooooo04Goool0
03Ooool00`0003?o03?o0010<ol000?o09Tco`0co`00Fc?o00030000oooooooo04Goool003Soool0
0`0003?o03?o000o<ol000?o09Tco`0co`00Fc?o00030000oooooooo04Goool003Soool00`0003?o
03?o000o<ol000?o09Tco`0co`00Fc?o00030000oooooooo04Goool003Woool00`0003?o03?o000n
<ol000?o09Tco`0co`00Fc?o00800016oooo000joooo00<0000co`0co`00?C?o0003o`2I<ol0<ol0
05/co`000`000?ooooooo`15oooo000koooo00<0000co`0co`00?3?o0003o`2I<ol0<ol005/co`00
0`000?ooooooo`15oooo000loooo00<0000co`0co`00>c?o0003o`2I<ol0<ol005/co`000`000?oo
ooooo`15oooo000loooo00<0000co`0co`00>c?o0003o`2I<ol0<ol005/co`000`000?ooooooo`15
oooo000moooo00<0000co`0co`00>S?o0003o`2I<ol0<ol005/co`000`000?ooooooo`15oooo000m
oooo00<0000co`0co`00>S?o0003o`2I<ol0<ol005/co`000`000?ooooooo`15oooo000noooo00<0
000co`0co`00>C?o0003o`2I<ol0<ol005/co`000`000?ooooooo`15oooo000noooo00<0000co`0c
o`00>C?o0003o`2I<ol0<ol005/co`000`000?ooooooo`15oooo000ooooo00<0000co`0co`00>3?o
0003o`2I<ol0<ol005/co`020000A_ooo`00?oooo`030000<ol0<ol003Pco`000ol0VC?o03?o001K
<ol000<0003oooooool0AOooo`00@?ooo`030000<ol0<ol003Lco`000ol0VC?o03?o001K<ol000<0
003oooooool0AOooo`00@Oooo`030000<ol0<ol003Hco`000ol0VC?o03?o001K<ol000<0003ooooo
ool0AOooo`00@Oooo`030000<ol0<ol003Hco`000ol0VC?o03?o001K<ol000<0003oooooool0AOoo
o`00@_ooo`030000<ol0<ol003Dco`000ol0VC?o03?o001K<ol000<0003oooooool0AOooo`00@_oo
o`030000<ol0<ol003Dco`000ol0VC?o03?o0012<ol00P0000@co`02000013?o00800005<ol00`00
00<co`000`000?ooooooo`15oooo0013oooo00<0000co`0co`00=3?o0003o`2I<ol0<ol0044co`00
100003?o03?o000000Pco`00100003?o03?o000000Dco`000`0003?o03?o0002<ol000<0003ooooo
ool0AOooo`00@oooo`030000<ol0<ol003@co`000ol0VC?o03?o0011<ol000@0000co`0co`000008
<ol000@0000co`0co`000002<ol01@0000<co`030000AOooo`00A?ooo`030000<ol0<ol003<co`00
0ol0VC?o03?o0011<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0000co`0c
o`000004<ol000<0003oooooool0AOooo`00A?ooo`030000<ol0<ol003<co`000ol0VC?o03?o0011
<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`00000013?o00030000
oooooooo04Goool004Goool00`0003?o03?o000b<ol000?o09Tco`0co`00@S?o0080000:<ol00P00
00Dco`02000013?o00030000oooooooo04Goool004Goool00`0003?o03?o000b<ol000?o09Tco`0c
o`00Fc?o00030000oooooooo04Goool004Koool00`0003?o03?o000a<ol000?o09Tco`0co`00Fc?o
00030000oooooooo04Goool004Koool00`0003?o03?o000a<ol000?o09Tco`0co`00Fc?o00030000
oooooooo04Goool004Ooool00`0003?o03?o000`<ol000?o09Tco`0co`00Fc?o00030000oooooooo
04Goool004Ooool00`0003?o03?o000`<ol000?o09Tco`0co`00Fc?o00800016oooo0018oooo00<0
000co`0co`00;c?o0003o`2I<ol0<ol005/co`000`000?ooooooo`15oooo0018oooo00<0000co`0c
o`00;c?o0003o`2I<ol0<ol005/co`000`000?ooooooo`15oooo0019oooo00<0000co`0co`00;S?o
0003o`2I<ol0<ol005/co`000`000?ooooooo`15oooo0019oooo00<0000co`0co`00;S?o0003o`2I
<ol0<ol005/co`000`000?ooooooo`15oooo001:oooo00<0000co`0co`00;C?o0003o`2I<ol0<ol0
05/co`000`000?ooooooo`15oooo001:oooo00<0000co`0co`00;C?o0003o`2I<ol0<ol005/co`00
0`000?ooooooo`15oooo001;oooo00<0000co`0co`00;3?o0003o`2I<ol0<ol005/co`000`000?oo
ooooo`15oooo001;oooo00<0000co`0co`00;3?o0003o`2I<ol0<ol005/co`020000A_ooo`00C?oo
oh`co`18oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00COoooh/co`18oooo001=ooooRc?o
04Soool004kooolZ<ol000<0000co`0co`009c?o00030000<ol0<ol003<co`18oooo001>oooo:C?o
00030000<ol0<ol000Pco`000`0003?o03?o000N<ol000<0000co`0co`00<S?o04Soool004oooolX
<ol000<0000co`0co`000S?o00800004<ol000<0000co`0co`001S?o00800004<ol00P0000@co`02
000013?o00800004<ol000<0000co`0co`00<S?o04Soool004oooolX<ol000D0000co`0co`0co`00
00000S?o00030000<ol0<ol0008co`000`0003?o03?o0004<ol000@0000co`0co`000008<ol000@0
000co`0co`000002<ol000@0000co`0co`000003<ol000<0000co`0co`00<S?o04Soool004oooolW
<ol000<0000co`0co`000S?o00030000<ol0<ol000`co`00100003?o03?o000000Pco`00100003?o
03?o000000Dco`000`0003?o03?o0002<ol000<0000co`0co`00<C?o04Soool0053ooolW<ol000<0
000co`0co`001@0000/co`00100003?o03?o000000Pco`00100003?o03?o000000<co`02000013?o
00030000<ol0<ol0038co`18oooo001@oooo9c?o00050000<ol0<ol0<ol0000000hco`00100003?o
03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o0003<ol000<0000co`0co`00<S?o
04Soool0053ooolX<ol000<0000co`0co`0043?o0080000:<ol00P0000@co`0300000S?o00030000
<ol0<ol003<co`18oooo001AooooQc?o04Soool0057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.41127 .30902 L
.41696 .30902 L
.42237 .30902 L
.42482 .30902 L
.42617 .30902 L
.42744 .30902 L
s
.42744 .30902 m
.42744 .61803 L
s
0 .4 1 r
.02381 .30161 m
.06244 .30047 L
.10458 .29902 L
.14415 .29744 L
.18221 .29567 L
.22272 .2935 L
.26171 .29106 L
.30316 .28805 L
.34309 .28466 L
.3815 .28087 L
.40095 .27872 L
.41127 .27751 L
.41696 .27682 L
.42237 .27615 L
.42482 .27585 L
.42617 .27568 L
.42744 .27551 L
.42816 .30902 L
.42894 .30902 L
.42966 .30902 L
.43031 .30902 L
.43161 .30902 L
.43298 .30902 L
.43413 .30902 L
.43537 .30902 L
.43654 .30902 L
.4376 .30902 L
.43885 .30902 L
.43956 .30902 L
.44021 .30902 L
.44141 .30902 L
.44268 .30902 L
.44385 .30902 L
.44493 .30902 L
.44611 .30902 L
.44735 .30902 L
.45173 .30902 L
.45292 .30902 L
.45404 .30902 L
.45533 .30902 L
.4565 .30902 L
.4578 .30902 L
.45848 .30902 L
.4592 .30902 L
.46051 .30902 L
.46172 .30902 L
.46293 .30902 L
.46425 .30902 L
.46549 .30902 L
.46665 .30902 L
Mistroke
.46779 .30902 L
.46883 .30902 L
.47003 .30902 L
.47115 .30902 L
.47239 .30902 L
.47369 .30902 L
.47481 .30902 L
.47603 .30902 L
.47734 .30902 L
.47808 .30902 L
.47875 .30902 L
.48006 .30902 L
.48129 .30902 L
.48234 .30902 L
.4835 .30902 L
.48472 .30902 L
.48585 .30902 L
.48691 .30902 L
.48788 .30902 L
.48895 .30902 L
.49007 .30902 L
.49121 .30902 L
.49243 .30902 L
.49358 .30902 L
.49463 .30902 L
.49586 .30902 L
.49655 .30902 L
.49719 .30902 L
.49836 .30902 L
.4996 .30902 L
.50082 .30902 L
.50151 .30902 L
.50214 .30902 L
.50331 .30902 L
.50455 .30902 L
.50566 .30902 L
.5067 .30902 L
.50784 .30902 L
.50907 .30902 L
.5103 .30902 L
.51099 .30902 L
.51164 .30902 L
.51296 .30902 L
.51369 .30902 L
.51436 .30902 L
.51556 .30902 L
.51686 .30902 L
.51808 .30902 L
.51922 .30902 L
.52027 .30902 L
Mistroke
.5214 .30902 L
.52247 .30902 L
.52345 .30902 L
.5246 .30902 L
.52584 .30902 L
.52702 .30902 L
.52812 .30902 L
.52935 .30902 L
.53051 .30902 L
.53155 .30902 L
.53268 .30902 L
.53391 .30902 L
.53521 .30902 L
.53632 .30902 L
.53754 .30902 L
.53885 .30902 L
.54006 .30902 L
.54069 .30902 L
.54138 .30902 L
.54211 .30902 L
.54279 .30902 L
.54396 .30902 L
.54518 .30902 L
.54582 .30902 L
.54653 .30902 L
.54776 .30902 L
.54896 .30902 L
.55009 .30902 L
.5514 .30902 L
.55258 .30902 L
.5537 .30902 L
.55474 .30902 L
.55587 .30902 L
.55707 .30902 L
.55837 .30902 L
.55955 .30902 L
.56021 .30902 L
.56092 .30902 L
.56222 .30902 L
.56343 .30902 L
.56472 .30902 L
.56593 .30902 L
.56703 .30902 L
.56772 .30902 L
.56845 .30902 L
.56975 .30902 L
.57047 .30902 L
.57115 .30902 L
.57189 .30902 L
.57268 .30902 L
Mistroke
.57336 .30902 L
.57411 .30902 L
.57481 .30902 L
.57546 .30902 L
.57675 .30902 L
.57799 .30902 L
.57915 .30902 L
.58042 .30902 L
.58157 .30902 L
.58264 .30902 L
.58391 .30902 L
.58507 .30902 L
.5857 .30902 L
.5864 .30902 L
.58765 .30902 L
.58884 .30902 L
.58994 .30902 L
.5911 .30902 L
.59236 .30902 L
.59346 .30902 L
.59446 .30902 L
.59561 .30902 L
.5967 .30902 L
.59789 .30902 L
.59919 .30902 L
.60046 .30902 L
.60118 .30902 L
.60183 .30902 L
.60303 .30902 L
.60428 .30902 L
.60538 .30902 L
.60658 .30902 L
.6073 .30902 L
.60799 .30902 L
.60927 .30902 L
.60999 .30902 L
.61065 .30902 L
.61138 .30902 L
.61215 .30902 L
.61342 .30902 L
.61461 .30902 L
.61592 .30902 L
.61665 .30902 L
.61733 .30902 L
.61862 .30902 L
.61983 .30902 L
.62092 .30902 L
.6221 .30902 L
.62339 .30902 L
.6241 .30902 L
Mistroke
.62475 .30902 L
.62592 .30902 L
.62719 .30902 L
.62838 .30902 L
.6295 .30902 L
.63051 .30902 L
.63161 .30902 L
.6328 .30902 L
.63407 .30902 L
.63515 .30902 L
.63634 .30902 L
.63765 .30902 L
.63831 .30902 L
.63903 .30902 L
.64031 .30902 L
.64149 .30902 L
.64222 .30902 L
.6429 .30902 L
.64418 .30902 L
.64489 .30902 L
.64555 .30902 L
.64627 .30902 L
.64704 .30902 L
.64824 .30902 L
.64936 .30902 L
.65005 .30902 L
.6507 .30902 L
.65192 .30902 L
.6532 .30902 L
.65439 .30902 L
.65569 .30902 L
.65635 .30902 L
.65707 .30902 L
.65829 .30902 L
.65941 .30902 L
.66065 .30902 L
.66135 .30902 L
.66198 .30902 L
.66325 .30902 L
.66397 .30902 L
.66463 .30902 L
.66585 .30902 L
.66715 .30902 L
.66824 .30902 L
.66942 .30902 L
.67053 .30902 L
.67154 .30902 L
.67273 .30902 L
.67403 .30902 L
.67525 .30902 L
Mistroke
.67639 .30902 L
.6777 .30902 L
.67844 .30902 L
.67911 .30902 L
.68034 .30902 L
.68103 .30902 L
.68168 .30902 L
.68281 .30902 L
.68401 .30902 L
.6853 .30902 L
.68648 .30902 L
.68715 .30902 L
.68785 .30902 L
.68912 .30902 L
.68983 .30902 L
.69049 .30902 L
.69122 .30902 L
.692 .30902 L
.69264 .30902 L
.69333 .30902 L
.69406 .30902 L
.69473 .30902 L
.69594 .30902 L
.69723 .30902 L
.69847 .30902 L
.69917 .30902 L
.69982 .30902 L
.70114 .30902 L
.70189 .30902 L
.70256 .30902 L
.70377 .30902 L
.70509 .30902 L
.70633 .30902 L
.70748 .30902 L
.70818 .30902 L
.70893 .30902 L
.70965 .30902 L
.7103 .30902 L
.71155 .30902 L
.71286 .30902 L
.71354 .30902 L
.71427 .30902 L
.71559 .30902 L
.7164 .30902 L
.71716 .30902 L
.71784 .30902 L
.71858 .30902 L
.71983 .30902 L
.721 .30902 L
.72229 .30902 L
Mistroke
.72301 .30902 L
.72367 .30902 L
.72499 .30902 L
.72574 .30902 L
.72643 .30902 L
.7277 .30902 L
.72842 .30902 L
.72906 .30902 L
.73031 .30902 L
.73145 .30902 L
.73271 .30902 L
.73335 .30902 L
.73404 .30902 L
.7352 .30902 L
.73628 .30902 L
.73757 .30902 L
.73874 .30902 L
.73991 .30902 L
.74102 .30902 L
.74223 .30902 L
.74354 .30902 L
.74482 .30902 L
.74602 .30902 L
.74727 .30902 L
.74793 .30902 L
.74864 .30902 L
.74993 .30902 L
.75114 .30902 L
.75224 .30902 L
.75342 .30902 L
.75453 .30902 L
.7557 .30902 L
.7567 .30902 L
.75781 .30902 L
.75847 .30902 L
.75919 .30902 L
.7605 .30902 L
.76178 .30902 L
.76297 .30902 L
.7637 .30902 L
.76438 .30902 L
.76566 .30902 L
.76633 .30902 L
.76704 .30902 L
.76781 .30902 L
.76852 .30902 L
.76972 .30902 L
.771 .30902 L
.77331 .30902 L
.77399 .30902 L
Mistroke
.77472 .30902 L
.77541 .30902 L
.77606 .30902 L
.77727 .30902 L
.77856 .30902 L
.7797 .30902 L
.78095 .30902 L
.78225 .30902 L
.78346 .30902 L
.78459 .30902 L
.78563 .30902 L
.78682 .30902 L
.78794 .30902 L
.79805 .30902 L
.81634 .30902 L
.85483 .30902 L
.89578 .30902 L
.93521 .30902 L
.97312 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Voooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:
oooo00<0003oooooool0:?ooo`040000oooo06Ko06Ko9Oooo`040000oooooooo00002oooo`030000
oooooooo02Goool00`000?ooooooo`0Woooo00@0003oooooool0000;oooo00<0003oooooool03?oo
o`003?ooo`@00004oooo00<0003oooooool08Oooo`@00004oooo00<0003oooooool02?ooo`80000S
oooo100000@0I_l01000001Vooooo`1Voaooool400000_ooo`040000oooooooo00002Oooo`80000X
oooo0P0002Soool010000?ooooooo`0000Woool200003oooo`004_ooo`040000oooooooo0000:_oo
o`030000oooooooo00Soool00`000?ooooooo`0Moooo1`1Vo`Koool010000?ooooooo`1VobGoool0
10000?ooooooo`0000Woool00`000?ooooooo`0Woooo00<0003oooooool09oooo`040000oooooooo
00002Oooo`030000oooooooo00koool001?oool20000:_ooo`80000:oooo0`0001;oool;06Ko3?oo
o`800002oooo00<0I_ooooooool09?ooo`80000:oooo0`0002Ooool00`000?ooooooo`0Xoooo0P00
00[oool300003_ooo`00BooooaD0I_lKoooo00<0I_ooooooool0F_ooo`030000oooooooo04Goool0
047oool:06Ko<?ooo`0306Kooooooooo05[oool00`000?ooooooo`15oooo000/oooo5@1Voc[oool0
0`1Vooooooooo`1Joooo00<0003oooooool0AOooo`004Ooooa/0I_m?oooo00<0I_ooooooool0F_oo
o`030000oooooooo04Goool007_oool00`1Vooooooooo`1Joooo00<0003oooooool0AOooo`002ooo
ool0000700003oooo`004Oooo`030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0003<ol000Go09Tco`0co`0co`0000002C?o00030000<ol0<ol000Lco`000`0003?o
03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0co`00;c?o00030000<ol0<ol002lco`00
0`0003?o03?o0003<ol000?o09Tco`0co`00:3?o00030000<ol0<ol002lco`000`000?ooooooo`0_
oooo00<0003oooooool04oooo`004OooofXco`000ol0VC?o03?o001J<ol000<0003oooooool0AOoo
o`004OooofXco`000ol0VC?o03?o001J<ol000<0003oooooool0AOooo`004OooofXco`000ol0VC?o
03?o001J<ol000<0003oooooool0AOooo`004OooofXco`000ol0VC?o03?o001J<ol000<0003ooooo
ool0AOooo`004OooofXco`000ol0VC?o03?o001J<ol000<0003oooooool0AOooo`004OooofXco`00
0ol0VC?o03?o001J<ol00P0004Koool0017ooomZ<ol000?o09Tco`0co`00FS?o00030000oooooooo
04Goool0017ooomZ<ol000?o09Tco`0co`00FS?o00030000oooooooo04Goool0017ooomZ<ol000?o
09Tco`0co`00FS?o00030000oooooooo04Goool0017ooomZ<ol000?o09Tco`0co`00FS?o00030000
oooooooo04Goool0017ooomZ<ol000?o09Tco`0co`00FS?o00030000oooooooo04Goool0017ooomZ
<ol000?o09Tco`0co`00FS?o00030000oooooooo04Goool0017ooomZ<ol000?o09Tco`0co`00FS?o
00030000oooooooo04Goool0017oool20000J3?o0003o`2I<ol0<ol005Xco`020000A_ooo`004ooo
o`80001V<ol000?o09Tco`0co`00FS?o00030000oooooooo04Goool001Goool20000I3?o0003o`2I
<ol0<ol005Xco`000`000?ooooooo`15oooo000Goooo0P00068co`000ol0VC?o03?o001J<ol000<0
003oooooool0AOooo`006Oooo`80001P<ol000?o09Tco`0co`00FS?o00030000oooooooo04Goool0
01_oool20000GS?o0003o`2I<ol0<ol005Xco`000`000?ooooooo`15oooo000Moooo0P0005`co`00
0ol0VC?o03?o001J<ol000<0003oooooool0AOooo`007oooo`030000<ol0<ol005Tco`000ol0VC?o
03?o001J<ol000<0003oooooool0AOooo`008?ooo`030000<ol0<ol005Pco`000ol0VC?o03?o001J
<ol00P0004Koool0027oool20000F3?o0003o`2I<ol0<ol005Xco`000`000?ooooooo`15oooo000S
oooo00<0000co`0co`00EC?o0003o`2I<ol0<ol005Xco`000`000?ooooooo`15oooo000Toooo0P00
05Dco`000ol0VC?o03?o001J<ol000<0003oooooool0AOooo`009_ooo`030000<ol0<ol0058co`00
0ol0VC?o03?o001J<ol000<0003oooooool0AOooo`009oooo`030000<ol0<ol0054co`000ol0VC?o
03?o001J<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol0050co`000ol0VC?o03?o0011
<ol00P0000@co`02000013?o00800003<ol0100000@co`000`000?ooooooo`15oooo000Yoooo00<0
000co`0co`00Cc?o0003o`2I<ol0<ol0040co`00100003?o03?o000000Pco`00100003?o03?o0000
008co`000`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_ooo`030000<ol0<ol004hco`00
0ol0VC?o03?o0010<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`0c
o`0013?o00<00015oooo000[oooo0P0004hco`000ol0VC?o03?o0010<ol000@0000co`0co`000008
<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o00030000oooooooo04Goool002goool0
0`0003?o03?o001;<ol000?o09Tco`0co`00@3?o00040000<ol0<ol0000023?o00040000<ol0<ol0
00000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool002koool00`0003?o03?o001:
<ol000?o09Tco`0co`00@C?o0080000:<ol00P0000@co`0200001C?o00030000oooooooo04Goool0
02ooool00`0003?o03?o0019<ol000?o09Tco`0co`00FS?o00030000oooooooo04Goool0033oool0
0`0003?o03?o0018<ol000?o09Tco`0co`00FS?o00030000oooooooo04Goool0037oool00`0003?o
03?o0017<ol000?o09Tco`0co`00FS?o00030000oooooooo04Goool003;oool00`0003?o03?o0016
<ol000?o09Tco`0co`00FS?o00030000oooooooo04Goool003?oool00`0003?o03?o0015<ol000?o
09Tco`0co`00FS?o00800016oooo000coooo00<0000co`0co`00AC?o0003o`2I<ol0<ol005Xco`00
0`000?ooooooo`15oooo000doooo00<0000co`0co`00A3?o0003o`2I<ol0<ol005Xco`000`000?oo
ooooo`15oooo000eoooo00<0000co`0co`00@c?o0003o`2I<ol0<ol005Xco`000`000?ooooooo`15
oooo000foooo00<0000co`0co`00@S?o0003o`2I<ol0<ol005Xco`000`000?ooooooo`15oooo000g
oooo00<0000co`0co`00@C?o0003o`2I<ol0<ol005Xco`000`000?ooooooo`15oooo000hoooo00<0
000co`0co`00@3?o0003o`2I<ol0<ol005Xco`000`000?ooooooo`15oooo000hoooo00<0000co`0c
o`00@3?o0003o`2I<ol0<ol005Xco`000`000?ooooooo`15oooo000ioooo00<0000co`0co`00?c?o
0003o`2I<ol0<ol005Xco`020000A_ooo`00>_ooo`030000<ol0<ol003hco`000ol0VC?o03?o001J
<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol003dco`000ol0VC?o03?o001J<ol000<0
003oooooool0AOooo`00??ooo`030000<ol0<ol003`co`000ol0VC?o03?o001J<ol000<0003ooooo
ool0AOooo`00??ooo`030000<ol0<ol003`co`000ol0VC?o03?o001J<ol000<0003oooooool0AOoo
o`00?Oooo`030000<ol0<ol003/co`000ol0VC?o03?o001J<ol000<0003oooooool0AOooo`00?Ooo
o`030000<ol0<ol003/co`000ol0VC?o03?o001J<ol000<0003oooooool0AOooo`00?_ooo`030000
<ol0<ol003Xco`000ol0VC?o03?o001J<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol0
03Xco`000ol0VC?o03?o001J<ol000<0003oooooool0AOooo`00?oooo`030000<ol0<ol003Tco`00
0ol0VC?o03?o001J<ol00P0004Koool003ooool00`0003?o03?o000i<ol000?o09Tco`0co`00FS?o
00030000oooooooo04Goool0043oool00`0003?o03?o000h<ol000?o09Tco`0co`00FS?o00030000
oooooooo04Goool0047oool00`0003?o03?o000g<ol000?o09Tco`0co`00FS?o00030000oooooooo
04Goool0047oool00`0003?o03?o000g<ol000?o09Tco`0co`00FS?o00030000oooooooo04Goool0
04;oool00`0003?o03?o000f<ol000?o09Tco`0co`00FS?o00030000oooooooo04Goool004;oool0
0`0003?o03?o000f<ol000?o09Tco`0co`00@C?o00800004<ol00P0000@co`0200001C?o00<00003
<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol003Dco`000ol0VC?o03?o0010<ol000@0
000co`0co`000008<ol000@0000co`0co`000005<ol000<0000co`0co`000S?o00030000oooooooo
04Goool004?oool00`0003?o03?o000e<ol000?o09Tco`0co`00@3?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool00`0003?o03?o000d<ol000?o
09Tco`0co`00@3?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0
000013?o00030000oooooooo04Goool004Coool00`0003?o03?o000d<ol000?o09Tco`0co`00@3?o
00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0000000@co`000`000?oo
ooooo`15oooo0015oooo00<0000co`0co`00<c?o0003o`2I<ol0<ol0044co`0200002S?o00800005
<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`00<c?o0003o`2I<ol0<ol0
05Xco`000`000?ooooooo`15oooo0016oooo00<0000co`0co`00<S?o0003o`2I<ol0<ol005Xco`00
0`000?ooooooo`15oooo0016oooo00<0000co`0co`00<S?o0003o`2I<ol0<ol005Xco`000`000?oo
ooooo`15oooo0017oooo00<0000co`0co`00<C?o0003o`2I<ol0<ol005Xco`000`000?ooooooo`15
oooo0017oooo00<0000co`0co`00<C?o0003o`2I<ol0<ol005Xco`020000A_ooo`00B?ooo`030000
<ol0<ol0030co`000ol0VC?o03?o001J<ol000<0003oooooool0AOooo`00B?ooo`030000<ol0<ol0
030co`000ol0VC?o03?o001J<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol002lco`00
0ol0VC?o03?o001J<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol002lco`000ol0VC?o
03?o001J<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol002hco`000ol0VC?o03?o001J
<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol002hco`000ol0VC?o03?o001J<ol000<0
003oooooool0AOooo`00Boooo`030000<ol0<ol002dco`000ol0VC?o03?o001J<ol000<0003ooooo
ool0AOooo`00Boooo`030000<ol0<ol002dco`000ol0VC?o03?o001J<ol00P0004Koool004cooon<
<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;<ol0B?ooo`00COoooh/co`18
oooo001>oooo:S?o00030000<ol0<ol002Lco`000`0003?o03?o000c<ol0B?ooo`00C_ooobTco`00
0`0003?o03?o0008<ol000<0000co`0co`007S?o00030000<ol0<ol0038co`18oooo001?oooo:3?o
00030000<ol0<ol0008co`02000013?o00030000<ol0<ol000Hco`02000013?o00800004<ol00P00
00<co`03000013?o00030000<ol0<ol0038co`18oooo001?oooo:3?o00050000<ol0<ol0<ol00000
008co`000`0003?o03?o0002<ol000<0000co`0co`0013?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000S?o00040000<ol0<ol000000c?o00030000<ol0<ol0038co`18oooo001?oooo9c?o
00030000<ol0<ol0008co`000`0003?o03?o000<<ol000@0000co`0co`000008<ol000@0000co`0c
o`000002<ol000@0000co`0co`000004<ol000<0000co`0co`00<C?o04Soool0053ooolW<ol000<0
000co`0co`001@0000/co`00100003?o03?o000000Pco`00100003?o03?o0000008co`03000013?o
00030000<ol0<ol0038co`18oooo001@oooo9c?o00050000<ol0<ol0<ol0000000hco`00100003?o
03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o0003<ol000<0000co`0co`00<S?o
04Soool0053ooolX<ol000<0000co`0co`0043?o0080000:<ol00P0000@co`0300000S?o00030000
<ol0<ol003<co`18oooo001AooooQc?o04Soool0057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.07) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.41127 .30902 L
.41696 .30902 L
.42237 .30902 L
.42744 .30902 L
.42883 .30902 L
.42959 .30902 L
.43031 .30902 L
.43098 .30902 L
s
.43098 .30902 m
.43099 .61803 L
s
0 .4 1 r
.02381 .30038 m
.06244 .29904 L
.10458 .29735 L
.14415 .2955 L
.18221 .29344 L
.22272 .2909 L
.26171 .28806 L
.30316 .28454 L
.34309 .28059 L
.3815 .27616 L
.40095 .27365 L
.41127 .27224 L
.41696 .27144 L
.42237 .27066 L
.42744 .26991 L
.42883 .26971 L
.42959 .26959 L
.43031 .26948 L
.43098 .26938 L
.43171 .30902 L
.43298 .30902 L
.43415 .30902 L
.43543 .30902 L
.43608 .30902 L
.43678 .30902 L
.43803 .30902 L
.43928 .30902 L
.44046 .30902 L
.44153 .30902 L
.44268 .30902 L
.44386 .30902 L
.44496 .30902 L
.44617 .30902 L
.44748 .30902 L
.44877 .30902 L
.44942 .30902 L
.45013 .30902 L
.45141 .30902 L
.45257 .30902 L
.45375 .30902 L
.45486 .30902 L
.45603 .30902 L
.45731 .30902 L
.45842 .30902 L
.4596 .30902 L
.46061 .30902 L
.46172 .30902 L
.46301 .30902 L
.46421 .30902 L
.46553 .30902 L
Mistroke
.46626 .30902 L
.46693 .30902 L
.46816 .30902 L
.46885 .30902 L
.46948 .30902 L
.47065 .30902 L
.47188 .30902 L
.47299 .30902 L
.47417 .30902 L
.47529 .30902 L
.47631 .30902 L
.4775 .30902 L
.4788 .30902 L
.48003 .30902 L
.48116 .30902 L
.48236 .30902 L
.48365 .30902 L
.48487 .30902 L
.48599 .30902 L
.48722 .30902 L
.48793 .30902 L
.48858 .30902 L
.48926 .30902 L
.48999 .30902 L
.4913 .30902 L
.49197 .30902 L
.49268 .30902 L
.49396 .30902 L
.49467 .30902 L
.49533 .30902 L
.49606 .30902 L
.49684 .30902 L
.49751 .30902 L
.49824 .30902 L
.49893 .30902 L
.49957 .30902 L
.50077 .30902 L
.50206 .30902 L
.50319 .30902 L
.50443 .30902 L
.50573 .30902 L
.50693 .30902 L
.50807 .30902 L
.5091 .30902 L
.51029 .30902 L
.51141 .30902 L
.51263 .30902 L
.51393 .30902 L
.51503 .30902 L
.51625 .30902 L
Mistroke
.51756 .30902 L
.51829 .30902 L
.51896 .30902 L
.52027 .30902 L
.5215 .30902 L
.52265 .30902 L
.5237 .30902 L
.5249 .30902 L
.52604 .30902 L
.52709 .30902 L
.52806 .30902 L
.52912 .30902 L
.53024 .30902 L
.53138 .30902 L
.53259 .30902 L
.53374 .30902 L
.53479 .30902 L
.53601 .30902 L
.53671 .30902 L
.53735 .30902 L
.53853 .30902 L
.53977 .30902 L
.54091 .30902 L
.54216 .30902 L
.54346 .30902 L
.54467 .30902 L
.54581 .30902 L
.54684 .30902 L
.54803 .30902 L
.54915 .30902 L
.55038 .30902 L
.55168 .30902 L
.55279 .30902 L
.55401 .30902 L
.55531 .30902 L
.55605 .30902 L
.55672 .30902 L
.55802 .30902 L
.55926 .30902 L
.56042 .30902 L
.56146 .30902 L
.56267 .30902 L
.5638 .30902 L
.56486 .30902 L
.56583 .30902 L
.56689 .30902 L
.56801 .30902 L
.56915 .30902 L
.57037 .30902 L
.57151 .30902 L
Mistroke
.57256 .30902 L
.57379 .30902 L
.57448 .30902 L
.57512 .30902 L
.5763 .30902 L
.57755 .30902 L
.57866 .30902 L
.57985 .30902 L
.58115 .30902 L
.58237 .30902 L
.5836 .30902 L
.58477 .30902 L
.58582 .30902 L
.58695 .30902 L
.58759 .30902 L
.58829 .30902 L
.58902 .30902 L
.5897 .30902 L
.59092 .30902 L
.59223 .30902 L
.59345 .30902 L
.59475 .30902 L
.59585 .30902 L
.59707 .30902 L
.59828 .30902 L
.59942 .30902 L
.60066 .30902 L
.60135 .30902 L
.60198 .30902 L
.60307 .30902 L
.60425 .30902 L
.60549 .30902 L
.60664 .30902 L
.60778 .30902 L
.60885 .30902 L
.60981 .30902 L
.61086 .30902 L
.612 .30902 L
.6132 .30902 L
.61423 .30902 L
.61537 .30902 L
.61666 .30902 L
.61786 .30902 L
.61918 .30902 L
.61991 .30902 L
.62058 .30902 L
.6218 .30902 L
.62249 .30902 L
.62313 .30902 L
.62429 .30902 L
Mistroke
.62552 .30902 L
.62663 .30902 L
.62781 .30902 L
.62893 .30902 L
.62995 .30902 L
.63115 .30902 L
.63245 .30902 L
.63367 .30902 L
.63481 .30902 L
.64 .30902 L
.64068 .30902 L
.64141 .30902 L
.64272 .30902 L
.64344 .30902 L
.64409 .30902 L
.64486 .30902 L
.64559 .30902 L
.6469 .30902 L
.64812 .30902 L
.64875 .30902 L
.64945 .30902 L
.65018 .30902 L
.65086 .30902 L
.65208 .30902 L
.65319 .30902 L
.65448 .30902 L
.6557 .30902 L
.65676 .30902 L
.65795 .30902 L
.65918 .30902 L
.66034 .30902 L
.66142 .30902 L
.66241 .30902 L
.6635 .30902 L
.66464 .30902 L
.66581 .30902 L
.66705 .30902 L
.66823 .30902 L
.6693 .30902 L
.67055 .30902 L
.67126 .30902 L
.67191 .30902 L
.67312 .30902 L
.67439 .30902 L
.67566 .30902 L
.67683 .30902 L
.67747 .30902 L
.67818 .30902 L
.67945 .30902 L
.68065 .30902 L
Mistroke
.68191 .30902 L
.68311 .30902 L
.6842 .30902 L
.68488 .30902 L
.68559 .30902 L
.68687 .30902 L
.68758 .30902 L
.68825 .30902 L
.68898 .30902 L
.68976 .30902 L
.69044 .30902 L
.69117 .30902 L
.69186 .30902 L
.6925 .30902 L
.69371 .30902 L
.695 .30902 L
.69614 .30902 L
.69738 .30902 L
.69868 .30902 L
.69989 .30902 L
.70103 .30902 L
.70206 .30902 L
.70325 .30902 L
.70438 .30902 L
.7056 .30902 L
.7069 .30902 L
.70802 .30902 L
.70922 .30902 L
.71052 .30902 L
.71173 .30902 L
.71246 .30902 L
.71316 .30902 L
.71448 .30902 L
.71563 .30902 L
.71668 .30902 L
.71788 .30902 L
.71902 .30902 L
.72007 .30902 L
.72104 .30902 L
.7221 .30902 L
.72323 .30902 L
.72436 .30902 L
.72558 .30902 L
.72673 .30902 L
.72777 .30902 L
.729 .30902 L
.7297 .30902 L
.73034 .30902 L
.73151 .30902 L
.73276 .30902 L
Mistroke
.73396 .30902 L
.73527 .30902 L
.73651 .30902 L
.73767 .30902 L
.73881 .30902 L
.73984 .30902 L
.74097 .30902 L
.74216 .30902 L
.74346 .30902 L
.74466 .30902 L
.74595 .30902 L
.74668 .30902 L
.74737 .30902 L
.74861 .30902 L
.74974 .30902 L
.75104 .30902 L
.75228 .30902 L
.75332 .30902 L
.75448 .30902 L
.75682 .30902 L
.76104 .30902 L
.77057 .30902 L
.7718 .30902 L
.77311 .30902 L
.77435 .30902 L
.77548 .30902 L
.77675 .30902 L
.77795 .30902 L
.77924 .30902 L
.77998 .30902 L
.78065 .30902 L
.78297 .30902 L
.7841 .30902 L
.78514 .30902 L
.78623 .30902 L
.78741 .30902 L
.7899 .30902 L
.81075 .30902 L
.85049 .30902 L
.88871 .30902 L
.92938 .30902 L
.96854 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.07) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@0000;oool200001?ooo`80000Yoooo1@0002Ooool200001?ooo`800004oooo0P00
02Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003ooooo
ool0:oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`00001Vo`1Vo`0206Ko9?oo
o`040000oooooooo00002?ooo`040000oooooooo00009oooo`030000oooooooo02Ooool010000?oo
ooooo`0000Soool010000?ooooooo`0000koool001?oool00`000?ooooooo`0Zoooo00<0003ooooo
ool02_ooo`030000oooooooo02;oool606Ko00D0003oooooooooool0I_l09?ooo`040000oooooooo
00002oooo`030000oooooooo02Goool00`000?ooooooo`0Woooo00@0003oooooool0000;oooo00<0
003oooooool03?ooo`003?ooo`@00004oooo00<0003oooooool08Oooo`@00004oooo00<0003ooooo
ool02?ooo`80000Noooo1@1Vo`@00004oooo00D0003oooooooooool0I_l07_ooo`@00002oooo00@0
003oooooool00009oooo0P0002Soool20000:?ooo`040000oooooooo00002Oooo`80000?oooo000B
oooo00@0003oooooool0000Zoooo00<0003oooooool02?ooo`030000oooooooo01;oool;06Ko3Ooo
o`050000oooooooooooo06Ko02Coool010000?ooooooo`0000Woool00`000?ooooooo`0Woooo00<0
003oooooool09oooo`040000oooooooo00002Oooo`030000oooooooo00koool001?oool20000:_oo
o`80000:oooo0`0000Ooool;06Ko5oooo`800003oooo00<0I_ooooooool08oooo`80000:oooo0`00
02Ooool00`000?ooooooo`0Xoooo0P0000[oool300003_ooo`00@Ooooa@0I_lWoooo00<0I_oooooo
ool0FOooo`030000oooooooo04Goool003Ooool:06Ko>oooo`0306Kooooooooo05Woool00`000?oo
ooooo`15oooo000Roooo5@1VodGoool00`1Vooooooooo`1Ioooo00<0003oooooool0AOooo`004Ooo
oa40I_mJoooo00<0I_ooooooool0FOooo`030000oooooooo04Goool007coool00`1Vooooooooo`1I
oooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0004<ol000Co09Tco`0co`000009<ol000<0
000co`0co`001c?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo01?oool0017oool00`0003?o03?o000_
<ol000<0000co`0co`00;c?o00030000<ol0<ol000@co`000ol0VC?o03?o000W<ol000<0000co`0c
o`00;c?o00030000oooooooo02ooool00`000?ooooooo`0Coooo000AooooJc?o0003o`2I<ol0<ol0
05Tco`000`000?ooooooo`15oooo000AooooJc?o0003o`2I<ol0<ol005Tco`000`000?ooooooo`15
oooo000AooooJc?o0003o`2I<ol0<ol005Tco`000`000?ooooooo`15oooo000AooooJc?o0003o`2I
<ol0<ol005Tco`000`000?ooooooo`15oooo000AooooJc?o0003o`2I<ol0<ol005Tco`000`000?oo
ooooo`15oooo000AooooJc?o0003o`2I<ol0<ol005Tco`020000A_ooo`004Oooof/co`000ol0VC?o
03?o001I<ol000<0003oooooool0AOooo`004Oooof/co`000ol0VC?o03?o001I<ol000<0003ooooo
ool0AOooo`004Oooof/co`000ol0VC?o03?o001I<ol000<0003oooooool0AOooo`004Oooof/co`00
0ol0VC?o03?o001I<ol000<0003oooooool0AOooo`004Oooof/co`000ol0VC?o03?o001I<ol000<0
003oooooool0AOooo`004Oooof/co`000ol0VC?o03?o001I<ol000<0003oooooool0AOooo`004Ooo
of/co`000ol0VC?o03?o001I<ol000<0003oooooool0AOooo`004Oooo`80001Y<ol000?o09Tco`0c
o`00FC?o00800016oooo000Coooo0P0006Lco`000ol0VC?o03?o001I<ol000<0003oooooool0AOoo
o`005Oooo`80001U<ol000?o09Tco`0co`00FC?o00030000oooooooo04Goool001Ooool20000Hc?o
0003o`2I<ol0<ol005Tco`000`000?ooooooo`15oooo000Ioooo0P00064co`000ol0VC?o03?o001I
<ol000<0003oooooool0AOooo`006oooo`80001O<ol000?o09Tco`0co`00FC?o00030000oooooooo
04Goool001goool20000GC?o0003o`2I<ol0<ol005Tco`000`000?ooooooo`15oooo000Ooooo00<0
000co`0co`00FS?o0003o`2I<ol0<ol005Tco`000`000?ooooooo`15oooo000Poooo00<0000co`0c
o`00FC?o0003o`2I<ol0<ol005Tco`020000A_ooo`008Oooo`80001I<ol000?o09Tco`0co`00FC?o
00030000oooooooo04Goool002?oool00`0003?o03?o001F<ol000?o09Tco`0co`00FC?o00030000
oooooooo04Goool002Coool20000ES?o0003o`2I<ol0<ol005Tco`000`000?ooooooo`15oooo000V
oooo00<0000co`0co`00Dc?o0003o`2I<ol0<ol005Tco`000`000?ooooooo`15oooo000Woooo00<0
000co`0co`00DS?o0003o`2I<ol0<ol005Tco`000`000?ooooooo`15oooo000Xoooo00<0000co`0c
o`00DC?o0003o`2I<ol0<ol0040co`02000013?o00800004<ol00P0000<co`04000013?o00030000
oooooooo04Goool002Woool00`0003?o03?o001@<ol000?o09Tco`0co`00?c?o00040000<ol0<ol0
000023?o00040000<ol0<ol000000S?o00030000<ol0<ol000Dco`000`000?ooooooo`15oooo000Z
oooo00<0000co`0co`00Cc?o0003o`2I<ol0<ol003lco`00100003?o03?o000000Pco`00100003?o
03?o000000<co`000`0003?o03?o0004<ol00`0004Goool002_oool20000Cc?o0003o`2I<ol0<ol0
03lco`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`0003?o03?o0003<ol000<0
003oooooool0AOooo`00;Oooo`030000<ol0<ol004`co`000ol0VC?o03?o000o<ol000@0000co`0c
o`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000004<ol000<0003oooooool0AOoo
o`00;_ooo`030000<ol0<ol004/co`000ol0VC?o03?o0010<ol00P0000Xco`02000013?o00800005
<ol000<0003oooooool0AOooo`00;oooo`030000<ol0<ol004Xco`000ol0VC?o03?o001I<ol000<0
003oooooool0AOooo`00<?ooo`030000<ol0<ol004Tco`000ol0VC?o03?o001I<ol000<0003ooooo
ool0AOooo`00<Oooo`030000<ol0<ol004Pco`000ol0VC?o03?o001I<ol000<0003oooooool0AOoo
o`00<_ooo`030000<ol0<ol004Lco`000ol0VC?o03?o001I<ol000<0003oooooool0AOooo`00<ooo
o`030000<ol0<ol004Hco`000ol0VC?o03?o001I<ol00P0004Koool003?oool00`0003?o03?o0016
<ol000?o09Tco`0co`00FC?o00030000oooooooo04Goool003Coool00`0003?o03?o0015<ol000?o
09Tco`0co`00FC?o00030000oooooooo04Goool003Goool00`0003?o03?o0014<ol000?o09Tco`0c
o`00FC?o00030000oooooooo04Goool003Koool00`0003?o03?o0013<ol000?o09Tco`0co`00FC?o
00030000oooooooo04Goool003Ooool00`0003?o03?o0012<ol000?o09Tco`0co`00FC?o00030000
oooooooo04Goool003Soool00`0003?o03?o0011<ol000?o09Tco`0co`00FC?o00030000oooooooo
04Goool003Soool00`0003?o03?o0011<ol000?o09Tco`0co`00FC?o00030000oooooooo04Goool0
03Woool00`0003?o03?o0010<ol000?o09Tco`0co`00FC?o00800016oooo000joooo00<0000co`0c
o`00?c?o0003o`2I<ol0<ol005Tco`000`000?ooooooo`15oooo000koooo00<0000co`0co`00?S?o
0003o`2I<ol0<ol005Tco`000`000?ooooooo`15oooo000loooo00<0000co`0co`00?C?o0003o`2I
<ol0<ol005Tco`000`000?ooooooo`15oooo000loooo00<0000co`0co`00?C?o0003o`2I<ol0<ol0
05Tco`000`000?ooooooo`15oooo000moooo00<0000co`0co`00?3?o0003o`2I<ol0<ol005Tco`00
0`000?ooooooo`15oooo000moooo00<0000co`0co`00?3?o0003o`2I<ol0<ol005Tco`000`000?oo
ooooo`15oooo000noooo00<0000co`0co`00>c?o0003o`2I<ol0<ol005Tco`000`000?ooooooo`15
oooo000noooo00<0000co`0co`00>c?o0003o`2I<ol0<ol005Tco`000`000?ooooooo`15oooo000o
oooo00<0000co`0co`00>S?o0003o`2I<ol0<ol005Tco`020000A_ooo`00?oooo`030000<ol0<ol0
03Xco`000ol0VC?o03?o001I<ol000<0003oooooool0AOooo`00@?ooo`030000<ol0<ol003Tco`00
0ol0VC?o03?o001I<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol003Pco`000ol0VC?o
03?o001I<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol003Pco`000ol0VC?o03?o001I
<ol000<0003oooooool0AOooo`00@_ooo`030000<ol0<ol003Lco`000ol0VC?o03?o001I<ol000<0
003oooooool0AOooo`00@_ooo`030000<ol0<ol003Lco`000ol0VC?o03?o0010<ol00P0000@co`02
000013?o00800005<ol00`0000<co`000`000?ooooooo`15oooo0013oooo00<0000co`0co`00=S?o
0003o`2I<ol0<ol003lco`00100003?o03?o000000Pco`00100003?o03?o000000Dco`000`0003?o
03?o0002<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol003Hco`000ol0VC?o03?o000o
<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol01@0000<co`030000AOooo`00A?oo
o`030000<ol0<ol003Dco`000ol0VC?o03?o000o<ol000@0000co`0co`000008<ol000@0000co`0c
o`000002<ol000@0000co`0co`000004<ol000<0003oooooool0AOooo`00A?ooo`030000<ol0<ol0
03Dco`000ol0VC?o03?o000o<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0
000co`00000013?o00030000oooooooo04Goool004Goool00`0003?o03?o000d<ol000?o09Tco`0c
o`00@3?o0080000:<ol00P0000Dco`02000013?o00030000oooooooo04Goool004Goool00`0003?o
03?o000d<ol000?o09Tco`0co`00FC?o00030000oooooooo04Goool004Koool00`0003?o03?o000c
<ol000?o09Tco`0co`00FC?o00030000oooooooo04Goool004Koool00`0003?o03?o000c<ol000?o
09Tco`0co`00FC?o00030000oooooooo04Goool004Ooool00`0003?o03?o000b<ol000?o09Tco`0c
o`00FC?o00030000oooooooo04Goool004Ooool00`0003?o03?o000b<ol000?o09Tco`0co`00FC?o
00800016oooo0018oooo00<0000co`0co`00<C?o0003o`2I<ol0<ol005Tco`000`000?ooooooo`15
oooo0018oooo00<0000co`0co`00<C?o0003o`2I<ol0<ol005Tco`000`000?ooooooo`15oooo0019
oooo00<0000co`0co`00<3?o0003o`2I<ol0<ol005Tco`000`000?ooooooo`15oooo0019oooo00<0
000co`0co`00<3?o0003o`2I<ol0<ol005Tco`000`000?ooooooo`15oooo001:oooo00<0000co`0c
o`00;c?o0003o`2I<ol0<ol005Tco`000`000?ooooooo`15oooo001:oooo00<0000co`0co`00;c?o
0003o`2I<ol0<ol005Tco`000`000?ooooooo`15oooo001;oooo00<0000co`0co`00;S?o0003o`2I
<ol0<ol005Tco`000`000?ooooooo`15oooo001;oooo00<0000co`0co`00;S?o0003o`2I<ol0<ol0
05Tco`020000A_ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00COoo
oh/co`18oooo001=ooooRc?o04Soool004kooolZ<ol000<0000co`0co`009c?o00030000<ol0<ol0
03<co`18oooo001>oooo:C?o00030000<ol0<ol000Pco`000`0003?o03?o000N<ol000<0000co`0c
o`00<S?o04Soool004oooolX<ol000<0000co`0co`000S?o00800004<ol000<0000co`0co`001S?o
00800004<ol00P0000@co`0200001C?o00030000<ol0<ol0008co`000`0003?o03?o000b<ol0B?oo
o`00CoooobPco`001@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o00030000<ol0<ol0
00@co`00100003?o03?o000000Pco`00100003?o03?o000000@co`000`0003?o03?o0002<ol000<0
000co`0co`00<S?o04Soool004oooolW<ol000<0000co`0co`000S?o00030000<ol0<ol000`co`00
100003?o03?o000000Pco`00100003?o03?o000000@co`000`0003?o03?o0003<ol000<0000co`0c
o`00<C?o04Soool0053ooolW<ol000<0000co`0co`001@0000/co`00100003?o03?o000000Pco`00
100003?o03?o000000Dco`001@0003?o03?o03?o0000000d<ol0B?ooo`00D?ooobLco`001@0003?o
03?o03?o0000000><ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0000co`0c
o`000003<ol000<0000co`0co`00<S?o04Soool0053ooolX<ol000<0000co`0co`0043?o0080000:
<ol00P0000<co`0400000S?o00030000<ol0<ol003<co`18oooo001AooooQc?o04Soool0057ooon7
<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.41127 .30902 L
.42237 .30902 L
.42781 .30902 L
.43049 .30902 L
.43298 .30902 L
.43413 .30902 L
.43522 .30902 L
s
.43522 .30902 m
.43523 .61803 L
s
0 .4 1 r
.02381 .29914 m
.06244 .29761 L
.10458 .29568 L
.14415 .29356 L
.18221 .29121 L
.22272 .2883 L
.26171 .28506 L
.30316 .28103 L
.34309 .27651 L
.3815 .27145 L
.40095 .26858 L
.41127 .26697 L
.42237 .26516 L
.42781 .26424 L
.43049 .26378 L
.43298 .26335 L
.43413 .26315 L
.43522 .26296 L
.43648 .30902 L
.43762 .30902 L
.43888 .30902 L
.44005 .30902 L
.44133 .30902 L
.44198 .30902 L
.44268 .30902 L
.44396 .30902 L
.44517 .30902 L
.44625 .30902 L
.44743 .30902 L
.44872 .30902 L
.44936 .30902 L
.45008 .30902 L
.45136 .30902 L
.45253 .30902 L
.45364 .30902 L
.45481 .30902 L
.45598 .30902 L
.45727 .30902 L
.45838 .30902 L
.45957 .30902 L
.46068 .30902 L
.46172 .30902 L
.46295 .30902 L
.46366 .30902 L
.46431 .30902 L
.46563 .30902 L
.46635 .30902 L
.46705 .30902 L
.46827 .30902 L
.4694 .30902 L
Mistroke
.47064 .30902 L
.47196 .30902 L
.47271 .30902 L
.4734 .30902 L
.47415 .30902 L
.47496 .30902 L
.47567 .30902 L
.47634 .30902 L
.47704 .30902 L
.47779 .30902 L
.47847 .30902 L
.47921 .30902 L
.4799 .30902 L
.48055 .30902 L
.48177 .30902 L
.48306 .30902 L
.48431 .30902 L
.48544 .30902 L
.48669 .30902 L
.48801 .30902 L
.48916 .30902 L
.49023 .30902 L
.4914 .30902 L
.49265 .30902 L
.49336 .30902 L
.49402 .30902 L
.49474 .30902 L
.4955 .30902 L
.49678 .30902 L
.49751 .30902 L
.49819 .30902 L
.50321 .30902 L
.51365 .30902 L
.51493 .30902 L
.51614 .30902 L
.5174 .30902 L
.51806 .30902 L
.51879 .30902 L
.51999 .30902 L
.52127 .30902 L
.52235 .30902 L
.52354 .30902 L
.52468 .30902 L
.52576 .30902 L
.52701 .30902 L
.52814 .30902 L
.52921 .30902 L
.53019 .30902 L
.53128 .30902 L
.53242 .30902 L
Mistroke
.53357 .30902 L
.5348 .30902 L
.53596 .30902 L
.53702 .30902 L
.53827 .30902 L
.53897 .30902 L
.53962 .30902 L
.54082 .30902 L
.54209 .30902 L
.54333 .30902 L
.54404 .30902 L
.5447 .30902 L
.5454 .30902 L
.54603 .30902 L
.54676 .30902 L
.54745 .30902 L
.54868 .30902 L
.54982 .30902 L
.55106 .30902 L
.55169 .30902 L
.55239 .30902 L
.55309 .30902 L
.55383 .30902 L
.55515 .30902 L
.55589 .30902 L
.55657 .30902 L
.55733 .30902 L
.55813 .30902 L
.55883 .30902 L
.55958 .30902 L
.5603 .30902 L
.56095 .30902 L
.5622 .30902 L
.56352 .30902 L
.56477 .30902 L
.56591 .30902 L
.56723 .30902 L
.56848 .30902 L
.56964 .30902 L
.57071 .30902 L
.57188 .30902 L
.57313 .30902 L
.5738 .30902 L
.5745 .30902 L
.57528 .30902 L
.57599 .30902 L
.57727 .30902 L
.578 .30902 L
.57867 .30902 L
.57993 .30902 L
Mistroke
.58062 .30902 L
.58127 .30902 L
.58243 .30902 L
.58369 .30902 L
.59313 .30902 L
.59571 .30902 L
.59639 .30902 L
.59714 .30902 L
.59784 .30902 L
.59849 .30902 L
.59976 .30902 L
.60047 .30902 L
.60112 .30902 L
.60235 .30902 L
.60352 .30902 L
.60474 .30902 L
.60543 .30902 L
.60608 .30902 L
.60738 .30902 L
.60811 .30902 L
.60878 .30902 L
.60997 .30902 L
.61126 .30902 L
.61249 .30902 L
.61362 .30902 L
.61492 .30902 L
.61614 .30902 L
.61683 .30902 L
.61747 .30902 L
.61818 .30902 L
.61892 .30902 L
.61959 .30902 L
.62031 .30902 L
.62161 .30902 L
.6224 .30902 L
.62315 .30902 L
.62382 .30902 L
.62455 .30902 L
.63481 .30902 L
.63604 .30902 L
.63674 .30902 L
.63738 .30902 L
.63867 .30902 L
.63983 .30902 L
.64097 .30902 L
.64205 .30902 L
.64319 .30902 L
.64441 .30902 L
.64564 .30902 L
.64693 .30902 L
Mistroke
.64803 .30902 L
.64924 .30902 L
.65054 .30902 L
.65125 .30902 L
.65193 .30902 L
.65324 .30902 L
.65443 .30902 L
.65506 .30902 L
.65576 .30902 L
.65649 .30902 L
.65718 .30902 L
.6584 .30902 L
.65971 .30902 L
.66545 .30902 L
.68552 .30902 L
.6904 .30902 L
.69561 .30902 L
.69635 .30902 L
.69715 .30902 L
.69791 .30902 L
.69861 .30902 L
.69993 .30902 L
.70059 .30902 L
.70132 .30902 L
.70202 .30902 L
.70265 .30902 L
.70333 .30902 L
.70407 .30902 L
.70538 .30902 L
.70663 .30902 L
.70785 .30902 L
.70896 .30902 L
.71018 .30902 L
.71147 .30902 L
.71259 .30902 L
.71364 .30902 L
.71478 .30902 L
.71601 .30902 L
.71671 .30902 L
.71735 .30902 L
.71805 .30902 L
.7188 .30902 L
.72006 .30902 L
.72077 .30902 L
.72144 .30902 L
.72268 .30902 L
.72382 .30902 L
.72513 .30902 L
.72637 .30902 L
.7277 .30902 L
Mistroke
.72889 .30902 L
.72956 .30902 L
.73028 .30902 L
.73158 .30902 L
.73641 .30902 L
.73711 .30902 L
.73785 .30902 L
.73855 .30902 L
.73919 .30902 L
.73991 .30902 L
.74059 .30902 L
.74133 .30902 L
.74212 .30902 L
.74343 .30902 L
.74464 .30902 L
.74594 .30902 L
.74668 .30902 L
.74737 .30902 L
.74855 .30902 L
.7498 .30902 L
.75099 .30902 L
.75207 .30902 L
.75334 .30902 L
.75405 .30902 L
.75471 .30902 L
.75592 .30902 L
.75721 .30902 L
.75843 .30902 L
.75975 .30902 L
.761 .30902 L
.76214 .30902 L
.76283 .30902 L
.76347 .30902 L
.76417 .30902 L
.76492 .30902 L
.76563 .30902 L
.7663 .30902 L
.76756 .30902 L
.76864 .30902 L
.76982 .30902 L
.77105 .30902 L
.7722 .30902 L
.77327 .30902 L
.77425 .30902 L
.77539 .30902 L
.77646 .30902 L
.77762 .30902 L
.77885 .30902 L
.7799 .30902 L
.78106 .30902 L
Mistroke
.78231 .30902 L
.78301 .30902 L
.78364 .30902 L
.78489 .30902 L
.78607 .30902 L
.78731 .30902 L
.78865 .30902 L
.79109 .30902 L
.79564 .30902 L
.80585 .30902 L
.82423 .30902 L
.86521 .30902 L
.90468 .30902 L
.94262 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo001koooo0`1Voe[oool00`000?ooooooo`15
oooo000Boooo100002Soool500000_ooo`800004oooo0P0002Woool500000_ooo`0306Kooooooooo
02;oool200001?ooo`800004oooo0P0002Soool00`000?ooooooo`0Xoooo0P0000Coool200001?oo
o`80000?oooo000Boooo00<0003oooooool0:oooo`030000oooooooo00Ooool010000?ooooooo`00
01ooool906Ko0_ooo`030000oooooooo00;oool00`1Vooooooooo`0Qoooo00@0003oooooool00008
oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo00002?ooo`040000
oooooooo00003_ooo`004oooo`030000oooooooo02[oool00`000?ooooooo`0:oooo00<0003ooooo
ool06?ooo`D0I_l;oooo00<0003oooooool00_ooo`0306Kooooooooo027oool010000?ooooooo`00
00_oool00`000?ooooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000
oooooooo00coool000coool400001?ooo`030000oooooooo027oool400001?ooo`030000oooooooo
00Soool200004oooo`P0I_l8oooo100000Coool00`000?ooooooo`02oooo00<0I_ooooooool06ooo
o`@00002oooo00@0003oooooool00009oooo0P0002Soool20000:?ooo`040000oooooooo00002Ooo
o`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0003oooooool02?ooo`030000oooooooo
00Ooool;06Ko6?ooo`030000oooooooo00;oool00`1Vooooooooo`0Qoooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000706Ko8_ooo`800004oooo00<0I_oooooo
ool08_ooo`80000:oooo0`0002Ooool00`000?ooooooo`0Xoooo0P0000[oool300003_ooo`00=ooo
oa@0I_lboooo00<0I_ooooooool0F?ooo`030000oooooooo04Goool002coool;06KoA_ooo`0306Ko
oooooooo05Soool00`000?ooooooo`15oooo000Goooo5@1Voe7oool00`1Vooooooooo`1Hoooo00<0
003oooooool0AOooo`004Oooo`H0I_mVoooo00<0I_ooooooool0F?ooo`030000oooooooo04Goool0
07goool00`1Vooooooooo`1Hoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Ooo
o`030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0005<ol000?o
09Tco`0000002C?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000A
oooo00<0000co`0co`00;c?o00030000<ol0<ol002lco`000`0003?o03?o0005<ol000?o09Tco`0c
o`009S?o00030000<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Ooo
of`co`000ol0VC?o03?o001H<ol000<0003oooooool0AOooo`004Oooof`co`000ol0VC?o03?o001H
<ol000<0003oooooool0AOooo`004Oooof`co`000ol0VC?o03?o001H<ol000<0003oooooool0AOoo
o`004Oooof`co`000ol0VC?o03?o001H<ol000<0003oooooool0AOooo`004Oooof`co`000ol0VC?o
03?o001H<ol000<0003oooooool0AOooo`004Oooof`co`000ol0VC?o03?o001H<ol00P0004Koool0
017ooom/<ol000?o09Tco`0co`00F3?o00030000oooooooo04Goool0017ooom/<ol000?o09Tco`0c
o`00F3?o00030000oooooooo04Goool0017ooom/<ol000?o09Tco`0co`00F3?o00030000oooooooo
04Goool0017ooom/<ol000?o09Tco`0co`00F3?o00030000oooooooo04Goool0017ooom/<ol000?o
09Tco`0co`00F3?o00030000oooooooo04Goool0017ooom/<ol000?o09Tco`0co`00F3?o00030000
oooooooo04Goool0017ooom/<ol000?o09Tco`0co`00F3?o00030000oooooooo04Goool0017oool2
0000JS?o0003o`2I<ol0<ol005Pco`020000A_ooo`004oooo`80001X<ol000?o09Tco`0co`00F3?o
00030000oooooooo04Goool001Goool20000IS?o0003o`2I<ol0<ol005Pco`000`000?ooooooo`15
oooo000Goooo0P0006@co`000ol0VC?o03?o001H<ol000<0003oooooool0AOooo`006Oooo`80001R
<ol000?o09Tco`0co`00F3?o00030000oooooooo04Goool001_oool20000H3?o0003o`2I<ol0<ol0
05Pco`000`000?ooooooo`15oooo000Moooo0P0005hco`000ol0VC?o03?o001H<ol000<0003ooooo
ool0AOooo`007oooo`030000<ol0<ol005/co`000ol0VC?o03?o001H<ol000<0003oooooool0AOoo
o`008?ooo`030000<ol0<ol005Xco`000ol0VC?o03?o001H<ol00P0004Koool0027oool20000FS?o
0003o`2I<ol0<ol005Pco`000`000?ooooooo`15oooo000Soooo00<0000co`0co`00Ec?o0003o`2I
<ol0<ol005Pco`000`000?ooooooo`15oooo000Toooo0P0005Lco`000ol0VC?o03?o001H<ol000<0
003oooooool0AOooo`009_ooo`030000<ol0<ol005@co`000ol0VC?o03?o001H<ol000<0003ooooo
ool0AOooo`009oooo`030000<ol0<ol005<co`000ol0VC?o03?o001H<ol000<0003oooooool0AOoo
o`00:?ooo`030000<ol0<ol0058co`000ol0VC?o03?o000o<ol00P0000@co`02000013?o00800003
<ol0100000@co`000`000?ooooooo`15oooo000Yoooo00<0000co`0co`00DC?o0003o`2I<ol0<ol0
03hco`00100003?o03?o000000Pco`00100003?o03?o0000008co`000`0003?o03?o0005<ol000<0
003oooooool0AOooo`00:_ooo`030000<ol0<ol0050co`000ol0VC?o03?o000n<ol000@0000co`0c
o`000008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00<00015oooo000[oooo0P00
050co`000ol0VC?o03?o000n<ol000@0000co`0co`000008<ol000@0000co`0co`000004<ol000<0
000co`0co`000c?o00030000oooooooo04Goool002goool00`0003?o03?o001=<ol000?o09Tco`0c
o`00?S?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o
00030000oooooooo04Goool002koool00`0003?o03?o001<<ol000?o09Tco`0co`00?c?o0080000:
<ol00P0000@co`0200001C?o00030000oooooooo04Goool002ooool00`0003?o03?o001;<ol000?o
09Tco`0co`00F3?o00030000oooooooo04Goool0033oool00`0003?o03?o001:<ol000?o09Tco`0c
o`00F3?o00030000oooooooo04Goool0037oool00`0003?o03?o0019<ol000?o09Tco`0co`00F3?o
00030000oooooooo04Goool003;oool00`0003?o03?o0018<ol000?o09Tco`0co`00F3?o00030000
oooooooo04Goool003?oool00`0003?o03?o0017<ol000?o09Tco`0co`00F3?o00800016oooo000c
oooo00<0000co`0co`00Ac?o0003o`2I<ol0<ol005Pco`000`000?ooooooo`15oooo000doooo00<0
000co`0co`00AS?o0003o`2I<ol0<ol005Pco`000`000?ooooooo`15oooo000eoooo00<0000co`0c
o`00AC?o0003o`2I<ol0<ol005Pco`000`000?ooooooo`15oooo000foooo00<0000co`0co`00A3?o
0003o`2I<ol0<ol005Pco`000`000?ooooooo`15oooo000goooo00<0000co`0co`00@c?o0003o`2I
<ol0<ol005Pco`000`000?ooooooo`15oooo000hoooo00<0000co`0co`00@S?o0003o`2I<ol0<ol0
05Pco`000`000?ooooooo`15oooo000hoooo00<0000co`0co`00@S?o0003o`2I<ol0<ol005Pco`00
0`000?ooooooo`15oooo000ioooo00<0000co`0co`00@C?o0003o`2I<ol0<ol005Pco`020000A_oo
o`00>_ooo`030000<ol0<ol0040co`000ol0VC?o03?o001H<ol000<0003oooooool0AOooo`00>ooo
o`030000<ol0<ol003lco`000ol0VC?o03?o001H<ol000<0003oooooool0AOooo`00??ooo`030000
<ol0<ol003hco`000ol0VC?o03?o001H<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol0
03hco`000ol0VC?o03?o001H<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol003dco`00
0ol0VC?o03?o001H<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol003dco`000ol0VC?o
03?o001H<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol003`co`000ol0VC?o03?o001H
<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol003`co`000ol0VC?o03?o001H<ol000<0
003oooooool0AOooo`00?oooo`030000<ol0<ol003/co`000ol0VC?o03?o001H<ol00P0004Koool0
03ooool00`0003?o03?o000k<ol000?o09Tco`0co`00F3?o00030000oooooooo04Goool0043oool0
0`0003?o03?o000j<ol000?o09Tco`0co`00F3?o00030000oooooooo04Goool0047oool00`0003?o
03?o000i<ol000?o09Tco`0co`00F3?o00030000oooooooo04Goool0047oool00`0003?o03?o000i
<ol000?o09Tco`0co`00F3?o00030000oooooooo04Goool004;oool00`0003?o03?o000h<ol000?o
09Tco`0co`00F3?o00030000oooooooo04Goool004;oool00`0003?o03?o000h<ol000?o09Tco`0c
o`00?c?o00800004<ol00P0000@co`0200001C?o00<00003<ol000<0003oooooool0AOooo`00@ooo
o`030000<ol0<ol003Lco`000ol0VC?o03?o000n<ol000@0000co`0co`000008<ol000@0000co`0c
o`000005<ol000<0000co`0co`000S?o00030000oooooooo04Goool004?oool00`0003?o03?o000g
<ol000?o09Tco`0co`00?S?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00D00003
<ol00`0004Goool004Coool00`0003?o03?o000f<ol000?o09Tco`0co`00?S?o00040000<ol0<ol0
000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool0
04Coool00`0003?o03?o000f<ol000?o09Tco`0co`00?S?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000c?o00030000<ol0000000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0c
o`00=C?o0003o`2I<ol0<ol003lco`0200002S?o00800005<ol00P0000@co`000`000?ooooooo`15
oooo0015oooo00<0000co`0co`00=C?o0003o`2I<ol0<ol005Pco`000`000?ooooooo`15oooo0016
oooo00<0000co`0co`00=3?o0003o`2I<ol0<ol005Pco`000`000?ooooooo`15oooo0016oooo00<0
000co`0co`00=3?o0003o`2I<ol0<ol005Pco`000`000?ooooooo`15oooo0017oooo00<0000co`0c
o`00<c?o0003o`2I<ol0<ol005Pco`000`000?ooooooo`15oooo0017oooo00<0000co`0co`00<c?o
0003o`2I<ol0<ol005Pco`020000A_ooo`00B?ooo`030000<ol0<ol0038co`000ol0VC?o03?o001H
<ol000<0003oooooool0AOooo`00B?ooo`030000<ol0<ol0038co`000ol0VC?o03?o001H<ol000<0
003oooooool0AOooo`00BOooo`030000<ol0<ol0034co`000ol0VC?o03?o001H<ol000<0003ooooo
ool0AOooo`00BOooo`030000<ol0<ol0034co`000ol0VC?o03?o001H<ol000<0003oooooool0AOoo
o`00B_ooo`030000<ol0<ol0030co`000ol0VC?o03?o001H<ol000<0003oooooool0AOooo`00B_oo
o`030000<ol0<ol0030co`000ol0VC?o03?o001H<ol000<0003oooooool0AOooo`00Boooo`030000
<ol0<ol002lco`000ol0VC?o03?o001H<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol0
02lco`000ol0VC?o03?o001H<ol00P0004Koool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001<
ooooS3?o04Soool004gooon;<ol0B?ooo`00COoooh/co`18oooo001>oooo:S?o00030000<ol0<ol0
02Lco`000`0003?o03?o000c<ol0B?ooo`00C_ooobTco`000`0003?o03?o0008<ol000<0000co`0c
o`007S?o00030000<ol0<ol0038co`18oooo001?oooo:3?o00030000<ol0<ol0008co`02000013?o
00030000<ol0<ol000Hco`02000013?o00800004<ol00P0000@co`02000013?o00030000<ol0<ol0
038co`18oooo001?oooo:3?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0
000co`0co`0013?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0
00000c?o00030000<ol0<ol0038co`18oooo001?oooo9c?o00030000<ol0<ol0008co`000`0003?o
03?o000<<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000004
<ol000<0000co`0co`00<C?o04Soool0053ooolW<ol000<0000co`0co`001@0000/co`00100003?o
03?o000000Pco`00100003?o03?o000000<co`02000013?o00030000<ol0<ol0038co`18oooo001@
oooo9c?o00050000<ol0<ol0<ol0000000hco`00100003?o03?o000000Pco`00100003?o03?o0000
008co`00100003?o03?o000000<co`000`0003?o03?o000b<ol0B?ooo`00D?ooobPco`000`0003?o
03?o000@<ol00P0000Xco`02000013?o00800003<ol000<0000co`0co`00<c?o04Soool0057ooon7
<ol0B?ooo`00DOooohLco`18oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.09) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.41127 .30902 L
.42237 .30902 L
.42781 .30902 L
.43298 .30902 L
.43522 .30902 L
.43762 .30902 L
.43833 .30902 L
.43899 .30902 L
s
.43899 .30902 m
.439 .61803 L
s
0 .4 1 r
.02381 .2979 m
.06244 .29618 L
.10458 .294 L
.14415 .29162 L
.18221 .28897 L
.22272 .2857 L
.26171 .28204 L
.30316 .27752 L
.34309 .27243 L
.3815 .26673 L
.40095 .2635 L
.41127 .26169 L
.42237 .25965 L
.42781 .25862 L
.43298 .25762 L
.43522 .25717 L
.43762 .2567 L
.43833 .25656 L
.43899 .25642 L
.44024 .30902 L
.44142 .30902 L
.44268 .30902 L
.44387 .30902 L
.44498 .30902 L
.4462 .30902 L
.4475 .30902 L
.44816 .30902 L
.44887 .30902 L
.45017 .30902 L
.45143 .30902 L
.4526 .30902 L
.45368 .30902 L
.4547 .30902 L
.45591 .30902 L
.45702 .30902 L
.45812 .30902 L
.45928 .30902 L
.46044 .30902 L
.46172 .30902 L
.46304 .30902 L
.46425 .30902 L
.46489 .30902 L
.46559 .30902 L
.46632 .30902 L
.467 .30902 L
.46826 .30902 L
.46941 .30902 L
.47004 .30902 L
.47073 .30902 L
.47199 .30902 L
Mistroke
.47322 .30902 L
.47434 .30902 L
.47562 .30902 L
.47684 .30902 L
.47796 .30902 L
.47899 .30902 L
.48022 .30902 L
.48133 .30902 L
.48254 .30902 L
.48384 .30902 L
.48505 .30902 L
.48619 .30902 L
.48683 .30902 L
.48752 .30902 L
.48875 .30902 L
.49007 .30902 L
.49082 .30902 L
.49152 .30902 L
.49284 .30902 L
.4935 .30902 L
.49423 .30902 L
.49551 .30902 L
.4967 .30902 L
.49743 .30902 L
.49812 .30902 L
.4994 .30902 L
.50011 .30902 L
.50079 .30902 L
.50157 .30902 L
.50228 .30902 L
.50343 .30902 L
.50468 .30902 L
.50584 .30902 L
.50692 .30902 L
.5081 .30902 L
.5094 .30902 L
.51005 .30902 L
.51075 .30902 L
.51202 .30902 L
.51268 .30902 L
.51338 .30902 L
.51464 .30902 L
.51596 .30902 L
.51671 .30902 L
.5174 .30902 L
.51862 .30902 L
.51993 .30902 L
.52118 .30902 L
.52233 .30902 L
.52339 .30902 L
Mistroke
.52453 .30902 L
.52561 .30902 L
.5266 .30902 L
.52775 .30902 L
.52901 .30902 L
.53019 .30902 L
.5313 .30902 L
.53254 .30902 L
.53371 .30902 L
.53476 .30902 L
.5359 .30902 L
.53714 .30902 L
.53845 .30902 L
.53957 .30902 L
.5408 .30902 L
.5421 .30902 L
.54331 .30902 L
.54394 .30902 L
.54464 .30902 L
.54536 .30902 L
.54604 .30902 L
.54729 .30902 L
.54843 .30902 L
.54969 .30902 L
.55101 .30902 L
.55213 .30902 L
.55332 .30902 L
.55444 .30902 L
.55546 .30902 L
.55666 .30902 L
.55796 .30902 L
.55919 .30902 L
.56032 .30902 L
.56153 .30902 L
.56282 .30902 L
.56404 .30902 L
.56516 .30902 L
.56647 .30902 L
.56721 .30902 L
.56789 .30902 L
.56915 .30902 L
.5698 .30902 L
.57048 .30902 L
.57121 .30902 L
.57188 .30902 L
.5726 .30902 L
.57339 .30902 L
.57408 .30902 L
.57481 .30902 L
.57613 .30902 L
Mistroke
.57679 .30902 L
.57751 .30902 L
.57881 .30902 L
.58007 .30902 L
.58124 .30902 L
.58249 .30902 L
.58367 .30902 L
.58473 .30902 L
.58589 .30902 L
.58715 .30902 L
.58785 .30902 L
.58849 .30902 L
.58973 .30902 L
.5909 .30902 L
.592 .30902 L
.59317 .30902 L
.59416 .30902 L
.59525 .30902 L
.59643 .30902 L
.59768 .30902 L
.59887 .30902 L
.59996 .30902 L
.60123 .30902 L
.60193 .30902 L
.60259 .30902 L
.60375 .30902 L
.60503 .30902 L
.6057 .30902 L
.60641 .30902 L
.60768 .30902 L
.60839 .30902 L
.60905 .30902 L
.61055 .30902 L
.61185 .30902 L
.61309 .30902 L
.61419 .30902 L
.6154 .30902 L
.6167 .30902 L
.61737 .30902 L
.61809 .30902 L
.61938 .30902 L
.62058 .30902 L
.62183 .30902 L
.62253 .30902 L
.62316 .30902 L
.62441 .30902 L
.62555 .30902 L
.62619 .30902 L
.6269 .30902 L
.6276 .30902 L
Mistroke
.62835 .30902 L
.62901 .30902 L
.62971 .30902 L
.63098 .30902 L
.63225 .30902 L
.63297 .30902 L
.63364 .30902 L
.63485 .30902 L
.63615 .30902 L
.6373 .30902 L
.63839 .30902 L
.63958 .30902 L
.64086 .30902 L
.64202 .30902 L
.64311 .30902 L
.6443 .30902 L
.64557 .30902 L
.64621 .30902 L
.64691 .30902 L
.64817 .30902 L
.6494 .30902 L
.65053 .30902 L
.65159 .30902 L
.65258 .30902 L
.65367 .30902 L
.65484 .30902 L
.65606 .30902 L
.65722 .30902 L
.65826 .30902 L
.65939 .30902 L
.6606 .30902 L
.66172 .30902 L
.66294 .30902 L
.66422 .30902 L
.66535 .30902 L
.66639 .30902 L
.66754 .30902 L
.66877 .30902 L
.66942 .30902 L
.67011 .30902 L
.67086 .30902 L
.67156 .30902 L
.67281 .30902 L
.67353 .30902 L
.6742 .30902 L
.67544 .30902 L
.67657 .30902 L
.67789 .30902 L
.67913 .30902 L
.68045 .30902 L
Mistroke
.68165 .30902 L
.68232 .30902 L
.68304 .30902 L
.68434 .30902 L
.68556 .30902 L
.68686 .30902 L
.68796 .30902 L
.68917 .30902 L
.68991 .30902 L
.6906 .30902 L
.69191 .30902 L
.69264 .30902 L
.69331 .30902 L
.6941 .30902 L
.69484 .30902 L
.69606 .30902 L
.69671 .30902 L
.6974 .30902 L
.6981 .30902 L
.69882 .30902 L
.70013 .30902 L
.70136 .30902 L
.70206 .30902 L
.7027 .30902 L
.70388 .30902 L
.70513 .30902 L
.70617 .30902 L
.7073 .30902 L
.70853 .30902 L
.70968 .30902 L
.71098 .30902 L
.71172 .30902 L
.71241 .30902 L
.71367 .30902 L
.71437 .30902 L
.71501 .30902 L
.71621 .30902 L
.71752 .30902 L
.71875 .30902 L
.71988 .30902 L
.72094 .30902 L
.72208 .30902 L
.72316 .30902 L
.72414 .30902 L
.72529 .30902 L
.72654 .30902 L
.72772 .30902 L
.72881 .30902 L
.72994 .30902 L
.73099 .30902 L
Mistroke
.73215 .30902 L
.73339 .30902 L
.73824 .30902 L
.74834 .30902 L
.74902 .30902 L
.74976 .30902 L
.75046 .30902 L
.7511 .30902 L
.75185 .30902 L
.75265 .30902 L
.75332 .30902 L
.75405 .30902 L
.75474 .30902 L
.75537 .30902 L
.75605 .30902 L
.7568 .30902 L
.75811 .30902 L
.75936 .30902 L
.76441 .30902 L
.76564 .30902 L
.76629 .30902 L
.76697 .30902 L
.76773 .30902 L
.76842 .30902 L
.76907 .30902 L
.76979 .30902 L
.77105 .30902 L
.77221 .30902 L
.77284 .30902 L
.77353 .30902 L
.77479 .30902 L
.77596 .30902 L
.77721 .30902 L
.77827 .30902 L
.77944 .30902 L
.78074 .30902 L
.78193 .30902 L
.78325 .30902 L
.78398 .30902 L
.78465 .30902 L
.78587 .30902 L
.78656 .30902 L
.7872 .30902 L
.78959 .30902 L
.79887 .30902 L
.81976 .30902 L
.85927 .30902 L
.89727 .30902 L
.93773 .30902 L
.97619 .30902 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.09) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOooo`00OOooo`80I_mI
oooo00<0003oooooool0AOooo`00N?ooo`L0I_mIoooo00<0003oooooool0AOooo`00L_ooo`H0I_l6
oooo00<0I_ooooooool0Eoooo`030000oooooooo04Goool001;oool40000:?ooo`D00002oooo0P00
00Coool200008?ooo`D0I_l4oooo1@0000?oool00`1Vooooooooo`0Qoooo0P0000Coool200001?oo
o`80000Xoooo00<0003oooooool0:?ooo`800004oooo0P0000Coool200003oooo`004_ooo`030000
oooooooo02_oool00`000?ooooooo`07oooo00@0003oooooool0000Joooo1@1Vo`_oool00`000?oo
ooooo`03oooo00<0I_ooooooool08?ooo`040000oooooooo00002?ooo`040000oooooooo00009ooo
o`030000oooooooo02Ooool010000?ooooooo`0000Soool010000?ooooooo`0000koool001?oool0
0`000?ooooooo`0Zoooo00<0003oooooool02_ooo`030000oooooooo013oool806Ko4?ooo`030000
oooooooo00?oool00`1Vooooooooo`0Poooo00@0003oooooool0000;oooo00<0003oooooool09Ooo
o`030000oooooooo02Ooool010000?ooooooo`0000_oool00`000?ooooooo`0<oooo000<oooo1000
00Coool00`000?ooooooo`0Qoooo100000Coool00`000?ooooooo`08oooo0P0000Soool;06Ko4?oo
o`@00004oooo00<0003oooooool00oooo`0306Kooooooooo01[oool400000_ooo`040000oooooooo
00002Oooo`80000Xoooo0P0002Soool010000?ooooooo`0000Woool200003oooo`004_ooo`040000
oooooooo0000:_ooo`030000oooooooo00Soool00`00001Vo`1Vo`0706Ko8oooo`030000oooooooo
00?oool00`1Vooooooooo`0Poooo00@0003oooooool00009oooo00<0003oooooool09oooo`030000
oooooooo02Ooool010000?ooooooo`0000Woool00`000?ooooooo`0>oooo000Coooo0P0002[oool2
00002P1Vo`<0000Yoooo0P0000Goool00`1Vooooooooo`0Qoooo0P0000[oool300009oooo`030000
oooooooo02Soool200002_ooo`<0000>oooo000goooo2P1Vocgoool00`1Vooooooooo`1Goooo00<0
003oooooool0AOooo`008_oooaD0I_m7oooo00<0I_ooooooool0Eoooo`030000oooooooo04Goool0
017ooolA06KoG?ooo`0306Kooooooooo05Ooool00`000?ooooooo`15oooo001noooo00<0I_oooooo
ool0Eoooo`030000oooooooo04Goool007koool00`1Vooooooooo`1Goooo00<0003oooooool0AOoo
o`002oooool0000700003oooo`004Oooo`030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0006<ol000?o09T0000co`0023?o00030000<ol0<ol000Lco`000`0003?o
03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0co`00;c?o00030000<ol0<ol002lco`00
0`0003?o03?o0006<ol000?o09Tco`0co`009C?o00030000<ol0<ol002lco`000`000?ooooooo`0_
oooo00<0003oooooool04oooo`004Oooofdco`000ol0VC?o03?o001G<ol000<0003oooooool0AOoo
o`004Oooofdco`000ol0VC?o03?o001G<ol000<0003oooooool0AOooo`004Oooofdco`000ol0VC?o
03?o001G<ol000<0003oooooool0AOooo`004Oooofdco`000ol0VC?o03?o001G<ol000<0003ooooo
ool0AOooo`004Oooofdco`000ol0VC?o03?o001G<ol000<0003oooooool0AOooo`004Oooofdco`00
0ol0VC?o03?o001G<ol00P0004Koool0017ooom]<ol000?o09Tco`0co`00Ec?o00030000oooooooo
04Goool0017ooom]<ol000?o09Tco`0co`00Ec?o00030000oooooooo04Goool0017ooom]<ol000?o
09Tco`0co`00Ec?o00030000oooooooo04Goool0017ooom]<ol000?o09Tco`0co`00Ec?o00030000
oooooooo04Goool0017ooom]<ol000?o09Tco`0co`00Ec?o00030000oooooooo04Goool0017ooom]
<ol000?o09Tco`0co`00Ec?o00030000oooooooo04Goool0017ooom]<ol000?o09Tco`0co`00Ec?o
00030000oooooooo04Goool0017oool20000Jc?o0003o`2I<ol0<ol005Lco`020000A_ooo`004ooo
o`80001Y<ol000?o09Tco`0co`00Ec?o00030000oooooooo04Goool001Goool20000Ic?o0003o`2I
<ol0<ol005Lco`000`000?ooooooo`15oooo000Goooo0P0006Dco`000ol0VC?o03?o001G<ol000<0
003oooooool0AOooo`006Oooo`80001S<ol000?o09Tco`0co`00Ec?o00030000oooooooo04Goool0
01_oool20000HC?o0003o`2I<ol0<ol005Lco`000`000?ooooooo`15oooo000Moooo0P0005lco`00
0ol0VC?o03?o001G<ol000<0003oooooool0AOooo`007oooo`030000<ol0<ol005`co`000ol0VC?o
03?o001G<ol000<0003oooooool0AOooo`008?ooo`030000<ol0<ol005/co`000ol0VC?o03?o001G
<ol00P0004Koool0027oool20000Fc?o0003o`2I<ol0<ol005Lco`000`000?ooooooo`15oooo000S
oooo00<0000co`0co`00F3?o0003o`2I<ol0<ol005Lco`000`000?ooooooo`15oooo000Toooo0P00
05Pco`000ol0VC?o03?o001G<ol000<0003oooooool0AOooo`009_ooo`030000<ol0<ol005Dco`00
0ol0VC?o03?o001G<ol000<0003oooooool0AOooo`009oooo`030000<ol0<ol005@co`000ol0VC?o
03?o001G<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol005<co`000ol0VC?o03?o000n
<ol00P0000@co`02000013?o00800003<ol0100000@co`000`000?ooooooo`15oooo000Yoooo00<0
000co`0co`00DS?o0003o`2I<ol0<ol003dco`00100003?o03?o000000Pco`00100003?o03?o0000
008co`000`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_ooo`030000<ol0<ol0054co`00
0ol0VC?o03?o000m<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`0c
o`0013?o00<00015oooo000[oooo0P00054co`000ol0VC?o03?o000m<ol000@0000co`0co`000008
<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o00030000oooooooo04Goool002goool0
0`0003?o03?o001><ol000?o09Tco`0co`00?C?o00040000<ol0<ol0000023?o00040000<ol0<ol0
00000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool002koool00`0003?o03?o001=
<ol000?o09Tco`0co`00?S?o0080000:<ol00P0000@co`0200001C?o00030000oooooooo04Goool0
02ooool00`0003?o03?o001<<ol000?o09Tco`0co`00Ec?o00030000oooooooo04Goool0033oool0
0`0003?o03?o001;<ol000?o09Tco`0co`00Ec?o00030000oooooooo04Goool0037oool00`0003?o
03?o001:<ol000?o09Tco`0co`00Ec?o00030000oooooooo04Goool003;oool00`0003?o03?o0019
<ol000?o09Tco`0co`00Ec?o00030000oooooooo04Goool003?oool00`0003?o03?o0018<ol000?o
09Tco`0co`00Ec?o00800016oooo000coooo00<0000co`0co`00B3?o0003o`2I<ol0<ol005Lco`00
0`000?ooooooo`15oooo000doooo00<0000co`0co`00Ac?o0003o`2I<ol0<ol005Lco`000`000?oo
ooooo`15oooo000eoooo00<0000co`0co`00AS?o0003o`2I<ol0<ol005Lco`000`000?ooooooo`15
oooo000foooo00<0000co`0co`00AC?o0003o`2I<ol0<ol005Lco`000`000?ooooooo`15oooo000g
oooo00<0000co`0co`00A3?o0003o`2I<ol0<ol005Lco`000`000?ooooooo`15oooo000hoooo00<0
000co`0co`00@c?o0003o`2I<ol0<ol005Lco`000`000?ooooooo`15oooo000hoooo00<0000co`0c
o`00@c?o0003o`2I<ol0<ol005Lco`000`000?ooooooo`15oooo000ioooo00<0000co`0co`00@S?o
0003o`2I<ol0<ol005Lco`020000A_ooo`00>_ooo`030000<ol0<ol0044co`000ol0VC?o03?o001G
<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol0040co`000ol0VC?o03?o001G<ol000<0
003oooooool0AOooo`00??ooo`030000<ol0<ol003lco`000ol0VC?o03?o001G<ol000<0003ooooo
ool0AOooo`00??ooo`030000<ol0<ol003lco`000ol0VC?o03?o001G<ol000<0003oooooool0AOoo
o`00?Oooo`030000<ol0<ol003hco`000ol0VC?o03?o001G<ol000<0003oooooool0AOooo`00?Ooo
o`030000<ol0<ol003hco`000ol0VC?o03?o001G<ol000<0003oooooool0AOooo`00?_ooo`030000
<ol0<ol003dco`000ol0VC?o03?o001G<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol0
03dco`000ol0VC?o03?o001G<ol000<0003oooooool0AOooo`00?oooo`030000<ol0<ol003`co`00
0ol0VC?o03?o001G<ol00P0004Koool003ooool00`0003?o03?o000l<ol000?o09Tco`0co`00Ec?o
00030000oooooooo04Goool0043oool00`0003?o03?o000k<ol000?o09Tco`0co`00Ec?o00030000
oooooooo04Goool0047oool00`0003?o03?o000j<ol000?o09Tco`0co`00Ec?o00030000oooooooo
04Goool0047oool00`0003?o03?o000j<ol000?o09Tco`0co`00Ec?o00030000oooooooo04Goool0
04;oool00`0003?o03?o000i<ol000?o09Tco`0co`00Ec?o00030000oooooooo04Goool004;oool0
0`0003?o03?o000i<ol000?o09Tco`0co`00?S?o00800004<ol00P0000@co`0200001C?o00<00003
<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol003Pco`000ol0VC?o03?o000m<ol000@0
000co`0co`000008<ol000@0000co`0co`000005<ol000<0000co`0co`000S?o00030000oooooooo
04Goool004?oool00`0003?o03?o000h<ol000?o09Tco`0co`00?C?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool00`0003?o03?o000g<ol000?o
09Tco`0co`00?C?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0
000013?o00030000oooooooo04Goool004Coool00`0003?o03?o000g<ol000?o09Tco`0co`00?C?o
00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0000000@co`000`000?oo
ooooo`15oooo0015oooo00<0000co`0co`00=S?o0003o`2I<ol0<ol003hco`0200002S?o00800005
<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`00=S?o0003o`2I<ol0<ol0
05Lco`000`000?ooooooo`15oooo0016oooo00<0000co`0co`00=C?o0003o`2I<ol0<ol005Lco`00
0`000?ooooooo`15oooo0016oooo00<0000co`0co`00=C?o0003o`2I<ol0<ol005Lco`000`000?oo
ooooo`15oooo0017oooo00<0000co`0co`00=3?o0003o`2I<ol0<ol005Lco`000`000?ooooooo`15
oooo0017oooo00<0000co`0co`00=3?o0003o`2I<ol0<ol005Lco`020000A_ooo`00B?ooo`030000
<ol0<ol003<co`000ol0VC?o03?o001G<ol000<0003oooooool0AOooo`00B?ooo`030000<ol0<ol0
03<co`000ol0VC?o03?o001G<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol0038co`00
0ol0VC?o03?o001G<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol0038co`000ol0VC?o
03?o001G<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol0034co`000ol0VC?o03?o001G
<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol0034co`000ol0VC?o03?o001G<ol000<0
003oooooool0AOooo`00Boooo`030000<ol0<ol0030co`000ol0VC?o03?o001G<ol000<0003ooooo
ool0AOooo`00Boooo`030000<ol0<ol0030co`000ol0VC?o03?o001G<ol00P0004Koool004cooon<
<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;<ol0B?ooo`00COoooh/co`18
oooo001>oooo:S?o00030000<ol0<ol002Lco`000`0003?o03?o000c<ol0B?ooo`00C_ooobTco`00
0`0003?o03?o0008<ol000<0000co`0co`007S?o00030000<ol0<ol0038co`18oooo001?oooo:3?o
00030000<ol0<ol0008co`02000013?o00030000<ol0<ol000Hco`02000013?o00800004<ol00P00
00<co`03000013?o00030000<ol0<ol0038co`18oooo001?oooo:3?o00050000<ol0<ol0<ol00000
008co`000`0003?o03?o0002<ol000<0000co`0co`0013?o00040000<ol0<ol0000023?o00040000
<ol0<ol0000013?o00030000<ol0<ol0008co`000`0003?o03?o000b<ol0B?ooo`00CoooobLco`00
0`0003?o03?o0002<ol000<0000co`0co`0033?o00040000<ol0<ol0000023?o00040000<ol0<ol0
00000c?o00<00004<ol000<0000co`0co`00<C?o04Soool0053ooolW<ol000<0000co`0co`001@00
00/co`00100003?o03?o000000Pco`00100003?o03?o0000008co`00100003?o03?o000000<co`00
0`0003?o03?o000b<ol0B?ooo`00D?ooobLco`001@0003?o03?o03?o0000000><ol000@0000co`0c
o`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000003<ol000<0000co`0co`00<S?o
04Soool0053ooolX<ol000<0000co`0co`0043?o0080000:<ol00P0000@co`0300000S?o00030000
<ol0<ol003<co`18oooo001AooooQc?o04Soool0057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.43215 .30902 L
.43755 .30902 L
.44021 .30902 L
.44151 .30902 L
.44268 .30902 L
s
.44268 .30902 m
.44269 .61803 L
s
0 .4 1 r
.02381 .29665 m
.06244 .29474 L
.10458 .29232 L
.14415 .28967 L
.18221 .28673 L
.22272 .28309 L
.26171 .27903 L
.30316 .274 L
.34309 .26833 L
.3815 .262 L
.40095 .25841 L
.42237 .25413 L
.43215 .25205 L
.43755 .25086 L
.44021 .25027 L
.44151 .24998 L
.44268 .24972 L
.44387 .30902 L
.44498 .30902 L
.44616 .30902 L
.44744 .30902 L
.44875 .30902 L
.44941 .30902 L
.45014 .30902 L
.45142 .30902 L
.45262 .30902 L
.4538 .30902 L
.45492 .30902 L
.45592 .30902 L
.45701 .30902 L
.4582 .30902 L
.45946 .30902 L
.46053 .30902 L
.46172 .30902 L
.46293 .30902 L
.46406 .30902 L
.46531 .30902 L
.466 .30902 L
.46663 .30902 L
.46791 .30902 L
.46863 .30902 L
.4693 .30902 L
.47052 .30902 L
.47181 .30902 L
.47291 .30902 L
.47409 .30902 L
.47511 .30902 L
.47622 .30902 L
.47752 .30902 L
.47875 .30902 L
Mistroke
.47995 .30902 L
.48106 .30902 L
.48238 .30902 L
.48312 .30902 L
.48379 .30902 L
.48505 .30902 L
.48636 .30902 L
.48755 .30902 L
.48865 .30902 L
.48987 .30902 L
.49117 .30902 L
.49184 .30902 L
.49255 .30902 L
.49333 .30902 L
.49406 .30902 L
.49536 .30902 L
.4961 .30902 L
.49679 .30902 L
.49808 .30902 L
.49926 .30902 L
.50056 .30902 L
.50121 .30902 L
.50192 .30902 L
.50256 .30902 L
.50325 .30902 L
.50447 .30902 L
.50515 .30902 L
.50589 .30902 L
.50659 .30902 L
.50722 .30902 L
.50844 .30902 L
.5096 .30902 L
.51086 .30902 L
.51156 .30902 L
.51222 .30902 L
.51334 .30902 L
.51457 .30902 L
.51578 .30902 L
.51707 .30902 L
.51822 .30902 L
.51942 .30902 L
.52044 .30902 L
.52157 .30902 L
.52225 .30902 L
.52298 .30902 L
.52368 .30902 L
.52432 .30902 L
.52553 .30902 L
.52682 .30902 L
.52748 .30902 L
Mistroke
.52819 .30902 L
.52949 .30902 L
.53027 .30902 L
.53102 .30902 L
.53169 .30902 L
.53242 .30902 L
.53311 .30902 L
.53376 .30902 L
.53496 .30902 L
.53626 .30902 L
.53699 .30902 L
.53767 .30902 L
.5388 .30902 L
.54003 .30902 L
.54133 .30902 L
.54253 .30902 L
.5438 .30902 L
.54443 .30902 L
.54514 .30902 L
.54639 .30902 L
.54755 .30902 L
.5482 .30902 L
.5489 .30902 L
.54959 .30902 L
.55036 .30902 L
.55107 .30902 L
.55174 .30902 L
.55299 .30902 L
.55419 .30902 L
.55548 .30902 L
.55615 .30902 L
.55686 .30902 L
.55813 .30902 L
.5593 .30902 L
.5604 .30902 L
.56161 .30902 L
.5629 .30902 L
.56414 .30902 L
.56528 .30902 L
.56654 .30902 L
.56724 .30902 L
.56788 .30902 L
.56905 .30902 L
.57031 .30902 L
.57151 .30902 L
.5726 .30902 L
.57367 .30902 L
.57466 .30902 L
.57575 .30902 L
.57691 .30902 L
Mistroke
.57814 .30902 L
.57929 .30902 L
.58043 .30902 L
.58146 .30902 L
.58261 .30902 L
.58384 .30902 L
.58498 .30902 L
.58607 .30902 L
.58733 .30902 L
.5885 .30902 L
.58978 .30902 L
.5905 .30902 L
.59115 .30902 L
.59179 .30902 L
.59247 .30902 L
.59369 .30902 L
.595 .30902 L
.59575 .30902 L
.59644 .30902 L
.5977 .30902 L
.59885 .30902 L
.59948 .30902 L
.60017 .30902 L
.60143 .30902 L
.60382 .30902 L
.60499 .30902 L
.60607 .30902 L
.6072 .30902 L
.60841 .30902 L
.60967 .30902 L
.61031 .30902 L
.611 .30902 L
.61216 .30902 L
.61322 .30902 L
.61444 .30902 L
.61559 .30902 L
.61666 .30902 L
.61764 .30902 L
.61872 .30902 L
.61986 .30902 L
.62107 .30902 L
.62239 .30902 L
.62364 .30902 L
.62479 .30902 L
.62593 .30902 L
.62697 .30902 L
.62817 .30902 L
.62929 .30902 L
.63053 .30902 L
.63183 .30902 L
Mistroke
.63294 .30902 L
.63416 .30902 L
.63548 .30902 L
.63689 .30902 L
.63757 .30902 L
.63822 .30902 L
.63943 .30902 L
.64049 .30902 L
.64147 .30902 L
.6425 .30902 L
.64362 .30902 L
.64476 .30902 L
.64598 .30902 L
.64711 .30902 L
.64814 .30902 L
.64936 .30902 L
.65005 .30902 L
.65069 .30902 L
.65185 .30902 L
.65309 .30902 L
.65424 .30902 L
.6553 .30902 L
.65648 .30902 L
.65774 .30902 L
.65898 .30902 L
.65968 .30902 L
.66033 .30902 L
.66153 .30902 L
.6628 .30902 L
.66393 .30902 L
.66499 .30902 L
.66615 .30902 L
.66741 .30902 L
.66866 .30902 L
.66936 .30902 L
.67002 .30902 L
.67071 .30902 L
.67134 .30902 L
.67207 .30902 L
.67276 .30902 L
.67399 .30902 L
.67512 .30902 L
.67635 .30902 L
.67704 .30902 L
.67768 .30902 L
.67881 .30902 L
.67988 .30902 L
.68086 .30902 L
.68194 .30902 L
.68311 .30902 L
Mistroke
.68437 .30902 L
.68554 .30902 L
.68662 .30902 L
.68786 .30902 L
.6885 .30902 L
.68919 .30902 L
.69034 .30902 L
.6916 .30902 L
.69273 .30902 L
.69394 .30902 L
.69497 .30902 L
.69611 .30902 L
.6974 .30902 L
.69862 .30902 L
.69993 .30902 L
.70067 .30902 L
.70135 .30902 L
.70377 .30902 L
.70499 .30902 L
.70568 .30902 L
.70632 .30902 L
.71562 .30902 L
.71693 .30902 L
.71767 .30902 L
.71835 .30902 L
.7196 .30902 L
.72024 .30902 L
.72092 .30902 L
.72211 .30902 L
.72322 .30902 L
.72453 .30902 L
.72574 .30902 L
.72702 .30902 L
.72774 .30902 L
.72839 .30902 L
.72916 .30902 L
.72989 .30902 L
.73056 .30902 L
.73128 .30902 L
.73192 .30902 L
.73261 .30902 L
.73334 .30902 L
.73402 .30902 L
.73524 .30902 L
.73654 .30902 L
.73893 .30902 L
.73962 .30902 L
.74028 .30902 L
.74151 .30902 L
.74267 .30902 L
Mistroke
.74374 .30902 L
.74492 .30902 L
.74617 .30902 L
.74749 .30902 L
.74872 .30902 L
.74983 .30902 L
.75104 .30902 L
.75639 .30902 L
.75786 .30902 L
.75858 .30902 L
.75923 .30902 L
.75992 .30902 L
.76066 .30902 L
.76147 .30902 L
.76223 .30902 L
.76288 .30902 L
.76357 .30902 L
.7648 .30902 L
.76549 .30902 L
.76613 .30902 L
.76684 .30902 L
.7676 .30902 L
.76886 .30902 L
.76957 .30902 L
.77023 .30902 L
.77094 .30902 L
.77157 .30902 L
.77231 .30902 L
.77301 .30902 L
.77424 .30902 L
.77538 .30902 L
.77663 .30902 L
.77727 .30902 L
.77796 .30902 L
.77923 .30902 L
.77995 .30902 L
.78062 .30902 L
.78185 .30902 L
.78315 .30902 L
.78443 .30902 L
.78564 .30902 L
.78672 .30902 L
.78789 .30902 L
.79857 .30902 L
.81787 .30902 L
.8589 .30902 L
.89841 .30902 L
.93641 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`800016oooo001koooo1@1VoeSoool00`000?ooooooo`15oooo001g
oooo101Vo`Coool00`1Vooooooooo`1Foooo00<0003oooooool0AOooo`00L_ooo`D0I_l8oooo00<0
I_ooooooool0E_ooo`030000oooooooo04Goool006goool506Ko3Oooo`0306Kooooooooo05Koool0
0`000?ooooooo`15oooo000Boooo100002Soool500000_ooo`800004oooo0P0001_oool506Ko2Ooo
o`D00004oooo00<0I_ooooooool08?ooo`800004oooo0P0000Coool20000:?ooo`030000oooooooo
02Soool200001?ooo`800004oooo0P0000ooool001;oool00`000?ooooooo`0[oooo00<0003ooooo
ool01oooo`040000oooooooo00004_ooo`P0I_l@oooo00<0003oooooool01?ooo`0306Kooooooooo
01ooool010000?ooooooo`0000Soool010000?ooooooo`0002Ooool00`000?ooooooo`0Woooo00@0
003oooooool00008oooo00@0003oooooool0000>oooo000Coooo00<0003oooooool0:_ooo`030000
oooooooo00[oool00`000?ooooooo`05oooo2`1VoaSoool00`000?ooooooo`04oooo00<0I_oooooo
ool07oooo`040000oooooooo00002oooo`030000oooooooo02Goool00`000?ooooooo`0Woooo00@0
003oooooool0000;oooo00<0003oooooool03?ooo`003?ooo`@00004oooo00<0003oooooool08Ooo
o`@00004oooo00<0003oooooool02?ooo`80000806Ko6oooo`@00004oooo00<0003oooooool01?oo
o`0306Kooooooooo01Woool400000_ooo`040000oooooooo00002Oooo`80000Xoooo0P0002Soool0
10000?ooooooo`0000Woool200003oooo`004_ooo`040000oooooooo0000:_ooo`03000006Ko06Ko
00P0I_l00`000?ooooooo`0Zoooo00<0003oooooool01?ooo`0306Kooooooooo01ooool010000?oo
ooooo`0000Woool00`000?ooooooo`0Woooo00<0003oooooool09oooo`040000oooooooo00002Ooo
o`030000oooooooo00koool001?oool200008_ooo`P0I_l200002_ooo`<0000Yoooo0P0000Koool0
0`1Vooooooooo`0Poooo0P0000[oool300009oooo`030000oooooooo02Soool200002_ooo`<0000>
oooo000/oooo2`1VodSoool00`1Vooooooooo`1Foooo00<0003oooooool0AOooo`005ooooaD0I_mC
oooo00<0I_ooooooool0E_ooo`030000oooooooo04Goool0017oool606KoJ?ooo`0306Kooooooooo
05Koool00`000?ooooooo`15oooo001ooooo00<0I_ooooooool0E_ooo`030000oooooooo04Goool0
07ooool00`1Vooooooooo`1Foooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Ooo
o`030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000A
oooo00<0000co`0co`00;c?o00030000<ol0<ol002lco`000`0003?o03?o0007<ol000?o09Tco`0c
o`0093?o00030000<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Ooo
ofhco`000ol0VC?o03?o001F<ol000<0003oooooool0AOooo`004Oooofhco`000ol0VC?o03?o001F
<ol000<0003oooooool0AOooo`004Oooofhco`000ol0VC?o03?o001F<ol000<0003oooooool0AOoo
o`004Oooofhco`000ol0VC?o03?o001F<ol000<0003oooooool0AOooo`004Oooofhco`000ol0VC?o
03?o001F<ol000<0003oooooool0AOooo`004Oooofhco`000ol0VC?o03?o001F<ol00P0004Koool0
017ooom^<ol000?o09Tco`0co`00ES?o00030000oooooooo04Goool0017ooom^<ol000?o09Tco`0c
o`00ES?o00030000oooooooo04Goool0017ooom^<ol000?o09Tco`0co`00ES?o00030000oooooooo
04Goool0017ooom^<ol000?o09Tco`0co`00ES?o00030000oooooooo04Goool0017ooom^<ol000?o
09Tco`0co`00ES?o00030000oooooooo04Goool0017ooom^<ol000?o09Tco`0co`00ES?o00030000
oooooooo04Goool0017ooom^<ol000?o09Tco`0co`00ES?o00030000oooooooo04Goool0017oool2
0000K3?o0003o`2I<ol0<ol005Hco`020000A_ooo`004oooo`80001Z<ol000?o09Tco`0co`00ES?o
00030000oooooooo04Goool001Goool20000J3?o0003o`2I<ol0<ol005Hco`000`000?ooooooo`15
oooo000Goooo0P0006Hco`000ol0VC?o03?o001F<ol000<0003oooooool0AOooo`006Oooo`80001T
<ol000?o09Tco`0co`00ES?o00030000oooooooo04Goool001_oool20000HS?o0003o`2I<ol0<ol0
05Hco`000`000?ooooooo`15oooo000Moooo0P00060co`000ol0VC?o03?o001F<ol000<0003ooooo
ool0AOooo`007oooo`030000<ol0<ol005dco`000ol0VC?o03?o001F<ol000<0003oooooool0AOoo
o`008?ooo`030000<ol0<ol005`co`000ol0VC?o03?o001F<ol00P0004Koool0027oool20000G3?o
0003o`2I<ol0<ol005Hco`000`000?ooooooo`15oooo000Soooo00<0000co`0co`00FC?o0003o`2I
<ol0<ol005Hco`000`000?ooooooo`15oooo000Toooo0P0005Tco`000ol0VC?o03?o001F<ol000<0
003oooooool0AOooo`009_ooo`030000<ol0<ol005Hco`000ol0VC?o03?o001F<ol000<0003ooooo
ool0AOooo`009oooo`030000<ol0<ol005Dco`000ol0VC?o03?o001F<ol000<0003oooooool0AOoo
o`00:?ooo`030000<ol0<ol005@co`000ol0VC?o03?o000m<ol00P0000@co`02000013?o00800003
<ol0100000@co`000`000?ooooooo`15oooo000Yoooo00<0000co`0co`00Dc?o0003o`2I<ol0<ol0
03`co`00100003?o03?o000000Pco`00100003?o03?o0000008co`000`0003?o03?o0005<ol000<0
003oooooool0AOooo`00:_ooo`030000<ol0<ol0058co`000ol0VC?o03?o000l<ol000@0000co`0c
o`000008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00<00015oooo000[oooo0P00
058co`000ol0VC?o03?o000l<ol000@0000co`0co`000008<ol000@0000co`0co`000004<ol000<0
000co`0co`000c?o00030000oooooooo04Goool002goool00`0003?o03?o001?<ol000?o09Tco`0c
o`00?3?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o
00030000oooooooo04Goool002koool00`0003?o03?o001><ol000?o09Tco`0co`00?C?o0080000:
<ol00P0000@co`0200001C?o00030000oooooooo04Goool002ooool00`0003?o03?o001=<ol000?o
09Tco`0co`00ES?o00030000oooooooo04Goool0033oool00`0003?o03?o001<<ol000?o09Tco`0c
o`00ES?o00030000oooooooo04Goool0037oool00`0003?o03?o001;<ol000?o09Tco`0co`00ES?o
00030000oooooooo04Goool003;oool00`0003?o03?o001:<ol000?o09Tco`0co`00ES?o00030000
oooooooo04Goool003?oool00`0003?o03?o0019<ol000?o09Tco`0co`00ES?o00800016oooo000c
oooo00<0000co`0co`00BC?o0003o`2I<ol0<ol005Hco`000`000?ooooooo`15oooo000doooo00<0
000co`0co`00B3?o0003o`2I<ol0<ol005Hco`000`000?ooooooo`15oooo000eoooo00<0000co`0c
o`00Ac?o0003o`2I<ol0<ol005Hco`000`000?ooooooo`15oooo000foooo00<0000co`0co`00AS?o
0003o`2I<ol0<ol005Hco`000`000?ooooooo`15oooo000goooo00<0000co`0co`00AC?o0003o`2I
<ol0<ol005Hco`000`000?ooooooo`15oooo000hoooo00<0000co`0co`00A3?o0003o`2I<ol0<ol0
05Hco`000`000?ooooooo`15oooo000hoooo00<0000co`0co`00A3?o0003o`2I<ol0<ol005Hco`00
0`000?ooooooo`15oooo000ioooo00<0000co`0co`00@c?o0003o`2I<ol0<ol005Hco`020000A_oo
o`00>_ooo`030000<ol0<ol0048co`000ol0VC?o03?o001F<ol000<0003oooooool0AOooo`00>ooo
o`030000<ol0<ol0044co`000ol0VC?o03?o001F<ol000<0003oooooool0AOooo`00??ooo`030000
<ol0<ol0040co`000ol0VC?o03?o001F<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol0
040co`000ol0VC?o03?o001F<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol003lco`00
0ol0VC?o03?o001F<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol003lco`000ol0VC?o
03?o001F<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol003hco`000ol0VC?o03?o001F
<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol003hco`000ol0VC?o03?o001F<ol000<0
003oooooool0AOooo`00?oooo`030000<ol0<ol003dco`000ol0VC?o03?o001F<ol00P0004Koool0
03ooool00`0003?o03?o000m<ol000?o09Tco`0co`00ES?o00030000oooooooo04Goool0043oool0
0`0003?o03?o000l<ol000?o09Tco`0co`00ES?o00030000oooooooo04Goool0047oool00`0003?o
03?o000k<ol000?o09Tco`0co`00ES?o00030000oooooooo04Goool0047oool00`0003?o03?o000k
<ol000?o09Tco`0co`00ES?o00030000oooooooo04Goool004;oool00`0003?o03?o000j<ol000?o
09Tco`0co`00ES?o00030000oooooooo04Goool004;oool00`0003?o03?o000j<ol000?o09Tco`0c
o`00?C?o00800004<ol00P0000@co`0200001C?o00<00003<ol000<0003oooooool0AOooo`00@ooo
o`030000<ol0<ol003Tco`000ol0VC?o03?o000l<ol000@0000co`0co`000008<ol000@0000co`0c
o`000005<ol000<0000co`0co`000S?o00030000oooooooo04Goool004?oool00`0003?o03?o000i
<ol000?o09Tco`0co`00?3?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00D00003
<ol00`0004Goool004Coool00`0003?o03?o000h<ol000?o09Tco`0co`00?3?o00040000<ol0<ol0
000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool0
04Coool00`0003?o03?o000h<ol000?o09Tco`0co`00?3?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000c?o00030000<ol0000000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0c
o`00=c?o0003o`2I<ol0<ol003dco`0200002S?o00800005<ol00P0000@co`000`000?ooooooo`15
oooo0015oooo00<0000co`0co`00=c?o0003o`2I<ol0<ol005Hco`000`000?ooooooo`15oooo0016
oooo00<0000co`0co`00=S?o0003o`2I<ol0<ol005Hco`000`000?ooooooo`15oooo0016oooo00<0
000co`0co`00=S?o0003o`2I<ol0<ol005Hco`000`000?ooooooo`15oooo0017oooo00<0000co`0c
o`00=C?o0003o`2I<ol0<ol005Hco`000`000?ooooooo`15oooo0017oooo00<0000co`0co`00=C?o
0003o`2I<ol0<ol005Hco`020000A_ooo`00B?ooo`030000<ol0<ol003@co`000ol0VC?o03?o001F
<ol000<0003oooooool0AOooo`00B?ooo`030000<ol0<ol003@co`000ol0VC?o03?o001F<ol000<0
003oooooool0AOooo`00BOooo`030000<ol0<ol003<co`000ol0VC?o03?o001F<ol000<0003ooooo
ool0AOooo`00BOooo`030000<ol0<ol003<co`000ol0VC?o03?o001F<ol000<0003oooooool0AOoo
o`00B_ooo`030000<ol0<ol0038co`000ol0VC?o03?o001F<ol000<0003oooooool0AOooo`00B_oo
o`030000<ol0<ol0038co`000ol0VC?o03?o001F<ol000<0003oooooool0AOooo`00Boooo`030000
<ol0<ol0034co`000ol0VC?o03?o001F<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol0
034co`000ol0VC?o03?o001F<ol00P0004Koool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001<
ooooS3?o04Soool004gooon;<ol0B?ooo`00COoooh/co`18oooo001>oooo;C?o00030000<ol0<ol0
024co`000`0003?o03?o000f<ol0B?ooo`00C_ooob`co`000`0003?o03?o0008<ol000<0000co`0c
o`0063?o00030000<ol0<ol003Dco`18oooo001?oooo:c?o00030000<ol0<ol0008co`02000013?o
00030000<ol0<ol000Hco`02000013?o00800003<ol01@00008co`000`0003?o03?o000e<ol0B?oo
o`00Coooob/co`001@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o00030000<ol0<ol0
00@co`00100003?o03?o000000Xco`000`0003?o03?o0002<ol000<0000co`0co`00=C?o04Soool0
04oooolZ<ol000<0000co`0co`000S?o00030000<ol0<ol000`co`00100003?o03?o000000Xco`00
0`0003?o03?o0003<ol000<0000co`0co`00=3?o04Soool0053ooolZ<ol000<0000co`0co`001@00
00/co`00100003?o03?o000000Xco`000`0003?o03?o0002<ol000<0000co`0co`00=C?o04Soool0
053ooolZ<ol000D0000co`0co`0co`0000003S?o00040000<ol0<ol000002S?o00030000<ol0<ol0
008co`000`0003?o03?o000e<ol0B?ooo`00D?ooob/co`000`0003?o03?o000@<ol00P0000Xco`02
00000c?o00030000<ol0<ol003Hco`18oooo001AooooQc?o04Soool0057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.11) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.43215 .30902 L
.43755 .30902 L
.44021 .30902 L
.44268 .30902 L
.44498 .30902 L
.44627 .30902 L
s
.44627 .30902 m
.44628 .61803 L
s
0 .4 1 r
.02381 .29541 m
.06244 .29331 L
.10458 .29064 L
.14415 .28772 L
.18221 .28448 L
.22272 .28048 L
.26171 .27601 L
.30316 .27047 L
.34309 .26423 L
.3815 .25726 L
.40095 .25331 L
.42237 .2486 L
.43215 .24631 L
.43755 .245 L
.44021 .24435 L
.44268 .24374 L
.44498 .24316 L
.44627 .24284 L
.44744 .30902 L
.44872 .30902 L
.44939 .30902 L
.45011 .30902 L
.45142 .30902 L
.45262 .30902 L
.4537 .30902 L
.45486 .30902 L
.45596 .30902 L
.45696 .30902 L
.45813 .30902 L
.4594 .30902 L
.4606 .30902 L
.46172 .30902 L
.46289 .30902 L
.46413 .30902 L
.46519 .30902 L
.46635 .30902 L
.4676 .30902 L
.4683 .30902 L
.46894 .30902 L
.47017 .30902 L
.47134 .30902 L
.47244 .30902 L
.4736 .30902 L
.47459 .30902 L
.47568 .30902 L
.47685 .30902 L
.47811 .30902 L
.4793 .30902 L
.48038 .30902 L
.48165 .30902 L
Mistroke
.48236 .30902 L
.483 .30902 L
.48426 .30902 L
.48544 .30902 L
.48611 .30902 L
.48682 .30902 L
.48809 .30902 L
.48879 .30902 L
.48945 .30902 L
.49018 .30902 L
.49095 .30902 L
.49224 .30902 L
.49297 .30902 L
.49365 .30902 L
.49489 .30902 L
.4962 .30902 L
.49737 .30902 L
.49848 .30902 L
.49968 .30902 L
.50098 .30902 L
.50224 .30902 L
.50339 .30902 L
.50471 .30902 L
.50596 .30902 L
.50711 .30902 L
.50818 .30902 L
.50934 .30902 L
.51058 .30902 L
.51182 .30902 L
.51252 .30902 L
.51316 .30902 L
.5144 .30902 L
.51557 .30902 L
.51624 .30902 L
.51694 .30902 L
.5182 .30902 L
.5189 .30902 L
.51956 .30902 L
.52028 .30902 L
.52106 .30902 L
.5223 .30902 L
.52362 .30902 L
.52438 .30902 L
.52507 .30902 L
.52577 .30902 L
.52642 .30902 L
.52711 .30902 L
.52783 .30902 L
.52913 .30902 L
.52986 .30902 L
Mistroke
.53053 .30902 L
.53127 .30902 L
.53207 .30902 L
.53337 .30902 L
.5341 .30902 L
.53478 .30902 L
.53602 .30902 L
.53672 .30902 L
.53735 .30902 L
.53854 .30902 L
.53983 .30902 L
.54105 .30902 L
.54217 .30902 L
.54344 .30902 L
.54464 .30902 L
.54571 .30902 L
.54688 .30902 L
.54815 .30902 L
.5495 .30902 L
.55065 .30902 L
.55192 .30902 L
.5531 .30902 L
.55418 .30902 L
.55536 .30902 L
.55661 .30902 L
.5577 .30902 L
.55871 .30902 L
.55983 .30902 L
.56101 .30902 L
.56169 .30902 L
.56241 .30902 L
.56369 .30902 L
.56435 .30902 L
.56507 .30902 L
.56585 .30902 L
.56659 .30902 L
.56726 .30902 L
.568 .30902 L
.56934 .30902 L
.57185 .30902 L
.57658 .30902 L
.57906 .30902 L
.58168 .30902 L
.58232 .30902 L
.58301 .30902 L
.58376 .30902 L
.58446 .30902 L
.58515 .30902 L
.5858 .30902 L
.58702 .30902 L
Mistroke
.58827 .30902 L
.58942 .30902 L
.59069 .30902 L
.59133 .30902 L
.59204 .30902 L
.59325 .30902 L
.59437 .30902 L
.59565 .30902 L
.59688 .30902 L
.598 .30902 L
.59904 .30902 L
.60019 .30902 L
.60141 .30902 L
.60209 .30902 L
.60273 .30902 L
.6034 .30902 L
.60413 .30902 L
.60487 .30902 L
.60566 .30902 L
.6064 .30902 L
.60708 .30902 L
.60839 .30902 L
.60913 .30902 L
.60982 .30902 L
.61108 .30902 L
.61171 .30902 L
.61242 .30902 L
.61371 .30902 L
.61489 .30902 L
.61619 .30902 L
.61685 .30902 L
.61756 .30902 L
.61878 .30902 L
.62007 .30902 L
.62129 .30902 L
.6224 .30902 L
.62359 .30902 L
.62471 .30902 L
.62593 .30902 L
.62724 .30902 L
.6279 .30902 L
.62862 .30902 L
.62993 .30902 L
.6312 .30902 L
.63238 .30902 L
.63358 .30902 L
.63471 .30902 L
.63573 .30902 L
.63683 .30902 L
.63803 .30902 L
Mistroke
.6393 .30902 L
.64039 .30902 L
.64158 .30902 L
.64225 .30902 L
.64297 .30902 L
.64429 .30902 L
.64558 .30902 L
.64677 .30902 L
.64805 .30902 L
.64879 .30902 L
.64947 .30902 L
.65019 .30902 L
.65085 .30902 L
.65157 .30902 L
.65234 .30902 L
.65354 .30902 L
.65482 .30902 L
.65603 .30902 L
.65713 .30902 L
.65842 .30902 L
.65915 .30902 L
.65983 .30902 L
.66106 .30902 L
.66237 .30902 L
.66358 .30902 L
.66491 .30902 L
.66616 .30902 L
.66731 .30902 L
.66844 .30902 L
.6695 .30902 L
.6706 .30902 L
.67183 .30902 L
.67306 .30902 L
.67437 .30902 L
.67549 .30902 L
.67671 .30902 L
.67802 .30902 L
.67876 .30902 L
.67943 .30902 L
.68074 .30902 L
.68197 .30902 L
.68303 .30902 L
.68419 .30902 L
.68541 .30902 L
.68654 .30902 L
.6876 .30902 L
.68858 .30902 L
.6897 .30902 L
.69076 .30902 L
.69191 .30902 L
Mistroke
.69313 .30902 L
.69428 .30902 L
.69532 .30902 L
.69655 .30902 L
.69725 .30902 L
.69788 .30902 L
.69906 .30902 L
.7003 .30902 L
.70152 .30902 L
.70221 .30902 L
.70284 .30902 L
.70401 .30902 L
.70526 .30902 L
.70637 .30902 L
.70741 .30902 L
.70855 .30902 L
.70978 .30902 L
.71101 .30902 L
.71171 .30902 L
.71236 .30902 L
.71368 .30902 L
.71441 .30902 L
.71508 .30902 L
.71628 .30902 L
.71758 .30902 L
.71881 .30902 L
.71994 .30902 L
.721 .30902 L
.72213 .30902 L
.7232 .30902 L
.72418 .30902 L
.72533 .30902 L
.72658 .30902 L
.72775 .30902 L
.72885 .30902 L
.73008 .30902 L
.73124 .30902 L
.73229 .30902 L
.73341 .30902 L
.73465 .30902 L
.73595 .30902 L
.73706 .30902 L
.73828 .30902 L
.7395 .30902 L
.7408 .30902 L
.74147 .30902 L
.74222 .30902 L
.74354 .30902 L
.74477 .30902 L
.74547 .30902 L
Mistroke
.7461 .30902 L
.74734 .30902 L
.74851 .30902 L
.74963 .30902 L
.75082 .30902 L
.75195 .30902 L
.75297 .30902 L
.75417 .30902 L
.75547 .30902 L
.7567 .30902 L
.75783 .30902 L
.75904 .30902 L
.76034 .30902 L
.76156 .30902 L
.76268 .30902 L
.76399 .30902 L
.76468 .30902 L
.76541 .30902 L
.76605 .30902 L
.76676 .30902 L
.768 .30902 L
.76868 .30902 L
.7694 .30902 L
.77067 .30902 L
.77138 .30902 L
.77205 .30902 L
.77282 .30902 L
.77355 .30902 L
.77487 .30902 L
.77607 .30902 L
.77736 .30902 L
.77809 .30902 L
.77876 .30902 L
.78001 .30902 L
.7812 .30902 L
.78228 .30902 L
.78343 .30902 L
.78467 .30902 L
.78583 .30902 L
.78653 .30902 L
.7872 .30902 L
.78844 .30902 L
.79751 .30902 L
.81814 .30902 L
.85672 .30902 L
.89775 .30902 L
.93726 .30902 L
.97526 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.11) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo001moooo101V
oeOoool00`000?ooooooo`15oooo001hoooo1@1Vo`?oool00`1Vooooooooo`1Eoooo0P0004Koool0
07Koool206Ko2?ooo`0306Kooooooooo05Goool00`000?ooooooo`15oooo001boooo101Vo`[oool0
0`1Vooooooooo`1Eoooo00<0003oooooool0AOooo`00Joooo`L0I_l>oooo00<0I_ooooooool0EOoo
o`030000oooooooo04Goool006?oool806Ko5Oooo`0306Kooooooooo05Goool00`000?ooooooo`15
oooo000Boooo100002Soool500000_ooo`800004oooo0P00013oool606Ko4oooo`D00005oooo00<0
I_ooooooool07oooo`800004oooo0P0000Coool20000:?ooo`030000oooooooo02Soool200001?oo
o`800004oooo0P0000ooool001;oool00`000?ooooooo`0[oooo00<0003oooooool01oooo`040000
oooooooo00002_ooo`D0I_lKoooo00<0003oooooool01Oooo`0306Kooooooooo01koool010000?oo
ooooo`0000Soool010000?ooooooo`0002Ooool00`000?ooooooo`0Woooo00@0003oooooool00008
oooo00@0003oooooool0000>oooo000Coooo00<0003oooooool0:_ooo`030000oooooooo00[oool0
0`000?ooooooo`02oooo1P1Vob3oool00`000?ooooooo`05oooo00<0I_ooooooool07_ooo`040000
oooooooo00002oooo`030000oooooooo02Goool00`000?ooooooo`0Woooo00@0003oooooool0000;
oooo00<0003oooooool03?ooo`003?ooo`@00004oooo00<0003oooooool08Oooo`@00004oooo00<0
003oooooool02?ooo`80000506Ko7_ooo`@00004oooo00<0003oooooool01Oooo`0306Kooooooooo
01Soool400000_ooo`040000oooooooo00002Oooo`80000Xoooo0P0002Soool010000?ooooooo`00
00Woool200003oooo`004_ooo`040000oooooooo0000:_ooo`03000006Ko06Ko00P0I_l00`000?oo
ooooo`0Zoooo00<0003oooooool01Oooo`0306Kooooooooo01koool010000?ooooooo`0000Woool0
0`000?ooooooo`0Woooo00<0003oooooool09oooo`040000oooooooo00002Oooo`030000oooooooo
00koool001?oool200008_ooo`P0I_l200002_ooo`<0000Yoooo0P0000Ooool00`1Vooooooooo`0O
oooo0P0000[oool300009oooo`030000oooooooo02Soool200002_ooo`<0000>oooo000Roooo5@1V
odWoool00`1Vooooooooo`1Eoooo00<0003oooooool0AOooo`005oooo`/0I_mNoooo00<0I_oooooo
ool0EOooo`030000oooooooo04Goool0017oool606KoJOooo`0306Kooooooooo05Goool00`000?oo
ooooo`15oooo0020oooo00<0I_ooooooool0EOooo`030000oooooooo04Goool0083oool00`1Voooo
ooooo`1Eoooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003o09Tco`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0c
o`00;c?o00030000<ol0<ol002lco`000`0003?o03?o0008<ol000?o09Tco`0co`008c?o00030000
<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Ooooflco`000ol0VC?o
03?o001E<ol000<0003oooooool0AOooo`004Ooooflco`000ol0VC?o03?o001E<ol000<0003ooooo
ool0AOooo`004Ooooflco`000ol0VC?o03?o001E<ol000<0003oooooool0AOooo`004Ooooflco`00
0ol0VC?o03?o001E<ol000<0003oooooool0AOooo`004Ooooflco`000ol0VC?o03?o001E<ol000<0
003oooooool0AOooo`004Ooooflco`000ol0VC?o03?o001E<ol00P0004Koool0017ooom_<ol000?o
09Tco`0co`00EC?o00030000oooooooo04Goool0017ooom_<ol000?o09Tco`0co`00EC?o00030000
oooooooo04Goool0017ooom_<ol000?o09Tco`0co`00EC?o00030000oooooooo04Goool0017ooom_
<ol000?o09Tco`0co`00EC?o00030000oooooooo04Goool0017ooom_<ol000?o09Tco`0co`00EC?o
00030000oooooooo04Goool0017ooom_<ol000?o09Tco`0co`00EC?o00030000oooooooo04Goool0
017ooom_<ol000?o09Tco`0co`00EC?o00030000oooooooo04Goool0017oool20000KC?o0003o`2I
<ol0<ol005Dco`020000A_ooo`004oooo`80001[<ol000?o09Tco`0co`00EC?o00030000oooooooo
04Goool001Goool20000JC?o0003o`2I<ol0<ol005Dco`000`000?ooooooo`15oooo000Goooo0P00
06Lco`000ol0VC?o03?o001E<ol000<0003oooooool0AOooo`006Oooo`80001U<ol000?o09Tco`0c
o`00EC?o00030000oooooooo04Goool001_oool20000Hc?o0003o`2I<ol0<ol005Dco`000`000?oo
ooooo`15oooo000Moooo0P00064co`000ol0VC?o03?o001E<ol000<0003oooooool0AOooo`007ooo
o`030000<ol0<ol005hco`000ol0VC?o03?o001E<ol000<0003oooooool0AOooo`008?ooo`030000
<ol0<ol005dco`000ol0VC?o03?o001E<ol00P0004Koool0027oool20000GC?o0003o`2I<ol0<ol0
05Dco`000`000?ooooooo`15oooo000Soooo00<0000co`0co`00FS?o0003o`2I<ol0<ol005Dco`00
0`000?ooooooo`15oooo000Toooo0P0005Xco`000ol0VC?o03?o001E<ol000<0003oooooool0AOoo
o`009_ooo`030000<ol0<ol005Lco`000ol0VC?o03?o001E<ol000<0003oooooool0AOooo`009ooo
o`030000<ol0<ol005Hco`000ol0VC?o03?o001E<ol000<0003oooooool0AOooo`00:?ooo`030000
<ol0<ol005Dco`000ol0VC?o03?o000l<ol00P0000@co`02000013?o00800003<ol0100000@co`00
0`000?ooooooo`15oooo000Yoooo00<0000co`0co`00E3?o0003o`2I<ol0<ol003/co`00100003?o
03?o000000Pco`00100003?o03?o0000008co`000`0003?o03?o0005<ol000<0003oooooool0AOoo
o`00:_ooo`030000<ol0<ol005<co`000ol0VC?o03?o000k<ol000@0000co`0co`000008<ol000@0
000co`0co`000003<ol000<0000co`0co`0013?o00<00015oooo000[oooo0P0005<co`000ol0VC?o
03?o000k<ol000@0000co`0co`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o
00030000oooooooo04Goool002goool00`0003?o03?o001@<ol000?o09Tco`0co`00>c?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo
04Goool002koool00`0003?o03?o001?<ol000?o09Tco`0co`00?3?o0080000:<ol00P0000@co`02
00001C?o00030000oooooooo04Goool002ooool00`0003?o03?o001><ol000?o09Tco`0co`00EC?o
00030000oooooooo04Goool0033oool00`0003?o03?o001=<ol000?o09Tco`0co`00EC?o00030000
oooooooo04Goool0037oool00`0003?o03?o001<<ol000?o09Tco`0co`00EC?o00030000oooooooo
04Goool003;oool00`0003?o03?o001;<ol000?o09Tco`0co`00EC?o00030000oooooooo04Goool0
03?oool00`0003?o03?o001:<ol000?o09Tco`0co`00EC?o00800016oooo000coooo00<0000co`0c
o`00BS?o0003o`2I<ol0<ol005Dco`000`000?ooooooo`15oooo000doooo00<0000co`0co`00BC?o
0003o`2I<ol0<ol005Dco`000`000?ooooooo`15oooo000eoooo00<0000co`0co`00B3?o0003o`2I
<ol0<ol005Dco`000`000?ooooooo`15oooo000foooo00<0000co`0co`00Ac?o0003o`2I<ol0<ol0
05Dco`000`000?ooooooo`15oooo000goooo00<0000co`0co`00AS?o0003o`2I<ol0<ol005Dco`00
0`000?ooooooo`15oooo000hoooo00<0000co`0co`00AC?o0003o`2I<ol0<ol005Dco`000`000?oo
ooooo`15oooo000hoooo00<0000co`0co`00AC?o0003o`2I<ol0<ol005Dco`000`000?ooooooo`15
oooo000ioooo00<0000co`0co`00A3?o0003o`2I<ol0<ol005Dco`020000A_ooo`00>_ooo`030000
<ol0<ol004<co`000ol0VC?o03?o001E<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol0
048co`000ol0VC?o03?o001E<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol0044co`00
0ol0VC?o03?o001E<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol0044co`000ol0VC?o
03?o001E<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol0040co`000ol0VC?o03?o001E
<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol0040co`000ol0VC?o03?o001E<ol000<0
003oooooool0AOooo`00?_ooo`030000<ol0<ol003lco`000ol0VC?o03?o001E<ol000<0003ooooo
ool0AOooo`00?_ooo`030000<ol0<ol003lco`000ol0VC?o03?o001E<ol000<0003oooooool0AOoo
o`00?oooo`030000<ol0<ol003hco`000ol0VC?o03?o001E<ol00P0004Koool003ooool00`0003?o
03?o000n<ol000?o09Tco`0co`00EC?o00030000oooooooo04Goool0043oool00`0003?o03?o000m
<ol000?o09Tco`0co`00EC?o00030000oooooooo04Goool0047oool00`0003?o03?o000l<ol000?o
09Tco`0co`00EC?o00030000oooooooo04Goool0047oool00`0003?o03?o000l<ol000?o09Tco`0c
o`00EC?o00030000oooooooo04Goool004;oool00`0003?o03?o000k<ol000?o09Tco`0co`00EC?o
00030000oooooooo04Goool004;oool00`0003?o03?o000k<ol000?o09Tco`0co`00?3?o00800004
<ol00P0000@co`0200001C?o00<00003<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol0
03Xco`000ol0VC?o03?o000k<ol000@0000co`0co`000008<ol000@0000co`0co`000005<ol000<0
000co`0co`000S?o00030000oooooooo04Goool004?oool00`0003?o03?o000j<ol000?o09Tco`0c
o`00>c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00D00003<ol00`0004Goool0
04Coool00`0003?o03?o000i<ol000?o09Tco`0co`00>c?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool004Coool00`0003?o
03?o000i<ol000?o09Tco`0co`00>c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o
00030000<ol0000000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`00>3?o0003o`2I
<ol0<ol003`co`0200002S?o00800005<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0
000co`0co`00>3?o0003o`2I<ol0<ol005Dco`000`000?ooooooo`15oooo0016oooo00<0000co`0c
o`00=c?o0003o`2I<ol0<ol005Dco`000`000?ooooooo`15oooo0016oooo00<0000co`0co`00=c?o
0003o`2I<ol0<ol005Dco`000`000?ooooooo`15oooo0017oooo00<0000co`0co`00=S?o0003o`2I
<ol0<ol005Dco`000`000?ooooooo`15oooo0017oooo00<0000co`0co`00=S?o0003o`2I<ol0<ol0
05Dco`020000A_ooo`00B?ooo`030000<ol0<ol003Dco`000ol0VC?o03?o001E<ol000<0003ooooo
ool0AOooo`00B?ooo`030000<ol0<ol003Dco`000ol0VC?o03?o001E<ol000<0003oooooool0AOoo
o`00BOooo`030000<ol0<ol003@co`000ol0VC?o03?o001E<ol000<0003oooooool0AOooo`00BOoo
o`030000<ol0<ol003@co`000ol0VC?o03?o001E<ol000<0003oooooool0AOooo`00B_ooo`030000
<ol0<ol003<co`000ol0VC?o03?o001E<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol0
03<co`000ol0VC?o03?o001E<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol0038co`00
0ol0VC?o03?o001E<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol0038co`000ol0VC?o
03?o001E<ol00P0004Koool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool0
04gooon;<ol0B?ooo`00COoooh/co`18oooo001>oooo:S?o00030000<ol0<ol002Lco`000`0003?o
03?o000c<ol0B?ooo`00C_ooobTco`000`0003?o03?o0008<ol000<0000co`0co`007S?o00030000
<ol0<ol0038co`18oooo001?oooo:3?o00030000<ol0<ol0008co`02000013?o00030000<ol0<ol0
00Hco`02000013?o00800003<ol01@000003<ol00000000000<00002<ol000<0000co`0co`00<S?o
04Soool004oooolX<ol000D0000co`0co`0co`0000000S?o00030000<ol0<ol0008co`000`0003?o
03?o0004<ol000@0000co`0co`00000:<ol000<0000co`0co`000c?o00030000<ol0<ol0008co`00
0`0003?o03?o000b<ol0B?ooo`00CoooobLco`000`0003?o03?o0002<ol000<0000co`0co`0033?o
00040000<ol0<ol000002S?o00030000<ol0<ol000<co`000`0003?o03?o0003<ol000<0000co`0c
o`00<C?o04Soool0053ooolW<ol000<0000co`0co`001@0000/co`00100003?o03?o000000Xco`00
0`0003?o03?o0003<ol000<0000co`0co`000S?o00030000<ol0<ol0038co`18oooo001@oooo9c?o
00050000<ol0<ol0<ol0000000hco`00100003?o03?o000000Xco`000`0003?o03?o0003<ol000<0
000co`0co`000S?o00030000<ol0<ol0038co`18oooo001@oooo:3?o00030000<ol0<ol0010co`02
00002S?o00800004<ol00P0000<co`000`0003?o03?o000c<ol0B?ooo`00DOooohLco`18oooo001A
ooooQc?o04Soool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.43215 .30902 L
.43755 .30902 L
.44268 .30902 L
.44744 .30902 L
.44874 .30902 L
.44945 .30902 L
.45013 .30902 L
s
.45013 .30902 m
.45013 .61803 L
s
0 .4 1 r
.02381 .29416 m
.06244 .29186 L
.10458 .28895 L
.14415 .28577 L
.18221 .28223 L
.22272 .27786 L
.26171 .27298 L
.30316 .26693 L
.34309 .26013 L
.3815 .25251 L
.40095 .2482 L
.42237 .24305 L
.43215 .24055 L
.43755 .23913 L
.44268 .23775 L
.44744 .23645 L
.44874 .23609 L
.44945 .23589 L
.45013 .2357 L
.45143 .30902 L
.45262 .30902 L
.45733 .30902 L
.45962 .30902 L
.46063 .30902 L
.46172 .30902 L
.46287 .30902 L
.46396 .30902 L
.46521 .30902 L
.46637 .30902 L
.46755 .30902 L
.46885 .30902 L
.4695 .30902 L
.47021 .30902 L
.47148 .30902 L
.47273 .30902 L
.47344 .30902 L
.4741 .30902 L
.4748 .30902 L
.47544 .30902 L
.47618 .30902 L
.47686 .30902 L
.47808 .30902 L
.4794 .30902 L
.48056 .30902 L
.48179 .30902 L
.48294 .30902 L
.48399 .30902 L
.48519 .30902 L
.48634 .30902 L
.48739 .30902 L
Mistroke
.48837 .30902 L
.48945 .30902 L
.49059 .30902 L
.49185 .30902 L
.49256 .30902 L
.49321 .30902 L
.49441 .30902 L
.49567 .30902 L
.49674 .30902 L
.49787 .30902 L
.49912 .30902 L
.50027 .30902 L
.50148 .30902 L
.50217 .30902 L
.50282 .30902 L
.50399 .30902 L
.50524 .30902 L
.50639 .30902 L
.50761 .30902 L
.50864 .30902 L
.50977 .30902 L
.51108 .30902 L
.51232 .30902 L
.51301 .30902 L
.51375 .30902 L
.51504 .30902 L
.51628 .30902 L
.5176 .30902 L
.51871 .30902 L
.51994 .30902 L
.52117 .30902 L
.52234 .30902 L
.52338 .30902 L
.52452 .30902 L
.52576 .30902 L
.52707 .30902 L
.52819 .30902 L
.52943 .30902 L
.53058 .30902 L
.53163 .30902 L
.53278 .30902 L
.534 .30902 L
.53506 .30902 L
.53605 .30902 L
.53713 .30902 L
.53829 .30902 L
.53952 .30902 L
.54022 .30902 L
.54087 .30902 L
.54219 .30902 L
Mistroke
.54293 .30902 L
.54361 .30902 L
.54481 .30902 L
.54613 .30902 L
.54737 .30902 L
.54852 .30902 L
.54921 .30902 L
.54997 .30902 L
.55068 .30902 L
.55134 .30902 L
.55258 .30902 L
.55389 .30902 L
.55521 .30902 L
.55594 .30902 L
.55662 .30902 L
.55741 .30902 L
.55817 .30902 L
.55891 .30902 L
.55961 .30902 L
.56077 .30902 L
.56204 .30902 L
.56329 .30902 L
.56399 .30902 L
.56463 .30902 L
.56571 .30902 L
.56689 .30902 L
.56812 .30902 L
.56926 .30902 L
.56992 .30902 L
.57063 .30902 L
.57192 .30902 L
.57318 .30902 L
.57434 .30902 L
.57559 .30902 L
.5763 .30902 L
.57697 .30902 L
.57767 .30902 L
.57831 .30902 L
.57976 .30902 L
.58087 .30902 L
.58204 .30902 L
.58333 .30902 L
.58451 .30902 L
.58563 .30902 L
.58682 .30902 L
.58795 .30902 L
.58898 .30902 L
.59024 .30902 L
.59144 .30902 L
.59273 .30902 L
Mistroke
.59346 .30902 L
.59413 .30902 L
.59521 .30902 L
.59639 .30902 L
.59763 .30902 L
.59879 .30902 L
.60018 .30902 L
.6015 .30902 L
.60269 .30902 L
.60398 .30902 L
.60471 .30902 L
.60538 .30902 L
.60615 .30902 L
.60687 .30902 L
.60816 .30902 L
.60889 .30902 L
.60956 .30902 L
.61076 .30902 L
.61187 .30902 L
.6131 .30902 L
.61441 .30902 L
.61507 .30902 L
.61579 .30902 L
.61709 .30902 L
.61836 .30902 L
.61954 .30902 L
.62071 .30902 L
.62195 .30902 L
.62301 .30902 L
.62417 .30902 L
.62542 .30902 L
.62612 .30902 L
.62675 .30902 L
.62799 .30902 L
.62916 .30902 L
.63025 .30902 L
.63141 .30902 L
.6324 .30902 L
.63349 .30902 L
.63466 .30902 L
.63592 .30902 L
.63702 .30902 L
.63819 .30902 L
.63956 .30902 L
.64083 .30902 L
.64155 .30902 L
.64232 .30902 L
.64304 .30902 L
.64371 .30902 L
.64435 .30902 L
Mistroke
.64505 .30902 L
.64578 .30902 L
.64646 .30902 L
.64767 .30902 L
.64895 .30902 L
.65022 .30902 L
.65094 .30902 L
.6516 .30902 L
.65281 .30902 L
.6541 .30902 L
.65634 .30902 L
.65761 .30902 L
.65879 .30902 L
.65995 .30902 L
.66118 .30902 L
.6625 .30902 L
.66369 .30902 L
.6648 .30902 L
.666 .30902 L
.66714 .30902 L
.66818 .30902 L
.66939 .30902 L
.67052 .30902 L
.67176 .30902 L
.67246 .30902 L
.6731 .30902 L
.67437 .30902 L
.67509 .30902 L
.67576 .30902 L
.67699 .30902 L
.67829 .30902 L
.67942 .30902 L
.68045 .30902 L
.68158 .30902 L
.68277 .30902 L
.68381 .30902 L
.68478 .30902 L
.68584 .30902 L
.68698 .30902 L
.68822 .30902 L
.68892 .30902 L
.68957 .30902 L
.69075 .30902 L
.69201 .30902 L
.69306 .30902 L
.69419 .30902 L
.69542 .30902 L
.69658 .30902 L
.69727 .30902 L
.69791 .30902 L
Mistroke
.69912 .30902 L
.70042 .30902 L
.70115 .30902 L
.70182 .30902 L
.70295 .30902 L
.70419 .30902 L
.70547 .30902 L
.70669 .30902 L
.70738 .30902 L
.70813 .30902 L
.70944 .30902 L
.71019 .30902 L
.71098 .30902 L
.71165 .30902 L
.7124 .30902 L
.71372 .30902 L
.71446 .30902 L
.71514 .30902 L
.7164 .30902 L
.71772 .30902 L
.71898 .30902 L
.72013 .30902 L
.72145 .30902 L
.72269 .30902 L
.72385 .30902 L
.72491 .30902 L
.72608 .30902 L
.72732 .30902 L
.72856 .30902 L
.72925 .30902 L
.7299 .30902 L
.73116 .30902 L
.73232 .30902 L
.73298 .30902 L
.73368 .30902 L
.73495 .30902 L
.73572 .30902 L
.73645 .30902 L
.73711 .30902 L
.73781 .30902 L
.73906 .30902 L
.7402 .30902 L
.74142 .30902 L
.74206 .30902 L
.74275 .30902 L
.74398 .30902 L
.74511 .30902 L
.74618 .30902 L
.74735 .30902 L
.74804 .30902 L
Mistroke
.7487 .30902 L
.74995 .30902 L
.75064 .30902 L
.75128 .30902 L
.75199 .30902 L
.75274 .30902 L
.7534 .30902 L
.75411 .30902 L
.75539 .30902 L
.75664 .30902 L
.7578 .30902 L
.75902 .30902 L
.76032 .30902 L
.76156 .30902 L
.76268 .30902 L
.764 .30902 L
.76474 .30902 L
.76543 .30902 L
.7667 .30902 L
.76734 .30902 L
.76804 .30902 L
.76873 .30902 L
.76945 .30902 L
.77073 .30902 L
.77145 .30902 L
.77212 .30902 L
.77285 .30902 L
.77363 .30902 L
.77431 .30902 L
.77504 .30902 L
.77574 .30902 L
.77638 .30902 L
.77759 .30902 L
.77888 .30902 L
.78008 .30902 L
.7814 .30902 L
.78265 .30902 L
.7838 .30902 L
.78494 .30902 L
.78598 .30902 L
.78718 .30902 L
.7883 .30902 L
.79843 .30902 L
.81674 .30902 L
.85532 .30902 L
.89635 .30902 L
.93586 .30902 L
.97386 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003ooooo
ool0AOooo`00P?ooo`80I_mFoooo00<0003oooooool0AOooo`00Noooo`D0I_l00oooo`1Vooooo`1E
oooo00<0003oooooool0AOooo`00Moooo`@0I_l6oooo00<0I_ooooooool0E?ooo`030000oooooooo
04Goool007;oool506Ko2_ooo`0306Kooooooooo05Coool20000A_ooo`00KOooo`D0I_l?oooo00<0
I_ooooooool0E?ooo`030000oooooooo04Goool006Soool506Ko5?ooo`0306Kooooooooo05Coool0
0`000?ooooooo`15oooo001Soooo1@1VoaWoool00`1Vooooooooo`1Doooo00<0003oooooool0AOoo
o`00GOooo`H0I_lNoooo00<0I_ooooooool0E?ooo`030000oooooooo04Goool001;oool40000:?oo
o`D00002oooo0P0000Coool200002oooo`D0I_lIoooo1@0000Koool00`1Vooooooooo`0Noooo0P00
00Coool200001?ooo`80000Xoooo00<0003oooooool0:?ooo`800004oooo0P0000Coool200003ooo
o`004_ooo`030000oooooooo02_oool00`000?ooooooo`07oooo00@0003oooooool00004oooo1P1V
ob3oool00`000?ooooooo`06oooo00<0I_ooooooool07Oooo`040000oooooooo00002?ooo`040000
oooooooo00009oooo`030000oooooooo02Ooool010000?ooooooo`0000Soool010000?ooooooo`00
00koool001?oool00`000?ooooooo`0Zoooo00<0003oooooool02?ooo`80I_l00`00001Vo`1Vo`02
06Ko9_ooo`030000oooooooo00Koool00`1Vooooooooo`0Moooo00@0003oooooool0000;oooo00<0
003oooooool09Oooo`030000oooooooo02Ooool010000?ooooooo`0000_oool00`000?ooooooo`0<
oooo000<oooo100000Coool00`000?ooooooo`0Qoooo100000Coool00`00001Vo`1Vo`0806Ko0P00
02?oool400001?ooo`030000oooooooo00Koool00`1Vooooooooo`0Goooo100000;oool010000?oo
ooooo`0000Woool20000:?ooo`80000Xoooo00@0003oooooool00009oooo0P0000ooool001;oool0
10000?ooooooo`00027oool906Ko00<0003oooooool02?ooo`030000oooooooo02[oool00`000?oo
ooooo`06oooo00<0I_ooooooool07Oooo`040000oooooooo00002Oooo`030000oooooooo02Ooool0
0`000?ooooooo`0Woooo00@0003oooooool00009oooo00<0003oooooool03_ooo`004oooo`80000G
oooo2`1Vo`Soool200002_ooo`<0000Yoooo0P0000Soool00`1Vooooooooo`0Noooo0P0000[oool3
00009oooo`030000oooooooo02Soool200002_ooo`<0000>oooo000Roooo2P1VoeGoool00`1Voooo
ooooo`1Doooo00<0003oooooool0AOooo`004Ooooa40I_mOoooo00<0I_ooooooool0E?ooo`030000
oooooooo04Goool0087oool00`1Vooooooooo`1Doooo00<0003oooooool0AOooo`00POooo`0306Ko
oooooooo05Coool00`000?ooooooo`15oooo0021oooo00<0I_ooooooool0E?ooo`030000oooooooo
04Goool000_ooooo00001`0000ooool0017oool00`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0o`2I00Lco`000`0003?o03?o0007<ol000<0
000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool04oooo`004Oooo`030000<ol0<ol002lco`000`0003?o03?o000_
<ol000<0000co`0co`002C?o0003o`2I<ol0<ol0028co`000`0003?o03?o000_<ol000<0003ooooo
ool0;oooo`030000oooooooo01?oool0017ooom`<ol000?o09Tco`0co`00E3?o00030000oooooooo
04Goool0017ooom`<ol000?o09Tco`0co`00E3?o00030000oooooooo04Goool0017ooom`<ol000?o
09Tco`0co`00E3?o00030000oooooooo04Goool0017ooom`<ol000?o09Tco`0co`00E3?o00030000
oooooooo04Goool0017ooom`<ol000?o09Tco`0co`00E3?o00030000oooooooo04Goool0017ooom`
<ol000?o09Tco`0co`00E3?o00800016oooo000AooooL3?o0003o`2I<ol0<ol005@co`000`000?oo
ooooo`15oooo000AooooL3?o0003o`2I<ol0<ol005@co`000`000?ooooooo`15oooo000AooooL3?o
0003o`2I<ol0<ol005@co`000`000?ooooooo`15oooo000AooooL3?o0003o`2I<ol0<ol005@co`00
0`000?ooooooo`15oooo000AooooL3?o0003o`2I<ol0<ol005@co`000`000?ooooooo`15oooo000A
ooooL3?o0003o`2I<ol0<ol005@co`000`000?ooooooo`15oooo000AooooL3?o0003o`2I<ol0<ol0
05@co`000`000?ooooooo`15oooo000Aoooo0P0006hco`000ol0VC?o03?o001D<ol00P0004Koool0
01?oool20000K3?o0003o`2I<ol0<ol005@co`000`000?ooooooo`15oooo000Eoooo0P0006Xco`00
0ol0VC?o03?o001D<ol000<0003oooooool0AOooo`005oooo`80001X<ol000?o09Tco`0co`00E3?o
00030000oooooooo04Goool001Woool20000IS?o0003o`2I<ol0<ol005@co`000`000?ooooooo`15
oooo000Koooo0P0006@co`000ol0VC?o03?o001D<ol000<0003oooooool0AOooo`007Oooo`80001R
<ol000?o09Tco`0co`00E3?o00030000oooooooo04Goool001ooool00`0003?o03?o001O<ol000?o
09Tco`0co`00E3?o00030000oooooooo04Goool0023oool00`0003?o03?o001N<ol000?o09Tco`0c
o`00E3?o00800016oooo000Qoooo0P0005hco`000ol0VC?o03?o001D<ol000<0003oooooool0AOoo
o`008oooo`030000<ol0<ol005/co`000ol0VC?o03?o001D<ol000<0003oooooool0AOooo`009?oo
o`80001K<ol000?o09Tco`0co`00E3?o00030000oooooooo04Goool002Koool00`0003?o03?o001H
<ol000?o09Tco`0co`00E3?o00030000oooooooo04Goool002Ooool00`0003?o03?o001G<ol000?o
09Tco`0co`00E3?o00030000oooooooo04Goool002Soool00`0003?o03?o001F<ol000?o09Tco`0c
o`00>c?o00800004<ol00P0000@co`0200000c?o00@00004<ol000<0003oooooool0AOooo`00:Ooo
o`030000<ol0<ol005Dco`000ol0VC?o03?o000j<ol000@0000co`0co`000008<ol000@0000co`0c
o`000002<ol000<0000co`0co`001C?o00030000oooooooo04Goool002[oool00`0003?o03?o001D
<ol000?o09Tco`0co`00>S?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000
<ol0<ol000@co`030000AOooo`00:oooo`80001D<ol000?o09Tco`0co`00>S?o00040000<ol0<ol0
000023?o00040000<ol0<ol0000013?o00030000<ol0<ol000<co`000`000?ooooooo`15oooo000]
oooo00<0000co`0co`00DC?o0003o`2I<ol0<ol003Xco`00100003?o03?o000000Pco`00100003?o
03?o0000008co`00100003?o03?o000000@co`000`000?ooooooo`15oooo000^oooo00<0000co`0c
o`00D3?o0003o`2I<ol0<ol003/co`0200002S?o00800004<ol00P0000Dco`000`000?ooooooo`15
oooo000_oooo00<0000co`0co`00Cc?o0003o`2I<ol0<ol005@co`000`000?ooooooo`15oooo000`
oooo00<0000co`0co`00CS?o0003o`2I<ol0<ol005@co`000`000?ooooooo`15oooo000aoooo00<0
000co`0co`00CC?o0003o`2I<ol0<ol005@co`000`000?ooooooo`15oooo000boooo00<0000co`0c
o`00C3?o0003o`2I<ol0<ol005@co`000`000?ooooooo`15oooo000coooo00<0000co`0co`00Bc?o
0003o`2I<ol0<ol005@co`020000A_ooo`00<oooo`030000<ol0<ol004/co`000ol0VC?o03?o001D
<ol000<0003oooooool0AOooo`00=?ooo`030000<ol0<ol004Xco`000ol0VC?o03?o001D<ol000<0
003oooooool0AOooo`00=Oooo`030000<ol0<ol004Tco`000ol0VC?o03?o001D<ol000<0003ooooo
ool0AOooo`00=_ooo`030000<ol0<ol004Pco`000ol0VC?o03?o001D<ol000<0003oooooool0AOoo
o`00=oooo`030000<ol0<ol004Lco`000ol0VC?o03?o001D<ol000<0003oooooool0AOooo`00>?oo
o`030000<ol0<ol004Hco`000ol0VC?o03?o001D<ol000<0003oooooool0AOooo`00>?ooo`030000
<ol0<ol004Hco`000ol0VC?o03?o001D<ol000<0003oooooool0AOooo`00>Oooo`030000<ol0<ol0
04Dco`000ol0VC?o03?o001D<ol00P0004Koool003[oool00`0003?o03?o0014<ol000?o09Tco`0c
o`00E3?o00030000oooooooo04Goool003_oool00`0003?o03?o0013<ol000?o09Tco`0co`00E3?o
00030000oooooooo04Goool003coool00`0003?o03?o0012<ol000?o09Tco`0co`00E3?o00030000
oooooooo04Goool003coool00`0003?o03?o0012<ol000?o09Tco`0co`00E3?o00030000oooooooo
04Goool003goool00`0003?o03?o0011<ol000?o09Tco`0co`00E3?o00030000oooooooo04Goool0
03goool00`0003?o03?o0011<ol000?o09Tco`0co`00E3?o00030000oooooooo04Goool003koool0
0`0003?o03?o0010<ol000?o09Tco`0co`00E3?o00030000oooooooo04Goool003koool00`0003?o
03?o0010<ol000?o09Tco`0co`00E3?o00030000oooooooo04Goool003ooool00`0003?o03?o000o
<ol000?o09Tco`0co`00E3?o00800016oooo000ooooo00<0000co`0co`00?c?o0003o`2I<ol0<ol0
05@co`000`000?ooooooo`15oooo0010oooo00<0000co`0co`00?S?o0003o`2I<ol0<ol005@co`00
0`000?ooooooo`15oooo0011oooo00<0000co`0co`00?C?o0003o`2I<ol0<ol005@co`000`000?oo
ooooo`15oooo0011oooo00<0000co`0co`00?C?o0003o`2I<ol0<ol005@co`000`000?ooooooo`15
oooo0012oooo00<0000co`0co`00?3?o0003o`2I<ol0<ol005@co`000`000?ooooooo`15oooo0012
oooo00<0000co`0co`00?3?o0003o`2I<ol0<ol003/co`02000013?o00800004<ol00P0000Dco`03
00000c?o00030000oooooooo04Goool004?oool00`0003?o03?o000k<ol000?o09Tco`0co`00>S?o
00040000<ol0<ol0000023?o00040000<ol0<ol000001C?o00030000<ol0<ol0008co`000`000?oo
ooooo`15oooo0013oooo00<0000co`0co`00>c?o0003o`2I<ol0<ol003Xco`00100003?o03?o0000
00Pco`00100003?o03?o0000008co`0500000c?o00<00015oooo0014oooo00<0000co`0co`00>S?o
0003o`2I<ol0<ol003Xco`00100003?o03?o000000Pco`00100003?o03?o0000008co`00100003?o
03?o000000@co`000`000?ooooooo`15oooo0014oooo00<0000co`0co`00>S?o0003o`2I<ol0<ol0
03Xco`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o00000004<ol000<0
003oooooool0AOooo`00AOooo`030000<ol0<ol003Tco`000ol0VC?o03?o000k<ol00P0000Xco`02
00001C?o00800004<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol003Tco`000ol0VC?o
03?o001D<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol003Pco`000ol0VC?o03?o001D
<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol003Pco`000ol0VC?o03?o001D<ol000<0
003oooooool0AOooo`00Aoooo`030000<ol0<ol003Lco`000ol0VC?o03?o001D<ol000<0003ooooo
ool0AOooo`00Aoooo`030000<ol0<ol003Lco`000ol0VC?o03?o001D<ol00P0004Koool004Soool0
0`0003?o03?o000f<ol000?o09Tco`0co`00E3?o00030000oooooooo04Goool004Soool00`0003?o
03?o000f<ol000?o09Tco`0co`00E3?o00030000oooooooo04Goool004Woool00`0003?o03?o000e
<ol000?o09Tco`0co`00E3?o00030000oooooooo04Goool004Woool00`0003?o03?o000e<ol000?o
09Tco`0co`00E3?o00030000oooooooo04Goool004[oool00`0003?o03?o000d<ol000?o09Tco`0c
o`00E3?o00030000oooooooo04Goool004[oool00`0003?o03?o000d<ol000?o09Tco`0co`00E3?o
00030000oooooooo04Goool004_oool00`0003?o03?o000c<ol000?o09Tco`0co`00E3?o00030000
oooooooo04Goool004_oool00`0003?o03?o000c<ol000?o09Tco`0co`00E3?o00800016oooo001<
ooooS3?o04Soool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001=ooooRc?o04Soool004gooon;
<ol0B?ooo`00C_ooobXco`000`0003?o03?o000W<ol000<0000co`0co`00<c?o04Soool004kooolY
<ol000<0000co`0co`0023?o00030000<ol0<ol001hco`000`0003?o03?o000b<ol0B?ooo`00Cooo
obPco`000`0003?o03?o0002<ol00P0000@co`000`0003?o03?o0006<ol00P0000@co`0200000c?o
00D000000c?o00000000000200000c?o00030000<ol0<ol0038co`18oooo001?oooo:3?o00050000
<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0000co`0co`0013?o00040000<ol0<ol0
00002S?o00050000<ol0<ol0<ol0000000Hco`000`0003?o03?o000b<ol0B?ooo`00CoooobLco`00
0`0003?o03?o0002<ol000<0000co`0co`0033?o00040000<ol0<ol000002S?o00030000<ol0<ol0
008co`000`0003?o03?o0004<ol000<0000co`0co`00<C?o04Soool0053ooolW<ol000<0000co`0c
o`001@0000/co`00100003?o03?o000000Xco`000`0003?o03?o0003<ol000<0000co`0co`000S?o
00030000<ol0<ol0038co`18oooo001@oooo9c?o00050000<ol0<ol0<ol0000000hco`00100003?o
03?o000000Xco`001@0003?o03?o03?o00000002<ol000D0000co`0co`0co`000000=3?o04Soool0
053ooolX<ol000<0000co`0co`0043?o0080000:<ol00P0000@co`0200000c?o00030000<ol0<ol0
03<co`18oooo001AooooQc?o04Soool0057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.13) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.43215 .30902 L
.44268 .30902 L
.44778 .30902 L
.45029 .30902 L
.45151 .30902 L
.45262 .30902 L
.45371 .30902 L
s
.45371 .30902 m
.45371 .61803 L
s
0 .4 1 r
.02381 .29291 m
.06244 .29042 L
.10458 .28726 L
.14415 .28381 L
.18221 .27997 L
.22272 .27524 L
.26171 .26994 L
.30316 .26339 L
.34309 .25601 L
.3815 .24775 L
.40095 .24308 L
.42237 .2375 L
.43215 .23479 L
.44268 .23175 L
.44778 .23023 L
.45029 .22947 L
.45151 .2291 L
.45262 .22876 L
.45371 .22843 L
.45473 .30902 L
.4558 .30902 L
.45697 .30902 L
.45817 .30902 L
.45944 .30902 L
.46053 .30902 L
.46172 .30902 L
.46302 .30902 L
.46424 .30902 L
.46551 .30902 L
.46619 .30902 L
.46692 .30902 L
.46766 .30902 L
.46845 .30902 L
.46912 .30902 L
.46986 .30902 L
.47054 .30902 L
.47126 .30902 L
.47257 .30902 L
.47327 .30902 L
.47391 .30902 L
.47461 .30902 L
.47535 .30902 L
.47659 .30902 L
.4773 .30902 L
.47796 .30902 L
.4792 .30902 L
.48033 .30902 L
.48163 .30902 L
.48286 .30902 L
.48408 .30902 L
Mistroke
.48518 .30902 L
.48645 .30902 L
.48765 .30902 L
.48876 .30902 L
.48978 .30902 L
.4909 .30902 L
.49209 .30902 L
.49328 .30902 L
.49457 .30902 L
.49578 .30902 L
.49688 .30902 L
.49818 .30902 L
.49891 .30902 L
.49958 .30902 L
.50082 .30902 L
.50214 .30902 L
.50331 .30902 L
.50454 .30902 L
.50559 .30902 L
.50674 .30902 L
.50798 .30902 L
.50868 .30902 L
.50931 .30902 L
.51054 .30902 L
.51169 .30902 L
.51278 .30902 L
.51393 .30902 L
.51491 .30902 L
.51599 .30902 L
.51715 .30902 L
.5184 .30902 L
.51958 .30902 L
.52065 .30902 L
.52191 .30902 L
.52255 .30902 L
.52325 .30902 L
.52449 .30902 L
.52566 .30902 L
.52633 .30902 L
.52703 .30902 L
.52829 .30902 L
.52894 .30902 L
.52964 .30902 L
.53041 .30902 L
.53112 .30902 L
.5324 .30902 L
.53379 .30902 L
.53511 .30902 L
.53632 .30902 L
.53741 .30902 L
Mistroke
.53862 .30902 L
.53987 .30902 L
.54105 .30902 L
.5423 .30902 L
.54299 .30902 L
.54363 .30902 L
.54486 .30902 L
.54602 .30902 L
.54668 .30902 L
.54738 .30902 L
.54862 .30902 L
.54932 .30902 L
.54997 .30902 L
.55068 .30902 L
.55144 .30902 L
.55271 .30902 L
.55343 .30902 L
.55409 .30902 L
.55531 .30902 L
.5566 .30902 L
.55776 .30902 L
.55884 .30902 L
.56003 .30902 L
.56131 .30902 L
.56249 .30902 L
.56375 .30902 L
.56494 .30902 L
.56602 .30902 L
.56724 .30902 L
.56839 .30902 L
.56963 .30902 L
.57033 .30902 L
.57098 .30902 L
.57204 .30902 L
.57303 .30902 L
.57412 .30902 L
.57529 .30902 L
.57651 .30902 L
.57767 .30902 L
.57871 .30902 L
.57984 .30902 L
.58049 .30902 L
.58118 .30902 L
.58241 .30902 L
.58373 .30902 L
.58448 .30902 L
.58518 .30902 L
.58645 .30902 L
.5876 .30902 L
.58826 .30902 L
Mistroke
.58895 .30902 L
.5902 .30902 L
.59129 .30902 L
.59251 .30902 L
.5938 .30902 L
.59501 .30902 L
.59616 .30902 L
.59721 .30902 L
.59957 .30902 L
.60206 .30902 L
.60271 .30902 L
.60342 .30902 L
.60471 .30902 L
.60551 .30902 L
.60624 .30902 L
.60691 .30902 L
.60762 .30902 L
.60891 .30902 L
.60964 .30902 L
.61033 .30902 L
.61097 .30902 L
.61166 .30902 L
.61288 .30902 L
.61357 .30902 L
.6143 .30902 L
.61562 .30902 L
.61683 .30902 L
.61797 .30902 L
.61921 .30902 L
.61992 .30902 L
.62056 .30902 L
.62183 .30902 L
.62304 .30902 L
.62412 .30902 L
.62529 .30902 L
.62657 .30902 L
.62722 .30902 L
.62793 .30902 L
.62918 .30902 L
.63036 .30902 L
.63153 .30902 L
.63265 .30902 L
.63367 .30902 L
.63475 .30902 L
.63592 .30902 L
.63701 .30902 L
.6383 .30902 L
.63947 .30902 L
.64077 .30902 L
.64143 .30902 L
Mistroke
.64214 .30902 L
.64341 .30902 L
.6446 .30902 L
.64532 .30902 L
.646 .30902 L
.64727 .30902 L
.64794 .30902 L
.64864 .30902 L
.64942 .30902 L
.65014 .30902 L
.65132 .30902 L
.6526 .30902 L
.6538 .30902 L
.65491 .30902 L
.65613 .30902 L
.65684 .30902 L
.65747 .30902 L
.65815 .30902 L
.65887 .30902 L
.66017 .30902 L
.66129 .30902 L
.66249 .30902 L
.6638 .30902 L
.66503 .30902 L
.66569 .30902 L
.66641 .30902 L
.66772 .30902 L
.66899 .30902 L
.67017 .30902 L
.67127 .30902 L
.67229 .30902 L
.67342 .30902 L
.67464 .30902 L
.67584 .30902 L
.67711 .30902 L
.67938 .30902 L
.68066 .30902 L
.68187 .30902 L
.68254 .30902 L
.68326 .30902 L
.68453 .30902 L
.68574 .30902 L
.68702 .30902 L
.68811 .30902 L
.68932 .30902 L
.69004 .30902 L
.69073 .30902 L
.69202 .30902 L
.69274 .30902 L
.69341 .30902 L
Mistroke
.69415 .30902 L
.69493 .30902 L
.69561 .30902 L
.69635 .30902 L
.69705 .30902 L
.69769 .30902 L
.69891 .30902 L
.70019 .30902 L
.70132 .30902 L
.70253 .30902 L
.70384 .30902 L
.70506 .30902 L
.70619 .30902 L
.70725 .30902 L
.70842 .30902 L
.70967 .30902 L
.71032 .30902 L
.71103 .30902 L
.71176 .30902 L
.71245 .30902 L
.71368 .30902 L
.71499 .30902 L
.7163 .30902 L
.71753 .30902 L
.71864 .30902 L
.71984 .30902 L
.7209 .30902 L
.72204 .30902 L
.7233 .30902 L
.72447 .30902 L
.72579 .30902 L
.72703 .30902 L
.72816 .30902 L
.72938 .30902 L
.73052 .30902 L
.73159 .30902 L
.73282 .30902 L
.73394 .30902 L
.735 .30902 L
.73597 .30902 L
.73704 .30902 L
.73817 .30902 L
.7394 .30902 L
.74009 .30902 L
.74073 .30902 L
.7419 .30902 L
.74315 .30902 L
.74426 .30902 L
.7453 .30902 L
.74645 .30902 L
Mistroke
.74768 .30902 L
.74898 .30902 L
.74972 .30902 L
.7504 .30902 L
.75165 .30902 L
.75236 .30902 L
.75299 .30902 L
.75419 .30902 L
.7555 .30902 L
.75672 .30902 L
.75786 .30902 L
.75892 .30902 L
.76005 .30902 L
.76113 .30902 L
.76211 .30902 L
.76325 .30902 L
.7645 .30902 L
.76567 .30902 L
.76677 .30902 L
.7679 .30902 L
.76915 .30902 L
.77036 .30902 L
.77167 .30902 L
.7762 .30902 L
.7786 .30902 L
.77991 .30902 L
.78115 .30902 L
.78231 .30902 L
.78357 .30902 L
.78471 .30902 L
.78576 .30902 L
.79623 .30902 L
.81732 .30902 L
.8567 .30902 L
.89456 .30902 L
.93487 .30902 L
.97367 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.13) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0003oooooool0AOoo
o`00f?ooo`030000oooooooo04Goool0087oool206KoEOooo`030000oooooooo04Goool007koool3
06Ko00?oool0I_ooool0E?ooo`030000oooooooo04Goool007Soool606Ko1?ooo`0306Kooooooooo
05?oool00`000?ooooooo`15oooo001foooo0P1Vo`[oool00`1Vooooooooo`1Coooo00<0003ooooo
ool0AOooo`00L_ooo`@0I_l<oooo00<0I_ooooooool0Doooo`030000oooooooo04Goool006goool5
06Ko4?ooo`0306Kooooooooo05?oool20000A_ooo`00J?ooo`D0I_lEoooo00<0I_ooooooool0Dooo
o`030000oooooooo04Goool006?oool506Ko6_ooo`0306Kooooooooo05?oool00`000?ooooooo`15
oooo001Moooo1P1Voaooool00`1Vooooooooo`1Coooo00<0003oooooool0AOooo`00F?ooo`D0I_lU
oooo00<0I_ooooooool0Doooo`030000oooooooo04Goool001;oool40000:?ooo`D00002oooo0P00
00Coool200001Oooo`H0I_lNoooo1@0000Ooool00`1Vooooooooo`0Moooo0P0000Coool200001?oo
o`80000Xoooo00<0003oooooool0:?ooo`800004oooo0P0000Coool200003oooo`004_ooo`030000
oooooooo02_oool00`000?ooooooo`07oooo00@00000I_l0I_l0000406Ko9_ooo`030000oooooooo
00Ooool00`1Vooooooooo`0Loooo00@0003oooooool00008oooo00@0003oooooool0000Woooo00<0
003oooooool09oooo`040000oooooooo00002?ooo`040000oooooooo00003_ooo`004oooo`030000
oooooooo02[oool00`000?ooooooo`0806Ko0_ooo`030000oooooooo02Soool00`000?ooooooo`07
oooo00<0I_ooooooool07?ooo`040000oooooooo00002oooo`030000oooooooo02Goool00`000?oo
ooooo`0Woooo00@0003oooooool0000;oooo00<0003oooooool03?ooo`003?ooo`@00004oooo00<0
003oooooool08Oooo`@00002oooo0P1Vo`03000006Ko06Ko00Soool200008oooo`@00004oooo00<0
003oooooool01oooo`0306Kooooooooo01Koool400000_ooo`040000oooooooo00002Oooo`80000X
oooo0P0002Soool010000?ooooooo`0000Woool200003oooo`004_ooo`040000oooooooo00008Ooo
o`L0I_l2oooo00<0003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`07oooo00<0
I_ooooooool07?ooo`040000oooooooo00002Oooo`030000oooooooo02Ooool00`000?ooooooo`0W
oooo00@0003oooooool00009oooo00<0003oooooool03_ooo`004oooo`80000=oooo5@1Vo`Soool2
00002_ooo`<0000Yoooo0P0000Woool00`1Vooooooooo`0Moooo0P0000[oool300009oooo`030000
oooooooo02Soool200002_ooo`<0000>oooo000Goooo2`1Vof3oool00`1Vooooooooo`1Coooo00<0
003oooooool0AOooo`004Oooo`H0I_m[oooo00<0I_ooooooool0Doooo`030000oooooooo04Goool0
08;oool00`1Vooooooooo`1Coooo00<0003oooooool0AOooo`00P_ooo`0306Kooooooooo05?oool0
0`000?ooooooo`15oooo0022oooo00<0I_ooooooool0Doooo`030000oooooooo04Goool000_ooooo
00001`0000ooool0017oool00`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00040000<ol0<ol0o`2I1S?o00030000<ol0<ol000Lco`000`0003?o03?o0006
<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`0Coooo000Aoooo00<0000co`0co`00;c?o00030000<ol0<ol002lco`000`0003?o
03?o000:<ol000?o09Tco`0co`008C?o00030000<ol0<ol002lco`000`000?ooooooo`0_oooo00<0
003oooooool04oooo`004Oooog4co`000ol0VC?o03?o001C<ol000<0003oooooool0AOooo`004Ooo
og4co`000ol0VC?o03?o001C<ol000<0003oooooool0AOooo`004Oooog4co`000ol0VC?o03?o001C
<ol000<0003oooooool0AOooo`004Oooog4co`000ol0VC?o03?o001C<ol000<0003oooooool0AOoo
o`004Oooog4co`000ol0VC?o03?o001C<ol000<0003oooooool0AOooo`004Oooog4co`000ol0VC?o
03?o001C<ol00P0004Koool0017oooma<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool0
017oooma<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool0017oooma<ol000?o09Tco`0c
o`00Dc?o00030000oooooooo04Goool0017oooma<ol000?o09Tco`0co`00Dc?o00030000oooooooo
04Goool0017oooma<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool0017oooma<ol000?o
09Tco`0co`00Dc?o00030000oooooooo04Goool0017oooma<ol000?o09Tco`0co`00Dc?o00030000
oooooooo04Goool0017oool20000Kc?o0003o`2I<ol0<ol005<co`020000A_ooo`004oooo`80001]
<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool001Goool20000Jc?o0003o`2I<ol0<ol0
05<co`000`000?ooooooo`15oooo000Goooo0P0006Tco`000ol0VC?o03?o001C<ol000<0003ooooo
ool0AOooo`006Oooo`80001W<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool001_oool2
0000IC?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo000Moooo0P0006<co`000ol0VC?o
03?o001C<ol000<0003oooooool0AOooo`007oooo`030000<ol0<ol0060co`000ol0VC?o03?o001C
<ol000<0003oooooool0AOooo`008?ooo`030000<ol0<ol005lco`000ol0VC?o03?o001C<ol00P00
04Koool0027oool20000Gc?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo000Soooo00<0
000co`0co`00G3?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo000Toooo0P0005`co`00
0ol0VC?o03?o001C<ol000<0003oooooool0AOooo`009_ooo`030000<ol0<ol005Tco`000ol0VC?o
03?o001C<ol000<0003oooooool0AOooo`009oooo`030000<ol0<ol005Pco`000ol0VC?o03?o001C
<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol005Lco`000ol0VC?o03?o000j<ol00P00
00@co`02000013?o00800003<ol0100000@co`000`000?ooooooo`15oooo000Yoooo00<0000co`0c
o`00ES?o0003o`2I<ol0<ol003Tco`00100003?o03?o000000Pco`00100003?o03?o0000008co`00
0`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_ooo`030000<ol0<ol005Dco`000ol0VC?o
03?o000i<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o
00<00015oooo000[oooo0P0005Dco`000ol0VC?o03?o000i<ol000@0000co`0co`000008<ol000@0
000co`0co`000004<ol000<0000co`0co`000c?o00030000oooooooo04Goool002goool00`0003?o
03?o001B<ol000?o09Tco`0co`00>C?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o
00040000<ol0<ol0000013?o00030000oooooooo04Goool002koool00`0003?o03?o001A<ol000?o
09Tco`0co`00>S?o0080000:<ol00P0000@co`0200001C?o00030000oooooooo04Goool002ooool0
0`0003?o03?o001@<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool0033oool00`0003?o
03?o001?<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool0037oool00`0003?o03?o001>
<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool003;oool00`0003?o03?o001=<ol000?o
09Tco`0co`00Dc?o00030000oooooooo04Goool003?oool00`0003?o03?o001<<ol000?o09Tco`0c
o`00Dc?o00800016oooo000coooo00<0000co`0co`00C3?o0003o`2I<ol0<ol005<co`000`000?oo
ooooo`15oooo000doooo00<0000co`0co`00Bc?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15
oooo000eoooo00<0000co`0co`00BS?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo000f
oooo00<0000co`0co`00BC?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo000goooo00<0
000co`0co`00B3?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo000hoooo00<0000co`0c
o`00Ac?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo000hoooo00<0000co`0co`00Ac?o
0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo000ioooo00<0000co`0co`00AS?o0003o`2I
<ol0<ol005<co`020000A_ooo`00>_ooo`030000<ol0<ol004Dco`000ol0VC?o03?o001C<ol000<0
003oooooool0AOooo`00>oooo`030000<ol0<ol004@co`000ol0VC?o03?o001C<ol000<0003ooooo
ool0AOooo`00??ooo`030000<ol0<ol004<co`000ol0VC?o03?o001C<ol000<0003oooooool0AOoo
o`00??ooo`030000<ol0<ol004<co`000ol0VC?o03?o001C<ol000<0003oooooool0AOooo`00?Ooo
o`030000<ol0<ol0048co`000ol0VC?o03?o001C<ol000<0003oooooool0AOooo`00?Oooo`030000
<ol0<ol0048co`000ol0VC?o03?o001C<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol0
044co`000ol0VC?o03?o001C<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol0044co`00
0ol0VC?o03?o001C<ol000<0003oooooool0AOooo`00?oooo`030000<ol0<ol0040co`000ol0VC?o
03?o001C<ol00P0004Koool003ooool00`0003?o03?o0010<ol000?o09Tco`0co`00Dc?o00030000
oooooooo04Goool0043oool00`0003?o03?o000o<ol000?o09Tco`0co`00Dc?o00030000oooooooo
04Goool0047oool00`0003?o03?o000n<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool0
047oool00`0003?o03?o000n<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool004;oool0
0`0003?o03?o000m<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool004;oool00`0003?o
03?o000m<ol000?o09Tco`0co`00>S?o00800004<ol00P0000@co`0200001C?o00<00003<ol000<0
003oooooool0AOooo`00@oooo`030000<ol0<ol003`co`000ol0VC?o03?o000i<ol000@0000co`0c
o`000008<ol000@0000co`0co`000005<ol000<0000co`0co`000S?o00030000oooooooo04Goool0
04?oool00`0003?o03?o000l<ol000?o09Tco`0co`00>C?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool00`0003?o03?o000k<ol000?o09Tco`0c
o`00>C?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o
00030000oooooooo04Goool004Coool00`0003?o03?o000k<ol000?o09Tco`0co`00>C?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0000000@co`000`000?ooooooo`15
oooo0015oooo00<0000co`0co`00>S?o0003o`2I<ol0<ol003Xco`0200002S?o00800005<ol00P00
00@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`00>S?o0003o`2I<ol0<ol005<co`00
0`000?ooooooo`15oooo0016oooo00<0000co`0co`00>C?o0003o`2I<ol0<ol005<co`000`000?oo
ooooo`15oooo0016oooo00<0000co`0co`00>C?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15
oooo0017oooo00<0000co`0co`00>3?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo0017
oooo00<0000co`0co`00>3?o0003o`2I<ol0<ol005<co`020000A_ooo`00B?ooo`030000<ol0<ol0
03Lco`000ol0VC?o03?o001C<ol000<0003oooooool0AOooo`00B?ooo`030000<ol0<ol003Lco`00
0ol0VC?o03?o001C<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol003Hco`000ol0VC?o
03?o001C<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol003Hco`000ol0VC?o03?o001C
<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol003Dco`000ol0VC?o03?o001C<ol000<0
003oooooool0AOooo`00B_ooo`030000<ol0<ol003Dco`000ol0VC?o03?o001C<ol000<0003ooooo
ool0AOooo`00Boooo`030000<ol0<ol003@co`000ol0VC?o03?o001C<ol000<0003oooooool0AOoo
o`00Boooo`030000<ol0<ol003@co`000ol0VC?o03?o001C<ol00P0004Koool004cooon<<ol0B?oo
o`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;<ol0B?ooo`00COoooh/co`18oooo001>
oooo:S?o00030000<ol0<ol002Lco`000`0003?o03?o000c<ol0B?ooo`00C_ooobTco`000`0003?o
03?o0008<ol000<0000co`0co`007S?o00030000<ol0<ol0038co`18oooo001?oooo:3?o00030000
<ol0<ol0008co`02000013?o00030000<ol0<ol000Hco`02000013?o00800003<ol01@00008co`02
000013?o00030000<ol0<ol0038co`18oooo001?oooo:3?o00050000<ol0<ol0<ol00000008co`00
0`0003?o03?o0002<ol000<0000co`0co`0013?o00040000<ol0<ol000002S?o00050000<ol0<ol0
<ol00000008co`001@0003?o03?o03?o0000000d<ol0B?ooo`00CoooobLco`000`0003?o03?o0002
<ol000<0000co`0co`0033?o00040000<ol0<ol000002S?o00030000<ol0<ol000<co`000`0003?o
03?o0003<ol000<0000co`0co`00<C?o04Soool0053ooolW<ol000<0000co`0co`001@0000/co`00
100003?o03?o000000Xco`000`0003?o03?o0004<ol000D0000co`0co`0co`000000=3?o04Soool0
053ooolW<ol000D0000co`0co`0co`0000003S?o00040000<ol0<ol000002S?o00050000<ol0<ol0
<ol00000008co`001@0003?o03?o03?o0000000d<ol0B?ooo`00D?ooobPco`000`0003?o03?o000@
<ol00P0000Xco`02000013?o00800003<ol000<0000co`0co`00<c?o04Soool0057ooon7<ol0B?oo
o`00DOooohLco`18oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.43215 .30902 L
.44268 .30902 L
.44778 .30902 L
.45262 .30902 L
.45473 .30902 L
.45588 .30902 L
.45697 .30902 L
s
.45697 .30902 m
.45698 .61803 L
s
0 .4 1 r
.02381 .29165 m
.06244 .28897 L
.10458 .28557 L
.14415 .28185 L
.18221 .27771 L
.22272 .27261 L
.26171 .2669 L
.30316 .25983 L
.34309 .25188 L
.3815 .24298 L
.40095 .23794 L
.42237 .23193 L
.43215 .229 L
.44268 .22573 L
.44778 .22409 L
.45262 .22251 L
.45473 .22181 L
.45588 .22142 L
.45697 .22106 L
.45826 .30902 L
.45943 .30902 L
.46053 .30902 L
.46172 .30902 L
.46296 .30902 L
.46409 .30902 L
.46531 .30902 L
.466 .30902 L
.46663 .30902 L
.46778 .30902 L
.46899 .30902 L
.47005 .30902 L
.47122 .30902 L
.47188 .30902 L
.47257 .30902 L
.47381 .30902 L
.4745 .30902 L
.47514 .30902 L
.47585 .30902 L
.4766 .30902 L
.47726 .30902 L
.47796 .30902 L
.47925 .30902 L
.4805 .30902 L
.48166 .30902 L
.48287 .30902 L
.48417 .30902 L
.4854 .30902 L
.48653 .30902 L
.48784 .30902 L
.48859 .30902 L
Mistroke
.48928 .30902 L
.49054 .30902 L
.49125 .30902 L
.49189 .30902 L
.49257 .30902 L
.49329 .30902 L
.49457 .30902 L
.49529 .30902 L
.49595 .30902 L
.49673 .30902 L
.49747 .30902 L
.4981 .30902 L
.4988 .30902 L
.5 .30902 L
.50069 .30902 L
.50142 .30902 L
.50272 .30902 L
.50386 .30902 L
.50511 .30902 L
.50641 .30902 L
.50762 .30902 L
.50876 .30902 L
.5098 .30902 L
.51099 .30902 L
.51212 .30902 L
.51334 .30902 L
.51464 .30902 L
.51575 .30902 L
.51697 .30902 L
.51828 .30902 L
.51902 .30902 L
.51969 .30902 L
.52099 .30902 L
.52223 .30902 L
.52328 .30902 L
.52443 .30902 L
.52564 .30902 L
.52678 .30902 L
.52783 .30902 L
.5288 .30902 L
.52987 .30902 L
.53099 .30902 L
.53213 .30902 L
.53334 .30902 L
.53449 .30902 L
.53554 .30902 L
.53677 .30902 L
.53746 .30902 L
.5381 .30902 L
.53928 .30902 L
Mistroke
.54052 .30902 L
.54173 .30902 L
.54305 .30902 L
.54429 .30902 L
.54544 .30902 L
.54659 .30902 L
.54762 .30902 L
.54882 .30902 L
.54994 .30902 L
.55127 .30902 L
.55251 .30902 L
.5538 .30902 L
.55449 .30902 L
.55522 .30902 L
.55652 .30902 L
.55776 .30902 L
.55887 .30902 L
.56007 .30902 L
.56113 .30902 L
.56229 .30902 L
.5635 .30902 L
.56464 .30902 L
.5657 .30902 L
.56668 .30902 L
.56774 .30902 L
.56887 .30902 L
.57001 .30902 L
.57122 .30902 L
.57237 .30902 L
.57341 .30902 L
.57464 .30902 L
.57533 .30902 L
.57597 .30902 L
.57714 .30902 L
.57838 .30902 L
.57959 .30902 L
.58091 .30902 L
.58216 .30902 L
.58331 .30902 L
.58446 .30902 L
.5855 .30902 L
.5867 .30902 L
.58782 .30902 L
.58906 .30902 L
.59037 .30902 L
.59148 .30902 L
.5927 .30902 L
.59402 .30902 L
.59474 .30902 L
.59543 .30902 L
Mistroke
.59606 .30902 L
.59676 .30902 L
.59797 .30902 L
.5991 .30902 L
.60017 .30902 L
.60133 .30902 L
.60259 .30902 L
.6039 .30902 L
.60515 .30902 L
.60627 .30902 L
.60749 .30902 L
.60865 .30902 L
.6097 .30902 L
.61091 .30902 L
.61205 .30902 L
.61311 .30902 L
.61408 .30902 L
.61515 .30902 L
.61628 .30902 L
.6175 .30902 L
.61819 .30902 L
.61883 .30902 L
.62 .30902 L
.62124 .30902 L
.62235 .30902 L
.62339 .30902 L
.62453 .30902 L
.62576 .30902 L
.62834 .30902 L
.62902 .30902 L
.62974 .30902 L
.63105 .30902 L
.63225 .30902 L
.63337 .30902 L
.63401 .30902 L
.6347 .30902 L
.63591 .30902 L
.63707 .30902 L
.63831 .30902 L
.63948 .30902 L
.64054 .30902 L
.64174 .30902 L
.64288 .30902 L
.64411 .30902 L
.6448 .30902 L
.64545 .30902 L
.6466 .30902 L
.64768 .30902 L
.64866 .30902 L
.64971 .30902 L
Mistroke
.65086 .30902 L
.65207 .30902 L
.65311 .30902 L
.65424 .30902 L
.65555 .30902 L
.65676 .30902 L
.65739 .30902 L
.65809 .30902 L
.65882 .30902 L
.6595 .30902 L
.66075 .30902 L
.66189 .30902 L
.66315 .30902 L
.66447 .30902 L
.66559 .30902 L
.66678 .30902 L
.6679 .30902 L
.66892 .30902 L
.67012 .30902 L
.67142 .30902 L
.67265 .30902 L
.67378 .30902 L
.67499 .30902 L
.67629 .30902 L
.67751 .30902 L
.67863 .30902 L
.67994 .30902 L
.68068 .30902 L
.68136 .30902 L
.68262 .30902 L
.68325 .30902 L
.68395 .30902 L
.68463 .30902 L
.68534 .30902 L
.68662 .30902 L
.68733 .30902 L
.68799 .30902 L
.68872 .30902 L
.6895 .30902 L
.69017 .30902 L
.6909 .30902 L
.69159 .30902 L
.69223 .30902 L
.69343 .30902 L
.69471 .30902 L
.69591 .30902 L
.69723 .30902 L
.69847 .30902 L
.69963 .30902 L
.70077 .30902 L
Mistroke
.7018 .30902 L
.703 .30902 L
.70412 .30902 L
.70536 .30902 L
.70666 .30902 L
.70777 .30902 L
.70899 .30902 L
.7103 .30902 L
.71104 .30902 L
.71171 .30902 L
.71301 .30902 L
.71425 .30902 L
.7153 .30902 L
.71646 .30902 L
.71767 .30902 L
.7188 .30902 L
.71986 .30902 L
.72083 .30902 L
.7219 .30902 L
.72302 .30902 L
.72416 .30902 L
.72538 .30902 L
.72653 .30902 L
.72757 .30902 L
.7288 .30902 L
.72949 .30902 L
.73013 .30902 L
.73131 .30902 L
.73255 .30902 L
.73376 .30902 L
.73508 .30902 L
.73633 .30902 L
.73748 .30902 L
.73863 .30902 L
.73967 .30902 L
.74087 .30902 L
.74199 .30902 L
.74323 .30902 L
.74453 .30902 L
.74565 .30902 L
.74687 .30902 L
.75213 .30902 L
.76154 .30902 L
.7627 .30902 L
.76379 .30902 L
.76492 .30902 L
.76617 .30902 L
.76725 .30902 L
.76823 .30902 L
.76937 .30902 L
Mistroke
.77045 .30902 L
.77166 .30902 L
.77279 .30902 L
.77403 .30902 L
.77535 .30902 L
.77604 .30902 L
.77679 .30902 L
.7775 .30902 L
.77815 .30902 L
.77938 .30902 L
.78068 .30902 L
.78179 .30902 L
.78298 .30902 L
.7841 .30902 L
.78512 .30902 L
.78632 .30902 L
.78763 .30902 L
.79 .30902 L
.81093 .30902 L
.85169 .30902 L
.89093 .30902 L
.92866 .30902 L
.96883 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo0022oooo00<0I_ooooooool0Dooo
o`030000oooooooo04Goool007koool506KoEOooo`030000oooooooo04Goool007_oool306Ko1?oo
o`0306Kooooooooo05?oool00`000?ooooooo`15oooo001hoooo0`1Vo`Ooool00`1Vooooooooo`1C
oooo00<0003oooooool0AOooo`00M_ooo`80I_l:oooo00<0I_ooooooool0Doooo`030000oooooooo
04Goool007;oool406Ko3?ooo`0306Kooooooooo05?oool00`000?ooooooo`15oooo001]oooo1@1V
oa3oool00`1Vooooooooo`1Coooo00<0003oooooool0AOooo`00J?ooo`D0I_lEoooo00<0I_oooooo
ool0Doooo`800016oooo001Soooo1@1Voa[oool00`1Vooooooooo`1Coooo00<0003oooooool0AOoo
o`00GOooo`H0I_lOoooo00<0I_ooooooool0Doooo`030000oooooooo04Goool005Soool506Ko9Ooo
o`0306Kooooooooo05?oool00`000?ooooooo`15oooo001Boooo1P1Vob[oool00`1Vooooooooo`1C
oooo00<0003oooooool0AOooo`004_ooo`@0000Xoooo1@0000;oool200001?ooo`80000506Ko9?oo
o`D00008oooo00<0I_ooooooool07?ooo`800004oooo0P0000Coool20000:?ooo`030000oooooooo
02Soool200001?ooo`800004oooo0P0000ooool001;oool00`000?ooooooo`0[oooo00<0003ooooo
ool01Oooo`80I_l01000001Vo`1Vo`0002[oool00`000?ooooooo`08oooo00<0I_ooooooool06ooo
o`040000oooooooo00002?ooo`040000oooooooo00009oooo`030000oooooooo02Ooool010000?oo
ooooo`0000Soool010000?ooooooo`0000koool001?oool00`000?ooooooo`0Zoooo00<00000I_l0
I_l01@1Vo`Goool00`000?ooooooo`0Xoooo00<0003oooooool02?ooo`0306Kooooooooo01_oool0
10000?ooooooo`0000_oool00`000?ooooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo
00002oooo`030000oooooooo00coool000coool400001?ooo`030000oooooooo023oool00`1Vo`00
000000020000101Vo`030000oooooooo00Soool200008oooo`@00004oooo00<0003oooooool02?oo
o`0306Kooooooooo01Goool400000_ooo`040000oooooooo00002Oooo`80000Xoooo0P0002Soool0
10000?ooooooo`0000Woool200003oooo`004_ooo`040000oooooooo00005_ooo`/0I_l9oooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`08oooo00<0I_ooooooool06ooo
o`040000oooooooo00002Oooo`030000oooooooo02Ooool00`000?ooooooo`0Woooo00@0003ooooo
ool00009oooo00<0003oooooool03_ooo`004oooo`80000=oooo2P1Voa?oool200002_ooo`<0000Y
oooo0P0000[oool00`1Vooooooooo`0Loooo0P0000[oool300009oooo`030000oooooooo02Soool2
00002_ooo`<0000>oooo000Goooo2`1Vof7oool00`1Vooooooooo`1Boooo00<0003oooooool0AOoo
o`004Oooo`H0I_m/oooo00<0I_ooooooool0D_ooo`030000oooooooo04Goool008?oool00`1Voooo
ooooo`1Boooo00<0003oooooool0AOooo`00Poooo`0306Kooooooooo05;oool00`000?ooooooo`15
oooo0023oooo00<0I_ooooooool0D_ooo`030000oooooooo04Goool000_ooooo00001`0000ooool0
017oool00`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00040000<ol0<ol0o`2I1S?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0C
oooo000Aoooo00<0000co`0co`00;c?o00030000<ol0<ol002lco`000`0003?o03?o000:<ol000?o
09Tco`0co`008C?o00030000<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04ooo
o`004Oooog4co`000ol0VC?o03?o001C<ol000<0003oooooool0AOooo`004Oooog4co`000ol0VC?o
03?o001C<ol000<0003oooooool0AOooo`004Oooog4co`000ol0VC?o03?o001C<ol000<0003ooooo
ool0AOooo`004Oooog4co`000ol0VC?o03?o001C<ol000<0003oooooool0AOooo`004Oooog4co`00
0ol0VC?o03?o001C<ol000<0003oooooool0AOooo`004Oooog4co`000ol0VC?o03?o001C<ol00P00
04Koool0017oooma<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool0017oooma<ol000?o
09Tco`0co`00Dc?o00030000oooooooo04Goool0017oooma<ol000?o09Tco`0co`00Dc?o00030000
oooooooo04Goool0017oooma<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool0017oooma
<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool0017oooma<ol000?o09Tco`0co`00Dc?o
00030000oooooooo04Goool0017oooma<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool0
017oool20000Kc?o0003o`2I<ol0<ol005<co`020000A_ooo`004oooo`80001]<ol000?o09Tco`0c
o`00Dc?o00030000oooooooo04Goool001Goool20000Jc?o0003o`2I<ol0<ol005<co`000`000?oo
ooooo`15oooo000Goooo0P0006Tco`000ol0VC?o03?o001C<ol000<0003oooooool0AOooo`006Ooo
o`80001W<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool001_oool20000IC?o0003o`2I
<ol0<ol005<co`000`000?ooooooo`15oooo000Moooo0P0006<co`000ol0VC?o03?o001C<ol000<0
003oooooool0AOooo`007oooo`030000<ol0<ol0060co`000ol0VC?o03?o001C<ol000<0003ooooo
ool0AOooo`008?ooo`030000<ol0<ol005lco`000ol0VC?o03?o001C<ol00P0004Koool0027oool2
0000Gc?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo000Soooo00<0000co`0co`00G3?o
0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo000Toooo0P0005`co`000ol0VC?o03?o001C
<ol000<0003oooooool0AOooo`009_ooo`030000<ol0<ol005Tco`000ol0VC?o03?o001C<ol000<0
003oooooool0AOooo`009oooo`030000<ol0<ol005Pco`000ol0VC?o03?o001C<ol000<0003ooooo
ool0AOooo`00:?ooo`030000<ol0<ol005Lco`000ol0VC?o03?o000j<ol00P0000@co`02000013?o
00800003<ol0100000@co`000`000?ooooooo`15oooo000Yoooo00<0000co`0co`00ES?o0003o`2I
<ol0<ol003Tco`00100003?o03?o000000Pco`00100003?o03?o0000008co`000`0003?o03?o0005
<ol000<0003oooooool0AOooo`00:_ooo`030000<ol0<ol005Dco`000ol0VC?o03?o000i<ol000@0
000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00<00015oooo000[
oooo0P0005Dco`000ol0VC?o03?o000i<ol000@0000co`0co`000008<ol000@0000co`0co`000004
<ol000<0000co`0co`000c?o00030000oooooooo04Goool002goool00`0003?o03?o001B<ol000?o
09Tco`0co`00>C?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0
000013?o00030000oooooooo04Goool002koool00`0003?o03?o001A<ol000?o09Tco`0co`00>S?o
0080000:<ol00P0000@co`0200001C?o00030000oooooooo04Goool002ooool00`0003?o03?o001@
<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool0033oool00`0003?o03?o001?<ol000?o
09Tco`0co`00Dc?o00030000oooooooo04Goool0037oool00`0003?o03?o001><ol000?o09Tco`0c
o`00Dc?o00030000oooooooo04Goool003;oool00`0003?o03?o001=<ol000?o09Tco`0co`00Dc?o
00030000oooooooo04Goool003?oool00`0003?o03?o001<<ol000?o09Tco`0co`00Dc?o00800016
oooo000coooo00<0000co`0co`00C3?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo000d
oooo00<0000co`0co`00Bc?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo000eoooo00<0
000co`0co`00BS?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo000foooo00<0000co`0c
o`00BC?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo000goooo00<0000co`0co`00B3?o
0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo000hoooo00<0000co`0co`00Ac?o0003o`2I
<ol0<ol005<co`000`000?ooooooo`15oooo000hoooo00<0000co`0co`00Ac?o0003o`2I<ol0<ol0
05<co`000`000?ooooooo`15oooo000ioooo00<0000co`0co`00AS?o0003o`2I<ol0<ol005<co`02
0000A_ooo`00>_ooo`030000<ol0<ol004Dco`000ol0VC?o03?o001C<ol000<0003oooooool0AOoo
o`00>oooo`030000<ol0<ol004@co`000ol0VC?o03?o001C<ol000<0003oooooool0AOooo`00??oo
o`030000<ol0<ol004<co`000ol0VC?o03?o001C<ol000<0003oooooool0AOooo`00??ooo`030000
<ol0<ol004<co`000ol0VC?o03?o001C<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol0
048co`000ol0VC?o03?o001C<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol0048co`00
0ol0VC?o03?o001C<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol0044co`000ol0VC?o
03?o001C<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol0044co`000ol0VC?o03?o001C
<ol000<0003oooooool0AOooo`00?oooo`030000<ol0<ol0040co`000ol0VC?o03?o001C<ol00P00
04Koool003ooool00`0003?o03?o0010<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool0
043oool00`0003?o03?o000o<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool0047oool0
0`0003?o03?o000n<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool0047oool00`0003?o
03?o000n<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool004;oool00`0003?o03?o000m
<ol000?o09Tco`0co`00Dc?o00030000oooooooo04Goool004;oool00`0003?o03?o000m<ol000?o
09Tco`0co`00>S?o00800004<ol00P0000@co`0200001C?o00<00003<ol000<0003oooooool0AOoo
o`00@oooo`030000<ol0<ol003`co`000ol0VC?o03?o000i<ol000@0000co`0co`000008<ol000@0
000co`0co`000005<ol000<0000co`0co`000S?o00030000oooooooo04Goool004?oool00`0003?o
03?o000l<ol000?o09Tco`0co`00>C?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o
00D00003<ol00`0004Goool004Coool00`0003?o03?o000k<ol000?o09Tco`0co`00>C?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo
04Goool004Coool00`0003?o03?o000k<ol000?o09Tco`0co`00>C?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000c?o00030000<ol0000000@co`000`000?ooooooo`15oooo0015oooo00<0
000co`0co`00>S?o0003o`2I<ol0<ol003Xco`0200002S?o00800005<ol00P0000@co`000`000?oo
ooooo`15oooo0015oooo00<0000co`0co`00>S?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15
oooo0016oooo00<0000co`0co`00>C?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo0016
oooo00<0000co`0co`00>C?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo0017oooo00<0
000co`0co`00>3?o0003o`2I<ol0<ol005<co`000`000?ooooooo`15oooo0017oooo00<0000co`0c
o`00>3?o0003o`2I<ol0<ol005<co`020000A_ooo`00B?ooo`030000<ol0<ol003Lco`000ol0VC?o
03?o001C<ol000<0003oooooool0AOooo`00B?ooo`030000<ol0<ol003Lco`000ol0VC?o03?o001C
<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol003Hco`000ol0VC?o03?o001C<ol000<0
003oooooool0AOooo`00BOooo`030000<ol0<ol003Hco`000ol0VC?o03?o001C<ol000<0003ooooo
ool0AOooo`00B_ooo`030000<ol0<ol003Dco`000ol0VC?o03?o001C<ol000<0003oooooool0AOoo
o`00B_ooo`030000<ol0<ol003Dco`000ol0VC?o03?o001C<ol000<0003oooooool0AOooo`00Booo
o`030000<ol0<ol003@co`000ol0VC?o03?o001C<ol000<0003oooooool0AOooo`00Boooo`030000
<ol0<ol003@co`000ol0VC?o03?o001C<ol00P0004Koool004cooon<<ol0B?ooo`00C?oooh`co`18
oooo001<ooooS3?o04Soool004gooon;<ol0B?ooo`00COoooh/co`18oooo001>oooo:S?o00030000
<ol0<ol002Lco`000`0003?o03?o000c<ol0B?ooo`00C_ooobTco`000`0003?o03?o0008<ol000<0
000co`0co`007S?o00030000<ol0<ol0038co`18oooo001?oooo:3?o00030000<ol0<ol0008co`02
000013?o00030000<ol0<ol000Hco`02000013?o00800003<ol01@0000<co`0300000S?o00030000
<ol0<ol0038co`18oooo001?oooo:3?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002
<ol000<0000co`0co`0013?o00040000<ol0<ol000002S?o00030000<ol0<ol000@co`001@0003?o
03?o03?o0000000d<ol0B?ooo`00CoooobLco`000`0003?o03?o0002<ol000<0000co`0co`0033?o
00040000<ol0<ol000002S?o00040000<ol0<ol0<ol01@0000<co`000`0003?o03?o000a<ol0B?oo
o`00D?ooobLco`000`0003?o03?o000500002c?o00040000<ol0<ol000002S?o00050000<ol0<ol0
<ol00000008co`001@0003?o03?o03?o0000000d<ol0B?ooo`00D?ooobLco`001@0003?o03?o03?o
0000000><ol000@0000co`0co`00000:<ol000<0000co`0co`000S?o00030000<ol0000000<co`00
0`0003?o03?o000b<ol0B?ooo`00D?ooobPco`000`0003?o03?o000@<ol00P0000Xco`0200001C?o
00800002<ol000<0000co`0co`00<c?o04Soool0057ooon7<ol0B?ooo`00DOooohLco`18oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.45262 .30902 L
.45734 .30902 L
.45963 .30902 L
.46063 .30902 L
.46172 .30902 L
s
.46172 .30902 m
.46172 .61803 L
s
0 .4 1 r
.02381 .29039 m
.06244 .28752 L
.10458 .28387 L
.14415 .27988 L
.18221 .27544 L
.22272 .26997 L
.26171 .26385 L
.30316 .25627 L
.34309 .24774 L
.3815 .2382 L
.42237 .22634 L
.44268 .21969 L
.45262 .21624 L
.45734 .21455 L
.45963 .21372 L
.46063 .21335 L
.46172 .21296 L
.46283 .30902 L
.46388 .30902 L
.46508 .30902 L
.46618 .30902 L
.46731 .30902 L
.46856 .30902 L
.46985 .30902 L
.47106 .30902 L
.47221 .30902 L
.4733 .30902 L
.47428 .30902 L
.47535 .30902 L
.47651 .30902 L
.47774 .30902 L
.47879 .30902 L
.47994 .30902 L
.48118 .30902 L
.48248 .30902 L
.48359 .30902 L
.48481 .30902 L
.48612 .30902 L
.48686 .30902 L
.48753 .30902 L
.48883 .30902 L
.49006 .30902 L
.49121 .30902 L
.49243 .30902 L
.49347 .30902 L
.49461 .30902 L
.49584 .30902 L
.49716 .30902 L
.49841 .30902 L
.49955 .30902 L
Mistroke
.50084 .30902 L
.50206 .30902 L
.50315 .30902 L
.50433 .30902 L
.50562 .30902 L
.50627 .30902 L
.50699 .30902 L
.50825 .30902 L
.50942 .30902 L
.51061 .30902 L
.51174 .30902 L
.51275 .30902 L
.51384 .30902 L
.51504 .30902 L
.5163 .30902 L
.51738 .30902 L
.51857 .30902 L
.51989 .30902 L
.52055 .30902 L
.52127 .30902 L
.52254 .30902 L
.52373 .30902 L
.52445 .30902 L
.52514 .30902 L
.52641 .30902 L
.52713 .30902 L
.52779 .30902 L
.52851 .30902 L
.52928 .30902 L
.53047 .30902 L
.53175 .30902 L
.53296 .30902 L
.53406 .30902 L
.53535 .30902 L
.53608 .30902 L
.53676 .30902 L
.538 .30902 L
.53931 .30902 L
.54045 .30902 L
.54169 .30902 L
.54298 .30902 L
.54419 .30902 L
.54532 .30902 L
.54635 .30902 L
.54754 .30902 L
.54867 .30902 L
.54989 .30902 L
.55118 .30902 L
.55229 .30902 L
.55351 .30902 L
Mistroke
.55481 .30902 L
.55555 .30902 L
.55622 .30902 L
.55752 .30902 L
.55876 .30902 L
.55991 .30902 L
.56095 .30902 L
.56216 .30902 L
.56329 .30902 L
.56434 .30902 L
.56531 .30902 L
.56638 .30902 L
.5675 .30902 L
.56863 .30902 L
.56985 .30902 L
.571 .30902 L
.57204 .30902 L
.57327 .30902 L
.57396 .30902 L
.57461 .30902 L
.57578 .30902 L
.57703 .30902 L
.6148 .30902 L
.61612 .30902 L
.61736 .30902 L
.61805 .30902 L
.6188 .30902 L
.6201 .30902 L
.62503 .30902 L
.62632 .30902 L
.62753 .30902 L
.62879 .30902 L
.62945 .30902 L
.63017 .30902 L
.63095 .30902 L
.6317 .30902 L
.63237 .30902 L
.63309 .30902 L
.63377 .30902 L
.63449 .30902 L
.63579 .30902 L
.63709 .30902 L
.63829 .30902 L
.63961 .30902 L
.64027 .30902 L
.64099 .30902 L
.64222 .30902 L
.64353 .30902 L
.64476 .30902 L
.64589 .30902 L
Mistroke
.64814 .30902 L
.64941 .30902 L
.65058 .30902 L
.65161 .30902 L
.65274 .30902 L
.65392 .30902 L
.65502 .30902 L
.65626 .30902 L
.65741 .30902 L
.65867 .30902 L
.65938 .30902 L
.66001 .30902 L
.66119 .30902 L
.66246 .30902 L
.66366 .30902 L
.66476 .30902 L
.66583 .30902 L
.66682 .30902 L
.66792 .30902 L
.66909 .30902 L
.67367 .30902 L
.67492 .30902 L
.67563 .30902 L
.67627 .30902 L
.67747 .30902 L
.67872 .30902 L
.67994 .30902 L
.68063 .30902 L
.68127 .30902 L
.68199 .30902 L
.68263 .30902 L
.68338 .30902 L
.68409 .30902 L
.68526 .30902 L
.6865 .30902 L
.68872 .30902 L
.69373 .30902 L
.69493 .30902 L
.69607 .30902 L
.69738 .30902 L
.69857 .30902 L
.69989 .30902 L
.70063 .30902 L
.70132 .30902 L
.70257 .30902 L
.70327 .30902 L
.7039 .30902 L
.70459 .30902 L
.70533 .30902 L
.70664 .30902 L
Mistroke
.70737 .30902 L
.70805 .30902 L
.7088 .30902 L
.7096 .30902 L
.71029 .30902 L
.71104 .30902 L
.71175 .30902 L
.71241 .30902 L
.71365 .30902 L
.71496 .30902 L
.7162 .30902 L
.71734 .30902 L
.71859 .30902 L
.7199 .30902 L
.72105 .30902 L
.72211 .30902 L
.72328 .30902 L
.72453 .30902 L
.72524 .30902 L
.7259 .30902 L
.72662 .30902 L
.72738 .30902 L
.72866 .30902 L
.72938 .30902 L
.73006 .30902 L
.73133 .30902 L
.73248 .30902 L
.73312 .30902 L
.73382 .30902 L
.73508 .30902 L
.73629 .30902 L
.73741 .30902 L
.73863 .30902 L
.73991 .30902 L
.74104 .30902 L
.74208 .30902 L
.74323 .30902 L
.74446 .30902 L
.74511 .30902 L
.7458 .30902 L
.74655 .30902 L
.74725 .30902 L
.7485 .30902 L
.74922 .30902 L
.74989 .30902 L
.75113 .30902 L
.75226 .30902 L
.75358 .30902 L
.75482 .30902 L
.75734 .30902 L
Mistroke
.76003 .30902 L
.76133 .30902 L
.76256 .30902 L
.76367 .30902 L
.76486 .30902 L
.76555 .30902 L
.76618 .30902 L
.76689 .30902 L
.76764 .30902 L
.76836 .30902 L
.76914 .30902 L
.76988 .30902 L
.77057 .30902 L
.7712 .30902 L
.7719 .30902 L
.77263 .30902 L
.77331 .30902 L
.77452 .30902 L
.77582 .30902 L
.77707 .30902 L
.77822 .30902 L
.77953 .30902 L
.78078 .30902 L
.78193 .30902 L
.78299 .30902 L
.78416 .30902 L
.78539 .30902 L
.78664 .30902 L
.78733 .30902 L
.78797 .30902 L
.79038 .30902 L
.79586 .30902 L
.81697 .30902 L
.85673 .30902 L
.89499 .30902 L
.93569 .30902 L
.97488 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15
oooo0022oooo0`1Voe?oool00`000?ooooooo`15oooo0021oooo00@0I_ooooooool0I_mCoooo0P00
04Koool007koool306Ko0oooo`0306Kooooooooo057oool00`000?ooooooo`15oooo001koooo0`1V
o`Koool00`1Vooooooooo`1Aoooo00<0003oooooool0AOooo`00N?ooo`<0I_l9oooo00<0I_oooooo
ool0DOooo`030000oooooooo04Goool007Goool306Ko3?ooo`0306Kooooooooo057oool00`000?oo
ooooo`15oooo001aoooo101Vo`ooool00`1Vooooooooo`1Aoooo00<0003oooooool0AOooo`00KOoo
o`@0I_lCoooo00<0I_ooooooool0DOooo`030000oooooooo04Goool006Soool506Ko5oooo`0306Ko
oooooooo057oool00`000?ooooooo`15oooo001Soooo1@1Voacoool00`1Vooooooooo`1Aoooo0P00
04Koool005goool606Ko8Oooo`0306Kooooooooo057oool00`000?ooooooo`15oooo001Hoooo1@1V
obOoool00`1Vooooooooo`1Aoooo00<0003oooooool0AOooo`00D_ooo`H0I_l/oooo00<0I_oooooo
ool0DOooo`030000oooooooo04Goool004goool506Ko<_ooo`0306Kooooooooo057oool00`000?oo
ooooo`15oooo000Boooo100002Soool500000_ooo`8000001?ooo`1Vo`1Vo`1Vo`80000Yoooo1@00
00Woool00`1Vooooooooo`0Koooo0P0000Coool200001?ooo`80000Xoooo00<0003oooooool0:?oo
o`800004oooo0P0000Coool200003oooo`004_ooo`030000oooooooo02_oool00`00001Vo`1Vo`05
06Ko0_ooo`040000oooooooo0000:_ooo`030000oooooooo00Woool00`1Vooooooooo`0Joooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02?oool706Ko00<0003ooooo
ool02_ooo`030000oooooooo02Soool00`000?ooooooo`09oooo00<0I_ooooooool06_ooo`040000
oooooooo00002oooo`030000oooooooo02Goool00`000?ooooooo`0Woooo00@0003oooooool0000;
oooo00<0003oooooool03?ooo`003?ooo`@00004oooo00<0003oooooool07Oooo`@0I_l400001?oo
o`030000oooooooo00Soool200008oooo`@00004oooo00<0003oooooool02Oooo`0306Kooooooooo
01Coool400000_ooo`040000oooooooo00002Oooo`80000Xoooo0P0002Soool010000?ooooooo`00
00Woool200003oooo`004_ooo`040000oooooooo00005_ooo`P0I_l<oooo00<0003oooooool02?oo
o`030000oooooooo02[oool00`000?ooooooo`09oooo00<0I_ooooooool06_ooo`040000oooooooo
00002Oooo`030000oooooooo02Ooool00`000?ooooooo`0Woooo00@0003oooooool00009oooo00<0
003oooooool03_ooo`004oooo`80000=oooo2P1Voa?oool200002_ooo`<0000Yoooo0P0000_oool0
0`1Vooooooooo`0Koooo0P0000[oool300009oooo`030000oooooooo02Soool200002_ooo`<0000>
oooo000Aoooo4@1Vof;oool00`1Vooooooooo`1Aoooo00<0003oooooool0AOooo`00Q?ooo`0306Ko
oooooooo057oool00`000?ooooooo`15oooo0024oooo00<0I_ooooooool0DOooo`030000oooooooo
04Goool008Coool00`1Vooooooooo`1Aoooo00<0003oooooool0AOooo`00Q?ooo`0306Kooooooooo
057oool00`000?ooooooo`15oooo000;ooooo`0000L0000?oooo000Aoooo00<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0002<ol000?o
09Tco`0co`000S?o00030000<ol0<ol000Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000A
oooo00<0000co`0co`00;c?o00030000<ol0<ol002lco`000`0003?o03?o000<<ol000?o09Tco`0c
o`007c?o00030000<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Ooo
og<co`000ol0VC?o03?o001A<ol000<0003oooooool0AOooo`004Oooog<co`000ol0VC?o03?o001A
<ol000<0003oooooool0AOooo`004Oooog<co`000ol0VC?o03?o001A<ol000<0003oooooool0AOoo
o`004Oooog<co`000ol0VC?o03?o001A<ol000<0003oooooool0AOooo`004Oooog<co`000ol0VC?o
03?o001A<ol000<0003oooooool0AOooo`004Oooog<co`000ol0VC?o03?o001A<ol00P0004Koool0
017ooomc<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool0017ooomc<ol000?o09Tco`0c
o`00DC?o00030000oooooooo04Goool0017ooomc<ol000?o09Tco`0co`00DC?o00030000oooooooo
04Goool0017ooomc<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool0017ooomc<ol000?o
09Tco`0co`00DC?o00030000oooooooo04Goool0017ooomc<ol000?o09Tco`0co`00DC?o00030000
oooooooo04Goool0017ooomc<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool0017oool2
0000LC?o0003o`2I<ol0<ol0054co`020000A_ooo`004oooo`80001_<ol000?o09Tco`0co`00DC?o
00030000oooooooo04Goool001Goool20000KC?o0003o`2I<ol0<ol0054co`000`000?ooooooo`15
oooo000Goooo0P0006/co`000ol0VC?o03?o001A<ol000<0003oooooool0AOooo`006Oooo`80001Y
<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool001_oool20000Ic?o0003o`2I<ol0<ol0
054co`000`000?ooooooo`15oooo000Moooo0P0006Dco`000ol0VC?o03?o001A<ol000<0003ooooo
ool0AOooo`007oooo`030000<ol0<ol0068co`000ol0VC?o03?o001A<ol000<0003oooooool0AOoo
o`008?ooo`030000<ol0<ol0064co`000ol0VC?o03?o001A<ol00P0004Koool0027oool20000HC?o
0003o`2I<ol0<ol0054co`000`000?ooooooo`15oooo000Soooo00<0000co`0co`00GS?o0003o`2I
<ol0<ol0054co`000`000?ooooooo`15oooo000Toooo0P0005hco`000ol0VC?o03?o001A<ol000<0
003oooooool0AOooo`009_ooo`030000<ol0<ol005/co`000ol0VC?o03?o001A<ol000<0003ooooo
ool0AOooo`009oooo`030000<ol0<ol005Xco`000ol0VC?o03?o001A<ol000<0003oooooool0AOoo
o`00:?ooo`030000<ol0<ol005Tco`000ol0VC?o03?o000h<ol00P0000@co`02000013?o00800003
<ol0100000@co`000`000?ooooooo`15oooo000Yoooo00<0000co`0co`00F3?o0003o`2I<ol0<ol0
03Lco`00100003?o03?o000000Pco`00100003?o03?o0000008co`000`0003?o03?o0005<ol000<0
003oooooool0AOooo`00:_ooo`030000<ol0<ol005Lco`000ol0VC?o03?o000g<ol000@0000co`0c
o`000008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00<00015oooo000[oooo0P00
05Lco`000ol0VC?o03?o000g<ol000@0000co`0co`000008<ol000@0000co`0co`000004<ol000<0
000co`0co`000c?o00030000oooooooo04Goool002goool00`0003?o03?o001D<ol000?o09Tco`0c
o`00=c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o
00030000oooooooo04Goool002koool00`0003?o03?o001C<ol000?o09Tco`0co`00>3?o0080000:
<ol00P0000@co`0200001C?o00030000oooooooo04Goool002ooool00`0003?o03?o001B<ol000?o
09Tco`0co`00DC?o00030000oooooooo04Goool0033oool00`0003?o03?o001A<ol000?o09Tco`0c
o`00DC?o00030000oooooooo04Goool0037oool00`0003?o03?o001@<ol000?o09Tco`0co`00DC?o
00030000oooooooo04Goool003;oool00`0003?o03?o001?<ol000?o09Tco`0co`00DC?o00030000
oooooooo04Goool003?oool00`0003?o03?o001><ol000?o09Tco`0co`00DC?o00800016oooo000c
oooo00<0000co`0co`00CS?o0003o`2I<ol0<ol0054co`000`000?ooooooo`15oooo000doooo00<0
000co`0co`00CC?o0003o`2I<ol0<ol0054co`000`000?ooooooo`15oooo000eoooo00<0000co`0c
o`00C3?o0003o`2I<ol0<ol0054co`000`000?ooooooo`15oooo000foooo00<0000co`0co`00Bc?o
0003o`2I<ol0<ol0054co`000`000?ooooooo`15oooo000goooo00<0000co`0co`00BS?o0003o`2I
<ol0<ol0054co`000`000?ooooooo`15oooo000hoooo00<0000co`0co`00BC?o0003o`2I<ol0<ol0
054co`000`000?ooooooo`15oooo000hoooo00<0000co`0co`00BC?o0003o`2I<ol0<ol0054co`00
0`000?ooooooo`15oooo000ioooo00<0000co`0co`00B3?o0003o`2I<ol0<ol0054co`020000A_oo
o`00>_ooo`030000<ol0<ol004Lco`000ol0VC?o03?o001A<ol000<0003oooooool0AOooo`00>ooo
o`030000<ol0<ol004Hco`000ol0VC?o03?o001A<ol000<0003oooooool0AOooo`00??ooo`030000
<ol0<ol004Dco`000ol0VC?o03?o001A<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol0
04Dco`000ol0VC?o03?o001A<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol004@co`00
0ol0VC?o03?o001A<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol004@co`000ol0VC?o
03?o001A<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol004<co`000ol0VC?o03?o001A
<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol004<co`000ol0VC?o03?o001A<ol000<0
003oooooool0AOooo`00?oooo`030000<ol0<ol0048co`000ol0VC?o03?o001A<ol00P0004Koool0
03ooool00`0003?o03?o0012<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool0043oool0
0`0003?o03?o0011<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool0047oool00`0003?o
03?o0010<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool0047oool00`0003?o03?o0010
<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool004;oool00`0003?o03?o000o<ol000?o
09Tco`0co`00DC?o00030000oooooooo04Goool004;oool00`0003?o03?o000o<ol000?o09Tco`0c
o`00>3?o00800004<ol00P0000@co`0200001C?o00<00003<ol000<0003oooooool0AOooo`00@ooo
o`030000<ol0<ol003hco`000ol0VC?o03?o000g<ol000@0000co`0co`000008<ol000@0000co`0c
o`000005<ol000<0000co`0co`000S?o00030000oooooooo04Goool004?oool00`0003?o03?o000n
<ol000?o09Tco`0co`00=c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00D00003
<ol00`0004Goool004Coool00`0003?o03?o000m<ol000?o09Tco`0co`00=c?o00040000<ol0<ol0
000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool0
04Coool00`0003?o03?o000m<ol000?o09Tco`0co`00=c?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000c?o00030000<ol0000000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0c
o`00?3?o0003o`2I<ol0<ol003Pco`0200002S?o00800005<ol00P0000@co`000`000?ooooooo`15
oooo0015oooo00<0000co`0co`00?3?o0003o`2I<ol0<ol0054co`000`000?ooooooo`15oooo0016
oooo00<0000co`0co`00>c?o0003o`2I<ol0<ol0054co`000`000?ooooooo`15oooo0016oooo00<0
000co`0co`00>c?o0003o`2I<ol0<ol0054co`000`000?ooooooo`15oooo0017oooo00<0000co`0c
o`00>S?o0003o`2I<ol0<ol0054co`000`000?ooooooo`15oooo0017oooo00<0000co`0co`00>S?o
0003o`2I<ol0<ol0054co`020000A_ooo`00B?ooo`030000<ol0<ol003Tco`000ol0VC?o03?o001A
<ol000<0003oooooool0AOooo`00B?ooo`030000<ol0<ol003Tco`000ol0VC?o03?o001A<ol000<0
003oooooool0AOooo`00BOooo`030000<ol0<ol003Pco`000ol0VC?o03?o001A<ol000<0003ooooo
ool0AOooo`00BOooo`030000<ol0<ol003Pco`000ol0VC?o03?o001A<ol000<0003oooooool0AOoo
o`00B_ooo`030000<ol0<ol003Lco`000ol0VC?o03?o001A<ol000<0003oooooool0AOooo`00B_oo
o`030000<ol0<ol003Lco`000ol0VC?o03?o001A<ol000<0003oooooool0AOooo`00Boooo`030000
<ol0<ol003Hco`000ol0VC?o03?o001A<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol0
03Hco`000ol0VC?o03?o001A<ol00P0004Koool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001<
ooooS3?o04Soool004gooon;<ol0B?ooo`00COoooh/co`18oooo001>oooo:S?o00030000<ol0<ol0
02Lco`000`0003?o03?o000c<ol0B?ooo`00C_ooobTco`000`0003?o03?o0008<ol000<0000co`0c
o`007S?o00030000<ol0<ol0038co`18oooo001?oooo:3?o00030000<ol0<ol0008co`02000013?o
00030000<ol0<ol000Hco`02000013?o00800003<ol01@00008co`02000013?o00030000<ol0<ol0
038co`18oooo001?oooo:3?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0
000co`0co`0013?o00040000<ol0<ol000002S?o00050000<ol0<ol0<ol00000008co`001@0003?o
03?o03?o0000000d<ol0B?ooo`00CoooobLco`000`0003?o03?o0002<ol000<0000co`0co`0033?o
00040000<ol0<ol000002S?o00030000<ol0<ol000@co`000`0003?o03?o0002<ol000<0000co`0c
o`00<C?o04Soool0053ooolW<ol000<0000co`0co`001@0000/co`00100003?o03?o000000Xco`00
0`0003?o03?o0002<ol00P0000@co`000`0003?o03?o000b<ol0B?ooo`00D?ooobLco`001@0003?o
03?o03?o0000000><ol000@0000co`0co`00000:<ol000<0000co`0co`000S?o00030000<ol0<ol0
00<co`000`0003?o03?o000b<ol0B?ooo`00D?ooobPco`000`0003?o03?o000@<ol00P0000Xco`02
000013?o00<00002<ol000<0000co`0co`00<c?o04Soool0057ooon7<ol0B?ooo`00DOooohLco`18
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.45262 .30902 L
.45734 .30902 L
.46172 .30902 L
.46388 .30902 L
.46509 .30902 L
s
.46509 .30902 m
.46509 .61803 L
s
0 .4 1 r
.02381 .28913 m
.06244 .28606 L
.10458 .28217 L
.14415 .27791 L
.18221 .27317 L
.22272 .26732 L
.26171 .26079 L
.30316 .25269 L
.34309 .24359 L
.3815 .2334 L
.42237 .22074 L
.44268 .21364 L
.45262 .20995 L
.45734 .20815 L
.46172 .20645 L
.46388 .20559 L
.46509 .20511 L
.46618 .30902 L
.46739 .30902 L
.4687 .30902 L
.46993 .30902 L
.47106 .30902 L
.47213 .30902 L
.47312 .30902 L
.47421 .30902 L
.47538 .30902 L
.47661 .30902 L
.47777 .30902 L
.47881 .30902 L
.47994 .30902 L
.48117 .30902 L
.48249 .30902 L
.48374 .30902 L
.48488 .30902 L
.4861 .30902 L
.48738 .30902 L
.48869 .30902 L
.48944 .30902 L
.49013 .30902 L
.49136 .30902 L
.49252 .30902 L
.49356 .30902 L
.49468 .30902 L
.49591 .30902 L
.49722 .30902 L
.49833 .30902 L
.49955 .30902 L
.50085 .30902 L
.50205 .30902 L
.50336 .30902 L
Mistroke
.5041 .30902 L
.50476 .30902 L
.50599 .30902 L
.50668 .30902 L
.50731 .30902 L
.50848 .30902 L
.50971 .30902 L
.51082 .30902 L
.51201 .30902 L
.51312 .30902 L
.51414 .30902 L
.51534 .30902 L
.51664 .30902 L
.51787 .30902 L
.519 .30902 L
.5202 .30902 L
.52149 .30902 L
.52271 .30902 L
.52382 .30902 L
.52506 .30902 L
.52576 .30902 L
.52641 .30902 L
.52773 .30902 L
.52847 .30902 L
.52914 .30902 L
.52981 .30902 L
.53052 .30902 L
.53179 .30902 L
.5325 .30902 L
.53317 .30902 L
.53389 .30902 L
.53467 .30902 L
.53534 .30902 L
.53607 .30902 L
.53676 .30902 L
.5374 .30902 L
.53861 .30902 L
.53989 .30902 L
.54103 .30902 L
.54227 .30902 L
.54356 .30902 L
.54477 .30902 L
.5459 .30902 L
.54693 .30902 L
.54812 .30902 L
.54925 .30902 L
.55047 .30902 L
.55176 .30902 L
.55287 .30902 L
.55409 .30902 L
Mistroke
.55539 .30902 L
.55613 .30902 L
.5568 .30902 L
.5581 .30902 L
.55934 .30902 L
.56039 .30902 L
.56152 .30902 L
.56259 .30902 L
.56357 .30902 L
.56472 .30902 L
.56593 .30902 L
.56696 .30902 L
.56808 .30902 L
.56931 .30902 L
.57 .30902 L
.57063 .30902 L
.57178 .30902 L
.57302 .30902 L
.57425 .30902 L
.57538 .30902 L
.57646 .30902 L
.57761 .30902 L
.57875 .30902 L
.57999 .30902 L
.58129 .30902 L
.5825 .30902 L
.58364 .30902 L
.58467 .30902 L
.58587 .30902 L
.58699 .30902 L
.58822 .30902 L
.58951 .30902 L
.59062 .30902 L
.59184 .30902 L
.59315 .30902 L
.59388 .30902 L
.59456 .30902 L
.59586 .30902 L
.5971 .30902 L
.59825 .30902 L
.5993 .30902 L
.6005 .30902 L
.60164 .30902 L
.60269 .30902 L
.60366 .30902 L
.60472 .30902 L
.60585 .30902 L
.60698 .30902 L
.6082 .30902 L
.60935 .30902 L
Mistroke
.6104 .30902 L
.61162 .30902 L
.61232 .30902 L
.61296 .30902 L
.61413 .30902 L
.61538 .30902 L
.62022 .30902 L
.62155 .30902 L
.62227 .30902 L
.62296 .30902 L
.6236 .30902 L
.62429 .30902 L
.6255 .30902 L
.62666 .30902 L
.62794 .30902 L
.63052 .30902 L
.63513 .30902 L
.63624 .30902 L
.63744 .30902 L
.63858 .30902 L
.63964 .30902 L
.64087 .30902 L
.64217 .30902 L
.64326 .30902 L
.64447 .30902 L
.6456 .30902 L
.64664 .30902 L
.64778 .30902 L
.64898 .30902 L
.65002 .30902 L
.65099 .30902 L
.65206 .30902 L
.6532 .30902 L
.65451 .30902 L
.65571 .30902 L
.65703 .30902 L
.6577 .30902 L
.65843 .30902 L
.65966 .30902 L
.66098 .30902 L
.66223 .30902 L
.66337 .30902 L
.66454 .30902 L
.66563 .30902 L
.66683 .30902 L
.6681 .30902 L
.66932 .30902 L
.67046 .30902 L
.67149 .30902 L
.6726 .30902 L
Mistroke
.67391 .30902 L
.67513 .30902 L
.67583 .30902 L
.67646 .30902 L
.6772 .30902 L
.6779 .30902 L
.67857 .30902 L
.67929 .30902 L
.68057 .30902 L
.68197 .30902 L
.68271 .30902 L
.68348 .30902 L
.68476 .30902 L
.68593 .30902 L
.68703 .30902 L
.68824 .30902 L
.68955 .30902 L
.69029 .30902 L
.69095 .30902 L
.69225 .30902 L
.69348 .30902 L
.69472 .30902 L
.69591 .30902 L
.69656 .30902 L
.69727 .30902 L
.69851 .30902 L
.6997 .30902 L
.70096 .30902 L
.70203 .30902 L
.70322 .30902 L
.70444 .30902 L
.70575 .30902 L
.70699 .30902 L
.70813 .30902 L
.70938 .30902 L
.71009 .30902 L
.71075 .30902 L
.71145 .30902 L
.71209 .30902 L
.71283 .30902 L
.71352 .30902 L
.71459 .30902 L
.71576 .30902 L
.7169 .30902 L
.71813 .30902 L
.71927 .30902 L
.72032 .30902 L
.72137 .30902 L
.72238 .30902 L
.72353 .30902 L
Mistroke
.72476 .30902 L
.72592 .30902 L
.72697 .30902 L
.72821 .30902 L
.72891 .30902 L
.72955 .30902 L
.73074 .30902 L
.73198 .30902 L
.7332 .30902 L
.73389 .30902 L
.73453 .30902 L
.7357 .30902 L
.73694 .30902 L
.73805 .30902 L
.73909 .30902 L
.74024 .30902 L
.74147 .30902 L
.7427 .30902 L
.7434 .30902 L
.74405 .30902 L
.74536 .30902 L
.7461 .30902 L
.74677 .30902 L
.74797 .30902 L
.74927 .30902 L
.7505 .30902 L
.75163 .30902 L
.75268 .30902 L
.75367 .30902 L
.75482 .30902 L
.75587 .30902 L
.75702 .30902 L
.75828 .30902 L
.75945 .30902 L
.76054 .30902 L
.76177 .30902 L
.76293 .30902 L
.76398 .30902 L
.7651 .30902 L
.76634 .30902 L
.76764 .30902 L
.76875 .30902 L
.76996 .30902 L
.77119 .30902 L
.77249 .30902 L
.77316 .30902 L
.77391 .30902 L
.77522 .30902 L
.77646 .30902 L
.77716 .30902 L
Mistroke
.77779 .30902 L
.77903 .30902 L
.7802 .30902 L
.78132 .30902 L
.78251 .30902 L
.78363 .30902 L
.78465 .30902 L
.78586 .30902 L
.78716 .30902 L
.78952 .30902 L
.81045 .30902 L
.85143 .30902 L
.89089 .30902 L
.92884 .30902 L
.96924 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;ooool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00Q?ooo`0306Kooooooooo057oool00`000?ooooooo`15oooo0021
oooo101Voe?oool00`000?ooooooo`15oooo001noooo0`1Vo`?oool00`1Vooooooooo`1Aoooo00<0
003oooooool0AOooo`00Noooo`<0I_l6oooo00<0I_ooooooool0DOooo`800016oooo001hoooo0`1V
o`Woool00`1Vooooooooo`1Aoooo00<0003oooooool0AOooo`00MOooo`<0I_l<oooo00<0I_oooooo
ool0DOooo`030000oooooooo04Goool0077oool406Ko3oooo`0306Kooooooooo057oool00`000?oo
ooooo`15oooo001^oooo0`1Voa?oool00`1Vooooooooo`1Aoooo00<0003oooooool0AOooo`00Jooo
o`<0I_lFoooo00<0I_ooooooool0DOooo`030000oooooooo04Goool006Ooool406Ko6Oooo`0306Ko
oooooooo057oool00`000?ooooooo`15oooo001Soooo101Voagoool00`1Vooooooooo`1Aoooo00<0
003oooooool0AOooo`00GOooo`H0I_lQoooo00<0I_ooooooool0DOooo`800016oooo001Ioooo101V
obOoool00`1Vooooooooo`1Aoooo00<0003oooooool0AOooo`00EOooo`@0I_l[oooo00<0I_oooooo
ool0DOooo`030000oooooooo04Goool0057oool406Ko<?ooo`0306Kooooooooo053oool00`000?oo
ooooo`15oooo001;oooo1P1VocCoool00`1Vooooooooo`1@oooo00<0003oooooool0AOooo`004_oo
o`@0000Xoooo1@000080I_l20000101Vo`80000Yoooo1@0000[oool00`1Vooooooooo`0Joooo0P00
00Coool200001?ooo`80000Xoooo00<0003oooooool0:?ooo`800004oooo0P0000Coool200003ooo
o`004_ooo`030000oooooooo02Woool206Ko00<00000I_l0I_l01oooo`040000oooooooo0000:_oo
o`030000oooooooo00[oool00`1Vooooooooo`0Ioooo00@0003oooooool00008oooo00@0003ooooo
ool0000Woooo00<0003oooooool09oooo`040000oooooooo00002?ooo`040000oooooooo00003_oo
o`004oooo`030000oooooooo027oool706Ko0_ooo`030000oooooooo00[oool00`000?ooooooo`0X
oooo00<0003oooooool02_ooo`0306Kooooooooo01Woool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`030000oooooooo01Goool;06Ko00?oool0000000000P0000Coool00`000?oo
ooooo`08oooo0P0002?oool400001?ooo`030000oooooooo00[oool00`1Vooooooooo`0Coooo1000
00;oool010000?ooooooo`0000Woool20000:?ooo`80000Xoooo00@0003oooooool00009oooo0P00
00ooool001;oool010000?ooooooo`0000coool:06Ko5?ooo`030000oooooooo00Soool00`000?oo
ooooo`0Zoooo00<0003oooooool02_ooo`0306Kooooooooo01Woool010000?ooooooo`0000Woool0
0`000?ooooooo`0Woooo00<0003oooooool09oooo`040000oooooooo00002Oooo`030000oooooooo
00koool001?oool200000_ooo`/0I_lMoooo0P0000[oool30000:Oooo`80000<oooo00<0I_oooooo
ool06_ooo`80000:oooo0`0002Ooool00`000?ooooooo`0Xoooo0P0000[oool300003_ooo`004Ooo
o`H0I_m^oooo00<0I_ooooooool0D?ooo`030000oooooooo04Goool008Goool00`1Vooooooooo`1@
oooo00<0003oooooool0AOooo`00QOooo`0306Kooooooooo053oool00`000?ooooooo`15oooo0025
oooo00<0I_ooooooool0D?ooo`030000oooooooo04Goool008Goool00`1Vooooooooo`1@oooo00<0
003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`000S?o0003o`2I<ol0<ol0
008co`000`0003?o03?o0007<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool04oooo`004Oooo`030000
<ol0<ol002lco`000`0003?o03?o000_<ol000<0000co`0co`0033?o0003o`2I<ol0<ol001lco`00
0`0003?o03?o000_<ol000<0003oooooool0;oooo`030000oooooooo01?oool0017ooomc<ol000?o
09Tco`0co`00DC?o00030000oooooooo04Goool0017ooomc<ol000?o09Tco`0co`00DC?o00030000
oooooooo04Goool0017ooomc<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool0017ooomc
<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool0017ooomc<ol000?o09Tco`0co`00DC?o
00030000oooooooo04Goool0017ooomc<ol000?o09Tco`0co`00DC?o00800016oooo000AooooLc?o
0003o`2I<ol0<ol0054co`000`000?ooooooo`15oooo000AooooLc?o0003o`2I<ol0<ol0054co`00
0`000?ooooooo`15oooo000AooooLc?o0003o`2I<ol0<ol0054co`000`000?ooooooo`15oooo000A
ooooLc?o0003o`2I<ol0<ol0054co`000`000?ooooooo`15oooo000AooooLc?o0003o`2I<ol0<ol0
054co`000`000?ooooooo`15oooo000AooooLc?o0003o`2I<ol0<ol0054co`000`000?ooooooo`15
oooo000AooooLc?o0003o`2I<ol0<ol0054co`000`000?ooooooo`15oooo000Aoooo0P00074co`00
0ol0VC?o03?o001A<ol00P0004Koool001?oool20000Kc?o0003o`2I<ol0<ol0054co`000`000?oo
ooooo`15oooo000Eoooo0P0006dco`000ol0VC?o03?o001A<ol000<0003oooooool0AOooo`005ooo
o`80001[<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool001Woool20000JC?o0003o`2I
<ol0<ol0054co`000`000?ooooooo`15oooo000Koooo0P0006Lco`000ol0VC?o03?o001A<ol000<0
003oooooool0AOooo`007Oooo`80001U<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool0
01ooool00`0003?o03?o001R<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool0023oool0
0`0003?o03?o001Q<ol000?o09Tco`0co`00DC?o00800016oooo000Qoooo0P00064co`000ol0VC?o
03?o001A<ol000<0003oooooool0AOooo`008oooo`030000<ol0<ol005hco`000ol0VC?o03?o001A
<ol000<0003oooooool0AOooo`009?ooo`80001N<ol000?o09Tco`0co`00DC?o00030000oooooooo
04Goool002Koool00`0003?o03?o001K<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool0
02Ooool00`0003?o03?o001J<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool002Soool0
0`0003?o03?o001I<ol000?o09Tco`0co`00>3?o00800004<ol00P0000@co`0200000c?o00@00004
<ol000<0003oooooool0AOooo`00:Oooo`030000<ol0<ol005Pco`000ol0VC?o03?o000g<ol000@0
000co`0co`000008<ol000@0000co`0co`000002<ol000<0000co`0co`001C?o00030000oooooooo
04Goool002[oool00`0003?o03?o001G<ol000?o09Tco`0co`00=c?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000c?o00030000<ol0<ol000@co`030000AOooo`00:oooo`80001G<ol000?o
09Tco`0co`00=c?o00040000<ol0<ol0000023?o00040000<ol0<ol0000013?o00030000<ol0<ol0
00<co`000`000?ooooooo`15oooo000]oooo00<0000co`0co`00E3?o0003o`2I<ol0<ol003Lco`00
100003?o03?o000000Pco`00100003?o03?o0000008co`00100003?o03?o000000@co`000`000?oo
ooooo`15oooo000^oooo00<0000co`0co`00Dc?o0003o`2I<ol0<ol003Pco`0200002S?o00800004
<ol00P0000Dco`000`000?ooooooo`15oooo000_oooo00<0000co`0co`00DS?o0003o`2I<ol0<ol0
054co`000`000?ooooooo`15oooo000`oooo00<0000co`0co`00DC?o0003o`2I<ol0<ol0054co`00
0`000?ooooooo`15oooo000aoooo00<0000co`0co`00D3?o0003o`2I<ol0<ol0054co`000`000?oo
ooooo`15oooo000boooo00<0000co`0co`00Cc?o0003o`2I<ol0<ol0054co`000`000?ooooooo`15
oooo000coooo00<0000co`0co`00CS?o0003o`2I<ol0<ol0054co`020000A_ooo`00<oooo`030000
<ol0<ol004hco`000ol0VC?o03?o001A<ol000<0003oooooool0AOooo`00=?ooo`030000<ol0<ol0
04dco`000ol0VC?o03?o001A<ol000<0003oooooool0AOooo`00=Oooo`030000<ol0<ol004`co`00
0ol0VC?o03?o001A<ol000<0003oooooool0AOooo`00=_ooo`030000<ol0<ol004/co`000ol0VC?o
03?o001A<ol000<0003oooooool0AOooo`00=oooo`030000<ol0<ol004Xco`000ol0VC?o03?o001A
<ol000<0003oooooool0AOooo`00>?ooo`030000<ol0<ol004Tco`000ol0VC?o03?o001A<ol000<0
003oooooool0AOooo`00>?ooo`030000<ol0<ol004Tco`000ol0VC?o03?o001A<ol000<0003ooooo
ool0AOooo`00>Oooo`030000<ol0<ol004Pco`000ol0VC?o03?o001A<ol00P0004Koool003[oool0
0`0003?o03?o0017<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool003_oool00`0003?o
03?o0016<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool003coool00`0003?o03?o0015
<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool003coool00`0003?o03?o0015<ol000?o
09Tco`0co`00DC?o00030000oooooooo04Goool003goool00`0003?o03?o0014<ol000?o09Tco`0c
o`00DC?o00030000oooooooo04Goool003goool00`0003?o03?o0014<ol000?o09Tco`0co`00DC?o
00030000oooooooo04Goool003koool00`0003?o03?o0013<ol000?o09Tco`0co`00DC?o00030000
oooooooo04Goool003koool00`0003?o03?o0013<ol000?o09Tco`0co`00DC?o00030000oooooooo
04Goool003ooool00`0003?o03?o0012<ol000?o09Tco`0co`00DC?o00800016oooo000ooooo00<0
000co`0co`00@S?o0003o`2I<ol0<ol0054co`000`000?ooooooo`15oooo0010oooo00<0000co`0c
o`00@C?o0003o`2I<ol0<ol0054co`000`000?ooooooo`15oooo0011oooo00<0000co`0co`00@3?o
0003o`2I<ol0<ol0054co`000`000?ooooooo`15oooo0011oooo00<0000co`0co`00@3?o0003o`2I
<ol0<ol0054co`000`000?ooooooo`15oooo0012oooo00<0000co`0co`00?c?o0003o`2I<ol0<ol0
054co`000`000?ooooooo`15oooo0012oooo00<0000co`0co`00?c?o0003o`2I<ol0<ol003Pco`02
000013?o00800004<ol00P0000Dco`0300000c?o00030000oooooooo04Goool004?oool00`0003?o
03?o000n<ol000?o09Tco`0co`00=c?o00040000<ol0<ol0000023?o00040000<ol0<ol000001C?o
00030000<ol0<ol0008co`000`000?ooooooo`15oooo0013oooo00<0000co`0co`00?S?o0003o`2I
<ol0<ol003Lco`00100003?o03?o000000Pco`00100003?o03?o0000008co`0500000c?o00<00015
oooo0014oooo00<0000co`0co`00?C?o0003o`2I<ol0<ol003Lco`00100003?o03?o000000Pco`00
100003?o03?o0000008co`00100003?o03?o000000@co`000`000?ooooooo`15oooo0014oooo00<0
000co`0co`00?C?o0003o`2I<ol0<ol003Lco`00100003?o03?o000000Pco`00100003?o03?o0000
00<co`000`0003?o00000004<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol003`co`00
0ol0VC?o03?o000h<ol00P0000Xco`0200001C?o00800004<ol000<0003oooooool0AOooo`00AOoo
o`030000<ol0<ol003`co`000ol0VC?o03?o001A<ol000<0003oooooool0AOooo`00A_ooo`030000
<ol0<ol003/co`000ol0VC?o03?o001A<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol0
03/co`000ol0VC?o03?o001A<ol000<0003oooooool0AOooo`00Aoooo`030000<ol0<ol003Xco`00
0ol0VC?o03?o001A<ol000<0003oooooool0AOooo`00Aoooo`030000<ol0<ol003Xco`000ol0VC?o
03?o001A<ol00P0004Koool004Soool00`0003?o03?o000i<ol000?o09Tco`0co`00DC?o00030000
oooooooo04Goool004Soool00`0003?o03?o000i<ol000?o09Tco`0co`00DC?o00030000oooooooo
04Goool004Woool00`0003?o03?o000h<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool0
04Woool00`0003?o03?o000h<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool004[oool0
0`0003?o03?o000g<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool004[oool00`0003?o
03?o000g<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool004_oool00`0003?o03?o000f
<ol000?o09Tco`0co`00DC?o00030000oooooooo04Goool004_oool00`0003?o03?o000f<ol000?o
09Tco`0co`00DC?o00800016oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00C?oooh`co`18
oooo001=ooooRc?o04Soool004gooon;<ol0B?ooo`00C_ooobXco`000`0003?o03?o000W<ol000<0
000co`0co`00<c?o04Soool004kooolY<ol000<0000co`0co`0023?o00030000<ol0<ol001hco`00
0`0003?o03?o000b<ol0B?ooo`00CoooobPco`000`0003?o03?o0002<ol00P0000@co`000`0003?o
03?o0006<ol00P0000@co`0200000c?o00D0000013?o00000000000000@co`000`0003?o03?o000b
<ol0B?ooo`00CoooobPco`001@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o00030000
<ol0<ol000@co`00100003?o03?o000000Xco`001@0003?o03?o03?o00000002<ol000D0000co`0c
o`0co`000000=3?o04Soool004oooolW<ol000<0000co`0co`000S?o00030000<ol0<ol000`co`00
100003?o03?o000000Xco`001@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o00030000
<ol0<ol0034co`18oooo001@oooo9c?o00030000<ol0<ol000D0000;<ol000@0000co`0co`00000:
<ol000@0000co`0co`0co`03000013?o00030000<ol0<ol0038co`18oooo001@oooo9c?o00050000
<ol0<ol0<ol0000000hco`00100003?o03?o000000Xco`000`0003?o03?o0002<ol000<0000co`0c
o`000c?o00030000<ol0<ol0038co`18oooo001@oooo:3?o00030000<ol0<ol0010co`0200002S?o
00800004<ol00`00008co`000`0003?o03?o000c<ol0B?ooo`00DOooohLco`18oooo001AooooQc?o
04Soool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.17) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.45262 .30902 L
.46172 .30902 L
.46618 .30902 L
.46741 .30902 L
.46871 .30902 L
s
.46871 .30902 m
.46872 .61803 L
s
0 .4 1 r
.02381 .28787 m
.06244 .2846 L
.10458 .28046 L
.14415 .27593 L
.18221 .27089 L
.22272 .26467 L
.26171 .25772 L
.30316 .24911 L
.34309 .23942 L
.3815 .22858 L
.42237 .21512 L
.44268 .20757 L
.45262 .20365 L
.46172 .19992 L
.46618 .19803 L
.46741 .19751 L
.46871 .19695 L
.46994 .30902 L
.47106 .30902 L
.47213 .30902 L
.47326 .30902 L
.4745 .30902 L
.47564 .30902 L
.4767 .30902 L
.47769 .30902 L
.47878 .30902 L
.47994 .30902 L
.48125 .30902 L
.48247 .30902 L
.4831 .30902 L
.4838 .30902 L
.48453 .30902 L
.48521 .30902 L
.48646 .30902 L
.48761 .30902 L
.48887 .30902 L
.48951 .30902 L
.4902 .30902 L
.49143 .30902 L
.49254 .30902 L
.49383 .30902 L
.49504 .30902 L
.49617 .30902 L
.49721 .30902 L
.49835 .30902 L
.49955 .30902 L
.50076 .30902 L
.50208 .30902 L
.50333 .30902 L
.50448 .30902 L
Mistroke
.50563 .30902 L
.50666 .30902 L
.50786 .30902 L
.50899 .30902 L
.51022 .30902 L
.51153 .30902 L
.51264 .30902 L
.51386 .30902 L
.51518 .30902 L
.5159 .30902 L
.51659 .30902 L
.51722 .30902 L
.51792 .30902 L
.51913 .30902 L
.52026 .30902 L
.52132 .30902 L
.52249 .30902 L
.52374 .30902 L
.52499 .30902 L
.5263 .30902 L
.52742 .30902 L
.52864 .30902 L
.5298 .30902 L
.53085 .30902 L
.53206 .30902 L
.5332 .30902 L
.53426 .30902 L
.53524 .30902 L
.53631 .30902 L
.53744 .30902 L
.53865 .30902 L
.53934 .30902 L
.53998 .30902 L
.54115 .30902 L
.54239 .30902 L
.54349 .30902 L
.54453 .30902 L
.54567 .30902 L
.5469 .30902 L
.54813 .30902 L
.54883 .30902 L
.54948 .30902 L
.55079 .30902 L
.55153 .30902 L
.55219 .30902 L
.55339 .30902 L
.55469 .30902 L
.55592 .30902 L
.55705 .30902 L
.55811 .30902 L
Mistroke
.55924 .30902 L
.56129 .30902 L
.56254 .30902 L
.56372 .30902 L
.56479 .30902 L
.56595 .30902 L
.57538 .30902 L
.5807 .30902 L
.58197 .30902 L
.58261 .30902 L
.58331 .30902 L
.58455 .30902 L
.58571 .30902 L
.58684 .30902 L
.58788 .30902 L
.58907 .30902 L
.5902 .30902 L
.59141 .30902 L
.59253 .30902 L
.59376 .30902 L
.59507 .30902 L
.59636 .30902 L
.59754 .30902 L
.59884 .30902 L
.5995 .30902 L
.60021 .30902 L
.60142 .30902 L
.60271 .30902 L
.60393 .30902 L
.60504 .30902 L
.60573 .30902 L
.60645 .30902 L
.60776 .30902 L
.60848 .30902 L
.60916 .30902 L
.6099 .30902 L
.6107 .30902 L
.61139 .30902 L
.61213 .30902 L
.61284 .30902 L
.61349 .30902 L
.61473 .30902 L
.61604 .30902 L
.6167 .30902 L
.6174 .30902 L
.61866 .30902 L
.61998 .30902 L
.62074 .30902 L
.62142 .30902 L
.62264 .30902 L
Mistroke
.62396 .30902 L
.62521 .30902 L
.62637 .30902 L
.62701 .30902 L
.62769 .30902 L
.62894 .30902 L
.6297 .30902 L
.63042 .30902 L
.63107 .30902 L
.63178 .30902 L
.63253 .30902 L
.63321 .30902 L
.634 .30902 L
.63475 .30902 L
.63544 .30902 L
.63608 .30902 L
.63677 .30902 L
.63751 .30902 L
.63877 .30902 L
.63991 .30902 L
.64123 .30902 L
.64249 .30902 L
.64364 .30902 L
.64471 .30902 L
.64589 .30902 L
.64713 .30902 L
.64838 .30902 L
.64972 .30902 L
.65099 .30902 L
.65215 .30902 L
.65344 .30902 L
.65418 .30902 L
.65485 .30902 L
.65557 .30902 L
.65633 .30902 L
.65703 .30902 L
.6577 .30902 L
.65885 .30902 L
.66009 .30902 L
.66126 .30902 L
.66232 .30902 L
.66357 .30902 L
.66428 .30902 L
.66493 .30902 L
.66613 .30902 L
.66741 .30902 L
.66811 .30902 L
.66875 .30902 L
.66945 .30902 L
.67019 .30902 L
Mistroke
.67144 .30902 L
.67216 .30902 L
.67281 .30902 L
.67403 .30902 L
.67534 .30902 L
.67655 .30902 L
.6777 .30902 L
.67876 .30902 L
.67993 .30902 L
.68115 .30902 L
.6823 .30902 L
.68336 .30902 L
.68434 .30902 L
.68542 .30902 L
.68654 .30902 L
.68769 .30902 L
.68892 .30902 L
.69008 .30902 L
.69113 .30902 L
.69237 .30902 L
.69307 .30902 L
.69372 .30902 L
.6949 .30902 L
.69615 .30902 L
.69737 .30902 L
.69869 .30902 L
.69994 .30902 L
.7011 .30902 L
.70213 .30902 L
.70328 .30902 L
.70448 .30902 L
.70561 .30902 L
.70685 .30902 L
.70815 .30902 L
.70927 .30902 L
.71049 .30902 L
.71576 .30902 L
.73408 .30902 L
.73529 .30902 L
.73642 .30902 L
.7376 .30902 L
.73891 .30902 L
.74022 .30902 L
.74096 .30902 L
.74163 .30902 L
.74292 .30902 L
.74414 .30902 L
.74529 .30902 L
.7465 .30902 L
.74765 .30902 L
Mistroke
.74869 .30902 L
.74995 .30902 L
.75058 .30902 L
.75128 .30902 L
.75251 .30902 L
.75366 .30902 L
.75497 .30902 L
.7557 .30902 L
.75637 .30902 L
.75709 .30902 L
.75788 .30902 L
.75862 .30902 L
.7593 .30902 L
.76052 .30902 L
.76183 .30902 L
.76258 .30902 L
.76327 .30902 L
.76393 .30902 L
.76462 .30902 L
.76582 .30902 L
.76693 .30902 L
.76815 .30902 L
.76946 .30902 L
.77012 .30902 L
.77084 .30902 L
.77215 .30902 L
.7746 .30902 L
.77581 .30902 L
.77695 .30902 L
.77759 .30902 L
.77828 .30902 L
.77949 .30902 L
.78064 .30902 L
.78186 .30902 L
.78406 .30902 L
.78472 .30902 L
.78542 .30902 L
.78618 .30902 L
.78688 .30902 L
.78953 .30902 L
.79448 .30902 L
.81552 .30902 L
.85355 .30902 L
.89404 .30902 L
.93301 .30902 L
.97443 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.17) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo002hoooo100000;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00__oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool008Goool00`1Vooooooooo`0goooo0P0000[oool200001?ooo`800005oooo00<0
003oooooool0AOooo`00Poooo`<0I_mBoooo00<0003oooooool0AOooo`00POooo`80I_l2oooo00<0
I_ooooooool0D?ooo`030000oooooooo04Goool007koool306Ko1?ooo`0306Kooooooooo053oool0
0`000?ooooooo`15oooo001koooo0`1Vo`Ooool00`1Vooooooooo`1@oooo00<0003oooooool0AOoo
o`00N?ooo`<0I_l:oooo00<0I_ooooooool0D?ooo`800016oooo001eoooo0`1Vo`goool00`1Voooo
ooooo`1@oooo00<0003oooooool0AOooo`00LOooo`@0I_l@oooo00<0I_ooooooool0D?ooo`030000
oooooooo04Goool006koool306Ko5?ooo`0306Kooooooooo053oool00`000?ooooooo`15oooo001[
oooo0`1VoaOoool00`1Vooooooooo`1@oooo00<0003oooooool0AOooo`00Ioooo`@0I_lJoooo00<0
I_ooooooool0D?ooo`030000oooooooo04Goool006Coool306Ko7_ooo`0306Kooooooooo053oool0
0`000?ooooooo`15oooo001Poooo101Vob7oool00`1Vooooooooo`1@oooo00<0003oooooool0AOoo
o`00G?ooo`@0I_lUoooo00<0I_ooooooool0D?ooo`800016oooo001Hoooo101VobWoool00`1Voooo
ooooo`1@oooo00<0003oooooool0AOooo`00D_ooo`H0I_l^oooo00<0I_ooooooool0Coooo`030000
oooooooo04Goool004goool506Ko=?ooo`0306Kooooooooo04ooool00`000?ooooooo`15oooo0018
oooo1@1VocWoool00`1Vooooooooo`1?oooo00<0003oooooool0AOooo`004_ooo`@0000Xoooo1@00
0080I_l2000000@0I_ooooooooooool20000:Oooo`D0000;oooo00<0I_ooooooool06Oooo`800004
oooo0P0000Coool20000:?ooo`030000oooooooo02Soool200001?ooo`800004oooo0P0000ooool0
01;oool00`000?ooooooo`0Roooo2@1Vo`030000oooooooo00Ooool010000?ooooooo`0002[oool0
0`000?ooooooo`0;oooo00<0I_ooooooool06?ooo`040000oooooooo00002?ooo`040000oooooooo
00009oooo`030000oooooooo02Ooool010000?ooooooo`0000Soool010000?ooooooo`0000koool0
01?oool00`000?ooooooo`0Ioooo201Vo`Woool00`000?ooooooo`0:oooo00<0003oooooool0:?oo
o`030000oooooooo00_oool00`1Vooooooooo`0Hoooo00@0003oooooool0000;oooo00<0003ooooo
ool09Oooo`030000oooooooo02Ooool010000?ooooooo`0000_oool00`000?ooooooo`0<oooo000<
oooo100000Coool00`000?ooooooo`0Boooo1P1Vo`Woool400001?ooo`030000oooooooo00Soool2
00008oooo`@00004oooo00<0003oooooool02oooo`0306Kooooooooo01;oool400000_ooo`040000
oooooooo00002Oooo`80000Xoooo0P0002Soool010000?ooooooo`0000Woool200003oooo`004_oo
o`040000oooooooo00003?ooo`L0I_lGoooo00<0003oooooool02?ooo`030000oooooooo02[oool0
0`000?ooooooo`0;oooo00<0I_ooooooool06?ooo`040000oooooooo00002Oooo`030000oooooooo
02Ooool00`000?ooooooo`0Woooo00@0003oooooool00009oooo00<0003oooooool03_ooo`004ooo
o`800002oooo2`1Voagoool200002_ooo`<0000Yoooo0P0000goool00`1Vooooooooo`0Ioooo0P00
00[oool300009oooo`030000oooooooo02Soool200002_ooo`<0000>oooo000Aoooo1P1Vofooool0
0`1Vooooooooo`1?oooo00<0003oooooool0AOooo`00Q_ooo`0306Kooooooooo04ooool00`000?oo
ooooo`15oooo0026oooo00<0I_ooooooool0Coooo`030000oooooooo04Goool008Koool00`1Voooo
ooooo`1?oooo00<0003oooooool0AOooo`00Q_ooo`0306Kooooooooo04ooool00`000?ooooooo`15
oooo000;ooooo`0000L0000?oooo000Aoooo00<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0003<ol000Go09Tco`0co`0co`0000002C?o
00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo01?oool0017oool00`0003?o03?o000_<ol000<0000co`0c
o`00;c?o00030000<ol0<ol000dco`000ol0VC?o03?o000N<ol000<0000co`0co`00;c?o00030000
oooooooo02ooool00`000?ooooooo`0Coooo000AooooM3?o0003o`2I<ol0<ol0050co`000`000?oo
ooooo`15oooo000AooooM3?o0003o`2I<ol0<ol0050co`000`000?ooooooo`15oooo000AooooM3?o
0003o`2I<ol0<ol0050co`000`000?ooooooo`15oooo000AooooM3?o0003o`2I<ol0<ol0050co`00
0`000?ooooooo`15oooo000AooooM3?o0003o`2I<ol0<ol0050co`000`000?ooooooo`15oooo000A
ooooM3?o0003o`2I<ol0<ol0050co`020000A_ooo`004Oooog@co`000ol0VC?o03?o001@<ol000<0
003oooooool0AOooo`004Oooog@co`000ol0VC?o03?o001@<ol000<0003oooooool0AOooo`004Ooo
og@co`000ol0VC?o03?o001@<ol000<0003oooooool0AOooo`004Oooog@co`000ol0VC?o03?o001@
<ol000<0003oooooool0AOooo`004Oooog@co`000ol0VC?o03?o001@<ol000<0003oooooool0AOoo
o`004Oooog@co`000ol0VC?o03?o001@<ol000<0003oooooool0AOooo`004Oooog@co`000ol0VC?o
03?o001@<ol000<0003oooooool0AOooo`004Oooo`80001b<ol000?o09Tco`0co`00D3?o00800016
oooo000Coooo0P00070co`000ol0VC?o03?o001@<ol000<0003oooooool0AOooo`005Oooo`80001^
<ol000?o09Tco`0co`00D3?o00030000oooooooo04Goool001Ooool20000K3?o0003o`2I<ol0<ol0
050co`000`000?ooooooo`15oooo000Ioooo0P0006Xco`000ol0VC?o03?o001@<ol000<0003ooooo
ool0AOooo`006oooo`80001X<ol000?o09Tco`0co`00D3?o00030000oooooooo04Goool001goool2
0000IS?o0003o`2I<ol0<ol0050co`000`000?ooooooo`15oooo000Ooooo00<0000co`0co`00Hc?o
0003o`2I<ol0<ol0050co`000`000?ooooooo`15oooo000Poooo00<0000co`0co`00HS?o0003o`2I
<ol0<ol0050co`020000A_ooo`008Oooo`80001R<ol000?o09Tco`0co`00D3?o00030000oooooooo
04Goool002?oool00`0003?o03?o001O<ol000?o09Tco`0co`00D3?o00030000oooooooo04Goool0
02Coool20000Gc?o0003o`2I<ol0<ol0050co`000`000?ooooooo`15oooo000Voooo00<0000co`0c
o`00G3?o0003o`2I<ol0<ol0050co`000`000?ooooooo`15oooo000Woooo00<0000co`0co`00Fc?o
0003o`2I<ol0<ol0050co`000`000?ooooooo`15oooo000Xoooo00<0000co`0co`00FS?o0003o`2I
<ol0<ol003Lco`02000013?o00800004<ol00P0000<co`04000013?o00030000oooooooo04Goool0
02Woool00`0003?o03?o001I<ol000?o09Tco`0co`00=S?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000S?o00030000<ol0<ol000Dco`000`000?ooooooo`15oooo000Zoooo00<0000co`0c
o`00F3?o0003o`2I<ol0<ol003Hco`00100003?o03?o000000Pco`00100003?o03?o000000<co`00
0`0003?o03?o0004<ol00`0004Goool002_oool20000F3?o0003o`2I<ol0<ol003Hco`00100003?o
03?o000000Pco`00100003?o03?o000000@co`000`0003?o03?o0003<ol000<0003oooooool0AOoo
o`00;Oooo`030000<ol0<ol005Dco`000ol0VC?o03?o000f<ol000@0000co`0co`000008<ol000@0
000co`0co`000002<ol000@0000co`0co`000004<ol000<0003oooooool0AOooo`00;_ooo`030000
<ol0<ol005@co`000ol0VC?o03?o000g<ol00P0000Xco`02000013?o00800005<ol000<0003ooooo
ool0AOooo`00;oooo`030000<ol0<ol005<co`000ol0VC?o03?o001@<ol000<0003oooooool0AOoo
o`00<?ooo`030000<ol0<ol0058co`000ol0VC?o03?o001@<ol000<0003oooooool0AOooo`00<Ooo
o`030000<ol0<ol0054co`000ol0VC?o03?o001@<ol000<0003oooooool0AOooo`00<_ooo`030000
<ol0<ol0050co`000ol0VC?o03?o001@<ol000<0003oooooool0AOooo`00<oooo`030000<ol0<ol0
04lco`000ol0VC?o03?o001@<ol00P0004Koool003?oool00`0003?o03?o001?<ol000?o09Tco`0c
o`00D3?o00030000oooooooo04Goool003Coool00`0003?o03?o001><ol000?o09Tco`0co`00D3?o
00030000oooooooo04Goool003Goool00`0003?o03?o001=<ol000?o09Tco`0co`00D3?o00030000
oooooooo04Goool003Koool00`0003?o03?o001<<ol000?o09Tco`0co`00D3?o00030000oooooooo
04Goool003Ooool00`0003?o03?o001;<ol000?o09Tco`0co`00D3?o00030000oooooooo04Goool0
03Soool00`0003?o03?o001:<ol000?o09Tco`0co`00D3?o00030000oooooooo04Goool003Soool0
0`0003?o03?o001:<ol000?o09Tco`0co`00D3?o00030000oooooooo04Goool003Woool00`0003?o
03?o0019<ol000?o09Tco`0co`00D3?o00800016oooo000joooo00<0000co`0co`00B3?o0003o`2I
<ol0<ol0050co`000`000?ooooooo`15oooo000koooo00<0000co`0co`00Ac?o0003o`2I<ol0<ol0
050co`000`000?ooooooo`15oooo000loooo00<0000co`0co`00AS?o0003o`2I<ol0<ol0050co`00
0`000?ooooooo`15oooo000loooo00<0000co`0co`00AS?o0003o`2I<ol0<ol0050co`000`000?oo
ooooo`15oooo000moooo00<0000co`0co`00AC?o0003o`2I<ol0<ol0050co`000`000?ooooooo`15
oooo000moooo00<0000co`0co`00AC?o0003o`2I<ol0<ol0050co`000`000?ooooooo`15oooo000n
oooo00<0000co`0co`00A3?o0003o`2I<ol0<ol0050co`000`000?ooooooo`15oooo000noooo00<0
000co`0co`00A3?o0003o`2I<ol0<ol0050co`000`000?ooooooo`15oooo000ooooo00<0000co`0c
o`00@c?o0003o`2I<ol0<ol0050co`020000A_ooo`00?oooo`030000<ol0<ol004<co`000ol0VC?o
03?o001@<ol000<0003oooooool0AOooo`00@?ooo`030000<ol0<ol0048co`000ol0VC?o03?o001@
<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol0044co`000ol0VC?o03?o001@<ol000<0
003oooooool0AOooo`00@Oooo`030000<ol0<ol0044co`000ol0VC?o03?o001@<ol000<0003ooooo
ool0AOooo`00@_ooo`030000<ol0<ol0040co`000ol0VC?o03?o001@<ol000<0003oooooool0AOoo
o`00@_ooo`030000<ol0<ol0040co`000ol0VC?o03?o000g<ol00P0000@co`02000013?o00800005
<ol00`0000<co`000`000?ooooooo`15oooo0013oooo00<0000co`0co`00?c?o0003o`2I<ol0<ol0
03Hco`00100003?o03?o000000Pco`00100003?o03?o000000Dco`000`0003?o03?o0002<ol000<0
003oooooool0AOooo`00@oooo`030000<ol0<ol003lco`000ol0VC?o03?o000f<ol000@0000co`0c
o`000008<ol000@0000co`0co`000002<ol01@0000<co`030000AOooo`00A?ooo`030000<ol0<ol0
03hco`000ol0VC?o03?o000f<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0
000co`0co`000004<ol000<0003oooooool0AOooo`00A?ooo`030000<ol0<ol003hco`000ol0VC?o
03?o000f<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`00000013?o
00030000oooooooo04Goool004Goool00`0003?o03?o000m<ol000?o09Tco`0co`00=c?o0080000:
<ol00P0000Dco`02000013?o00030000oooooooo04Goool004Goool00`0003?o03?o000m<ol000?o
09Tco`0co`00D3?o00030000oooooooo04Goool004Koool00`0003?o03?o000l<ol000?o09Tco`0c
o`00D3?o00030000oooooooo04Goool004Koool00`0003?o03?o000l<ol000?o09Tco`0co`00D3?o
00030000oooooooo04Goool004Ooool00`0003?o03?o000k<ol000?o09Tco`0co`00D3?o00030000
oooooooo04Goool004Ooool00`0003?o03?o000k<ol000?o09Tco`0co`00D3?o00800016oooo0018
oooo00<0000co`0co`00>S?o0003o`2I<ol0<ol0050co`000`000?ooooooo`15oooo0018oooo00<0
000co`0co`00>S?o0003o`2I<ol0<ol0050co`000`000?ooooooo`15oooo0019oooo00<0000co`0c
o`00>C?o0003o`2I<ol0<ol0050co`000`000?ooooooo`15oooo0019oooo00<0000co`0co`00>C?o
0003o`2I<ol0<ol0050co`000`000?ooooooo`15oooo001:oooo00<0000co`0co`00>3?o0003o`2I
<ol0<ol0050co`000`000?ooooooo`15oooo001:oooo00<0000co`0co`00>3?o0003o`2I<ol0<ol0
050co`000`000?ooooooo`15oooo001;oooo00<0000co`0co`00=c?o0003o`2I<ol0<ol0050co`00
0`000?ooooooo`15oooo001;oooo00<0000co`0co`00=c?o0003o`2I<ol0<ol0050co`020000A_oo
o`00C?oooh`co`18oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00COoooh/co`18oooo001=
ooooRc?o04Soool004kooolZ<ol000<0000co`0co`009c?o00030000<ol0<ol003<co`18oooo001>
oooo:C?o00030000<ol0<ol000Pco`000`0003?o03?o000N<ol000<0000co`0co`00<S?o04Soool0
04oooolX<ol000<0000co`0co`000S?o00800004<ol000<0000co`0co`001S?o00800004<ol00P00
00<co`0500000c?o00030000<ol0<ol0008co`000`0003?o03?o000b<ol0B?ooo`00CoooobPco`00
1@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o00030000<ol0<ol000@co`00100003?o
03?o000000Xco`000`0003?o03?o0003<ol000<0000co`0co`000S?o00030000<ol0<ol0038co`18
oooo001?oooo9c?o00030000<ol0<ol0008co`000`0003?o03?o000<<ol000@0000co`0co`00000:
<ol000<0000co`0co`000c?o00030000<ol0<ol000<co`000`0003?o03?o000a<ol0B?ooo`00D?oo
obLco`000`0003?o03?o000500002c?o00040000<ol0<ol000002S?o00030000<ol0<ol000@co`00
1@0003?o03?o03?o0000000d<ol0B?ooo`00D?ooobLco`001@0003?o03?o03?o0000000><ol000@0
000co`0co`00000:<ol000D0000co`0co`0co`0000000S?o00050000<ol0<ol0<ol0000003@co`18
oooo001@oooo:3?o00030000<ol0<ol0010co`0200002S?o00800003<ol01000008co`000`0003?o
03?o000c<ol0B?ooo`00DOooohLco`18oooo001AooooQc?o04Soool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.45262 .30902 L
.46172 .30902 L
.46618 .30902 L
.46854 .30902 L
.46984 .30902 L
.47106 .30902 L
.47222 .30902 L
s
.47222 .30902 m
.47223 .61803 L
s
0 .4 1 r
.02381 .2866 m
.06244 .28313 L
.10458 .27874 L
.14415 .27394 L
.18221 .2686 L
.22272 .26201 L
.26171 .25464 L
.30316 .24551 L
.34309 .23524 L
.3815 .22375 L
.42237 .20948 L
.44268 .20148 L
.45262 .19732 L
.46172 .19336 L
.46618 .19137 L
.46854 .1903 L
.46984 .18971 L
.47106 .18915 L
.47222 .18861 L
.47348 .30902 L
.47462 .30902 L
.47567 .30902 L
.47666 .30902 L
.47775 .30902 L
.47888 .30902 L
.47994 .30902 L
.48116 .30902 L
.48185 .30902 L
.48249 .30902 L
.48365 .30902 L
.48489 .30902 L
.486 .30902 L
.48704 .30902 L
.48818 .30902 L
.48941 .30902 L
.49064 .30902 L
.49134 .30902 L
.49199 .30902 L
.4933 .30902 L
.49403 .30902 L
.4947 .30902 L
.4959 .30902 L
.4972 .30902 L
.49842 .30902 L
.49955 .30902 L
.5008 .30902 L
.50199 .30902 L
.50422 .30902 L
.50547 .30902 L
.50663 .30902 L
Mistroke
.5079 .30902 L
.5086 .30902 L
.50925 .30902 L
.51042 .30902 L
.51149 .30902 L
.51267 .30902 L
.51392 .30902 L
.515 .30902 L
.51602 .30902 L
.51713 .30902 L
.51831 .30902 L
.51961 .30902 L
.52098 .30902 L
.52169 .30902 L
.52248 .30902 L
.52319 .30902 L
.52387 .30902 L
.52519 .30902 L
.5264 .30902 L
.52703 .30902 L
.52772 .30902 L
.52845 .30902 L
.52912 .30902 L
.5304 .30902 L
.53161 .30902 L
.5327 .30902 L
.53388 .30902 L
.53516 .30902 L
.53581 .30902 L
.53652 .30902 L
.53778 .30902 L
.53895 .30902 L
.54021 .30902 L
.54085 .30902 L
.54155 .30902 L
.54279 .30902 L
.54395 .30902 L
.54461 .30902 L
.54531 .30902 L
.54657 .30902 L
.54726 .30902 L
.54791 .30902 L
.54863 .30902 L
.54939 .30902 L
.55183 .30902 L
.5525 .30902 L
.55321 .30902 L
.55448 .30902 L
.55566 .30902 L
.55676 .30902 L
Mistroke
.55798 .30902 L
.55928 .30902 L
.56053 .30902 L
.56123 .30902 L
.56188 .30902 L
.56308 .30902 L
.56436 .30902 L
.56561 .30902 L
.56679 .30902 L
.56785 .30902 L
.569 .30902 L
.57006 .30902 L
.57124 .30902 L
.57246 .30902 L
.5736 .30902 L
.57467 .30902 L
.57564 .30902 L
.57677 .30902 L
.57783 .30902 L
.57897 .30902 L
.5802 .30902 L
.58136 .30902 L
.58243 .30902 L
.58371 .30902 L
.5849 .30902 L
.58614 .30902 L
.58679 .30902 L
.58749 .30902 L
.58814 .30902 L
.58882 .30902 L
.58957 .30902 L
.59026 .30902 L
.5915 .30902 L
.59221 .30902 L
.59287 .30902 L
.5941 .30902 L
.59523 .30902 L
.59652 .30902 L
.59776 .30902 L
.59892 .30902 L
.59997 .30902 L
.60119 .30902 L
.60233 .30902 L
.6034 .30902 L
.60437 .30902 L
.60544 .30902 L
.60657 .30902 L
.60772 .30902 L
.60895 .30902 L
.6101 .30902 L
Mistroke
.61116 .30902 L
.61231 .30902 L
.61355 .30902 L
.61426 .30902 L
.61491 .30902 L
.61618 .30902 L
.61736 .30902 L
.61866 .30902 L
.61988 .30902 L
.62101 .30902 L
.62231 .30902 L
.62349 .30902 L
.62414 .30902 L
.62485 .30902 L
.62613 .30902 L
.62724 .30902 L
.62846 .30902 L
.62973 .30902 L
.63091 .30902 L
.63203 .30902 L
.63304 .30902 L
.63421 .30902 L
.63532 .30902 L
.63651 .30902 L
.63782 .30902 L
.63848 .30902 L
.6392 .30902 L
.64049 .30902 L
.64159 .30902 L
.64277 .30902 L
.64406 .30902 L
.64527 .30902 L
.64601 .30902 L
.64671 .30902 L
.64802 .30902 L
.64874 .30902 L
.64941 .30902 L
.65014 .30902 L
.65092 .30902 L
.65219 .30902 L
.65338 .30902 L
.65469 .30902 L
.65543 .30902 L
.6561 .30902 L
.6573 .30902 L
.65857 .30902 L
.65923 .30902 L
.65996 .30902 L
.66124 .30902 L
.66245 .30902 L
Mistroke
.66375 .30902 L
.66497 .30902 L
.66608 .30902 L
.6668 .30902 L
.66746 .30902 L
.66818 .30902 L
.66895 .30902 L
.67024 .30902 L
.67098 .30902 L
.67167 .30902 L
.67294 .30902 L
.6741 .30902 L
.67538 .30902 L
.67602 .30902 L
.67672 .30902 L
.68152 .30902 L
.68218 .30902 L
.6829 .30902 L
.6842 .30902 L
.68547 .30902 L
.68663 .30902 L
.68774 .30902 L
.68877 .30902 L
.6899 .30902 L
.69111 .30902 L
.69238 .30902 L
.69359 .30902 L
.69467 .30902 L
.69585 .30902 L
.69698 .30902 L
.6982 .30902 L
.69936 .30902 L
.70042 .30902 L
.70159 .30902 L
.70287 .30902 L
.70352 .30902 L
.70422 .30902 L
.70546 .30902 L
.70679 .30902 L
.70748 .30902 L
.70822 .30902 L
.70957 .30902 L
.71082 .30902 L
.71202 .30902 L
.71314 .30902 L
.71437 .30902 L
.71569 .30902 L
.71683 .30902 L
.71805 .30902 L
.71875 .30902 L
Mistroke
.71938 .30902 L
.72062 .30902 L
.72178 .30902 L
.72303 .30902 L
.72421 .30902 L
.7253 .30902 L
.72635 .30902 L
.72733 .30902 L
.7285 .30902 L
.72957 .30902 L
.73069 .30902 L
.73175 .30902 L
.73286 .30902 L
.73408 .30902 L
.7353 .30902 L
.73641 .30902 L
.73764 .30902 L
.73893 .30902 L
.74006 .30902 L
.7411 .30902 L
.74225 .30902 L
.74348 .30902 L
.74413 .30902 L
.74482 .30902 L
.74558 .30902 L
.74628 .30902 L
.74754 .30902 L
.74825 .30902 L
.74892 .30902 L
.75016 .30902 L
.7513 .30902 L
.75261 .30902 L
.75386 .30902 L
.75454 .30902 L
.75519 .30902 L
.75639 .30902 L
.75768 .30902 L
.75841 .30902 L
.75908 .30902 L
.7602 .30902 L
.76143 .30902 L
.76271 .30902 L
.76391 .30902 L
.76459 .30902 L
.76534 .30902 L
.76604 .30902 L
.76668 .30902 L
.76791 .30902 L
.7692 .30902 L
.76987 .30902 L
Mistroke
.7706 .30902 L
.7719 .30902 L
.7727 .30902 L
.77346 .30902 L
.77413 .30902 L
.77487 .30902 L
.77619 .30902 L
.7774 .30902 L
.77869 .30902 L
.77942 .30902 L
.7801 .30902 L
.78124 .30902 L
.78246 .30902 L
.78377 .30902 L
.78496 .30902 L
.78564 .30902 L
.78637 .30902 L
.78767 .30902 L
.79062 .30902 L
.79598 .30902 L
.81607 .30902 L
.85379 .30902 L
.89397 .30902 L
.93264 .30902 L
.97375 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00_oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00__ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000
oooooooo00Goool00`000?ooooooo`15oooo002noooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool01?ooo`<00015oooo0025oooo0P1Voc7oool400000_ooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo00?oool00`000?ooooooo`15
oooo0023oooo0P1Vo`03oooo06Kooooo03Koool010000?ooooooo`0000Soool010000?ooooooo`00
00;oool010000?ooooooo`0000Coool00`000?ooooooo`15oooo0021oooo0P1Vo`?oool00`1Voooo
ooooo`0foooo0P0000[oool200001?ooo`800005oooo00<0003oooooool0AOooo`00O_ooo`<0I_l5
oooo00<0I_ooooooool0Coooo`030000oooooooo04Goool007_oool306Ko2?ooo`0306Kooooooooo
04ooool00`000?ooooooo`15oooo001hoooo0`1Vo`_oool00`1Vooooooooo`1?oooo00<0003ooooo
ool0AOooo`00M_ooo`80I_l>oooo00<0I_ooooooool0Coooo`030000oooooooo04Goool007?oool3
06Ko4?ooo`0306Kooooooooo04ooool20000A_ooo`00LOooo`80I_lCoooo00<0I_ooooooool0Cooo
o`030000oooooooo04Goool006koool306Ko5Oooo`0306Kooooooooo04ooool00`000?ooooooo`15
oooo001[oooo0`1VoaSoool00`1Vooooooooo`1?oooo00<0003oooooool0AOooo`00Ioooo`@0I_lK
oooo00<0I_ooooooool0Coooo`030000oooooooo04Goool006Coool306Ko7oooo`0306Kooooooooo
04ooool00`000?ooooooo`15oooo001Poooo101Vob;oool00`1Vooooooooo`1?oooo00<0003ooooo
ool0AOooo`00G?ooo`@0I_lVoooo00<0I_ooooooool0Coooo`030000oooooooo04Goool005Soool4
06Ko:_ooo`0306Kooooooooo04ooool20000A_ooo`00D_ooo`H0I_l_oooo00<0I_ooooooool0C_oo
o`030000oooooooo04Goool004goool506Ko=Oooo`0306Kooooooooo04koool00`000?ooooooo`15
oooo0018oooo1@1Voc[oool00`1Vooooooooo`1>oooo00<0003oooooool0AOooo`00@oooo`D0I_lo
oooo00<0I_ooooooool0C_ooo`030000oooooooo04Goool001;oool40000:?ooo`D00002oooo0P00
00Coool20000:Oooo`D0000<oooo00<0I_ooooooool06?ooo`800004oooo0P0000Coool20000:?oo
o`030000oooooooo02Soool200001?ooo`800004oooo0P0000ooool001;oool00`000?ooooooo`0R
oooo1`1Vo`;oool00`000?ooooooo`07oooo00@0003oooooool0000Zoooo00<0003oooooool03?oo
o`0306Kooooooooo01Ooool010000?ooooooo`0000Soool010000?ooooooo`0002Ooool00`000?oo
ooooo`0Woooo00@0003oooooool00008oooo00@0003oooooool0000>oooo000Coooo00<0003ooooo
ool05_ooo`/0I_l9oooo00<0003oooooool02_ooo`030000oooooooo02Soool00`000?ooooooo`0<
oooo00<0I_ooooooool05oooo`040000oooooooo00002oooo`030000oooooooo02Goool00`000?oo
ooooo`0Woooo00@0003oooooool0000;oooo00<0003oooooool03?ooo`003?ooo`@00004oooo00<0
003oooooool02oooo`X0I_l<oooo100000Coool00`000?ooooooo`08oooo0P0002?oool400001?oo
o`030000oooooooo00coool00`1Vooooooooo`0Aoooo100000;oool010000?ooooooo`0000Woool2
0000:?ooo`80000Xoooo00@0003oooooool00009oooo0P0000ooool001;oool01@000?ooooooo`00
0?ooo`0;06Ko7_ooo`030000oooooooo00Soool00`000?ooooooo`0Zoooo00<0003oooooool03?oo
o`0306Kooooooooo01Ooool010000?ooooooo`0000Woool00`000?ooooooo`0Woooo00<0003ooooo
ool09oooo`040000oooooooo00002Oooo`030000oooooooo00koool0017oool206Ko0P000080I_lX
oooo0P0000[oool30000:Oooo`80000>oooo00<0I_ooooooool06?ooo`80000:oooo0`0002Ooool0
0`000?ooooooo`0Xoooo0P0000[oool300003_ooo`00Qoooo`0306Kooooooooo04koool00`000?oo
ooooo`15oooo0027oooo00<0I_ooooooool0C_ooo`030000oooooooo04Goool008Ooool00`1Voooo
ooooo`1>oooo00<0003oooooool0AOooo`00Qoooo`0306Kooooooooo04koool00`000?ooooooo`15
oooo0027oooo00<0I_ooooooool0C_ooo`030000oooooooo04Goool000_ooooo00001`0000ooool0
017oool00`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000@co`001?l0VC?o03?o000000Tco`000`0003?o03?o0006<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0C
oooo000Aoooo00<0000co`0co`00;c?o00030000<ol0<ol002lco`000`0003?o03?o000><ol000?o
09Tco`0co`007C?o00030000<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04ooo
o`004OooogDco`000ol0VC?o03?o001?<ol000<0003oooooool0AOooo`004OooogDco`000ol0VC?o
03?o001?<ol000<0003oooooool0AOooo`004OooogDco`000ol0VC?o03?o001?<ol000<0003ooooo
ool0AOooo`004OooogDco`000ol0VC?o03?o001?<ol000<0003oooooool0AOooo`004OooogDco`00
0ol0VC?o03?o001?<ol000<0003oooooool0AOooo`004OooogDco`000ol0VC?o03?o001?<ol00P00
04Koool0017ooome<ol000?o09Tco`0co`00Cc?o00030000oooooooo04Goool0017ooome<ol000?o
09Tco`0co`00Cc?o00030000oooooooo04Goool0017ooome<ol000?o09Tco`0co`00Cc?o00030000
oooooooo04Goool0017ooome<ol000?o09Tco`0co`00Cc?o00030000oooooooo04Goool0017ooome
<ol000?o09Tco`0co`00Cc?o00030000oooooooo04Goool0017ooome<ol000?o09Tco`0co`00Cc?o
00030000oooooooo04Goool0017ooome<ol000?o09Tco`0co`00Cc?o00030000oooooooo04Goool0
017oool20000Lc?o0003o`2I<ol0<ol004lco`020000A_ooo`004oooo`80001a<ol000?o09Tco`0c
o`00Cc?o00030000oooooooo04Goool001Goool20000Kc?o0003o`2I<ol0<ol004lco`000`000?oo
ooooo`15oooo000Goooo0P0006dco`000ol0VC?o03?o001?<ol000<0003oooooool0AOooo`006Ooo
o`80001[<ol000?o09Tco`0co`00Cc?o00030000oooooooo04Goool001_oool20000JC?o0003o`2I
<ol0<ol004lco`000`000?ooooooo`15oooo000Moooo0P0006Lco`000ol0VC?o03?o001?<ol000<0
003oooooool0AOooo`007oooo`030000<ol0<ol006@co`000ol0VC?o03?o001?<ol000<0003ooooo
ool0AOooo`008?ooo`030000<ol0<ol006<co`000ol0VC?o03?o001?<ol00P0004Koool0027oool2
0000Hc?o0003o`2I<ol0<ol004lco`000`000?ooooooo`15oooo000Soooo00<0000co`0co`00H3?o
0003o`2I<ol0<ol004lco`000`000?ooooooo`15oooo000Toooo0P00060co`000ol0VC?o03?o001?
<ol000<0003oooooool0AOooo`009_ooo`030000<ol0<ol005dco`000ol0VC?o03?o001?<ol000<0
003oooooool0AOooo`009oooo`030000<ol0<ol005`co`000ol0VC?o03?o001?<ol000<0003ooooo
ool0AOooo`00:?ooo`030000<ol0<ol005/co`000ol0VC?o03?o000f<ol00P0000@co`02000013?o
00800003<ol0100000@co`000`000?ooooooo`15oooo000Yoooo00<0000co`0co`00FS?o0003o`2I
<ol0<ol003Dco`00100003?o03?o000000Pco`00100003?o03?o0000008co`000`0003?o03?o0005
<ol000<0003oooooool0AOooo`00:_ooo`030000<ol0<ol005Tco`000ol0VC?o03?o000e<ol000@0
000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00<00015oooo000[
oooo0P0005Tco`000ol0VC?o03?o000e<ol000@0000co`0co`000008<ol000@0000co`0co`000004
<ol000<0000co`0co`000c?o00030000oooooooo04Goool002goool00`0003?o03?o001F<ol000?o
09Tco`0co`00=C?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0
000013?o00030000oooooooo04Goool002koool00`0003?o03?o001E<ol000?o09Tco`0co`00=S?o
0080000:<ol00P0000@co`0200001C?o00030000oooooooo04Goool002ooool00`0003?o03?o001D
<ol000?o09Tco`0co`00Cc?o00030000oooooooo04Goool0033oool00`0003?o03?o001C<ol000?o
09Tco`0co`00Cc?o00030000oooooooo04Goool0037oool00`0003?o03?o001B<ol000?o09Tco`0c
o`00Cc?o00030000oooooooo04Goool003;oool00`0003?o03?o001A<ol000?o09Tco`0co`00Cc?o
00030000oooooooo04Goool003?oool00`0003?o03?o001@<ol000?o09Tco`0co`00Cc?o00800016
oooo000coooo00<0000co`0co`00D3?o0003o`2I<ol0<ol004lco`000`000?ooooooo`15oooo000d
oooo00<0000co`0co`00Cc?o0003o`2I<ol0<ol004lco`000`000?ooooooo`15oooo000eoooo00<0
000co`0co`00CS?o0003o`2I<ol0<ol004lco`000`000?ooooooo`15oooo000foooo00<0000co`0c
o`00CC?o0003o`2I<ol0<ol004lco`000`000?ooooooo`15oooo000goooo00<0000co`0co`00C3?o
0003o`2I<ol0<ol004lco`000`000?ooooooo`15oooo000hoooo00<0000co`0co`00Bc?o0003o`2I
<ol0<ol004lco`000`000?ooooooo`15oooo000hoooo00<0000co`0co`00Bc?o0003o`2I<ol0<ol0
04lco`000`000?ooooooo`15oooo000ioooo00<0000co`0co`00BS?o0003o`2I<ol0<ol004lco`02
0000A_ooo`00>_ooo`030000<ol0<ol004Tco`000ol0VC?o03?o001?<ol000<0003oooooool0AOoo
o`00>oooo`030000<ol0<ol004Pco`000ol0VC?o03?o001?<ol000<0003oooooool0AOooo`00??oo
o`030000<ol0<ol004Lco`000ol0VC?o03?o001?<ol000<0003oooooool0AOooo`00??ooo`030000
<ol0<ol004Lco`000ol0VC?o03?o001?<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol0
04Hco`000ol0VC?o03?o001?<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol004Hco`00
0ol0VC?o03?o001?<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol004Dco`000ol0VC?o
03?o001?<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol004Dco`000ol0VC?o03?o001?
<ol000<0003oooooool0AOooo`00?oooo`030000<ol0<ol004@co`000ol0VC?o03?o001?<ol00P00
04Koool003ooool00`0003?o03?o0014<ol000?o09Tco`0co`00Cc?o00030000oooooooo04Goool0
043oool00`0003?o03?o0013<ol000?o09Tco`0co`00Cc?o00030000oooooooo04Goool0047oool0
0`0003?o03?o0012<ol000?o09Tco`0co`00Cc?o00030000oooooooo04Goool0047oool00`0003?o
03?o0012<ol000?o09Tco`0co`00Cc?o00030000oooooooo04Goool004;oool00`0003?o03?o0011
<ol000?o09Tco`0co`00Cc?o00030000oooooooo04Goool004;oool00`0003?o03?o0011<ol000?o
09Tco`0co`00=S?o00800004<ol00P0000@co`0200001C?o00<00003<ol000<0003oooooool0AOoo
o`00@oooo`030000<ol0<ol0040co`000ol0VC?o03?o000e<ol000@0000co`0co`000008<ol000@0
000co`0co`000005<ol000<0000co`0co`000S?o00030000oooooooo04Goool004?oool00`0003?o
03?o0010<ol000?o09Tco`0co`00=C?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o
00D00003<ol00`0004Goool004Coool00`0003?o03?o000o<ol000?o09Tco`0co`00=C?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo
04Goool004Coool00`0003?o03?o000o<ol000?o09Tco`0co`00=C?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000c?o00030000<ol0000000@co`000`000?ooooooo`15oooo0015oooo00<0
000co`0co`00?S?o0003o`2I<ol0<ol003Hco`0200002S?o00800005<ol00P0000@co`000`000?oo
ooooo`15oooo0015oooo00<0000co`0co`00?S?o0003o`2I<ol0<ol004lco`000`000?ooooooo`15
oooo0016oooo00<0000co`0co`00?C?o0003o`2I<ol0<ol004lco`000`000?ooooooo`15oooo0016
oooo00<0000co`0co`00?C?o0003o`2I<ol0<ol004lco`000`000?ooooooo`15oooo0017oooo00<0
000co`0co`00?3?o0003o`2I<ol0<ol004lco`000`000?ooooooo`15oooo0017oooo00<0000co`0c
o`00?3?o0003o`2I<ol0<ol004lco`020000A_ooo`00B?ooo`030000<ol0<ol003/co`000ol0VC?o
03?o001?<ol000<0003oooooool0AOooo`00B?ooo`030000<ol0<ol003/co`000ol0VC?o03?o001?
<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol003Xco`000ol0VC?o03?o001?<ol000<0
003oooooool0AOooo`00BOooo`030000<ol0<ol003Xco`000ol0VC?o03?o001?<ol000<0003ooooo
ool0AOooo`00B_ooo`030000<ol0<ol003Tco`000ol0VC?o03?o001?<ol000<0003oooooool0AOoo
o`00B_ooo`030000<ol0<ol003Tco`000ol0VC?o03?o001?<ol000<0003oooooool0AOooo`00Booo
o`030000<ol0<ol003Pco`000ol0VC?o03?o001?<ol000<0003oooooool0AOooo`00Boooo`030000
<ol0<ol003Pco`000ol0VC?o03?o001?<ol00P0004Koool004cooon<<ol0B?ooo`00C?oooh`co`18
oooo001<ooooS3?o04Soool004gooon;<ol0B?ooo`00COoooh/co`18oooo001>oooo:S?o00030000
<ol0<ol002Lco`000`0003?o03?o000c<ol0B?ooo`00C_ooobTco`000`0003?o03?o0008<ol000<0
000co`0co`007S?o00030000<ol0<ol0038co`18oooo001?oooo:3?o00030000<ol0<ol0008co`02
000013?o00030000<ol0<ol000Hco`02000013?o00800003<ol01@00008co`02000013?o00030000
<ol0<ol0038co`18oooo001?oooo:3?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002
<ol000<0000co`0co`0013?o00040000<ol0<ol000002S?o00050000<ol0<ol0<ol00000008co`00
1@0003?o03?o03?o0000000d<ol0B?ooo`00CoooobLco`000`0003?o03?o0002<ol000<0000co`0c
o`0033?o00040000<ol0<ol000002S?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002
<ol000<0000co`0co`00<C?o04Soool0053ooolW<ol000<0000co`0co`001@0000/co`00100003?o
03?o000000Xco`000`0003?o03?o0002<ol00P0000@co`000`0003?o03?o000b<ol0B?ooo`00D?oo
obLco`001@0003?o03?o03?o0000000><ol000@0000co`0co`00000:<ol000D0000co`0co`0co`00
00000S?o00050000<ol0<ol0<ol0000003@co`18oooo001@oooo:3?o00030000<ol0<ol0010co`02
00002S?o00800004<ol00P0000<co`000`0003?o03?o000c<ol0B?ooo`00DOooohLco`18oooo001A
ooooQc?o04Soool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.19) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.45262 .30902 L
.46172 .30902 L
.46618 .30902 L
.47106 .30902 L
.47329 .30902 L
.47451 .30902 L
.47567 .30902 L
.47674 .30902 L
s
.47674 .30902 m
.47675 .61803 L
s
0 .4 1 r
.02381 .28532 m
.06244 .28166 L
.10458 .27702 L
.14415 .27194 L
.18221 .2663 L
.22272 .25933 L
.26171 .25154 L
.30316 .2419 L
.34309 .23105 L
.3815 .2189 L
.42237 .20382 L
.44268 .19536 L
.45262 .19097 L
.46172 .18679 L
.46618 .18468 L
.47106 .18233 L
.47329 .18124 L
.47451 .18064 L
.47567 .18007 L
.47674 .17953 L
.47791 .30902 L
.47897 .30902 L
.47994 .30902 L
.48108 .30902 L
.48229 .30902 L
.48344 .30902 L
.48449 .30902 L
.48572 .30902 L
.48641 .30902 L
.48705 .30902 L
.48823 .30902 L
.48948 .30902 L
.49067 .30902 L
.49195 .30902 L
.49316 .30902 L
.49427 .30902 L
.4955 .30902 L
.49619 .30902 L
.49684 .30902 L
.49815 .30902 L
.49889 .30902 L
.49955 .30902 L
.50074 .30902 L
.50186 .30902 L
.50308 .30902 L
.5044 .30902 L
.50506 .30902 L
.50578 .30902 L
.50708 .30902 L
.50837 .30902 L
Mistroke
.50953 .30902 L
.51073 .30902 L
.51185 .30902 L
.51303 .30902 L
.51431 .30902 L
.51874 .30902 L
.52005 .30902 L
.52079 .30902 L
.52147 .30902 L
.52277 .30902 L
.52401 .30902 L
.52528 .30902 L
.526 .30902 L
.52666 .30902 L
.52734 .30902 L
.52808 .30902 L
.52885 .30902 L
.52957 .30902 L
.5308 .30902 L
.53208 .30902 L
.53317 .30902 L
.53437 .30902 L
.53567 .30902 L
.53639 .30902 L
.53705 .30902 L
.53833 .30902 L
.53953 .30902 L
.54069 .30902 L
.54193 .30902 L
.54311 .30902 L
.54418 .30902 L
.54543 .30902 L
.54614 .30902 L
.5468 .30902 L
.548 .30902 L
.54928 .30902 L
.5505 .30902 L
.55181 .30902 L
.55304 .30902 L
.55418 .30902 L
.55543 .30902 L
.55615 .30902 L
.55681 .30902 L
.55751 .30902 L
.55815 .30902 L
.55889 .30902 L
.55959 .30902 L
.56065 .30902 L
.56182 .30902 L
.56305 .30902 L
Mistroke
.56419 .30902 L
.56526 .30902 L
.56624 .30902 L
.56737 .30902 L
.56844 .30902 L
.5696 .30902 L
.57083 .30902 L
.57199 .30902 L
.57304 .30902 L
.57428 .30902 L
.57493 .30902 L
.57562 .30902 L
.57689 .30902 L
.57805 .30902 L
.57927 .30902 L
.57996 .30902 L
.5806 .30902 L
.58177 .30902 L
.58302 .30902 L
.58413 .30902 L
.58517 .30902 L
.58631 .30902 L
.58754 .30902 L
.58877 .30902 L
.58947 .30902 L
.59012 .30902 L
.59144 .30902 L
.59218 .30902 L
.59284 .30902 L
.59404 .30902 L
.59535 .30902 L
.59657 .30902 L
.59771 .30902 L
.59876 .30902 L
.5999 .30902 L
.60097 .30902 L
.60195 .30902 L
.60437 .30902 L
.60555 .30902 L
.60662 .30902 L
.60774 .30902 L
.60893 .30902 L
.61023 .30902 L
.61145 .30902 L
.6126 .30902 L
.61366 .30902 L
.61482 .30902 L
.61604 .30902 L
.61727 .30902 L
.61796 .30902 L
Mistroke
.6186 .30902 L
.61978 .30902 L
.62102 .30902 L
.62214 .30902 L
.62318 .30902 L
.62433 .30902 L
.62556 .30902 L
.62686 .30902 L
.62755 .30902 L
.62828 .30902 L
.62899 .30902 L
.62962 .30902 L
.63087 .30902 L
.63207 .30902 L
.63338 .30902 L
.63461 .30902 L
.63574 .30902 L
.6368 .30902 L
.63794 .30902 L
.63901 .30902 L
.63999 .30902 L
.64114 .30902 L
.64239 .30902 L
.64357 .30902 L
.64466 .30902 L
.64578 .30902 L
.64683 .30902 L
.64799 .30902 L
.64923 .30902 L
.65046 .30902 L
.65176 .30902 L
.65287 .30902 L
.65409 .30902 L
.65541 .30902 L
.65662 .30902 L
.65726 .30902 L
.65796 .30902 L
.65869 .30902 L
.65937 .30902 L
.66062 .30902 L
.66177 .30902 L
.66241 .30902 L
.6631 .30902 L
.66436 .30902 L
.66559 .30902 L
.6667 .30902 L
.6679 .30902 L
.6692 .30902 L
.6704 .30902 L
.67151 .30902 L
Mistroke
.67257 .30902 L
.67369 .30902 L
.675 .30902 L
.67619 .30902 L
.67684 .30902 L
.67756 .30902 L
.67886 .30902 L
.68007 .30902 L
.68136 .30902 L
.68247 .30902 L
.68368 .30902 L
.68437 .30902 L
.6851 .30902 L
.6864 .30902 L
.68713 .30902 L
.6878 .30902 L
.68854 .30902 L
.68933 .30902 L
.69002 .30902 L
.69076 .30902 L
.69147 .30902 L
.69211 .30902 L
.69334 .30902 L
.69464 .30902 L
.69585 .30902 L
.69717 .30902 L
.69842 .30902 L
.69958 .30902 L
.70062 .30902 L
.70177 .30902 L
.70409 .30902 L
.70532 .30902 L
.70647 .30902 L
.70766 .30902 L
.70897 .30902 L
.70967 .30902 L
.7103 .30902 L
.71103 .30902 L
.71172 .30902 L
.71293 .30902 L
.71424 .30902 L
.71662 .30902 L
.71783 .30902 L
.71851 .30902 L
.71915 .30902 L
.72152 .30902 L
.72369 .30902 L
.72473 .30902 L
.72588 .30902 L
.72696 .30902 L
Mistroke
.72796 .30902 L
.72913 .30902 L
.73019 .30902 L
.73141 .30902 L
.73256 .30902 L
.73373 .30902 L
.73497 .30902 L
.73615 .30902 L
.73722 .30902 L
.73848 .30902 L
.73919 .30902 L
.73984 .30902 L
.74105 .30902 L
.74233 .30902 L
.74355 .30902 L
.74486 .30902 L
.7461 .30902 L
.74723 .30902 L
.74849 .30902 L
.74921 .30902 L
.74987 .30902 L
.75057 .30902 L
.75121 .30902 L
.75195 .30902 L
.75265 .30902 L
.75371 .30902 L
.75489 .30902 L
.75611 .30902 L
.75726 .30902 L
.75831 .30902 L
.75931 .30902 L
.76046 .30902 L
.76151 .30902 L
.76611 .30902 L
.76737 .30902 L
.76807 .30902 L
.76871 .30902 L
.76995 .30902 L
.77112 .30902 L
.77229 .30902 L
.77354 .30902 L
.77472 .30902 L
.77579 .30902 L
.77706 .30902 L
.77777 .30902 L
.77843 .30902 L
.77963 .30902 L
.78091 .30902 L
.78214 .30902 L
.78345 .30902 L
Mistroke
.78469 .30902 L
.78583 .30902 L
.78652 .30902 L
.78716 .30902 L
.78861 .30902 L
.79125 .30902 L
.80973 .30902 L
.84884 .30902 L
.89039 .30902 L
.93044 .30902 L
.96896 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.19) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00R?ooo`0306Kooooooooo03Coool200001?ooo`800004oooo0P00
00?oool400001?ooo`030000oooooooo04Goool008Koool306Ko=Oooo`040000oooooooo00002?oo
o`040000oooooooo00000_ooo`030000oooooooo00Goool00`000?ooooooo`15oooo0023oooo0`1V
o`;oool00`1Vooooooooo`0coooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`<00015oooo0021oooo0P1Vo`Goool00`1Vooooooooo`0]oooo100000;oool0
10000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003ooooo
ool0AOooo`00Ooooo`80I_l7oooo00<0I_ooooooool0<oooo`040000oooooooo00002?ooo`040000
oooooooo00000_ooo`040000oooooooo00001?ooo`030000oooooooo04Goool007goool206Ko2Ooo
o`0306Kooooooooo03Coool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo001k
oooo0P1Vo`_oool00`1Vooooooooo`1=oooo00<0003oooooool0AOooo`00N?ooo`<0I_l=oooo00<0
I_ooooooool0COooo`030000oooooooo04Goool007Koool206Ko4?ooo`0306Kooooooooo04goool0
0`000?ooooooo`15oooo001coooo0`1Voa;oool00`1Vooooooooo`1=oooo00<0003oooooool0AOoo
o`00LOooo`80I_lEoooo00<0I_ooooooool0COooo`800016oooo001^oooo0`1VoaOoool00`1Voooo
ooooo`1=oooo00<0003oooooool0AOooo`00Joooo`<0I_lJoooo00<0I_ooooooool0COooo`030000
oooooooo04Goool006Ooool406Ko7Oooo`0306Kooooooooo04goool00`000?ooooooo`15oooo001T
oooo0`1Vob7oool00`1Vooooooooo`1=oooo00<0003oooooool0AOooo`00H?ooo`@0I_lToooo00<0
I_ooooooool0COooo`030000oooooooo04Goool005coool406Ko:?ooo`0306Kooooooooo04goool0
0`000?ooooooo`15oooo001Hoooo101Vobcoool00`1Vooooooooo`1=oooo00<0003oooooool0AOoo
o`00D_ooo`H0I_l`oooo00<0I_ooooooool0COooo`800016oooo001=oooo1@1VocKoool00`1Voooo
ooooo`1=oooo00<0003oooooool0AOooo`00B?ooo`D0I_lkoooo00<0I_ooooooool0COooo`030000
oooooooo04Goool004?oool506Ko@?ooo`0306Kooooooooo04goool00`000?ooooooo`15oooo000n
oooo1@1VodGoool00`1Vooooooooo`1=oooo00<0003oooooool0AOooo`004_ooo`@0000Qoooo1`1V
o`D00002oooo0P0000Coool20000:Oooo`D0000=oooo00<0I_ooooooool05oooo`800004oooo0P00
00Coool20000:?ooo`030000oooooooo02Soool200001?ooo`800004oooo0P0000ooool001;oool0
0`000?ooooooo`0Joooo201Vo`Woool00`000?ooooooo`07oooo00@0003oooooool0000Zoooo00<0
003oooooool03Oooo`0306Kooooooooo01Koool010000?ooooooo`0000Soool010000?ooooooo`00
02Ooool00`000?ooooooo`0Woooo00@0003oooooool00008oooo00@0003oooooool0000>oooo000C
oooo00<0003oooooool04oooo`H0I_lAoooo00<0003oooooool02_ooo`030000oooooooo02Soool0
0`000?ooooooo`0=oooo00<0I_ooooooool05_ooo`040000oooooooo00002oooo`030000oooooooo
02Goool00`000?ooooooo`0Woooo00@0003oooooool0000;oooo00<0003oooooool03?ooo`003?oo
o`@00004oooo00<0003oooooool02oooo`L0I_l?oooo100000Coool00`000?ooooooo`08oooo0P00
02?oool400001?ooo`030000oooooooo00goool00`1Vooooooooo`0@oooo100000;oool010000?oo
ooooo`0000Woool20000:?ooo`80000Xoooo00@0003oooooool00009oooo0P0000ooool001;oool0
1@000?ooooooo`000?ooo`0;06Ko7_ooo`030000oooooooo00Soool00`000?ooooooo`0Zoooo00<0
003oooooool03Oooo`0306Kooooooooo01Koool010000?ooooooo`0000Woool00`000?ooooooo`0W
oooo00<0003oooooool09oooo`040000oooooooo00002Oooo`030000oooooooo00koool0017oool2
06Ko0P000080I_lXoooo0P0000[oool30000:Oooo`80000?oooo00<0I_ooooooool05oooo`80000:
oooo0`0002Ooool00`000?ooooooo`0Xoooo0P0000[oool300003_ooo`00R?ooo`0306Kooooooooo
04goool00`000?ooooooo`15oooo0028oooo00<0I_ooooooool0COooo`030000oooooooo04Goool0
08Soool00`1Vooooooooo`1=oooo00<0003oooooool0AOooo`00R?ooo`0306Kooooooooo04goool0
0`000?ooooooo`15oooo0028oooo00<0I_ooooooool0COooo`030000oooooooo04Goool000_ooooo
00001`0000ooool0017oool00`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Hco`000ol0V@0003?o0008<ol000<0000co`0co`001S?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool04oooo`004Oooo`030000<ol0<ol002lco`000`0003?o03?o000_<ol000<0000co`0c
o`0043?o0003o`2I<ol0<ol001/co`000`0003?o03?o000_<ol000<0003oooooool0;oooo`030000
oooooooo01?oool0017ooomg<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool0017ooomg
<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool0017ooomg<ol000?o09Tco`0co`00CC?o
00030000oooooooo04Goool0017ooomg<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool0
017ooomg<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool0017ooomg<ol000?o09Tco`0c
o`00CC?o00800016oooo000AooooMc?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo000A
ooooMc?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo000AooooMc?o0003o`2I<ol0<ol0
04dco`000`000?ooooooo`15oooo000AooooMc?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15
oooo000AooooMc?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo000AooooMc?o0003o`2I
<ol0<ol004dco`000`000?ooooooo`15oooo000AooooMc?o0003o`2I<ol0<ol004dco`000`000?oo
ooooo`15oooo000Aoooo0P0007Dco`000ol0VC?o03?o001=<ol00P0004Koool001?oool20000Lc?o
0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo000Eoooo0P00074co`000ol0VC?o03?o001=
<ol000<0003oooooool0AOooo`005oooo`80001_<ol000?o09Tco`0co`00CC?o00030000oooooooo
04Goool001Woool20000KC?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo000Koooo0P00
06/co`000ol0VC?o03?o001=<ol000<0003oooooool0AOooo`007Oooo`80001Y<ol000?o09Tco`0c
o`00CC?o00030000oooooooo04Goool001ooool00`0003?o03?o001V<ol000?o09Tco`0co`00CC?o
00030000oooooooo04Goool0023oool00`0003?o03?o001U<ol000?o09Tco`0co`00CC?o00800016
oooo000Qoooo0P0006Dco`000ol0VC?o03?o001=<ol000<0003oooooool0AOooo`008oooo`030000
<ol0<ol0068co`000ol0VC?o03?o001=<ol000<0003oooooool0AOooo`009?ooo`80001R<ol000?o
09Tco`0co`00CC?o00030000oooooooo04Goool002Koool00`0003?o03?o001O<ol000?o09Tco`0c
o`00CC?o00030000oooooooo04Goool002Ooool00`0003?o03?o001N<ol000?o09Tco`0co`00CC?o
00030000oooooooo04Goool002Soool00`0003?o03?o001M<ol000?o09Tco`0co`00=3?o00800004
<ol00P0000@co`0200000c?o00@00004<ol000<0003oooooool0AOooo`00:Oooo`030000<ol0<ol0
05`co`000ol0VC?o03?o000c<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000<0
000co`0co`001C?o00030000oooooooo04Goool002[oool00`0003?o03?o001K<ol000?o09Tco`0c
o`00<c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0<ol000@co`03
0000AOooo`00:oooo`80001K<ol000?o09Tco`0co`00<c?o00040000<ol0<ol0000023?o00040000
<ol0<ol0000013?o00030000<ol0<ol000<co`000`000?ooooooo`15oooo000]oooo00<0000co`0c
o`00F3?o0003o`2I<ol0<ol003<co`00100003?o03?o000000Pco`00100003?o03?o0000008co`00
100003?o03?o000000@co`000`000?ooooooo`15oooo000^oooo00<0000co`0co`00Ec?o0003o`2I
<ol0<ol003@co`0200002S?o00800004<ol00P0000Dco`000`000?ooooooo`15oooo000_oooo00<0
000co`0co`00ES?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo000`oooo00<0000co`0c
o`00EC?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo000aoooo00<0000co`0co`00E3?o
0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo000boooo00<0000co`0co`00Dc?o0003o`2I
<ol0<ol004dco`000`000?ooooooo`15oooo000coooo00<0000co`0co`00DS?o0003o`2I<ol0<ol0
04dco`020000A_ooo`00<oooo`030000<ol0<ol0058co`000ol0VC?o03?o001=<ol000<0003ooooo
ool0AOooo`00=?ooo`030000<ol0<ol0054co`000ol0VC?o03?o001=<ol000<0003oooooool0AOoo
o`00=Oooo`030000<ol0<ol0050co`000ol0VC?o03?o001=<ol000<0003oooooool0AOooo`00=_oo
o`030000<ol0<ol004lco`000ol0VC?o03?o001=<ol000<0003oooooool0AOooo`00=oooo`030000
<ol0<ol004hco`000ol0VC?o03?o001=<ol000<0003oooooool0AOooo`00>?ooo`030000<ol0<ol0
04dco`000ol0VC?o03?o001=<ol000<0003oooooool0AOooo`00>?ooo`030000<ol0<ol004dco`00
0ol0VC?o03?o001=<ol000<0003oooooool0AOooo`00>Oooo`030000<ol0<ol004`co`000ol0VC?o
03?o001=<ol00P0004Koool003[oool00`0003?o03?o001;<ol000?o09Tco`0co`00CC?o00030000
oooooooo04Goool003_oool00`0003?o03?o001:<ol000?o09Tco`0co`00CC?o00030000oooooooo
04Goool003coool00`0003?o03?o0019<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool0
03coool00`0003?o03?o0019<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool003goool0
0`0003?o03?o0018<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool003goool00`0003?o
03?o0018<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool003koool00`0003?o03?o0017
<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool003koool00`0003?o03?o0017<ol000?o
09Tco`0co`00CC?o00030000oooooooo04Goool003ooool00`0003?o03?o0016<ol000?o09Tco`0c
o`00CC?o00800016oooo000ooooo00<0000co`0co`00AS?o0003o`2I<ol0<ol004dco`000`000?oo
ooooo`15oooo0010oooo00<0000co`0co`00AC?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15
oooo0011oooo00<0000co`0co`00A3?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo0011
oooo00<0000co`0co`00A3?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo0012oooo00<0
000co`0co`00@c?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo0012oooo00<0000co`0c
o`00@c?o0003o`2I<ol0<ol003@co`02000013?o00800004<ol00P0000Dco`0300000c?o00030000
oooooooo04Goool004?oool00`0003?o03?o0012<ol000?o09Tco`0co`00<c?o00040000<ol0<ol0
000023?o00040000<ol0<ol000001C?o00030000<ol0<ol0008co`000`000?ooooooo`15oooo0013
oooo00<0000co`0co`00@S?o0003o`2I<ol0<ol003<co`00100003?o03?o000000Pco`00100003?o
03?o0000008co`0500000c?o00<00015oooo0014oooo00<0000co`0co`00@C?o0003o`2I<ol0<ol0
03<co`00100003?o03?o000000Pco`00100003?o03?o0000008co`00100003?o03?o000000@co`00
0`000?ooooooo`15oooo0014oooo00<0000co`0co`00@C?o0003o`2I<ol0<ol003<co`00100003?o
03?o000000Pco`00100003?o03?o000000<co`000`0003?o00000004<ol000<0003oooooool0AOoo
o`00AOooo`030000<ol0<ol0040co`000ol0VC?o03?o000d<ol00P0000Xco`0200001C?o00800004
<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol0040co`000ol0VC?o03?o001=<ol000<0
003oooooool0AOooo`00A_ooo`030000<ol0<ol003lco`000ol0VC?o03?o001=<ol000<0003ooooo
ool0AOooo`00A_ooo`030000<ol0<ol003lco`000ol0VC?o03?o001=<ol000<0003oooooool0AOoo
o`00Aoooo`030000<ol0<ol003hco`000ol0VC?o03?o001=<ol000<0003oooooool0AOooo`00Aooo
o`030000<ol0<ol003hco`000ol0VC?o03?o001=<ol00P0004Koool004Soool00`0003?o03?o000m
<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool004Soool00`0003?o03?o000m<ol000?o
09Tco`0co`00CC?o00030000oooooooo04Goool004Woool00`0003?o03?o000l<ol000?o09Tco`0c
o`00CC?o00030000oooooooo04Goool004Woool00`0003?o03?o000l<ol000?o09Tco`0co`00CC?o
00030000oooooooo04Goool004[oool00`0003?o03?o000k<ol000?o09Tco`0co`00CC?o00030000
oooooooo04Goool004[oool00`0003?o03?o000k<ol000?o09Tco`0co`00CC?o00030000oooooooo
04Goool004_oool00`0003?o03?o000j<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool0
04_oool00`0003?o03?o000j<ol000?o09Tco`0co`00CC?o00800016oooo001<ooooS3?o04Soool0
04cooon<<ol0B?ooo`00C?oooh`co`18oooo001=ooooRc?o04Soool004gooon;<ol0B?ooo`00C_oo
obXco`000`0003?o03?o000W<ol000<0000co`0co`00<c?o04Soool004kooolY<ol000<0000co`0c
o`0023?o00030000<ol0<ol001hco`000`0003?o03?o000b<ol0B?ooo`00CoooobPco`000`0003?o
03?o0002<ol00P0000@co`000`0003?o03?o0006<ol00P0000@co`0200000c?o00D0000013?o0000
0000000000@co`000`0003?o03?o000b<ol0B?ooo`00CoooobPco`001@0003?o03?o03?o00000002
<ol000<0000co`0co`000S?o00030000<ol0<ol000@co`00100003?o03?o000000Xco`000`0003?o
03?o0003<ol000<0000co`0co`000S?o00030000<ol0<ol0038co`18oooo001?oooo9c?o00030000
<ol0<ol0008co`000`0003?o03?o000<<ol000@0000co`0co`00000:<ol000<0000co`0co`000S?o
00<00004<ol000<0000co`0co`00<C?o04Soool0053ooolW<ol000<0000co`0co`001@0000/co`00
100003?o03?o000000Xco`001@0003?o03?o03?o00000002<ol000D0000co`0co`0co`000000=3?o
04Soool0053ooolW<ol000D0000co`0co`0co`0000003S?o00040000<ol0<ol000002S?o00050000
<ol0<ol0<ol00000008co`001@0003?o03?o03?o0000000d<ol0B?ooo`00D?ooobPco`000`0003?o
03?o000@<ol00P0000Xco`02000013?o00<00002<ol000<0000co`0co`00<c?o04Soool0057ooon7
<ol0B?ooo`00DOooohLco`18oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.46172 .30902 L
.47106 .30902 L
.47567 .30902 L
.47791 .30902 L
.47889 .30902 L
.47994 .30902 L
s
.47994 .30902 m
.47995 .61803 L
s
0 .4 1 r
.02381 .28404 m
.06244 .28019 L
.10458 .27529 L
.14415 .26994 L
.18221 .26399 L
.22272 .25665 L
.26171 .24844 L
.30316 .23828 L
.34309 .22684 L
.3815 .21404 L
.42237 .19814 L
.44268 .18923 L
.46172 .18019 L
.47106 .17549 L
.47567 .17311 L
.47791 .17193 L
.47889 .17142 L
.47994 .17085 L
.48116 .30902 L
.48231 .30902 L
.48352 .30902 L
.48484 .30902 L
.48554 .30902 L
.48619 .30902 L
.48688 .30902 L
.48762 .30902 L
.48831 .30902 L
.48896 .30902 L
.49018 .30902 L
.49131 .30902 L
.49251 .30902 L
.49354 .30902 L
.49467 .30902 L
.49588 .30902 L
.49719 .30902 L
.49842 .30902 L
.49955 .30902 L
.50083 .30902 L
.50203 .30902 L
.50313 .30902 L
.50429 .30902 L
.50556 .30902 L
.50672 .30902 L
.50798 .30902 L
.50869 .30902 L
.50935 .30902 L
.51053 .30902 L
.51165 .30902 L
.51266 .30902 L
.51375 .30902 L
Mistroke
.51494 .30902 L
.5162 .30902 L
.5174 .30902 L
.51848 .30902 L
.51977 .30902 L
.52097 .30902 L
.52223 .30902 L
.52289 .30902 L
.5236 .30902 L
.52438 .30902 L
.52511 .30902 L
.52577 .30902 L
.52649 .30902 L
.52716 .30902 L
.52787 .30902 L
.52914 .30902 L
.53033 .30902 L
.5316 .30902 L
.53281 .30902 L
.53391 .30902 L
.53456 .30902 L
.53524 .30902 L
.53648 .30902 L
.53777 .30902 L
.53851 .30902 L
.53918 .30902 L
.54037 .30902 L
.54149 .30902 L
.54272 .30902 L
.54404 .30902 L
.5447 .30902 L
.54542 .30902 L
.54673 .30902 L
.548 .30902 L
.54918 .30902 L
.55131 .30902 L
.55251 .30902 L
.55365 .30902 L
.55484 .30902 L
.55593 .30902 L
.55713 .30902 L
.5584 .30902 L
.5597 .30902 L
.56089 .30902 L
.56154 .30902 L
.56225 .30902 L
.56354 .30902 L
.56475 .30902 L
.56603 .30902 L
.56713 .30902 L
Mistroke
.56833 .30902 L
.56906 .30902 L
.56975 .30902 L
.57104 .30902 L
.57177 .30902 L
.57255 .30902 L
.57328 .30902 L
.57395 .30902 L
.57525 .30902 L
.57647 .30902 L
.57778 .30902 L
.57853 .30902 L
.57921 .30902 L
.58047 .30902 L
.58167 .30902 L
.58275 .30902 L
.58391 .30902 L
.58518 .30902 L
.58583 .30902 L
.58653 .30902 L
.58778 .30902 L
.58896 .30902 L
.59007 .30902 L
.59124 .30902 L
.59224 .30902 L
.59333 .30902 L
.59451 .30902 L
.59578 .30902 L
.59697 .30902 L
.59805 .30902 L
.61872 .30902 L
.63792 .30902 L
.63923 .30902 L
.63995 .30902 L
.64064 .30902 L
.64127 .30902 L
.64196 .30902 L
.64318 .30902 L
.64384 .30902 L
.64455 .30902 L
.64583 .30902 L
.64662 .30902 L
.64736 .30902 L
.64802 .30902 L
.64874 .30902 L
.64995 .30902 L
.65064 .30902 L
.65127 .30902 L
.65256 .30902 L
.65329 .30902 L
Mistroke
.65394 .30902 L
.65512 .30902 L
.6564 .30902 L
.6576 .30902 L
.65872 .30902 L
.65996 .30902 L
.66115 .30902 L
.66221 .30902 L
.66337 .30902 L
.66463 .30902 L
.66533 .30902 L
.66597 .30902 L
.66721 .30902 L
.66838 .30902 L
.66948 .30902 L
.67065 .30902 L
.67164 .30902 L
.67273 .30902 L
.6739 .30902 L
.67516 .30902 L
.67635 .30902 L
.67744 .30902 L
.6787 .30902 L
.67989 .30902 L
.68114 .30902 L
.6818 .30902 L
.68251 .30902 L
.68323 .30902 L
.684 .30902 L
.68466 .30902 L
.68537 .30902 L
.68604 .30902 L
.68675 .30902 L
.68802 .30902 L
.68932 .30902 L
.69005 .30902 L
.69073 .30902 L
.69197 .30902 L
.69328 .30902 L
.69446 .30902 L
.69556 .30902 L
.69806 .30902 L
.6993 .30902 L
.70047 .30902 L
.70111 .30902 L
.70181 .30902 L
.70303 .30902 L
.70375 .30902 L
.7045 .30902 L
.70514 .30902 L
Mistroke
.70585 .30902 L
.7065 .30902 L
.7072 .30902 L
.70846 .30902 L
.70973 .30902 L
.71045 .30902 L
.71111 .30902 L
.71363 .30902 L
.71834 .30902 L
.72733 .30902 L
.72839 .30902 L
.72951 .30902 L
.73074 .30902 L
.73187 .30902 L
.7331 .30902 L
.7338 .30902 L
.73445 .30902 L
.73562 .30902 L
.73687 .30902 L
.73811 .30902 L
.73881 .30902 L
.73947 .30902 L
.74016 .30902 L
.74079 .30902 L
.74152 .30902 L
.74221 .30902 L
.74343 .30902 L
.74457 .30902 L
.74581 .30902 L
.74713 .30902 L
.74844 .30902 L
.74918 .30902 L
.74985 .30902 L
.75118 .30902 L
.75241 .30902 L
.75307 .30902 L
.75377 .30902 L
.75455 .30902 L
.75525 .30902 L
.75599 .30902 L
.75679 .30902 L
.75755 .30902 L
.75825 .30902 L
.75941 .30902 L
.76065 .30902 L
.76183 .30902 L
.7629 .30902 L
.76416 .30902 L
.76487 .30902 L
.76553 .30902 L
Mistroke
.76674 .30902 L
.76803 .30902 L
.76869 .30902 L
.76938 .30902 L
.77014 .30902 L
.77084 .30902 L
.77209 .30902 L
.77281 .30902 L
.77347 .30902 L
.77472 .30902 L
.77586 .30902 L
.77717 .30902 L
.77841 .30902 L
.77955 .30902 L
.78078 .30902 L
.78194 .30902 L
.783 .30902 L
.78418 .30902 L
.78547 .30902 L
.78617 .30902 L
.78683 .30902 L
.78806 .30902 L
.79063 .30902 L
.79338 .30902 L
.79832 .30902 L
.81674 .30902 L
.85522 .30902 L
.89614 .30902 L
.93556 .30902 L
.97345 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool008Soool00`1Vooooooooo`1=oooo00<0
003oooooool0AOooo`00Q_ooo`<0I_m?oooo00<0003oooooool0AOooo`00QOooo`0406Kooooooooo
06Ko=_ooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0003oooooool0AOooo`00Pooo
o`80I_l3oooo00<0I_ooooooool0<oooo`040000oooooooo00002?ooo`040000oooooooo00000_oo
o`030000oooooooo00Goool00`000?ooooooo`15oooo0021oooo0P1Vo`Goool00`1Vooooooooo`0c
oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`<00015
oooo001noooo0`1Vo`Ooool00`1Vooooooooo`0]oooo100000;oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00Noooo`<0I_l:
oooo00<0I_ooooooool0<oooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000
oooooooo00001?ooo`030000oooooooo04Goool007Soool306Ko3Oooo`0306Kooooooooo03Coool2
00002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo001foooo0P1Voa3oool00`1Voooo
ooooo`1=oooo00<0003oooooool0AOooo`00Loooo`<0I_lBoooo00<0I_ooooooool0COooo`030000
oooooooo04Goool0077oool206Ko5Oooo`0306Kooooooooo04goool00`000?ooooooo`15oooo001^
oooo0`1VoaOoool00`1Vooooooooo`1=oooo00<0003oooooool0AOooo`00K?ooo`80I_lJoooo00<0
I_ooooooool0COooo`800016oooo001Yoooo0`1Voacoool00`1Vooooooooo`1=oooo00<0003ooooo
ool0AOooo`00Ioooo`80I_lOoooo00<0I_ooooooool0COooo`030000oooooooo04Goool006Coool3
06Ko8Oooo`0306Kooooooooo04goool00`000?ooooooo`15oooo001Poooo101VobCoool00`1Voooo
ooooo`1=oooo00<0003oooooool0AOooo`00G?ooo`@0I_lXoooo00<0I_ooooooool0COooo`030000
oooooooo04Goool005Soool406Ko;?ooo`0306Kooooooooo04goool00`000?ooooooo`15oooo001B
oooo1P1Voc7oool00`1Vooooooooo`1<oooo00<0003oooooool0AOooo`00COooo`D0I_lgoooo00<0
I_ooooooool0C?ooo`800016oooo0018oooo1@1Voccoool00`1Vooooooooo`1<oooo00<0003ooooo
ool0AOooo`00@oooo`D0I_m1oooo00<0I_ooooooool0C?ooo`030000oooooooo04Goool003koool5
06KoA_ooo`0306Kooooooooo04coool00`000?ooooooo`15oooo000ioooo1@1Vod_oool00`1Voooo
ooooo`1<oooo00<0003oooooool0AOooo`004_ooo`@0000Noooo1@1Vo`Goool500000_ooo`800004
oooo0P0002Woool500003_ooo`0306Kooooooooo01Koool200001?ooo`800004oooo0P0002Soool0
0`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003oooooool05ooo
o`P0I_l<oooo00<0003oooooool01oooo`040000oooooooo0000:_ooo`030000oooooooo00koool0
0`1Vooooooooo`0Eoooo00@0003oooooool00008oooo00@0003oooooool0000Woooo00<0003ooooo
ool09oooo`040000oooooooo00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo
00koool806Ko5?ooo`030000oooooooo00[oool00`000?ooooooo`0Xoooo00<0003oooooool03_oo
o`0306Kooooooooo01Goool010000?ooooooo`0000_oool00`000?ooooooo`0Uoooo00<0003ooooo
ool09oooo`040000oooooooo00002oooo`030000oooooooo00coool000coool400001?ooo`030000
oooooooo00Soool506Ko5?ooo`@00004oooo00<0003oooooool02?ooo`80000Soooo100000Coool0
0`000?ooooooo`0>oooo00<0I_ooooooool03oooo`@00002oooo00@0003oooooool00009oooo0P00
02Soool20000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00D0003oooooool0003o
ool0201Vob7oool00`000?ooooooo`08oooo00<0003oooooool0:_ooo`030000oooooooo00koool0
0`1Vooooooooo`0Eoooo00@0003oooooool00009oooo00<0003oooooool09oooo`030000oooooooo
02Ooool010000?ooooooo`0000Woool00`000?ooooooo`0>oooo000Aoooo0P1Vo`80000206Ko:?oo
o`80000:oooo0`0002Woool200004?ooo`0306Kooooooooo01Koool200002_ooo`<0000Woooo00<0
003oooooool0:?ooo`80000:oooo0`0000koool008Woool00`1Vooooooooo`1<oooo00<0003ooooo
ool0AOooo`00ROooo`0306Kooooooooo04coool00`000?ooooooo`15oooo0029oooo00<0I_oooooo
ool0C?ooo`030000oooooooo04Goool008Woool00`1Vooooooooo`1<oooo00<0003oooooool0AOoo
o`00ROooo`0306Kooooooooo04coool00`000?ooooooo`15oooo000;ooooo`0000L0000?oooo000A
oooo00<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0006<ol000?o09T0000co`0023?o00030000<ol0<ol000Hco`000`0003?o03?o0007
<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo01?oool0
017oool00`0003?o03?o000_<ol000<0000co`0co`00;c?o00030000<ol0<ol0010co`000ol0VC?o
03?o000K<ol000<0000co`0co`00;c?o00030000oooooooo02ooool00`000?ooooooo`0Coooo000A
ooooMc?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo000AooooMc?o0003o`2I<ol0<ol0
04dco`000`000?ooooooo`15oooo000AooooMc?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15
oooo000AooooMc?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo000AooooMc?o0003o`2I
<ol0<ol004dco`000`000?ooooooo`15oooo000AooooMc?o0003o`2I<ol0<ol004dco`020000A_oo
o`004OooogLco`000ol0VC?o03?o001=<ol000<0003oooooool0AOooo`004OooogLco`000ol0VC?o
03?o001=<ol000<0003oooooool0AOooo`004OooogLco`000ol0VC?o03?o001=<ol000<0003ooooo
ool0AOooo`004OooogLco`000ol0VC?o03?o001=<ol000<0003oooooool0AOooo`004OooogLco`00
0ol0VC?o03?o001=<ol000<0003oooooool0AOooo`004OooogLco`000ol0VC?o03?o001=<ol000<0
003oooooool0AOooo`004OooogLco`000ol0VC?o03?o001=<ol000<0003oooooool0AOooo`004Ooo
o`80001e<ol000?o09Tco`0co`00CC?o00800016oooo000Coooo0P0007<co`000ol0VC?o03?o001=
<ol000<0003oooooool0AOooo`005Oooo`80001a<ol000?o09Tco`0co`00CC?o00030000oooooooo
04Goool001Ooool20000Kc?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo000Ioooo0P00
06dco`000ol0VC?o03?o001=<ol000<0003oooooool0AOooo`006oooo`80001[<ol000?o09Tco`0c
o`00CC?o00030000oooooooo04Goool001goool20000JC?o0003o`2I<ol0<ol004dco`000`000?oo
ooooo`15oooo000Ooooo00<0000co`0co`00IS?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15
oooo000Poooo00<0000co`0co`00IC?o0003o`2I<ol0<ol004dco`020000A_ooo`008Oooo`80001U
<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool002?oool00`0003?o03?o001R<ol000?o
09Tco`0co`00CC?o00030000oooooooo04Goool002Coool20000HS?o0003o`2I<ol0<ol004dco`00
0`000?ooooooo`15oooo000Voooo00<0000co`0co`00Gc?o0003o`2I<ol0<ol004dco`000`000?oo
ooooo`15oooo000Woooo00<0000co`0co`00GS?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15
oooo000Xoooo00<0000co`0co`00GC?o0003o`2I<ol0<ol003@co`02000013?o00800004<ol00P00
00<co`04000013?o00030000oooooooo04Goool002Woool00`0003?o03?o001L<ol000?o09Tco`0c
o`00<c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00030000<ol0<ol000Dco`00
0`000?ooooooo`15oooo000Zoooo00<0000co`0co`00Fc?o0003o`2I<ol0<ol003<co`00100003?o
03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o0004<ol00`0004Goool002_oool2
0000Fc?o0003o`2I<ol0<ol003<co`00100003?o03?o000000Pco`00100003?o03?o000000@co`00
0`0003?o03?o0003<ol000<0003oooooool0AOooo`00;Oooo`030000<ol0<ol005Pco`000ol0VC?o
03?o000c<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000004
<ol000<0003oooooool0AOooo`00;_ooo`030000<ol0<ol005Lco`000ol0VC?o03?o000d<ol00P00
00Xco`02000013?o00800005<ol000<0003oooooool0AOooo`00;oooo`030000<ol0<ol005Hco`00
0ol0VC?o03?o001=<ol000<0003oooooool0AOooo`00<?ooo`030000<ol0<ol005Dco`000ol0VC?o
03?o001=<ol000<0003oooooool0AOooo`00<Oooo`030000<ol0<ol005@co`000ol0VC?o03?o001=
<ol000<0003oooooool0AOooo`00<_ooo`030000<ol0<ol005<co`000ol0VC?o03?o001=<ol000<0
003oooooool0AOooo`00<oooo`030000<ol0<ol0058co`000ol0VC?o03?o001=<ol00P0004Koool0
03?oool00`0003?o03?o001B<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool003Coool0
0`0003?o03?o001A<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool003Goool00`0003?o
03?o001@<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool003Koool00`0003?o03?o001?
<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool003Ooool00`0003?o03?o001><ol000?o
09Tco`0co`00CC?o00030000oooooooo04Goool003Soool00`0003?o03?o001=<ol000?o09Tco`0c
o`00CC?o00030000oooooooo04Goool003Soool00`0003?o03?o001=<ol000?o09Tco`0co`00CC?o
00030000oooooooo04Goool003Woool00`0003?o03?o001<<ol000?o09Tco`0co`00CC?o00800016
oooo000joooo00<0000co`0co`00Bc?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo000k
oooo00<0000co`0co`00BS?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo000loooo00<0
000co`0co`00BC?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo000loooo00<0000co`0c
o`00BC?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo000moooo00<0000co`0co`00B3?o
0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo000moooo00<0000co`0co`00B3?o0003o`2I
<ol0<ol004dco`000`000?ooooooo`15oooo000noooo00<0000co`0co`00Ac?o0003o`2I<ol0<ol0
04dco`000`000?ooooooo`15oooo000noooo00<0000co`0co`00Ac?o0003o`2I<ol0<ol004dco`00
0`000?ooooooo`15oooo000ooooo00<0000co`0co`00AS?o0003o`2I<ol0<ol004dco`020000A_oo
o`00?oooo`030000<ol0<ol004Hco`000ol0VC?o03?o001=<ol000<0003oooooool0AOooo`00@?oo
o`030000<ol0<ol004Dco`000ol0VC?o03?o001=<ol000<0003oooooool0AOooo`00@Oooo`030000
<ol0<ol004@co`000ol0VC?o03?o001=<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol0
04@co`000ol0VC?o03?o001=<ol000<0003oooooool0AOooo`00@_ooo`030000<ol0<ol004<co`00
0ol0VC?o03?o001=<ol000<0003oooooool0AOooo`00@_ooo`030000<ol0<ol004<co`000ol0VC?o
03?o000d<ol00P0000@co`02000013?o00800005<ol00`0000<co`000`000?ooooooo`15oooo0013
oooo00<0000co`0co`00@S?o0003o`2I<ol0<ol003<co`00100003?o03?o000000Pco`00100003?o
03?o000000Dco`000`0003?o03?o0002<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol0
048co`000ol0VC?o03?o000c<ol000@0000co`0co`000008<ol000@0000co`0co`000002<ol01@00
00<co`030000AOooo`00A?ooo`030000<ol0<ol0044co`000ol0VC?o03?o000c<ol000@0000co`0c
o`000008<ol000@0000co`0co`000002<ol000@0000co`0co`000004<ol000<0003oooooool0AOoo
o`00A?ooo`030000<ol0<ol0044co`000ol0VC?o03?o000c<ol000@0000co`0co`000008<ol000@0
000co`0co`000003<ol000<0000co`00000013?o00030000oooooooo04Goool004Goool00`0003?o
03?o0010<ol000?o09Tco`0co`00=3?o0080000:<ol00P0000Dco`02000013?o00030000oooooooo
04Goool004Goool00`0003?o03?o0010<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool0
04Koool00`0003?o03?o000o<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool004Koool0
0`0003?o03?o000o<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool004Ooool00`0003?o
03?o000n<ol000?o09Tco`0co`00CC?o00030000oooooooo04Goool004Ooool00`0003?o03?o000n
<ol000?o09Tco`0co`00CC?o00800016oooo0018oooo00<0000co`0co`00?C?o0003o`2I<ol0<ol0
04dco`000`000?ooooooo`15oooo0018oooo00<0000co`0co`00?C?o0003o`2I<ol0<ol004dco`00
0`000?ooooooo`15oooo0019oooo00<0000co`0co`00?3?o0003o`2I<ol0<ol004dco`000`000?oo
ooooo`15oooo0019oooo00<0000co`0co`00?3?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15
oooo001:oooo00<0000co`0co`00>c?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo001:
oooo00<0000co`0co`00>c?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo001;oooo00<0
000co`0co`00>S?o0003o`2I<ol0<ol004dco`000`000?ooooooo`15oooo001;oooo00<0000co`0c
o`00>S?o0003o`2I<ol0<ol004dco`020000A_ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool0
04cooon<<ol0B?ooo`00COoooh/co`18oooo001=ooooRc?o04Soool004koool]<ol000<0000co`0c
o`008C?o00030000<ol0<ol003Hco`18oooo001>oooo;3?o00030000<ol0<ol000Pco`000`0003?o
03?o000H<ol000<0000co`0co`00=C?o04Soool004ooool[<ol000<0000co`0co`000S?o00800004
<ol000<0000co`0co`001S?o00800004<ol00P0000<co`0400000c?o00030000<ol0<ol003Dco`18
oooo001?oooo:c?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0000co`0c
o`0013?o00040000<ol0<ol0000023?o00030000<ol0<ol000@co`000`0003?o03?o000e<ol0B?oo
o`00CoooobXco`000`0003?o03?o0002<ol000<0000co`0co`0033?o00040000<ol0<ol000002C?o
00030000<ol0<ol000@co`000`0003?o03?o000d<ol0B?ooo`00D?ooobXco`000`0003?o03?o0005
00002c?o00040000<ol0<ol000002S?o00030000<ol0<ol0008co`000`0003?o03?o000e<ol0B?oo
o`00D?ooobXco`001@0003?o03?o03?o0000000><ol000@0000co`0co`000008<ol000@0000co`0c
o`000003<ol000<0000co`0co`00=C?o04Soool0053oool[<ol000<0000co`0co`0043?o0080000:
<ol00P0000<co`000`0003?o03?o000f<ol0B?ooo`00DOooohLco`18oooo001AooooQc?o04Soool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.21) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.46172 .30902 L
.47106 .30902 L
.47567 .30902 L
.47994 .30902 L
.48231 .30902 L
.483 .30902 L
.48364 .30902 L
s
.48364 .30902 m
.48364 .61803 L
s
0 .4 1 r
.02381 .28276 m
.06244 .2787 L
.10458 .27356 L
.14415 .26793 L
.18221 .26168 L
.22272 .25396 L
.26171 .24533 L
.30316 .23464 L
.34309 .22261 L
.3815 .20915 L
.42237 .19244 L
.44268 .18306 L
.46172 .17356 L
.47106 .16862 L
.47567 .16612 L
.47994 .16375 L
.48231 .16242 L
.483 .16203 L
.48364 .16167 L
.48484 .30902 L
.48549 .30902 L
.48618 .30902 L
.48741 .30902 L
.48809 .30902 L
.48873 .30902 L
.48943 .30902 L
.49018 .30902 L
.49139 .30902 L
.4927 .30902 L
.49394 .30902 L
.49508 .30902 L
.49611 .30902 L
.49725 .30902 L
.49844 .30902 L
.49955 .30902 L
.50073 .30902 L
.50198 .30902 L
.50317 .30902 L
.50425 .30902 L
.50551 .30902 L
.50623 .30902 L
.50689 .30902 L
.5081 .30902 L
.50938 .30902 L
.51061 .30902 L
.51193 .30902 L
.51317 .30902 L
.51431 .30902 L
.51713 .30902 L
.51973 .30902 L
Mistroke
.52087 .30902 L
.52193 .30902 L
.52316 .30902 L
.52428 .30902 L
.52553 .30902 L
.52616 .30902 L
.52686 .30902 L
.52808 .30902 L
.52923 .30902 L
.53032 .30902 L
.53132 .30902 L
.53247 .30902 L
.53356 .30902 L
.53472 .30902 L
.5358 .30902 L
.53698 .30902 L
.53824 .30902 L
.53938 .30902 L
.54063 .30902 L
.54193 .30902 L
.54314 .30902 L
.54428 .30902 L
.54532 .30902 L
.54651 .30902 L
.54763 .30902 L
.54886 .30902 L
.55016 .30902 L
.55127 .30902 L
.55249 .30902 L
.55524 .30902 L
.55644 .30902 L
.55775 .30902 L
.55897 .30902 L
.56009 .30902 L
.56117 .30902 L
.56231 .30902 L
.56351 .30902 L
.56464 .30902 L
.56587 .30902 L
.56657 .30902 L
.56721 .30902 L
.56827 .30902 L
.56926 .30902 L
.57035 .30902 L
.57151 .30902 L
.57273 .30902 L
.57388 .30902 L
.57492 .30902 L
.57604 .30902 L
.57727 .30902 L
Mistroke
.57839 .30902 L
.57969 .30902 L
.58092 .30902 L
.58206 .30902 L
.58311 .30902 L
.58426 .30902 L
.58549 .30902 L
.58675 .30902 L
.58792 .30902 L
.58915 .30902 L
.59049 .30902 L
.59119 .30902 L
.59185 .30902 L
.59261 .30902 L
.5933 .30902 L
.59455 .30902 L
.59525 .30902 L
.59589 .30902 L
.5972 .30902 L
.59795 .30902 L
.59865 .30902 L
.59939 .30902 L
.60006 .30902 L
.6008 .30902 L
.60158 .30902 L
.60222 .30902 L
.6029 .30902 L
.60413 .30902 L
.60489 .30902 L
.6056 .30902 L
.60624 .30902 L
.60693 .30902 L
.60813 .30902 L
.60882 .30902 L
.60946 .30902 L
.61075 .30902 L
.61147 .30902 L
.61213 .30902 L
.61331 .30902 L
.61459 .30902 L
.61581 .30902 L
.61693 .30902 L
.61822 .30902 L
.61887 .30902 L
.61959 .30902 L
.62086 .30902 L
.62203 .30902 L
.62274 .30902 L
.6234 .30902 L
.62411 .30902 L
Mistroke
.62488 .30902 L
.62555 .30902 L
.62626 .30902 L
.62753 .30902 L
.62871 .30902 L
.62998 .30902 L
.63118 .30902 L
.63228 .30902 L
.63356 .30902 L
.63424 .30902 L
.63496 .30902 L
.63628 .30902 L
.63751 .30902 L
.63876 .30902 L
.63992 .30902 L
.64119 .30902 L
.64183 .30902 L
.64253 .30902 L
.64372 .30902 L
.64498 .30902 L
.64618 .30902 L
.64727 .30902 L
.6484 .30902 L
.64945 .30902 L
.6506 .30902 L
.65182 .30902 L
.65288 .30902 L
.65387 .30902 L
.65496 .30902 L
.65613 .30902 L
.65738 .30902 L
.65853 .30902 L
.65984 .30902 L
.66108 .30902 L
.66224 .30902 L
.6633 .30902 L
.66446 .30902 L
.6657 .30902 L
.66694 .30902 L
.66763 .30902 L
.66827 .30902 L
.6695 .30902 L
.67068 .30902 L
.67134 .30902 L
.67204 .30902 L
.6733 .30902 L
.67407 .30902 L
.6748 .30902 L
.67546 .30902 L
.67616 .30902 L
Mistroke
.67748 .30902 L
.67871 .30902 L
.67942 .30902 L
.68006 .30902 L
.68151 .30902 L
.68218 .30902 L
.6829 .30902 L
.68368 .30902 L
.68441 .30902 L
.68571 .30902 L
.68646 .30902 L
.68715 .30902 L
.68839 .30902 L
.68969 .30902 L
.6908 .30902 L
.69202 .30902 L
.69333 .30902 L
.69407 .30902 L
.69473 .30902 L
.69603 .30902 L
.69726 .30902 L
.69841 .30902 L
.69966 .30902 L
.70083 .30902 L
.7019 .30902 L
.70315 .30902 L
.70386 .30902 L
.70452 .30902 L
.7058 .30902 L
.707 .30902 L
.70814 .30902 L
.70937 .30902 L
.71004 .30902 L
.71074 .30902 L
.71199 .30902 L
.7133 .30902 L
.71453 .30902 L
.71523 .30902 L
.71587 .30902 L
.7166 .30902 L
.7173 .30902 L
.71837 .30902 L
.71954 .30902 L
.72076 .30902 L
.72191 .30902 L
.72298 .30902 L
.72395 .30902 L
.72508 .30902 L
.72616 .30902 L
.72731 .30902 L
Mistroke
.72854 .30902 L
.7297 .30902 L
.73075 .30902 L
.73199 .30902 L
.73269 .30902 L
.73333 .30902 L
.73451 .30902 L
.73576 .30902 L
.73698 .30902 L
.73763 .30902 L
.73831 .30902 L
.73956 .30902 L
.74072 .30902 L
.74183 .30902 L
.74287 .30902 L
.74401 .30902 L
.74525 .30902 L
.74648 .30902 L
.74718 .30902 L
.74783 .30902 L
.74914 .30902 L
.74982 .30902 L
.75055 .30902 L
.75186 .30902 L
.75309 .30902 L
.7543 .30902 L
.75541 .30902 L
.75646 .30902 L
.7576 .30902 L
.75867 .30902 L
.75965 .30902 L
.76079 .30902 L
.76204 .30902 L
.76322 .30902 L
.76431 .30902 L
.76555 .30902 L
.76671 .30902 L
.76776 .30902 L
.76888 .30902 L
.77011 .30902 L
.77142 .30902 L
.77253 .30902 L
.77374 .30902 L
.77505 .30902 L
.77626 .30902 L
.77757 .30902 L
.77831 .30902 L
.779 .30902 L
.78017 .30902 L
.78142 .30902 L
Mistroke
.7821 .30902 L
.78275 .30902 L
.78398 .30902 L
.7851 .30902 L
.78629 .30902 L
.78843 .30902 L
.7933 .30902 L
.81423 .30902 L
.85578 .30902 L
.89583 .30902 L
.93435 .30902 L
.97533 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.21) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15oooo0028oooo0P1V
odkoool00`000?ooooooo`15oooo0027oooo00<0I_ooool0I_l0C_ooo`030000oooooooo04Goool0
08Koool0101Vooooooooo`1Vodkoool00`000?ooooooo`15oooo0023oooo0`1Vo`?oool00`1Voooo
ooooo`1<oooo00<0003oooooool0AOooo`00POooo`80I_l6oooo00<0I_ooooooool0<oooo`800004
oooo0P0000Coool200000oooo`@00004oooo00<0003oooooool0AOooo`00Ooooo`80I_l8oooo00<0
I_ooooooool0<_ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000oooooooo
00Goool00`000?ooooooo`15oooo001moooo0P1Vo`[oool00`1Vooooooooo`0boooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`<00015oooo001koooo0P1V
o`coool00`1Vooooooooo`0/oooo100000;oool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00N?ooo`<0I_l>oooo00<0I_oooooo
ool0<_ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?oo
o`030000oooooooo04Goool007Koool206Ko4Oooo`0306Kooooooooo03?oool200002_ooo`800004
oooo0P0000Goool00`000?ooooooo`15oooo001coooo0`1Voa?oool00`1Vooooooooo`1<oooo00<0
003oooooool0AOooo`00LOooo`80I_lFoooo00<0I_ooooooool0C?ooo`030000oooooooo04Goool0
06koool306Ko6?ooo`0306Kooooooooo04coool00`000?ooooooo`15oooo001/oooo0P1Voa_oool0
0`1Vooooooooo`1<oooo00<0003oooooool0AOooo`00JOooo`<0I_lMoooo00<0I_ooooooool0C?oo
o`800016oooo001Woooo0P1Vob3oool00`1Vooooooooo`1<oooo00<0003oooooool0AOooo`00I?oo
o`<0I_lRoooo00<0I_ooooooool0C?ooo`030000oooooooo04Goool0063oool406Ko9Oooo`0306Ko
oooooooo04coool00`000?ooooooo`15oooo001Loooo101VobWoool00`1Vooooooooo`1<oooo00<0
003oooooool0AOooo`00FOooo`<0I_l]oooo00<0I_ooooooool0C?ooo`030000oooooooo04Goool0
05Goool406Ko<Oooo`0306Kooooooooo04_oool00`000?ooooooo`15oooo001Aoooo101VocGoool0
0`1Vooooooooo`1;oooo00<0003oooooool0AOooo`00COooo`@0I_lioooo00<0I_ooooooool0Booo
o`800016oooo0018oooo1@1Vocgoool00`1Vooooooooo`1;oooo00<0003oooooool0AOooo`00@ooo
o`D0I_m2oooo00<0I_ooooooool0Boooo`030000oooooooo04Goool003koool506KoAoooo`0306Ko
oooooooo04_oool00`000?ooooooo`15oooo000goooo1`1Vodcoool00`1Vooooooooo`1;oooo00<0
003oooooool0AOooo`004_ooo`@0000Ioooo201Vo`Ooool500000_ooo`800004oooo0P0002Woool5
00003oooo`0306Kooooooooo01Goool200001?ooo`800004oooo0P0002Soool00`000?ooooooo`0X
oooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003oooooool05?ooo`H0I_lAoooo00<0
003oooooool01oooo`040000oooooooo0000:_ooo`030000oooooooo00ooool00`1Vooooooooo`0D
oooo00@0003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000
oooooooo00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo00coool706Ko5ooo
o`030000oooooooo00[oool00`000?ooooooo`0Xoooo00<0003oooooool03oooo`0306Kooooooooo
01Coool010000?ooooooo`0000_oool00`000?ooooooo`0Uoooo00<0003oooooool09oooo`040000
oooooooo00002oooo`030000oooooooo00coool000coool400001?ooo`030000oooooooo00/0I_lF
oooo100000Coool00`000?ooooooo`08oooo0P0002?oool400001?ooo`030000oooooooo00ooool0
0`1Vooooooooo`0>oooo100000;oool010000?ooooooo`0000Woool20000:?ooo`80000Xoooo00@0
003oooooool00009oooo0P0000ooool0017oool01P1Vo`00001Vo`1Vo`00001VobWoool00`000?oo
ooooo`08oooo00<0003oooooool0:_ooo`030000oooooooo00ooool00`1Vooooooooo`0Doooo00@0
003oooooool00009oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`00
00Woool00`000?ooooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P00017oool0
0`1Vooooooooo`0Eoooo0P0000[oool300009oooo`030000oooooooo02Soool200002_ooo`<0000>
oooo002:oooo00<0I_ooooooool0Boooo`030000oooooooo04Goool008[oool00`1Vooooooooo`1;
oooo00<0003oooooool0AOooo`00R_ooo`0306Kooooooooo04_oool00`000?ooooooo`15oooo002:
oooo00<0I_ooooooool0Boooo`030000oooooooo04Goool008[oool00`1Vooooooooo`1;oooo00<0
003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0co`00;c?o00030000
<ol0<ol002lco`000`0003?o03?o000A<ol000?o09Tco`0co`006S?o00030000<ol0<ol002lco`00
0`000?ooooooo`0_oooo00<0003oooooool04oooo`004OooogPco`000ol0VC?o03?o001<<ol000<0
003oooooool0AOooo`004OooogPco`000ol0VC?o03?o001<<ol000<0003oooooool0AOooo`004Ooo
ogPco`000ol0VC?o03?o001<<ol000<0003oooooool0AOooo`004OooogPco`000ol0VC?o03?o001<
<ol000<0003oooooool0AOooo`004OooogPco`000ol0VC?o03?o001<<ol000<0003oooooool0AOoo
o`004OooogPco`000ol0VC?o03?o001<<ol00P0004Koool0017ooomh<ol000?o09Tco`0co`00C3?o
00030000oooooooo04Goool0017ooomh<ol000?o09Tco`0co`00C3?o00030000oooooooo04Goool0
017ooomh<ol000?o09Tco`0co`00C3?o00030000oooooooo04Goool0017ooomh<ol000?o09Tco`0c
o`00C3?o00030000oooooooo04Goool0017ooomh<ol000?o09Tco`0co`00C3?o00030000oooooooo
04Goool0017ooomh<ol000?o09Tco`0co`00C3?o00030000oooooooo04Goool0017ooomh<ol000?o
09Tco`0co`00C3?o00030000oooooooo04Goool0017oool20000MS?o0003o`2I<ol0<ol004`co`02
0000A_ooo`004oooo`80001d<ol000?o09Tco`0co`00C3?o00030000oooooooo04Goool001Goool2
0000LS?o0003o`2I<ol0<ol004`co`000`000?ooooooo`15oooo000Goooo0P00070co`000ol0VC?o
03?o001<<ol000<0003oooooool0AOooo`006Oooo`80001^<ol000?o09Tco`0co`00C3?o00030000
oooooooo04Goool001_oool20000K3?o0003o`2I<ol0<ol004`co`000`000?ooooooo`15oooo000M
oooo0P0006Xco`000ol0VC?o03?o001<<ol000<0003oooooool0AOooo`007oooo`030000<ol0<ol0
06Lco`000ol0VC?o03?o001<<ol000<0003oooooool0AOooo`008?ooo`030000<ol0<ol006Hco`00
0ol0VC?o03?o001<<ol00P0004Koool0027oool20000IS?o0003o`2I<ol0<ol004`co`000`000?oo
ooooo`15oooo000Soooo00<0000co`0co`00Hc?o0003o`2I<ol0<ol004`co`000`000?ooooooo`15
oooo000Toooo0P0006<co`000ol0VC?o03?o001<<ol000<0003oooooool0AOooo`009_ooo`030000
<ol0<ol0060co`000ol0VC?o03?o001<<ol000<0003oooooool0AOooo`009oooo`030000<ol0<ol0
05lco`000ol0VC?o03?o001<<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol005hco`00
0ol0VC?o03?o000c<ol00P0000@co`02000013?o00800003<ol0100000@co`000`000?ooooooo`15
oooo000Yoooo00<0000co`0co`00GC?o0003o`2I<ol0<ol0038co`00100003?o03?o000000Pco`00
100003?o03?o0000008co`000`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_ooo`030000
<ol0<ol005`co`000ol0VC?o03?o000b<ol000@0000co`0co`000008<ol000@0000co`0co`000003
<ol000<0000co`0co`0013?o00<00015oooo000[oooo0P0005`co`000ol0VC?o03?o000b<ol000@0
000co`0co`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o00030000oooooooo
04Goool002goool00`0003?o03?o001I<ol000?o09Tco`0co`00<S?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool002koool0
0`0003?o03?o001H<ol000?o09Tco`0co`00<c?o0080000:<ol00P0000@co`0200001C?o00030000
oooooooo04Goool002ooool00`0003?o03?o001G<ol000?o09Tco`0co`00C3?o00030000oooooooo
04Goool0033oool00`0003?o03?o001F<ol000?o09Tco`0co`00C3?o00030000oooooooo04Goool0
037oool00`0003?o03?o001E<ol000?o09Tco`0co`00C3?o00030000oooooooo04Goool003;oool0
0`0003?o03?o001D<ol000?o09Tco`0co`00C3?o00030000oooooooo04Goool003?oool00`0003?o
03?o001C<ol000?o09Tco`0co`00C3?o00800016oooo000coooo00<0000co`0co`00Dc?o0003o`2I
<ol0<ol004`co`000`000?ooooooo`15oooo000doooo00<0000co`0co`00DS?o0003o`2I<ol0<ol0
04`co`000`000?ooooooo`15oooo000eoooo00<0000co`0co`00DC?o0003o`2I<ol0<ol004`co`00
0`000?ooooooo`15oooo000foooo00<0000co`0co`00D3?o0003o`2I<ol0<ol004`co`000`000?oo
ooooo`15oooo000goooo00<0000co`0co`00Cc?o0003o`2I<ol0<ol004`co`000`000?ooooooo`15
oooo000hoooo00<0000co`0co`00CS?o0003o`2I<ol0<ol004`co`000`000?ooooooo`15oooo000h
oooo00<0000co`0co`00CS?o0003o`2I<ol0<ol004`co`000`000?ooooooo`15oooo000ioooo00<0
000co`0co`00CC?o0003o`2I<ol0<ol004`co`020000A_ooo`00>_ooo`030000<ol0<ol004`co`00
0ol0VC?o03?o001<<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol004/co`000ol0VC?o
03?o001<<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol004Xco`000ol0VC?o03?o001<
<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol004Xco`000ol0VC?o03?o001<<ol000<0
003oooooool0AOooo`00?Oooo`030000<ol0<ol004Tco`000ol0VC?o03?o001<<ol000<0003ooooo
ool0AOooo`00?Oooo`030000<ol0<ol004Tco`000ol0VC?o03?o001<<ol000<0003oooooool0AOoo
o`00?_ooo`030000<ol0<ol004Pco`000ol0VC?o03?o001<<ol000<0003oooooool0AOooo`00?_oo
o`030000<ol0<ol004Pco`000ol0VC?o03?o001<<ol000<0003oooooool0AOooo`00?oooo`030000
<ol0<ol004Lco`000ol0VC?o03?o001<<ol00P0004Koool003ooool00`0003?o03?o0017<ol000?o
09Tco`0co`00C3?o00030000oooooooo04Goool0043oool00`0003?o03?o0016<ol000?o09Tco`0c
o`00C3?o00030000oooooooo04Goool0047oool00`0003?o03?o0015<ol000?o09Tco`0co`00C3?o
00030000oooooooo04Goool0047oool00`0003?o03?o0015<ol000?o09Tco`0co`00C3?o00030000
oooooooo04Goool004;oool00`0003?o03?o0014<ol000?o09Tco`0co`00C3?o00030000oooooooo
04Goool004;oool00`0003?o03?o0014<ol000?o09Tco`0co`00<c?o00800004<ol00P0000@co`02
00001C?o00<00003<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol004<co`000ol0VC?o
03?o000b<ol000@0000co`0co`000008<ol000@0000co`0co`000005<ol000<0000co`0co`000S?o
00030000oooooooo04Goool004?oool00`0003?o03?o0013<ol000?o09Tco`0co`00<S?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool00`0003?o
03?o0012<ol000?o09Tco`0co`00<S?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o
00040000<ol0<ol0000013?o00030000oooooooo04Goool004Coool00`0003?o03?o0012<ol000?o
09Tco`0co`00<S?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol00000
00@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`00@C?o0003o`2I<ol0<ol003<co`02
00002S?o00800005<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`00@C?o
0003o`2I<ol0<ol004`co`000`000?ooooooo`15oooo0016oooo00<0000co`0co`00@3?o0003o`2I
<ol0<ol004`co`000`000?ooooooo`15oooo0016oooo00<0000co`0co`00@3?o0003o`2I<ol0<ol0
04`co`000`000?ooooooo`15oooo0017oooo00<0000co`0co`00?c?o0003o`2I<ol0<ol004`co`00
0`000?ooooooo`15oooo0017oooo00<0000co`0co`00?c?o0003o`2I<ol0<ol004`co`020000A_oo
o`00B?ooo`030000<ol0<ol003hco`000ol0VC?o03?o001<<ol000<0003oooooool0AOooo`00B?oo
o`030000<ol0<ol003hco`000ol0VC?o03?o001<<ol000<0003oooooool0AOooo`00BOooo`030000
<ol0<ol003dco`000ol0VC?o03?o001<<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol0
03dco`000ol0VC?o03?o001<<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol003`co`00
0ol0VC?o03?o001<<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol003`co`000ol0VC?o
03?o001<<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol003/co`000ol0VC?o03?o001<
<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol003/co`000ol0VC?o03?o001<<ol00P00
04Koool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;<ol0B?oo
o`00COoooh/co`18oooo001>oooo:S?o00030000<ol0<ol002Lco`000`0003?o03?o000c<ol0B?oo
o`00C_ooobTco`000`0003?o03?o0008<ol000<0000co`0co`007S?o00030000<ol0<ol0038co`18
oooo001?oooo:3?o00030000<ol0<ol0008co`02000013?o00030000<ol0<ol000Hco`02000013?o
00800003<ol01000008co`0500000S?o00030000<ol0<ol0038co`18oooo001?oooo:3?o00050000
<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0000co`0co`0013?o00040000<ol0<ol0
000023?o00030000<ol0<ol000Dco`000`0003?o03?o0002<ol000<0000co`0co`00<S?o04Soool0
04oooolW<ol000<0000co`0co`000S?o00030000<ol0<ol000`co`00100003?o03?o000000Tco`00
0`0003?o03?o0004<ol000<0000co`0co`000c?o00030000<ol0<ol0034co`18oooo001@oooo9c?o
00030000<ol0<ol000D0000;<ol000@0000co`0co`00000:<ol000<0000co`0co`000c?o00030000
<ol0<ol0008co`000`0003?o03?o000b<ol0B?ooo`00D?ooobLco`001@0003?o03?o03?o0000000>
<ol000@0000co`0co`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000S?o00030000
<ol0<ol0038co`18oooo001@oooo:3?o00030000<ol0<ol0010co`0200002S?o00800004<ol00P00
00<co`000`0003?o03?o000c<ol0B?ooo`00DOooohLco`18oooo001AooooQc?o04Soool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.46172 .30902 L
.47106 .30902 L
.47994 .30902 L
.48484 .30902 L
.48618 .30902 L
.48692 .30902 L
.48761 .30902 L
.48826 .30902 L
s
.48826 .30902 m
.48826 .61803 L
s
0 .4 1 r
.02381 .28147 m
.06244 .27721 L
.10458 .27182 L
.14415 .26592 L
.18221 .25935 L
.22272 .25125 L
.26171 .2422 L
.30316 .23098 L
.34309 .21837 L
.3815 .20425 L
.42237 .18671 L
.44268 .17688 L
.46172 .16691 L
.47106 .16173 L
.47994 .15661 L
.48484 .15372 L
.48618 .15291 L
.48692 .15247 L
.48761 .15205 L
.48826 .15166 L
.48896 .30902 L
.49018 .30902 L
.49131 .30902 L
.49256 .30902 L
.49385 .30902 L
.49506 .30902 L
.4962 .30902 L
.49723 .30902 L
.49842 .30902 L
.49955 .30902 L
.50069 .30902 L
.50192 .30902 L
.50308 .30902 L
.50414 .30902 L
.50532 .30902 L
.50661 .30902 L
.50726 .30902 L
.50795 .30902 L
.50921 .30902 L
.5099 .30902 L
.51053 .30902 L
.51123 .30902 L
.51197 .30902 L
.51321 .30902 L
.51392 .30902 L
.51458 .30902 L
.51581 .30902 L
.51693 .30902 L
.51823 .30902 L
.51946 .30902 L
Mistroke
.52062 .30902 L
.52168 .30902 L
.52289 .30902 L
.52403 .30902 L
.5251 .30902 L
.52607 .30902 L
.52714 .30902 L
.52827 .30902 L
.52942 .30902 L
.53065 .30902 L
.5318 .30902 L
.53286 .30902 L
.53409 .30902 L
.53479 .30902 L
.53544 .30902 L
.53662 .30902 L
.53788 .30902 L
.53902 .30902 L
.54027 .30902 L
.54157 .30902 L
.54279 .30902 L
.54392 .30902 L
.54496 .30902 L
.54615 .30902 L
.54728 .30902 L
.54851 .30902 L
.54981 .30902 L
.55091 .30902 L
.55213 .30902 L
.55281 .30902 L
.55354 .30902 L
.55424 .30902 L
.55488 .30902 L
.5561 .30902 L
.55739 .30902 L
.55851 .30902 L
.55956 .30902 L
.56071 .30902 L
.56195 .30902 L
.5632 .30902 L
.56451 .30902 L
.56562 .30902 L
.56685 .30902 L
.56791 .30902 L
.56891 .30902 L
.56994 .30902 L
.57109 .30902 L
.57224 .30902 L
.57348 .30902 L
.57463 .30902 L
Mistroke
.57568 .30902 L
.57698 .30902 L
.57771 .30902 L
.57839 .30902 L
.57963 .30902 L
.58033 .30902 L
.58096 .30902 L
.58335 .30902 L
.58594 .30902 L
.58716 .30902 L
.58845 .30902 L
.58954 .30902 L
.59075 .30902 L
.59188 .30902 L
.59309 .30902 L
.59423 .30902 L
.59527 .30902 L
.59657 .30902 L
.59723 .30902 L
.59795 .30902 L
.59923 .30902 L
.60042 .30902 L
.60111 .30902 L
.60183 .30902 L
.60312 .30902 L
.60384 .30902 L
.60451 .30902 L
.60524 .30902 L
.60603 .30902 L
.60735 .30902 L
.60809 .30902 L
.60877 .30902 L
.61003 .30902 L
.61137 .30902 L
.61621 .30902 L
.61734 .30902 L
.61853 .30902 L
.61984 .30902 L
.62106 .30902 L
.6223 .30902 L
.62347 .30902 L
.62454 .30902 L
.62566 .30902 L
.62629 .30902 L
.62699 .30902 L
.62821 .30902 L
.6289 .30902 L
.62963 .30902 L
.63033 .30902 L
.63096 .30902 L
Mistroke
.63215 .30902 L
.63345 .30902 L
.63467 .30902 L
.6358 .30902 L
.63685 .30902 L
.63799 .30902 L
.63905 .30902 L
.64003 .30902 L
.64117 .30902 L
.64242 .30902 L
.6436 .30902 L
.64469 .30902 L
.64592 .30902 L
.64708 .30902 L
.64813 .30902 L
.64925 .30902 L
.65049 .30902 L
.65179 .30902 L
.6529 .30902 L
.65412 .30902 L
.65542 .30902 L
.65663 .30902 L
.65731 .30902 L
.65795 .30902 L
.65862 .30902 L
.65936 .30902 L
.66052 .30902 L
.66174 .30902 L
.66239 .30902 L
.66309 .30902 L
.66432 .30902 L
.66554 .30902 L
.66665 .30902 L
.66793 .30902 L
.66914 .30902 L
.67026 .30902 L
.67129 .30902 L
.67242 .30902 L
.67362 .30902 L
.67492 .30902 L
.6761 .30902 L
.67675 .30902 L
.67747 .30902 L
.67876 .30902 L
.67997 .30902 L
.68126 .30902 L
.68248 .30902 L
.68358 .30902 L
.68426 .30902 L
.68499 .30902 L
Mistroke
.68629 .30902 L
.68701 .30902 L
.68769 .30902 L
.68843 .30902 L
.68922 .30902 L
.6899 .30902 L
.69065 .30902 L
.69135 .30902 L
.692 .30902 L
.69323 .30902 L
.69453 .30902 L
.69567 .30902 L
.69692 .30902 L
.69822 .30902 L
.69943 .30902 L
.70057 .30902 L
.7016 .30902 L
.7028 .30902 L
.70392 .30902 L
.70515 .30902 L
.70645 .30902 L
.70756 .30902 L
.70878 .30902 L
.71009 .30902 L
.71081 .30902 L
.71149 .30902 L
.71213 .30902 L
.71282 .30902 L
.71403 .30902 L
.71516 .30902 L
.71622 .30902 L
.71738 .30902 L
.71863 .30902 L
.71988 .30902 L
.72119 .30902 L
.72353 .30902 L
.72805 .30902 L
.73232 .30902 L
.73348 .30902 L
.73471 .30902 L
.73536 .30902 L
.73606 .30902 L
.73731 .30902 L
.73844 .30902 L
.73965 .30902 L
.74079 .30902 L
.74185 .30902 L
.74315 .30902 L
.74384 .30902 L
.74457 .30902 L
Mistroke
.74716 .30902 L
.74848 .30902 L
.74972 .30902 L
.75083 .30902 L
.75203 .30902 L
.75318 .30902 L
.75425 .30902 L
.75542 .30902 L
.75668 .30902 L
.758 .30902 L
.75925 .30902 L
.76037 .30902 L
.76159 .30902 L
.76264 .30902 L
.76381 .30902 L
.76502 .30902 L
.76616 .30902 L
.76722 .30902 L
.76819 .30902 L
.76926 .30902 L
.77039 .30902 L
.77162 .30902 L
.77232 .30902 L
.77296 .30902 L
.77414 .30902 L
.77539 .30902 L
.77651 .30902 L
.77755 .30902 L
.7787 .30902 L
.77993 .30902 L
.78124 .30902 L
.78193 .30902 L
.78267 .30902 L
.78338 .30902 L
.78402 .30902 L
.78526 .30902 L
.78647 .30902 L
.78777 .30902 L
.79013 .30902 L
.8085 .30902 L
.84957 .30902 L
.88911 .30902 L
.92714 .30902 L
.96763 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool008[oool2
06KoC?ooo`030000oooooooo04Goool008Soool406KoC?ooo`800016oooo0027oooo00D0I_oooooo
ooooool0I_l0C?ooo`030000oooooooo04Goool008Koool00`1Vooooooooo`02oooo00<0I_oooooo
ool0B_ooo`030000oooooooo04Goool008Coool206Ko1Oooo`0306Kooooooooo04[oool00`000?oo
ooooo`15oooo0022oooo0P1Vo`Ooool00`1Vooooooooo`1:oooo00<0003oooooool0AOooo`00P?oo
o`80I_l9oooo00<0I_ooooooool0B_ooo`030000oooooooo04Goool007koool206Ko2oooo`0306Ko
oooooooo037oool200001?ooo`800004oooo0P0000?oool400001?ooo`030000oooooooo04Goool0
07_oool306Ko3Oooo`0306Kooooooooo033oool010000?ooooooo`0000Soool010000?ooooooo`00
00;oool00`000?ooooooo`05oooo00<0003oooooool0AOooo`00NOooo`80I_l@oooo00<0I_oooooo
ool0<?ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool3
0000AOooo`00Moooo`80I_lBoooo00<0I_ooooooool0:_ooo`@00002oooo00@0003oooooool00008
oooo00@0003oooooool00004oooo00<0003oooooool00oooo`030000oooooooo04Goool007Goool2
06Ko5?ooo`0306Kooooooooo033oool010000?ooooooo`0000Soool010000?ooooooo`0000;oool0
10000?ooooooo`0000Coool00`000?ooooooo`15oooo001coooo0P1VoaKoool00`1Vooooooooo`0a
oooo0P0000[oool200001?ooo`800005oooo00<0003oooooool0AOooo`00LOooo`80I_lHoooo00<0
I_ooooooool0B_ooo`030000oooooooo04Goool006koool306Ko6_ooo`0306Kooooooooo04[oool0
0`000?ooooooo`15oooo001[oooo0`1Voagoool00`1Vooooooooo`1:oooo00<0003oooooool0AOoo
o`00Ioooo`@0I_lPoooo00<0I_ooooooool0B_ooo`030000oooooooo04Goool006Coool306Ko9?oo
o`0306Kooooooooo04[oool20000A_ooo`00HOooo`<0I_lWoooo00<0I_ooooooool0B_ooo`030000
oooooooo04Goool005ooool206Ko:_ooo`0306Kooooooooo04[oool00`000?ooooooo`15oooo001L
oooo0`1Vobcoool00`1Vooooooooo`1:oooo00<0003oooooool0AOooo`00FOooo`<0I_l_oooo00<0
I_ooooooool0B_ooo`030000oooooooo04Goool005Goool406Ko<_ooo`0306Kooooooooo04[oool0
0`000?ooooooo`15oooo001Aoooo101VocKoool00`1Vooooooooo`1:oooo00<0003oooooool0AOoo
o`00COooo`@0I_ljoooo00<0I_ooooooool0B_ooo`030000oooooooo04Goool004Soool506Ko?_oo
o`0306Kooooooooo04[oool20000A_ooo`00@oooo`D0I_m3oooo00<0I_ooooooool0B_ooo`030000
oooooooo04Goool003koool506KoB?ooo`0306Kooooooooo04[oool00`000?ooooooo`15oooo000i
oooo1@1Vodgoool00`1Vooooooooo`1:oooo00<0003oooooool0AOooo`00=?ooo`D0I_mBoooo00<0
I_ooooooool0B_ooo`030000oooooooo04Goool001;oool400005_ooo`P0I_l:oooo1@0000;oool2
00001?ooo`80000Yoooo1@00013oool00`1Vooooooooo`0Doooo0P0000Coool200001?ooo`80000X
oooo00<0003oooooool0:?ooo`800004oooo0P0000Coool200003oooo`004_ooo`030000oooooooo
00ooool806Ko5?ooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0@
oooo00<0I_ooooooool04oooo`040000oooooooo00002?ooo`040000oooooooo00009oooo`030000
oooooooo02Ooool010000?ooooooo`0000Soool010000?ooooooo`0000koool001?oool00`000?oo
ooooo`09oooo1@1Voacoool00`000?ooooooo`0:oooo00<0003oooooool0:?ooo`030000oooooooo
013oool00`1Vooooooooo`0Coooo00@0003oooooool0000;oooo00<0003oooooool09Oooo`030000
oooooooo02Ooool010000?ooooooo`0000_oool00`000?ooooooo`0<oooo000<oooo100000Coool0
0`000?ooooooo`0806Ko6Oooo`@00004oooo00<0003oooooool02?ooo`80000Soooo100000Coool0
0`000?ooooooo`0@oooo00<0I_ooooooool03Oooo`@00002oooo00@0003oooooool00009oooo0P00
02Soool20000:?ooo`040000oooooooo00002Oooo`80000?oooo000Aoooo00H0I_l00000I_l0I_l0
0000I_lYoooo00<0003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0@oooo00<0
I_ooooooool04oooo`040000oooooooo00002Oooo`030000oooooooo02Ooool00`000?ooooooo`0W
oooo00@0003oooooool00009oooo00<0003oooooool03_ooo`004oooo`80000Zoooo0P0000[oool3
0000:Oooo`80000Boooo00<0I_ooooooool05?ooo`80000:oooo0`0002Ooool00`000?ooooooo`0X
oooo0P0000[oool300003_ooo`00Roooo`0306Kooooooooo04[oool00`000?ooooooo`15oooo002;
oooo00<0I_ooooooool0B_ooo`030000oooooooo04Goool008_oool00`1Vooooooooo`1:oooo00<0
003oooooool0AOooo`00Roooo`0306Kooooooooo04[oool00`000?ooooooo`15oooo002;oooo00<0
I_ooooooool0B_ooo`030000oooooooo04Goool000_ooooo00001`0000ooool0017oool00`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o0?l0V@07<ol000<0000co`0co`001S?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool04oooo`004Oooo`030000
<ol0<ol002lco`000`0003?o03?o000_<ol000<0000co`0co`004c?o0003o`2I<ol0<ol001Pco`00
0`0003?o03?o000_<ol000<0003oooooool0;oooo`030000oooooooo01?oool0017ooomj<ol000?o
09Tco`0co`00BS?o00030000oooooooo04Goool0017ooomj<ol000?o09Tco`0co`00BS?o00030000
oooooooo04Goool0017ooomj<ol000?o09Tco`0co`00BS?o00030000oooooooo04Goool0017ooomj
<ol000?o09Tco`0co`00BS?o00030000oooooooo04Goool0017ooomj<ol000?o09Tco`0co`00BS?o
00030000oooooooo04Goool0017ooomj<ol000?o09Tco`0co`00BS?o00800016oooo000AooooNS?o
0003o`2I<ol0<ol004Xco`000`000?ooooooo`15oooo000AooooNS?o0003o`2I<ol0<ol004Xco`00
0`000?ooooooo`15oooo000AooooNS?o0003o`2I<ol0<ol004Xco`000`000?ooooooo`15oooo000A
ooooNS?o0003o`2I<ol0<ol004Xco`000`000?ooooooo`15oooo000AooooNS?o0003o`2I<ol0<ol0
04Xco`000`000?ooooooo`15oooo000AooooNS?o0003o`2I<ol0<ol004Xco`000`000?ooooooo`15
oooo000AooooNS?o0003o`2I<ol0<ol004Xco`000`000?ooooooo`15oooo000Aoooo0P0007Pco`00
0ol0VC?o03?o001:<ol00P0004Koool001?oool20000MS?o0003o`2I<ol0<ol004Xco`000`000?oo
ooooo`15oooo000Eoooo0P0007@co`000ol0VC?o03?o001:<ol000<0003oooooool0AOooo`005ooo
o`80001b<ol000?o09Tco`0co`00BS?o00030000oooooooo04Goool001Woool20000L3?o0003o`2I
<ol0<ol004Xco`000`000?ooooooo`15oooo000Koooo0P0006hco`000ol0VC?o03?o001:<ol000<0
003oooooool0AOooo`007Oooo`80001/<ol000?o09Tco`0co`00BS?o00030000oooooooo04Goool0
01ooool00`0003?o03?o001Y<ol000?o09Tco`0co`00BS?o00030000oooooooo04Goool0023oool0
0`0003?o03?o001X<ol000?o09Tco`0co`00BS?o00800016oooo000Qoooo0P0006Pco`000ol0VC?o
03?o001:<ol000<0003oooooool0AOooo`008oooo`030000<ol0<ol006Dco`000ol0VC?o03?o001:
<ol000<0003oooooool0AOooo`009?ooo`80001U<ol000?o09Tco`0co`00BS?o00030000oooooooo
04Goool002Koool00`0003?o03?o001R<ol000?o09Tco`0co`00BS?o00030000oooooooo04Goool0
02Ooool00`0003?o03?o001Q<ol000?o09Tco`0co`00BS?o00030000oooooooo04Goool002Soool0
0`0003?o03?o001P<ol000?o09Tco`0co`00<C?o00800004<ol00P0000@co`0200000c?o00@00004
<ol000<0003oooooool0AOooo`00:Oooo`030000<ol0<ol005lco`000ol0VC?o03?o000`<ol000@0
000co`0co`000008<ol000@0000co`0co`000002<ol000<0000co`0co`001C?o00030000oooooooo
04Goool002[oool00`0003?o03?o001N<ol000?o09Tco`0co`00<3?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000c?o00030000<ol0<ol000@co`030000AOooo`00:oooo`80001N<ol000?o
09Tco`0co`00<3?o00040000<ol0<ol0000023?o00040000<ol0<ol0000013?o00030000<ol0<ol0
00<co`000`000?ooooooo`15oooo000]oooo00<0000co`0co`00Fc?o0003o`2I<ol0<ol0030co`00
100003?o03?o000000Pco`00100003?o03?o0000008co`00100003?o03?o000000@co`000`000?oo
ooooo`15oooo000^oooo00<0000co`0co`00FS?o0003o`2I<ol0<ol0034co`0200002S?o00800004
<ol00P0000Dco`000`000?ooooooo`15oooo000_oooo00<0000co`0co`00FC?o0003o`2I<ol0<ol0
04Xco`000`000?ooooooo`15oooo000`oooo00<0000co`0co`00F3?o0003o`2I<ol0<ol004Xco`00
0`000?ooooooo`15oooo000aoooo00<0000co`0co`00Ec?o0003o`2I<ol0<ol004Xco`000`000?oo
ooooo`15oooo000boooo00<0000co`0co`00ES?o0003o`2I<ol0<ol004Xco`000`000?ooooooo`15
oooo000coooo00<0000co`0co`00EC?o0003o`2I<ol0<ol004Xco`020000A_ooo`00<oooo`030000
<ol0<ol005Dco`000ol0VC?o03?o001:<ol000<0003oooooool0AOooo`00=?ooo`030000<ol0<ol0
05@co`000ol0VC?o03?o001:<ol000<0003oooooool0AOooo`00=Oooo`030000<ol0<ol005<co`00
0ol0VC?o03?o001:<ol000<0003oooooool0AOooo`00=_ooo`030000<ol0<ol0058co`000ol0VC?o
03?o001:<ol000<0003oooooool0AOooo`00=oooo`030000<ol0<ol0054co`000ol0VC?o03?o001:
<ol000<0003oooooool0AOooo`00>?ooo`030000<ol0<ol0050co`000ol0VC?o03?o001:<ol000<0
003oooooool0AOooo`00>?ooo`030000<ol0<ol0050co`000ol0VC?o03?o001:<ol000<0003ooooo
ool0AOooo`00>Oooo`030000<ol0<ol004lco`000ol0VC?o03?o001:<ol00P0004Koool003[oool0
0`0003?o03?o001><ol000?o09Tco`0co`00BS?o00030000oooooooo04Goool003_oool00`0003?o
03?o001=<ol000?o09Tco`0co`00BS?o00030000oooooooo04Goool003coool00`0003?o03?o001<
<ol000?o09Tco`0co`00BS?o00030000oooooooo04Goool003coool00`0003?o03?o001<<ol000?o
09Tco`0co`00BS?o00030000oooooooo04Goool003goool00`0003?o03?o001;<ol000?o09Tco`0c
o`00BS?o00030000oooooooo04Goool003goool00`0003?o03?o001;<ol000?o09Tco`0co`00BS?o
00030000oooooooo04Goool003koool00`0003?o03?o001:<ol000?o09Tco`0co`00BS?o00030000
oooooooo04Goool003koool00`0003?o03?o001:<ol000?o09Tco`0co`00BS?o00030000oooooooo
04Goool003ooool00`0003?o03?o0019<ol000?o09Tco`0co`00BS?o00800016oooo000ooooo00<0
000co`0co`00BC?o0003o`2I<ol0<ol004Xco`000`000?ooooooo`15oooo0010oooo00<0000co`0c
o`00B3?o0003o`2I<ol0<ol004Xco`000`000?ooooooo`15oooo0011oooo00<0000co`0co`00Ac?o
0003o`2I<ol0<ol004Xco`000`000?ooooooo`15oooo0011oooo00<0000co`0co`00Ac?o0003o`2I
<ol0<ol004Xco`000`000?ooooooo`15oooo0012oooo00<0000co`0co`00AS?o0003o`2I<ol0<ol0
04Xco`000`000?ooooooo`15oooo0012oooo00<0000co`0co`00AS?o0003o`2I<ol0<ol0034co`02
000013?o00800004<ol00P0000Dco`0300000c?o00030000oooooooo04Goool004?oool00`0003?o
03?o0015<ol000?o09Tco`0co`00<3?o00040000<ol0<ol0000023?o00040000<ol0<ol000001C?o
00030000<ol0<ol0008co`000`000?ooooooo`15oooo0013oooo00<0000co`0co`00AC?o0003o`2I
<ol0<ol0030co`00100003?o03?o000000Pco`00100003?o03?o0000008co`0500000c?o00<00015
oooo0014oooo00<0000co`0co`00A3?o0003o`2I<ol0<ol0030co`00100003?o03?o000000Pco`00
100003?o03?o0000008co`00100003?o03?o000000@co`000`000?ooooooo`15oooo0014oooo00<0
000co`0co`00A3?o0003o`2I<ol0<ol0030co`00100003?o03?o000000Pco`00100003?o03?o0000
00<co`000`0003?o00000004<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol004<co`00
0ol0VC?o03?o000a<ol00P0000Xco`0200001C?o00800004<ol000<0003oooooool0AOooo`00AOoo
o`030000<ol0<ol004<co`000ol0VC?o03?o001:<ol000<0003oooooool0AOooo`00A_ooo`030000
<ol0<ol0048co`000ol0VC?o03?o001:<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol0
048co`000ol0VC?o03?o001:<ol000<0003oooooool0AOooo`00Aoooo`030000<ol0<ol0044co`00
0ol0VC?o03?o001:<ol000<0003oooooool0AOooo`00Aoooo`030000<ol0<ol0044co`000ol0VC?o
03?o001:<ol00P0004Koool004Soool00`0003?o03?o0010<ol000?o09Tco`0co`00BS?o00030000
oooooooo04Goool004Soool00`0003?o03?o0010<ol000?o09Tco`0co`00BS?o00030000oooooooo
04Goool004Woool00`0003?o03?o000o<ol000?o09Tco`0co`00BS?o00030000oooooooo04Goool0
04Woool00`0003?o03?o000o<ol000?o09Tco`0co`00BS?o00030000oooooooo04Goool004[oool0
0`0003?o03?o000n<ol000?o09Tco`0co`00BS?o00030000oooooooo04Goool004[oool00`0003?o
03?o000n<ol000?o09Tco`0co`00BS?o00030000oooooooo04Goool004_oool00`0003?o03?o000m
<ol000?o09Tco`0co`00BS?o00030000oooooooo04Goool004_oool00`0003?o03?o000m<ol000?o
09Tco`0co`00BS?o00800016oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00C?oooh`co`18
oooo001=ooooRc?o04Soool004gooon;<ol0B?ooo`00C_ooobXco`000`0003?o03?o000W<ol000<0
000co`0co`00<c?o04Soool004kooolY<ol000<0000co`0co`0023?o00030000<ol0<ol001hco`00
0`0003?o03?o000b<ol0B?ooo`00CoooobPco`000`0003?o03?o0002<ol00P0000@co`000`0003?o
03?o0006<ol00P0000@co`0200000c?o00@00002<ol0100000<co`000`0003?o03?o000b<ol0B?oo
o`00CoooobPco`001@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o00030000<ol0<ol0
00@co`00100003?o03?o000000Pco`000`0003?o03?o0003<ol000<0000co`0co`0013?o00030000
<ol0<ol0038co`18oooo001?oooo9c?o00030000<ol0<ol0008co`000`0003?o03?o000<<ol000@0
000co`0co`000009<ol000<0000co`0co`000c?o00030000<ol0<ol000@co`000`0003?o03?o000a
<ol0B?ooo`00D?ooobLco`000`0003?o03?o000500002c?o00040000<ol0<ol000002S?o00030000
<ol0<ol000<co`000`0003?o03?o0002<ol000<0000co`0co`00<S?o04Soool0053ooolW<ol000D0
000co`0co`0co`0000003S?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000
<ol0<ol000000c?o00030000<ol0<ol0038co`18oooo001@oooo:3?o00030000<ol0<ol0010co`02
00002S?o00800004<ol00P0000<co`000`0003?o03?o000c<ol0B?ooo`00DOooohLco`18oooo001A
ooooQc?o04Soool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.23) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.46172 .30902 L
.47994 .30902 L
.48519 .30902 L
.48778 .30902 L
.49018 .30902 L
.4913 .30902 L
.49235 .30902 L
s
.49235 .30902 m
.49236 .61803 L
s
0 .4 1 r
.02381 .28017 m
.06244 .27572 L
.10458 .27007 L
.14415 .26389 L
.18221 .25702 L
.22272 .24854 L
.26171 .23906 L
.30316 .22732 L
.34309 .2141 L
.3815 .19932 L
.42237 .18096 L
.44268 .17067 L
.46172 .16023 L
.47994 .14945 L
.48519 .14619 L
.48778 .14456 L
.49018 .14303 L
.4913 .14231 L
.49235 .14164 L
.49356 .30902 L
.49466 .30902 L
.49589 .30902 L
.49701 .30902 L
.49825 .30902 L
.49955 .30902 L
.50077 .30902 L
.50146 .30902 L
.5021 .30902 L
.50327 .30902 L
.50451 .30902 L
.50562 .30902 L
.50666 .30902 L
.5078 .30902 L
.50903 .30902 L
.51026 .30902 L
.51096 .30902 L
.51161 .30902 L
.51293 .30902 L
.51366 .30902 L
.51433 .30902 L
.51553 .30902 L
.51683 .30902 L
.51806 .30902 L
.51919 .30902 L
.52025 .30902 L
.52138 .30902 L
.52245 .30902 L
.52343 .30902 L
.52458 .30902 L
.52582 .30902 L
Mistroke
.527 .30902 L
.5281 .30902 L
.52933 .30902 L
.53049 .30902 L
.53153 .30902 L
.53266 .30902 L
.53752 .30902 L
.53985 .30902 L
.54117 .30902 L
.54238 .30902 L
.54345 .30902 L
.54462 .30902 L
.54584 .30902 L
.54698 .30902 L
.55228 .30902 L
.55711 .30902 L
.55781 .30902 L
.55847 .30902 L
.55915 .30902 L
.5599 .30902 L
.56114 .30902 L
.56246 .30902 L
.56542 .30902 L
.56688 .30902 L
.56752 .30902 L
.56822 .30902 L
.56949 .30902 L
.57018 .30902 L
.57083 .30902 L
.57154 .30902 L
.57219 .30902 L
.57294 .30902 L
.57365 .30902 L
.57488 .30902 L
.57601 .30902 L
.57726 .30902 L
.57789 .30902 L
.57858 .30902 L
.57976 .30902 L
.58101 .30902 L
.58216 .30902 L
.58324 .30902 L
.58451 .30902 L
.58567 .30902 L
.58631 .30902 L
.587 .30902 L
.58826 .30902 L
.58936 .30902 L
.59056 .30902 L
.59182 .30902 L
Mistroke
.593 .30902 L
.5941 .30902 L
.5951 .30902 L
.59626 .30902 L
.59737 .30902 L
.59867 .30902 L
.59986 .30902 L
.60051 .30902 L
.60123 .30902 L
.60251 .30902 L
.60372 .30902 L
.605 .30902 L
.60609 .30902 L
.60729 .30902 L
.60802 .30902 L
.60871 .30902 L
.60999 .30902 L
.61067 .30902 L
.61138 .30902 L
.61217 .30902 L
.61289 .30902 L
.61417 .30902 L
.61538 .30902 L
.6167 .30902 L
.61743 .30902 L
.61812 .30902 L
.6194 .30902 L
.62055 .30902 L
.62164 .30902 L
.62282 .30902 L
.62412 .30902 L
.62477 .30902 L
.62549 .30902 L
.62677 .30902 L
.62796 .30902 L
.6286 .30902 L
.6293 .30902 L
.63057 .30902 L
.63181 .30902 L
.63295 .30902 L
.63366 .30902 L
.63432 .30902 L
.63555 .30902 L
.63624 .30902 L
.63688 .30902 L
.63758 .30902 L
.63832 .30902 L
.63947 .30902 L
.64052 .30902 L
.64166 .30902 L
Mistroke
.64289 .30902 L
.64403 .30902 L
.64508 .30902 L
.64608 .30902 L
.64715 .30902 L
.64829 .30902 L
.64953 .30902 L
.65069 .30902 L
.65175 .30902 L
.653 .30902 L
.65365 .30902 L
.65435 .30902 L
.65564 .30902 L
.65683 .30902 L
.65807 .30902 L
.65877 .30902 L
.65943 .30902 L
.66012 .30902 L
.66076 .30902 L
.66149 .30902 L
.66218 .30902 L
.6634 .30902 L
.66454 .30902 L
.66578 .30902 L
.6671 .30902 L
.66842 .30902 L
.66915 .30902 L
.66983 .30902 L
.67108 .30902 L
.67239 .30902 L
.67309 .30902 L
.67383 .30902 L
.67454 .30902 L
.67518 .30902 L
.67593 .30902 L
.67675 .30902 L
.67752 .30902 L
.67823 .30902 L
.67939 .30902 L
.68064 .30902 L
.68181 .30902 L
.68289 .30902 L
.68418 .30902 L
.6849 .30902 L
.68555 .30902 L
.68683 .30902 L
.68802 .30902 L
.68925 .30902 L
.69057 .30902 L
.69127 .30902 L
Mistroke
.69201 .30902 L
.69265 .30902 L
.69334 .30902 L
.69461 .30902 L
.69531 .30902 L
.69596 .30902 L
.69721 .30902 L
.6984 .30902 L
.69954 .30902 L
.70077 .30902 L
.70193 .30902 L
.703 .30902 L
.70428 .30902 L
.70547 .30902 L
.70671 .30902 L
.70737 .30902 L
.70807 .30902 L
.70876 .30902 L
.7094 .30902 L
.7101 .30902 L
.71084 .30902 L
.71208 .30902 L
.71279 .30902 L
.71345 .30902 L
.71468 .30902 L
.71581 .30902 L
.7171 .30902 L
.71834 .30902 L
.71939 .30902 L
.72055 .30902 L
.72177 .30902 L
.72292 .30902 L
.72398 .30902 L
.72496 .30902 L
.72603 .30902 L
.72716 .30902 L
.7283 .30902 L
.72953 .30902 L
.73069 .30902 L
.73174 .30902 L
.73298 .30902 L
.73368 .30902 L
.73433 .30902 L
.73677 .30902 L
.73791 .30902 L
.73915 .30902 L
.74033 .30902 L
.74143 .30902 L
.74269 .30902 L
.7434 .30902 L
Mistroke
.74404 .30902 L
.74528 .30902 L
.74644 .30902 L
.74754 .30902 L
.7487 .30902 L
.7497 .30902 L
.75079 .30902 L
.75196 .30902 L
.75322 .30902 L
.75433 .30902 L
.7555 .30902 L
.75615 .30902 L
.75688 .30902 L
.75815 .30902 L
.75887 .30902 L
.75964 .30902 L
.76037 .30902 L
.76104 .30902 L
.76226 .30902 L
.76295 .30902 L
.7636 .30902 L
.7649 .30902 L
.76563 .30902 L
.76629 .30902 L
.76755 .30902 L
.76872 .30902 L
.76999 .30902 L
.77064 .30902 L
.77135 .30902 L
.77254 .30902 L
.77382 .30902 L
.77502 .30902 L
.77612 .30902 L
.77742 .30902 L
.77863 .30902 L
.77973 .30902 L
.78091 .30902 L
.7822 .30902 L
.78285 .30902 L
.78356 .30902 L
.78482 .30902 L
.786 .30902 L
.78719 .30902 L
.78831 .30902 L
.79042 .30902 L
.79515 .30902 L
.81589 .30902 L
.85428 .30902 L
.89512 .30902 L
.93445 .30902 L
Mistroke
.97226 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.23) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool008coool00`1Voooo
ooooo`19oooo00<0003oooooool0AOooo`00R_ooo`<0I_m;oooo00<0003oooooool0AOooo`00R_oo
o`0306Kooooo06Ko04_oool00`000?ooooooo`15oooo0028oooo0P1Vo`;oool00`1Vooooooooo`19
oooo00<0003oooooool0AOooo`00Q_ooo`80I_l4oooo00<0I_ooooooool0BOooo`800016oooo0024
oooo0P1Vo`Koool00`1Vooooooooo`19oooo00<0003oooooool0AOooo`00P_ooo`80I_l8oooo00<0
I_ooooooool0BOooo`030000oooooooo04Goool0083oool206Ko2_ooo`0306Kooooooooo04Woool0
0`000?ooooooo`15oooo001ooooo00<0I_ooooooool02_ooo`0306Kooooooooo04Woool00`000?oo
ooooo`15oooo001moooo0P1Vo`goool00`1Vooooooooo`19oooo00<0003oooooool0AOooo`00Nooo
o`80I_l?oooo00<0I_ooooooool0<?ooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0
003oooooool0AOooo`00NOooo`80I_lAoooo00<0I_ooooooool0;oooo`040000oooooooo00002?oo
o`040000oooooooo00000_ooo`030000oooooooo00Goool00`000?ooooooo`15oooo001goooo0P1V
oa?oool00`1Vooooooooo`0_oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool01?ooo`<00015oooo001eoooo0P1VoaGoool00`1Vooooooooo`0Yoooo100000;oool0
10000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003ooooo
ool0AOooo`00Loooo`80I_lGoooo00<0I_ooooooool0;oooo`040000oooooooo00002?ooo`040000
oooooooo00000_ooo`040000oooooooo00001?ooo`030000oooooooo04Goool0077oool206Ko6Ooo
o`0306Kooooooooo033oool200002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo001^
oooo0`1Voa_oool00`1Vooooooooo`19oooo00<0003oooooool0AOooo`00Joooo`<0I_lNoooo00<0
I_ooooooool0BOooo`030000oooooooo04Goool006Ooool406Ko8Oooo`0306Kooooooooo04Woool0
0`000?ooooooo`15oooo001Toooo0`1VobGoool00`1Vooooooooo`19oooo00<0003oooooool0AOoo
o`00HOooo`<0I_lXoooo00<0I_ooooooool0BOooo`800016oooo001Ooooo0P1Vob_oool00`1Voooo
ooooo`19oooo00<0003oooooool0AOooo`00G?ooo`<0I_l]oooo00<0I_ooooooool0BOooo`030000
oooooooo04Goool005Woool306Ko<?ooo`0306Kooooooooo04Woool00`000?ooooooo`15oooo001E
oooo101Voc?oool00`1Vooooooooo`19oooo00<0003oooooool0AOooo`00DOooo`@0I_lgoooo00<0
I_ooooooool0BOooo`030000oooooooo04Goool004goool406Ko>oooo`0306Kooooooooo04Woool0
0`000?ooooooo`15oooo0018oooo1@1Vocooool00`1Vooooooooo`19oooo00<0003oooooool0AOoo
o`00A?ooo`@0I_m4oooo00<0I_ooooooool0BOooo`800016oooo0011oooo0`1VodSoool00`1Voooo
ooooo`19oooo00<0003oooooool0AOooo`00?Oooo`@0I_m;oooo00<0I_ooooooool0BOooo`030000
oooooooo04Goool003Ooool606KoCoooo`0306Kooooooooo04Woool00`000?ooooooo`15oooo000_
oooo201VoeGoool00`1Vooooooooo`19oooo00<0003oooooool0AOooo`004_ooo`@0000Coooo1P1V
o`ooool500000_ooo`800004oooo0P0002Woool500004Oooo`0306Kooooooooo01?oool200001?oo
o`800004oooo0P0002Soool00`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000B
oooo00<0003oooooool03Oooo`L0I_lGoooo00<0003oooooool01oooo`040000oooooooo0000:_oo
o`030000oooooooo017oool00`1Vooooooooo`0Boooo00@0003oooooool00008oooo00@0003ooooo
ool0000Woooo00<0003oooooool09oooo`040000oooooooo00002?ooo`040000oooooooo00003_oo
o`004oooo`030000oooooooo00Coool806Ko7_ooo`030000oooooooo00[oool00`000?ooooooo`0X
oooo00<0003oooooool04Oooo`0306Kooooooooo01;oool010000?ooooooo`0000_oool00`000?oo
ooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo00002oooo`030000oooooooo00coool0
00coool400001?ooo`03000006Ko06Ko00<0I_lNoooo100000Coool00`000?ooooooo`08oooo0P00
02?oool400001?ooo`030000oooooooo017oool00`1Vooooooooo`0<oooo100000;oool010000?oo
ooooo`0000Woool20000:?ooo`80000Xoooo00@0003oooooool00009oooo0P0000ooool0017oool0
1@1Vo`00001Vooooo`00000Zoooo00<0003oooooool02?ooo`030000oooooooo02[oool00`000?oo
ooooo`0Aoooo00<0I_ooooooool04_ooo`040000oooooooo00002Oooo`030000oooooooo02Ooool0
0`000?ooooooo`0Woooo00@0003oooooool00009oooo00<0003oooooool03_ooo`004oooo`80000Z
oooo0P0000[oool30000:Oooo`80000Coooo00<0I_ooooooool04oooo`80000:oooo0`0002Ooool0
0`000?ooooooo`0Xoooo0P0000[oool300003_ooo`00S?ooo`0306Kooooooooo04Woool00`000?oo
ooooo`15oooo002<oooo00<0I_ooooooool0BOooo`030000oooooooo04Goool008coool00`1Voooo
ooooo`19oooo00<0003oooooool0AOooo`00S?ooo`0306Kooooooooo04Woool00`000?ooooooo`15
oooo002<oooo00<0I_ooooooool0BOooo`030000oooooooo04Goool000_ooooo00001`0000ooool0
017oool00`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`00100003?o03?o0?l0V@Hco`000`0003?o03?o0006<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0C
oooo000Aoooo00<0000co`0co`00;c?o00030000<ol0<ol002lco`000`0003?o03?o000D<ol000?o
09Tco`0co`005c?o00030000<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04ooo
o`004Oooog/co`000ol0VC?o03?o0019<ol000<0003oooooool0AOooo`004Oooog/co`000ol0VC?o
03?o0019<ol000<0003oooooool0AOooo`004Oooog/co`000ol0VC?o03?o0019<ol000<0003ooooo
ool0AOooo`004Oooog/co`000ol0VC?o03?o0019<ol000<0003oooooool0AOooo`004Oooog/co`00
0ol0VC?o03?o0019<ol000<0003oooooool0AOooo`004Oooog/co`000ol0VC?o03?o0019<ol00P00
04Koool0017ooomk<ol000?o09Tco`0co`00BC?o00030000oooooooo04Goool0017ooomk<ol000?o
09Tco`0co`00BC?o00030000oooooooo04Goool0017ooomk<ol000?o09Tco`0co`00BC?o00030000
oooooooo04Goool0017ooomk<ol000?o09Tco`0co`00BC?o00030000oooooooo04Goool0017ooomk
<ol000?o09Tco`0co`00BC?o00030000oooooooo04Goool0017ooomk<ol000?o09Tco`0co`00BC?o
00030000oooooooo04Goool0017ooomk<ol000?o09Tco`0co`00BC?o00030000oooooooo04Goool0
017oool20000NC?o0003o`2I<ol0<ol004Tco`020000A_ooo`004oooo`80001g<ol000?o09Tco`0c
o`00BC?o00030000oooooooo04Goool001Goool20000MC?o0003o`2I<ol0<ol004Tco`000`000?oo
ooooo`15oooo000Goooo0P0007<co`000ol0VC?o03?o0019<ol000<0003oooooool0AOooo`006Ooo
o`80001a<ol000?o09Tco`0co`00BC?o00030000oooooooo04Goool001_oool20000Kc?o0003o`2I
<ol0<ol004Tco`000`000?ooooooo`15oooo000Moooo0P0006dco`000ol0VC?o03?o0019<ol000<0
003oooooool0AOooo`007oooo`030000<ol0<ol006Xco`000ol0VC?o03?o0019<ol000<0003ooooo
ool0AOooo`008?ooo`030000<ol0<ol006Tco`000ol0VC?o03?o0019<ol00P0004Koool0027oool2
0000JC?o0003o`2I<ol0<ol004Tco`000`000?ooooooo`15oooo000Soooo00<0000co`0co`00IS?o
0003o`2I<ol0<ol004Tco`000`000?ooooooo`15oooo000Toooo0P0006Hco`000ol0VC?o03?o0019
<ol000<0003oooooool0AOooo`009_ooo`030000<ol0<ol006<co`000ol0VC?o03?o0019<ol000<0
003oooooool0AOooo`009oooo`030000<ol0<ol0068co`000ol0VC?o03?o0019<ol000<0003ooooo
ool0AOooo`00:?ooo`030000<ol0<ol0064co`000ol0VC?o03?o000`<ol00P0000@co`02000013?o
00800003<ol0100000@co`000`000?ooooooo`15oooo000Yoooo00<0000co`0co`00H3?o0003o`2I
<ol0<ol002lco`00100003?o03?o000000Pco`00100003?o03?o0000008co`000`0003?o03?o0005
<ol000<0003oooooool0AOooo`00:_ooo`030000<ol0<ol005lco`000ol0VC?o03?o000_<ol000@0
000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00<00015oooo000[
oooo0P0005lco`000ol0VC?o03?o000_<ol000@0000co`0co`000008<ol000@0000co`0co`000004
<ol000<0000co`0co`000c?o00030000oooooooo04Goool002goool00`0003?o03?o001L<ol000?o
09Tco`0co`00;c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0
000013?o00030000oooooooo04Goool002koool00`0003?o03?o001K<ol000?o09Tco`0co`00<3?o
0080000:<ol00P0000@co`0200001C?o00030000oooooooo04Goool002ooool00`0003?o03?o001J
<ol000?o09Tco`0co`00BC?o00030000oooooooo04Goool0033oool00`0003?o03?o001I<ol000?o
09Tco`0co`00BC?o00030000oooooooo04Goool0037oool00`0003?o03?o001H<ol000?o09Tco`0c
o`00BC?o00030000oooooooo04Goool003;oool00`0003?o03?o001G<ol000?o09Tco`0co`00BC?o
00030000oooooooo04Goool003?oool00`0003?o03?o001F<ol000?o09Tco`0co`00BC?o00800016
oooo000coooo00<0000co`0co`00ES?o0003o`2I<ol0<ol004Tco`000`000?ooooooo`15oooo000d
oooo00<0000co`0co`00EC?o0003o`2I<ol0<ol004Tco`000`000?ooooooo`15oooo000eoooo00<0
000co`0co`00E3?o0003o`2I<ol0<ol004Tco`000`000?ooooooo`15oooo000foooo00<0000co`0c
o`00Dc?o0003o`2I<ol0<ol004Tco`000`000?ooooooo`15oooo000goooo00<0000co`0co`00DS?o
0003o`2I<ol0<ol004Tco`000`000?ooooooo`15oooo000hoooo00<0000co`0co`00DC?o0003o`2I
<ol0<ol004Tco`000`000?ooooooo`15oooo000hoooo00<0000co`0co`00DC?o0003o`2I<ol0<ol0
04Tco`000`000?ooooooo`15oooo000ioooo00<0000co`0co`00D3?o0003o`2I<ol0<ol004Tco`02
0000A_ooo`00>_ooo`030000<ol0<ol004lco`000ol0VC?o03?o0019<ol000<0003oooooool0AOoo
o`00>oooo`030000<ol0<ol004hco`000ol0VC?o03?o0019<ol000<0003oooooool0AOooo`00??oo
o`030000<ol0<ol004dco`000ol0VC?o03?o0019<ol000<0003oooooool0AOooo`00??ooo`030000
<ol0<ol004dco`000ol0VC?o03?o0019<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol0
04`co`000ol0VC?o03?o0019<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol004`co`00
0ol0VC?o03?o0019<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol004/co`000ol0VC?o
03?o0019<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol004/co`000ol0VC?o03?o0019
<ol000<0003oooooool0AOooo`00?oooo`030000<ol0<ol004Xco`000ol0VC?o03?o0019<ol00P00
04Koool003ooool00`0003?o03?o001:<ol000?o09Tco`0co`00BC?o00030000oooooooo04Goool0
043oool00`0003?o03?o0019<ol000?o09Tco`0co`00BC?o00030000oooooooo04Goool0047oool0
0`0003?o03?o0018<ol000?o09Tco`0co`00BC?o00030000oooooooo04Goool0047oool00`0003?o
03?o0018<ol000?o09Tco`0co`00BC?o00030000oooooooo04Goool004;oool00`0003?o03?o0017
<ol000?o09Tco`0co`00BC?o00030000oooooooo04Goool004;oool00`0003?o03?o0017<ol000?o
09Tco`0co`00<3?o00800004<ol00P0000@co`0200001C?o00<00003<ol000<0003oooooool0AOoo
o`00@oooo`030000<ol0<ol004Hco`000ol0VC?o03?o000_<ol000@0000co`0co`000008<ol000@0
000co`0co`000005<ol000<0000co`0co`000S?o00030000oooooooo04Goool004?oool00`0003?o
03?o0016<ol000?o09Tco`0co`00;c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o
00D00003<ol00`0004Goool004Coool00`0003?o03?o0015<ol000?o09Tco`0co`00;c?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo
04Goool004Coool00`0003?o03?o0015<ol000?o09Tco`0co`00;c?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000c?o00030000<ol0000000@co`000`000?ooooooo`15oooo0015oooo00<0
000co`0co`00A3?o0003o`2I<ol0<ol0030co`0200002S?o00800005<ol00P0000@co`000`000?oo
ooooo`15oooo0015oooo00<0000co`0co`00A3?o0003o`2I<ol0<ol004Tco`000`000?ooooooo`15
oooo0016oooo00<0000co`0co`00@c?o0003o`2I<ol0<ol004Tco`000`000?ooooooo`15oooo0016
oooo00<0000co`0co`00@c?o0003o`2I<ol0<ol004Tco`000`000?ooooooo`15oooo0017oooo00<0
000co`0co`00@S?o0003o`2I<ol0<ol004Tco`000`000?ooooooo`15oooo0017oooo00<0000co`0c
o`00@S?o0003o`2I<ol0<ol004Tco`020000A_ooo`00B?ooo`030000<ol0<ol0044co`000ol0VC?o
03?o0019<ol000<0003oooooool0AOooo`00B?ooo`030000<ol0<ol0044co`000ol0VC?o03?o0019
<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol0040co`000ol0VC?o03?o0019<ol000<0
003oooooool0AOooo`00BOooo`030000<ol0<ol0040co`000ol0VC?o03?o0019<ol000<0003ooooo
ool0AOooo`00B_ooo`030000<ol0<ol003lco`000ol0VC?o03?o0019<ol000<0003oooooool0AOoo
o`00B_ooo`030000<ol0<ol003lco`000ol0VC?o03?o0019<ol000<0003oooooool0AOooo`00Booo
o`030000<ol0<ol003hco`000ol0VC?o03?o0019<ol000<0003oooooool0AOooo`00Boooo`030000
<ol0<ol003hco`000ol0VC?o03?o0019<ol00P0004Koool004cooon<<ol0B?ooo`00C?oooh`co`18
oooo001<ooooS3?o04Soool004gooon;<ol0B?ooo`00COoooh/co`18oooo001>oooo:S?o00030000
<ol0<ol002Lco`000`0003?o03?o000c<ol0B?ooo`00C_ooobTco`000`0003?o03?o0008<ol000<0
000co`0co`007S?o00030000<ol0<ol0038co`18oooo001?oooo:3?o00030000<ol0<ol0008co`02
000013?o00030000<ol0<ol000Hco`02000013?o00800003<ol0100000<co`02000013?o00030000
<ol0<ol0038co`18oooo001?oooo:3?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002
<ol000<0000co`0co`0013?o00040000<ol0<ol0000023?o00030000<ol0<ol000<co`00100003?o
03?o000000<co`000`0003?o03?o000b<ol0B?ooo`00CoooobLco`000`0003?o03?o0002<ol000<0
000co`0co`0033?o00040000<ol0<ol000002C?o00030000<ol0<ol000@co`000`0003?o03?o0003
<ol000<0000co`0co`00<C?o04Soool0053ooolW<ol000<0000co`0co`001@0000/co`00100003?o
03?o000000Xco`000`0003?o03?o0004<ol000D0000co`0co`0co`000000=3?o04Soool0053ooolW
<ol000D0000co`0co`0co`0000003S?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o
00040000<ol0<ol000000c?o00030000<ol0<ol0038co`18oooo001@oooo:3?o00030000<ol0<ol0
010co`0200002S?o00800004<ol00P0000<co`000`0003?o03?o000c<ol0B?ooo`00DOooohLco`18
oooo001AooooQc?o04Soool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.46172 .30902 L
.47994 .30902 L
.48519 .30902 L
.49018 .30902 L
.49235 .30902 L
.49466 .30902 L
.49535 .30902 L
.49599 .30902 L
s
.49599 .30902 m
.496 .61803 L
s
0 .4 1 r
.02381 .27887 m
.06244 .27422 L
.10458 .26831 L
.14415 .26185 L
.18221 .25467 L
.22272 .24581 L
.26171 .2359 L
.30316 .22363 L
.34309 .20982 L
.3815 .19438 L
.42237 .17519 L
.44268 .16443 L
.46172 .15352 L
.47994 .14225 L
.48519 .13885 L
.49018 .13554 L
.49235 .13409 L
.49466 .13252 L
.49535 .13205 L
.49599 .13161 L
.4972 .30902 L
.49833 .30902 L
.49955 .30902 L
.50079 .30902 L
.50192 .30902 L
.50323 .30902 L
.50447 .30902 L
.50561 .30902 L
.50667 .30902 L
.50783 .30902 L
.50906 .30902 L
.51029 .30902 L
.51098 .30902 L
.51161 .30902 L
.51278 .30902 L
.51402 .30902 L
.51467 .30902 L
.51537 .30902 L
.51663 .30902 L
.5174 .30902 L
.51813 .30902 L
.51878 .30902 L
.51949 .30902 L
.5208 .30902 L
.52203 .30902 L
.52273 .30902 L
.52337 .30902 L
.52411 .30902 L
.52481 .30902 L
.52549 .30902 L
Mistroke
.52621 .30902 L
.52751 .30902 L
.52831 .30902 L
.52905 .30902 L
.52972 .30902 L
.53045 .30902 L
.53167 .30902 L
.53237 .30902 L
.53301 .30902 L
.53432 .30902 L
.53505 .30902 L
.53572 .30902 L
.53691 .30902 L
.5382 .30902 L
.53943 .30902 L
.54055 .30902 L
.54174 .30902 L
.54298 .30902 L
.54404 .30902 L
.5452 .30902 L
.54646 .30902 L
.54716 .30902 L
.5478 .30902 L
.54904 .30902 L
.55021 .30902 L
.55131 .30902 L
.55247 .30902 L
.55346 .30902 L
.55455 .30902 L
.55573 .30902 L
.55698 .30902 L
.55817 .30902 L
.55926 .30902 L
.56053 .30902 L
.56118 .30902 L
.56189 .30902 L
.56314 .30902 L
.56432 .30902 L
.565 .30902 L
.56571 .30902 L
.56698 .30902 L
.56768 .30902 L
.56834 .30902 L
.56907 .30902 L
.56984 .30902 L
.57114 .30902 L
.57187 .30902 L
.57254 .30902 L
.57376 .30902 L
.57445 .30902 L
Mistroke
.57509 .30902 L
.57621 .30902 L
.57741 .30902 L
.5787 .30902 L
.57987 .30902 L
.58116 .30902 L
.58238 .30902 L
.58347 .30902 L
.58464 .30902 L
.58593 .30902 L
.58658 .30902 L
.58729 .30902 L
.58855 .30902 L
.58973 .30902 L
.59091 .30902 L
.59204 .30902 L
.59305 .30902 L
.59414 .30902 L
.59534 .30902 L
.5966 .30902 L
.59768 .30902 L
.59887 .30902 L
.60018 .30902 L
.60084 .30902 L
.60156 .30902 L
.60283 .30902 L
.60402 .30902 L
.60474 .30902 L
.60543 .30902 L
.6067 .30902 L
.60742 .30902 L
.60808 .30902 L
.6088 .30902 L
.60957 .30902 L
.61076 .30902 L
.61204 .30902 L
.61324 .30902 L
.61435 .30902 L
.61564 .30902 L
.61637 .30902 L
.61704 .30902 L
.61828 .30902 L
.6196 .30902 L
.62085 .30902 L
.62204 .30902 L
.62269 .30902 L
.62341 .30902 L
.62465 .30902 L
.62583 .30902 L
.62709 .30902 L
Mistroke
.62817 .30902 L
.62935 .30902 L
.63057 .30902 L
.63188 .30902 L
.63312 .30902 L
.63426 .30902 L
.63557 .30902 L
.63632 .30902 L
.63701 .30902 L
.63827 .30902 L
.63898 .30902 L
.63963 .30902 L
.64035 .30902 L
.6411 .30902 L
.64176 .30902 L
.64249 .30902 L
.64314 .30902 L
.64383 .30902 L
.64509 .30902 L
.64583 .30902 L
.64665 .30902 L
.64742 .30902 L
.64813 .30902 L
.64877 .30902 L
.64947 .30902 L
.65021 .30902 L
.6509 .30902 L
.65217 .30902 L
.65287 .30902 L
.65352 .30902 L
.65477 .30902 L
.65595 .30902 L
.65716 .30902 L
.65848 .30902 L
.65918 .30902 L
.65993 .30902 L
.66056 .30902 L
.66126 .30902 L
.66257 .30902 L
.66376 .30902 L
.66443 .30902 L
.66515 .30902 L
.66646 .30902 L
.66768 .30902 L
.66899 .30902 L
.67022 .30902 L
.67133 .30902 L
.67252 .30902 L
.67362 .30902 L
.67482 .30902 L
Mistroke
.67609 .30902 L
.6772 .30902 L
.67823 .30902 L
.67936 .30902 L
.68057 .30902 L
.68125 .30902 L
.68196 .30902 L
.68325 .30902 L
.68397 .30902 L
.68464 .30902 L
.68538 .30902 L
.68617 .30902 L
.68681 .30902 L
.68752 .30902 L
.6882 .30902 L
.68893 .30902 L
.69025 .30902 L
.69147 .30902 L
.69275 .30902 L
.69343 .30902 L
.69415 .30902 L
.69546 .30902 L
.69667 .30902 L
.69783 .30902 L
.69892 .30902 L
.70011 .30902 L
.70139 .30902 L
.70261 .30902 L
.7033 .30902 L
.70395 .30902 L
.70525 .30902 L
.70599 .30902 L
.70666 .30902 L
.7078 .30902 L
.70904 .30902 L
.71034 .30902 L
.71155 .30902 L
.71224 .30902 L
.71298 .30902 L
.71369 .30902 L
.71434 .30902 L
.71558 .30902 L
.71689 .30902 L
.71756 .30902 L
.71829 .30902 L
.71961 .30902 L
.72041 .30902 L
.72117 .30902 L
.72185 .30902 L
.7226 .30902 L
Mistroke
.72326 .30902 L
.72396 .30902 L
.72525 .30902 L
.7265 .30902 L
.72765 .30902 L
.7289 .30902 L
.72961 .30902 L
.73027 .30902 L
.73303 .30902 L
.73429 .30902 L
.73547 .30902 L
.73654 .30902 L
.7377 .30902 L
.73896 .30902 L
.7396 .30902 L
.7403 .30902 L
.74155 .30902 L
.74271 .30902 L
.74389 .30902 L
.74515 .30902 L
.74633 .30902 L
.74741 .30902 L
.74868 .30902 L
.74939 .30902 L
.75005 .30902 L
.75126 .30902 L
.75255 .30902 L
.75378 .30902 L
.75509 .30902 L
.75634 .30902 L
.75748 .30902 L
.75817 .30902 L
.75881 .30902 L
.75957 .30902 L
.76026 .30902 L
.76154 .30902 L
.76224 .30902 L
.7629 .30902 L
.76398 .30902 L
.76516 .30902 L
.76639 .30902 L
.76754 .30902 L
.76861 .30902 L
.76959 .30902 L
.77073 .30902 L
.7718 .30902 L
.77296 .30902 L
.77419 .30902 L
.77524 .30902 L
.7764 .30902 L
Mistroke
.77766 .30902 L
.77836 .30902 L
.779 .30902 L
.78024 .30902 L
.78141 .30902 L
.7826 .30902 L
.78389 .30902 L
.78457 .30902 L
.7853 .30902 L
.78659 .30902 L
.78781 .30902 L
.78895 .30902 L
.79153 .30902 L
.8008 .30902 L
.82167 .30902 L
.86055 .30902 L
.90189 .30902 L
.94171 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool00`000?ooooooo`15
oooo002<oooo0P1Vod[oool00`000?ooooooo`15oooo002;oooo0`1Vod[oool00`000?ooooooo`15
oooo002:oooo00@0I_ooooooool0I_m:oooo00<0003oooooool0AOooo`00R?ooo`80I_l3oooo00<0
I_ooooooool0B?ooo`030000oooooooo04Goool008Ooool00`1Vooooooooo`03oooo00<0I_oooooo
ool0B?ooo`030000oooooooo04Goool008Goool206Ko1_ooo`0306Kooooooooo04Soool00`000?oo
ooooo`15oooo0023oooo0P1Vo`Soool00`1Vooooooooo`18oooo0P0004Koool0087oool206Ko2_oo
o`0306Kooooooooo04Soool00`000?ooooooo`15oooo001ooooo0P1Vo`coool00`1Vooooooooo`18
oooo00<0003oooooool0AOooo`00OOooo`80I_l>oooo00<0I_ooooooool0B?ooo`030000oooooooo
04Goool007_oool206Ko4?ooo`0306Kooooooooo04Soool00`000?ooooooo`15oooo001ioooo0P1V
oa;oool00`1Vooooooooo`18oooo00<0003oooooool0AOooo`00Moooo`80I_lDoooo00<0I_oooooo
ool0;oooo`800004oooo0P0000Coool200000oooo`@00004oooo00<0003oooooool0AOooo`00MOoo
o`80I_lFoooo00<0I_ooooooool0;_ooo`040000oooooooo00002?ooo`040000oooooooo00000_oo
o`030000oooooooo00Goool00`000?ooooooo`15oooo001coooo0P1VoaSoool00`1Vooooooooo`0^
oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`<00015
oooo001aoooo0P1Voa[oool00`1Vooooooooo`0Xoooo100000;oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`03oooo00<0003oooooool0AOooo`00K_ooo`<0I_lL
oooo00<0I_ooooooool0;_ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000
oooooooo00001?ooo`030000oooooooo04Goool006coool206Ko7oooo`0306Kooooooooo02ooool2
00002_ooo`800004oooo0P0000Goool00`000?ooooooo`15oooo001Yoooo0`1Vob7oool00`1Voooo
ooooo`18oooo00<0003oooooool0AOooo`00Ioooo`80I_lToooo00<0I_ooooooool0B?ooo`030000
oooooooo04Goool006Coool306Ko9_ooo`0306Kooooooooo04Soool00`000?ooooooo`15oooo001Q
oooo0`1VobWoool00`1Vooooooooo`18oooo00<0003oooooool0AOooo`00Goooo`80I_l/oooo00<0
I_ooooooool0B?ooo`800016oooo001Loooo0`1Vobkoool00`1Vooooooooo`18oooo00<0003ooooo
ool0AOooo`00FOooo`<0I_laoooo00<0I_ooooooool0B?ooo`030000oooooooo04Goool005Goool4
06Ko=?ooo`0306Kooooooooo04Soool00`000?ooooooo`15oooo001Aoooo101VocSoool00`1Voooo
ooooo`18oooo00<0003oooooool0AOooo`00C_ooo`<0I_lloooo00<0I_ooooooool0B?ooo`030000
oooooooo04Goool004_oool306Ko?oooo`0306Kooooooooo04Soool00`000?ooooooo`15oooo0017
oooo101Vod;oool00`1Vooooooooo`18oooo00<0003oooooool0AOooo`00@oooo`@0I_m6oooo00<0
I_ooooooool0B?ooo`800016oooo000noooo1@1Vod[oool00`1Vooooooooo`18oooo00<0003ooooo
ool0AOooo`00>Oooo`D0I_m?oooo00<0I_ooooooool0B?ooo`030000oooooooo04Goool003Coool5
06KoE?ooo`0306Kooooooooo04Soool00`000?ooooooo`15oooo000_oooo1@1VoeWoool00`1Voooo
ooooo`18oooo00<0003oooooool0AOooo`004_ooo`@0000Coooo1P1Vo`ooool500000_ooo`800004
oooo0P0002Woool500004_ooo`0306Kooooooooo01;oool200001?ooo`800004oooo0P0002Soool0
0`000?ooooooo`0Xoooo0P0000Coool200001?ooo`80000?oooo000Boooo00<0003oooooool03Ooo
o`L0I_lGoooo00<0003oooooool01oooo`040000oooooooo0000:_ooo`030000oooooooo01;oool0
0`1Vooooooooo`0Aoooo00@0003oooooool00008oooo00@0003oooooool0000Woooo00<0003ooooo
ool09oooo`040000oooooooo00002?ooo`040000oooooooo00003_ooo`004oooo`040000oooooooo
oooo2`1Voakoool00`000?ooooooo`0:oooo00<0003oooooool0:?ooo`030000oooooooo01;oool0
0`1Vooooooooo`0Aoooo00@0003oooooool0000;oooo00<0003oooooool09Oooo`030000oooooooo
02Ooool010000?ooooooo`0000_oool00`000?ooooooo`0<oooo000<oooo10000005oooo06Ko06Ko
06Ko00000080I_lQoooo100000Coool00`000?ooooooo`08oooo0P0002?oool400001?ooo`030000
oooooooo01;oool00`1Vooooooooo`0;oooo100000;oool010000?ooooooo`0000Woool20000:?oo
o`80000Xoooo00@0003oooooool00009oooo0P0000ooool001;oool010000?ooooooo`0002[oool0
0`000?ooooooo`08oooo00<0003oooooool0:_ooo`030000oooooooo01;oool00`1Vooooooooo`0A
oooo00@0003oooooool00009oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?oo
ooooo`0000Woool00`000?ooooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P00
01Coool00`1Vooooooooo`0Boooo0P0000[oool300009oooo`030000oooooooo02Soool200002_oo
o`<0000>oooo002=oooo00<0I_ooooooool0B?ooo`030000oooooooo04Goool008goool00`1Voooo
ooooo`18oooo00<0003oooooool0AOooo`00SOooo`0306Kooooooooo04Soool00`000?ooooooo`15
oooo002=oooo00<0I_ooooooool0B?ooo`030000oooooooo04Goool008goool00`1Vooooooooo`18
oooo00<0003oooooool0AOooo`002oooool0000700003oooo`004Oooo`030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00050000
<ol0<ol0<ol0o`2I00Dco`000`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0
003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0c
o`00;c?o00030000<ol0<ol002lco`000`0003?o03?o000E<ol000?o09Tco`0co`005S?o00030000
<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Oooog`co`000ol0VC?o
03?o0018<ol000<0003oooooool0AOooo`004Oooog`co`000ol0VC?o03?o0018<ol000<0003ooooo
ool0AOooo`004Oooog`co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`004Oooog`co`00
0ol0VC?o03?o0018<ol000<0003oooooool0AOooo`004Oooog`co`000ol0VC?o03?o0018<ol000<0
003oooooool0AOooo`004Oooog`co`000ol0VC?o03?o0018<ol00P0004Koool0017oooml<ol000?o
09Tco`0co`00B3?o00030000oooooooo04Goool0017oooml<ol000?o09Tco`0co`00B3?o00030000
oooooooo04Goool0017oooml<ol000?o09Tco`0co`00B3?o00030000oooooooo04Goool0017oooml
<ol000?o09Tco`0co`00B3?o00030000oooooooo04Goool0017oooml<ol000?o09Tco`0co`00B3?o
00030000oooooooo04Goool0017oooml<ol000?o09Tco`0co`00B3?o00030000oooooooo04Goool0
017oooml<ol000?o09Tco`0co`00B3?o00030000oooooooo04Goool0017oool20000NS?o0003o`2I
<ol0<ol004Pco`020000A_ooo`004oooo`80001h<ol000?o09Tco`0co`00B3?o00030000oooooooo
04Goool001Goool20000MS?o0003o`2I<ol0<ol004Pco`000`000?ooooooo`15oooo000Goooo0P00
07@co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`006Oooo`80001b<ol000?o09Tco`0c
o`00B3?o00030000oooooooo04Goool001_oool20000L3?o0003o`2I<ol0<ol004Pco`000`000?oo
ooooo`15oooo000Moooo0P0006hco`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`007ooo
o`030000<ol0<ol006/co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`008?ooo`030000
<ol0<ol006Xco`000ol0VC?o03?o0018<ol00P0004Koool0027oool20000JS?o0003o`2I<ol0<ol0
04Pco`000`000?ooooooo`15oooo000Soooo00<0000co`0co`00Ic?o0003o`2I<ol0<ol004Pco`00
0`000?ooooooo`15oooo000Toooo0P0006Lco`000ol0VC?o03?o0018<ol000<0003oooooool0AOoo
o`009_ooo`030000<ol0<ol006@co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`009ooo
o`030000<ol0<ol006<co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`00:?ooo`030000
<ol0<ol0068co`000ol0VC?o03?o000_<ol00P0000@co`02000013?o00800003<ol0100000@co`00
0`000?ooooooo`15oooo000Yoooo00<0000co`0co`00HC?o0003o`2I<ol0<ol002hco`00100003?o
03?o000000Pco`00100003?o03?o0000008co`000`0003?o03?o0005<ol000<0003oooooool0AOoo
o`00:_ooo`030000<ol0<ol0060co`000ol0VC?o03?o000^<ol000@0000co`0co`000008<ol000@0
000co`0co`000003<ol000<0000co`0co`0013?o00<00015oooo000[oooo0P00060co`000ol0VC?o
03?o000^<ol000@0000co`0co`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o
00030000oooooooo04Goool002goool00`0003?o03?o001M<ol000?o09Tco`0co`00;S?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo
04Goool002koool00`0003?o03?o001L<ol000?o09Tco`0co`00;c?o0080000:<ol00P0000@co`02
00001C?o00030000oooooooo04Goool002ooool00`0003?o03?o001K<ol000?o09Tco`0co`00B3?o
00030000oooooooo04Goool0033oool00`0003?o03?o001J<ol000?o09Tco`0co`00B3?o00030000
oooooooo04Goool0037oool00`0003?o03?o001I<ol000?o09Tco`0co`00B3?o00030000oooooooo
04Goool003;oool00`0003?o03?o001H<ol000?o09Tco`0co`00B3?o00030000oooooooo04Goool0
03?oool00`0003?o03?o001G<ol000?o09Tco`0co`00B3?o00800016oooo000coooo00<0000co`0c
o`00Ec?o0003o`2I<ol0<ol004Pco`000`000?ooooooo`15oooo000doooo00<0000co`0co`00ES?o
0003o`2I<ol0<ol004Pco`000`000?ooooooo`15oooo000eoooo00<0000co`0co`00EC?o0003o`2I
<ol0<ol004Pco`000`000?ooooooo`15oooo000foooo00<0000co`0co`00E3?o0003o`2I<ol0<ol0
04Pco`000`000?ooooooo`15oooo000goooo00<0000co`0co`00Dc?o0003o`2I<ol0<ol004Pco`00
0`000?ooooooo`15oooo000hoooo00<0000co`0co`00DS?o0003o`2I<ol0<ol004Pco`000`000?oo
ooooo`15oooo000hoooo00<0000co`0co`00DS?o0003o`2I<ol0<ol004Pco`000`000?ooooooo`15
oooo000ioooo00<0000co`0co`00DC?o0003o`2I<ol0<ol004Pco`020000A_ooo`00>_ooo`030000
<ol0<ol0050co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol0
04lco`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol004hco`00
0ol0VC?o03?o0018<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol004hco`000ol0VC?o
03?o0018<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol004dco`000ol0VC?o03?o0018
<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol004dco`000ol0VC?o03?o0018<ol000<0
003oooooool0AOooo`00?_ooo`030000<ol0<ol004`co`000ol0VC?o03?o0018<ol000<0003ooooo
ool0AOooo`00?_ooo`030000<ol0<ol004`co`000ol0VC?o03?o0018<ol000<0003oooooool0AOoo
o`00?oooo`030000<ol0<ol004/co`000ol0VC?o03?o0018<ol00P0004Koool003ooool00`0003?o
03?o001;<ol000?o09Tco`0co`00B3?o00030000oooooooo04Goool0043oool00`0003?o03?o001:
<ol000?o09Tco`0co`00B3?o00030000oooooooo04Goool0047oool00`0003?o03?o0019<ol000?o
09Tco`0co`00B3?o00030000oooooooo04Goool0047oool00`0003?o03?o0019<ol000?o09Tco`0c
o`00B3?o00030000oooooooo04Goool004;oool00`0003?o03?o0018<ol000?o09Tco`0co`00B3?o
00030000oooooooo04Goool004;oool00`0003?o03?o0018<ol000?o09Tco`0co`00;c?o00800004
<ol00P0000@co`0200001C?o00<00003<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol0
04Lco`000ol0VC?o03?o000^<ol000@0000co`0co`000008<ol000@0000co`0co`000005<ol000<0
000co`0co`000S?o00030000oooooooo04Goool004?oool00`0003?o03?o0017<ol000?o09Tco`0c
o`00;S?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00D00003<ol00`0004Goool0
04Coool00`0003?o03?o0016<ol000?o09Tco`0co`00;S?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool004Coool00`0003?o
03?o0016<ol000?o09Tco`0co`00;S?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o
00030000<ol0000000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`00AC?o0003o`2I
<ol0<ol002lco`0200002S?o00800005<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0
000co`0co`00AC?o0003o`2I<ol0<ol004Pco`000`000?ooooooo`15oooo0016oooo00<0000co`0c
o`00A3?o0003o`2I<ol0<ol004Pco`000`000?ooooooo`15oooo0016oooo00<0000co`0co`00A3?o
0003o`2I<ol0<ol004Pco`000`000?ooooooo`15oooo0017oooo00<0000co`0co`00@c?o0003o`2I
<ol0<ol004Pco`000`000?ooooooo`15oooo0017oooo00<0000co`0co`00@c?o0003o`2I<ol0<ol0
04Pco`020000A_ooo`00B?ooo`030000<ol0<ol0048co`000ol0VC?o03?o0018<ol000<0003ooooo
ool0AOooo`00B?ooo`030000<ol0<ol0048co`000ol0VC?o03?o0018<ol000<0003oooooool0AOoo
o`00BOooo`030000<ol0<ol0044co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`00BOoo
o`030000<ol0<ol0044co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`00B_ooo`030000
<ol0<ol0040co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol0
040co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol003lco`00
0ol0VC?o03?o0018<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol003lco`000ol0VC?o
03?o0018<ol00P0004Koool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool0
04gooon;<ol0B?ooo`00COoooh/co`18oooo001>oooo:S?o00030000<ol0<ol002Lco`000`0003?o
03?o000c<ol0B?ooo`00C_ooobTco`000`0003?o03?o0008<ol000<0000co`0co`007S?o00030000
<ol0<ol0038co`18oooo001?oooo:3?o00030000<ol0<ol0008co`02000013?o00030000<ol0<ol0
00Hco`02000013?o00800003<ol0100000@co`0300000S?o00030000<ol0<ol0038co`18oooo001?
oooo:3?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0000co`0co`0013?o
00040000<ol0<ol0000023?o00030000<ol0<ol000Hco`001@0003?o03?o03?o0000000d<ol0B?oo
o`00CoooobLco`000`0003?o03?o0002<ol000<0000co`0co`0033?o00040000<ol0<ol000002C?o
00030000<ol0<ol0008co`0500000c?o00030000<ol0<ol0034co`18oooo001@oooo9c?o00030000
<ol0<ol000D0000;<ol000@0000co`0co`00000:<ol000D0000co`0co`0co`0000000S?o00050000
<ol0<ol0<ol0000003@co`18oooo001@oooo9c?o00050000<ol0<ol0<ol0000000hco`00100003?o
03?o000000Pco`00100003?o03?o000000<co`000`0003?o00000003<ol000<0000co`0co`00<S?o
04Soool0053ooolX<ol000<0000co`0co`0043?o0080000:<ol00P0000Dco`0200000S?o00030000
<ol0<ol003<co`18oooo001AooooQc?o04Soool0057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.48147 .30902 L
.49012 .30902 L
.49468 .30902 L
.49719 .30902 L
.49842 .30902 L
.49955 .30902 L
s
.49955 .30902 m
.49956 .61803 L
s
0 .4 1 r
.02381 .27757 m
.06244 .27271 L
.10458 .26655 L
.14415 .25981 L
.18221 .25232 L
.22272 .24307 L
.26171 .23273 L
.30316 .21993 L
.34309 .20552 L
.3815 .18941 L
.42237 .16938 L
.46172 .14678 L
.48147 .134 L
.49012 .12807 L
.49468 .12485 L
.49719 .12306 L
.49842 .12217 L
.49955 .12136 L
.50085 .30902 L
.50154 .30902 L
.50226 .30902 L
.50343 .30902 L
.50471 .30902 L
.50591 .30902 L
.50719 .30902 L
.5084 .30902 L
.5095 .30902 L
.51071 .30902 L
.51183 .30902 L
.51306 .30902 L
.51436 .30902 L
.51549 .30902 L
.51655 .30902 L
.51771 .30902 L
.51896 .30902 L
.52027 .30902 L
.52149 .30902 L
.5222 .30902 L
.52283 .30902 L
.52357 .30902 L
.52427 .30902 L
.52557 .30902 L
.52622 .30902 L
.52695 .30902 L
.52773 .30902 L
.52846 .30902 L
.52913 .30902 L
.52985 .30902 L
.53234 .30902 L
.53357 .30902 L
Mistroke
.53469 .30902 L
.53599 .30902 L
.53666 .30902 L
.53739 .30902 L
.53858 .30902 L
.53984 .30902 L
.54115 .30902 L
.54189 .30902 L
.54256 .30902 L
.54386 .30902 L
.5451 .30902 L
.54631 .30902 L
.54743 .30902 L
.54866 .30902 L
.54997 .30902 L
.5525 .30902 L
.55319 .30902 L
.55383 .30902 L
.55449 .30902 L
.55522 .30902 L
.55598 .30902 L
.55678 .30902 L
.55753 .30902 L
.55821 .30902 L
.5589 .30902 L
.55965 .30902 L
.56036 .30902 L
.56101 .30902 L
.57078 .30902 L
.572 .30902 L
.57316 .30902 L
.5738 .30902 L
.57449 .30902 L
.57571 .30902 L
.57641 .30902 L
.57716 .30902 L
.5778 .30902 L
.5785 .30902 L
.57915 .30902 L
.57985 .30902 L
.58112 .30902 L
.58237 .30902 L
.58351 .30902 L
.58482 .30902 L
.58606 .30902 L
.58721 .30902 L
.58827 .30902 L
.58944 .30902 L
.59067 .30902 L
.59191 .30902 L
Mistroke
.59261 .30902 L
.59324 .30902 L
.59448 .30902 L
.59565 .30902 L
.59631 .30902 L
.59701 .30902 L
.59827 .30902 L
.599 .30902 L
.59976 .30902 L
.60042 .30902 L
.60113 .30902 L
.60182 .30902 L
.60255 .30902 L
.60387 .30902 L
.60467 .30902 L
.60542 .30902 L
.6061 .30902 L
.60683 .30902 L
.60753 .30902 L
.60818 .30902 L
.60887 .30902 L
.60962 .30902 L
.61086 .30902 L
.61156 .30902 L
.6122 .30902 L
.61341 .30902 L
.61453 .30902 L
.61576 .30902 L
.61708 .30902 L
.61775 .30902 L
.61847 .30902 L
.61978 .30902 L
.62105 .30902 L
.62222 .30902 L
.66165 .30902 L
.69955 .30902 L
.71902 .30902 L
.72032 .30902 L
.72104 .30902 L
.7217 .30902 L
.72248 .30902 L
.72321 .30902 L
.72389 .30902 L
.72462 .30902 L
.72526 .30902 L
.72597 .30902 L
.72739 .30902 L
.72994 .30902 L
.73122 .30902 L
.73243 .30902 L
Mistroke
.7331 .30902 L
.73383 .30902 L
.7351 .30902 L
.73632 .30902 L
.7376 .30902 L
.7387 .30902 L
.73991 .30902 L
.7412 .30902 L
.7424 .30902 L
.74371 .30902 L
.74444 .30902 L
.74511 .30902 L
.74633 .30902 L
.74765 .30902 L
.74889 .30902 L
.75004 .30902 L
.75115 .30902 L
.75219 .30902 L
.75333 .30902 L
.75455 .30902 L
.75931 .30902 L
.76062 .30902 L
.76135 .30902 L
.76202 .30902 L
.76326 .30902 L
.76457 .30902 L
.76584 .30902 L
.76656 .30902 L
.76722 .30902 L
.76797 .30902 L
.76864 .30902 L
.76942 .30902 L
.77015 .30902 L
.77137 .30902 L
.77266 .30902 L
.77376 .30902 L
.77497 .30902 L
.77627 .30902 L
.777 .30902 L
.77767 .30902 L
.77896 .30902 L
.78019 .30902 L
.78141 .30902 L
.78271 .30902 L
.78394 .30902 L
.78505 .30902 L
.78637 .30902 L
.7871 .30902 L
.78778 .30902 L
.79036 .30902 L
Mistroke
.80142 .30902 L
.82154 .30902 L
.86106 .30902 L
.89908 .30902 L
.93954 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
0=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo
04Goool008goool00`1Vooooooooo`18oooo00<0003oooooool0AOooo`00S?ooo`80I_m:oooo0P00
04Koool008_oool00`1Vooooo`1Vo`1:oooo00<0003oooooool0AOooo`00ROooo`80I_l2oooo00<0
I_ooooooool0B?ooo`030000oooooooo04Goool008Soool00`1Vooooooooo`02oooo00<0I_oooooo
ool0B?ooo`030000oooooooo04Goool008Koool206Ko1Oooo`0306Kooooooooo04Soool00`000?oo
ooooo`15oooo0025oooo00<0I_ooooooool01Oooo`0306Kooooooooo04Soool00`000?ooooooo`15
oooo0024oooo00<0I_ooooooool01_ooo`0306Kooooooooo04Soool00`000?ooooooo`15oooo0022
oooo0P1Vo`Woool00`1Vooooooooo`18oooo00<0003oooooool0AOooo`00P?ooo`80I_l;oooo00<0
I_ooooooool0B?ooo`800016oooo001noooo0P1Vo`goool00`1Vooooooooo`18oooo00<0003ooooo
ool0AOooo`00O?ooo`80I_l?oooo00<0I_ooooooool0B?ooo`030000oooooooo04Goool007[oool2
06Ko4Oooo`0306Kooooooooo04Soool00`000?ooooooo`15oooo001ioooo00<0I_ooooooool04Ooo
o`0306Kooooooooo04Soool00`000?ooooooo`15oooo001goooo0P1VoaCoool00`1Vooooooooo`18
oooo00<0003oooooool0AOooo`00MOooo`80I_lFoooo00<0I_ooooooool0;oooo`800004oooo0P00
00Coool200000oooo`@00004oooo00<0003oooooool0AOooo`00Loooo`80I_lHoooo00<0I_oooooo
ool0;_ooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`030000oooooooo00Goool0
0`000?ooooooo`15oooo001aoooo0P1Voa[oool00`1Vooooooooo`0^oooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool01?ooo`<00015oooo001^oooo0`1Voacoool0
0`1Vooooooooo`0Xoooo100000;oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool0
0`000?ooooooo`03oooo00<0003oooooool0AOooo`00K?ooo`80I_lOoooo00<0I_ooooooool0;_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool006Woool306Ko8Oooo`0306Kooooooooo02ooool200002_ooo`800004oooo0P00
00Goool00`000?ooooooo`15oooo001Woooo0P1VobCoool00`1Vooooooooo`18oooo00<0003ooooo
ool0AOooo`00I?ooo`<0I_lVoooo00<0I_ooooooool0B?ooo`030000oooooooo04Goool0067oool3
06Ko:Oooo`0306Kooooooooo04Soool00`000?ooooooo`15oooo001Ooooo0P1Vobcoool00`1Voooo
ooooo`18oooo00<0003oooooool0AOooo`00G?ooo`<0I_l_oooo00<0I_ooooooool0Aoooo`800016
oooo001Ioooo0`1Voc;oool00`1Vooooooooo`17oooo00<0003oooooool0AOooo`00EOooo`@0I_le
oooo00<0I_ooooooool0Aoooo`030000oooooooo04Goool0057oool406Ko>Oooo`0306Kooooooooo
04Ooool00`000?ooooooo`15oooo001>oooo0`1Vocgoool00`1Vooooooooo`17oooo00<0003ooooo
ool0AOooo`00Boooo`<0I_m0oooo00<0I_ooooooool0Aoooo`030000oooooooo04Goool004Ooool4
06Ko@oooo`0306Kooooooooo04Ooool00`000?ooooooo`15oooo0013oooo101VodOoool00`1Voooo
ooooo`17oooo00<0003oooooool0AOooo`00?_ooo`D0I_m;oooo00<0I_ooooooool0Aoooo`800016
oooo000ioooo1@1Voe3oool00`1Vooooooooo`17oooo00<0003oooooool0AOooo`00=?ooo`D0I_mE
oooo00<0I_ooooooool0Aoooo`030000oooooooo04Goool002ooool506KoF_ooo`0306Kooooooooo
04Ooool00`000?ooooooo`15oooo000Yoooo1P1Voeooool00`1Vooooooooo`17oooo00<0003ooooo
ool0AOooo`004_ooo`@0000>oooo1@1VoaGoool500000_ooo`800004oooo0P0002Woool500004ooo
o`0306Kooooooooo017oool200001?ooo`800004oooo0P0002Soool00`000?ooooooo`0Xoooo0P00
00Coool200001?ooo`80000?oooo000Boooo00<0003oooooool02_ooo`D0I_lLoooo00<0003ooooo
ool01oooo`040000oooooooo0000:_ooo`030000oooooooo01?oool00`1Vooooooooo`0@oooo00@0
003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo
00002?ooo`040000oooooooo00003_ooo`004oooo`040000oooooooooooo201Vob7oool00`000?oo
ooooo`0:oooo00<0003oooooool0:?ooo`030000oooooooo01?oool00`1Vooooooooo`0@oooo00@0
003oooooool0000;oooo00<0003oooooool09Oooo`030000oooooooo02Ooool010000?ooooooo`00
00_oool00`000?ooooooo`0<oooo000<oooo10000005oooo06Ko06Ko06Ko00000080I_lQoooo1000
00Coool00`000?ooooooo`08oooo0P0002?oool400001?ooo`030000oooooooo01?oool00`1Voooo
ooooo`0:oooo100000;oool010000?ooooooo`0000Woool20000:?ooo`80000Xoooo00@0003ooooo
ool00009oooo0P0000ooool001;oool010000?ooooooo`0002[oool00`000?ooooooo`08oooo00<0
003oooooool0:_ooo`030000oooooooo01?oool00`1Vooooooooo`0@oooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0001Goool00`1Vooooooooo`0A
oooo0P0000[oool300009oooo`030000oooooooo02Soool200002_ooo`<0000>oooo002>oooo00<0
I_ooooooool0Aoooo`030000oooooooo04Goool008koool00`1Vooooooooo`17oooo00<0003ooooo
ool0AOooo`00S_ooo`0306Kooooooooo04Ooool00`000?ooooooo`15oooo002>oooo00<0I_oooooo
ool0Aoooo`030000oooooooo04Goool008koool00`1Vooooooooo`17oooo00<0003oooooool0AOoo
o`002oooool0000700003oooo`004Oooo`030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00050000<ol0<ol0<ol0o`2I00Dco`00
0`0003?o03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003ooooo
ool01oooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0co`00;c?o00030000<ol0<ol0
02lco`000`0003?o03?o000E<ol000?o09Tco`0co`005S?o00030000<ol0<ol002lco`000`000?oo
ooooo`0_oooo00<0003oooooool04oooo`004Oooog`co`000ol0VC?o03?o0018<ol000<0003ooooo
ool0AOooo`004Oooog`co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`004Oooog`co`00
0ol0VC?o03?o0018<ol000<0003oooooool0AOooo`004Oooog`co`000ol0VC?o03?o0018<ol000<0
003oooooool0AOooo`004Oooog`co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`004Ooo
og`co`000ol0VC?o03?o0018<ol00P0004Koool0017oooml<ol000?o09Tco`0co`00B3?o00030000
oooooooo04Goool0017oooml<ol000?o09Tco`0co`00B3?o00030000oooooooo04Goool0017oooml
<ol000?o09Tco`0co`00B3?o00030000oooooooo04Goool0017oooml<ol000?o09Tco`0co`00B3?o
00030000oooooooo04Goool0017oooml<ol000?o09Tco`0co`00B3?o00030000oooooooo04Goool0
017oooml<ol000?o09Tco`0co`00B3?o00030000oooooooo04Goool0017oooml<ol000?o09Tco`0c
o`00B3?o00030000oooooooo04Goool0017oool20000NS?o0003o`2I<ol0<ol004Pco`020000A_oo
o`004oooo`80001h<ol000?o09Tco`0co`00B3?o00030000oooooooo04Goool001Goool20000MS?o
0003o`2I<ol0<ol004Pco`000`000?ooooooo`15oooo000Goooo0P0007@co`000ol0VC?o03?o0018
<ol000<0003oooooool0AOooo`006Oooo`80001b<ol000?o09Tco`0co`00B3?o00030000oooooooo
04Goool001_oool20000L3?o0003o`2I<ol0<ol004Pco`000`000?ooooooo`15oooo000Moooo0P00
06hco`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`007oooo`030000<ol0<ol006/co`00
0ol0VC?o03?o0018<ol000<0003oooooool0AOooo`008?ooo`030000<ol0<ol006Xco`000ol0VC?o
03?o0018<ol00P0004Koool0027oool20000JS?o0003o`2I<ol0<ol004Pco`000`000?ooooooo`15
oooo000Soooo00<0000co`0co`00Ic?o0003o`2I<ol0<ol004Pco`000`000?ooooooo`15oooo000T
oooo0P0006Lco`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`009_ooo`030000<ol0<ol0
06@co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`009oooo`030000<ol0<ol006<co`00
0ol0VC?o03?o0018<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol0068co`000ol0VC?o
03?o000_<ol00P0000@co`02000013?o00800003<ol0100000@co`000`000?ooooooo`15oooo000Y
oooo00<0000co`0co`00HC?o0003o`2I<ol0<ol002hco`00100003?o03?o000000Pco`00100003?o
03?o0000008co`000`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_ooo`030000<ol0<ol0
060co`000ol0VC?o03?o000^<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0
000co`0co`0013?o00<00015oooo000[oooo0P00060co`000ol0VC?o03?o000^<ol000@0000co`0c
o`000008<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o00030000oooooooo04Goool0
02goool00`0003?o03?o001M<ol000?o09Tco`0co`00;S?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool002koool00`0003?o
03?o001L<ol000?o09Tco`0co`00;c?o0080000:<ol00P0000@co`0200001C?o00030000oooooooo
04Goool002ooool00`0003?o03?o001K<ol000?o09Tco`0co`00B3?o00030000oooooooo04Goool0
033oool00`0003?o03?o001J<ol000?o09Tco`0co`00B3?o00030000oooooooo04Goool0037oool0
0`0003?o03?o001I<ol000?o09Tco`0co`00B3?o00030000oooooooo04Goool003;oool00`0003?o
03?o001H<ol000?o09Tco`0co`00B3?o00030000oooooooo04Goool003?oool00`0003?o03?o001G
<ol000?o09Tco`0co`00B3?o00800016oooo000coooo00<0000co`0co`00Ec?o0003o`2I<ol0<ol0
04Pco`000`000?ooooooo`15oooo000doooo00<0000co`0co`00ES?o0003o`2I<ol0<ol004Pco`00
0`000?ooooooo`15oooo000eoooo00<0000co`0co`00EC?o0003o`2I<ol0<ol004Pco`000`000?oo
ooooo`15oooo000foooo00<0000co`0co`00E3?o0003o`2I<ol0<ol004Pco`000`000?ooooooo`15
oooo000goooo00<0000co`0co`00Dc?o0003o`2I<ol0<ol004Pco`000`000?ooooooo`15oooo000h
oooo00<0000co`0co`00DS?o0003o`2I<ol0<ol004Pco`000`000?ooooooo`15oooo000hoooo00<0
000co`0co`00DS?o0003o`2I<ol0<ol004Pco`000`000?ooooooo`15oooo000ioooo00<0000co`0c
o`00DC?o0003o`2I<ol0<ol004Pco`020000A_ooo`00>_ooo`030000<ol0<ol0050co`000ol0VC?o
03?o0018<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol004lco`000ol0VC?o03?o0018
<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol004hco`000ol0VC?o03?o0018<ol000<0
003oooooool0AOooo`00??ooo`030000<ol0<ol004hco`000ol0VC?o03?o0018<ol000<0003ooooo
ool0AOooo`00?Oooo`030000<ol0<ol004dco`000ol0VC?o03?o0018<ol000<0003oooooool0AOoo
o`00?Oooo`030000<ol0<ol004dco`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`00?_oo
o`030000<ol0<ol004`co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`00?_ooo`030000
<ol0<ol004`co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`00?oooo`030000<ol0<ol0
04/co`000ol0VC?o03?o0018<ol00P0004Koool003ooool00`0003?o03?o001;<ol000?o09Tco`0c
o`00B3?o00030000oooooooo04Goool0043oool00`0003?o03?o001:<ol000?o09Tco`0co`00B3?o
00030000oooooooo04Goool0047oool00`0003?o03?o0019<ol000?o09Tco`0co`00B3?o00030000
oooooooo04Goool0047oool00`0003?o03?o0019<ol000?o09Tco`0co`00B3?o00030000oooooooo
04Goool004;oool00`0003?o03?o0018<ol000?o09Tco`0co`00B3?o00030000oooooooo04Goool0
04;oool00`0003?o03?o0018<ol000?o09Tco`0co`00;c?o00800004<ol00P0000@co`0200001C?o
00<00003<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol004Lco`000ol0VC?o03?o000^
<ol000@0000co`0co`000008<ol000@0000co`0co`000005<ol000<0000co`0co`000S?o00030000
oooooooo04Goool004?oool00`0003?o03?o0017<ol000?o09Tco`0co`00;S?o00040000<ol0<ol0
000023?o00040000<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool00`0003?o03?o0016
<ol000?o09Tco`0co`00;S?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000
<ol0<ol0000013?o00030000oooooooo04Goool004Coool00`0003?o03?o0016<ol000?o09Tco`0c
o`00;S?o00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0000000@co`00
0`000?ooooooo`15oooo0015oooo00<0000co`0co`00AC?o0003o`2I<ol0<ol002lco`0200002S?o
00800005<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`00AC?o0003o`2I
<ol0<ol004Pco`000`000?ooooooo`15oooo0016oooo00<0000co`0co`00A3?o0003o`2I<ol0<ol0
04Pco`000`000?ooooooo`15oooo0016oooo00<0000co`0co`00A3?o0003o`2I<ol0<ol004Pco`00
0`000?ooooooo`15oooo0017oooo00<0000co`0co`00@c?o0003o`2I<ol0<ol004Pco`000`000?oo
ooooo`15oooo0017oooo00<0000co`0co`00@c?o0003o`2I<ol0<ol004Pco`020000A_ooo`00B?oo
o`030000<ol0<ol0048co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`00B?ooo`030000
<ol0<ol0048co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol0
044co`000ol0VC?o03?o0018<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol0044co`00
0ol0VC?o03?o0018<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol0040co`000ol0VC?o
03?o0018<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol0040co`000ol0VC?o03?o0018
<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol003lco`000ol0VC?o03?o0018<ol000<0
003oooooool0AOooo`00Boooo`030000<ol0<ol003lco`000ol0VC?o03?o0018<ol00P0004Koool0
04cooon<<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;<ol0B?ooo`00COoo
oh/co`18oooo001>oooo:S?o00030000<ol0<ol002Lco`000`0003?o03?o000c<ol0B?ooo`00C_oo
obTco`000`0003?o03?o0008<ol000<0000co`0co`007S?o00030000<ol0<ol0038co`18oooo001?
oooo:3?o00030000<ol0<ol0008co`02000013?o00030000<ol0<ol000Hco`02000013?o00800003
<ol0100000<co`02000013?o00030000<ol0<ol0038co`18oooo001?oooo:3?o00050000<ol0<ol0
<ol00000008co`000`0003?o03?o0002<ol000<0000co`0co`0013?o00040000<ol0<ol0000023?o
00030000<ol0<ol000<co`00100003?o03?o000000<co`000`0003?o03?o000b<ol0B?ooo`00Cooo
obLco`000`0003?o03?o0002<ol000<0000co`0co`0033?o00040000<ol0<ol000002C?o00030000
<ol0<ol000Dco`000`0003?o03?o0002<ol000<0000co`0co`00<C?o04Soool0053ooolW<ol000<0
000co`0co`001@0000/co`00100003?o03?o000000Xco`000`0003?o03?o0002<ol00P0000@co`00
0`0003?o03?o000b<ol0B?ooo`00D?ooobLco`001@0003?o03?o03?o0000000><ol000@0000co`0c
o`000008<ol000@0000co`0co`000003<ol000<0000co`0co`000c?o00030000<ol0<ol0038co`18
oooo001@oooo:3?o00030000<ol0<ol0010co`0200002S?o00800004<ol00`00008co`000`0003?o
03?o000c<ol0B?ooo`00DOooohLco`18oooo001AooooQc?o04Soool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.48147 .30902 L
.49012 .30902 L
.49468 .30902 L
.49955 .30902 L
.50095 .30902 L
.50226 .30902 L
.50344 .30902 L
s
.50344 .30902 m
.50344 .61803 L
s
0 .4 1 r
.02381 .27625 m
.06244 .27119 L
.10458 .26478 L
.14415 .25776 L
.18221 .24995 L
.22272 .24032 L
.26171 .22954 L
.30316 .21621 L
.34309 .2012 L
.3815 .18441 L
.42237 .16355 L
.46172 .14 L
.48147 .12669 L
.49012 .12051 L
.49468 .11716 L
.49955 .11352 L
.50095 .11246 L
.50226 .11146 L
.50344 .11056 L
.50471 .30902 L
.50592 .30902 L
.50721 .30902 L
.5083 .30902 L
.5095 .30902 L
.51071 .30902 L
.51186 .30902 L
.5125 .30902 L
.51319 .30902 L
.51439 .30902 L
.51554 .30902 L
.51677 .30902 L
.51781 .30902 L
.51896 .30902 L
.52027 .30902 L
.52149 .30902 L
.52275 .30902 L
.52343 .30902 L
.52414 .30902 L
.52493 .30902 L
.52567 .30902 L
.52634 .30902 L
.52706 .30902 L
.52973 .30902 L
.53105 .30902 L
.53228 .30902 L
.53357 .30902 L
.53426 .30902 L
.53499 .30902 L
.53629 .30902 L
.53752 .30902 L
Mistroke
.53863 .30902 L
.53984 .30902 L
.54049 .30902 L
.54117 .30902 L
.5424 .30902 L
.54372 .30902 L
.54447 .30902 L
.54517 .30902 L
.54644 .30902 L
.54759 .30902 L
.54823 .30902 L
.54892 .30902 L
.55018 .30902 L
.55131 .30902 L
.55255 .30902 L
.55384 .30902 L
.55505 .30902 L
.55618 .30902 L
.55722 .30902 L
.55836 .30902 L
.55955 .30902 L
.56087 .30902 L
.56207 .30902 L
.56273 .30902 L
.56345 .30902 L
.56475 .30902 L
.56597 .30902 L
.56726 .30902 L
.56837 .30902 L
.56958 .30902 L
.57025 .30902 L
.57098 .30902 L
.57167 .30902 L
.57231 .30902 L
.57306 .30902 L
.57385 .30902 L
.57451 .30902 L
.57524 .30902 L
.57656 .30902 L
.5773 .30902 L
.57797 .30902 L
.57922 .30902 L
.58054 .30902 L
.58177 .30902 L
.58246 .30902 L
.5831 .30902 L
.58428 .30902 L
.58553 .30902 L
.58664 .30902 L
.58769 .30902 L
Mistroke
.58883 .30902 L
.59007 .30902 L
.59137 .30902 L
.59211 .30902 L
.59279 .30902 L
.59405 .30902 L
.59475 .30902 L
.59539 .30902 L
.59659 .30902 L
.59789 .30902 L
.59912 .30902 L
.60025 .30902 L
.60132 .30902 L
.60246 .30902 L
.60353 .30902 L
.60451 .30902 L
.60566 .30902 L
.60691 .30902 L
.60918 .30902 L
.61041 .30902 L
.61156 .30902 L
.61276 .30902 L
.6134 .30902 L
.61408 .30902 L
.61523 .30902 L
.61645 .30902 L
.61748 .30902 L
.61861 .30902 L
.61993 .30902 L
.62115 .30902 L
.62179 .30902 L
.62249 .30902 L
.6239 .30902 L
.62514 .30902 L
.62631 .30902 L
.62696 .30902 L
.62766 .30902 L
.6289 .30902 L
.63011 .30902 L
.6314 .30902 L
.63262 .30902 L
.63372 .30902 L
.63484 .30902 L
.63605 .30902 L
.63719 .30902 L
.63824 .30902 L
.63946 .30902 L
.64076 .30902 L
.64199 .30902 L
.64311 .30902 L
Mistroke
.64442 .30902 L
.64511 .30902 L
.64585 .30902 L
.64649 .30902 L
.64719 .30902 L
.64844 .30902 L
.64915 .30902 L
.64983 .30902 L
.65111 .30902 L
.65183 .30902 L
.65249 .30902 L
.65322 .30902 L
.65399 .30902 L
.65467 .30902 L
.6554 .30902 L
.65608 .30902 L
.65672 .30902 L
.65792 .30902 L
.65919 .30902 L
.66041 .30902 L
.6611 .30902 L
.66174 .30902 L
.66291 .30902 L
.66415 .30902 L
.66525 .30902 L
.66629 .30902 L
.66744 .30902 L
.66867 .30902 L
.6699 .30902 L
.6706 .30902 L
.67125 .30902 L
.67256 .30902 L
.6733 .30902 L
.67396 .30902 L
.67516 .30902 L
.67646 .30902 L
.67769 .30902 L
.67882 .30902 L
.67988 .30902 L
.68101 .30902 L
.68208 .30902 L
.68306 .30902 L
.68421 .30902 L
.68545 .30902 L
.68663 .30902 L
.68773 .30902 L
.68896 .30902 L
.69012 .30902 L
.69116 .30902 L
.69229 .30902 L
Mistroke
.69352 .30902 L
.69482 .30902 L
.69594 .30902 L
.69715 .30902 L
.69846 .30902 L
.69967 .30902 L
.7003 .30902 L
.701 .30902 L
.70241 .30902 L
.70364 .30902 L
.70434 .30902 L
.70497 .30902 L
.70615 .30902 L
.70738 .30902 L
.70849 .30902 L
.70969 .30902 L
.71081 .30902 L
.71183 .30902 L
.71303 .30902 L
.71433 .30902 L
.71556 .30902 L
.71669 .30902 L
.7179 .30902 L
.7192 .30902 L
.72042 .30902 L
.72154 .30902 L
.72285 .30902 L
.72359 .30902 L
.72427 .30902 L
.72553 .30902 L
.72616 .30902 L
.72686 .30902 L
.72754 .30902 L
.72825 .30902 L
.72953 .30902 L
.73024 .30902 L
.7309 .30902 L
.73163 .30902 L
.73241 .30902 L
.73308 .30902 L
.73381 .30902 L
.7345 .30902 L
.73514 .30902 L
.73634 .30902 L
.73762 .30902 L
.73882 .30902 L
.74014 .30902 L
.74138 .30902 L
.74253 .30902 L
.74368 .30902 L
Mistroke
.74471 .30902 L
.74591 .30902 L
.74703 .30902 L
.74826 .30902 L
.74957 .30902 L
.75068 .30902 L
.7519 .30902 L
.75257 .30902 L
.75331 .30902 L
.75401 .30902 L
.75465 .30902 L
.75587 .30902 L
.75716 .30902 L
.75828 .30902 L
.75933 .30902 L
.76173 .30902 L
.76662 .30902 L
.77546 .30902 L
.78056 .30902 L
.78183 .30902 L
.78304 .30902 L
.78412 .30902 L
.7853 .30902 L
.78646 .30902 L
.78769 .30902 L
.78902 .30902 L
.79024 .30902 L
.79565 .30902 L
.81416 .30902 L
.85205 .30902 L
.8924 .30902 L
.93123 .30902 L
.97251 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool0
08koool00`1Vooooooooo`17oooo00<0003oooooool0AOooo`00SOooo`80I_m9oooo00<0003ooooo
ool0AOooo`00S?ooo`0306Kooooo06Ko04Woool00`000?ooooooo`15oooo002;oooo00@0I_oooooo
ool0I_m9oooo00<0003oooooool0AOooo`00R_ooo`0506Kooooooooooooo06Ko04Woool20000A_oo
o`00ROooo`0306Kooooooooo00;oool00`1Vooooooooo`17oooo00<0003oooooool0AOooo`00Qooo
o`80I_l5oooo00<0I_ooooooool0Aoooo`030000oooooooo04Goool008Goool206Ko1oooo`0306Ko
oooooooo04Ooool00`000?ooooooo`15oooo0024oooo00<0I_ooooooool01oooo`0306Kooooooooo
04Ooool00`000?ooooooo`15oooo0022oooo0P1Vo`[oool00`1Vooooooooo`17oooo00<0003ooooo
ool0AOooo`00P?ooo`80I_l<oooo00<0I_ooooooool0Aoooo`030000oooooooo04Goool007koool2
06Ko3_ooo`0306Kooooooooo04Ooool00`000?ooooooo`15oooo001loooo0P1Voa3oool00`1Voooo
ooooo`17oooo0P0004Koool007[oool206Ko4_ooo`0306Kooooooooo04Ooool00`000?ooooooo`15
oooo001ioooo00<0I_ooooooool04_ooo`0306Kooooooooo04Ooool00`000?ooooooo`15oooo001g
oooo0P1VoaGoool00`1Vooooooooo`17oooo00<0003oooooool0AOooo`00MOooo`80I_lGoooo00<0
I_ooooooool0Aoooo`030000oooooooo04Goool007Coool00`1Vooooooooo`0Goooo00<0I_oooooo
ool0Aoooo`030000oooooooo04Goool007;oool206Ko6_ooo`0306Kooooooooo02koool200001?oo
o`800004oooo0P0000?oool400001?ooo`030000oooooooo04Goool0073oool206Ko7?ooo`0306Ko
oooooooo02goool010000?ooooooo`0000Soool010000?ooooooo`0000;oool00`000?ooooooo`05
oooo00<0003oooooool0AOooo`00K_ooo`80I_lNoooo00<0I_ooooooool0;Oooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool30000AOooo`00K?ooo`80I_lP
oooo00<0I_ooooooool09oooo`@00002oooo00@0003oooooool00008oooo00@0003oooooool00004
oooo00<0003oooooool00oooo`030000oooooooo04Goool006Woool306Ko8_ooo`0306Kooooooooo
02goool010000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000Coool0
0`000?ooooooo`15oooo001Woooo0P1VobGoool00`1Vooooooooo`0^oooo0P0000[oool200001?oo
o`800005oooo00<0003oooooool0AOooo`00I?ooo`<0I_lWoooo00<0I_ooooooool0Aoooo`030000
oooooooo04Goool0067oool306Ko:_ooo`0306Kooooooooo04Ooool00`000?ooooooo`15oooo001O
oooo0P1Vobgoool00`1Vooooooooo`17oooo00<0003oooooool0AOooo`00G?ooo`<0I_l`oooo00<0
I_ooooooool0A_ooo`030000oooooooo04Goool005Woool306Ko<oooo`0306Kooooooooo04Koool2
0000A_ooo`00EOooo`@0I_lfoooo00<0I_ooooooool0A_ooo`030000oooooooo04Goool0057oool4
06Ko>_ooo`0306Kooooooooo04Koool00`000?ooooooo`15oooo001>oooo0`1Vockoool00`1Voooo
ooooo`16oooo00<0003oooooool0AOooo`00Boooo`<0I_m1oooo00<0I_ooooooool0A_ooo`030000
oooooooo04Goool004Ooool406KoA?ooo`0306Kooooooooo04Koool00`000?ooooooo`15oooo0014
oooo0`1VodSoool00`1Vooooooooo`16oooo00<0003oooooool0AOooo`00@Oooo`<0I_m;oooo00<0
I_ooooooool0A_ooo`030000oooooooo04Goool003goool406KoC_ooo`0306Kooooooooo04Koool2
0000A_ooo`00>Oooo`@0I_mBoooo00<0I_ooooooool0A_ooo`030000oooooooo04Goool003Coool5
06KoE_ooo`0306Kooooooooo04Koool00`000?ooooooo`15oooo000_oooo1@1Voe_oool00`1Voooo
ooooo`16oooo00<0003oooooool0AOooo`00:Oooo`H0I_mPoooo00<0I_ooooooool0A_ooo`030000
oooooooo04Goool001;oool400003?ooo`L0I_lEoooo1@0000;oool200001?ooo`80000Yoooo1@00
01Coool00`1Vooooooooo`0@oooo0P0000Coool200001?ooo`80000Xoooo00<0003oooooool0:?oo
o`800004oooo0P0000Coool200003oooo`004_ooo`030000oooooooo00Goool806Ko7_ooo`030000
oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Doooo00<0I_ooooooool03ooo
o`040000oooooooo00002?ooo`040000oooooooo00009oooo`030000oooooooo02Ooool010000?oo
ooooo`0000Soool010000?ooooooo`0000koool001?oool00`00001Vo`1Vo`0406Ko9_ooo`030000
oooooooo00[oool00`000?ooooooo`0Xoooo00<0003oooooool05?ooo`0306Kooooooooo00ooool0
10000?ooooooo`0000_oool00`000?ooooooo`0Uoooo00<0003oooooool09oooo`040000oooooooo
00002oooo`030000oooooooo00coool000coool4000000Goool0I_l0I_l0I_l000008oooo`@00004
oooo00<0003oooooool02?ooo`80000Soooo100000Coool00`000?ooooooo`0Doooo00<0I_oooooo
ool02Oooo`@00002oooo00@0003oooooool00009oooo0P0002Soool20000:?ooo`040000oooooooo
00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0003oooooool02?ooo`030000
oooooooo02[oool00`000?ooooooo`0Doooo00<0I_ooooooool03oooo`040000oooooooo00002Ooo
o`030000oooooooo02Ooool00`000?ooooooo`0Woooo00@0003oooooool00009oooo00<0003ooooo
ool03_ooo`004oooo`80000Zoooo0P0000[oool30000:Oooo`80000Foooo00<0I_ooooooool04?oo
o`80000:oooo0`0002Ooool00`000?ooooooo`0Xoooo0P0000[oool300003_ooo`00Soooo`0306Ko
oooooooo04Koool00`000?ooooooo`15oooo002?oooo00<0I_ooooooool0A_ooo`030000oooooooo
04Goool008ooool00`1Vooooooooo`16oooo00<0003oooooool0AOooo`00Soooo`0306Kooooooooo
04Koool00`000?ooooooo`15oooo002?oooo00<0I_ooooooool0A_ooo`030000oooooooo04Goool0
00_ooooo00001`0000ooool0017oool00`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0002<ol000?o09Tco`0c
o`000S?o00030000<ol0<ol000Hco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo01?oool0017oool00`0003?o03?o000_<ol000<0
000co`0co`00;c?o00030000<ol0<ol001Hco`000ol0VC?o03?o000E<ol000<0000co`0co`00;c?o
00030000oooooooo02ooool00`000?ooooooo`0Coooo000AooooOC?o0003o`2I<ol0<ol004Lco`00
0`000?ooooooo`15oooo000AooooOC?o0003o`2I<ol0<ol004Lco`000`000?ooooooo`15oooo000A
ooooOC?o0003o`2I<ol0<ol004Lco`000`000?ooooooo`15oooo000AooooOC?o0003o`2I<ol0<ol0
04Lco`000`000?ooooooo`15oooo000AooooOC?o0003o`2I<ol0<ol004Lco`000`000?ooooooo`15
oooo000AooooOC?o0003o`2I<ol0<ol004Lco`020000A_ooo`004Oooogdco`000ol0VC?o03?o0017
<ol000<0003oooooool0AOooo`004Oooogdco`000ol0VC?o03?o0017<ol000<0003oooooool0AOoo
o`004Oooogdco`000ol0VC?o03?o0017<ol000<0003oooooool0AOooo`004Oooogdco`000ol0VC?o
03?o0017<ol000<0003oooooool0AOooo`004Oooogdco`000ol0VC?o03?o0017<ol000<0003ooooo
ool0AOooo`004Oooogdco`000ol0VC?o03?o0017<ol000<0003oooooool0AOooo`004Oooogdco`00
0ol0VC?o03?o0017<ol000<0003oooooool0AOooo`004Oooo`80001k<ol000?o09Tco`0co`00Ac?o
00800016oooo000Coooo0P0007Tco`000ol0VC?o03?o0017<ol000<0003oooooool0AOooo`005Ooo
o`80001g<ol000?o09Tco`0co`00Ac?o00030000oooooooo04Goool001Ooool20000MC?o0003o`2I
<ol0<ol004Lco`000`000?ooooooo`15oooo000Ioooo0P0007<co`000ol0VC?o03?o0017<ol000<0
003oooooool0AOooo`006oooo`80001a<ol000?o09Tco`0co`00Ac?o00030000oooooooo04Goool0
01goool20000Kc?o0003o`2I<ol0<ol004Lco`000`000?ooooooo`15oooo000Ooooo00<0000co`0c
o`00K3?o0003o`2I<ol0<ol004Lco`000`000?ooooooo`15oooo000Poooo00<0000co`0co`00Jc?o
0003o`2I<ol0<ol004Lco`020000A_ooo`008Oooo`80001[<ol000?o09Tco`0co`00Ac?o00030000
oooooooo04Goool002?oool00`0003?o03?o001X<ol000?o09Tco`0co`00Ac?o00030000oooooooo
04Goool002Coool20000J3?o0003o`2I<ol0<ol004Lco`000`000?ooooooo`15oooo000Voooo00<0
000co`0co`00IC?o0003o`2I<ol0<ol004Lco`000`000?ooooooo`15oooo000Woooo00<0000co`0c
o`00I3?o0003o`2I<ol0<ol004Lco`000`000?ooooooo`15oooo000Xoooo00<0000co`0co`00Hc?o
0003o`2I<ol0<ol002hco`02000013?o00800004<ol00P0000<co`04000013?o00030000oooooooo
04Goool002Woool00`0003?o03?o001R<ol000?o09Tco`0co`00;C?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000S?o00030000<ol0<ol000Dco`000`000?ooooooo`15oooo000Zoooo00<0
000co`0co`00HC?o0003o`2I<ol0<ol002dco`00100003?o03?o000000Pco`00100003?o03?o0000
00<co`000`0003?o03?o0004<ol00`0004Goool002_oool20000HC?o0003o`2I<ol0<ol002dco`00
100003?o03?o000000Pco`00100003?o03?o000000@co`000`0003?o03?o0003<ol000<0003ooooo
ool0AOooo`00;Oooo`030000<ol0<ol005hco`000ol0VC?o03?o000]<ol000@0000co`0co`000008
<ol000@0000co`0co`000002<ol000@0000co`0co`000004<ol000<0003oooooool0AOooo`00;_oo
o`030000<ol0<ol005dco`000ol0VC?o03?o000^<ol00P0000Xco`02000013?o00800005<ol000<0
003oooooool0AOooo`00;oooo`030000<ol0<ol005`co`000ol0VC?o03?o0017<ol000<0003ooooo
ool0AOooo`00<?ooo`030000<ol0<ol005/co`000ol0VC?o03?o0017<ol000<0003oooooool0AOoo
o`00<Oooo`030000<ol0<ol005Xco`000ol0VC?o03?o0017<ol000<0003oooooool0AOooo`00<_oo
o`030000<ol0<ol005Tco`000ol0VC?o03?o0017<ol000<0003oooooool0AOooo`00<oooo`030000
<ol0<ol005Pco`000ol0VC?o03?o0017<ol00P0004Koool003?oool00`0003?o03?o001H<ol000?o
09Tco`0co`00Ac?o00030000oooooooo04Goool003Coool00`0003?o03?o001G<ol000?o09Tco`0c
o`00Ac?o00030000oooooooo04Goool003Goool00`0003?o03?o001F<ol000?o09Tco`0co`00Ac?o
00030000oooooooo04Goool003Koool00`0003?o03?o001E<ol000?o09Tco`0co`00Ac?o00030000
oooooooo04Goool003Ooool00`0003?o03?o001D<ol000?o09Tco`0co`00Ac?o00030000oooooooo
04Goool003Soool00`0003?o03?o001C<ol000?o09Tco`0co`00Ac?o00030000oooooooo04Goool0
03Soool00`0003?o03?o001C<ol000?o09Tco`0co`00Ac?o00030000oooooooo04Goool003Woool0
0`0003?o03?o001B<ol000?o09Tco`0co`00Ac?o00800016oooo000joooo00<0000co`0co`00DC?o
0003o`2I<ol0<ol004Lco`000`000?ooooooo`15oooo000koooo00<0000co`0co`00D3?o0003o`2I
<ol0<ol004Lco`000`000?ooooooo`15oooo000loooo00<0000co`0co`00Cc?o0003o`2I<ol0<ol0
04Lco`000`000?ooooooo`15oooo000loooo00<0000co`0co`00Cc?o0003o`2I<ol0<ol004Lco`00
0`000?ooooooo`15oooo000moooo00<0000co`0co`00CS?o0003o`2I<ol0<ol004Lco`000`000?oo
ooooo`15oooo000moooo00<0000co`0co`00CS?o0003o`2I<ol0<ol004Lco`000`000?ooooooo`15
oooo000noooo00<0000co`0co`00CC?o0003o`2I<ol0<ol004Lco`000`000?ooooooo`15oooo000n
oooo00<0000co`0co`00CC?o0003o`2I<ol0<ol004Lco`000`000?ooooooo`15oooo000ooooo00<0
000co`0co`00C3?o0003o`2I<ol0<ol004Lco`020000A_ooo`00?oooo`030000<ol0<ol004`co`00
0ol0VC?o03?o0017<ol000<0003oooooool0AOooo`00@?ooo`030000<ol0<ol004/co`000ol0VC?o
03?o0017<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol004Xco`000ol0VC?o03?o0017
<ol000<0003oooooool0AOooo`00@Oooo`030000<ol0<ol004Xco`000ol0VC?o03?o0017<ol000<0
003oooooool0AOooo`00@_ooo`030000<ol0<ol004Tco`000ol0VC?o03?o0017<ol000<0003ooooo
ool0AOooo`00@_ooo`030000<ol0<ol004Tco`000ol0VC?o03?o000^<ol00P0000@co`02000013?o
00800005<ol00`0000<co`000`000?ooooooo`15oooo0013oooo00<0000co`0co`00B3?o0003o`2I
<ol0<ol002dco`00100003?o03?o000000Pco`00100003?o03?o000000Dco`000`0003?o03?o0002
<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol004Pco`000ol0VC?o03?o000]<ol000@0
000co`0co`000008<ol000@0000co`0co`000002<ol01@0000<co`030000AOooo`00A?ooo`030000
<ol0<ol004Lco`000ol0VC?o03?o000]<ol000@0000co`0co`000008<ol000@0000co`0co`000002
<ol000@0000co`0co`000004<ol000<0003oooooool0AOooo`00A?ooo`030000<ol0<ol004Lco`00
0ol0VC?o03?o000]<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`00
000013?o00030000oooooooo04Goool004Goool00`0003?o03?o0016<ol000?o09Tco`0co`00;S?o
0080000:<ol00P0000Dco`02000013?o00030000oooooooo04Goool004Goool00`0003?o03?o0016
<ol000?o09Tco`0co`00Ac?o00030000oooooooo04Goool004Koool00`0003?o03?o0015<ol000?o
09Tco`0co`00Ac?o00030000oooooooo04Goool004Koool00`0003?o03?o0015<ol000?o09Tco`0c
o`00Ac?o00030000oooooooo04Goool004Ooool00`0003?o03?o0014<ol000?o09Tco`0co`00Ac?o
00030000oooooooo04Goool004Ooool00`0003?o03?o0014<ol000?o09Tco`0co`00Ac?o00800016
oooo0018oooo00<0000co`0co`00@c?o0003o`2I<ol0<ol004Lco`000`000?ooooooo`15oooo0018
oooo00<0000co`0co`00@c?o0003o`2I<ol0<ol004Lco`000`000?ooooooo`15oooo0019oooo00<0
000co`0co`00@S?o0003o`2I<ol0<ol004Lco`000`000?ooooooo`15oooo0019oooo00<0000co`0c
o`00@S?o0003o`2I<ol0<ol004Lco`000`000?ooooooo`15oooo001:oooo00<0000co`0co`00@C?o
0003o`2I<ol0<ol004Lco`000`000?ooooooo`15oooo001:oooo00<0000co`0co`00@C?o0003o`2I
<ol0<ol004Lco`000`000?ooooooo`15oooo001;oooo00<0000co`0co`00@3?o0003o`2I<ol0<ol0
04Lco`000`000?ooooooo`15oooo001;oooo00<0000co`0co`00@3?o0003o`2I<ol0<ol004Lco`02
0000A_ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00COoooh/co`18
oooo001=ooooRc?o04Soool004kooolZ<ol000<0000co`0co`009c?o00030000<ol0<ol003<co`18
oooo001>oooo:C?o00030000<ol0<ol000Pco`000`0003?o03?o000N<ol000<0000co`0co`00<S?o
04Soool004oooolX<ol000<0000co`0co`000S?o00800004<ol000<0000co`0co`001S?o00800004
<ol00P0000<co`0400000S?o00<00004<ol000<0000co`0co`00<S?o04Soool004oooolX<ol000D0
000co`0co`0co`0000000S?o00030000<ol0<ol0008co`000`0003?o03?o0004<ol000@0000co`0c
o`000008<ol000<0000co`0co`000c?o00040000<ol0<ol000000c?o00030000<ol0<ol0038co`18
oooo001?oooo9c?o00030000<ol0<ol0008co`000`0003?o03?o000<<ol000@0000co`0co`000009
<ol000<0000co`0co`000S?o00040000<ol0<ol0000013?o00030000<ol0<ol0034co`18oooo001@
oooo9c?o00030000<ol0<ol000D0000;<ol000@0000co`0co`00000:<ol000@0000co`0co`0co`03
000013?o00030000<ol0<ol0038co`18oooo001@oooo9c?o00050000<ol0<ol0<ol0000000hco`00
100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o03?o0003<ol000<0000co`0c
o`00<S?o04Soool0053ooolX<ol000<0000co`0co`0043?o0080000:<ol00P0000@co`0300000S?o
00030000<ol0<ol003<co`18oooo001AooooQc?o04Soool0057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.27) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.48147 .30902 L
.49012 .30902 L
.49955 .30902 L
.50205 .30902 L
.50471 .30902 L
.50601 .30902 L
.50722 .30902 L
s
.50722 .30902 m
.50723 .61803 L
s
0 .4 1 r
.02381 .27493 m
.06244 .26967 L
.10458 .26299 L
.14415 .25569 L
.18221 .24757 L
.22272 .23755 L
.26171 .22634 L
.30316 .21247 L
.34309 .19686 L
.3815 .17939 L
.42237 .15769 L
.46172 .1332 L
.48147 .11934 L
.49012 .11292 L
.49955 .10564 L
.50205 .10367 L
.50471 .10154 L
.50601 .1005 L
.50722 .09951 L
.50832 .30902 L
.5095 .30902 L
.51064 .30902 L
.5119 .30902 L
.51321 .30902 L
.51443 .30902 L
.51557 .30902 L
.51662 .30902 L
.51782 .30902 L
.51896 .30902 L
.52016 .30902 L
.52148 .30902 L
.52214 .30902 L
.52286 .30902 L
.52416 .30902 L
.52538 .30902 L
.52666 .30902 L
.52776 .30902 L
.52896 .30902 L
.5297 .30902 L
.53039 .30902 L
.53169 .30902 L
.53241 .30902 L
.53308 .30902 L
.53382 .30902 L
.5346 .30902 L
.53589 .30902 L
.53709 .30902 L
.53778 .30902 L
.53842 .30902 L
.53915 .30902 L
Mistroke
.53984 .30902 L
.54109 .30902 L
.54226 .30902 L
.54348 .30902 L
.54412 .30902 L
.54481 .30902 L
.54556 .30902 L
.54628 .30902 L
.54691 .30902 L
.54761 .30902 L
.54826 .30902 L
.54895 .30902 L
.55018 .30902 L
.55133 .30902 L
.55257 .30902 L
.55374 .30902 L
.55481 .30902 L
.556 .30902 L
.5573 .30902 L
.55795 .30902 L
.55865 .30902 L
.55991 .30902 L
.56105 .30902 L
.56226 .30902 L
.5629 .30902 L
.56359 .30902 L
.56481 .30902 L
.56597 .30902 L
.5672 .30902 L
.56837 .30902 L
.56944 .30902 L
.57054 .30902 L
.57156 .30902 L
.57268 .30902 L
.57388 .30902 L
.57491 .30902 L
.57588 .30902 L
.57694 .30902 L
.57808 .30902 L
.57932 .30902 L
.58047 .30902 L
.58174 .30902 L
.58245 .30902 L
.58309 .30902 L
.58439 .30902 L
.58512 .30902 L
.5858 .30902 L
.58705 .30902 L
.58836 .30902 L
.58948 .30902 L
Mistroke
.59068 .30902 L
.59182 .30902 L
.59285 .30902 L
.59407 .30902 L
.59539 .30902 L
.59664 .30902 L
.5978 .30902 L
.59912 .30902 L
.59986 .30902 L
.60054 .30902 L
.6018 .30902 L
.60243 .30902 L
.60313 .30902 L
.60433 .30902 L
.60562 .30902 L
.60684 .30902 L
.60796 .30902 L
.60863 .30902 L
.60934 .30902 L
.61062 .30902 L
.61352 .30902 L
.61878 .30902 L
.62816 .30902 L
.6294 .30902 L
.63071 .30902 L
.63196 .30902 L
.63309 .30902 L
.63436 .30902 L
.63556 .30902 L
.63686 .30902 L
.63759 .30902 L
.63827 .30902 L
.63941 .30902 L
.64048 .30902 L
.64174 .30902 L
.6429 .30902 L
.64412 .30902 L
.64527 .30902 L
.64648 .30902 L
.64717 .30902 L
.64781 .30902 L
.64895 .30902 L
.65003 .30902 L
.65101 .30902 L
.65204 .30902 L
.65317 .30902 L
.65421 .30902 L
.65533 .30902 L
.65655 .30902 L
.65786 .30902 L
Mistroke
.65908 .30902 L
.65971 .30902 L
.66041 .30902 L
.66113 .30902 L
.66182 .30902 L
.66307 .30902 L
.66421 .30902 L
.66554 .30902 L
.66679 .30902 L
.66791 .30902 L
.6691 .30902 L
.67023 .30902 L
.67125 .30902 L
.67245 .30902 L
.67375 .30902 L
.67498 .30902 L
.67612 .30902 L
.67733 .30902 L
.67862 .30902 L
.67985 .30902 L
.68097 .30902 L
.68228 .30902 L
.68302 .30902 L
.6837 .30902 L
.68496 .30902 L
.68559 .30902 L
.68629 .30902 L
.68697 .30902 L
.68769 .30902 L
.68896 .30902 L
.68967 .30902 L
.69034 .30902 L
.69106 .30902 L
.69184 .30902 L
.69251 .30902 L
.69324 .30902 L
.69393 .30902 L
.69457 .30902 L
.69705 .30902 L
.69812 .30902 L
.69927 .30902 L
.70052 .30902 L
.70169 .30902 L
.70609 .30902 L
.70746 .30902 L
.70875 .30902 L
.70991 .30902 L
.71116 .30902 L
.71234 .30902 L
.71358 .30902 L
Mistroke
.71464 .30902 L
.7158 .30902 L
.71652 .30902 L
.7172 .30902 L
.71847 .30902 L
.71918 .30902 L
.71983 .30902 L
.72055 .30902 L
.72132 .30902 L
.72258 .30902 L
.72377 .30902 L
.72506 .30902 L
.72579 .30902 L
.72646 .30902 L
.72767 .30902 L
.72879 .30902 L
.73001 .30902 L
.73133 .30902 L
.73199 .30902 L
.73271 .30902 L
.73401 .30902 L
.73527 .30902 L
.73644 .30902 L
.7377 .30902 L
.73889 .30902 L
.73996 .30902 L
.74112 .30902 L
.74239 .30902 L
.74303 .30902 L
.74374 .30902 L
.74498 .30902 L
.74615 .30902 L
.74726 .30902 L
.74843 .30902 L
.74943 .30902 L
.75052 .30902 L
.7517 .30902 L
.75296 .30902 L
.75415 .30902 L
.75523 .30902 L
.75652 .30902 L
.75717 .30902 L
.75788 .30902 L
.75914 .30902 L
.76032 .30902 L
.76104 .30902 L
.76171 .30902 L
.76299 .30902 L
.7637 .30902 L
.76435 .30902 L
Mistroke
.76508 .30902 L
.76585 .30902 L
.76715 .30902 L
.76784 .30902 L
.76856 .30902 L
.76919 .30902 L
.76989 .30902 L
.77111 .30902 L
.7723 .30902 L
.77358 .30902 L
.77478 .30902 L
.77588 .30902 L
.77706 .30902 L
.77817 .30902 L
.77938 .30902 L
.78069 .30902 L
.78199 .30902 L
.78264 .30902 L
.78336 .30902 L
.78464 .30902 L
.7858 .30902 L
.78698 .30902 L
.7881 .30902 L
.79055 .30902 L
.79497 .30902 L
.81574 .30902 L
.85421 .30902 L
.89514 .30902 L
.93455 .30902 L
.97244 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.27) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo0P0004Koool00=Soool0
0`000?ooooooo`15oooo002?oooo00<0I_ooooooool0A_ooo`030000oooooooo04Goool008goool3
06KoB?ooo`030000oooooooo04Goool008coool0101Vooooooooo`1VodSoool00`000?ooooooo`15
oooo002;oooo00D0I_ooooooooooool0I_l0B?ooo`030000oooooooo04Goool008[oool00`1Voooo
ooooo`02oooo00<0I_ooooooool0A_ooo`030000oooooooo04Goool008Woool00`1Vooooooooo`03
oooo00<0I_ooooooool0A_ooo`030000oooooooo04Goool008Ooool206Ko1_ooo`0306Kooooooooo
04Koool20000A_ooo`00QOooo`80I_l8oooo00<0I_ooooooool0A_ooo`030000oooooooo04Goool0
08Coool00`1Vooooooooo`08oooo00<0I_ooooooool0A_ooo`030000oooooooo04Goool008;oool2
06Ko2oooo`0306Kooooooooo04Koool00`000?ooooooo`15oooo0021oooo00<0I_ooooooool02ooo
o`0306Kooooooooo04Koool00`000?ooooooo`15oooo001ooooo0P1Vo`koool00`1Vooooooooo`16
oooo00<0003oooooool0AOooo`00OOooo`80I_l@oooo00<0I_ooooooool0A_ooo`030000oooooooo
04Goool007coool00`1Vooooooooo`0@oooo00<0I_ooooooool0A_ooo`030000oooooooo04Goool0
07[oool206Ko4oooo`0306Kooooooooo04Koool20000A_ooo`00NOooo`0306Kooooooooo01?oool0
0`1Vooooooooo`16oooo00<0003oooooool0AOooo`00Moooo`80I_lFoooo00<0I_ooooooool0A_oo
o`030000oooooooo04Goool007Goool206Ko6?ooo`0306Kooooooooo04Koool00`000?ooooooo`15
oooo001coooo0P1Voa[oool00`1Vooooooooo`16oooo00<0003oooooool0AOooo`00LOooo`80I_lL
oooo00<0I_ooooooool0A_ooo`030000oooooooo04Goool006ooool206Ko7_ooo`0306Kooooooooo
02goool200001?ooo`800004oooo0P0000?oool400001?ooo`030000oooooooo04Goool006goool2
06Ko8?ooo`0306Kooooooooo02coool010000?ooooooo`0000Soool010000?ooooooo`0000;oool0
0`000?ooooooo`05oooo00<0003oooooool0AOooo`00Joooo`80I_lRoooo00<0I_ooooooool0;?oo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00Coool30000AOoo
o`00JOooo`80I_lToooo00<0I_ooooooool09_ooo`@00002oooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool00oooo`030000oooooooo04Goool006Ooool206Ko9_oo
o`0306Kooooooooo02coool010000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?oo
ooooo`0000Coool00`000?ooooooo`15oooo001Toooo0`1VobSoool00`1Vooooooooo`0]oooo0P00
00[oool200001?ooo`800005oooo00<0003oooooool0AOooo`00HOooo`<0I_l[oooo00<0I_oooooo
ool0A_ooo`030000oooooooo04Goool005ooool206Ko;_ooo`0306Kooooooooo04Koool00`000?oo
ooooo`15oooo001Loooo0`1Voc7oool00`1Vooooooooo`15oooo00<0003oooooool0AOooo`00FOoo
o`<0I_ldoooo00<0I_ooooooool0AOooo`030000oooooooo04Goool005Koool306Ko=oooo`0306Ko
oooooooo04Goool20000A_ooo`00E?ooo`80I_ljoooo00<0I_ooooooool0AOooo`030000oooooooo
04Goool0057oool306Ko??ooo`0306Kooooooooo04Goool00`000?ooooooo`15oooo001=oooo101V
ocooool00`1Vooooooooo`15oooo00<0003oooooool0AOooo`00B?ooo`D0I_m3oooo00<0I_oooooo
ool0AOooo`030000oooooooo04Goool004Coool406KoB?ooo`0306Kooooooooo04Goool00`000?oo
ooooo`15oooo0011oooo0`1Vodcoool00`1Vooooooooo`15oooo00<0003oooooool0AOooo`00?Ooo
o`@0I_m?oooo00<0I_ooooooool0AOooo`030000oooooooo04Goool003Woool406KoDoooo`0306Ko
oooooooo04Goool20000A_ooo`00=?ooo`D0I_mGoooo00<0I_ooooooool0AOooo`030000oooooooo
04Goool002ooool506KoG?ooo`0306Kooooooooo04Goool00`000?ooooooo`15oooo000Yoooo1P1V
of7oool00`1Vooooooooo`15oooo00<0003oooooool0AOooo`009?ooo`D0I_mWoooo00<0I_oooooo
ool0AOooo`030000oooooooo04Goool001;oool400002Oooo`D0I_lJoooo1@0000;oool200001?oo
o`80000Yoooo1@0001Goool00`1Vooooooooo`0?oooo0P0000Coool200001?ooo`80000Xoooo00<0
003oooooool0:?ooo`800004oooo0P0000Coool200003oooo`004_ooo`030000oooooooo00;oool8
06Ko8Oooo`030000oooooooo00Ooool010000?ooooooo`0002[oool00`000?ooooooo`0Eoooo00<0
I_ooooooool03_ooo`040000oooooooo00002?ooo`040000oooooooo00009oooo`030000oooooooo
02Ooool010000?ooooooo`0000Soool010000?ooooooo`0000koool0017oool206Ko00@00000I_l0
I_l0I_lYoooo00<0003oooooool02_ooo`030000oooooooo02Soool00`000?ooooooo`0Eoooo00<0
I_ooooooool03_ooo`040000oooooooo00002oooo`030000oooooooo02Goool00`000?ooooooo`0W
oooo00@0003oooooool0000;oooo00<0003oooooool03?ooo`003?ooo`@00004oooo00<0003ooooo
ool08Oooo`@00004oooo00<0003oooooool02?ooo`80000Soooo100000Coool00`000?ooooooo`0E
oooo00<0I_ooooooool02?ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool20000:?oo
o`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0003ooooo
ool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Eoooo00<0I_ooooooool03_ooo`040000
oooooooo00002Oooo`030000oooooooo02Ooool00`000?ooooooo`0Woooo00@0003oooooool00009
oooo00<0003oooooool03_ooo`004oooo`80000Zoooo0P0000[oool30000:Oooo`80000Goooo00<0
I_ooooooool03oooo`80000:oooo0`0002Ooool00`000?ooooooo`0Xoooo0P0000[oool300003_oo
o`00T?ooo`0306Kooooooooo04Goool00`000?ooooooo`15oooo002@oooo00<0I_ooooooool0AOoo
o`030000oooooooo04Goool0093oool00`1Vooooooooo`15oooo00<0003oooooool0AOooo`00T?oo
o`0306Kooooooooo04Goool00`000?ooooooo`15oooo002@oooo00<0I_ooooooool0AOooo`030000
oooooooo04Goool000_ooooo00001`0000ooool0017oool00`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`00
0`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0003
<ol000Go09Tco`0co`0co`00000023?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool04oooo`004Oooo`030000<ol0<ol002lco`00
0`0003?o03?o000_<ol000<0000co`0co`005c?o0003o`2I<ol0<ol001@co`000`0003?o03?o000_
<ol000<0003oooooool0;oooo`030000oooooooo01?oool0017ooomn<ol000?o09Tco`0co`00AS?o
00030000oooooooo04Goool0017ooomn<ol000?o09Tco`0co`00AS?o00030000oooooooo04Goool0
017ooomn<ol000?o09Tco`0co`00AS?o00030000oooooooo04Goool0017ooomn<ol000?o09Tco`0c
o`00AS?o00030000oooooooo04Goool0017ooomn<ol000?o09Tco`0co`00AS?o00030000oooooooo
04Goool0017ooomn<ol000?o09Tco`0co`00AS?o00800016oooo000AooooOS?o0003o`2I<ol0<ol0
04Hco`000`000?ooooooo`15oooo000AooooOS?o0003o`2I<ol0<ol004Hco`000`000?ooooooo`15
oooo000AooooOS?o0003o`2I<ol0<ol004Hco`000`000?ooooooo`15oooo000AooooOS?o0003o`2I
<ol0<ol004Hco`000`000?ooooooo`15oooo000AooooOS?o0003o`2I<ol0<ol004Hco`000`000?oo
ooooo`15oooo000AooooOS?o0003o`2I<ol0<ol004Hco`000`000?ooooooo`15oooo000AooooOS?o
0003o`2I<ol0<ol004Hco`000`000?ooooooo`15oooo000Aoooo0P0007`co`000ol0VC?o03?o0016
<ol00P0004Koool001?oool20000NS?o0003o`2I<ol0<ol004Hco`000`000?ooooooo`15oooo000E
oooo0P0007Pco`000ol0VC?o03?o0016<ol000<0003oooooool0AOooo`005oooo`80001f<ol000?o
09Tco`0co`00AS?o00030000oooooooo04Goool001Woool20000M3?o0003o`2I<ol0<ol004Hco`00
0`000?ooooooo`15oooo000Koooo0P00078co`000ol0VC?o03?o0016<ol000<0003oooooool0AOoo
o`007Oooo`80001`<ol000?o09Tco`0co`00AS?o00030000oooooooo04Goool001ooool00`0003?o
03?o001]<ol000?o09Tco`0co`00AS?o00030000oooooooo04Goool0023oool00`0003?o03?o001/
<ol000?o09Tco`0co`00AS?o00800016oooo000Qoooo0P0006`co`000ol0VC?o03?o0016<ol000<0
003oooooool0AOooo`008oooo`030000<ol0<ol006Tco`000ol0VC?o03?o0016<ol000<0003ooooo
ool0AOooo`009?ooo`80001Y<ol000?o09Tco`0co`00AS?o00030000oooooooo04Goool002Koool0
0`0003?o03?o001V<ol000?o09Tco`0co`00AS?o00030000oooooooo04Goool002Ooool00`0003?o
03?o001U<ol000?o09Tco`0co`00AS?o00030000oooooooo04Goool002Soool00`0003?o03?o001T
<ol000?o09Tco`0co`00;C?o00800004<ol00P0000@co`0200000c?o00@00004<ol000<0003ooooo
ool0AOooo`00:Oooo`030000<ol0<ol006<co`000ol0VC?o03?o000/<ol000@0000co`0co`000008
<ol000@0000co`0co`000002<ol000<0000co`0co`001C?o00030000oooooooo04Goool002[oool0
0`0003?o03?o001R<ol000?o09Tco`0co`00;3?o00040000<ol0<ol0000023?o00040000<ol0<ol0
00000c?o00030000<ol0<ol000@co`030000AOooo`00:oooo`80001R<ol000?o09Tco`0co`00;3?o
00040000<ol0<ol0000023?o00040000<ol0<ol0000013?o00030000<ol0<ol000<co`000`000?oo
ooooo`15oooo000]oooo00<0000co`0co`00Gc?o0003o`2I<ol0<ol002`co`00100003?o03?o0000
00Pco`00100003?o03?o0000008co`00100003?o03?o000000@co`000`000?ooooooo`15oooo000^
oooo00<0000co`0co`00GS?o0003o`2I<ol0<ol002dco`0200002S?o00800004<ol00P0000Dco`00
0`000?ooooooo`15oooo000_oooo00<0000co`0co`00GC?o0003o`2I<ol0<ol004Hco`000`000?oo
ooooo`15oooo000`oooo00<0000co`0co`00G3?o0003o`2I<ol0<ol004Hco`000`000?ooooooo`15
oooo000aoooo00<0000co`0co`00Fc?o0003o`2I<ol0<ol004Hco`000`000?ooooooo`15oooo000b
oooo00<0000co`0co`00FS?o0003o`2I<ol0<ol004Hco`000`000?ooooooo`15oooo000coooo00<0
000co`0co`00FC?o0003o`2I<ol0<ol004Hco`020000A_ooo`00<oooo`030000<ol0<ol005Tco`00
0ol0VC?o03?o0016<ol000<0003oooooool0AOooo`00=?ooo`030000<ol0<ol005Pco`000ol0VC?o
03?o0016<ol000<0003oooooool0AOooo`00=Oooo`030000<ol0<ol005Lco`000ol0VC?o03?o0016
<ol000<0003oooooool0AOooo`00=_ooo`030000<ol0<ol005Hco`000ol0VC?o03?o0016<ol000<0
003oooooool0AOooo`00=oooo`030000<ol0<ol005Dco`000ol0VC?o03?o0016<ol000<0003ooooo
ool0AOooo`00>?ooo`030000<ol0<ol005@co`000ol0VC?o03?o0016<ol000<0003oooooool0AOoo
o`00>?ooo`030000<ol0<ol005@co`000ol0VC?o03?o0016<ol000<0003oooooool0AOooo`00>Ooo
o`030000<ol0<ol005<co`000ol0VC?o03?o0016<ol00P0004Koool003[oool00`0003?o03?o001B
<ol000?o09Tco`0co`00AS?o00030000oooooooo04Goool003_oool00`0003?o03?o001A<ol000?o
09Tco`0co`00AS?o00030000oooooooo04Goool003coool00`0003?o03?o001@<ol000?o09Tco`0c
o`00AS?o00030000oooooooo04Goool003coool00`0003?o03?o001@<ol000?o09Tco`0co`00AS?o
00030000oooooooo04Goool003goool00`0003?o03?o001?<ol000?o09Tco`0co`00AS?o00030000
oooooooo04Goool003goool00`0003?o03?o001?<ol000?o09Tco`0co`00AS?o00030000oooooooo
04Goool003koool00`0003?o03?o001><ol000?o09Tco`0co`00AS?o00030000oooooooo04Goool0
03koool00`0003?o03?o001><ol000?o09Tco`0co`00AS?o00030000oooooooo04Goool003ooool0
0`0003?o03?o001=<ol000?o09Tco`0co`00AS?o00800016oooo000ooooo00<0000co`0co`00CC?o
0003o`2I<ol0<ol004Hco`000`000?ooooooo`15oooo0010oooo00<0000co`0co`00C3?o0003o`2I
<ol0<ol004Hco`000`000?ooooooo`15oooo0011oooo00<0000co`0co`00Bc?o0003o`2I<ol0<ol0
04Hco`000`000?ooooooo`15oooo0011oooo00<0000co`0co`00Bc?o0003o`2I<ol0<ol004Hco`00
0`000?ooooooo`15oooo0012oooo00<0000co`0co`00BS?o0003o`2I<ol0<ol004Hco`000`000?oo
ooooo`15oooo0012oooo00<0000co`0co`00BS?o0003o`2I<ol0<ol002dco`02000013?o00800004
<ol00P0000Dco`0300000c?o00030000oooooooo04Goool004?oool00`0003?o03?o0019<ol000?o
09Tco`0co`00;3?o00040000<ol0<ol0000023?o00040000<ol0<ol000001C?o00030000<ol0<ol0
008co`000`000?ooooooo`15oooo0013oooo00<0000co`0co`00BC?o0003o`2I<ol0<ol002`co`00
100003?o03?o000000Pco`00100003?o03?o0000008co`0500000c?o00<00015oooo0014oooo00<0
000co`0co`00B3?o0003o`2I<ol0<ol002`co`00100003?o03?o000000Pco`00100003?o03?o0000
008co`00100003?o03?o000000@co`000`000?ooooooo`15oooo0014oooo00<0000co`0co`00B3?o
0003o`2I<ol0<ol002`co`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o
00000004<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol004Lco`000ol0VC?o03?o000]
<ol00P0000Xco`0200001C?o00800004<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol0
04Lco`000ol0VC?o03?o0016<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol004Hco`00
0ol0VC?o03?o0016<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol004Hco`000ol0VC?o
03?o0016<ol000<0003oooooool0AOooo`00Aoooo`030000<ol0<ol004Dco`000ol0VC?o03?o0016
<ol000<0003oooooool0AOooo`00Aoooo`030000<ol0<ol004Dco`000ol0VC?o03?o0016<ol00P00
04Koool004Soool00`0003?o03?o0014<ol000?o09Tco`0co`00AS?o00030000oooooooo04Goool0
04Soool00`0003?o03?o0014<ol000?o09Tco`0co`00AS?o00030000oooooooo04Goool004Woool0
0`0003?o03?o0013<ol000?o09Tco`0co`00AS?o00030000oooooooo04Goool004Woool00`0003?o
03?o0013<ol000?o09Tco`0co`00AS?o00030000oooooooo04Goool004[oool00`0003?o03?o0012
<ol000?o09Tco`0co`00AS?o00030000oooooooo04Goool004[oool00`0003?o03?o0012<ol000?o
09Tco`0co`00AS?o00030000oooooooo04Goool004_oool00`0003?o03?o0011<ol000?o09Tco`0c
o`00AS?o00030000oooooooo04Goool004_oool00`0003?o03?o0011<ol000?o09Tco`0co`00AS?o
00800016oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001=ooooRc?o
04Soool004gooon;<ol0B?ooo`00C_ooobXco`000`0003?o03?o000W<ol000<0000co`0co`00<c?o
04Soool004kooolY<ol000<0000co`0co`0023?o00030000<ol0<ol001hco`000`0003?o03?o000b
<ol0B?ooo`00CoooobPco`000`0003?o03?o0002<ol00P0000@co`000`0003?o03?o0006<ol00P00
00@co`0200000c?o00@00004<ol000<0000co`0co`000S?o00030000<ol0<ol0038co`18oooo001?
oooo:3?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0000co`0co`0013?o
00040000<ol0<ol0000023?o00030000<ol0<ol000Dco`000`0003?o03?o0002<ol000<0000co`0c
o`00<S?o04Soool004oooolW<ol000<0000co`0co`000S?o00030000<ol0<ol000`co`00100003?o
03?o000000Tco`000`0003?o03?o0004<ol000<0000co`0co`000c?o00030000<ol0<ol0034co`18
oooo001@oooo9c?o00030000<ol0<ol000D0000;<ol000@0000co`0co`00000:<ol000<0000co`0c
o`0013?o00050000<ol0<ol0<ol0000003@co`18oooo001@oooo9c?o00050000<ol0<ol0<ol00000
00hco`00100003?o03?o000000Pco`00100003?o03?o0000008co`00100003?o03?o000000<co`00
0`0003?o03?o000b<ol0B?ooo`00D?ooobPco`000`0003?o03?o000@<ol00P0000Xco`0200000c?o
00@00002<ol000<0000co`0co`00<c?o04Soool0057ooon7<ol0B?ooo`00DOooohLco`18oooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.48147 .30902 L
.49955 .30902 L
.50431 .30902 L
.50682 .30902 L
.5082 .30902 L
.5095 .30902 L
.51074 .30902 L
s
.51074 .30902 m
.51074 .61803 L
s
0 .4 1 r
.02381 .27361 m
.06244 .26814 L
.10458 .2612 L
.14415 .25361 L
.18221 .24518 L
.22272 .23477 L
.26171 .22313 L
.30316 .20871 L
.34309 .19249 L
.3815 .17435 L
.42237 .1518 L
.46172 .12635 L
.48147 .11196 L
.49955 .09773 L
.50431 .0938 L
.50682 .0917 L
.5082 .09053 L
.5095 .08943 L
.51074 .08837 L
.51143 .30902 L
.51207 .30902 L
.51321 .30902 L
.51441 .30902 L
.51553 .30902 L
.51658 .30902 L
.51773 .30902 L
.51896 .30902 L
.51964 .30902 L
.52036 .30902 L
.52165 .30902 L
.52236 .30902 L
.52304 .30902 L
.52377 .30902 L
.52457 .30902 L
.52521 .30902 L
.52592 .30902 L
.52734 .30902 L
.52866 .30902 L
.52988 .30902 L
.53118 .30902 L
.5324 .30902 L
.5335 .30902 L
.5347 .30902 L
.536 .30902 L
.53665 .30902 L
.53737 .30902 L
.53865 .30902 L
.53984 .30902 L
.54109 .30902 L
.54179 .30902 L
Mistroke
.54242 .30902 L
.54366 .30902 L
.54482 .30902 L
.54609 .30902 L
.54673 .30902 L
.54743 .30902 L
.54819 .30902 L
.5489 .30902 L
.54955 .30902 L
.55025 .30902 L
.55152 .30902 L
.55224 .30902 L
.5529 .30902 L
.55412 .30902 L
.55542 .30902 L
.55657 .30902 L
.55766 .30902 L
.55885 .30902 L
.56013 .30902 L
.56974 .30902 L
.57089 .30902 L
.57214 .30902 L
.57333 .30902 L
.57442 .30902 L
.5754 .30902 L
.57648 .30902 L
.57761 .30902 L
.57866 .30902 L
.57981 .30902 L
.5809 .30902 L
.58216 .30902 L
.58331 .30902 L
.58454 .30902 L
.58571 .30902 L
.58692 .30902 L
.58756 .30902 L
.58826 .30902 L
.58892 .30902 L
.58962 .30902 L
.59087 .30902 L
.59202 .30902 L
.59328 .30902 L
.59399 .30902 L
.59465 .30902 L
.5954 .30902 L
.59611 .30902 L
.59737 .30902 L
.59808 .30902 L
.59874 .30902 L
.59995 .30902 L
Mistroke
.60109 .30902 L
.60241 .30902 L
.60362 .30902 L
.60431 .30902 L
.60495 .30902 L
.60565 .30902 L
.6064 .30902 L
.6071 .30902 L
.60776 .30902 L
.60899 .30902 L
.61032 .30902 L
.61098 .30902 L
.61171 .30902 L
.61301 .30902 L
.61421 .30902 L
.61494 .30902 L
.61564 .30902 L
.61694 .30902 L
.61766 .30902 L
.61834 .30902 L
.61907 .30902 L
.61986 .30902 L
.62099 .30902 L
.62224 .30902 L
.62354 .30902 L
.62475 .30902 L
.62589 .30902 L
.62692 .30902 L
.62811 .30902 L
.62924 .30902 L
.63046 .30902 L
.63176 .30902 L
.63287 .30902 L
.63409 .30902 L
.63476 .30902 L
.6355 .30902 L
.63619 .30902 L
.63683 .30902 L
.63805 .30902 L
.63934 .30902 L
.64057 .30902 L
.64173 .30902 L
.64277 .30902 L
.6439 .30902 L
.64514 .30902 L
.64645 .30902 L
.64757 .30902 L
.64879 .30902 L
.64995 .30902 L
.651 .30902 L
Mistroke
.65221 .30902 L
.65336 .30902 L
.65443 .30902 L
.65541 .30902 L
.65648 .30902 L
.65763 .30902 L
.65883 .30902 L
.66014 .30902 L
.66138 .30902 L
.66254 .30902 L
.66368 .30902 L
.66471 .30902 L
.66591 .30902 L
.66703 .30902 L
.66826 .30902 L
.66956 .30902 L
.67067 .30902 L
.67189 .30902 L
.6732 .30902 L
.67394 .30902 L
.67461 .30902 L
.67592 .30902 L
.67715 .30902 L
.6782 .30902 L
.67936 .30902 L
.68057 .30902 L
.6817 .30902 L
.68276 .30902 L
.68373 .30902 L
.68479 .30902 L
.68591 .30902 L
.68705 .30902 L
.68827 .30902 L
.68942 .30902 L
.69047 .30902 L
.6917 .30902 L
.69239 .30902 L
.69303 .30902 L
.6942 .30902 L
.69545 .30902 L
.69666 .30902 L
.69798 .30902 L
.69922 .30902 L
.70038 .30902 L
.70152 .30902 L
.70256 .30902 L
.70375 .30902 L
.70488 .30902 L
.70611 .30902 L
.70742 .30902 L
Mistroke
.70853 .30902 L
.70975 .30902 L
.71107 .30902 L
.7118 .30902 L
.71247 .30902 L
.71378 .30902 L
.71501 .30902 L
.71607 .30902 L
.71723 .30902 L
.71844 .30902 L
.71957 .30902 L
.72063 .30902 L
.7216 .30902 L
.72267 .30902 L
.72379 .30902 L
.72493 .30902 L
.72615 .30902 L
.72834 .30902 L
.72969 .30902 L
.73095 .30902 L
.73209 .30902 L
.73332 .30902 L
.75284 .30902 L
.75538 .30902 L
.75608 .30902 L
.75682 .30902 L
.75745 .30902 L
.75815 .30902 L
.7594 .30902 L
.7601 .30902 L
.76074 .30902 L
.76201 .30902 L
.76318 .30902 L
.76383 .30902 L
.76453 .30902 L
.7653 .30902 L
.76601 .30902 L
.76674 .30902 L
.76754 .30902 L
.76829 .30902 L
.76898 .30902 L
.77021 .30902 L
.7709 .30902 L
.77156 .30902 L
.77287 .30902 L
.77361 .30902 L
.77428 .30902 L
.77554 .30902 L
.77624 .30902 L
.77687 .30902 L
Mistroke
.77811 .30902 L
.77928 .30902 L
.77994 .30902 L
.78065 .30902 L
.7819 .30902 L
.78327 .30902 L
.78404 .30902 L
.78474 .30902 L
.78599 .30902 L
.78719 .30902 L
.78947 .30902 L
.79467 .30902 L
.81373 .30902 L
.85206 .30902 L
.89285 .30902 L
.93213 .30902 L
.96988 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool00=Soool00`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?oo
o`030000oooooooo04Goool008ooool206KoAoooo`030000oooooooo04Goool008ooool206KoAooo
o`800016oooo002=oooo0P1Vo`03oooo06Kooooo04Koool00`000?ooooooo`15oooo002<oooo00D0
I_ooooooooooool0I_l0Aoooo`030000oooooooo04Goool008_oool00`1Vooooooooo`02oooo00<0
I_ooooooool0AOooo`030000oooooooo04Goool008[oool00`1Vooooooooo`03oooo00<0I_oooooo
ool0AOooo`030000oooooooo04Goool008Woool00`1Vooooooooo`04oooo00<0I_ooooooool0AOoo
o`030000oooooooo04Goool008Ooool206Ko1oooo`0306Kooooooooo04Goool00`000?ooooooo`15
oooo0025oooo0P1Vo`Woool00`1Vooooooooo`15oooo00<0003oooooool0AOooo`00Q?ooo`0306Ko
oooooooo00Woool00`1Vooooooooo`15oooo0P0004Koool008;oool206Ko3?ooo`0306Kooooooooo
04Goool00`000?ooooooo`15oooo0021oooo00<0I_ooooooool03?ooo`0306Kooooooooo04Goool0
0`000?ooooooo`15oooo001ooooo0P1Vo`ooool00`1Vooooooooo`15oooo00<0003oooooool0AOoo
o`00OOooo`80I_lAoooo00<0I_ooooooool0AOooo`030000oooooooo04Goool007coool00`1Voooo
ooooo`0Aoooo00<0I_ooooooool0AOooo`030000oooooooo04Goool007[oool206Ko5?ooo`0306Ko
oooooooo04Goool00`000?ooooooo`15oooo001ioooo00<0I_ooooooool05?ooo`0306Kooooooooo
04Goool00`000?ooooooo`15oooo001goooo0P1VoaOoool00`1Vooooooooo`15oooo0P0004Koool0
07Goool206Ko6Oooo`0306Kooooooooo04Goool00`000?ooooooo`15oooo001doooo00<0I_oooooo
ool06Oooo`0306Kooooooooo04Goool00`000?ooooooo`15oooo001boooo0P1Voacoool00`1Voooo
ooooo`15oooo00<0003oooooool0AOooo`00L?ooo`80I_lNoooo00<0I_ooooooool0AOooo`030000
oooooooo04Goool006ooool00`1Vooooooooo`0Noooo00<0I_ooooooool0AOooo`030000oooooooo
04Goool006goool206Ko8Oooo`0306Kooooooooo02coool200001?ooo`800004oooo0P0000?oool4
00001?ooo`030000oooooooo04Goool006_oool206Ko8oooo`0306Kooooooooo02_oool010000?oo
ooooo`0000Soool010000?ooooooo`0000;oool00`000?ooooooo`05oooo00<0003oooooool0AOoo
o`00JOooo`80I_lUoooo00<0I_ooooooool0:oooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00Coool30000AOooo`00Ioooo`80I_lWoooo00<0I_ooooooool09Ooo
o`@00002oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool00ooo
o`030000oooooooo04Goool006Coool306Ko:Oooo`0306Kooooooooo02_oool010000?ooooooo`00
00Soool010000?ooooooo`0000;oool010000?ooooooo`0000Coool00`000?ooooooo`15oooo001Q
oooo0`1Vobcoool00`1Vooooooooo`0/oooo0P0000[oool200001?ooo`800005oooo00<0003ooooo
ool0AOooo`00Goooo`80I_l`oooo00<0I_ooooooool0A?ooo`030000oooooooo04Goool005coool3
06Ko<_ooo`0306Kooooooooo04Coool00`000?ooooooo`15oooo001Ioooo0`1VocGoool00`1Voooo
ooooo`14oooo00<0003oooooool0AOooo`00E_ooo`<0I_lhoooo00<0I_ooooooool0A?ooo`030000
oooooooo04Goool005Coool206Ko>oooo`0306Kooooooooo04Coool20000A_ooo`00DOooo`<0I_lm
oooo00<0I_ooooooool0A?ooo`030000oooooooo04Goool004koool306Ko@?ooo`0306Kooooooooo
04Coool00`000?ooooooo`15oooo001;oooo0`1Vod?oool00`1Vooooooooo`14oooo00<0003ooooo
ool0AOooo`00Aoooo`@0I_m6oooo00<0I_ooooooool0A?ooo`030000oooooooo04Goool004?oool4
06KoB_ooo`0306Kooooooooo04Coool00`000?ooooooo`15oooo000noooo1@1Vodkoool00`1Voooo
ooooo`14oooo00<0003oooooool0AOooo`00>_ooo`@0I_mCoooo00<0I_ooooooool0A?ooo`030000
oooooooo04Goool003Ooool306KoEoooo`0306Kooooooooo04Coool20000A_ooo`00<oooo`@0I_mJ
oooo00<0I_ooooooool0A?ooo`030000oooooooo04Goool002ooool406KoG_ooo`0306Kooooooooo
04Coool00`000?ooooooo`15oooo000Yoooo1P1Vof;oool00`1Vooooooooo`14oooo00<0003ooooo
ool0AOooo`008_ooo`L0I_mXoooo00<0I_ooooooool0A?ooo`030000oooooooo04Goool001;oool4
00001?ooo`P0I_lLoooo1@0000;oool200001?ooo`80000Yoooo1@0001Koool00`1Vooooooooo`0>
oooo0P0000Coool200001?ooo`80000Xoooo00<0003oooooool0:?ooo`800004oooo0P0000Coool2
00003oooo`004_ooo`030000oooo06Ko00D0I_lVoooo00<0003oooooool01oooo`040000oooooooo
0000:_ooo`030000oooooooo01Koool00`1Vooooooooo`0=oooo00@0003oooooool00008oooo00@0
003oooooool0000Woooo00<0003oooooool09oooo`040000oooooooo00002?ooo`040000oooooooo
00003_ooo`004Oooo`80I_l00`000?ooooooo`0Zoooo00<0003oooooool02_ooo`030000oooooooo
02Soool00`000?ooooooo`0Foooo00<0I_ooooooool03Oooo`040000oooooooo00002oooo`030000
oooooooo02Goool00`000?ooooooo`0Woooo00@0003oooooool0000;oooo00<0003oooooool03?oo
o`003?ooo`@00004oooo00<0003oooooool08Oooo`@00004oooo00<0003oooooool02?ooo`80000S
oooo100000Coool00`000?ooooooo`0Foooo00<0I_ooooooool01oooo`@00002oooo00@0003ooooo
ool00009oooo0P0002Soool20000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0
003oooooool0000Zoooo00<0003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0F
oooo00<0I_ooooooool03Oooo`040000oooooooo00002Oooo`030000oooooooo02Ooool00`000?oo
ooooo`0Woooo00@0003oooooool00009oooo00<0003oooooool03_ooo`004oooo`80000Zoooo0P00
00[oool30000:Oooo`80000Hoooo00<0I_ooooooool03_ooo`80000:oooo0`0002Ooool00`000?oo
ooooo`0Xoooo0P0000[oool300003_ooo`00TOooo`0306Kooooooooo04Coool00`000?ooooooo`15
oooo002Aoooo00<0I_ooooooool0A?ooo`030000oooooooo04Goool0097oool00`1Vooooooooo`14
oooo00<0003oooooool0AOooo`00TOooo`0306Kooooooooo04Coool00`000?ooooooo`15oooo002A
oooo00<0I_ooooooool0A?ooo`030000oooooooo04Goool000_ooooo00001`0000ooool0017oool0
0`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007
<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0c
o`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000
<ol0<ol000Lco`000`0003?o03?o0004<ol000Co09Tco`0co`000008<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0003oooooool01oooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`0Coooo000A
oooo00<0000co`0co`00;c?o00030000<ol0<ol002lco`000`0003?o03?o000H<ol000?o09Tco`0c
o`004c?o00030000<ol0<ol002lco`000`000?ooooooo`0_oooo00<0003oooooool04oooo`004Ooo
oglco`000ol0VC?o03?o0015<ol000<0003oooooool0AOooo`004Ooooglco`000ol0VC?o03?o0015
<ol000<0003oooooool0AOooo`004Ooooglco`000ol0VC?o03?o0015<ol000<0003oooooool0AOoo
o`004Ooooglco`000ol0VC?o03?o0015<ol000<0003oooooool0AOooo`004Ooooglco`000ol0VC?o
03?o0015<ol000<0003oooooool0AOooo`004Ooooglco`000ol0VC?o03?o0015<ol00P0004Koool0
017ooomo<ol000?o09Tco`0co`00AC?o00030000oooooooo04Goool0017ooomo<ol000?o09Tco`0c
o`00AC?o00030000oooooooo04Goool0017ooomo<ol000?o09Tco`0co`00AC?o00030000oooooooo
04Goool0017ooomo<ol000?o09Tco`0co`00AC?o00030000oooooooo04Goool0017ooomo<ol000?o
09Tco`0co`00AC?o00030000oooooooo04Goool0017ooomo<ol000?o09Tco`0co`00AC?o00030000
oooooooo04Goool0017ooomo<ol000?o09Tco`0co`00AC?o00030000oooooooo04Goool0017oool2
0000OC?o0003o`2I<ol0<ol004Dco`020000A_ooo`004oooo`80001k<ol000?o09Tco`0co`00AC?o
00030000oooooooo04Goool001Goool20000NC?o0003o`2I<ol0<ol004Dco`000`000?ooooooo`15
oooo000Goooo0P0007Lco`000ol0VC?o03?o0015<ol000<0003oooooool0AOooo`006Oooo`80001e
<ol000?o09Tco`0co`00AC?o00030000oooooooo04Goool001_oool20000Lc?o0003o`2I<ol0<ol0
04Dco`000`000?ooooooo`15oooo000Moooo0P00074co`000ol0VC?o03?o0015<ol000<0003ooooo
ool0AOooo`007oooo`030000<ol0<ol006hco`000ol0VC?o03?o0015<ol000<0003oooooool0AOoo
o`008?ooo`030000<ol0<ol006dco`000ol0VC?o03?o0015<ol00P0004Koool0027oool20000KC?o
0003o`2I<ol0<ol004Dco`000`000?ooooooo`15oooo000Soooo00<0000co`0co`00JS?o0003o`2I
<ol0<ol004Dco`000`000?ooooooo`15oooo000Toooo0P0006Xco`000ol0VC?o03?o0015<ol000<0
003oooooool0AOooo`009_ooo`030000<ol0<ol006Lco`000ol0VC?o03?o0015<ol000<0003ooooo
ool0AOooo`009oooo`030000<ol0<ol006Hco`000ol0VC?o03?o0015<ol000<0003oooooool0AOoo
o`00:?ooo`030000<ol0<ol006Dco`000ol0VC?o03?o000/<ol00P0000@co`02000013?o00800003
<ol0100000@co`000`000?ooooooo`15oooo000Yoooo00<0000co`0co`00I3?o0003o`2I<ol0<ol0
02/co`00100003?o03?o000000Pco`00100003?o03?o0000008co`000`0003?o03?o0005<ol000<0
003oooooool0AOooo`00:_ooo`030000<ol0<ol006<co`000ol0VC?o03?o000[<ol000@0000co`0c
o`000008<ol000@0000co`0co`000003<ol000<0000co`0co`0013?o00<00015oooo000[oooo0P00
06<co`000ol0VC?o03?o000[<ol000@0000co`0co`000008<ol000@0000co`0co`000004<ol000<0
000co`0co`000c?o00030000oooooooo04Goool002goool00`0003?o03?o001P<ol000?o09Tco`0c
o`00:c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o
00030000oooooooo04Goool002koool00`0003?o03?o001O<ol000?o09Tco`0co`00;3?o0080000:
<ol00P0000@co`0200001C?o00030000oooooooo04Goool002ooool00`0003?o03?o001N<ol000?o
09Tco`0co`00AC?o00030000oooooooo04Goool0033oool00`0003?o03?o001M<ol000?o09Tco`0c
o`00AC?o00030000oooooooo04Goool0037oool00`0003?o03?o001L<ol000?o09Tco`0co`00AC?o
00030000oooooooo04Goool003;oool00`0003?o03?o001K<ol000?o09Tco`0co`00AC?o00030000
oooooooo04Goool003?oool00`0003?o03?o001J<ol000?o09Tco`0co`00AC?o00800016oooo000c
oooo00<0000co`0co`00FS?o0003o`2I<ol0<ol004Dco`000`000?ooooooo`15oooo000doooo00<0
000co`0co`00FC?o0003o`2I<ol0<ol004Dco`000`000?ooooooo`15oooo000eoooo00<0000co`0c
o`00F3?o0003o`2I<ol0<ol004Dco`000`000?ooooooo`15oooo000foooo00<0000co`0co`00Ec?o
0003o`2I<ol0<ol004Dco`000`000?ooooooo`15oooo000goooo00<0000co`0co`00ES?o0003o`2I
<ol0<ol004Dco`000`000?ooooooo`15oooo000hoooo00<0000co`0co`00EC?o0003o`2I<ol0<ol0
04Dco`000`000?ooooooo`15oooo000hoooo00<0000co`0co`00EC?o0003o`2I<ol0<ol004Dco`00
0`000?ooooooo`15oooo000ioooo00<0000co`0co`00E3?o0003o`2I<ol0<ol004Dco`020000A_oo
o`00>_ooo`030000<ol0<ol005<co`000ol0VC?o03?o0015<ol000<0003oooooool0AOooo`00>ooo
o`030000<ol0<ol0058co`000ol0VC?o03?o0015<ol000<0003oooooool0AOooo`00??ooo`030000
<ol0<ol0054co`000ol0VC?o03?o0015<ol000<0003oooooool0AOooo`00??ooo`030000<ol0<ol0
054co`000ol0VC?o03?o0015<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol0050co`00
0ol0VC?o03?o0015<ol000<0003oooooool0AOooo`00?Oooo`030000<ol0<ol0050co`000ol0VC?o
03?o0015<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol004lco`000ol0VC?o03?o0015
<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol004lco`000ol0VC?o03?o0015<ol000<0
003oooooool0AOooo`00?oooo`030000<ol0<ol004hco`000ol0VC?o03?o0015<ol00P0004Koool0
03ooool00`0003?o03?o001><ol000?o09Tco`0co`00AC?o00030000oooooooo04Goool0043oool0
0`0003?o03?o001=<ol000?o09Tco`0co`00AC?o00030000oooooooo04Goool0047oool00`0003?o
03?o001<<ol000?o09Tco`0co`00AC?o00030000oooooooo04Goool0047oool00`0003?o03?o001<
<ol000?o09Tco`0co`00AC?o00030000oooooooo04Goool004;oool00`0003?o03?o001;<ol000?o
09Tco`0co`00AC?o00030000oooooooo04Goool004;oool00`0003?o03?o001;<ol000?o09Tco`0c
o`00;3?o00800004<ol00P0000@co`0200001C?o00<00003<ol000<0003oooooool0AOooo`00@ooo
o`030000<ol0<ol004Xco`000ol0VC?o03?o000[<ol000@0000co`0co`000008<ol000@0000co`0c
o`000005<ol000<0000co`0co`000S?o00030000oooooooo04Goool004?oool00`0003?o03?o001:
<ol000?o09Tco`0co`00:c?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00D00003
<ol00`0004Goool004Coool00`0003?o03?o0019<ol000?o09Tco`0co`00:c?o00040000<ol0<ol0
000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool0
04Coool00`0003?o03?o0019<ol000?o09Tco`0co`00:c?o00040000<ol0<ol0000023?o00040000
<ol0<ol000000c?o00030000<ol0000000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0c
o`00B3?o0003o`2I<ol0<ol002`co`0200002S?o00800005<ol00P0000@co`000`000?ooooooo`15
oooo0015oooo00<0000co`0co`00B3?o0003o`2I<ol0<ol004Dco`000`000?ooooooo`15oooo0016
oooo00<0000co`0co`00Ac?o0003o`2I<ol0<ol004Dco`000`000?ooooooo`15oooo0016oooo00<0
000co`0co`00Ac?o0003o`2I<ol0<ol004Dco`000`000?ooooooo`15oooo0017oooo00<0000co`0c
o`00AS?o0003o`2I<ol0<ol004Dco`000`000?ooooooo`15oooo0017oooo00<0000co`0co`00AS?o
0003o`2I<ol0<ol004Dco`020000A_ooo`00B?ooo`030000<ol0<ol004Dco`000ol0VC?o03?o0015
<ol000<0003oooooool0AOooo`00B?ooo`030000<ol0<ol004Dco`000ol0VC?o03?o0015<ol000<0
003oooooool0AOooo`00BOooo`030000<ol0<ol004@co`000ol0VC?o03?o0015<ol000<0003ooooo
ool0AOooo`00BOooo`030000<ol0<ol004@co`000ol0VC?o03?o0015<ol000<0003oooooool0AOoo
o`00B_ooo`030000<ol0<ol004<co`000ol0VC?o03?o0015<ol000<0003oooooool0AOooo`00B_oo
o`030000<ol0<ol004<co`000ol0VC?o03?o0015<ol000<0003oooooool0AOooo`00Boooo`030000
<ol0<ol0048co`000ol0VC?o03?o0015<ol000<0003oooooool0AOooo`00Boooo`030000<ol0<ol0
048co`000ol0VC?o03?o0015<ol00P0004Koool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001<
ooooS3?o04Soool004gooon;<ol0B?ooo`00COoooh/co`18oooo001>oooo:S?o00030000<ol0<ol0
02Lco`000`0003?o03?o000c<ol0B?ooo`00C_ooobTco`000`0003?o03?o0008<ol000<0000co`0c
o`007S?o00030000<ol0<ol0038co`18oooo001?oooo:3?o00030000<ol0<ol0008co`02000013?o
00030000<ol0<ol000Hco`02000013?o00800003<ol0100000<co`02000013?o00030000<ol0<ol0
038co`18oooo001?oooo:3?o00050000<ol0<ol0<ol00000008co`000`0003?o03?o0002<ol000<0
000co`0co`0013?o00040000<ol0<ol0000023?o00030000<ol0<ol000<co`00100003?o03?o0000
00<co`000`0003?o03?o000b<ol0B?ooo`00CoooobLco`000`0003?o03?o0002<ol000<0000co`0c
o`0033?o00040000<ol0<ol000002C?o00030000<ol0<ol0008co`00100003?o03?o000000@co`00
0`0003?o03?o000a<ol0B?ooo`00D?ooobLco`000`0003?o03?o000500002c?o00040000<ol0<ol0
00002S?o00030000<ol0<ol0008co`02000013?o00030000<ol0<ol0038co`18oooo001@oooo9c?o
00050000<ol0<ol0<ol0000000hco`00100003?o03?o000000Pco`00100003?o03?o0000008co`00
100003?o03?o000000<co`000`0003?o03?o000b<ol0B?ooo`00D?ooobPco`000`0003?o03?o000@
<ol00P0000Xco`02000013?o00800003<ol000<0000co`0co`00<c?o04Soool0057ooon7<ol0B?oo
o`00DOooohLco`18oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.29) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.48147 .30902 L
.49955 .30902 L
.50431 .30902 L
.5095 .30902 L
.51188 .30902 L
.51318 .30902 L
.51441 .30902 L
s
.51441 .30902 m
.51441 .61803 L
s
0 .4 1 r
.02381 .27227 m
.06244 .2666 L
.10458 .2594 L
.14415 .25153 L
.18221 .24277 L
.22272 .23197 L
.26171 .21989 L
.30316 .20494 L
.34309 .1881 L
.3815 .16927 L
.42237 .14588 L
.46172 .11947 L
.48147 .10454 L
.49955 .08977 L
.50431 .0857 L
.5095 .08116 L
.51188 .07905 L
.51318 .07788 L
.51441 .07677 L
.51555 .30902 L
.5168 .30902 L
.51792 .30902 L
.51896 .30902 L
.52017 .30902 L
.52146 .30902 L
.52269 .30902 L
.5238 .30902 L
.52511 .30902 L
.52585 .30902 L
.52653 .30902 L
.52778 .30902 L
.52841 .30902 L
.52911 .30902 L
.52979 .30902 L
.5305 .30902 L
.53178 .30902 L
.53249 .30902 L
.53315 .30902 L
.53387 .30902 L
.53465 .30902 L
.53532 .30902 L
.53605 .30902 L
.53737 .30902 L
.53865 .30902 L
.53984 .30902 L
.54109 .30902 L
.54228 .30902 L
.54335 .30902 L
.54451 .30902 L
.54577 .30902 L
Mistroke
.54648 .30902 L
.54712 .30902 L
.54836 .30902 L
.54953 .30902 L
.55064 .30902 L
.55181 .30902 L
.5528 .30902 L
.55389 .30902 L
.55507 .30902 L
.55633 .30902 L
.55752 .30902 L
.5586 .30902 L
.55988 .30902 L
.56053 .30902 L
.56124 .30902 L
.5625 .30902 L
.56369 .30902 L
.56436 .30902 L
.56507 .30902 L
.56635 .30902 L
.56705 .30902 L
.56771 .30902 L
.56844 .30902 L
.56921 .30902 L
.57051 .30902 L
.57119 .30902 L
.57192 .30902 L
.57255 .30902 L
.57324 .30902 L
.57447 .30902 L
.57566 .30902 L
.57694 .30902 L
.57813 .30902 L
.57924 .30902 L
.58046 .30902 L
.5811 .30902 L
.5818 .30902 L
.58249 .30902 L
.58322 .30902 L
.58452 .30902 L
.58572 .30902 L
.58685 .30902 L
.58808 .30902 L
.5894 .30902 L
.59014 .30902 L
.59083 .30902 L
.59158 .30902 L
.59238 .30902 L
.59307 .30902 L
.59372 .30902 L
Mistroke
.59447 .30902 L
.59519 .30902 L
.59582 .30902 L
.59652 .30902 L
.59773 .30902 L
.59841 .30902 L
.59914 .30902 L
.60046 .30902 L
.60112 .30902 L
.60182 .30902 L
.60307 .30902 L
.60376 .30902 L
.60441 .30902 L
.60513 .30902 L
.60589 .30902 L
.60655 .30902 L
.60727 .30902 L
.60857 .30902 L
.60984 .30902 L
.61101 .30902 L
.61215 .30902 L
.61321 .30902 L
.61438 .30902 L
.61565 .30902 L
.6169 .30902 L
.61822 .30902 L
.61934 .30902 L
.62057 .30902 L
.62189 .30902 L
.62311 .30902 L
.62375 .30902 L
.62445 .30902 L
.62518 .30902 L
.62586 .30902 L
.62712 .30902 L
.62827 .30902 L
.62891 .30902 L
.6296 .30902 L
.63086 .30902 L
.63209 .30902 L
.6332 .30902 L
.63449 .30902 L
.6357 .30902 L
.63683 .30902 L
.63786 .30902 L
.639 .30902 L
.6402 .30902 L
.64151 .30902 L
.6427 .30902 L
.64336 .30902 L
Mistroke
.64407 .30902 L
.64537 .30902 L
.64659 .30902 L
.64788 .30902 L
.64898 .30902 L
.6502 .30902 L
.65093 .30902 L
.65162 .30902 L
.65292 .30902 L
.65365 .30902 L
.65432 .30902 L
.65506 .30902 L
.65585 .30902 L
.65654 .30902 L
.65728 .30902 L
.65798 .30902 L
.65863 .30902 L
.65986 .30902 L
.66115 .30902 L
.66228 .30902 L
.66348 .30902 L
.6648 .30902 L
.66602 .30902 L
.66714 .30902 L
.66821 .30902 L
.67062 .30902 L
.67187 .30902 L
.67318 .30902 L
.67387 .30902 L
.67462 .30902 L
.67594 .30902 L
.68078 .30902 L
.6853 .30902 L
.68653 .30902 L
.68769 .30902 L
.68889 .30902 L
.69021 .30902 L
.69244 .30902 L
.69484 .30902 L
.69598 .30902 L
.69707 .30902 L
.69814 .30902 L
.69911 .30902 L
.70035 .30902 L
.70166 .30902 L
.70288 .30902 L
.70402 .30902 L
.70468 .30902 L
.70536 .30902 L
.7066 .30902 L
Mistroke
.70938 .30902 L
.71871 .30902 L
.72391 .30902 L
.72515 .30902 L
.72647 .30902 L
.72759 .30902 L
.72883 .30902 L
.7295 .30902 L
.73023 .30902 L
.73154 .30902 L
.7323 .30902 L
.73309 .30902 L
.73376 .30902 L
.7345 .30902 L
.73579 .30902 L
.73652 .30902 L
.73717 .30902 L
.73845 .30902 L
.73966 .30902 L
.7408 .30902 L
.74205 .30902 L
.74335 .30902 L
.74458 .30902 L
.74572 .30902 L
.74676 .30902 L
.74796 .30902 L
.7491 .30902 L
.75033 .30902 L
.75164 .30902 L
.75276 .30902 L
.754 .30902 L
.75532 .30902 L
.75606 .30902 L
.75675 .30902 L
.758 .30902 L
.75864 .30902 L
.75933 .30902 L
.76056 .30902 L
.76173 .30902 L
.76278 .30902 L
.76392 .30902 L
.76516 .30902 L
.76647 .30902 L
.76759 .30902 L
.76883 .30902 L
.76997 .30902 L
.77103 .30902 L
.77224 .30902 L
.77339 .30902 L
.77445 .30902 L
Mistroke
.77544 .30902 L
.77652 .30902 L
.77767 .30902 L
.77891 .30902 L
.77962 .30902 L
.78028 .30902 L
.78097 .30902 L
.78161 .30902 L
.78234 .30902 L
.78303 .30902 L
.78426 .30902 L
.78539 .30902 L
.78603 .30902 L
.78672 .30902 L
.78796 .30902 L
.79053 .30902 L
.79336 .30902 L
.79909 .30902 L
.81926 .30902 L
.86041 .30902 L
.90004 .30902 L
.93816 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.29) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00__ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`D00003oooo0`0004Goool00;Soool400000_oo
o`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00001?ooo`030000
oooooooo04Goool00;koool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
o`000004oooo00<0003oooooool0AOooo`00_oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool0097oool00`1Vooooooooo`14oooo00<0003oooooool0AOooo`00T?ooo`80I_m6
oooo00<0003oooooool0AOooo`00Soooo`0306Kooooo06Ko04Koool00`000?ooooooo`15oooo002=
oooo0P1Vo`;oool00`1Vooooooooo`14oooo00<0003oooooool0AOooo`00S?ooo`0306Kooooooooo
00;oool00`1Vooooooooo`14oooo0P0004Koool008_oool00`1Vooooooooo`03oooo00<0I_oooooo
ool0A?ooo`030000oooooooo04Goool008[oool00`1Vooooooooo`04oooo00<0I_ooooooool0A?oo
o`030000oooooooo04Goool008Woool00`1Vooooooooo`05oooo00<0I_ooooooool0A?ooo`030000
oooooooo04Goool008Soool00`1Vooooooooo`06oooo00<0I_ooooooool0A?ooo`030000oooooooo
04Goool008Koool206Ko2Oooo`0306Kooooooooo04Coool00`000?ooooooo`15oooo0025oooo00<0
I_ooooooool02Oooo`0306Kooooooooo04Coool00`000?ooooooo`15oooo0024oooo00<0I_oooooo
ool02_ooo`0306Kooooooooo04Coool00`000?ooooooo`15oooo0022oooo0P1Vo`goool00`1Voooo
ooooo`14oooo0P0004Koool0087oool00`1Vooooooooo`0=oooo00<0I_ooooooool0A?ooo`030000
oooooooo04Goool007ooool206Ko4?ooo`0306Kooooooooo04Coool00`000?ooooooo`15oooo001m
oooo0P1Voa;oool00`1Vooooooooo`14oooo00<0003oooooool0AOooo`00O?ooo`0306Kooooooooo
01;oool00`1Vooooooooo`14oooo00<0003oooooool0AOooo`00N_ooo`80I_lEoooo00<0I_oooooo
ool0A?ooo`030000oooooooo04Goool007Woool00`1Vooooooooo`0Eoooo00<0I_ooooooool0A?oo
o`030000oooooooo04Goool007Ooool206Ko6?ooo`0306Kooooooooo04Coool00`000?ooooooo`15
oooo001eoooo0P1Voa[oool00`1Vooooooooo`14oooo0P0004Koool007Coool00`1Vooooooooo`0J
oooo00<0I_ooooooool0A?ooo`030000oooooooo04Goool007;oool206Ko7Oooo`0306Kooooooooo
04Coool00`000?ooooooo`15oooo001`oooo0P1Voaooool00`1Vooooooooo`14oooo00<0003ooooo
ool0AOooo`00Koooo`0306Kooooooooo01ooool00`1Vooooooooo`14oooo00<0003oooooool0AOoo
o`00KOooo`80I_lRoooo00<0I_ooooooool0A?ooo`030000oooooooo04Goool006_oool206Ko9?oo
o`0306Kooooooooo02_oool200001?ooo`800004oooo0P0000?oool400001?ooo`030000oooooooo
04Goool006Woool206Ko9_ooo`0306Kooooooooo02[oool010000?ooooooo`0000Soool010000?oo
ooooo`0000;oool00`000?ooooooo`05oooo00<0003oooooool0AOooo`00Ioooo`80I_lXoooo00<0
I_ooooooool0:_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
00Coool30000AOooo`00I?ooo`<0I_lZoooo00<0I_ooooooool09?ooo`@00002oooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool00oooo`030000oooooooo04Goool0
067oool306Ko;Oooo`0306Kooooooooo02[oool010000?ooooooo`0000Soool010000?ooooooo`00
00;oool010000?ooooooo`0000Coool00`000?ooooooo`15oooo001Ooooo0P1Voc7oool00`1Voooo
ooooo`0Zoooo0P0000[oool200001?ooo`800005oooo00<0003oooooool0AOooo`00G?ooo`<0I_lc
oooo00<0I_ooooooool0@oooo`030000oooooooo04Goool005Woool306Ko=_ooo`0306Kooooooooo
04?oool00`000?ooooooo`15oooo001Foooo0`1VocWoool00`1Vooooooooo`13oooo00<0003ooooo
ool0AOooo`00E?ooo`80I_lloooo00<0I_ooooooool0@oooo`030000oooooooo04Goool0057oool3
06Ko?_ooo`0306Kooooooooo04?oool20000A_ooo`00C_ooo`<0I_m1oooo00<0I_ooooooool0@ooo
o`030000oooooooo04Goool004_oool306KoA?ooo`0306Kooooooooo04?oool00`000?ooooooo`15
oooo0017oooo101VodOoool00`1Vooooooooo`13oooo00<0003oooooool0AOooo`00A?ooo`<0I_m;
oooo00<0I_ooooooool0@oooo`030000oooooooo04Goool0047oool306KoC_ooo`0306Kooooooooo
04?oool00`000?ooooooo`15oooo000moooo101Voe7oool00`1Vooooooooo`13oooo00<0003ooooo
ool0AOooo`00>Oooo`@0I_mEoooo00<0I_ooooooool0@oooo`030000oooooooo04Goool003Coool5
06KoFOooo`0306Kooooooooo04?oool20000A_ooo`00;oooo`D0I_mNoooo00<0I_ooooooool0@ooo
o`030000oooooooo04Goool002Woool606KoHoooo`0306Kooooooooo04?oool00`000?ooooooo`15
oooo000Toooo1@1VofWoool00`1Vooooooooo`13oooo00<0003oooooool0AOooo`007oooo`D0I_m^
oooo00<0I_ooooooool0@oooo`030000oooooooo04Goool001;oool400001?ooo`D0I_lOoooo1@00
00;oool200001?ooo`80000Yoooo1@0001Ooool00`1Vooooooooo`0=oooo0P0000Coool200001?oo
o`80000Xoooo00<0003oooooool0:?ooo`800004oooo0P0000Coool200003oooo`004_ooo`030000
oooo06Ko00D0I_lVoooo00<0003oooooool01oooo`040000oooooooo0000:_ooo`030000oooooooo
01Ooool00`1Vooooooooo`0<oooo00@0003oooooool00008oooo00@0003oooooool0000Woooo00<0
003oooooool09oooo`040000oooooooo00002?ooo`040000oooooooo00003_ooo`004Oooo`80I_l0
0`000?ooooooo`0Zoooo00<0003oooooool02_ooo`030000oooooooo02Soool00`000?ooooooo`0G
oooo00<0I_ooooooool03?ooo`040000oooooooo00002oooo`030000oooooooo02Goool00`000?oo
ooooo`0Woooo00@0003oooooool0000;oooo00<0003oooooool03?ooo`003?ooo`@00004oooo00<0
003oooooool08Oooo`@00004oooo00<0003oooooool02?ooo`80000Soooo100000Coool00`000?oo
ooooo`0Goooo00<0I_ooooooool01_ooo`@00002oooo00@0003oooooool00009oooo0P0002Soool2
0000:?ooo`040000oooooooo00002Oooo`80000?oooo000Boooo00@0003oooooool0000Zoooo00<0
003oooooool02?ooo`030000oooooooo02[oool00`000?ooooooo`0Goooo00<0I_ooooooool03?oo
o`040000oooooooo00002Oooo`030000oooooooo02Ooool00`000?ooooooo`0Woooo00@0003ooooo
ool00009oooo00<0003oooooool03_ooo`004oooo`80000Zoooo0P0000[oool30000:Oooo`80000I
oooo00<0I_ooooooool03Oooo`80000:oooo0`0002Ooool00`000?ooooooo`0Xoooo0P0000[oool3
00003_ooo`00T_ooo`0306Kooooooooo04?oool00`000?ooooooo`15oooo002Boooo00<0I_oooooo
ool0@oooo`030000oooooooo04Goool009;oool00`1Vooooooooo`13oooo00<0003oooooool0AOoo
o`00T_ooo`0306Kooooooooo04?oool00`000?ooooooo`15oooo002Boooo00<0I_ooooooool0@ooo
o`030000oooooooo04Goool000_ooooo00001`0000ooool0017oool00`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0005<ol000?o09Tco`00000023?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00<0003oooooool04oooo`004Oooo`030000<ol0<ol002lco`00
0`0003?o03?o000_<ol000<0000co`0co`006C?o0003o`2I<ol0<ol0018co`000`0003?o03?o000_
<ol000<0003oooooool0;oooo`030000oooooooo01?oool0017ooon0<ol000?o09Tco`0co`00A3?o
00030000oooooooo04Goool0017ooon0<ol000?o09Tco`0co`00A3?o00030000oooooooo04Goool0
017ooon0<ol000?o09Tco`0co`00A3?o00030000oooooooo04Goool0017ooon0<ol000?o09Tco`0c
o`00A3?o00030000oooooooo04Goool0017ooon0<ol000?o09Tco`0co`00A3?o00030000oooooooo
04Goool0017ooon0<ol000?o09Tco`0co`00A3?o00800016oooo000AooooP3?o0003o`2I<ol0<ol0
04@co`000`000?ooooooo`15oooo000AooooP3?o0003o`2I<ol0<ol004@co`000`000?ooooooo`15
oooo000AooooP3?o0003o`2I<ol0<ol004@co`000`000?ooooooo`15oooo000AooooP3?o0003o`2I
<ol0<ol004@co`000`000?ooooooo`15oooo000AooooP3?o0003o`2I<ol0<ol004@co`000`000?oo
ooooo`15oooo000AooooP3?o0003o`2I<ol0<ol004@co`000`000?ooooooo`15oooo000AooooP3?o
0003o`2I<ol0<ol004@co`000`000?ooooooo`15oooo000Aoooo0P0007hco`000ol0VC?o03?o0014
<ol00P0004Koool001?oool20000O3?o0003o`2I<ol0<ol004@co`000`000?ooooooo`15oooo000E
oooo0P0007Xco`000ol0VC?o03?o0014<ol000<0003oooooool0AOooo`005oooo`80001h<ol000?o
09Tco`0co`00A3?o00030000oooooooo04Goool001Woool20000MS?o0003o`2I<ol0<ol004@co`00
0`000?ooooooo`15oooo000Koooo0P0007@co`000ol0VC?o03?o0014<ol000<0003oooooool0AOoo
o`007Oooo`80001b<ol000?o09Tco`0co`00A3?o00030000oooooooo04Goool001ooool00`0003?o
03?o001_<ol000?o09Tco`0co`00A3?o00030000oooooooo04Goool0023oool00`0003?o03?o001^
<ol000?o09Tco`0co`00A3?o00800016oooo000Qoooo0P0006hco`000ol0VC?o03?o0014<ol000<0
003oooooool0AOooo`008oooo`030000<ol0<ol006/co`000ol0VC?o03?o0014<ol000<0003ooooo
ool0AOooo`009?ooo`80001[<ol000?o09Tco`0co`00A3?o00030000oooooooo04Goool002Koool0
0`0003?o03?o001X<ol000?o09Tco`0co`00A3?o00030000oooooooo04Goool002Ooool00`0003?o
03?o001W<ol000?o09Tco`0co`00A3?o00030000oooooooo04Goool002Soool00`0003?o03?o001V
<ol000?o09Tco`0co`00:c?o00800004<ol00P0000@co`0200000c?o00@00004<ol000<0003ooooo
ool0AOooo`00:Oooo`030000<ol0<ol006Dco`000ol0VC?o03?o000Z<ol000@0000co`0co`000008
<ol000@0000co`0co`000002<ol000<0000co`0co`001C?o00030000oooooooo04Goool002[oool0
0`0003?o03?o001T<ol000?o09Tco`0co`00:S?o00040000<ol0<ol0000023?o00040000<ol0<ol0
00000c?o00030000<ol0<ol000@co`030000AOooo`00:oooo`80001T<ol000?o09Tco`0co`00:S?o
00040000<ol0<ol0000023?o00040000<ol0<ol0000013?o00030000<ol0<ol000<co`000`000?oo
ooooo`15oooo000]oooo00<0000co`0co`00HC?o0003o`2I<ol0<ol002Xco`00100003?o03?o0000
00Pco`00100003?o03?o0000008co`00100003?o03?o000000@co`000`000?ooooooo`15oooo000^
oooo00<0000co`0co`00H3?o0003o`2I<ol0<ol002/co`0200002S?o00800004<ol00P0000Dco`00
0`000?ooooooo`15oooo000_oooo00<0000co`0co`00Gc?o0003o`2I<ol0<ol004@co`000`000?oo
ooooo`15oooo000`oooo00<0000co`0co`00GS?o0003o`2I<ol0<ol004@co`000`000?ooooooo`15
oooo000aoooo00<0000co`0co`00GC?o0003o`2I<ol0<ol004@co`000`000?ooooooo`15oooo000b
oooo00<0000co`0co`00G3?o0003o`2I<ol0<ol004@co`000`000?ooooooo`15oooo000coooo00<0
000co`0co`00Fc?o0003o`2I<ol0<ol004@co`020000A_ooo`00<oooo`030000<ol0<ol005/co`00
0ol0VC?o03?o0014<ol000<0003oooooool0AOooo`00=?ooo`030000<ol0<ol005Xco`000ol0VC?o
03?o0014<ol000<0003oooooool0AOooo`00=Oooo`030000<ol0<ol005Tco`000ol0VC?o03?o0014
<ol000<0003oooooool0AOooo`00=_ooo`030000<ol0<ol005Pco`000ol0VC?o03?o0014<ol000<0
003oooooool0AOooo`00=oooo`030000<ol0<ol005Lco`000ol0VC?o03?o0014<ol000<0003ooooo
ool0AOooo`00>?ooo`030000<ol0<ol005Hco`000ol0VC?o03?o0014<ol000<0003oooooool0AOoo
o`00>?ooo`030000<ol0<ol005Hco`000ol0VC?o03?o0014<ol000<0003oooooool0AOooo`00>Ooo
o`030000<ol0<ol005Dco`000ol0VC?o03?o0014<ol00P0004Koool003[oool00`0003?o03?o001D
<ol000?o09Tco`0co`00A3?o00030000oooooooo04Goool003_oool00`0003?o03?o001C<ol000?o
09Tco`0co`00A3?o00030000oooooooo04Goool003coool00`0003?o03?o001B<ol000?o09Tco`0c
o`00A3?o00030000oooooooo04Goool003coool00`0003?o03?o001B<ol000?o09Tco`0co`00A3?o
00030000oooooooo04Goool003goool00`0003?o03?o001A<ol000?o09Tco`0co`00A3?o00030000
oooooooo04Goool003goool00`0003?o03?o001A<ol000?o09Tco`0co`00A3?o00030000oooooooo
04Goool003koool00`0003?o03?o001@<ol000?o09Tco`0co`00A3?o00030000oooooooo04Goool0
03koool00`0003?o03?o001@<ol000?o09Tco`0co`00A3?o00030000oooooooo04Goool003ooool0
0`0003?o03?o001?<ol000?o09Tco`0co`00A3?o00800016oooo000ooooo00<0000co`0co`00Cc?o
0003o`2I<ol0<ol004@co`000`000?ooooooo`15oooo0010oooo00<0000co`0co`00CS?o0003o`2I
<ol0<ol004@co`000`000?ooooooo`15oooo0011oooo00<0000co`0co`00CC?o0003o`2I<ol0<ol0
04@co`000`000?ooooooo`15oooo0011oooo00<0000co`0co`00CC?o0003o`2I<ol0<ol004@co`00
0`000?ooooooo`15oooo0012oooo00<0000co`0co`00C3?o0003o`2I<ol0<ol004@co`000`000?oo
ooooo`15oooo0012oooo00<0000co`0co`00C3?o0003o`2I<ol0<ol002/co`02000013?o00800004
<ol00P0000Dco`0300000c?o00030000oooooooo04Goool004?oool00`0003?o03?o001;<ol000?o
09Tco`0co`00:S?o00040000<ol0<ol0000023?o00040000<ol0<ol000001C?o00030000<ol0<ol0
008co`000`000?ooooooo`15oooo0013oooo00<0000co`0co`00Bc?o0003o`2I<ol0<ol002Xco`00
100003?o03?o000000Pco`00100003?o03?o0000008co`0500000c?o00<00015oooo0014oooo00<0
000co`0co`00BS?o0003o`2I<ol0<ol002Xco`00100003?o03?o000000Pco`00100003?o03?o0000
008co`00100003?o03?o000000@co`000`000?ooooooo`15oooo0014oooo00<0000co`0co`00BS?o
0003o`2I<ol0<ol002Xco`00100003?o03?o000000Pco`00100003?o03?o000000<co`000`0003?o
00000004<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol004Tco`000ol0VC?o03?o000[
<ol00P0000Xco`0200001C?o00800004<ol000<0003oooooool0AOooo`00AOooo`030000<ol0<ol0
04Tco`000ol0VC?o03?o0014<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol004Pco`00
0ol0VC?o03?o0014<ol000<0003oooooool0AOooo`00A_ooo`030000<ol0<ol004Pco`000ol0VC?o
03?o0014<ol000<0003oooooool0AOooo`00Aoooo`030000<ol0<ol004Lco`000ol0VC?o03?o0014
<ol000<0003oooooool0AOooo`00Aoooo`030000<ol0<ol004Lco`000ol0VC?o03?o0014<ol00P00
04Koool004Soool00`0003?o03?o0016<ol000?o09Tco`0co`00A3?o00030000oooooooo04Goool0
04Soool00`0003?o03?o0016<ol000?o09Tco`0co`00A3?o00030000oooooooo04Goool004Woool0
0`0003?o03?o0015<ol000?o09Tco`0co`00A3?o00030000oooooooo04Goool004Woool00`0003?o
03?o0015<ol000?o09Tco`0co`00A3?o00030000oooooooo04Goool004[oool00`0003?o03?o0014
<ol000?o09Tco`0co`00A3?o00030000oooooooo04Goool004[oool00`0003?o03?o0014<ol000?o
09Tco`0co`00A3?o00030000oooooooo04Goool004_oool00`0003?o03?o0013<ol000?o09Tco`0c
o`00A3?o00030000oooooooo04Goool004_oool00`0003?o03?o0013<ol000?o09Tco`0co`00A3?o
00800016oooo001<ooooS3?o04Soool004cooon<<ol0B?ooo`00C?oooh`co`18oooo001=ooooRc?o
04Soool004gooon;<ol0B?ooo`00C_ooobXco`000`0003?o03?o000W<ol000<0000co`0co`00<c?o
04Soool004kooolY<ol000<0000co`0co`0023?o00030000<ol0<ol001hco`000`0003?o03?o000b
<ol0B?ooo`00CoooobPco`000`0003?o03?o0002<ol00P0000@co`000`0003?o03?o0006<ol00P00
00@co`0200000c?o00@00002<ol00`0000@co`000`0003?o03?o000b<ol0B?ooo`00CoooobPco`00
1@0003?o03?o03?o00000002<ol000<0000co`0co`000S?o00030000<ol0<ol000@co`00100003?o
03?o000000Pco`000`0003?o03?o0005<ol000<0000co`0co`000S?o00030000<ol0<ol0038co`18
oooo001?oooo9c?o00030000<ol0<ol0008co`000`0003?o03?o000<<ol000@0000co`0co`000009
<ol000<0000co`0co`000c?o00<00004<ol000<0000co`0co`00<C?o04Soool0053ooolW<ol000<0
000co`0co`001@0000/co`00100003?o03?o000000Xco`001@0003?o03?o03?o00000002<ol000D0
000co`0co`0co`000000=3?o04Soool0053ooolW<ol000D0000co`0co`0co`0000003S?o00040000
<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol000000c?o00030000<ol0<ol0
038co`18oooo001@oooo:3?o00030000<ol0<ol0010co`0200002S?o00800004<ol00`00008co`00
0`0003?o03?o000c<ol0B?ooo`00DOooohLco`18oooo001AooooQc?o04Soool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
.2 1 0 r
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
.26171 .65815 L
.30316 .78516 L
.34309 .95159 L
.3815 1.16733 L
.42237 1.47871 L
.46172 1.88811 L
.49955 2.42176 L
.53984 3.20046 L
.57861 4.23918 L
.59832 4.91392 L
.61984 5.7959 L
.65954 7.95102 L
.67922 9.35688 L
.70019 11.1885 L
.72016 13.3412 L
.74177 16.2565 L
.76264 19.8432 L
.77257 21.8921 L
.77742 22.9887 L
.78184 24.0493 L
.78407 24.6088 L
.78534 24.9323 L
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .36836 m
.06244 .38811 L
.10458 .41722 L
.14415 .45428 L
.18221 .50189 L
.22272 .56993 L
s
.22272 .56993 m
.24398 .61803 L
s
.78649 .61803 m
.7865 .30902 L
.78752 .30902 L
.78865 .30902 L
.79092 .30902 L
.80066 .30902 L
.82133 .30902 L
.86153 .30902 L
.90022 .30902 L
.94136 .30902 L
.97619 .30902 L
s
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.5095 .30902 L
.51441 .30902 L
.5168 .30902 L
.51784 .30902 L
.51896 .30902 L
s
.51896 .30902 m
.51897 .61803 L
s
0 .4 1 r
.02381 .27093 m
.06244 .26505 L
.10458 .25759 L
.14415 .24943 L
.18221 .24036 L
.22272 .22916 L
.26171 .21664 L
.30316 .20114 L
.34309 .18369 L
.3815 .16417 L
.42237 .13993 L
.46172 .11255 L
.49955 .08177 L
.5095 .07284 L
.51441 .0683 L
.5168 .06605 L
.51784 .06507 L
.51896 .064 L
.52026 .30902 L
.52148 .30902 L
.52217 .30902 L
.52288 .30902 L
.52417 .30902 L
.52485 .30902 L
.52558 .30902 L
.52689 .30902 L
.52769 .30902 L
.52844 .30902 L
.52912 .30902 L
.52986 .30902 L
.53106 .30902 L
.53238 .30902 L
.53304 .30902 L
.53375 .30902 L
.53505 .30902 L
.53984 .30902 L
.54934 .30902 L
.55056 .30902 L
.55184 .30902 L
.55252 .30902 L
.55326 .30902 L
.55456 .30902 L
.55578 .30902 L
.55693 .30902 L
.55757 .30902 L
.55827 .30902 L
.55949 .30902 L
.56024 .30902 L
.56105 .30902 L
.56181 .30902 L
Mistroke
.5625 .30902 L
.56316 .30902 L
.56386 .30902 L
.56462 .30902 L
.56532 .30902 L
.56662 .30902 L
.56736 .30902 L
.56805 .30902 L
.56929 .30902 L
.56999 .30902 L
.57062 .30902 L
.57126 .30902 L
.57195 .30902 L
.57317 .30902 L
.57449 .30902 L
.57524 .30902 L
.57594 .30902 L
.57721 .30902 L
.57837 .30902 L
.57964 .30902 L
.58028 .30902 L
.58098 .30902 L
.58227 .30902 L
.58299 .30902 L
.58366 .30902 L
.58487 .30902 L
.58555 .30902 L
.58619 .30902 L
.5873 .30902 L
.58849 .30902 L
.58976 .30902 L
.59092 .30902 L
.59157 .30902 L
.59227 .30902 L
.59352 .30902 L
.59422 .30902 L
.59487 .30902 L
.59559 .30902 L
.59636 .30902 L
.59767 .30902 L
.59833 .30902 L
.59905 .30902 L
.60033 .30902 L
.60152 .30902 L
.60271 .30902 L
.604 .30902 L
.60522 .30902 L
.60635 .30902 L
.60736 .30902 L
.60848 .30902 L
Mistroke
.60965 .30902 L
.61074 .30902 L
.61201 .30902 L
.61322 .30902 L
.61431 .30902 L
.61549 .30902 L
.61678 .30902 L
.61749 .30902 L
.61814 .30902 L
.61941 .30902 L
.6206 .30902 L
.62176 .30902 L
.62285 .30902 L
.62411 .30902 L
.62526 .30902 L
.62653 .30902 L
.62725 .30902 L
.62791 .30902 L
.62911 .30902 L
.63038 .30902 L
.6316 .30902 L
.63291 .30902 L
.63404 .30902 L
.63528 .30902 L
.636 .30902 L
.63666 .30902 L
.63736 .30902 L
.63811 .30902 L
.63881 .30902 L
.63946 .30902 L
.6407 .30902 L
.64176 .30902 L
.64294 .30902 L
.64417 .30902 L
.64531 .30902 L
.64638 .30902 L
.64736 .30902 L
.64849 .30902 L
.64957 .30902 L
.65072 .30902 L
.65195 .30902 L
.65311 .30902 L
.65416 .30902 L
.65541 .30902 L
.6561 .30902 L
.65675 .30902 L
.65793 .30902 L
.65917 .30902 L
.6604 .30902 L
.66109 .30902 L
Mistroke
.66173 .30902 L
.66291 .30902 L
.66415 .30902 L
.66527 .30902 L
.66631 .30902 L
.66746 .30902 L
.66869 .30902 L
.66999 .30902 L
.67073 .30902 L
.67141 .30902 L
.67267 .30902 L
.67337 .30902 L
.674 .30902 L
.6752 .30902 L
.67651 .30902 L
.67774 .30902 L
.67887 .30902 L
.67993 .30902 L
.68107 .30902 L
.68312 .30902 L
.68779 .30902 L
.689 .30902 L
.69032 .30902 L
.69157 .30902 L
.69272 .30902 L
.69376 .30902 L
.6949 .30902 L
.6961 .30902 L
.69722 .30902 L
.73589 .30902 L
.73703 .30902 L
.73824 .30902 L
.73956 .30902 L
.74078 .30902 L
.74191 .30902 L
.74297 .30902 L
.74414 .30902 L
.74539 .30902 L
.74607 .30902 L
.74681 .30902 L
.74751 .30902 L
.74816 .30902 L
.74939 .30902 L
.7507 .30902 L
.75201 .30902 L
.75324 .30902 L
.75434 .30902 L
.75553 .30902 L
.75624 .30902 L
.75699 .30902 L
Mistroke
.7577 .30902 L
.75835 .30902 L
.75908 .30902 L
.75977 .30902 L
.76052 .30902 L
.76133 .30902 L
.76197 .30902 L
.76268 .30902 L
.76341 .30902 L
.7641 .30902 L
.76533 .30902 L
.76603 .30902 L
.76666 .30902 L
.76791 .30902 L
.76907 .30902 L
.77035 .30902 L
.77106 .30902 L
.77171 .30902 L
.77302 .30902 L
.77376 .30902 L
.77444 .30902 L
.77513 .30902 L
.77579 .30902 L
.77702 .30902 L
.77812 .30902 L
.77931 .30902 L
.78058 .30902 L
.78176 .30902 L
.78278 .30902 L
.78391 .30902 L
.78509 .30902 L
.78619 .30902 L
.78742 .30902 L
.78872 .30902 L
.79104 .30902 L
.79627 .30902 L
.81663 .30902 L
.8547 .30902 L
.89521 .30902 L
.93421 .30902 L
.97567 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.785714 0.380952 0.309017 6.18034 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -12 -9 ]
[.21429 .29652 12 0 ]
[.40476 .29652 -6 -9 ]
[.40476 .29652 6 0 ]
[.59524 .29652 -12 -9 ]
[.59524 .29652 12 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.77321 .0618 -30 -4.5 ]
[.77321 .0618 0 4.5 ]
[.77321 .18541 -30 -4.5 ]
[.77321 .18541 0 4.5 ]
[.77321 .43262 -24 -4.5 ]
[.77321 .43262 0 4.5 ]
[.77321 .55623 -24 -4.5 ]
[.77321 .55623 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1.5)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(-1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(-0.5)] .59524 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.5)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.78571 .0618 m
.79196 .0618 L
s
[(-0.04)] .77321 .0618 1 0 Mshowa
.78571 .18541 m
.79196 .18541 L
s
[(-0.02)] .77321 .18541 1 0 Mshowa
.78571 .43262 m
.79196 .43262 L
s
[(0.02)] .77321 .43262 1 0 Mshowa
.78571 .55623 m
.79196 .55623 L
s
[(0.04)] .77321 .55623 1 0 Mshowa
.125 Mabswid
.78571 .09271 m
.78946 .09271 L
s
.78571 .12361 m
.78946 .12361 L
s
.78571 .15451 m
.78946 .15451 L
s
.78571 .21631 m
.78946 .21631 L
s
.78571 .24721 m
.78946 .24721 L
s
.78571 .27812 m
.78946 .27812 L
s
.78571 .33992 m
.78946 .33992 L
s
.78571 .37082 m
.78946 .37082 L
s
.78571 .40172 m
.78946 .40172 L
s
.78571 .46353 m
.78946 .46353 L
s
.78571 .49443 m
.78946 .49443 L
s
.78571 .52533 m
.78946 .52533 L
s
.78571 .0309 m
.78946 .0309 L
s
.78571 0 m
.78946 0 L
s
.78571 .58713 m
.78946 .58713 L
s
.78571 .61803 m
.78946 .61803 L
s
.25 Mabswid
.78571 0 m
.78571 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{44, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003of?ooo`800016
oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?oo
ooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool0
0`000?ooooooo`15oooo003Hoooo00<0003oooooool0AOooo`00f?ooo`800016oooo003Hoooo00<0
003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00=Soool00`000?ooooooo`15oooo003H
oooo00<0003oooooool0AOooo`00f?ooo`030000oooooooo04Goool00;ooool200001?ooo`800004
oooo0P0000Goool300000oooo`030000oooooooo04Goool00;koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0AOooo`00Toooo`0306Ko
oooooooo02Soool010000?ooooooo`0000Soool010000?ooooooo`0000;oool500000oooo`<00015
oooo002Aoooo0`1VobCoool400000_ooo`040000oooooooo00002?ooo`040000oooooooo00000_oo
o`040000oooooooo00001?ooo`030000oooooooo04Goool0093oool0101Vooooooooo`1Vob[oool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooo`000004oooo00<0003ooooo
ool0AOooo`00T?ooo`0406Kooooooooo06Ko:oooo`80000:oooo0P0000Goool200001?ooo`030000
oooooooo04Goool008koool206Ko0oooo`0306Kooooooooo04;oool00`000?ooooooo`15oooo002=
oooo00<0I_ooooooool00oooo`0306Kooooooooo04;oool00`000?ooooooo`15oooo002<oooo00<0
I_ooooooool01?ooo`0306Kooooooooo04;oool00`000?ooooooo`15oooo002;oooo00<0I_oooooo
ool01Oooo`0306Kooooooooo04;oool00`000?ooooooo`15oooo002:oooo00<0I_ooooooool01_oo
o`0306Kooooooooo04;oool20000A_ooo`00R?ooo`80I_l9oooo00<0I_ooooooool0@_ooo`030000
oooooooo04Goool008Ooool00`1Vooooooooo`09oooo00<0I_ooooooool0@_ooo`030000oooooooo
04Goool008Koool00`1Vooooooooo`0:oooo00<0I_ooooooool0@_ooo`030000oooooooo04Goool0
08Goool00`1Vooooooooo`0;oooo00<0I_ooooooool0@_ooo`030000oooooooo04Goool008Coool0
0`1Vooooooooo`0<oooo00<0I_ooooooool0@_ooo`030000oooooooo04Goool008;oool206Ko3ooo
o`0306Kooooooooo04;oool00`000?ooooooo`15oooo0021oooo00<0I_ooooooool03oooo`0306Ko
oooooooo04;oool00`000?ooooooo`15oooo001ooooo0P1Voa;oool00`1Vooooooooo`12oooo0P00
04Koool007goool206Ko5?ooo`0306Kooooooooo04;oool00`000?ooooooo`15oooo001loooo00<0
I_ooooooool05?ooo`0306Kooooooooo04;oool00`000?ooooooo`15oooo001joooo0P1VoaOoool0
0`1Vooooooooo`12oooo00<0003oooooool0AOooo`00NOooo`0306Kooooooooo01Ooool00`1Voooo
ooooo`12oooo00<0003oooooool0AOooo`00Moooo`80I_lJoooo00<0I_ooooooool0@_ooo`030000
oooooooo04Goool007Goool206Ko7?ooo`0306Kooooooooo04;oool00`000?ooooooo`15oooo001d
oooo00<0I_ooooooool07?ooo`0306Kooooooooo04;oool00`000?ooooooo`15oooo001boooo0P1V
oaooool00`1Vooooooooo`12oooo0P0004Koool0073oool206Ko8Oooo`0306Kooooooooo04;oool0
0`000?ooooooo`15oooo001_oooo00<0I_ooooooool08Oooo`0306Kooooooooo04;oool00`000?oo
ooooo`15oooo001]oooo0P1VobCoool00`1Vooooooooo`12oooo00<0003oooooool0AOooo`00Jooo
o`80I_lVoooo00<0I_ooooooool0@_ooo`030000oooooooo04Goool006Woool206Ko:?ooo`0306Ko
oooooooo04;oool00`000?ooooooo`15oooo001Woooo0P1Vob[oool00`1Vooooooooo`0Yoooo0P00
00Coool200001?ooo`800003oooo100000Coool00`000?ooooooo`15oooo001Toooo0`1Vobcoool0
0`1Vooooooooo`0Xoooo00@0003oooooool00008oooo00@0003oooooool00002oooo00<0003ooooo
ool01Oooo`030000oooooooo04Goool006;oool206Ko;oooo`0306Kooooooooo02Soool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`04oooo0`0004Goool0063oool2
06Ko<Oooo`0306Kooooooooo02;oool400000_ooo`040000oooooooo00002?ooo`040000oooooooo
00001?ooo`030000oooooooo00?oool00`000?ooooooo`15oooo001Noooo0P1Voc?oool00`1Voooo
ooooo`0Xoooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00004
oooo00<0003oooooool0AOooo`00G?ooo`80I_leoooo00<0I_ooooooool0:Oooo`80000:oooo0P00
00Coool200001Oooo`030000oooooooo04Goool005Woool306Ko=oooo`0306Kooooooooo04;oool0
0`000?ooooooo`15oooo001Foooo0`1Voc[oool00`1Vooooooooo`12oooo00<0003oooooool0AOoo
o`00E?ooo`80I_lmoooo00<0I_ooooooool0@_ooo`030000oooooooo04Goool0057oool306Ko?ooo
o`0306Kooooooooo04;oool00`000?ooooooo`15oooo001>oooo0`1Vod;oool00`1Vooooooooo`12
oooo0P0004Koool004_oool306KoAOooo`0306Kooooooooo04;oool00`000?ooooooo`15oooo0017
oooo101VodSoool00`1Vooooooooo`12oooo00<0003oooooool0AOooo`00A?ooo`<0I_m<oooo00<0
I_ooooooool0@_ooo`030000oooooooo04Goool0047oool306KoCoooo`0306Kooooooooo04;oool0
0`000?ooooooo`15oooo000moooo101Voe;oool00`1Vooooooooo`12oooo00<0003oooooool0AOoo
o`00>_ooo`<0I_mFoooo00<0I_ooooooool0@_ooo`030000oooooooo04Goool003Ooool306KoFOoo
o`0306Kooooooooo04;oool00`000?ooooooo`15oooo000coooo101Voecoool00`1Vooooooooo`12
oooo0P0004Koool002ooool406KoH?ooo`0306Kooooooooo04;oool00`000?ooooooo`15oooo000Y
oooo1P1VofCoool00`1Vooooooooo`12oooo00<0003oooooool0AOooo`009?ooo`D0I_mZoooo00<0
I_ooooooool0@_ooo`030000oooooooo04Goool001ooool506KoKoooo`0306Kooooooooo04;oool0
0`000?ooooooo`15oooo000Boooo10000003oooo06Ko06Ko00H0I_lOoooo1@0000;oool200001?oo
o`80000Yoooo1@0001Soool00`1Vooooooooo`0<oooo0P0000Coool200001?ooo`80000Xoooo00<0
003oooooool0:?ooo`800004oooo0P0000Coool200003oooo`004Oooo`0306Ko000006Ko00<0I_lY
oooo00<0003oooooool01oooo`040000oooooooo0000:_ooo`030000oooooooo01Soool00`1Voooo
ooooo`0;oooo00@0003oooooool00008oooo00@0003oooooool0000Woooo00<0003oooooool09ooo
o`040000oooooooo00002?ooo`040000oooooooo00003_ooo`004oooo`030000oooooooo02[oool0
0`000?ooooooo`0:oooo00<0003oooooool0:?ooo`030000oooooooo01Soool00`1Vooooooooo`0;
oooo00@0003oooooool0000;oooo00<0003oooooool09Oooo`030000oooooooo02Ooool010000?oo
ooooo`0000_oool00`000?ooooooo`0<oooo000<oooo100000Coool00`000?ooooooo`0Qoooo1000
00Coool00`000?ooooooo`08oooo0P0002?oool400001?ooo`030000oooooooo01Soool00`1Voooo
ooooo`05oooo100000;oool010000?ooooooo`0000Woool20000:?ooo`80000Xoooo00@0003ooooo
ool00009oooo0P0000ooool001;oool010000?ooooooo`0002[oool00`000?ooooooo`08oooo00<0
003oooooool0:_ooo`030000oooooooo01Soool00`1Vooooooooo`0;oooo00@0003oooooool00009
oooo00<0003oooooool09oooo`030000oooooooo02Ooool010000?ooooooo`0000Woool00`000?oo
ooooo`0>oooo000Coooo0P0002[oool200002_ooo`<0000Yoooo0P0001[oool00`1Vooooooooo`0<
oooo0P0000[oool300009oooo`030000oooooooo02Soool200002_ooo`<0000>oooo002Coooo00<0
I_ooooooool0@_ooo`030000oooooooo04Goool009?oool00`1Vooooooooo`12oooo00<0003ooooo
ool0AOooo`00Toooo`0306Kooooooooo04;oool00`000?ooooooo`15oooo002Coooo00<0I_oooooo
ool0@_ooo`030000oooooooo04Goool009?oool00`1Vooooooooo`12oooo00<0003oooooool0AOoo
o`002oooool0000700003oooo`004Oooo`030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o
00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol0
00Lco`000`0003?o03?o0007<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o
03?o0006<ol000<0000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0
000co`0co`001c?o00030000<ol0<ol000Lco`000`0003?o03?o0007<ol000<0003oooooool01ooo
o`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Ooool00`000?ooooooo`0Coooo000Aoooo00<0000co`0co`00;c?o00030000<ol0<ol002lco`00
0`0003?o03?o000K<ol000?o09Tco`0co`0043?o00030000<ol0<ol002lco`000`000?ooooooo`0_
oooo00<0003oooooool04oooo`004Ooooh8co`000ol0VC?o03?o0012<ol000<0003oooooool0AOoo
o`004Ooooh8co`000ol0VC?o03?o0012<ol000<0003oooooool0AOooo`004Ooooh8co`000ol0VC?o
03?o0012<ol000<0003oooooool0AOooo`004Ooooh8co`000ol0VC?o03?o0012<ol000<0003ooooo
ool0AOooo`004Ooooh8co`000ol0VC?o03?o0012<ol000<0003oooooool0AOooo`004Ooooh8co`00
0ol0VC?o03?o0012<ol00P0004Koool0017ooon2<ol000?o09Tco`0co`00@S?o00030000oooooooo
04Goool0017ooon2<ol000?o09Tco`0co`00@S?o00030000oooooooo04Goool0017ooon2<ol000?o
09Tco`0co`00@S?o00030000oooooooo04Goool0017ooon2<ol000?o09Tco`0co`00@S?o00030000
oooooooo04Goool0017ooon2<ol000?o09Tco`0co`00@S?o00030000oooooooo04Goool0017ooon2
<ol000?o09Tco`0co`00@S?o00030000oooooooo04Goool0017ooon2<ol000?o09Tco`0co`00@S?o
00030000oooooooo04Goool0017oool20000P3?o0003o`2I<ol0<ol0048co`020000A_ooo`004ooo
o`80001n<ol000?o09Tco`0co`00@S?o00030000oooooooo04Goool001Goool20000O3?o0003o`2I
<ol0<ol0048co`000`000?ooooooo`15oooo000Goooo0P0007Xco`000ol0VC?o03?o0012<ol000<0
003oooooool0AOooo`006Oooo`80001h<ol000?o09Tco`0co`00@S?o00030000oooooooo04Goool0
01_oool20000MS?o0003o`2I<ol0<ol0048co`000`000?ooooooo`15oooo000Moooo0P0007@co`00
0ol0VC?o03?o0012<ol000<0003oooooool0AOooo`007oooo`030000<ol0<ol0074co`000ol0VC?o
03?o0012<ol000<0003oooooool0AOooo`008?ooo`030000<ol0<ol0070co`000ol0VC?o03?o0012
<ol00P0004Koool0027oool20000L3?o0003o`2I<ol0<ol0048co`000`000?ooooooo`15oooo000S
oooo00<0000co`0co`00KC?o0003o`2I<ol0<ol0048co`000`000?ooooooo`15oooo000Toooo0P00
06dco`000ol0VC?o03?o0012<ol000<0003oooooool0AOooo`009_ooo`030000<ol0<ol006Xco`00
0ol0VC?o03?o0012<ol000<0003oooooool0AOooo`009oooo`030000<ol0<ol006Tco`000ol0VC?o
03?o0012<ol000<0003oooooool0AOooo`00:?ooo`030000<ol0<ol006Pco`000ol0VC?o03?o000Y
<ol00P0000@co`02000013?o00800003<ol0100000@co`000`000?ooooooo`15oooo000Yoooo00<0
000co`0co`00Ic?o0003o`2I<ol0<ol002Pco`00100003?o03?o000000Pco`00100003?o03?o0000
008co`000`0003?o03?o0005<ol000<0003oooooool0AOooo`00:_ooo`030000<ol0<ol006Hco`00
0ol0VC?o03?o000X<ol000@0000co`0co`000008<ol000@0000co`0co`000003<ol000<0000co`0c
o`0013?o00<00015oooo000[oooo0P0006Hco`000ol0VC?o03?o000X<ol000@0000co`0co`000008
<ol000@0000co`0co`000004<ol000<0000co`0co`000c?o00030000oooooooo04Goool002goool0
0`0003?o03?o001S<ol000?o09Tco`0co`00:3?o00040000<ol0<ol0000023?o00040000<ol0<ol0
00000S?o00040000<ol0<ol0000013?o00030000oooooooo04Goool002koool00`0003?o03?o001R
<ol000?o09Tco`0co`00:C?o0080000:<ol00P0000@co`0200001C?o00030000oooooooo04Goool0
02ooool00`0003?o03?o001Q<ol000?o09Tco`0co`00@S?o00030000oooooooo04Goool0033oool0
0`0003?o03?o001P<ol000?o09Tco`0co`00@S?o00030000oooooooo04Goool0037oool00`0003?o
03?o001O<ol000?o09Tco`0co`00@S?o00030000oooooooo04Goool003;oool00`0003?o03?o001N
<ol000?o09Tco`0co`00@S?o00030000oooooooo04Goool003?oool00`0003?o03?o001M<ol000?o
09Tco`0co`00@S?o00800016oooo000coooo00<0000co`0co`00GC?o0003o`2I<ol0<ol0048co`00
0`000?ooooooo`15oooo000doooo00<0000co`0co`00G3?o0003o`2I<ol0<ol0048co`000`000?oo
ooooo`15oooo000eoooo00<0000co`0co`00Fc?o0003o`2I<ol0<ol0048co`000`000?ooooooo`15
oooo000foooo00<0000co`0co`00FS?o0003o`2I<ol0<ol0048co`000`000?ooooooo`15oooo000g
oooo00<0000co`0co`00FC?o0003o`2I<ol0<ol0048co`000`000?ooooooo`15oooo000hoooo00<0
000co`0co`00F3?o0003o`2I<ol0<ol0048co`000`000?ooooooo`15oooo000hoooo00<0000co`0c
o`00F3?o0003o`2I<ol0<ol0048co`000`000?ooooooo`15oooo000ioooo00<0000co`0co`00Ec?o
0003o`2I<ol0<ol0048co`020000A_ooo`00>_ooo`030000<ol0<ol005Hco`000ol0VC?o03?o0012
<ol000<0003oooooool0AOooo`00>oooo`030000<ol0<ol005Dco`000ol0VC?o03?o0012<ol000<0
003oooooool0AOooo`00??ooo`030000<ol0<ol005@co`000ol0VC?o03?o0012<ol000<0003ooooo
ool0AOooo`00??ooo`030000<ol0<ol005@co`000ol0VC?o03?o0012<ol000<0003oooooool0AOoo
o`00?Oooo`030000<ol0<ol005<co`000ol0VC?o03?o0012<ol000<0003oooooool0AOooo`00?Ooo
o`030000<ol0<ol005<co`000ol0VC?o03?o0012<ol000<0003oooooool0AOooo`00?_ooo`030000
<ol0<ol0058co`000ol0VC?o03?o0012<ol000<0003oooooool0AOooo`00?_ooo`030000<ol0<ol0
058co`000ol0VC?o03?o0012<ol000<0003oooooool0AOooo`00?oooo`030000<ol0<ol0054co`00
0ol0VC?o03?o0012<ol00P0004Koool003ooool00`0003?o03?o001A<ol000?o09Tco`0co`00@S?o
00030000oooooooo04Goool0043oool00`0003?o03?o001@<ol000?o09Tco`0co`00@S?o00030000
oooooooo04Goool0047oool00`0003?o03?o001?<ol000?o09Tco`0co`00@S?o00030000oooooooo
04Goool0047oool00`0003?o03?o001?<ol000?o09Tco`0co`00@S?o00030000oooooooo04Goool0
04;oool00`0003?o03?o001><ol000?o09Tco`0co`00@S?o00030000oooooooo04Goool004;oool0
0`0003?o03?o001><ol000?o09Tco`0co`00:C?o00800004<ol00P0000@co`0200001C?o00<00003
<ol000<0003oooooool0AOooo`00@oooo`030000<ol0<ol004dco`000ol0VC?o03?o000X<ol000@0
000co`0co`000008<ol000@0000co`0co`000005<ol000<0000co`0co`000S?o00030000oooooooo
04Goool004?oool00`0003?o03?o001=<ol000?o09Tco`0co`00:3?o00040000<ol0<ol0000023?o
00040000<ol0<ol000000S?o00D00003<ol00`0004Goool004Coool00`0003?o03?o001<<ol000?o
09Tco`0co`00:3?o00040000<ol0<ol0000023?o00040000<ol0<ol000000S?o00040000<ol0<ol0
000013?o00030000oooooooo04Goool004Coool00`0003?o03?o001<<ol000?o09Tco`0co`00:3?o
00040000<ol0<ol0000023?o00040000<ol0<ol000000c?o00030000<ol0000000@co`000`000?oo
ooooo`15oooo0015oooo00<0000co`0co`00Bc?o0003o`2I<ol0<ol002Tco`0200002S?o00800005
<ol00P0000@co`000`000?ooooooo`15oooo0015oooo00<0000co`0co`00Bc?o0003o`2I<ol0<ol0
048co`000`000?ooooooo`15oooo0016oooo00<0000co`0co`00BS?o0003o`2I<ol0<ol0048co`00
0`000?ooooooo`15oooo0016oooo00<0000co`0co`00BS?o0003o`2I<ol0<ol0048co`000`000?oo
ooooo`15oooo0017oooo00<0000co`0co`00BC?o0003o`2I<ol0<ol0048co`000`000?ooooooo`15
oooo0017oooo00<0000co`0co`00BC?o0003o`2I<ol0<ol0048co`020000A_ooo`00B?ooo`030000
<ol0<ol004Pco`000ol0VC?o03?o0012<ol000<0003oooooool0AOooo`00B?ooo`030000<ol0<ol0
04Pco`000ol0VC?o03?o0012<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol004Lco`00
0ol0VC?o03?o0012<ol000<0003oooooool0AOooo`00BOooo`030000<ol0<ol004Lco`000ol0VC?o
03?o0012<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol004Hco`000ol0VC?o03?o0012
<ol000<0003oooooool0AOooo`00B_ooo`030000<ol0<ol004Hco`000ol0VC?o03?o0012<ol000<0
003oooooool0AOooo`00Boooo`030000<ol0<ol004Dco`000ol0VC?o03?o0012<ol000<0003ooooo
ool0AOooo`00Boooo`030000<ol0<ol004Dco`000ol0VC?o03?o0012<ol00P0004Koool004cooon<
<ol0B?ooo`00C?oooh`co`18oooo001<ooooS3?o04Soool004gooon;<ol0B?ooo`00COoooh/co`18
oooo001>oooo;C?o00030000<ol0<ol0024co`000`0003?o03?o000f<ol0B?ooo`00C_ooob`co`00
0`0003?o03?o0008<ol000<0000co`0co`0063?o00030000<ol0<ol003Dco`18oooo001?oooo:c?o
00030000<ol0<ol0008co`02000013?o00030000<ol0<ol000Hco`02000013?o00800004<ol00P00
00@co`000`0003?o03?o000e<ol0B?ooo`00Coooob/co`001@0003?o03?o03?o00000002<ol000<0
000co`0co`000S?o00030000<ol0<ol000@co`00100003?o03?o000000Pco`00100003?o03?o0000
00<co`000`0003?o03?o000e<ol0B?ooo`00CoooobXco`000`0003?o03?o0002<ol000<0000co`0c
o`0033?o00040000<ol0<ol000002S?o00030000<ol0<ol000<co`000`0003?o03?o000d<ol0B?oo
o`00D?ooobXco`000`0003?o03?o000500002c?o00040000<ol0<ol000002c?o00050000<ol0<ol0
<ol0000003Lco`18oooo001@oooo:S?o00050000<ol0<ol0<ol0000000hco`00100003?o03?o0000
00Pco`00100003?o03?o000000<co`000`0003?o03?o000e<ol0B?ooo`00D?ooob/co`000`0003?o
03?o000@<ol00P0000Xco`0200000c?o00030000<ol0<ol003Hco`18oooo001AooooQc?o04Soool0
057ooon7<ol0B?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-2.18058, \
-0.0500005, 0.0100694, 0.000620672}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-2.18058, -0.0500005, 0.0100694, 0.000620672}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 819}},
ScreenStyleEnvironment->"Working",
WindowSize->{569, 788},
WindowMargins->{{132, Automatic}, {Automatic, -5}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 165, 4, 96, "Title"],
Cell[1895, 58, 1138, 31, 296, "Text"],
Cell[3036, 91, 120, 4, 49, "Text"],
Cell[3159, 97, 578, 13, 19, "Input",
  CellOpen->False],
Cell[3740, 112, 121, 4, 49, "Text"],
Cell[3864, 118, 59, 1, 30, "Input"],
Cell[3926, 121, 108, 1, 49, "Text"],
Cell[4037, 124, 2062, 44, 19, "Input",
  CellOpen->False],
Cell[6102, 170, 74, 2, 19, "Input",
  CellOpen->False],
Cell[6179, 174, 75, 2, 19, "Input",
  CellOpen->False],
Cell[6257, 178, 373, 12, 68, "Text"],

Cell[CellGroupData[{
Cell[6655, 194, 665, 11, 170, "Input"],

Cell[CellGroupData[{
Cell[7345, 209, 30698, 1506, 186, 22002, 1394, "GraphicsData", "PostScript", \
"Graphics"],
Cell[38046, 1717, 30720, 1501, 186, 21919, 1388, "GraphicsData", \
"PostScript", "Graphics"],
Cell[68769, 3220, 29767, 1447, 186, 21071, 1335, "GraphicsData", \
"PostScript", "Graphics"],
Cell[98539, 4669, 29068, 1396, 186, 20263, 1283, "GraphicsData", \
"PostScript", "Graphics"],
Cell[127610, 6067, 28659, 1376, 186, 19967, 1264, "GraphicsData", \
"PostScript", "Graphics"],
Cell[156272, 7445, 28245, 1343, 186, 19428, 1230, "GraphicsData", \
"PostScript", "Graphics"],
Cell[184520, 8790, 27534, 1304, 186, 18822, 1192, "GraphicsData", \
"PostScript", "Graphics"],
Cell[212057, 10096, 27050, 1267, 186, 18233, 1154, "GraphicsData", \
"PostScript", "Graphics"],
Cell[239110, 11365, 26541, 1242, 186, 17870, 1131, "GraphicsData", \
"PostScript", "Graphics"],
Cell[265654, 12609, 25871, 1202, 186, 17240, 1091, "GraphicsData", \
"PostScript", "Graphics"],
Cell[291528, 13813, 31203, 1548, 186, 22507, 1436, "GraphicsData", \
"PostScript", "Graphics"],
Cell[322734, 15363, 25073, 1117, 186, 15584, 996, "GraphicsData", \
"PostScript", "Graphics"],
Cell[347810, 16482, 25396, 1095, 186, 15064, 963, "GraphicsData", \
"PostScript", "Graphics"],
Cell[373209, 17579, 29787, 1171, 186, 15486, 990, "GraphicsData", \
"PostScript", "Graphics"],
Cell[402999, 18752, 30829, 1190, 186, 15605, 998, "GraphicsData", \
"PostScript", "Graphics"],
Cell[433831, 19944, 31973, 1202, 186, 15566, 995, "GraphicsData", \
"PostScript", "Graphics"],
Cell[465807, 21148, 32442, 1206, 186, 15533, 993, "GraphicsData", \
"PostScript", "Graphics"],
Cell[498252, 22356, 33394, 1216, 186, 15509, 991, "GraphicsData", \
"PostScript", "Graphics"],
Cell[531649, 23574, 33839, 1226, 186, 15602, 997, "GraphicsData", \
"PostScript", "Graphics"],
Cell[565491, 24802, 34268, 1235, 186, 15666, 1001, "GraphicsData", \
"PostScript", "Graphics"],
Cell[599762, 26039, 34104, 1227, 186, 15551, 994, "GraphicsData", \
"PostScript", "Graphics"],
Cell[633869, 27268, 34451, 1233, 186, 15578, 996, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[668369, 28507, 621, 9, 170, "Input"],

Cell[CellGroupData[{
Cell[669015, 28520, 30785, 1310, 186, 18404, 1153, "GraphicsData", \
"PostScript", "Graphics"],
Cell[699803, 29832, 31366, 1341, 186, 18867, 1182, "GraphicsData", \
"PostScript", "Graphics"],
Cell[731172, 31175, 30940, 1314, 186, 18441, 1155, "GraphicsData", \
"PostScript", "Graphics"],
Cell[762115, 32491, 30935, 1313, 186, 18428, 1154, "GraphicsData", \
"PostScript", "Graphics"],
Cell[793053, 33806, 30665, 1296, 186, 18166, 1137, "GraphicsData", \
"PostScript", "Graphics"],
Cell[823721, 35104, 30938, 1313, 186, 18419, 1154, "GraphicsData", \
"PostScript", "Graphics"],
Cell[854662, 36419, 30777, 1303, 186, 18299, 1145, "GraphicsData", \
"PostScript", "Graphics"],
Cell[885442, 37724, 30718, 1300, 186, 18236, 1142, "GraphicsData", \
"PostScript", "Graphics"],
Cell[916163, 39026, 30884, 1310, 186, 18402, 1152, "GraphicsData", \
"PostScript", "Graphics"],
Cell[947050, 40338, 30408, 1280, 186, 17918, 1122, "GraphicsData", \
"PostScript", "Graphics"],
Cell[977461, 41620, 30214, 1274, 186, 17845, 1117, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1007678, 42896, 30795, 1306, 186, 18345, 1148, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1038476, 44204, 30511, 1288, 186, 18053, 1130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1068990, 45494, 30430, 1283, 186, 17972, 1125, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1099423, 46779, 30142, 1265, 186, 17672, 1107, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1129568, 48046, 30442, 1284, 186, 17984, 1126, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1160013, 49332, 30012, 1258, 186, 17594, 1100, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1190028, 50592, 29742, 1242, 186, 17333, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1219773, 51836, 30310, 1278, 186, 17896, 1120, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1250086, 53116, 29830, 1246, 186, 17392, 1088, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1279919, 54364, 29270, 1218, 186, 16966, 1062, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1309192, 55584, 28753, 1179, 186, 16331, 1021, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1337948, 56765, 29697, 1239, 186, 17283, 1081, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1367648, 58006, 30037, 1261, 186, 17636, 1104, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1397688, 59269, 29764, 1244, 186, 17363, 1087, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1427455, 60515, 29540, 1229, 186, 17139, 1072, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1456998, 61746, 29603, 1236, 186, 17242, 1079, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1486604, 62984, 29583, 1236, 186, 17230, 1079, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1516190, 64222, 29591, 1236, 186, 17242, 1079, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1545784, 65460, 28196, 1147, 186, 15851, 990, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1573983, 66609, 33098, 1482, 186, 20996, 1328, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1607084, 68093, 28895, 1202, 186, 16554, 1045, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1635982, 69297, 28699, 1185, 186, 16290, 1028, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1664684, 70484, 28879, 1196, 186, 16445, 1038, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1693566, 71682, 28809, 1189, 186, 16327, 1031, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1722378, 72873, 29013, 1198, 186, 16458, 1039, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1751394, 74073, 28918, 1192, 186, 16363, 1033, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1780315, 75267, 28546, 1167, 186, 15958, 1007, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1808864, 76436, 28194, 1139, 186, 15505, 978, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1837061, 77577, 28785, 1176, 186, 16068, 1015, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1865849, 78755, 28673, 1171, 186, 16021, 1011, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1894525, 79928, 28866, 1175, 186, 16027, 1012, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1923394, 81105, 28930, 1176, 186, 16059, 1013, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1952327, 82283, 28804, 1166, 186, 15880, 1002, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1981134, 83451, 28621, 1153, 186, 15640, 988, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2009758, 84606, 28122, 1115, 186, 15052, 949, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2037883, 85723, 28647, 1145, 186, 15492, 978, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2066533, 86870, 28391, 1125, 186, 15188, 958, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2094927, 87997, 28920, 1158, 186, 15676, 990, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2123850, 89157, 28823, 1146, 186, 15486, 977, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2152676, 90305, 28261, 1112, 186, 14952, 943, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2180940, 91419, 28940, 1147, 186, 15478, 977, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2209883, 92568, 28781, 1131, 186, 15213, 959, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2238667, 93701, 28955, 1139, 186, 15298, 966, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2267625, 94842, 29281, 1157, 186, 15592, 984, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2296909, 96001, 27594, 1042, 186, 13743, 867, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2324506, 97045, 28954, 1123, 186, 15014, 947, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2353463, 98170, 29003, 1122, 186, 14969, 944, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2382469, 99294, 28890, 1110, 186, 14751, 931, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2411362, 100406, 29095, 1116, 186, 14831, 936, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2440460, 101524, 28612, 1084, 186, 14315, 903, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

