(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2344077,      98369]*)
(*NotebookOutlinePosition[   2344759,      98392]*)
(*  CellTagsIndexPosition[   2344715,      98388]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["FOCUSING WITH A BOUND STATE", "Text",
  FontSize->14,
  Background->None]], "Title",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  StyleBox["The wavefront  and the tail  are incident from the left.\n\nThe \
nonhomogeneity  ",
    FontSize->12],
  StyleBox["is located on the entire ",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"],
  StyleBox["x",
    FontSize->12,
    FontVariations->{"CompatibilityType"->0},
    CharacterEncoding->"WindowsANSI"],
  StyleBox["-axis.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"],
  StyleBox["  \n\nThe focusing location,  ",
    FontSize->12],
  StyleBox["x0, ",
    FontSize->12,
    FontVariations->{"CompatibilityType"->0},
    CharacterEncoding->"WindowsANSI"],
  StyleBox[" any real number, is in the nonhomogeneity and needs to be \
specified. \n\nThe potential   v[x], which is ",
    FontSize->12],
  StyleBox["the nonhomogeneity, is strictly negative. It corresponds to a \
reflectionless potential with one bound state of norming constant, c>0.\n\n\
The transmission coefficient, left reflection coefficient, and right \
reflection coefficient, respectively, are denoted by  T[k],  L[k],  R[k].\n\n\
The tail of the wave is denoted by  g[x,t].\n\nThe focusing moment is chosen \
as  t=0.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"]
}], "Text",
  FontSize->18,
  Background->RGBColor[1, 1, 0]],

Cell["\<\
The potential and the scattering coefficients are given next:\
\>", \
"Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(\(Clear[v, T, L, R, x0, g, c];\)\), "\[IndentingNewLine]", 
    \(\(v[
          x_] = \(-\ 
            16\)\ c^2\ E^\((2\ x)\)/\((2\ E^\((2\ x)\) + 
                  c^2)\)^2\ ;\)\), "\n", 
    \(\(T[k_] = \((k + I\ )\)/\((k - I)\);\)\), "\n", 
    \(\(L[k_] = 0;\)\), "\n", 
    \(\(R[k_] = 0;\)\)}], "Input",
  CellOpen->False],

Cell["\<\
Specify the focusing location  x0, any real number, and the norming \
constant c, a positive number, next:\
\>", "Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(\(\(c = 1\) \)\(;\)\(\ \)\(\(x0 = 1\) \)\(;\)\(\ \)\)\)], "Input"],

Cell["The tail  g[x,t]  of the focusing  wave is evaluated  next:", "Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(g[x_, t_] = 
        UnitStep[\(-x\) + x0 + 
              t]\ \((4\ c^2\ E^\((x + x0)\)\ \((E^t - 
                    E^\((\(-t\))\))\))\)/\((\((2\ E^\((2\ x)\) + 
                    c^2)\) \((2\ E^\((2\ x0)\) + c^2)\))\);\)\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`Animation`\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`FilledPlot`\)], "Input",
  CellOpen->False],

Cell[TextData[{
  "The focusing wave is animated  next. The wavefront (",
  StyleBox["magenta",
    FontColor->RGBColor[1, 0, 1]],
  ") and the tail (",
  StyleBox["blue",
    FontColor->RGBColor[0, 0, 1]],
  ") are incident from the left onto the nonhomogeneity (",
  StyleBox["green",
    FontColor->RGBColor[0, 1, 0]],
  "):"
}], "Text",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Animate[{FilledPlot\[IndentingNewLine][{v[x]}, \ {x, \ \(-5\), \ 
              6}, \ PlotRange -> {\(-3\), 4}, \ 
            Fills \[Rule] {Hue[ .3]}], \[IndentingNewLine]Plot[{10\ UnitStep[
                  x - x0 - t]}, \ {x, \ \(-5\), \ 6}, \ 
            PlotStyle\  \[Rule] \ Hue[0.9], \ 
            PlotRange -> {\(-3\), 4}], \ \[IndentingNewLine]Plot[{g[x, 
                t]}, \ {x, \ \(-5\), \ 6}, 
            PlotStyle\  \[Rule] \ 
              Hue[ .6], \ \ PlotRange -> {\(-3\), 
                4}]}, \ \[IndentingNewLine]{t, \ \(-6\), \ 3, 0.2}, 
        PlotLabel \[Rule] {"\<t\>", t}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -22.0938 0 ]
[.5 .63053 22.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -83.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
0 .4 1 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.69774 .26487 L
.73838 .26487 L
.77751 .26487 L
.81909 .26487 L
.85916 .26487 L
.89771 .26487 L
.93871 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -22.0938 0 ]
[.5 .63053 22.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -83.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo0011
oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0E
oooo000/oooo00<0003oooooool0:Oooo`030000oooooooo02Woool00`000?ooooooo`0Yoooo00<0
003oooooool0:Oooo`030000oooooooo02Woool00`000?ooooooo`0Eoooo0024oooo00<0003ooooo
ool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000oooooooo
09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?ooo`80002J
oooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?oo
ooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?ooo`80002Joooo0024oooo00<0003ooooo
ool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo0P00
09[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00O?ooo`D00003
oooo00<0003oooooool0VOooo`00O_ooo`030000oooooooo00?oool00`000?ooooooo`2Ioooo001n
oooo00<0003oooooool00oooo`<0002Ioooo001noooo00<0003oooooool00oooo`030000oooooooo
09Woool007koool00`000?ooooooo`03oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007goool00`000?ooooooo`04
oooo0`0009Woool007koool00`000?ooooooo`03oooo00<0003oooooool0VOooo`00O?ooo`040000
oooooooo00001?ooo`030000oooooooo09Woool007goool200001Oooo`030000oooooooo09Woool0
08Coool20000V_ooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?oo
o`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOoo
o`00Q?ooo`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool0
08Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?ooo`80002Joooo0024
oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0003oooooool0VOooo`00O?ooo`040000
oooooooo00001?ooo`030000oooooooo09Woool007koool00`000?ooooooo`03oooo0`0009Woool0
07ooool00`000?ooooooo`02oooo00<0003oooooool0VOooo`00O?ooo`040000oooooooo00001?oo
o`030000oooooooo09Woool007goool200001Oooo`030000oooooooo09Woool008Coool00`000?oo
ooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003ooooo
ool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000oooooooo
09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000
oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?oo
ooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?ooo`80002Joooo0024oooo00<0003ooooo
ool0VOooo`00Q?ooo`030000oooooooo09Woool007koool300000oooo`030000oooooooo09Woool0
07ooool00`000?ooooooo`02oooo00<0003oooooool0VOooo`00O?ooo`D00003oooo0`0009Woool0
07coool010000?ooooooo`000:3oool007goool00`000?ooo`00002Poooo001noooo0P000:3oool0
0?oooolQoooo003ooooo8Oooo`00Ooooo`030000oooooooo01coool00`000?ooooooo`1ooooo001n
oooo00<0003oooooool02?ooo`030000oooooooo01?oool00`000?ooooooo`1noooo001noooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`<00004oooo00<0003oooooool0O_oo
o`00O_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00003oooo00@0003oooooool00003oooo00<0003oooooool0O_ooo`00OOooo`030000oooooooo
00;oool00`000?ooooooo`0Coooo00@0003oooooool00004oooo00<0003oooooool0OOooo`00O_oo
o`030000oooooooo00D0000Boooo0`0000Coool00`000?ooooooo`1noooo001noooo00D0003ooooo
ooooool000005_ooo`030000oooooooo00?oool00`000?ooooooo`1noooo001ooooo00<0003ooooo
ool05oooo`<00002oooo00<0003oooooool0Ooooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.02846 .26487 L
.03279 .26487 L
.03754 .26487 L
.0389 .26487 L
.0402 .26487 L
s
.0402 .26487 m
.04066 .61803 L
s
0 .4 1 r
.02381 .12948 m
.02846 .12201 L
.03279 .11469 L
.03754 .10622 L
.0389 .10369 L
.0402 .10127 L
.04136 .26487 L
.04262 .26487 L
.06244 .26487 L
.10458 .26487 L
.14545 .26487 L
.1848 .26487 L
.22263 .26487 L
.26292 .26487 L
.30169 .26487 L
.34292 .26487 L
.38262 .26487 L
.42082 .26487 L
.46146 .26487 L
.50059 .26487 L
.54217 .26487 L
.58224 .26487 L
.62079 .26487 L
.6618 .26487 L
.70128 .26487 L
.73925 .26487 L
.77968 .26487 L
.81859 .26487 L
.85995 .26487 L
.89979 .26487 L
.93812 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool001[oool00`1Vooooooooo`1Ioooo00<0000co`0c
o`002S?o0080002Koooo000Joooo00<0I_ooooooool0F?ooo`030000<ol0<ol000`co`020000V_oo
o`006Oooo`80I_mIoooo00<0000co`0co`003C?o00030000oooooooo09Woool001Woool206KoF?oo
o`030000<ol0<ol000hco`020000V_ooo`006?ooo`0306Kooooo06Ko05Soool00`0003?o03?o000>
<ol000<0000co`000000VOooo`005oooo`0406Kooooooooo06KoEoooo`030000<ol0<ol000lco`02
000000<co`00003oool0Uoooo`005_ooo`0506Kooooooooooooo06Ko05Ooool00`0003?o03?o000?
<ol000@0000co`0co`00002Hoooo000Foooo00D0I_ooooooooooool0I_l0E_ooo`030000<ol0<ol0
010co`001@0003?o03?o03?o0000002Goooo000Joooo00<0I_ooooooool0E?ooo`030000<ol0<ol0
010co`000`0003?o03?o0002<ol000<0003oooooool0U?ooo`006_ooo`0306Kooooooooo05?oool0
0`0003?o03?o000A<ol000<0000co`0co`000S?o00030000oooooooo09Coool001[oool00`1Voooo
ooooo`1Boooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`006_ooo`0306Ko
oooooooo057oool00`0003?o03?o000C<ol000<0000co`0co`0013?o00030000oooooooo09;oool0
01[oool00`1Vooooooooo`1Aoooo00<0000co`0co`004c?o00030000<ol0<ol000@co`000`000?oo
ooooo`2Boooo000Joooo00<0I_ooooooool0D?ooo`030000<ol0<ol001@co`000`0003?o03?o0005
<ol000<0003oooooool0TOooo`006_ooo`0306Kooooooooo04ooool00`0003?o03?o000E<ol00P00
00Lco`000`000?ooooooo`2@oooo000Joooo00<0I_ooooooool0C_ooo`030000<ol0<ol001Hco`00
0`0003?o03?o0006<ol000<0003oooooool0T?ooo`006_ooo`0306Kooooooooo04koool00`0003?o
03?o000F<ol000<0000co`0co`001c?o00030000oooooooo08ooool001[oool00`1Vooooooooo`1=
oooo00<0000co`0co`003c?o00D00003<ol000<0000co`0co`0023?o00030000oooooooo08koool0
01[oool00`1Vooooooooo`1<oooo00<0000co`0co`004S?o00030000<ol0<ol000<co`000`0003?o
03?o0008<ol000<0003oooooool0S_ooo`006_ooo`0306Kooooooooo04_oool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00<00009<ol000<0003oooooool0SOooo`006_ooo`0306Kooooooooo
04_oool00`0003?o03?o000;<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0co`002S?o
00030000oooooooo08coool001_oool00`1Vooooooooo`19oooo00<0000co`0co`0053?o00030000
<ol0<ol000<co`000`0003?o03?o000;<ol000<0003oooooool0Roooo`006oooo`0306Kooooooooo
04Soool00`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Rooo
o`006oooo`0306Kooooooooo04Soool00`0003?o03?o000K<ol00P0000dco`000`000?ooooooo`2:
oooo000Koooo00<0I_ooooooool0Aoooo`030000<ol0<ol001`co`000`0003?o03?o000=<ol000<0
003oooooool0ROooo`006oooo`0306Kooooooooo04Koool00`0003?o03?o000M<ol000<0000co`0c
o`003S?o00030000oooooooo08Soool001_oool00`1Vooooooooo`15oooo00<0000co`0co`007S?o
00030000<ol0<ol000lco`000`000?ooooooo`27oooo000Koooo00<0I_ooooooool0AOooo`030000
<ol0<ol001hco`000`0003?o03?o000@<ol000<0003oooooool0Q_ooo`006oooo`0306Kooooooooo
04Coool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25oooo000Koooo00<0I_oooooo
ool0@oooo`030000<ol0<ol0020co`000`0003?o03?o000B<ol000<0003oooooool0Q?ooo`006ooo
o`0306Kooooooooo017oool300009oooo`@00002oooo0P0002<co`000`0003?o03?o000C<ol000<0
003oooooool04Oooo`@0000Zoooo0`0002Ooool300005oooo`006oooo`0306Kooooooooo01;oool0
0`000?ooooooo`0Voooo00<0003oooooool00_ooo`030000<ol0<ol002<co`000`0003?o03?o000D
<ol000<0003oooooool04?ooo`030000oooooooo02coool00`000?ooooooo`0Voooo00@0003ooooo
ool0000Foooo000Koooo00<0I_ooooooool03oooo`D0000Xoooo00@0003oooooool0000V<ol00P00
01Hco`0200004Oooo`030000oooooooo02Soool500009oooo`040000oooooooo00005_ooo`006ooo
o`0306Kooooooooo00Woool400000_ooo`040000oooooooo00008_ooo`@00004oooo0P0002Lco`00
0`0003?o03?o000G<ol000<0003oooooool03oooo`030000oooooooo02Ooool010000?ooooooo`00
02Soool300005oooo`006oooo`0306Kooooooooo013oool00`000?ooo`00000Xoooo0P000003<ol0
0000<ol002Hco`000`0003?o03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Ooo
o`030000oooo000002Woool00`000?ooooooo`0Foooo000Koooo00<0I_ooooooool04Oooo`80000W
oooo100002Pco`000`0003?o03?o000I<ol000<0003oooooool03?ooo`80000[oooo0P0002Woool3
00005_ooo`006oooo`0306Kooooooooo03Soool20000;3?o00030000<ol0<ol001Xco`020000OOoo
o`006oooo`0306Kooooooooo03Koool20000;S?o0080000M<ol00`0007[oool001_oool00`1Voooo
ooooo`0coooo0`00030co`000`0003?o03?o000O<ol01P0007Coool001_oool00`1Vooooooooo`0]
oooo1P0003<co`000`0003?o03?o000U<ol00`00077oool001_oool00`1Vooooooooo`0Soooo2P00
03Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`050000oooooooo
ooooo`2I00Koool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0E
oooo000Joooo00?o09Woooooool03oooo`030000oooooooo02Woool00`000?ooooooo`0Yoooo00<0
003oooooool0:Oooo`030000oooooooo02Woool00`000?ooooooo`0Yoooo00<0003oooooool05Ooo
o`006_ooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2Ioooo000Joooo00?o09Woooooool0Iooo
o`030000oooooooo09Woool001[oool00ol0VOooooooo`1Woooo0P0009[oool001[oool00ol0VOoo
ooooo`1Woooo00<0003oooooool0VOooo`006_ooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2I
oooo000Joooo00?o09Woooooool0Ioooo`030000oooooooo09Woool001[oool00ol0VOooooooo`1W
oooo0P0009[oool001[oool00ol0VOooooooo`1Woooo00<0003oooooool0VOooo`006_ooo`03o`2I
oooooooo06Ooool00`000?ooooooo`2Ioooo000Joooo00?o09Woooooool0Ioooo`030000oooooooo
09Woool001[oool00ol0VOooooooo`1Woooo00<0003oooooool0VOooo`006_ooo`03o`2Ioooooooo
06Ooool20000V_ooo`006_ooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2Ioooo000Joooo00?o
09Woooooool0Ioooo`030000oooooooo09Woool001[oool00ol0VOooooooo`1Woooo00<0003ooooo
ool0VOooo`006_ooo`03o`2Ioooooooo06Ooool20000V_ooo`006_ooo`03o`2Ioooooooo06Ooool0
0`000?ooooooo`2Ioooo000Joooo00?o09Woooooool0Ioooo`030000oooooooo09Woool001[oool0
0ol0VOooooooo`1Ooooo1@0000?oool00`000?ooooooo`2Ioooo000Joooo00?o09Woooooool0HOoo
o`030000oooooooo00?oool00`000?ooooooo`2Ioooo000Joooo00?o09Woooooool0HOooo`030000
oooooooo00?oool30000VOooo`006_ooo`03o`2Ioooooooo067oool00`000?ooooooo`03oooo00<0
003oooooool0VOooo`006_ooo`03o`2Ioooooooo067oool00`000?ooooooo`03oooo00<0003ooooo
ool0VOooo`006_ooo`03o`2Ioooooooo063oool200001Oooo`030000oooooooo09Woool001[oool0
0ol0VOooooooo`1Woooo0P0009[oool001[oool00ol0VOooooooo`1Woooo00<0003oooooool0VOoo
o`006_ooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2Ioooo000Joooo00?o09Woooooool0Iooo
o`030000oooooooo09Woool001[oool00ol0VOooooooo`1Woooo00<0003oooooool0VOooo`006_oo
o`03o`2Ioooooooo06Ooool20000V_ooo`006_ooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2I
oooo000Joooo00?o09Woooooool0Ioooo`030000oooooooo09Woool001[oool00ol0VOooooooo`1W
oooo00<0003oooooool0VOooo`006_ooo`03o`2Ioooooooo06Ooool20000V_ooo`006_ooo`03o`2I
oooooooo06Ooool00`000?ooooooo`2Ioooo000Joooo00?o09Woooooool0Ioooo`030000oooooooo
09Woool001[oool00ol0VOooooooo`1Woooo00<0003oooooool0VOooo`006_ooo`03o`2Ioooooooo
06Ooool00`000?ooooooo`2Ioooo000Joooo00?o09Woooooool0Ioooo`80002Joooo000Joooo00?o
09Woooooool0Ioooo`030000oooooooo09Woool001[oool00ol0VOooooooo`1Ooooo100000Coool0
0`000?ooooooo`2Ioooo000Joooo00?o09Woooooool0Goooo`030000oooooooo00Goool00`000?oo
ooooo`2Ioooo000Joooo00?o09Woooooool0H?ooo`030000oooooooo00Coool30000VOooo`006ooo
o`03o`2Ioooooooo063oool00`000?ooooooo`03oooo00<0003oooooool0VOooo`006oooo`03o`2I
oooooooo05koool010000?ooooooo`0000Coool00`000?ooooooo`2Ioooo000Koooo00?o09Wooooo
ool0Goooo`800005oooo00<0003oooooool0VOooo`006oooo`03o`2Ioooooooo06Koool20000V_oo
o`006oooo`03o`2Ioooooooo06Koool00`000?ooooooo`2Ioooo000Koooo00?o09Woooooool0I_oo
o`030000oooooooo09Woool001_oool00ol0VOooooooo`1Voooo00<0003oooooool0VOooo`006ooo
o`03o`2Ioooooooo06Koool00`000?ooooooo`2Ioooo000Koooo00?o09Woooooool0I_ooo`80002J
oooo000Koooo00?o09Woooooool0I_ooo`030000oooooooo09Woool001_oool00ol0VOooooooo`1V
oooo00<0003oooooool0VOooo`006oooo`03o`2Ioooooooo06Koool00`000?ooooooo`2Ioooo000K
oooo00?o09Woooooool0I_ooo`80002Joooo000Koooo00?o09Woooooool0I_ooo`030000oooooooo
09Woool001_oool00ol0VOooooooo`1Voooo00<0003oooooool0VOooo`006oooo`03o`2Ioooooooo
06Koool00`000?ooooooo`2Ioooo000Koooo00?o09Woooooool0I_ooo`030000oooooooo09Woool0
01_oool00ol0VOooooooo`1Voooo0P0009[oool001_oool00ol0VOooooooo`1Voooo00<0003ooooo
ool0VOooo`006oooo`03o`2Ioooooooo05ooool200001Oooo`030000oooooooo09Woool001_oool0
0ol0VOooooooo`1Noooo00@0003oooooool00004oooo00<0003oooooool0VOooo`006oooo`03o`2I
oooooooo063oool00`000?ooooooo`03oooo0`0009Woool001_oool00ol0VOooooooo`1Qoooo00<0
003oooooool00_ooo`030000oooooooo09Woool001_oool00ol0VOooooooo`1Noooo00@0003ooooo
ool00004oooo00<0003oooooool0VOooo`006oooo`03o`2Ioooooooo05ooool200001Oooo`030000
oooooooo09Woool001_oool00ol0VOooooooo`1Voooo00<0003oooooool0VOooo`006oooo`03o`2I
oooooooo06Koool20000V_ooo`006oooo`03o`2Ioooooooo06Koool00`000?ooooooo`2Ioooo000K
oooo00?o09Woooooool0I_ooo`030000oooooooo09Woool001_oool00ol0VOooooooo`1Voooo00<0
003oooooool0VOooo`006oooo`03o`2Ioooooooo06Koool20000V_ooo`006oooo`03o`2Ioooooooo
06Koool00`000?ooooooo`2Ioooo000Koooo00?o09Woooooool0I_ooo`030000oooooooo09Woool0
01_oool00ol0VOooooooo`1Voooo00<0003oooooool0VOooo`006oooo`03o`2Ioooooooo06Koool0
0`000?ooooooo`2Ioooo000Koooo00?o09Woooooool0I_ooo`80002Joooo000Koooo00?o09Wooooo
ool0I_ooo`030000oooooooo09Woool001_oool00ol0VOooooooo`1Voooo00<0003oooooool0VOoo
o`006oooo`03o`2Ioooooooo06Koool00`000?ooooooo`2Ioooo000Koooo00?o09Woooooool0I_oo
o`80002Joooo000Koooo00?o09Woooooool0I_ooo`030000oooooooo09Woool001_oool00ol0VOoo
ooooo`1Voooo00<0003oooooool0VOooo`006oooo`03o`2Ioooooooo063oool300000oooo`030000
oooooooo09Woool001_oool00ol0VOooooooo`1Qoooo00<0003oooooool00_ooo`030000oooooooo
09Woool001_oool00ol0VOooooooo`1Noooo1@0000?oool30000VOooo`00O?ooo`040000oooooooo
0000X?ooo`00OOooo`030000oooo00000:3oool007koool20000X?ooo`00ooooob7oool00?oooolQ
oooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`0=oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00003oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Foooo00<0003oooooool01_ooo`040000
oooooooo00001?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500004oooo`80000:
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005_ooo`030000
oooooooo00Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003ooooo
ool05oooo`<00009oooo0P0000?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.03279 .26487 L
.04262 .26487 L
.04758 .26487 L
.05288 .26487 L
.05546 .26487 L
.05672 .26487 L
.05789 .26487 L
s
.05789 .26487 m
.05831 .61803 L
s
0 .4 1 r
.02381 .15402 m
.03279 .14191 L
.04262 .12713 L
.04758 .11901 L
.05288 .1098 L
.05546 .10512 L
.05672 .10277 L
.05789 .10057 L
.05895 .26487 L
.06007 .26487 L
.06244 .26487 L
.10458 .26487 L
.14241 .26487 L
.1827 .26487 L
.22147 .26487 L
.2627 .26487 L
.30241 .26487 L
.3406 .26487 L
.38125 .26487 L
.42038 .26487 L
.46196 .26487 L
.50202 .26487 L
.54057 .26487 L
.58158 .26487 L
.62107 .26487 L
.65904 .26487 L
.69946 .26487 L
.73837 .26487 L
.77973 .26487 L
.81958 .26487 L
.85791 .26487 L
.89869 .26487 L
.93795 .26487 L
.97571 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool001ooool00`1Vooooooooo`1Doooo00<0000co`0c
o`002S?o0080002Koooo000Noooo0P1VoeGoool00`0003?o03?o000<<ol00P0009[oool001koool2
06KoE?ooo`030000<ol0<ol000dco`000`000?ooooooo`2Ioooo000Moooo00<0I_ooool0I_l0Dooo
o`030000<ol0<ol000hco`020000V_ooo`007?ooo`0406Kooooooooo06KoDoooo`030000<ol0<ol0
00hco`000`0003?o0000002Ioooo000Koooo00D0I_ooooooooooool0I_l0D_ooo`030000<ol0<ol0
00lco`02000000<co`00003oool0Uoooo`006oooo`0506Kooooooooooooo06Ko05;oool00`0003?o
03?o000?<ol000@0000co`0co`00002Hoooo000Joooo00<0I_ooooooool00_ooo`0306Kooooooooo
04ooool00`0003?o03?o000@<ol000D0000co`0co`0co`000000Uoooo`006_ooo`0306Kooooooooo
00;oool00`1Vooooooooo`1?oooo00<0000co`0co`0043?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo000Ioooo00<0I_ooooooool00oooo`0306Kooooooooo04koool00`0003?o03?o000A
<ol000<0000co`0co`000S?o00030000oooooooo09Coool001Woool00`1Vooooooooo`03oooo00<0
I_ooooooool0COooo`030000<ol0<ol0018co`02000013?o00030000oooooooo09?oool001Soool0
0`1Vooooooooo`04oooo00<0I_ooooooool0C?ooo`030000<ol0<ol001<co`000`0003?o03?o0004
<ol000<0003oooooool0T_ooo`005oooo`0306Kooooooooo00Goool00`1Vooooooooo`1<oooo00<0
000co`0co`004c?o00030000<ol0<ol000@co`000`000?ooooooo`2Boooo000Foooo00<0I_oooooo
ool01_ooo`0306Kooooooooo04_oool00`0003?o03?o000D<ol000<0000co`0co`001C?o00030000
oooooooo097oool001ooool00`1Vooooooooo`1:oooo00<0000co`0co`005C?o00800007<ol000<0
003oooooool0T?ooo`007oooo`0306Kooooooooo04Woool00`0003?o03?o000F<ol000<0000co`0c
o`001S?o00030000oooooooo093oool001ooool00`1Vooooooooo`19oooo00<0000co`0co`005S?o
00030000<ol0<ol000Lco`000`000?ooooooo`2?oooo000Ooooo00<0I_ooooooool0B?ooo`030000
<ol0<ol000lco`0500000c?o00030000<ol0<ol000Pco`000`000?ooooooo`2>oooo000Ooooo00<0
I_ooooooool0Aoooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0co`0023?o
00030000oooooooo08koool001ooool00`1Vooooooooo`16oooo00<0000co`0co`004c?o00030000
<ol0<ol000<co`0300002C?o00030000oooooooo08goool001ooool00`1Vooooooooo`16oooo00<0
000co`0co`002c?o00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000Xco`000`000?oo
ooooo`2<oooo000Ooooo00<0I_ooooooool0AOooo`030000<ol0<ol001@co`000`0003?o03?o0003
<ol000<0000co`0co`002c?o00030000oooooooo08_oool001ooool00`1Vooooooooo`14oooo00<0
000co`0co`0053?o00800005<ol000<0000co`0co`002c?o00030000oooooooo08_oool001ooool0
0`1Vooooooooo`14oooo00<0000co`0co`006c?o0080000=<ol000<0003oooooool0R_ooo`007ooo
o`0306Kooooooooo04?oool00`0003?o03?o000L<ol000<0000co`0co`003C?o00030000oooooooo
08Woool001ooool00`1Vooooooooo`12oooo00<0000co`0co`007C?o00030000<ol0<ol000hco`00
0`000?ooooooo`28oooo000Ooooo00<0I_ooooooool0@Oooo`030000<ol0<ol001hco`000`0003?o
03?o000?<ol000<0003oooooool0Qoooo`007oooo`0306Kooooooooo047oool00`0003?o03?o000N
<ol000<0000co`0co`0043?o00030000oooooooo08Koool001ooool00`1Vooooooooo`10oooo00<0
000co`0co`007c?o0080000B<ol000<0003oooooool0QOooo`007oooo`0306Kooooooooo03ooool0
0`0003?o03?o000P<ol000<0000co`0co`004S?o00030000oooooooo08Coool001ooool00`1Voooo
ooooo`0=oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo
017oool40000:_ooo`<0000Woooo0`0001Ooool001ooool00`1Vooooooooo`0>oooo00<0003ooooo
ool09_ooo`030000oooooooo00;oool00`0003?o03?o000S<ol000<0000co`0co`0053?o00030000
oooooooo013oool00`000?ooooooo`0/oooo00<0003oooooool09_ooo`040000oooooooo00005_oo
o`007oooo`0306Kooooooooo00_oool50000:?ooo`040000oooooooo00009S?o0080000F<ol00P00
017oool00`000?ooooooo`0Xoooo1@0002Ooool010000?ooooooo`0001Koool001ooool00`1Voooo
ooooo`05oooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0000co`0c
o`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000Xoooo0`00
01Ooool001ooool00`1Vooooooooo`0<oooo00<0003oool00000:?ooo`8000000c?o000003?o000V
<ol000<0000co`0co`0063?o00030000oooooooo00coool010000?ooooooo`0002Woool00`000?oo
o`00000Yoooo00<0003oooooool05_ooo`007oooo`0306Kooooooooo00goool200009oooo`@0000X
<ol000<0000co`0co`006C?o00030000oooooooo00coool20000:oooo`80000Yoooo0`0001Koool0
01ooool00`1Vooooooooo`0doooo0P0002`co`000`0003?o03?o000J<ol00P0007goool001ooool0
0`1Vooooooooo`0boooo0P0002hco`0200007C?o00<0001joooo000Ooooo00<0I_ooooooool0;ooo
o`<0000`<ol000<0000co`0co`007c?o00H0001doooo000Ooooo00<0I_ooooooool0:Oooo`H0000c
<ol000<0000co`0co`009C?o00<0001aoooo000Ooooo00<0I_ooooooool07oooo`X0000i<ol000<0
000co`0co`00:3?o00X0001Woooo000@ooooo`00017oool001Koool00`000?ooooooo`06oooo00?o
09Woool000002_ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`007oooo`03o`2I
oooooooo00[oool00`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo02Woool0
0`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo01Goool001ooool00ol0VOoo
ooooo`1Roooo00<0003oooooool0VOooo`007oooo`03o`2Ioooooooo06;oool00`000?ooooooo`2I
oooo000Ooooo00?o09Woooooool0H_ooo`80002Joooo000Ooooo00?o09Woooooool0H_ooo`030000
oooooooo09Woool001ooool00ol0VOooooooo`1Roooo00<0003oooooool0VOooo`007oooo`03o`2I
oooooooo06;oool00`000?ooooooo`2Ioooo000Ooooo00?o09Woooooool0H_ooo`80002Joooo000O
oooo00?o09Woooooool0H_ooo`030000oooooooo09Woool001ooool00ol0VOooooooo`1Roooo00<0
003oooooool0VOooo`007oooo`03o`2Ioooooooo06;oool00`000?ooooooo`2Ioooo000Ooooo00?o
09Woooooool0H_ooo`030000oooooooo09Woool001ooool00ol0VOooooooo`1Roooo0P0009[oool0
01ooool00ol0VOooooooo`1Roooo00<0003oooooool0VOooo`007oooo`03o`2Ioooooooo06;oool0
0`000?ooooooo`2Ioooo000Ooooo00?o09Woooooool0H_ooo`030000oooooooo09Woool001ooool0
0ol0VOooooooo`1Roooo0P0009[oool001ooool00ol0VOooooooo`1Roooo00<0003oooooool0VOoo
o`007oooo`03o`2Ioooooooo06;oool00`000?ooooooo`2Ioooo000Ooooo00?o09Woooooool0F_oo
o`D00003oooo00<0003oooooool0VOooo`007oooo`03o`2Ioooooooo05coool00`000?ooooooo`03
oooo00<0003oooooool0VOooo`007oooo`03o`2Ioooooooo05coool00`000?ooooooo`03oooo0`00
09Woool001ooool00ol0VOooooooo`1Loooo00<0003oooooool00oooo`030000oooooooo09Woool0
01ooool00ol0VOooooooo`1Loooo00<0003oooooool00oooo`030000oooooooo09Woool001ooool0
0ol0VOooooooo`1Koooo0P0000Goool00`000?ooooooo`2Ioooo000Ooooo00?o09Woooooool0H_oo
o`80002Joooo000Ooooo00?o09Woooooool0H_ooo`030000oooooooo09Woool001ooool00ol0VOoo
ooooo`1Roooo00<0003oooooool0VOooo`007oooo`03o`2Ioooooooo06;oool00`000?ooooooo`2I
oooo000Ooooo00?o09Woooooool0H_ooo`030000oooooooo09Woool001ooool00ol0VOooooooo`1R
oooo0P0009[oool001ooool00ol0VOooooooo`1Roooo00<0003oooooool0VOooo`007oooo`03o`2I
oooooooo06;oool00`000?ooooooo`2Ioooo000Ooooo00?o09Woooooool0H_ooo`030000oooooooo
09Woool001ooool00ol0VOooooooo`1Roooo0P0009[oool001ooool00ol0VOooooooo`1Roooo00<0
003oooooool0VOooo`007oooo`03o`2Ioooooooo06;oool00`000?ooooooo`2Ioooo000Ooooo00?o
09Woooooool0H_ooo`030000oooooooo09Woool001ooool00ol0VOooooooo`1Roooo00<0003ooooo
ool0VOooo`007oooo`03o`2Ioooooooo06;oool20000V_ooo`007oooo`03o`2Ioooooooo06;oool0
0`000?ooooooo`2Ioooo000Ooooo00?o09Woooooool0F_ooo`@00004oooo00<0003oooooool0VOoo
o`007oooo`03o`2Ioooooooo05[oool00`000?ooooooo`05oooo00<0003oooooool0VOooo`007ooo
o`03o`2Ioooooooo05_oool00`000?ooooooo`04oooo0`0009Woool001ooool00ol0VOooooooo`1L
oooo00<0003oooooool00oooo`030000oooooooo09Woool001ooool00ol0VOooooooo`1Joooo00@0
003oooooool00004oooo00<0003oooooool0VOooo`007oooo`03o`2Ioooooooo05_oool200001Ooo
o`030000oooooooo09Woool001ooool00ol0VOooooooo`1Roooo0P0009[oool001ooool00ol0VOoo
ooooo`1Roooo00<0003oooooool0VOooo`007oooo`03o`2Ioooooooo06;oool00`000?ooooooo`2I
oooo000Ooooo00?o09Woooooool0H_ooo`030000oooooooo09Woool001ooool00ol0VOooooooo`1R
oooo00<0003oooooool0VOooo`007oooo`03o`2Ioooooooo06;oool20000V_ooo`007oooo`03o`2I
oooooooo06;oool00`000?ooooooo`2Ioooo000Ooooo00?o09Woooooool0H_ooo`030000oooooooo
09Woool001ooool00ol0VOooooooo`1Roooo00<0003oooooool0VOooo`007oooo`03o`2Ioooooooo
06;oool20000V_ooo`007oooo`03o`2Ioooooooo06;oool00`000?ooooooo`2Ioooo000Ooooo00?o
09Woooooool0H_ooo`030000oooooooo09Woool001ooool00ol0VOooooooo`1Roooo00<0003ooooo
ool0VOooo`007oooo`03o`2Ioooooooo06;oool00`000?ooooooo`2Ioooo000Ooooo00?o09Wooooo
ool0H_ooo`80002Joooo000Ooooo00?o09Woooooool0H_ooo`030000oooooooo09Woool001ooool0
0ol0VOooooooo`1Koooo0P0000Goool00`000?ooooooo`2Ioooo000Ooooo00?o09Woooooool0F_oo
o`040000oooooooo00001?ooo`030000oooooooo09Woool001ooool00ol0VOooooooo`1Loooo00<0
003oooooool00oooo`<0002Ioooo000Ooooo00?o09Woooooool0GOooo`030000oooooooo00;oool0
0`000?ooooooo`2Ioooo000Ooooo00?o09Woooooool0F_ooo`040000oooooooo00001?ooo`030000
oooooooo09Woool001ooool00ol0VOooooooo`1Koooo0P0000Goool00`000?ooooooo`2Ioooo000O
oooo00?o09Woooooool0H_ooo`030000oooooooo09Woool001ooool00ol0VOooooooo`1Roooo0P00
09[oool001ooool00ol0VOooooooo`1Roooo00<0003oooooool0VOooo`007oooo`03o`2Ioooooooo
06;oool00`000?ooooooo`2Ioooo000Ooooo00?o09Woooooool0H_ooo`030000oooooooo09Woool0
01ooool00ol0VOooooooo`1Roooo0P0009[oool001ooool00ol0VOooooooo`1Roooo00<0003ooooo
ool0VOooo`007oooo`03o`2Ioooooooo06;oool00`000?ooooooo`2Ioooo000Ooooo00?o09Wooooo
ool0H_ooo`030000oooooooo09Woool001ooool00ol0VOooooooo`1Roooo00<0003oooooool0VOoo
o`007oooo`03o`2Ioooooooo06;oool20000V_ooo`007oooo`03o`2Ioooooooo06;oool00`000?oo
ooooo`2Ioooo000Ooooo00?o09Woooooool0H_ooo`030000oooooooo09Woool001ooool00ol0VOoo
ooooo`1Roooo00<0003oooooool0VOooo`007oooo`03o`2Ioooooooo06;oool20000V_ooo`007ooo
o`03o`2Ioooooooo06;oool00`000?ooooooo`2Ioooo000Ooooo00?o09Woooooool0H_ooo`030000
oooooooo09Woool001ooool00ol0VOooooooo`1Loooo0`0000?oool00`000?ooooooo`2Ioooo000O
oooo00?o09Woooooool0GOooo`030000oooooooo00;oool00`000?ooooooo`2Ioooo000Ooooo00?o
09Woooooool0F_ooo`D00003oooo0`0009Woool007coool010000?ooooooo`000:3oool007goool0
0`000?ooo`00002Poooo001noooo0P000:3oool00?oooolQoooo003ooooo8Oooo`00NOooo`030000
oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo
01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool03Oooo`800004oooo0P0000?oool300001?ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?oo
ooooo`02oooo00<0003oooooool05_ooo`030000oooooooo00Koool010000?ooooooo`0000Coool0
0`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001?oool200002Oooo`<00004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000001Koool00`000?ooooooo`09oooo00<0
003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0`0000Woool3
00000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.04262 .26487 L
.06244 .26487 L
.06747 .26487 L
.07024 .26487 L
.07286 .26487 L
.07404 .26487 L
.07529 .26487 L
s
.07529 .26487 m
.07555 .61803 L
s
0 .4 1 r
.02381 .17411 m
.04262 .1521 L
.06244 .12309 L
.06747 .11461 L
.07024 .10974 L
.07286 .10498 L
.07404 .10279 L
.07529 .10042 L
.07594 .26487 L
.07666 .26487 L
.07793 .26487 L
.08255 .26487 L
.10458 .26487 L
.14487 .26487 L
.18364 .26487 L
.22486 .26487 L
.26457 .26487 L
.30277 .26487 L
.34341 .26487 L
.38254 .26487 L
.42412 .26487 L
.46419 .26487 L
.50274 .26487 L
.54374 .26487 L
.58323 .26487 L
.6212 .26487 L
.66163 .26487 L
.70054 .26487 L
.7419 .26487 L
.78174 .26487 L
.82007 .26487 L
.86085 .26487 L
.90012 .26487 L
.93787 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool002?oool00`1Vooooooooo`1@oooo00<0000co`0c
o`002S?o0080002Koooo000Soooo00<0I_ooooooool0Coooo`030000<ol0<ol000`co`020000V_oo
o`008_ooo`80I_m@oooo00<0000co`0co`003C?o00030000oooooooo09Woool0027oool00`1Voooo
o`1Vo`1?oooo00<0000co`0co`003S?o0080002Joooo000Poooo00@0I_ooooooool0I_m?oooo00<0
000co`0co`003S?o00030000<ol0000009Woool0023oool0101Vooooooooo`1Vodkoool00`0003?o
03?o000?<ol00P000003<ol00000oooo09Ooool001ooool01@1Vooooooooooooo`1Vo`1>oooo00<0
000co`0co`003c?o00040000<ol0<ol00000V?ooo`007oooo`0506Kooooooooooooo06Ko04goool0
0`0003?o03?o000@<ol000D0000co`0co`0co`000000Uoooo`007_ooo`0306Kooooooooo00;oool0
0`1Vooooooooo`1;oooo00<0000co`0co`0043?o00030000<ol0<ol0008co`000`000?ooooooo`2D
oooo000Moooo00<0I_ooooooool00oooo`0306Kooooooooo04[oool00`0003?o03?o000A<ol000<0
000co`0co`000S?o00030000oooooooo09Coool001goool00`1Vooooooooo`03oooo00<0I_oooooo
ool0BOooo`030000<ol0<ol0018co`02000013?o00030000oooooooo09?oool001coool00`1Voooo
ooooo`04oooo00<0I_ooooooool0B?ooo`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0
003oooooool0T_ooo`007?ooo`0306Kooooooooo00Coool00`1Vooooooooo`18oooo00<0000co`0c
o`004c?o00030000<ol0<ol000@co`000`000?ooooooo`2Boooo000Koooo00<0I_ooooooool01Ooo
o`0306Kooooooooo04Ooool00`0003?o03?o000D<ol000<0000co`0co`001C?o00030000oooooooo
097oool001[oool00`1Vooooooooo`06oooo00<0I_ooooooool0A_ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool001Woool00`1Vooooooooo`07oooo00<0I_ooooooool0AOoo
o`030000<ol0<ol001Hco`000`0003?o03?o0006<ol000<0003oooooool0T?ooo`006?ooo`0306Ko
oooooooo00Soool00`1Vooooooooo`15oooo00<0000co`0co`005S?o00030000<ol0<ol000Lco`00
0`000?ooooooo`2?oooo000Goooo00<0I_ooooooool02Oooo`0306Kooooooooo04Coool00`0003?o
03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0003oooooool0S_ooo`005_ooo`0306Ko
oooooooo00[oool00`1Vooooooooo`13oooo00<0000co`0co`004S?o00030000<ol0<ol000<co`00
0`0003?o03?o0008<ol000<0003oooooool0S_ooo`008oooo`0306Kooooooooo04;oool00`0003?o
03?o000C<ol000<0000co`0co`000c?o00<00009<ol000<0003oooooool0SOooo`008oooo`0306Ko
oooooooo04;oool00`0003?o03?o000;<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`002S?o00030000oooooooo08coool002?oool00`1Vooooooooo`11oooo00<0000co`0co`0053?o
00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003oooooool0Roooo`008oooo`0306Ko
oooooooo043oool00`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003ooooo
ool0Roooo`008oooo`0306Kooooooooo043oool00`0003?o03?o000K<ol00P0000dco`000`000?oo
ooooo`2:oooo000Soooo00<0I_ooooooool0?oooo`030000<ol0<ol001`co`000`0003?o03?o000=
<ol000<0003oooooool0ROooo`008oooo`0306Kooooooooo03koool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool002?oool00`1Vooooooooo`0moooo00<0000co`0c
o`007S?o00030000<ol0<ol000lco`000`000?ooooooo`27oooo000Soooo00<0I_ooooooool0?Ooo
o`030000<ol0<ol001hco`000`0003?o03?o000@<ol000<0003oooooool0Q_ooo`008oooo`0306Ko
oooooooo03coool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25oooo000Soooo00<0
I_ooooooool0>oooo`030000<ol0<ol0020co`000`0003?o03?o000B<ol000<0003oooooool0Q?oo
o`008oooo`0306Kooooooooo00Woool300009oooo`@00002oooo0P0002<co`000`0003?o03?o000C
<ol000<0003oooooool04Oooo`@0000Zoooo0`0002Ooool300005oooo`008oooo`0306Kooooooooo
00[oool00`000?ooooooo`0Voooo00<0003oooooool00_ooo`030000<ol0<ol002<co`000`0003?o
03?o000D<ol000<0003oooooool04?ooo`030000oooooooo02coool00`000?ooooooo`0Voooo00@0
003oooooool0000Foooo000Soooo00<0I_ooooooool01oooo`D0000Xoooo00@0003oooooool0000V
<ol00P0001Hco`0200004Oooo`030000oooooooo02Soool500009oooo`040000oooooooo00005_oo
o`008oooo`0406Kooooooooooooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W
<ol000<0000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003ooooo
ool0000Xoooo0`0001Ooool002?oool00`1Vooooooooo`08oooo00<0003oool00000:?ooo`800000
0c?o000003?o000V<ol000<0000co`0co`0063?o00030000oooooooo00coool010000?ooooooo`00
02Woool00`000?ooo`00000Yoooo00<0003oooooool05_ooo`008oooo`0306Kooooooooo00Woool2
00009oooo`@0000X<ol000<0000co`0co`006C?o00030000oooooooo00coool20000:oooo`80000Y
oooo0`0001Koool002?oool00`1Vooooooooo`0`oooo0P0002`co`000`0003?o03?o000J<ol00P00
07goool002?oool00`1Vooooooooo`0^oooo0P0002hco`0200007C?o00<0001joooo000Soooo00<0
I_ooooooool0:oooo`<0000`<ol000<0000co`0co`007c?o00H0001doooo000Soooo00<0I_oooooo
ool09Oooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo000Soooo00<0I_ooooooool06ooo
o`X0000i<ol000<0000co`0co`00:3?o00X0001Woooo000@ooooo`00017oool001Koool00`000?oo
ooooo`08oooo00<0003ooooo09T02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Ooo
o`008oooo`03o`2Ioooooooo00Koool00`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000
oooooooo02Woool00`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo01Goool0
02?oool00ol0VOooooooo`1Noooo00<0003oooooool0VOooo`008oooo`03o`2Ioooooooo05koool0
0`000?ooooooo`2Ioooo000Soooo00?o09Woooooool0G_ooo`80002Joooo000Soooo00?o09Wooooo
ool0G_ooo`030000oooooooo09Woool002?oool00ol0VOooooooo`1Noooo00<0003oooooool0VOoo
o`008oooo`03o`2Ioooooooo05koool00`000?ooooooo`2Ioooo000Soooo00?o09Woooooool0G_oo
o`80002Joooo000Soooo00?o09Woooooool0G_ooo`030000oooooooo09Woool002?oool00ol0VOoo
ooooo`1Noooo00<0003oooooool0VOooo`008oooo`03o`2Ioooooooo05koool00`000?ooooooo`2I
oooo000Soooo00?o09Woooooool0G_ooo`030000oooooooo09Woool002?oool00ol0VOooooooo`1N
oooo0P0009[oool002?oool00ol0VOooooooo`1Noooo00<0003oooooool0VOooo`008oooo`03o`2I
oooooooo05koool00`000?ooooooo`2Ioooo000Soooo00?o09Woooooool0G_ooo`030000oooooooo
09Woool002?oool00ol0VOooooooo`1Noooo0P0009[oool002?oool00ol0VOooooooo`1Noooo00<0
003oooooool0VOooo`008oooo`03o`2Ioooooooo05koool00`000?ooooooo`2Ioooo000Soooo00?o
09Woooooool0E_ooo`D00003oooo00<0003oooooool0VOooo`008oooo`03o`2Ioooooooo05Soool0
0`000?ooooooo`03oooo00<0003oooooool0VOooo`008oooo`03o`2Ioooooooo05Soool00`000?oo
ooooo`03oooo0`0009Woool002?oool00ol0VOooooooo`1Hoooo00<0003oooooool00oooo`030000
oooooooo09Woool002?oool00ol0VOooooooo`1Hoooo00<0003oooooool00oooo`030000oooooooo
09Woool002?oool00ol0VOooooooo`1Goooo0P0000Goool00`000?ooooooo`2Ioooo000Soooo00?o
09Woooooool0G_ooo`80002Joooo000Soooo00?o09Woooooool0G_ooo`030000oooooooo09Woool0
02?oool00ol0VOooooooo`1Noooo00<0003oooooool0VOooo`008oooo`03o`2Ioooooooo05koool0
0`000?ooooooo`2Ioooo000Soooo00?o09Woooooool0G_ooo`030000oooooooo09Woool002?oool0
0ol0VOooooooo`1Noooo0P0009[oool002?oool00ol0VOooooooo`1Noooo00<0003oooooool0VOoo
o`008oooo`03o`2Ioooooooo05koool00`000?ooooooo`2Ioooo000Soooo00?o09Woooooool0G_oo
o`030000oooooooo09Woool002?oool00ol0VOooooooo`1Noooo0P0009[oool002?oool00ol0VOoo
ooooo`1Noooo00<0003oooooool0VOooo`008oooo`03o`2Ioooooooo05koool00`000?ooooooo`2I
oooo000Soooo00?o09Woooooool0G_ooo`030000oooooooo09Woool002?oool00ol0VOooooooo`1N
oooo00<0003oooooool0VOooo`008oooo`03o`2Ioooooooo05koool20000V_ooo`008oooo`03o`2I
oooooooo05koool00`000?ooooooo`2Ioooo000Soooo00?o09Woooooool0E_ooo`@00004oooo00<0
003oooooool0VOooo`008oooo`03o`2Ioooooooo05Koool00`000?ooooooo`05oooo00<0003ooooo
ool0VOooo`008oooo`03o`2Ioooooooo05Ooool00`000?ooooooo`04oooo0`0009Woool002?oool0
0ol0VOooooooo`1Hoooo00<0003oooooool00oooo`030000oooooooo09Woool002?oool00ol0VOoo
ooooo`1Foooo00@0003oooooool00004oooo00<0003oooooool0VOooo`008oooo`03o`2Ioooooooo
05Ooool200001Oooo`030000oooooooo09Woool002?oool00ol0VOooooooo`1Noooo0P0009[oool0
02?oool00ol0VOooooooo`1Noooo00<0003oooooool0VOooo`008oooo`03o`2Ioooooooo05koool0
0`000?ooooooo`2Ioooo000Soooo00?o09Woooooool0G_ooo`030000oooooooo09Woool002?oool0
0ol0VOooooooo`1Noooo00<0003oooooool0VOooo`008oooo`03o`2Ioooooooo05koool20000V_oo
o`008oooo`03o`2Ioooooooo05koool00`000?ooooooo`2Ioooo000Soooo00?o09Woooooool0G_oo
o`030000oooooooo09Woool002?oool00ol0VOooooooo`1Noooo00<0003oooooool0VOooo`008ooo
o`03o`2Ioooooooo05koool20000V_ooo`008oooo`03o`2Ioooooooo05koool00`000?ooooooo`2I
oooo000Soooo00?o09Woooooool0G_ooo`030000oooooooo09Woool002?oool00ol0VOooooooo`1N
oooo00<0003oooooool0VOooo`008oooo`03o`2Ioooooooo05koool00`000?ooooooo`2Ioooo000S
oooo00?o09Woooooool0G_ooo`80002Joooo000Soooo00?o09Woooooool0G_ooo`030000oooooooo
09Woool002?oool00ol0VOooooooo`1Goooo0P0000Goool00`000?ooooooo`2Ioooo000Soooo00?o
09Woooooool0E_ooo`040000oooooooo00001?ooo`030000oooooooo09Woool002?oool00ol0VOoo
ooooo`1Hoooo00<0003oooooool00oooo`<0002Ioooo000Soooo00?o09Woooooool0FOooo`030000
oooooooo00;oool00`000?ooooooo`2Ioooo000Soooo00?o09Woooooool0E_ooo`040000oooooooo
00001?ooo`030000oooooooo09Woool002?oool00ol0VOooooooo`1Goooo0P0000Goool00`000?oo
ooooo`2Ioooo000Soooo00?o09Woooooool0G_ooo`030000oooooooo09Woool002?oool00ol0VOoo
ooooo`1Noooo0P0009[oool002?oool00ol0VOooooooo`1Noooo00<0003oooooool0VOooo`008ooo
o`03o`2Ioooooooo05koool00`000?ooooooo`2Ioooo000Soooo00?o09Woooooool0G_ooo`030000
oooooooo09Woool002?oool00ol0VOooooooo`1Noooo0P0009[oool002?oool00ol0VOooooooo`1N
oooo00<0003oooooool0VOooo`008oooo`03o`2Ioooooooo05koool00`000?ooooooo`2Ioooo000S
oooo00?o09Woooooool0G_ooo`030000oooooooo09Woool002?oool00ol0VOooooooo`1Noooo00<0
003oooooool0VOooo`008oooo`03o`2Ioooooooo05koool20000V_ooo`008oooo`03o`2Ioooooooo
05koool00`000?ooooooo`2Ioooo000Soooo00?o09Woooooool0G_ooo`030000oooooooo09Woool0
02?oool00ol0VOooooooo`1Noooo00<0003oooooool0VOooo`008oooo`03o`2Ioooooooo05koool2
0000V_ooo`008oooo`03o`2Ioooooooo05koool00`000?ooooooo`2Ioooo000Soooo00?o09Wooooo
ool0G_ooo`030000oooooooo09Woool002?oool00ol0VOooooooo`1Hoooo0`0000?oool00`000?oo
ooooo`2Ioooo000Soooo00?o09Woooooool0FOooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo000Soooo00?o09Woooooool0E_ooo`D00003oooo0`0009Woool007coool010000?ooooooo`00
0:3oool007goool00`000?ooo`00002Poooo001noooo0P000:3oool00?oooolQoooo003ooooo8Ooo
o`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?oo
o`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool03Oooo`800004oooo0P0000Goool300000_ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool4
00000oooo`040000oooooooo00002oooo`050000oooooooooooo000007[oool007Ooool00`000?oo
ooooo`02oooo00<0003oooooool05_ooo`030000oooooooo00Koool500000oooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500004oooo`800009oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000001Koool00`000?ooooooo`09oooo00<0
003oool000000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0`0000[oool2
00000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.04262 .26487 L
.06244 .26487 L
.07216 .26487 L
.08255 .26487 L
.08562 .26487 L
.08852 .26487 L
.09113 .26487 L
.09184 .26487 L
.0926 .26487 L
s
.0926 .26487 m
.09286 .61803 L
s
0 .4 1 r
.02381 .19057 m
.04262 .17254 L
.06244 .14879 L
.07216 .13501 L
.08255 .11846 L
.08562 .11318 L
.08852 .10802 L
.09113 .10323 L
.09184 .10189 L
.0926 .10046 L
.09325 .26487 L
.09396 .26487 L
.10458 .26487 L
.14487 .26487 L
.18364 .26487 L
.22486 .26487 L
.26457 .26487 L
.30277 .26487 L
.34341 .26487 L
.38254 .26487 L
.42412 .26487 L
.46419 .26487 L
.50274 .26487 L
.54374 .26487 L
.58323 .26487 L
.6212 .26487 L
.66163 .26487 L
.70054 .26487 L
.7419 .26487 L
.78174 .26487 L
.82007 .26487 L
.86085 .26487 L
.90012 .26487 L
.93787 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool002Ooool206KoCOooo`030000<ol0<ol000Xco`02
0000Voooo`009oooo`80I_m<oooo00<0000co`0co`0033?o0080002Joooo000Voooo00<0I_ooool0
I_l0Boooo`030000<ol0<ol000dco`000`000?ooooooo`2Ioooo000Voooo00<0I_ooool0I_l0B_oo
o`030000<ol0<ol000hco`020000V_ooo`009Oooo`0406Kooooooooo06KoB_ooo`030000<ol0<ol0
00hco`000`0003?o0000002Ioooo000Toooo00D0I_ooooooooooool0I_l0BOooo`030000<ol0<ol0
00lco`02000000<co`00003oool0Uoooo`008oooo`0306Kooooooooo00;oool00`1Vooooooooo`17
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`008oooo`0306Kooooooooo00;oool0
0`1Vooooooooo`16oooo00<0000co`0co`0043?o00050000<ol0<ol0<ol0000009Ooool002;oool0
0`1Vooooooooo`03oooo00<0I_ooooooool0A_ooo`030000<ol0<ol0010co`000`0003?o03?o0002
<ol000<0003oooooool0U?ooo`008Oooo`0306Kooooooooo00Coool00`1Vooooooooo`15oooo00<0
000co`0co`004C?o00030000<ol0<ol0008co`000`000?ooooooo`2Doooo000Qoooo00<0I_oooooo
ool01?ooo`0306Kooooooooo04Coool00`0003?o03?o000B<ol00P0000@co`000`000?ooooooo`2C
oooo000Poooo00<0I_ooooooool01Oooo`0306Kooooooooo04?oool00`0003?o03?o000C<ol000<0
000co`0co`0013?o00030000oooooooo09;oool0023oool00`1Vooooooooo`05oooo00<0I_oooooo
ool0@oooo`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`007ooo
o`0306Kooooooooo00Koool00`1Vooooooooo`12oooo00<0000co`0co`0053?o00030000<ol0<ol0
00Dco`000`000?ooooooo`2Aoooo000Noooo00<0I_ooooooool01oooo`0306Kooooooooo047oool0
0`0003?o03?o000E<ol00P0000Lco`000`000?ooooooo`2@oooo000Moooo00<0I_ooooooool02?oo
o`0306Kooooooooo043oool00`0003?o03?o000F<ol000<0000co`0co`001S?o00030000oooooooo
093oool001goool00`1Vooooooooo`08oooo00<0I_ooooooool0@?ooo`030000<ol0<ol001Hco`00
0`0003?o03?o0007<ol000<0003oooooool0Soooo`007?ooo`0306Kooooooooo00Woool00`1Voooo
ooooo`0ooooo00<0000co`0co`003c?o00D00003<ol000<0000co`0co`0023?o00030000oooooooo
08koool001_oool00`1Vooooooooo`0:oooo00<0I_ooooooool0?_ooo`030000<ol0<ol0018co`00
0`0003?o03?o0003<ol000<0000co`0co`0023?o00030000oooooooo08koool001[oool00`1Voooo
ooooo`0;oooo00<0I_ooooooool0?Oooo`030000<ol0<ol001<co`000`0003?o03?o0003<ol00`00
00Tco`000`000?ooooooo`2=oooo000Hoooo0P1Vo`koool00`1Vooooooooo`0moooo00<0000co`0c
o`002c?o00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000Xco`000`000?ooooooo`2<
oooo000Goooo00<0I_ooooooool03_ooo`0306Kooooooooo03coool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`2;oooo000Foooo00<0I_oooooo
ool03oooo`0306Kooooooooo03_oool00`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;
<ol000<0003oooooool0Roooo`00:?ooo`0306Kooooooooo03_oool00`0003?o03?o000K<ol00P00
00dco`000`000?ooooooo`2:oooo000Xoooo00<0I_ooooooool0>_ooo`030000<ol0<ol001`co`00
0`0003?o03?o000=<ol000<0003oooooool0ROooo`00:?ooo`0306Kooooooooo03Woool00`0003?o
03?o000M<ol000<0000co`0co`003S?o00030000oooooooo08Soool002Soool00`1Vooooooooo`0h
oooo00<0000co`0co`007S?o00030000<ol0<ol000lco`000`000?ooooooo`27oooo000Xoooo00<0
I_ooooooool0>?ooo`030000<ol0<ol001hco`000`0003?o03?o000@<ol000<0003oooooool0Q_oo
o`00:?ooo`0306Kooooooooo03Ooool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo000Xoooo00<0I_ooooooool0=_ooo`030000<ol0<ol0020co`000`0003?o03?o000B<ol000<0
003oooooool0Q?ooo`00:?ooo`0306Kooooooooo00Coool300009oooo`@00002oooo0P0002<co`00
0`0003?o03?o000C<ol000<0003oooooool04Oooo`@0000Zoooo0`0002Ooool300005oooo`00:?oo
o`0306Kooooooooo00Goool00`000?ooooooo`0Voooo00<0003oooooool00_ooo`030000<ol0<ol0
02<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo02coool00`000?oo
ooooo`0Voooo00@0003oooooool0000Foooo000Xoooo00<0I_ooooooool00_ooo`D0000Xoooo00@0
003oooooool0000V<ol00P0001Hco`0200004Oooo`030000oooooooo02Soool500009oooo`040000
oooooooo00005_ooo`009oooo`@00002oooo00@0003oooooool0000Roooo100000Coool200009c?o
00030000<ol0<ol001Lco`000`000?ooooooo`0?oooo00<0003oooooool09oooo`040000oooooooo
0000:?ooo`<0000Goooo000Xoooo00<0I_ooooooool00oooo`030000oooo000002Soool2000000<c
o`00000co`009S?o00030000<ol0<ol001Pco`000`000?ooooooo`0<oooo00@0003oooooool0000Y
oooo00<0003oool00000:Oooo`030000oooooooo01Koool002Soool00`1Vooooooooo`04oooo0P00
02Ooool40000:3?o00030000<ol0<ol001Tco`000`000?ooooooo`0<oooo0P0002_oool20000:Ooo
o`<0000Foooo000Xoooo00<0I_ooooooool0:oooo`80000/<ol000<0000co`0co`006S?o0080001m
oooo000Xoooo00<0I_ooooooool0:Oooo`80000^<ol00P0001dco`030000N_ooo`00:?ooo`0306Ko
oooooooo02Koool30000<3?o00030000<ol0<ol001lco`060000M?ooo`00:?ooo`0306Kooooooooo
023oool60000<c?o00030000<ol0<ol002Dco`030000LOooo`00:?ooo`0306Kooooooooo01Koool:
0000>C?o00030000<ol0<ol002Pco`0:0000Ioooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool02?ooo`030000oooooooo00Coool01Ol0VOooooooooooo`00000:oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
01Goool002Soool01Ol0VOooooooooooo`00000[oooo00<0003oooooool0:Oooo`030000oooooooo
02Woool00`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo01Goool002Soool0
0ol0VOooooooo`1Ioooo00<0003oooooool0VOooo`00:?ooo`03o`2Ioooooooo05Woool00`000?oo
ooooo`2Ioooo000Xoooo00?o09Woooooool0FOooo`80002Joooo000Xoooo00?o09Woooooool0FOoo
o`030000oooooooo09Woool002Soool00ol0VOooooooo`1Ioooo00<0003oooooool0VOooo`00:?oo
o`03o`2Ioooooooo05Woool00`000?ooooooo`2Ioooo000Xoooo00?o09Woooooool0FOooo`80002J
oooo000Xoooo00?o09Woooooool0FOooo`030000oooooooo09Woool002Soool00ol0VOooooooo`1I
oooo00<0003oooooool0VOooo`00:?ooo`03o`2Ioooooooo05Woool00`000?ooooooo`2Ioooo000X
oooo00?o09Woooooool0FOooo`030000oooooooo09Woool002Soool00ol0VOooooooo`1Ioooo0P00
09[oool002Soool00ol0VOooooooo`1Ioooo00<0003oooooool0VOooo`00:?ooo`03o`2Ioooooooo
05Woool00`000?ooooooo`2Ioooo000Xoooo00?o09Woooooool0FOooo`030000oooooooo09Woool0
02Soool00ol0VOooooooo`1Ioooo0P0009[oool002Soool00ol0VOooooooo`1Ioooo00<0003ooooo
ool0VOooo`00:?ooo`03o`2Ioooooooo05Woool00`000?ooooooo`2Ioooo000Xoooo00?o09Wooooo
ool0DOooo`D00003oooo00<0003oooooool0VOooo`00:?ooo`03o`2Ioooooooo05?oool00`000?oo
ooooo`03oooo00<0003oooooool0VOooo`00:?ooo`03o`2Ioooooooo05?oool00`000?ooooooo`03
oooo0`0009Woool002Soool00ol0VOooooooo`1Coooo00<0003oooooool00oooo`030000oooooooo
09Woool002Soool00ol0VOooooooo`1Coooo00<0003oooooool00oooo`030000oooooooo09Woool0
02Soool00ol0VOooooooo`1Boooo0P0000Goool00`000?ooooooo`2Ioooo000Xoooo00?o09Wooooo
ool0FOooo`80002Joooo000Xoooo00?o09Woooooool0FOooo`030000oooooooo09Woool002Soool0
0ol0VOooooooo`1Ioooo00<0003oooooool0VOooo`00:?ooo`03o`2Ioooooooo05Woool00`000?oo
ooooo`2Ioooo000Xoooo00?o09Woooooool0FOooo`030000oooooooo09Woool002Soool00ol0VOoo
ooooo`1Ioooo0P0009[oool002Soool00ol0VOooooooo`1Ioooo00<0003oooooool0VOooo`00:?oo
o`03o`2Ioooooooo05Woool00`000?ooooooo`2Ioooo000Xoooo00?o09Woooooool0FOooo`030000
oooooooo09Woool002Soool00ol0VOooooooo`1Ioooo0P0009[oool002Soool00ol0VOooooooo`1I
oooo00<0003oooooool0VOooo`00:?ooo`03o`2Ioooooooo05Woool00`000?ooooooo`2Ioooo000X
oooo00?o09Woooooool0FOooo`030000oooooooo09Woool002Soool00ol0VOooooooo`1Ioooo00<0
003oooooool0VOooo`00:?ooo`03o`2Ioooooooo05Woool20000V_ooo`00:?ooo`03o`2Ioooooooo
05Woool00`000?ooooooo`2Ioooo000Xoooo00?o09Woooooool0DOooo`@00004oooo00<0003ooooo
ool0VOooo`00:?ooo`03o`2Ioooooooo057oool00`000?ooooooo`05oooo00<0003oooooool0VOoo
o`00:?ooo`03o`2Ioooooooo05;oool00`000?ooooooo`04oooo0`0009Woool002Soool00ol0VOoo
ooooo`1Coooo00<0003oooooool00oooo`030000oooooooo09Woool002Soool00ol0VOooooooo`1A
oooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00:?ooo`03o`2Ioooooooo05;oool2
00001Oooo`030000oooooooo09Woool002Soool00ol0VOooooooo`1Ioooo0P0009[oool002Soool0
0ol0VOooooooo`1Ioooo00<0003oooooool0VOooo`00:?ooo`03o`2Ioooooooo05Woool00`000?oo
ooooo`2Ioooo000Xoooo00?o09Woooooool0FOooo`030000oooooooo09Woool002Soool00ol0VOoo
ooooo`1Ioooo00<0003oooooool0VOooo`00:?ooo`03o`2Ioooooooo05Woool20000V_ooo`00:?oo
o`03o`2Ioooooooo05Woool00`000?ooooooo`2Ioooo000Xoooo00?o09Woooooool0FOooo`030000
oooooooo09Woool002Soool00ol0VOooooooo`1Ioooo00<0003oooooool0VOooo`00:?ooo`03o`2I
oooooooo05Woool20000V_ooo`00:?ooo`03o`2Ioooooooo05Woool00`000?ooooooo`2Ioooo000X
oooo00?o09Woooooool0FOooo`030000oooooooo09Woool002Soool00ol0VOooooooo`1Ioooo00<0
003oooooool0VOooo`00:?ooo`03o`2Ioooooooo05Woool00`000?ooooooo`2Ioooo000Xoooo00?o
09Woooooool0FOooo`80002Joooo000Xoooo00?o09Woooooool0FOooo`030000oooooooo09Woool0
02Soool00ol0VOooooooo`1Boooo0P0000Goool00`000?ooooooo`2Ioooo000Xoooo00?o09Wooooo
ool0DOooo`040000oooooooo00001?ooo`030000oooooooo09Woool002Soool00ol0VOooooooo`1C
oooo00<0003oooooool00oooo`<0002Ioooo000Xoooo00?o09Woooooool0E?ooo`030000oooooooo
00;oool00`000?ooooooo`2Ioooo000Xoooo00?o09Woooooool0DOooo`040000oooooooo00001?oo
o`030000oooooooo09Woool002Soool00ol0VOooooooo`1Boooo0P0000Goool00`000?ooooooo`2I
oooo000Xoooo00?o09Woooooool0FOooo`030000oooooooo09Woool002Soool00ol0VOooooooo`1I
oooo0P0009[oool002Soool00ol0VOooooooo`1Ioooo00<0003oooooool0VOooo`00:?ooo`03o`2I
oooooooo05Woool00`000?ooooooo`2Ioooo000Xoooo00?o09Woooooool0FOooo`030000oooooooo
09Woool002Soool00ol0VOooooooo`1Ioooo0P0009[oool002Soool00ol0VOooooooo`1Ioooo00<0
003oooooool0VOooo`00:?ooo`03o`2Ioooooooo05Woool00`000?ooooooo`2Ioooo000Xoooo00?o
09Woooooool0FOooo`030000oooooooo09Woool002Soool00ol0VOooooooo`1Ioooo00<0003ooooo
ool0VOooo`00:?ooo`03o`2Ioooooooo05Woool20000V_ooo`00:?ooo`03o`2Ioooooooo05Woool0
0`000?ooooooo`2Ioooo000Xoooo00?o09Woooooool0FOooo`030000oooooooo09Woool002Soool0
0ol0VOooooooo`1Ioooo00<0003oooooool0VOooo`00:?ooo`03o`2Ioooooooo05Woool20000V_oo
o`00:?ooo`03o`2Ioooooooo05Woool00`000?ooooooo`2Ioooo000Xoooo00?o09Woooooool0FOoo
o`030000oooooooo09Woool002Soool00ol0VOooooooo`1Coooo0`0000?oool00`000?ooooooo`2I
oooo000Xoooo00?o09Woooooool0E?ooo`030000oooooooo00;oool00`000?ooooooo`2Ioooo000X
oooo00?o09Woooooool0DOooo`D00003oooo0`0009Woool007coool010000?ooooooo`000:3oool0
07goool00`000?ooo`00002Poooo001noooo0P000:3oool00?oooolQoooo003ooooo8Oooo`00NOoo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03Oooo`800004oooo0P0000?oool400000oooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000ooo
o`040000oooooooo00002?ooo`030000oooooooo00Coool00`000?ooooooo`1hoooo001goooo00<0
003oooooool00_ooo`030000oooooooo01Koool00`000?ooooooo`07oooo00<0003oooooool01?oo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500004oooo`80000;oooo00<0003ooooo
ool00_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Foooo00<0003ooooo
ool02?ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0G
oooo0`0000Woool200000oooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.08255 .26487 L
.0932 .26487 L
.09905 .26487 L
.10458 .26487 L
.10708 .26487 L
.10844 .26487 L
.10972 .26487 L
.11039 .26487 L
s
.11039 .26487 m
.11068 .61803 L
s
0 .4 1 r
.02381 .20404 m
.04262 .18928 L
.06244 .16983 L
.08255 .145 L
.09409 .12794 L
.09912 .11975 L
.10458 .11031 L
.10712 .10572 L
.10851 .10315 L
.10981 .1007 L
.11092 .26487 L
.11211 .26487 L
.11464 .26487 L
.12415 .26487 L
.14509 .26487 L
.18631 .26487 L
.22602 .26487 L
.26421 .26487 L
.30486 .26487 L
.34399 .26487 L
.38557 .26487 L
.42564 .26487 L
.46419 .26487 L
.50519 .26487 L
.54468 .26487 L
.58265 .26487 L
.62308 .26487 L
.66198 .26487 L
.70335 .26487 L
.74319 .26487 L
.78152 .26487 L
.8223 .26487 L
.86157 .26487 L
.89932 .26487 L
.93952 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool002coool00`1Vooooooooo`17oooo00<0000co`0c
o`002S?o0080002Koooo000[oooo0P1VodSoool00`0003?o03?o000<<ol00P0009[oool002_oool2
06KoAoooo`030000<ol0<ol000dco`000`000?ooooooo`2Ioooo000Zoooo00<0I_ooool0I_l0A_oo
o`030000<ol0<ol000hco`020000V_ooo`00:Oooo`0406Kooooooooo06KoA_ooo`030000<ol0<ol0
00hco`000`0003?o0000002Ioooo000Yoooo00@0I_ooooooool0I_m5oooo00<0000co`0co`003c?o
008000000c?o00000?ooo`2Goooo000Xoooo00D0I_ooooooooooool0I_l0AOooo`030000<ol0<ol0
00lco`00100003?o03?o000009Soool002Soool01@1Vooooooooooooo`1Vo`14oooo00<0000co`0c
o`0043?o00050000<ol0<ol0<ol0000009Ooool002Ooool00`1Vooooooooo`02oooo00<0I_oooooo
ool0@_ooo`030000<ol0<ol0010co`000`0003?o03?o0002<ol000<0003oooooool0U?ooo`009_oo
o`0306Kooooooooo00?oool00`1Vooooooooo`11oooo00<0000co`0co`004C?o00030000<ol0<ol0
008co`000`000?ooooooo`2Doooo000Voooo00<0I_ooooooool00oooo`0306Kooooooooo043oool0
0`0003?o03?o000B<ol00P0000@co`000`000?ooooooo`2Coooo000Uoooo00<0I_ooooooool01?oo
o`0306Kooooooooo03ooool00`0003?o03?o000C<ol000<0000co`0co`0013?o00030000oooooooo
09;oool002Coool00`1Vooooooooo`05oooo00<0I_ooooooool0?oooo`030000<ol0<ol001<co`00
0`0003?o03?o0004<ol000<0003oooooool0T_ooo`008oooo`0306Kooooooooo00Koool00`1Voooo
ooooo`0noooo00<0000co`0co`0053?o00030000<ol0<ol000Dco`000`000?ooooooo`2Aoooo000R
oooo00<0I_ooooooool01oooo`0306Kooooooooo03goool00`0003?o03?o000E<ol00P0000Lco`00
0`000?ooooooo`2@oooo000Roooo00<0I_ooooooool01oooo`0306Kooooooooo03coool00`0003?o
03?o000F<ol000<0000co`0co`001S?o00030000oooooooo093oool0027oool00`1Vooooooooo`08
oooo00<0I_ooooooool0??ooo`030000<ol0<ol001Hco`000`0003?o03?o0007<ol000<0003ooooo
ool0Soooo`008?ooo`0306Kooooooooo00Woool00`1Vooooooooo`0koooo00<0000co`0co`003c?o
00D00003<ol000<0000co`0co`0023?o00030000oooooooo08koool001ooool00`1Vooooooooo`0:
oooo00<0I_ooooooool0>_ooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool001koool00`1Vooooooooo`0;oooo00<0I_ooooooool0>Ooo
o`030000<ol0<ol001<co`000`0003?o03?o0003<ol00`0000Tco`000`000?ooooooo`2=oooo000M
oooo00<0I_ooooooool03?ooo`0306Kooooooooo03Woool00`0003?o03?o000;<ol0100000@co`00
0`0003?o03?o0003<ol000<0000co`0co`002S?o00030000oooooooo08coool001coool00`1Voooo
ooooo`0=oooo00<0I_ooooooool0>?ooo`030000<ol0<ol001@co`000`0003?o03?o0003<ol000<0
000co`0co`002c?o00030000oooooooo08_oool001_oool00`1Vooooooooo`0>oooo00<0I_oooooo
ool0=oooo`030000<ol0<ol001@co`0200001C?o00030000<ol0<ol000/co`000`000?ooooooo`2;
oooo000Joooo00<0I_ooooooool03oooo`0306Kooooooooo03Ooool00`0003?o03?o000K<ol00P00
00dco`000`000?ooooooo`2:oooo000Hoooo0P1Voa;oool00`1Vooooooooo`0foooo00<0000co`0c
o`0073?o00030000<ol0<ol000dco`000`000?ooooooo`29oooo000Goooo00<0I_ooooooool04_oo
o`0306Kooooooooo03Goool00`0003?o03?o000M<ol000<0000co`0co`003S?o00030000oooooooo
08Soool001Koool00`1Vooooooooo`0Coooo00<0I_ooooooool0=?ooo`030000<ol0<ol001hco`00
0`0003?o03?o000?<ol000<0003oooooool0Qoooo`00;?ooo`0306Kooooooooo03Coool00`0003?o
03?o000N<ol000<0000co`0co`0043?o00030000oooooooo08Koool002coool00`1Vooooooooo`0c
oooo00<0000co`0co`007c?o0080000B<ol000<0003oooooool0QOooo`00;?ooo`0306Kooooooooo
03;oool00`0003?o03?o000P<ol000<0000co`0co`004S?o00030000oooooooo08Coool002coool0
0`1Vooooooooo`0300009oooo`@00002oooo0P0002<co`000`0003?o03?o000C<ol000<0003ooooo
ool04Oooo`@0000Zoooo0`0002Ooool300005oooo`00;?ooo`0506Kooooooooooooo000002Soool0
0`000?ooooooo`02oooo00<0000co`0co`008c?o00030000<ol0<ol001@co`000`000?ooooooo`0@
oooo00<0003oooooool0;?ooo`030000oooooooo02Koool010000?ooooooo`0001Koool002coool0
0`1Vo`00000000030000:?ooo`040000oooooooo00009S?o0080000F<ol00P00017oool00`000?oo
ooooo`0Xoooo1@0002Ooool010000?ooooooo`0001Koool002Ooool4000000?oool0I_l000000_oo
o`030000oooooooo023oool400001?ooo`80000W<ol000<0000co`0co`005c?o00030000oooooooo
00ooool00`000?ooooooo`0Woooo00@0003oooooool0000Xoooo0`0001Ooool002coool01@1Voooo
o`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o03?o000H<ol000<0003ooooo
ool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool00`000?ooooooo`0Foooo000/
oooo00<0I_ooooooool00P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?ooooooo`0<
oooo0P0002_oool20000:Oooo`<0000Foooo000/oooo00<0I_ooooooool09oooo`80000/<ol000<0
000co`0co`006S?o0080001moooo000/oooo00<0I_ooooooool09Oooo`80000^<ol00P0001dco`03
0000N_ooo`00;?ooo`0306Kooooooooo02;oool30000<3?o00030000<ol0<ol001lco`060000M?oo
o`00;?ooo`0306Kooooooooo01coool60000<c?o00030000<ol0<ol002Dco`030000LOooo`00;?oo
o`0306Kooooooooo01;oool:0000>C?o00030000<ol0<ol002Pco`0:0000Ioooo`004?ooool0000A
oooo000Foooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo01Goool002coool00`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000
oooooooo02Woool00`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo01Goool0
02coool00ol0VOooooooo`1Eoooo00<0003oooooool0VOooo`00;?ooo`03o`2Ioooooooo05Goool0
0`000?ooooooo`2Ioooo000/oooo00?o09Woooooool0EOooo`80002Joooo000/oooo00?o09Wooooo
ool0EOooo`030000oooooooo09Woool002coool00ol0VOooooooo`1Eoooo00<0003oooooool0VOoo
o`00;?ooo`03o`2Ioooooooo05Goool00`000?ooooooo`2Ioooo000/oooo00?o09Woooooool0EOoo
o`80002Joooo000/oooo00?o09Woooooool0EOooo`030000oooooooo09Woool002coool00ol0VOoo
ooooo`1Eoooo00<0003oooooool0VOooo`00;?ooo`03o`2Ioooooooo05Goool00`000?ooooooo`2I
oooo000/oooo00?o09Woooooool0EOooo`030000oooooooo09Woool002coool00ol0VOooooooo`1E
oooo0P0009[oool002coool00ol0VOooooooo`1Eoooo00<0003oooooool0VOooo`00;?ooo`03o`2I
oooooooo05Goool00`000?ooooooo`2Ioooo000/oooo00?o09Woooooool0EOooo`030000oooooooo
09Woool002coool00ol0VOooooooo`1Eoooo0P0009[oool002coool00ol0VOooooooo`1Eoooo00<0
003oooooool0VOooo`00;?ooo`03o`2Ioooooooo05Goool00`000?ooooooo`2Ioooo000/oooo00?o
09Woooooool0COooo`D00003oooo00<0003oooooool0VOooo`00;?ooo`03o`2Ioooooooo04ooool0
0`000?ooooooo`03oooo00<0003oooooool0VOooo`00;?ooo`03o`2Ioooooooo04ooool00`000?oo
ooooo`03oooo0`0009Woool002coool00ol0VOooooooo`1?oooo00<0003oooooool00oooo`030000
oooooooo09Woool002coool00ol0VOooooooo`1?oooo00<0003oooooool00oooo`030000oooooooo
09Woool002coool00ol0VOooooooo`1>oooo0P0000Goool00`000?ooooooo`2Ioooo000/oooo00?o
09Woooooool0EOooo`80002Joooo000/oooo00?o09Woooooool0EOooo`030000oooooooo09Woool0
02coool00ol0VOooooooo`1Eoooo00<0003oooooool0VOooo`00;?ooo`03o`2Ioooooooo05Goool0
0`000?ooooooo`2Ioooo000/oooo00?o09Woooooool0EOooo`030000oooooooo09Woool002coool0
0ol0VOooooooo`1Eoooo0P0009[oool002coool00ol0VOooooooo`1Eoooo00<0003oooooool0VOoo
o`00;?ooo`03o`2Ioooooooo05Goool00`000?ooooooo`2Ioooo000/oooo00?o09Woooooool0EOoo
o`030000oooooooo09Woool002coool00ol0VOooooooo`1Eoooo0P0009[oool002coool00ol0VOoo
ooooo`1Eoooo00<0003oooooool0VOooo`00;?ooo`03o`2Ioooooooo05Goool00`000?ooooooo`2I
oooo000/oooo00?o09Woooooool0EOooo`030000oooooooo09Woool002coool00ol0VOooooooo`1E
oooo00<0003oooooool0VOooo`00;?ooo`03o`2Ioooooooo05Goool20000V_ooo`00;?ooo`03o`2I
oooooooo05Goool00`000?ooooooo`2Ioooo000/oooo00?o09Woooooool0COooo`@00004oooo00<0
003oooooool0VOooo`00;?ooo`03o`2Ioooooooo04goool00`000?ooooooo`05oooo00<0003ooooo
ool0VOooo`00;?ooo`03o`2Ioooooooo04koool00`000?ooooooo`04oooo0`0009Woool002coool0
0ol0VOooooooo`1?oooo00<0003oooooool00oooo`030000oooooooo09Woool002coool00ol0VOoo
ooooo`1=oooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00;?ooo`03o`2Ioooooooo
04koool200001Oooo`030000oooooooo09Woool002coool00ol0VOooooooo`1Eoooo0P0009[oool0
02coool00ol0VOooooooo`1Eoooo00<0003oooooool0VOooo`00;?ooo`03o`2Ioooooooo05Goool0
0`000?ooooooo`2Ioooo000/oooo00?o09Woooooool0EOooo`030000oooooooo09Woool002coool0
0ol0VOooooooo`1Eoooo00<0003oooooool0VOooo`00;?ooo`03o`2Ioooooooo05Goool20000V_oo
o`00;?ooo`03o`2Ioooooooo05Goool00`000?ooooooo`2Ioooo000/oooo00?o09Woooooool0EOoo
o`030000oooooooo09Woool002coool00ol0VOooooooo`1Eoooo00<0003oooooool0VOooo`00;?oo
o`03o`2Ioooooooo05Goool20000V_ooo`00;?ooo`03o`2Ioooooooo05Goool00`000?ooooooo`2I
oooo000/oooo00?o09Woooooool0EOooo`030000oooooooo09Woool002coool00ol0VOooooooo`1E
oooo00<0003oooooool0VOooo`00;?ooo`03o`2Ioooooooo05Goool00`000?ooooooo`2Ioooo000/
oooo00?o09Woooooool0EOooo`80002Joooo000/oooo00?o09Woooooool0EOooo`030000oooooooo
09Woool002coool00ol0VOooooooo`1>oooo0P0000Goool00`000?ooooooo`2Ioooo000/oooo00?o
09Woooooool0COooo`040000oooooooo00001?ooo`030000oooooooo09Woool002coool00ol0VOoo
ooooo`1?oooo00<0003oooooool00oooo`<0002Ioooo000/oooo00?o09Woooooool0D?ooo`030000
oooooooo00;oool00`000?ooooooo`2Ioooo000/oooo00?o09Woooooool0COooo`040000oooooooo
00001?ooo`030000oooooooo09Woool002coool00ol0VOooooooo`1>oooo0P0000Goool00`000?oo
ooooo`2Ioooo000/oooo00?o09Woooooool0EOooo`030000oooooooo09Woool002coool00ol0VOoo
ooooo`1Eoooo0P0009[oool002coool00ol0VOooooooo`1Eoooo00<0003oooooool0VOooo`00;?oo
o`03o`2Ioooooooo05Goool00`000?ooooooo`2Ioooo000/oooo00?o09Woooooool0EOooo`030000
oooooooo09Woool002coool00ol0VOooooooo`1Eoooo0P0009[oool002coool00ol0VOooooooo`1E
oooo00<0003oooooool0VOooo`00;?ooo`03o`2Ioooooooo05Goool00`000?ooooooo`2Ioooo000/
oooo00?o09Woooooool0EOooo`030000oooooooo09Woool002coool00ol0VOooooooo`1Eoooo00<0
003oooooool0VOooo`00;?ooo`03o`2Ioooooooo05Goool20000V_ooo`00;?ooo`03o`2Ioooooooo
05Goool00`000?ooooooo`2Ioooo000/oooo00?o09Woooooool0EOooo`030000oooooooo09Woool0
02coool00ol0VOooooooo`1Eoooo00<0003oooooool0VOooo`00;?ooo`03o`2Ioooooooo05Goool2
0000V_ooo`00;?ooo`03o`2Ioooooooo05Goool00`000?ooooooo`2Ioooo000/oooo00?o09Wooooo
ool0EOooo`030000oooooooo09Woool002coool00ol0VOooooooo`1?oooo0`0000?oool00`000?oo
ooooo`2Ioooo000/oooo00?o09Woooooool0D?ooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo000/oooo00?o09Woooooool0COooo`D00003oooo0`0009Woool007coool010000?ooooooo`00
0:3oool007goool00`000?ooo`00002Poooo001noooo0P000:3oool00?oooolQoooo003ooooo8Ooo
o`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?oo
o`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool03Oooo`800004oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool0
10000?ooooooo`0000Woool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000
oooooooo01Koool00`000?ooooooo`08oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000Coooo0P0000[oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000005_oo
o`030000oooooooo00Woool00`000?ooooooo`1koooo001loooo00<0003oooooool05oooo`<00008
oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.08255 .26487 L
.10458 .26487 L
.11448 .26487 L
.11992 .26487 L
.1226 .26487 L
.12507 .26487 L
.12627 .26487 L
.12739 .26487 L
s
.12739 .26487 m
.12786 .61803 L
s
0 .4 1 r
.02381 .21507 m
.04262 .20298 L
.06244 .18706 L
.08255 .16673 L
.10458 .13833 L
.11464 .12276 L
.11959 .11442 L
.12415 .10629 L
.12547 .10386 L
.1267 .10156 L
.12799 .26487 L
.12867 .26487 L
.12941 .26487 L
.13511 .26487 L
.14509 .26487 L
.18631 .26487 L
.22602 .26487 L
.26421 .26487 L
.30486 .26487 L
.34399 .26487 L
.38557 .26487 L
.42564 .26487 L
.46419 .26487 L
.50519 .26487 L
.54468 .26487 L
.58265 .26487 L
.62308 .26487 L
.66198 .26487 L
.70335 .26487 L
.74319 .26487 L
.78152 .26487 L
.8223 .26487 L
.86157 .26487 L
.89932 .26487 L
.93952 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool0033oool00`1Vooooooooo`13oooo00<0000co`0c
o`002S?o0080002Koooo000`oooo00<0I_ooooooool0@_ooo`030000<ol0<ol000`co`020000V_oo
o`00;oooo`80I_m3oooo00<0000co`0co`003C?o00030000oooooooo09Woool002ooool206Ko@_oo
o`030000<ol0<ol000hco`020000V_ooo`00;_ooo`0306Kooooo06Ko04;oool00`0003?o03?o000>
<ol000<0000co`000000VOooo`00;Oooo`0406Kooooooooo06Ko@Oooo`030000<ol0<ol000lco`02
000000<co`00003oool0Uoooo`00;?ooo`0506Kooooooooooooo06Ko047oool00`0003?o03?o000?
<ol000@0000co`0co`00002Hoooo000/oooo00D0I_ooooooooooool0I_l0@?ooo`030000<ol0<ol0
010co`001@0003?o03?o03?o0000002Goooo000[oooo00<0I_ooooooool00_ooo`0306Kooooooooo
03koool00`0003?o03?o000@<ol000<0000co`0co`000S?o00030000oooooooo09Coool002_oool0
0`1Vooooooooo`02oooo00<0I_ooooooool0?Oooo`030000<ol0<ol0014co`000`0003?o03?o0002
<ol000<0003oooooool0U?ooo`00:_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0loooo00<0
000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00:Oooo`0306Kooooooooo00Coool0
0`1Vooooooooo`0koooo00<0000co`0co`004c?o00030000<ol0<ol000@co`000`000?ooooooo`2B
oooo000Xoooo00<0I_ooooooool01Oooo`0306Kooooooooo03_oool00`0003?o03?o000C<ol000<0
000co`0co`0013?o00030000oooooooo09;oool002Soool00`1Vooooooooo`05oooo00<0I_oooooo
ool0>_ooo`030000<ol0<ol001@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`009ooo
o`0306Kooooooooo00Koool00`1Vooooooooo`0ioooo00<0000co`0co`005C?o00800007<ol000<0
003oooooool0T?ooo`009_ooo`0306Kooooooooo00Ooool00`1Vooooooooo`0hoooo00<0000co`0c
o`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`2@oooo000Uoooo00<0I_ooooooool02?oo
o`0306Kooooooooo03Soool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000oooooooo
08ooool002Coool00`1Vooooooooo`09oooo00<0I_ooooooool0=oooo`030000<ol0<ol000lco`05
00000c?o00030000<ol0<ol000Pco`000`000?ooooooo`2>oooo000Soooo00<0I_ooooooool02_oo
o`0306Kooooooooo03Koool00`0003?o03?o000B<ol000<0000co`0co`000c?o00030000<ol0<ol0
00Pco`000`000?ooooooo`2>oooo000Roooo00<0I_ooooooool02oooo`0306Kooooooooo03Goool0
0`0003?o03?o000C<ol000<0000co`0co`000c?o00<00009<ol000<0003oooooool0SOooo`008Ooo
o`0306Kooooooooo00coool00`1Vooooooooo`0eoooo00<0000co`0co`002c?o00@00004<ol000<0
000co`0co`000c?o00030000<ol0<ol000Xco`000`000?ooooooo`2<oooo000Poooo00<0I_oooooo
ool03_ooo`0306Kooooooooo03?oool00`0003?o03?o000D<ol000<0000co`0co`000c?o00030000
<ol0<ol000/co`000`000?ooooooo`2;oooo000Ooooo00<0I_ooooooool03oooo`0306Kooooooooo
03;oool00`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Rooo
o`007_ooo`0306Kooooooooo013oool00`1Vooooooooo`0boooo00<0000co`0co`006c?o0080000=
<ol000<0003oooooool0R_ooo`007Oooo`0306Kooooooooo017oool00`1Vooooooooo`0aoooo00<0
000co`0co`0073?o00030000<ol0<ol000dco`000`000?ooooooo`29oooo000Loooo00<0I_oooooo
ool04_ooo`0306Kooooooooo033oool00`0003?o03?o000M<ol000<0000co`0co`003S?o00030000
oooooooo08Soool001_oool00`1Vooooooooo`0Coooo00<0I_ooooooool0;oooo`030000<ol0<ol0
01hco`000`0003?o03?o000?<ol000<0003oooooool0Qoooo`006Oooo`80I_lFoooo00<0I_oooooo
ool0;oooo`030000<ol0<ol001hco`000`0003?o03?o000@<ol000<0003oooooool0Q_ooo`005ooo
o`80I_lHoooo00<0I_ooooooool0;_ooo`030000<ol0<ol001lco`0200004S?o00030000oooooooo
08Goool001Koool00`1Vooooooooo`0Hoooo00<0I_ooooooool0;Oooo`030000<ol0<ol0020co`00
0`0003?o03?o000B<ol000<0003oooooool0Q?ooo`00;oooo`<0000Woooo100000;oool200008c?o
00030000<ol0<ol001<co`000`000?ooooooo`0Aoooo100002[oool300009oooo`<0000Goooo000`
oooo00<00000I_ooool09_ooo`030000oooooooo00;oool00`0003?o03?o000S<ol000<0000co`0c
o`0053?o00030000oooooooo013oool00`000?ooooooo`0/oooo00<0003oooooool09_ooo`040000
oooooooo00005_ooo`00;Oooo`D0000Xoooo00@0003oooooool0000V<ol00P0001Hco`0200004Ooo
o`030000oooooooo02Soool500009oooo`040000oooooooo00005_ooo`009oooo`@00002oooo00D0
003oooooool00000I_l08Oooo`@00004oooo0P0002Lco`000`0003?o03?o000G<ol000<0003ooooo
ool03oooo`030000oooooooo02Ooool010000?ooooooo`0002Soool300005oooo`00;_ooo`040000
oooo000006Ko9oooo`8000000c?o000003?o000V<ol000<0000co`0co`0063?o00030000oooooooo
00coool010000?ooooooo`0002Woool00`000?ooo`00000Yoooo00<0003oooooool05_ooo`00;ooo
o`8000000`1Vooooooooo`0Toooo100002Pco`000`0003?o03?o000I<ol000<0003oooooool03?oo
o`80000[oooo0P0002Woool300005_ooo`00<Oooo`0306Kooooooooo02;oool20000;3?o00030000
<ol0<ol001Xco`020000OOooo`00<Oooo`0306Kooooooooo023oool20000;S?o0080000M<ol00`00
07[oool0037oool00`1Vooooooooo`0Moooo0`00030co`000`0003?o03?o000O<ol01P0007Coool0
037oool00`1Vooooooooo`0Goooo1P0003<co`000`0003?o03?o000U<ol00`00077oool0037oool0
0`1Vooooooooo`0=oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00D0003ooooooooooooo09T01_oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`0Eoooo000/oooo00D0003ooooooooooooo09T09oooo`030000oooooooo
02Woool00`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo02Woool00`000?oo
ooooo`0Eoooo000`oooo00?o09Woooooool0DOooo`030000oooooooo09Woool0033oool00ol0VOoo
ooooo`1Aoooo00<0003oooooool0VOooo`00<?ooo`03o`2Ioooooooo057oool20000V_ooo`00<?oo
o`03o`2Ioooooooo057oool00`000?ooooooo`2Ioooo000`oooo00?o09Woooooool0DOooo`030000
oooooooo09Woool0033oool00ol0VOooooooo`1Aoooo00<0003oooooool0VOooo`00<?ooo`03o`2I
oooooooo057oool20000V_ooo`00<?ooo`03o`2Ioooooooo057oool00`000?ooooooo`2Ioooo000`
oooo00?o09Woooooool0DOooo`030000oooooooo09Woool0033oool00ol0VOooooooo`1Aoooo00<0
003oooooool0VOooo`00<?ooo`03o`2Ioooooooo057oool00`000?ooooooo`2Ioooo000`oooo00?o
09Woooooool0DOooo`80002Joooo000`oooo00?o09Woooooool0DOooo`030000oooooooo09Woool0
033oool00ol0VOooooooo`1Aoooo00<0003oooooool0VOooo`00<?ooo`03o`2Ioooooooo057oool0
0`000?ooooooo`2Ioooo000`oooo00?o09Woooooool0DOooo`80002Joooo000`oooo00?o09Wooooo
ool0DOooo`030000oooooooo09Woool0033oool00ol0VOooooooo`1Aoooo00<0003oooooool0VOoo
o`00<?ooo`03o`2Ioooooooo04Woool500000oooo`030000oooooooo09Woool0033oool00ol0VOoo
ooooo`1;oooo00<0003oooooool00oooo`030000oooooooo09Woool0033oool00ol0VOooooooo`1;
oooo00<0003oooooool00oooo`<0002Ioooo000`oooo00?o09Woooooool0Boooo`030000oooooooo
00?oool00`000?ooooooo`2Ioooo000`oooo00?o09Woooooool0Boooo`030000oooooooo00?oool0
0`000?ooooooo`2Ioooo000`oooo00?o09Woooooool0B_ooo`800005oooo00<0003oooooool0VOoo
o`00<?ooo`03o`2Ioooooooo057oool20000V_ooo`00<?ooo`03o`2Ioooooooo057oool00`000?oo
ooooo`2Ioooo000`oooo00?o09Woooooool0DOooo`030000oooooooo09Woool0033oool00ol0VOoo
ooooo`1Aoooo00<0003oooooool0VOooo`00<?ooo`03o`2Ioooooooo057oool00`000?ooooooo`2I
oooo000`oooo00?o09Woooooool0DOooo`80002Joooo000`oooo00?o09Woooooool0DOooo`030000
oooooooo09Woool0033oool00ol0VOooooooo`1Aoooo00<0003oooooool0VOooo`00<?ooo`03o`2I
oooooooo057oool00`000?ooooooo`2Ioooo000`oooo00?o09Woooooool0DOooo`80002Joooo000`
oooo00?o09Woooooool0DOooo`030000oooooooo09Woool0033oool00ol0VOooooooo`1Aoooo00<0
003oooooool0VOooo`00<?ooo`03o`2Ioooooooo057oool00`000?ooooooo`2Ioooo000`oooo00?o
09Woooooool0DOooo`030000oooooooo09Woool0033oool00ol0VOooooooo`1Aoooo0P0009[oool0
033oool00ol0VOooooooo`1Aoooo00<0003oooooool0VOooo`00<?ooo`03o`2Ioooooooo04Woool4
00001?ooo`030000oooooooo09Woool0033oool00ol0VOooooooo`19oooo00<0003oooooool01Ooo
o`030000oooooooo09Woool0033oool00ol0VOooooooo`1:oooo00<0003oooooool01?ooo`<0002I
oooo000aoooo00?o09Woooooool0B_ooo`030000oooooooo00?oool00`000?ooooooo`2Ioooo000a
oooo00?o09Woooooool0B?ooo`040000oooooooo00001?ooo`030000oooooooo09Woool0037oool0
0ol0VOooooooo`19oooo0P0000Goool00`000?ooooooo`2Ioooo000aoooo00?o09Woooooool0D?oo
o`80002Joooo000aoooo00?o09Woooooool0D?ooo`030000oooooooo09Woool0037oool00ol0VOoo
ooooo`1@oooo00<0003oooooool0VOooo`00<Oooo`03o`2Ioooooooo053oool00`000?ooooooo`2I
oooo000aoooo00?o09Woooooool0D?ooo`030000oooooooo09Woool0037oool00ol0VOooooooo`1@
oooo0P0009[oool0037oool00ol0VOooooooo`1@oooo00<0003oooooool0VOooo`00<Oooo`03o`2I
oooooooo053oool00`000?ooooooo`2Ioooo000aoooo00?o09Woooooool0D?ooo`030000oooooooo
09Woool0037oool00ol0VOooooooo`1@oooo0P0009[oool0037oool00ol0VOooooooo`1@oooo00<0
003oooooool0VOooo`00<Oooo`03o`2Ioooooooo053oool00`000?ooooooo`2Ioooo000aoooo00?o
09Woooooool0D?ooo`030000oooooooo09Woool0037oool00ol0VOooooooo`1@oooo00<0003ooooo
ool0VOooo`00<Oooo`03o`2Ioooooooo053oool20000V_ooo`00<Oooo`03o`2Ioooooooo053oool0
0`000?ooooooo`2Ioooo000aoooo00?o09Woooooool0BOooo`800005oooo00<0003oooooool0VOoo
o`00<Oooo`03o`2Ioooooooo04Soool010000?ooooooo`0000Coool00`000?ooooooo`2Ioooo000a
oooo00?o09Woooooool0B_ooo`030000oooooooo00?oool30000VOooo`00<Oooo`03o`2Ioooooooo
04_oool00`000?ooooooo`02oooo00<0003oooooool0VOooo`00<Oooo`03o`2Ioooooooo04Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2Ioooo000aoooo00?o09Woooooool0BOooo`800005
oooo00<0003oooooool0VOooo`00<Oooo`03o`2Ioooooooo053oool00`000?ooooooo`2Ioooo000a
oooo00?o09Woooooool0D?ooo`80002Joooo000aoooo00?o09Woooooool0D?ooo`030000oooooooo
09Woool0037oool00ol0VOooooooo`1@oooo00<0003oooooool0VOooo`00<Oooo`03o`2Ioooooooo
053oool00`000?ooooooo`2Ioooo000aoooo00?o09Woooooool0D?ooo`80002Joooo000aoooo00?o
09Woooooool0D?ooo`030000oooooooo09Woool0037oool00ol0VOooooooo`1@oooo00<0003ooooo
ool0VOooo`00<Oooo`03o`2Ioooooooo053oool00`000?ooooooo`2Ioooo000aoooo00?o09Wooooo
ool0D?ooo`030000oooooooo09Woool0037oool00ol0VOooooooo`1@oooo0P0009[oool0037oool0
0ol0VOooooooo`1@oooo00<0003oooooool0VOooo`00<Oooo`03o`2Ioooooooo053oool00`000?oo
ooooo`2Ioooo000aoooo00?o09Woooooool0D?ooo`030000oooooooo09Woool0037oool00ol0VOoo
ooooo`1@oooo0P0009[oool0037oool00ol0VOooooooo`1@oooo00<0003oooooool0VOooo`00<Ooo
o`03o`2Ioooooooo053oool00`000?ooooooo`2Ioooo000aoooo00?o09Woooooool0B_ooo`<00003
oooo00<0003oooooool0VOooo`00<Oooo`03o`2Ioooooooo04_oool00`000?ooooooo`02oooo00<0
003oooooool0VOooo`00<Oooo`03o`2Ioooooooo04Soool500000oooo`<0002Ioooo001loooo00@0
003oooooool0002Poooo001moooo00<0003oool00000X?ooo`00O_ooo`80002Poooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00koool300000_ooo`800004oooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`04oooo100000Koool00`000?ooooooo`06oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Coooo1@0000Ooool010000?oo
ooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000Woool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000F
oooo00<0003oool000002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Hoooo0P0000Woool200000oooo`030000oooooooo07Woool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.12507 .26487 L
.13506 .26487 L
.13979 .26487 L
.14186 .26487 L
.14305 .26487 L
.14415 .26487 L
s
.14415 .26487 m
.14458 .61803 L
s
0 .4 1 r
.02381 .22409 m
.04262 .2142 L
.06244 .20117 L
.08255 .18453 L
.10458 .16127 L
.12415 .13504 L
.12979 .12633 L
.13511 .11755 L
.1399 .10921 L
.14121 .10684 L
.1426 .10429 L
.14378 .10209 L
.14509 .26487 L
.14638 .26487 L
.14757 .26487 L
.15028 .26487 L
.15522 .26487 L
.1645 .26487 L
.18538 .26487 L
.22451 .26487 L
.26609 .26487 L
.30615 .26487 L
.34471 .26487 L
.38571 .26487 L
.4252 .26487 L
.46317 .26487 L
.50359 .26487 L
.5425 .26487 L
.58386 .26487 L
.62371 .26487 L
.66204 .26487 L
.70282 .26487 L
.74208 .26487 L
.77984 .26487 L
.82004 .26487 L
.85873 .26487 L
.89987 .26487 L
.93949 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool003Goool00`1Vooooooooo`0noooo00<0000co`0c
o`002S?o0080002Koooo000doooo0P1Vocooool00`0003?o03?o000<<ol00P0009[oool003Coool2
06Ko?_ooo`030000<ol0<ol000dco`000`000?ooooooo`2Ioooo000coooo00<0I_ooool0I_l0?Ooo
o`030000<ol0<ol000hco`020000V_ooo`00<_ooo`0406Kooooooooo06Ko?Oooo`030000<ol0<ol0
00hco`000`0003?o0000002Ioooo000aoooo00D0I_ooooooooooool0I_l0??ooo`030000<ol0<ol0
00lco`02000000<co`00003oool0Uoooo`00<Oooo`0506Kooooooooooooo06Ko03coool00`0003?o
03?o000?<ol000@0000co`0co`00002Hoooo000`oooo00<0I_ooooooool00_ooo`0306Kooooooooo
03Woool00`0003?o03?o000@<ol000D0000co`0co`0co`000000Uoooo`00<?ooo`0306Kooooooooo
00;oool00`1Vooooooooo`0ioooo00<0000co`0co`0043?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo000_oooo00<0I_ooooooool00oooo`0306Kooooooooo03Soool00`0003?o03?o000A
<ol000<0000co`0co`000S?o00030000oooooooo09Coool002ooool00`1Vooooooooo`03oooo00<0
I_ooooooool0=oooo`030000<ol0<ol0018co`02000013?o00030000oooooooo09?oool002koool0
0`1Vooooooooo`04oooo00<0I_ooooooool0=_ooo`030000<ol0<ol001<co`000`0003?o03?o0004
<ol000<0003oooooool0T_ooo`00;Oooo`0306Kooooooooo00Goool00`1Vooooooooo`0foooo00<0
000co`0co`004c?o00030000<ol0<ol000@co`000`000?ooooooo`2Boooo000/oooo00<0I_oooooo
ool01_ooo`0306Kooooooooo03Goool00`0003?o03?o000D<ol000<0000co`0co`001C?o00030000
oooooooo097oool002coool00`1Vooooooooo`06oooo00<0I_ooooooool0=?ooo`030000<ol0<ol0
01Dco`0200001c?o00030000oooooooo093oool002_oool00`1Vooooooooo`07oooo00<0I_oooooo
ool0<oooo`030000<ol0<ol001Hco`000`0003?o03?o0006<ol000<0003oooooool0T?ooo`00:_oo
o`0306Kooooooooo00Soool00`1Vooooooooo`0coooo00<0000co`0co`005S?o00030000<ol0<ol0
00Lco`000`000?ooooooo`2?oooo000Yoooo00<0I_ooooooool02Oooo`0306Kooooooooo03;oool0
0`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0003oooooool0S_ooo`00:?oo
o`0306Kooooooooo00[oool00`1Vooooooooo`0aoooo00<0000co`0co`004S?o00030000<ol0<ol0
00<co`000`0003?o03?o0008<ol000<0003oooooool0S_ooo`009oooo`0306Kooooooooo00_oool0
0`1Vooooooooo`0`oooo00<0000co`0co`004c?o00030000<ol0<ol000<co`0300002C?o00030000
oooooooo08goool002Koool00`1Vooooooooo`0<oooo00<0I_ooooooool0<?ooo`030000<ol0<ol0
00/co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?oo
o`009Oooo`0306Kooooooooo00goool00`1Vooooooooo`0_oooo00<0000co`0co`0053?o00030000
<ol0<ol000<co`000`0003?o03?o000;<ol000<0003oooooool0Roooo`009?ooo`0306Kooooooooo
00koool00`1Vooooooooo`0^oooo00<0000co`0co`0053?o00800005<ol000<0000co`0co`002c?o
00030000oooooooo08_oool002;oool206Ko4Oooo`0306Kooooooooo02koool00`0003?o03?o000K
<ol00P0000dco`000`000?ooooooo`2:oooo000Qoooo00<0I_ooooooool04Oooo`0306Kooooooooo
02goool00`0003?o03?o000L<ol000<0000co`0co`003C?o00030000oooooooo08Woool0023oool0
0`1Vooooooooo`0Boooo00<0I_ooooooool0;?ooo`030000<ol0<ol001dco`000`0003?o03?o000>
<ol000<0003oooooool0R?ooo`007_ooo`80I_lEoooo00<0I_ooooooool0:oooo`030000<ol0<ol0
01hco`000`0003?o03?o000?<ol000<0003oooooool0Qoooo`007?ooo`80I_lGoooo00<0I_oooooo
ool0:oooo`030000<ol0<ol001hco`000`0003?o03?o000@<ol000<0003oooooool0Q_ooo`006ooo
o`0306Kooooooooo01Ooool00`1Vooooooooo`0Zoooo00<0000co`0co`007c?o0080000B<ol000<0
003oooooool0QOooo`006Oooo`80I_lJoooo00<0I_ooooooool0:Oooo`030000<ol0<ol0020co`00
0`0003?o03?o000B<ol000<0003oooooool0Q?ooo`005oooo`80I_lFoooo0`0000?oool00`1Voooo
ooooo`0Qoooo100000;oool200008c?o00030000<ol0<ol001<co`000`000?ooooooo`0Aoooo1000
02[oool300009oooo`<0000Goooo000Foooo00<0I_ooooooool05oooo`030000oooooooo00;oool0
0`1Vooooooooo`0Qoooo00<0003oooooool00_ooo`030000<ol0<ol002<co`000`0003?o03?o000D
<ol000<0003oooooool04?ooo`030000oooooooo02coool00`000?ooooooo`0Voooo00@0003ooooo
ool0000Foooo000]oooo1@0000?oool00`1Vooooooooo`0Roooo00@0003oooooool0000V<ol00P00
01Hco`0200004Oooo`030000oooooooo02Soool500009oooo`040000oooooooo00005_ooo`009ooo
o`@00002oooo00@0003oooooool00004oooo00<0I_ooooooool06oooo`@00004oooo0P0002Lco`00
0`0003?o03?o000G<ol000<0003oooooool03oooo`030000oooooooo02Ooool010000?ooooooo`00
02Soool300005oooo`00;_ooo`030000oooo000000Coool00`1Vooooooooo`0Qoooo0P000003<ol0
0000<ol002Hco`000`0003?o03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Ooo
o`030000oooo000002Woool00`000?ooooooo`0Foooo000_oooo0P0000Coool00`1Vooooooooo`0P
oooo100002Pco`000`0003?o03?o000I<ol000<0003oooooool03?ooo`80000[oooo0P0002Woool3
00005_ooo`00=Oooo`0306Kooooooooo01koool20000;3?o00030000<ol0<ol001Xco`020000OOoo
o`00=Oooo`0306Kooooooooo01coool20000;S?o0080000M<ol00`0007[oool003Goool00`1Voooo
ooooo`0Ioooo0`00030co`000`0003?o03?o000O<ol01P0007Coool003Goool00`1Vooooooooo`0C
oooo1P0003<co`000`0003?o03?o000U<ol00`00077oool003Goool00`1Vooooooooo`09oooo2P00
03Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool01_ooo`03o`2Ioooo000000[oool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000/
oooo00<0003oooooool01_ooo`03o`2Ioooooooo023oool00`000?ooooooo`0Yoooo00<0003ooooo
ool0:Oooo`030000oooooooo02Woool00`000?ooooooo`0Yoooo00<0003oooooool05Oooo`00=Ooo
o`03o`2Ioooooooo04coool00`000?ooooooo`2Ioooo000eoooo00?o09Woooooool0C?ooo`030000
oooooooo09Woool003Goool00ol0VOooooooo`1<oooo0P0009[oool003Goool00ol0VOooooooo`1<
oooo00<0003oooooool0VOooo`00=Oooo`03o`2Ioooooooo04coool00`000?ooooooo`2Ioooo000e
oooo00?o09Woooooool0C?ooo`030000oooooooo09Woool003Goool00ol0VOooooooo`1<oooo0P00
09[oool003Goool00ol0VOooooooo`1<oooo00<0003oooooool0VOooo`00=Oooo`03o`2Ioooooooo
04coool00`000?ooooooo`2Ioooo000eoooo00?o09Woooooool0C?ooo`030000oooooooo09Woool0
03Goool00ol0VOooooooo`1<oooo00<0003oooooool0VOooo`00=Oooo`03o`2Ioooooooo04coool2
0000V_ooo`00=Oooo`03o`2Ioooooooo04coool00`000?ooooooo`2Ioooo000eoooo00?o09Wooooo
ool0C?ooo`030000oooooooo09Woool003Goool00ol0VOooooooo`1<oooo00<0003oooooool0VOoo
o`00=Oooo`03o`2Ioooooooo04coool20000V_ooo`00=Oooo`03o`2Ioooooooo04coool00`000?oo
ooooo`2Ioooo000eoooo00?o09Woooooool0C?ooo`030000oooooooo09Woool003Goool00ol0VOoo
ooooo`14oooo1@0000?oool00`000?ooooooo`2Ioooo000eoooo00?o09Woooooool0A_ooo`030000
oooooooo00?oool00`000?ooooooo`2Ioooo000eoooo00?o09Woooooool0A_ooo`030000oooooooo
00?oool30000VOooo`00=Oooo`03o`2Ioooooooo04Koool00`000?ooooooo`03oooo00<0003ooooo
ool0VOooo`00=Oooo`03o`2Ioooooooo04Koool00`000?ooooooo`03oooo00<0003oooooool0VOoo
o`00=Oooo`03o`2Ioooooooo04Goool200001Oooo`030000oooooooo09Woool003Goool00ol0VOoo
ooooo`1<oooo0P0009[oool003Goool00ol0VOooooooo`1<oooo00<0003oooooool0VOooo`00=Ooo
o`03o`2Ioooooooo04coool00`000?ooooooo`2Ioooo000eoooo00?o09Woooooool0C?ooo`030000
oooooooo09Woool003Goool00ol0VOooooooo`1<oooo00<0003oooooool0VOooo`00=Oooo`03o`2I
oooooooo04coool20000V_ooo`00=Oooo`03o`2Ioooooooo04coool00`000?ooooooo`2Ioooo000e
oooo00?o09Woooooool0C?ooo`030000oooooooo09Woool003Goool00ol0VOooooooo`1<oooo00<0
003oooooool0VOooo`00=Oooo`03o`2Ioooooooo04coool20000V_ooo`00=Oooo`03o`2Ioooooooo
04coool00`000?ooooooo`2Ioooo000eoooo00?o09Woooooool0C?ooo`030000oooooooo09Woool0
03Goool00ol0VOooooooo`1<oooo00<0003oooooool0VOooo`00=Oooo`03o`2Ioooooooo04coool0
0`000?ooooooo`2Ioooo000eoooo00?o09Woooooool0C?ooo`80002Joooo000eoooo00?o09Wooooo
ool0C?ooo`030000oooooooo09Woool003Goool00ol0VOooooooo`14oooo100000Coool00`000?oo
ooooo`2Ioooo000eoooo00?o09Woooooool0A?ooo`030000oooooooo00Goool00`000?ooooooo`2I
oooo000eoooo00?o09Woooooool0AOooo`030000oooooooo00Coool30000VOooo`00=Oooo`03o`2I
oooooooo04Koool00`000?ooooooo`03oooo00<0003oooooool0VOooo`00=Oooo`03o`2Ioooooooo
04Coool010000?ooooooo`0000Coool00`000?ooooooo`2Ioooo000eoooo00?o09Woooooool0AOoo
o`800005oooo00<0003oooooool0VOooo`00=Oooo`03o`2Ioooooooo04coool20000V_ooo`00=Ooo
o`03o`2Ioooooooo04coool00`000?ooooooo`2Ioooo000eoooo00?o09Woooooool0C?ooo`030000
oooooooo09Woool003Goool00ol0VOooooooo`1<oooo00<0003oooooool0VOooo`00=Oooo`03o`2I
oooooooo04coool00`000?ooooooo`2Ioooo000eoooo00?o09Woooooool0C?ooo`80002Joooo000e
oooo00?o09Woooooool0C?ooo`030000oooooooo09Woool003Goool00ol0VOooooooo`1<oooo00<0
003oooooool0VOooo`00=Oooo`03o`2Ioooooooo04coool00`000?ooooooo`2Ioooo000eoooo00?o
09Woooooool0C?ooo`80002Joooo000eoooo00?o09Woooooool0C?ooo`030000oooooooo09Woool0
03Goool00ol0VOooooooo`1<oooo00<0003oooooool0VOooo`00=Oooo`03o`2Ioooooooo04coool0
0`000?ooooooo`2Ioooo000eoooo00?o09Woooooool0C?ooo`030000oooooooo09Woool003Goool0
0ol0VOooooooo`1<oooo0P0009[oool003Goool00ol0VOooooooo`1<oooo00<0003oooooool0VOoo
o`00=Oooo`03o`2Ioooooooo04Goool200001Oooo`030000oooooooo09Woool003Goool00ol0VOoo
ooooo`14oooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00=Oooo`03o`2Ioooooooo
04Koool00`000?ooooooo`03oooo0`0009Woool003Goool00ol0VOooooooo`17oooo00<0003ooooo
ool00_ooo`030000oooooooo09Woool003Goool00ol0VOooooooo`14oooo00@0003oooooool00004
oooo00<0003oooooool0VOooo`00=Oooo`03o`2Ioooooooo04Goool200001Oooo`030000oooooooo
09Woool003Goool00ol0VOooooooo`1<oooo00<0003oooooool0VOooo`00=Oooo`03o`2Ioooooooo
04coool20000V_ooo`00=Oooo`03o`2Ioooooooo04coool00`000?ooooooo`2Ioooo000eoooo00?o
09Woooooool0C?ooo`030000oooooooo09Woool003Goool00ol0VOooooooo`1<oooo00<0003ooooo
ool0VOooo`00=Oooo`03o`2Ioooooooo04coool20000V_ooo`00=Oooo`03o`2Ioooooooo04coool0
0`000?ooooooo`2Ioooo000eoooo00?o09Woooooool0C?ooo`030000oooooooo09Woool003Goool0
0ol0VOooooooo`1<oooo00<0003oooooool0VOooo`00=Oooo`03o`2Ioooooooo04coool00`000?oo
ooooo`2Ioooo000eoooo00?o09Woooooool0C?ooo`80002Joooo000eoooo00?o09Woooooool0C?oo
o`030000oooooooo09Woool003Goool00ol0VOooooooo`1<oooo00<0003oooooool0VOooo`00=Ooo
o`03o`2Ioooooooo04coool00`000?ooooooo`2Ioooo000eoooo00?o09Woooooool0C?ooo`80002J
oooo000eoooo00?o09Woooooool0C?ooo`030000oooooooo09Woool003Goool00ol0VOooooooo`1<
oooo00<0003oooooool0VOooo`00=Oooo`03o`2Ioooooooo04Koool300000oooo`030000oooooooo
09Woool003Goool00ol0VOooooooo`17oooo00<0003oooooool00_ooo`030000oooooooo09Woool0
03Goool00ol0VOooooooo`14oooo1@0000?oool30000VOooo`00O?ooo`040000oooooooo0000X?oo
o`00OOooo`030000oooo00000:3oool007koool20000X?ooo`00ooooob7oool00?oooolQoooo001i
oooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0
003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`0>oooo0`0000;oool200000oooo`<00004oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00006
oooo00<0003oooooool01_ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool0
0`000?ooooooo`02oooo00<0003oooooool04oooo`D00007oooo00@0003oooooool00004oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Boooo00@0003oooooool00008oooo0`00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005_ooo`030000oooo0000
00Woool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Soool2
00002Oooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.12507 .26487 L
.13506 .26487 L
.14415 .26487 L
.14868 .26487 L
.1536 .26487 L
.15586 .26487 L
.15825 .26487 L
.16029 .26487 L
.16145 .26487 L
s
.16145 .26487 m
.16189 .61803 L
s
0 .4 1 r
.02381 .23149 m
.04262 .22339 L
.06244 .21272 L
.08255 .19909 L
.10458 .18006 L
.12415 .15858 L
.14509 .12958 L
.1553 .1127 L
.1581 .10772 L
.15964 .10492 L
.16107 .10226 L
.16229 .09996 L
.1636 .26487 L
.16435 .26487 L
.16506 .26487 L
.16639 .26487 L
.18653 .26487 L
.22473 .26487 L
.26537 .26487 L
.3045 .26487 L
.34608 .26487 L
.38615 .26487 L
.4247 .26487 L
.4657 .26487 L
.50519 .26487 L
.54316 .26487 L
.58359 .26487 L
.6225 .26487 L
.66386 .26487 L
.7037 .26487 L
.74203 .26487 L
.78281 .26487 L
.82208 .26487 L
.85983 .26487 L
.90003 .26487 L
.93872 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo000ioooo00<0I_ooooooool0>ooo
o`030000<ol0<ol000<co`0200000S?o008000000oooo`000?ooo`2Joooo000ioooo00<0I_oooooo
ool0>_ooo`030000<ol0<ol000Xco`020000Voooo`00>?ooo`80I_lkoooo00<0000co`0co`0033?o
0080002Joooo000hoooo0P1Voc[oool00`0003?o03?o000=<ol000<0003oooooool0VOooo`00>?oo
o`80I_lioooo00<0000co`0co`003S?o0080002Joooo000goooo00<0I_ooool0I_l0>Oooo`030000
<ol0<ol000hco`000`0003?o0000002Ioooo000foooo00@0I_ooooooool0I_lhoooo00<0000co`0c
o`003c?o008000000c?o00000?ooo`2Goooo000foooo00@0I_ooooooool0I_lhoooo00<0000co`0c
o`003c?o00040000<ol0<ol00000V?ooo`00=Oooo`0506Kooooooooooooo06Ko03Ooool00`0003?o
03?o000@<ol000D0000co`0co`0co`000000Uoooo`00=?ooo`0306Kooooooooo00;oool00`1Voooo
ooooo`0eoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`000`000?ooooooo`2Doooo000d
oooo00<0I_ooooooool00_ooo`0306Kooooooooo03Coool00`0003?o03?o000A<ol000<0000co`0c
o`000S?o00030000oooooooo09Coool003?oool00`1Vooooooooo`03oooo00<0I_ooooooool0<ooo
o`030000<ol0<ol0018co`02000013?o00030000oooooooo09?oool003;oool00`1Vooooooooo`04
oooo00<0I_ooooooool0<_ooo`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003ooooo
ool0T_ooo`00<Oooo`0306Kooooooooo00Goool00`1Vooooooooo`0boooo00<0000co`0co`004c?o
00030000<ol0<ol000@co`000`000?ooooooo`2Boooo000aoooo00<0I_ooooooool01Oooo`0306Ko
oooooooo037oool00`0003?o03?o000D<ol000<0000co`0co`001C?o00030000oooooooo097oool0
033oool00`1Vooooooooo`06oooo00<0I_ooooooool0<?ooo`030000<ol0<ol001Dco`0200001c?o
00030000oooooooo093oool002ooool00`1Vooooooooo`07oooo00<0I_ooooooool0;oooo`030000
<ol0<ol001Hco`000`0003?o03?o0006<ol000<0003oooooool0T?ooo`00;_ooo`0306Kooooooooo
00Soool00`1Vooooooooo`0_oooo00<0000co`0co`005S?o00030000<ol0<ol000Lco`000`000?oo
ooooo`2?oooo000]oooo00<0I_ooooooool02Oooo`0306Kooooooooo02koool00`0003?o03?o000?
<ol01@0000<co`000`0003?o03?o0008<ol000<0003oooooool0S_ooo`00;Oooo`0306Kooooooooo
00Woool00`1Vooooooooo`0]oooo00<0000co`0co`004S?o00030000<ol0<ol000<co`000`0003?o
03?o0008<ol000<0003oooooool0S_ooo`00;?ooo`0306Kooooooooo00[oool00`1Vooooooooo`0/
oooo00<0000co`0co`004c?o00030000<ol0<ol000<co`0300002C?o00030000oooooooo08goool0
02_oool00`1Vooooooooo`0;oooo00<0I_ooooooool0;?ooo`030000<ol0<ol000/co`04000013?o
00030000<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00:_ooo`0306Ko
oooooooo00goool00`1Vooooooooo`0Zoooo00<0000co`0co`0053?o00030000<ol0<ol000<co`00
0`0003?o03?o000;<ol000<0003oooooool0Roooo`00:Oooo`0306Kooooooooo00koool00`1Voooo
ooooo`0Yoooo00<0000co`0co`0053?o00800005<ol000<0000co`0co`002c?o00030000oooooooo
08_oool002Ooool206Ko4Oooo`0306Kooooooooo02Woool00`0003?o03?o000K<ol00P0000dco`00
0`000?ooooooo`2:oooo000Voooo00<0I_ooooooool04Oooo`0306Kooooooooo02Soool00`0003?o
03?o000L<ol000<0000co`0co`003C?o00030000oooooooo08Woool002Goool00`1Vooooooooo`0B
oooo00<0I_ooooooool09oooo`030000<ol0<ol001dco`000`0003?o03?o000><ol000<0003ooooo
ool0R?ooo`008oooo`80I_lEoooo00<0I_ooooooool09_ooo`030000<ol0<ol001hco`000`0003?o
03?o000?<ol000<0003oooooool0Qoooo`008Oooo`80I_lGoooo00<0I_ooooooool09_ooo`030000
<ol0<ol001hco`000`0003?o03?o000@<ol000<0003oooooool0Q_ooo`008?ooo`0306Kooooooooo
01Ooool00`1Vooooooooo`0Uoooo00<0000co`0co`007c?o0080000B<ol000<0003oooooool0QOoo
o`007_ooo`80I_lJoooo00<0I_ooooooool09?ooo`030000<ol0<ol0020co`000`0003?o03?o000B
<ol000<0003oooooool0Q?ooo`007?ooo`80I_lAoooo0`0000Soool00`1Vooooooooo`0Loooo1000
00;oool200008c?o00030000<ol0<ol001<co`000`000?ooooooo`0Aoooo100002[oool300009ooo
o`<0000Goooo000Joooo0P1VoaCoool00`000?ooooooo`07oooo00<0I_ooooooool07?ooo`030000
oooooooo00;oool00`0003?o03?o000S<ol000<0000co`0co`0053?o00030000oooooooo013oool0
0`000?ooooooo`0/oooo00<0003oooooool09_ooo`040000oooooooo00005_ooo`006?ooo`80I_lC
oooo1@0000Soool00`1Vooooooooo`0Moooo00@0003oooooool0000V<ol00P0001Hco`0200004Ooo
o`030000oooooooo02Soool500009oooo`040000oooooooo00005_ooo`005_ooo`80I_l?oooo1000
00;oool010000?ooooooo`0000Woool00`1Vooooooooo`0Foooo100000Coool200009c?o00030000
<ol0<ol001Lco`000`000?ooooooo`0?oooo00<0003oooooool09oooo`040000oooooooo0000:?oo
o`<0000Goooo000^oooo00<0003oool000002Oooo`0306Kooooooooo01coool2000000<co`00000c
o`009S?o00030000<ol0<ol001Pco`000`000?ooooooo`0<oooo00@0003oooooool0000Yoooo00<0
003oool00000:Oooo`030000oooooooo01Koool002ooool200002Oooo`0306Kooooooooo01_oool4
0000:3?o00030000<ol0<ol001Tco`000`000?ooooooo`0<oooo0P0002_oool20000:Oooo`<0000F
oooo000joooo00<0I_ooooooool06Oooo`80000/<ol000<0000co`0co`006S?o0080001moooo000j
oooo00<0I_ooooooool05oooo`80000^<ol00P0001dco`030000N_ooo`00>_ooo`0306Kooooooooo
01Coool30000<3?o00030000<ol0<ol001lco`060000M?ooo`00>_ooo`0306Kooooooooo00koool6
0000<c?o00030000<ol0<ol002Dco`030000LOooo`00>_ooo`0306Kooooooooo00Coool:0000>C?o
00030000<ol0<ol002Pco`0:0000Ioooo`004?ooool0000Aoooo000Foooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo09T02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool002coool0
0`000?ooooooo`0:oooo00?o09Woooooool07?ooo`030000oooooooo02Woool00`000?ooooooo`0Y
oooo00<0003oooooool0:Oooo`030000oooooooo02Woool00`000?ooooooo`0Eoooo000ioooo00?o
09Woooooool0B?ooo`030000oooooooo09Woool003Woool00ol0VOooooooo`18oooo00<0003ooooo
ool0VOooo`00>Oooo`03o`2Ioooooooo04Soool20000V_ooo`00>Oooo`03o`2Ioooooooo04Soool0
0`000?ooooooo`2Ioooo000ioooo00?o09Woooooool0B?ooo`030000oooooooo09Woool003Woool0
0ol0VOooooooo`18oooo00<0003oooooool0VOooo`00>Oooo`03o`2Ioooooooo04Soool20000V_oo
o`00>Oooo`03o`2Ioooooooo04Soool00`000?ooooooo`2Ioooo000ioooo00?o09Woooooool0B?oo
o`030000oooooooo09Woool003Woool00ol0VOooooooo`18oooo00<0003oooooool0VOooo`00>Ooo
o`03o`2Ioooooooo04Soool00`000?ooooooo`2Ioooo000ioooo00?o09Woooooool0B?ooo`80002J
oooo000ioooo00?o09Woooooool0B?ooo`030000oooooooo09Woool003Woool00ol0VOooooooo`18
oooo00<0003oooooool0VOooo`00>Oooo`03o`2Ioooooooo04Soool00`000?ooooooo`2Ioooo000i
oooo00?o09Woooooool0B?ooo`80002Joooo000ioooo00?o09Woooooool0B?ooo`030000oooooooo
09Woool003Woool00ol0VOooooooo`18oooo00<0003oooooool0VOooo`00>Oooo`03o`2Ioooooooo
043oool500000oooo`030000oooooooo09Woool003Woool00ol0VOooooooo`12oooo00<0003ooooo
ool00oooo`030000oooooooo09Woool003Woool00ol0VOooooooo`12oooo00<0003oooooool00ooo
o`<0002Ioooo000ioooo00?o09Woooooool0@_ooo`030000oooooooo00?oool00`000?ooooooo`2I
oooo000ioooo00?o09Woooooool0@_ooo`030000oooooooo00?oool00`000?ooooooo`2Ioooo000i
oooo00?o09Woooooool0@Oooo`800005oooo00<0003oooooool0VOooo`00>Oooo`03o`2Ioooooooo
04Soool20000V_ooo`00>Oooo`03o`2Ioooooooo04Soool00`000?ooooooo`2Ioooo000ioooo00?o
09Woooooool0B?ooo`030000oooooooo09Woool003Woool00ol0VOooooooo`18oooo00<0003ooooo
ool0VOooo`00>Oooo`03o`2Ioooooooo04Soool00`000?ooooooo`2Ioooo000ioooo00?o09Wooooo
ool0B?ooo`80002Joooo000ioooo00?o09Woooooool0B?ooo`030000oooooooo09Woool003Woool0
0ol0VOooooooo`18oooo00<0003oooooool0VOooo`00>Oooo`03o`2Ioooooooo04Soool00`000?oo
ooooo`2Ioooo000ioooo00?o09Woooooool0B?ooo`80002Joooo000ioooo00?o09Woooooool0B?oo
o`030000oooooooo09Woool003Woool00ol0VOooooooo`18oooo00<0003oooooool0VOooo`00>Ooo
o`03o`2Ioooooooo04Soool00`000?ooooooo`2Ioooo000ioooo00?o09Woooooool0B?ooo`030000
oooooooo09Woool003Woool00ol0VOooooooo`18oooo0P0009[oool003Woool00ol0VOooooooo`18
oooo00<0003oooooool0VOooo`00>Oooo`03o`2Ioooooooo043oool400001?ooo`030000oooooooo
09Woool003Woool00ol0VOooooooo`10oooo00<0003oooooool01Oooo`030000oooooooo09Woool0
03Woool00ol0VOooooooo`11oooo00<0003oooooool01?ooo`<0002Ioooo000ioooo00?o09Wooooo
ool0@_ooo`030000oooooooo00?oool00`000?ooooooo`2Ioooo000ioooo00?o09Woooooool0@?oo
o`040000oooooooo00001?ooo`030000oooooooo09Woool003Woool00ol0VOooooooo`11oooo0P00
00Goool00`000?ooooooo`2Ioooo000ioooo00?o09Woooooool0B?ooo`80002Joooo000ioooo00?o
09Woooooool0B?ooo`030000oooooooo09Woool003Woool00ol0VOooooooo`18oooo00<0003ooooo
ool0VOooo`00>Oooo`03o`2Ioooooooo04Soool00`000?ooooooo`2Ioooo000ioooo00?o09Wooooo
ool0B?ooo`030000oooooooo09Woool003Woool00ol0VOooooooo`18oooo0P0009[oool003Woool0
0ol0VOooooooo`18oooo00<0003oooooool0VOooo`00>Oooo`03o`2Ioooooooo04Soool00`000?oo
ooooo`2Ioooo000ioooo00?o09Woooooool0B?ooo`030000oooooooo09Woool003Woool00ol0VOoo
ooooo`18oooo0P0009[oool003Woool00ol0VOooooooo`18oooo00<0003oooooool0VOooo`00>Ooo
o`03o`2Ioooooooo04Soool00`000?ooooooo`2Ioooo000ioooo00?o09Woooooool0B?ooo`030000
oooooooo09Woool003Woool00ol0VOooooooo`18oooo00<0003oooooool0VOooo`00>Oooo`03o`2I
oooooooo04Soool20000V_ooo`00>Oooo`03o`2Ioooooooo04Soool00`000?ooooooo`2Ioooo000i
oooo00?o09Woooooool0@Oooo`800005oooo00<0003oooooool0VOooo`00>Oooo`03o`2Ioooooooo
043oool010000?ooooooo`0000Coool00`000?ooooooo`2Ioooo000ioooo00?o09Woooooool0@_oo
o`030000oooooooo00?oool30000VOooo`00>Oooo`03o`2Ioooooooo04?oool00`000?ooooooo`02
oooo00<0003oooooool0VOooo`00>Oooo`03o`2Ioooooooo043oool010000?ooooooo`0000Coool0
0`000?ooooooo`2Ioooo000ioooo00?o09Woooooool0@Oooo`800005oooo00<0003oooooool0VOoo
o`00>Oooo`03o`2Ioooooooo04Soool00`000?ooooooo`2Ioooo000ioooo00?o09Woooooool0B?oo
o`80002Joooo000ioooo00?o09Woooooool0B?ooo`030000oooooooo09Woool003Woool00ol0VOoo
ooooo`18oooo00<0003oooooool0VOooo`00>Oooo`03o`2Ioooooooo04Soool00`000?ooooooo`2I
oooo000ioooo00?o09Woooooool0B?ooo`80002Joooo000ioooo00?o09Woooooool0B?ooo`030000
oooooooo09Woool003Woool00ol0VOooooooo`18oooo00<0003oooooool0VOooo`00>Oooo`03o`2I
oooooooo04Soool00`000?ooooooo`2Ioooo000ioooo00?o09Woooooool0B?ooo`030000oooooooo
09Woool003Woool00ol0VOooooooo`18oooo0P0009[oool003Woool00ol0VOooooooo`18oooo00<0
003oooooool0VOooo`00>Oooo`03o`2Ioooooooo04Soool00`000?ooooooo`2Ioooo000ioooo00?o
09Woooooool0B?ooo`030000oooooooo09Woool003Woool00ol0VOooooooo`18oooo0P0009[oool0
03Woool00ol0VOooooooo`18oooo00<0003oooooool0VOooo`00>Oooo`03o`2Ioooooooo04Soool0
0`000?ooooooo`2Ioooo000ioooo00?o09Woooooool0@_ooo`<00003oooo00<0003oooooool0VOoo
o`00>Oooo`03o`2Ioooooooo04?oool00`000?ooooooo`02oooo00<0003oooooool0VOooo`00>Ooo
o`03o`2Ioooooooo043oool500000oooo`<0002Ioooo001loooo00@0003oooooool0002Poooo001m
oooo00<0003oool00000X?ooo`00O_ooo`80002Poooo003ooooo8Oooo`00ooooob7oool007Woool0
0`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?oo
ooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00koool300000_ooo`800005oooo0`0000;oool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000Koool0
0`000?ooooooo`09oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool0
0`000?ooooooo`0Coooo1@0000Ooool500000oooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500004_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`00000Foooo00<0003oool000002Oooo`030000oooo0000
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool06?ooo`80000:oooo0P0000;oool0
0`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.12507 .26487 L
.14415 .26487 L
.16254 .26487 L
.16783 .26487 L
.17284 .26487 L
.17502 .26487 L
.17733 .26487 L
.17854 .26487 L
.17922 .26487 L
s
.17922 .26487 m
.17948 .61803 L
s
0 .4 1 r
.02381 .23754 m
.04262 .23091 L
.06244 .22218 L
.08255 .21102 L
.10458 .19544 L
.12415 .17785 L
.14509 .15411 L
.1553 .14029 L
.16639 .12335 L
.17148 .11483 L
.17426 .10996 L
.17687 .10526 L
.178 .10316 L
.17908 .10114 L
.18033 .26487 L
.18147 .26487 L
.18653 .26487 L
.22473 .26487 L
.26537 .26487 L
.3045 .26487 L
.34608 .26487 L
.38615 .26487 L
.4247 .26487 L
.4657 .26487 L
.50519 .26487 L
.54316 .26487 L
.58359 .26487 L
.6225 .26487 L
.66386 .26487 L
.7037 .26487 L
.74203 .26487 L
.78281 .26487 L
.82208 .26487 L
.85983 .26487 L
.90003 .26487 L
.93872 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool003goool206Ko=oooo`030000<ol0<ol000Xco`02
0000Voooo`00?Oooo`80I_lfoooo00<0000co`0co`0033?o0080002Joooo000loooo00<0I_ooool0
I_l0=Oooo`030000<ol0<ol000dco`000`000?ooooooo`2Ioooo000loooo00<0I_ooool0I_l0=?oo
o`030000<ol0<ol000hco`020000V_ooo`00>oooo`0406Kooooooooo06Ko=?ooo`030000<ol0<ol0
00hco`000`0003?o0000002Ioooo000joooo00D0I_ooooooooooool0I_l0<oooo`030000<ol0<ol0
00lco`02000000<co`00003oool0Uoooo`00>_ooo`0506Kooooooooooooo06Ko03?oool00`0003?o
03?o000?<ol000@0000co`0co`00002Hoooo000ioooo00<0I_ooooooool00_ooo`0306Kooooooooo
033oool00`0003?o03?o000@<ol000D0000co`0co`0co`000000Uoooo`00>Oooo`0306Kooooooooo
00;oool00`1Vooooooooo`0`oooo00<0000co`0co`0043?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo000hoooo00<0I_ooooooool00oooo`0306Kooooooooo02ooool00`0003?o03?o000A
<ol000<0000co`0co`000S?o00030000oooooooo09Coool003Soool00`1Vooooooooo`03oooo00<0
I_ooooooool0;_ooo`030000<ol0<ol0018co`02000013?o00030000oooooooo09?oool003Ooool0
0`1Vooooooooo`04oooo00<0I_ooooooool0;Oooo`030000<ol0<ol001<co`000`0003?o03?o0004
<ol000<0003oooooool0T_ooo`00=_ooo`0306Kooooooooo00Goool00`1Vooooooooo`0]oooo00<0
000co`0co`004c?o00030000<ol0<ol000@co`000`000?ooooooo`2Boooo000eoooo00<0I_oooooo
ool01_ooo`0306Kooooooooo02coool00`0003?o03?o000D<ol000<0000co`0co`001C?o00030000
oooooooo097oool003Coool00`1Vooooooooo`07oooo00<0I_ooooooool0:oooo`030000<ol0<ol0
01Dco`0200001c?o00030000oooooooo093oool003?oool00`1Vooooooooo`08oooo00<0I_oooooo
ool0:_ooo`030000<ol0<ol001Hco`000`0003?o03?o0006<ol000<0003oooooool0T?ooo`00<_oo
o`0306Kooooooooo00Woool00`1Vooooooooo`0Zoooo00<0000co`0co`005S?o00030000<ol0<ol0
00Lco`000`000?ooooooo`2?oooo000boooo00<0I_ooooooool02Oooo`0306Kooooooooo02Woool0
0`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0003oooooool0S_ooo`00<Ooo
o`0306Kooooooooo00[oool00`1Vooooooooo`0Xoooo00<0000co`0co`004S?o00030000<ol0<ol0
00<co`000`0003?o03?o0008<ol000<0003oooooool0S_ooo`00<?ooo`0306Kooooooooo00_oool0
0`1Vooooooooo`0Woooo00<0000co`0co`004c?o00030000<ol0<ol000<co`0300002C?o00030000
oooooooo08goool002ooool00`1Vooooooooo`0<oooo00<0I_ooooooool09oooo`030000<ol0<ol0
00/co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?oo
o`00;_ooo`0306Kooooooooo00goool00`1Vooooooooo`0Voooo00<0000co`0co`0053?o00030000
<ol0<ol000<co`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00;Oooo`0306Kooooooooo
00koool00`1Vooooooooo`0Uoooo00<0000co`0co`0053?o00800005<ol000<0000co`0co`002c?o
00030000oooooooo08_oool002coool00`1Vooooooooo`0?oooo00<0I_ooooooool09Oooo`030000
<ol0<ol001/co`0200003C?o00030000oooooooo08[oool002_oool00`1Vooooooooo`0@oooo00<0
I_ooooooool09?ooo`030000<ol0<ol001`co`000`0003?o03?o000=<ol000<0003oooooool0ROoo
o`00:Oooo`80I_lCoooo00<0I_ooooooool08oooo`030000<ol0<ol001dco`000`0003?o03?o000>
<ol000<0003oooooool0R?ooo`00:?ooo`0306Kooooooooo01?oool00`1Vooooooooo`0Roooo00<0
000co`0co`007S?o00030000<ol0<ol000lco`000`000?ooooooo`27oooo000Voooo0P1VoaKoool0
0`1Vooooooooo`0Roooo00<0000co`0co`007S?o00030000<ol0<ol0010co`000`000?ooooooo`26
oooo000Toooo0P1VoaSoool00`1Vooooooooo`0Qoooo00<0000co`0co`007c?o0080000B<ol000<0
003oooooool0QOooo`008_ooo`80I_lJoooo00<0I_ooooooool08?ooo`030000<ol0<ol0020co`00
0`0003?o03?o000B<ol000<0003oooooool0Q?ooo`008?ooo`80I_l=oooo0`0000coool00`1Voooo
ooooo`0Hoooo100000;oool200008c?o00030000<ol0<ol001<co`000`000?ooooooo`0Aoooo1000
02[oool300009oooo`<0000Goooo000Noooo0P1Voa3oool00`000?ooooooo`0;oooo00<0I_oooooo
ool06?ooo`030000oooooooo00;oool00`0003?o03?o000S<ol000<0000co`0co`0053?o00030000
oooooooo013oool00`000?ooooooo`0/oooo00<0003oooooool09_ooo`040000oooooooo00005_oo
o`007?ooo`80I_l?oooo1@0000coool00`1Vooooooooo`0Ioooo00@0003oooooool0000V<ol00P00
01Hco`0200004Oooo`030000oooooooo02Soool500009oooo`040000oooooooo00005_ooo`006Ooo
o`<0I_l;oooo100000;oool010000?ooooooo`0000goool00`1Vooooooooo`0Boooo100000Coool2
00009c?o00030000<ol0<ol001Lco`000`000?ooooooo`0?oooo00<0003oooooool09oooo`040000
oooooooo0000:?ooo`<0000Goooo000Foooo0`1VoaGoool00`000?ooo`00000=oooo00<0I_oooooo
ool06?ooo`8000000c?o000003?o000V<ol000<0000co`0co`0063?o00030000oooooooo00coool0
10000?ooooooo`0002Woool00`000?ooo`00000Yoooo00<0003oooooool05_ooo`00;oooo`80000=
oooo00<0I_ooooooool05oooo`@0000X<ol000<0000co`0co`006C?o00030000oooooooo00coool2
0000:oooo`80000Yoooo0`0001Koool003koool00`1Vooooooooo`0Eoooo0P0002`co`000`0003?o
03?o000J<ol00P0007goool003koool00`1Vooooooooo`0Coooo0P0002hco`0200007C?o00<0001j
oooo000noooo00<0I_ooooooool04?ooo`<0000`<ol000<0000co`0co`007c?o00H0001doooo000n
oooo00<0I_ooooooool02_ooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo000noooo00<0
I_ooooooool02P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Coool01Ol0VOooooooooooo`00000:oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`0Eoooo000/oooo00<0003oooooool03oooo`03o`2Ioooooooo01Ooool00`000?oo
ooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo02Woool00`000?ooooooo`0Yoooo00<0
003oooooool05Oooo`00?_ooo`03o`2Ioooooooo04?oool00`000?ooooooo`2Ioooo000noooo00?o
09Woooooool0@oooo`030000oooooooo09Woool003koool00ol0VOooooooo`13oooo0P0009[oool0
03koool00ol0VOooooooo`13oooo00<0003oooooool0VOooo`00?_ooo`03o`2Ioooooooo04?oool0
0`000?ooooooo`2Ioooo000noooo00?o09Woooooool0@oooo`030000oooooooo09Woool003koool0
0ol0VOooooooo`13oooo0P0009[oool003koool00ol0VOooooooo`13oooo00<0003oooooool0VOoo
o`00?_ooo`03o`2Ioooooooo04?oool00`000?ooooooo`2Ioooo000noooo00?o09Woooooool0@ooo
o`030000oooooooo09Woool003koool00ol0VOooooooo`13oooo00<0003oooooool0VOooo`00?_oo
o`03o`2Ioooooooo04?oool20000V_ooo`00?_ooo`03o`2Ioooooooo04?oool00`000?ooooooo`2I
oooo000noooo00?o09Woooooool0@oooo`030000oooooooo09Woool003koool00ol0VOooooooo`13
oooo00<0003oooooool0VOooo`00?_ooo`03o`2Ioooooooo04?oool20000V_ooo`00?_ooo`03o`2I
oooooooo04?oool00`000?ooooooo`2Ioooo000noooo00?o09Woooooool0@oooo`030000oooooooo
09Woool003koool00ol0VOooooooo`0koooo1@0000?oool00`000?ooooooo`2Ioooo000noooo00?o
09Woooooool0?Oooo`030000oooooooo00?oool00`000?ooooooo`2Ioooo000noooo00?o09Wooooo
ool0?Oooo`030000oooooooo00?oool30000VOooo`00?_ooo`03o`2Ioooooooo03goool00`000?oo
ooooo`03oooo00<0003oooooool0VOooo`00?_ooo`03o`2Ioooooooo03goool00`000?ooooooo`03
oooo00<0003oooooool0VOooo`00?_ooo`03o`2Ioooooooo03coool200001Oooo`030000oooooooo
09Woool003koool00ol0VOooooooo`13oooo0P0009[oool003koool00ol0VOooooooo`13oooo00<0
003oooooool0VOooo`00?_ooo`03o`2Ioooooooo04?oool00`000?ooooooo`2Ioooo000noooo00?o
09Woooooool0@oooo`030000oooooooo09Woool003koool00ol0VOooooooo`13oooo00<0003ooooo
ool0VOooo`00?_ooo`03o`2Ioooooooo04?oool20000V_ooo`00?_ooo`03o`2Ioooooooo04?oool0
0`000?ooooooo`2Ioooo000noooo00?o09Woooooool0@oooo`030000oooooooo09Woool003koool0
0ol0VOooooooo`13oooo00<0003oooooool0VOooo`00?_ooo`03o`2Ioooooooo04?oool20000V_oo
o`00?_ooo`03o`2Ioooooooo04?oool00`000?ooooooo`2Ioooo000noooo00?o09Woooooool0@ooo
o`030000oooooooo09Woool003koool00ol0VOooooooo`13oooo00<0003oooooool0VOooo`00?_oo
o`03o`2Ioooooooo04?oool00`000?ooooooo`2Ioooo000noooo00?o09Woooooool0@oooo`80002J
oooo000noooo00?o09Woooooool0@oooo`030000oooooooo09Woool003koool00ol0VOooooooo`0k
oooo100000Coool00`000?ooooooo`2Ioooo000noooo00?o09Woooooool0>oooo`030000oooooooo
00Goool00`000?ooooooo`2Ioooo000noooo00?o09Woooooool0??ooo`030000oooooooo00Coool3
0000VOooo`00?_ooo`03o`2Ioooooooo03goool00`000?ooooooo`03oooo00<0003oooooool0VOoo
o`00?_ooo`03o`2Ioooooooo03_oool010000?ooooooo`0000Coool00`000?ooooooo`2Ioooo000n
oooo00?o09Woooooool0??ooo`800005oooo00<0003oooooool0VOooo`00?_ooo`03o`2Ioooooooo
04?oool20000V_ooo`00?_ooo`03o`2Ioooooooo04?oool00`000?ooooooo`2Ioooo000noooo00?o
09Woooooool0@oooo`030000oooooooo09Woool003koool00ol0VOooooooo`13oooo00<0003ooooo
ool0VOooo`00?_ooo`03o`2Ioooooooo04?oool00`000?ooooooo`2Ioooo000noooo00?o09Wooooo
ool0@oooo`80002Joooo000noooo00?o09Woooooool0@oooo`030000oooooooo09Woool003koool0
0ol0VOooooooo`13oooo00<0003oooooool0VOooo`00?_ooo`03o`2Ioooooooo04?oool00`000?oo
ooooo`2Ioooo000noooo00?o09Woooooool0@oooo`80002Joooo000noooo00?o09Woooooool0@ooo
o`030000oooooooo09Woool003koool00ol0VOooooooo`13oooo00<0003oooooool0VOooo`00?_oo
o`03o`2Ioooooooo04?oool00`000?ooooooo`2Ioooo000noooo00?o09Woooooool0@oooo`030000
oooooooo09Woool003koool00ol0VOooooooo`13oooo0P0009[oool003koool00ol0VOooooooo`13
oooo00<0003oooooool0VOooo`00?_ooo`03o`2Ioooooooo03coool200001Oooo`030000oooooooo
09Woool003koool00ol0VOooooooo`0koooo00@0003oooooool00004oooo00<0003oooooool0VOoo
o`00?_ooo`03o`2Ioooooooo03goool00`000?ooooooo`03oooo0`0009Woool003koool00ol0VOoo
ooooo`0noooo00<0003oooooool00_ooo`030000oooooooo09Woool003koool00ol0VOooooooo`0k
oooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00?_ooo`03o`2Ioooooooo03coool2
00001Oooo`030000oooooooo09Woool003koool00ol0VOooooooo`13oooo00<0003oooooool0VOoo
o`00?_ooo`03o`2Ioooooooo04?oool20000V_ooo`00?_ooo`03o`2Ioooooooo04?oool00`000?oo
ooooo`2Ioooo000noooo00?o09Woooooool0@oooo`030000oooooooo09Woool003koool00ol0VOoo
ooooo`13oooo00<0003oooooool0VOooo`00?_ooo`03o`2Ioooooooo04?oool20000V_ooo`00?_oo
o`03o`2Ioooooooo04?oool00`000?ooooooo`2Ioooo000noooo00?o09Woooooool0@oooo`030000
oooooooo09Woool003koool00ol0VOooooooo`13oooo00<0003oooooool0VOooo`00?_ooo`03o`2I
oooooooo04?oool00`000?ooooooo`2Ioooo000noooo00?o09Woooooool0@oooo`80002Joooo000n
oooo00?o09Woooooool0@oooo`030000oooooooo09Woool003koool00ol0VOooooooo`13oooo00<0
003oooooool0VOooo`00?_ooo`03o`2Ioooooooo04?oool00`000?ooooooo`2Ioooo000noooo00?o
09Woooooool0@oooo`80002Joooo000noooo00?o09Woooooool0@oooo`030000oooooooo09Woool0
03koool00ol0VOooooooo`13oooo00<0003oooooool0VOooo`00?_ooo`03o`2Ioooooooo03goool3
00000oooo`030000oooooooo09Woool003koool00ol0VOooooooo`0noooo00<0003oooooool00_oo
o`030000oooooooo09Woool003koool00ol0VOooooooo`0koooo1@0000?oool30000VOooo`00O?oo
o`040000oooooooo0000X?ooo`00OOooo`030000oooo00000:3oool007koool20000X?ooo`00oooo
ob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool0
0`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`0>oooo0`0000;oool200000oooo`@00003oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01?ooo`@00006oooo00<0003oooooool01_ooo`030000oooooooo00Coool00`000?oo
ooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01?oool500002?ooo`030000
oooooooo00Coool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000001Koool00`000?ooo`000008oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo01Soool200002Oooo`800003oooo00<0003oooooool0NOooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.16408 .26487 L
.18221 .26487 L
.18703 .26487 L
.18957 .26487 L
.19227 .26487 L
.19462 .26487 L
.19527 .26487 L
.19596 .26487 L
s
.19596 .26487 m
.19646 .61803 L
s
0 .4 1 r
.02381 .2425 m
.04262 .23707 L
.06244 .22992 L
.08255 .22079 L
.10458 .20803 L
.12415 .19364 L
.14509 .1742 L
.16639 .14901 L
.17617 .13524 L
.18653 .11888 L
.19111 .11102 L
.19364 .10651 L
.19488 .10423 L
.19604 .1021 L
.19669 .10087 L
.19739 .26487 L
.19816 .26487 L
.19886 .26487 L
.20144 .26487 L
.20651 .26487 L
.22495 .26487 L
.26501 .26487 L
.30357 .26487 L
.34457 .26487 L
.38406 .26487 L
.42203 .26487 L
.46245 .26487 L
.50136 .26487 L
.54272 .26487 L
.58257 .26487 L
.6209 .26487 L
.66168 .26487 L
.70095 .26487 L
.7387 .26487 L
.7789 .26487 L
.81759 .26487 L
.85873 .26487 L
.89835 .26487 L
.93646 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool004;oool00`1Vooooooooo`0aoooo00<0000co`0c
o`002S?o0080002Koooo0011oooo0P1Voc;oool00`0003?o03?o000<<ol00P0009[oool0047oool2
06Ko<Oooo`030000<ol0<ol000dco`000`000?ooooooo`2Ioooo0010oooo00<0I_ooool0I_l0<?oo
o`030000<ol0<ol000hco`020000V_ooo`00?oooo`0406Kooooooooo06Ko<?ooo`030000<ol0<ol0
00hco`000`0003?o0000002Ioooo000noooo00D0I_ooooooooooool0I_l0;oooo`030000<ol0<ol0
00lco`02000000<co`00003oool0Uoooo`00?_ooo`0506Kooooooooooooo06Ko02ooool00`0003?o
03?o000?<ol000@0000co`0co`00002Hoooo000moooo00<0I_ooooooool00_ooo`0306Kooooooooo
02coool00`0003?o03?o000@<ol000D0000co`0co`0co`000000Uoooo`00?Oooo`0306Kooooooooo
00;oool00`1Vooooooooo`0/oooo00<0000co`0co`0043?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo000loooo00<0I_ooooooool00oooo`0306Kooooooooo02_oool00`0003?o03?o000A
<ol000<0000co`0co`000S?o00030000oooooooo09Coool003_oool00`1Vooooooooo`04oooo00<0
I_ooooooool0:_ooo`030000<ol0<ol0018co`02000013?o00030000oooooooo09?oool003_oool0
0`1Vooooooooo`04oooo00<0I_ooooooool0:Oooo`030000<ol0<ol001<co`000`0003?o03?o0004
<ol000<0003oooooool0T_ooo`00>_ooo`0306Kooooooooo00Goool00`1Vooooooooo`0Yoooo00<0
000co`0co`004c?o00030000<ol0<ol000@co`000`000?ooooooo`2Boooo000ioooo00<0I_oooooo
ool01_ooo`0306Kooooooooo02Soool00`0003?o03?o000D<ol000<0000co`0co`001C?o00030000
oooooooo097oool003Soool00`1Vooooooooo`07oooo00<0I_ooooooool09oooo`030000<ol0<ol0
01Dco`0200001c?o00030000oooooooo093oool003Ooool00`1Vooooooooo`08oooo00<0I_oooooo
ool09_ooo`030000<ol0<ol001Hco`000`0003?o03?o0006<ol000<0003oooooool0T?ooo`00=ooo
o`0306Kooooooooo00Soool00`1Vooooooooo`0Voooo00<0000co`0co`005S?o00030000<ol0<ol0
00Lco`000`000?ooooooo`2?oooo000foooo00<0I_ooooooool02Oooo`0306Kooooooooo02Goool0
0`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0003oooooool0S_ooo`00=Ooo
o`0306Kooooooooo00[oool00`1Vooooooooo`0Toooo00<0000co`0co`004S?o00030000<ol0<ol0
00<co`000`0003?o03?o0008<ol000<0003oooooool0S_ooo`00=?ooo`0306Kooooooooo00_oool0
0`1Vooooooooo`0Soooo00<0000co`0co`004c?o00030000<ol0<ol000<co`0300002C?o00030000
oooooooo08goool003?oool00`1Vooooooooo`0<oooo00<0I_ooooooool08oooo`030000<ol0<ol0
00/co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?oo
o`00<_ooo`0306Kooooooooo00goool00`1Vooooooooo`0Roooo00<0000co`0co`0053?o00030000
<ol0<ol000<co`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00<Oooo`0306Kooooooooo
00koool00`1Vooooooooo`0Qoooo00<0000co`0co`0053?o00800005<ol000<0000co`0co`002c?o
00030000oooooooo08_oool0033oool00`1Vooooooooo`0?oooo00<0I_ooooooool08Oooo`030000
<ol0<ol001/co`0200003C?o00030000oooooooo08[oool002ooool00`1Vooooooooo`0@oooo00<0
I_ooooooool08?ooo`030000<ol0<ol001`co`000`0003?o03?o000=<ol000<0003oooooool0ROoo
o`00;Oooo`80I_lCoooo00<0I_ooooooool07oooo`030000<ol0<ol001dco`000`0003?o03?o000>
<ol000<0003oooooool0R?ooo`00;?ooo`0306Kooooooooo01?oool00`1Vooooooooo`0Noooo00<0
000co`0co`007S?o00030000<ol0<ol000lco`000`000?ooooooo`27oooo000[oooo00<0I_oooooo
ool05?ooo`0306Kooooooooo01koool00`0003?o03?o000N<ol000<0000co`0co`0043?o00030000
oooooooo08Koool002Woool206Ko5oooo`0306Kooooooooo01goool00`0003?o03?o000O<ol00P00
018co`000`000?ooooooo`25oooo000Woooo0P1VoaWoool00`1Vooooooooo`0Loooo00<0000co`0c
o`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000Toooo0`1Vo`Soool300004?oo
o`0306Kooooooooo01Coool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo
017oool40000:_ooo`<0000Woooo0`0001Ooool002;oool206Ko3?ooo`030000oooooooo00ooool0
0`1Vooooooooo`0Doooo00<0003oooooool00_ooo`030000<ol0<ol002<co`000`0003?o03?o000D
<ol000<0003oooooool04?ooo`030000oooooooo02coool00`000?ooooooo`0Voooo00@0003ooooo
ool0000Foooo000Ooooo0`1Vo`_oool500004?ooo`0306Kooooooooo01Goool010000?ooooooo`00
02Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003oooooool0000F
oooo000Moooo0P1Vo`Soool400000_ooo`040000oooooooo00004Oooo`0306Kooooooooo00koool4
00001?ooo`80000W<ol000<0000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0W
oooo00@0003oooooool0000Xoooo0`0001Ooool001[oool306Ko4Oooo`030000oooo0000017oool0
0`1Vooooooooo`0Doooo0P000003<ol00000<ol002Hco`000`0003?o03?o000H<ol000<0003ooooo
ool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool00`000?ooooooo`0Foooo000H
oooo0P1VoaGoool200004Oooo`0306Kooooooooo01?oool40000:3?o00030000<ol0<ol001Tco`00
0`000?ooooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo000Foooo0P1Vob[oool00`1Voooo
ooooo`0Aoooo0P0002`co`000`0003?o03?o000J<ol00P0007goool004;oool00`1Vooooooooo`0?
oooo0P0002hco`0200007C?o00<0001joooo0012oooo00<0I_ooooooool03?ooo`<0000`<ol000<0
000co`0co`007c?o00H0001doooo0012oooo00<0I_ooooooool01_ooo`H0000c<ol000<0000co`0c
o`009C?o00<0001aoooo0011oooo00<00000I_l000001`0003Tco`000`0003?o03?o000X<ol02P00
06Ooool0013ooooo00004Oooo`005_ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`0Eoooo000/oooo00<0003oooooool04oooo`03o`2I
oooooooo01?oool00`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo02Woool0
0`000?ooooooo`0Yoooo00<0003oooooool05Oooo`00@_ooo`03o`2Ioooooooo03ooool00`000?oo
ooooo`2Ioooo0012oooo00?o09Woooooool0?oooo`030000oooooooo09Woool004;oool00ol0VOoo
ooooo`0ooooo0P0009[oool004;oool00ol0VOooooooo`0ooooo00<0003oooooool0VOooo`00@_oo
o`03o`2Ioooooooo03ooool00`000?ooooooo`2Ioooo0012oooo00?o09Woooooool0?oooo`030000
oooooooo09Woool004;oool00ol0VOooooooo`0ooooo0P0009[oool004;oool00ol0VOooooooo`0o
oooo00<0003oooooool0VOooo`00@_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`2Ioooo0012
oooo00?o09Woooooool0?oooo`030000oooooooo09Woool004;oool00ol0VOooooooo`0ooooo00<0
003oooooool0VOooo`00@_ooo`03o`2Ioooooooo03ooool20000V_ooo`00@_ooo`03o`2Ioooooooo
03ooool00`000?ooooooo`2Ioooo0012oooo00?o09Woooooool0?oooo`030000oooooooo09Woool0
04;oool00ol0VOooooooo`0ooooo00<0003oooooool0VOooo`00@_ooo`03o`2Ioooooooo03ooool2
0000V_ooo`00@_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`2Ioooo0012oooo00?o09Wooooo
ool0?oooo`030000oooooooo09Woool004;oool00ol0VOooooooo`0goooo1@0000?oool00`000?oo
ooooo`2Ioooo0012oooo00?o09Woooooool0>Oooo`030000oooooooo00?oool00`000?ooooooo`2I
oooo0012oooo00?o09Woooooool0>Oooo`030000oooooooo00?oool30000VOooo`00@_ooo`03o`2I
oooooooo03Woool00`000?ooooooo`03oooo00<0003oooooool0VOooo`00@_ooo`03o`2Ioooooooo
03Woool00`000?ooooooo`03oooo00<0003oooooool0VOooo`00@_ooo`03o`2Ioooooooo03Soool2
00001Oooo`030000oooooooo09Woool004;oool00ol0VOooooooo`0ooooo0P0009[oool004;oool0
0ol0VOooooooo`0ooooo00<0003oooooool0VOooo`00@_ooo`03o`2Ioooooooo03ooool00`000?oo
ooooo`2Ioooo0012oooo00?o09Woooooool0?oooo`030000oooooooo09Woool004;oool00ol0VOoo
ooooo`0ooooo00<0003oooooool0VOooo`00@_ooo`03o`2Ioooooooo03ooool20000V_ooo`00@_oo
o`03o`2Ioooooooo03ooool00`000?ooooooo`2Ioooo0012oooo00?o09Woooooool0?oooo`030000
oooooooo09Woool004;oool00ol0VOooooooo`0ooooo00<0003oooooool0VOooo`00@_ooo`03o`2I
oooooooo03ooool20000V_ooo`00@_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`2Ioooo0012
oooo00?o09Woooooool0?oooo`030000oooooooo09Woool004;oool00ol0VOooooooo`0ooooo00<0
003oooooool0VOooo`00@_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`2Ioooo0012oooo00?o
09Woooooool0?oooo`80002Joooo0012oooo00?o09Woooooool0?oooo`030000oooooooo09Woool0
04;oool00ol0VOooooooo`0goooo100000Coool00`000?ooooooo`2Ioooo0012oooo00?o09Wooooo
ool0=oooo`030000oooooooo00Goool00`000?ooooooo`2Ioooo0012oooo00?o09Woooooool0>?oo
o`030000oooooooo00Coool30000VOooo`00@_ooo`03o`2Ioooooooo03Woool00`000?ooooooo`03
oooo00<0003oooooool0VOooo`00@_ooo`03o`2Ioooooooo03Ooool010000?ooooooo`0000Coool0
0`000?ooooooo`2Ioooo0012oooo00?o09Woooooool0>?ooo`800005oooo00<0003oooooool0VOoo
o`00@_ooo`03o`2Ioooooooo03ooool20000V_ooo`00@_ooo`03o`2Ioooooooo03ooool00`000?oo
ooooo`2Ioooo0012oooo00?o09Woooooool0?oooo`030000oooooooo09Woool004;oool00ol0VOoo
ooooo`0ooooo00<0003oooooool0VOooo`00@_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`2I
oooo0012oooo00?o09Woooooool0?oooo`80002Joooo0012oooo00?o09Woooooool0?oooo`030000
oooooooo09Woool004;oool00ol0VOooooooo`0ooooo00<0003oooooool0VOooo`00@_ooo`03o`2I
oooooooo03ooool00`000?ooooooo`2Ioooo0012oooo00?o09Woooooool0?oooo`80002Joooo0012
oooo00?o09Woooooool0?oooo`030000oooooooo09Woool004;oool00ol0VOooooooo`0ooooo00<0
003oooooool0VOooo`00@_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`2Ioooo0012oooo00?o
09Woooooool0?oooo`030000oooooooo09Woool004;oool00ol0VOooooooo`0ooooo0P0009[oool0
04;oool00ol0VOooooooo`0ooooo00<0003oooooool0VOooo`00@_ooo`03o`2Ioooooooo03Soool2
00001Oooo`030000oooooooo09Woool004;oool00ol0VOooooooo`0goooo00@0003oooooool00004
oooo00<0003oooooool0VOooo`00@_ooo`03o`2Ioooooooo03Woool00`000?ooooooo`03oooo0`00
09Woool004;oool00ol0VOooooooo`0joooo00<0003oooooool00_ooo`030000oooooooo09Woool0
04;oool00ol0VOooooooo`0goooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00@_oo
o`03o`2Ioooooooo03Soool200001Oooo`030000oooooooo09Woool004;oool00ol0VOooooooo`0o
oooo00<0003oooooool0VOooo`00@_ooo`03o`2Ioooooooo03ooool20000V_ooo`00@_ooo`03o`2I
oooooooo03ooool00`000?ooooooo`2Ioooo0012oooo00?o09Woooooool0?oooo`030000oooooooo
09Woool004;oool00ol0VOooooooo`0ooooo00<0003oooooool0VOooo`00@_ooo`03o`2Ioooooooo
03ooool20000V_ooo`00@_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`2Ioooo0012oooo00?o
09Woooooool0?oooo`030000oooooooo09Woool004;oool00ol0VOooooooo`0ooooo00<0003ooooo
ool0VOooo`00@_ooo`03o`2Ioooooooo03ooool00`000?ooooooo`2Ioooo0012oooo00?o09Wooooo
ool0?oooo`80002Joooo0012oooo00?o09Woooooool0?oooo`030000oooooooo09Woool004;oool0
0ol0VOooooooo`0ooooo00<0003oooooool0VOooo`00@_ooo`03o`2Ioooooooo03ooool00`000?oo
ooooo`2Ioooo0012oooo00?o09Woooooool0?oooo`80002Joooo0012oooo00?o09Woooooool0?ooo
o`030000oooooooo09Woool004;oool00ol0VOooooooo`0ooooo00<0003oooooool0VOooo`00@_oo
o`03o`2Ioooooooo03Woool300000oooo`030000oooooooo09Woool004;oool00ol0VOooooooo`0j
oooo00<0003oooooool00_ooo`030000oooooooo09Woool004;oool00ol0VOooooooo`0goooo1@00
00?oool30000VOooo`00O?ooo`040000oooooooo0000X?ooo`00OOooo`030000oooo00000:3oool0
07koool20000X?ooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000
oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo
07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0>oooo0`0000;oool2
00001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Coool400001_ooo`030000oooooooo00Ooool00`000?ooooooo`1k
oooo001joooo00<0003oooooool00_ooo`030000oooooooo01?oool500002Oooo`030000oooooooo
07[oool007_oool00`000?ooooooo`0500004_ooo`040000oooooooo00002Oooo`030000oooooooo
07_oool007_oool01@000?ooooooooooo`00000Foooo00<0003oool000002Oooo`030000oooooooo
07_oool007coool00`000?ooooooo`0Hoooo0P0000Soool00`000?ooooooo`1loooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.20178 .26487 L
.20742 .26487 L
.21019 .26487 L
.2114 .26487 L
.21274 .26487 L
.21394 .26487 L
s
.21394 .26487 m
.21439 .61803 L
s
0 .4 1 r
.02381 .24656 m
.04262 .24211 L
.06244 .23626 L
.08255 .22878 L
.10458 .21834 L
.12415 .20656 L
.14509 .19065 L
.16639 .17003 L
.18653 .14536 L
.19623 .13133 L
.20154 .12298 L
.20651 .1147 L
.21074 .10728 L
.21195 .10508 L
.21311 .10296 L
.21415 .10103 L
.21528 .26487 L
.21656 .26487 L
.21771 .26487 L
.22029 .26487 L
.22495 .26487 L
.26501 .26487 L
.30357 .26487 L
.34457 .26487 L
.38406 .26487 L
.42203 .26487 L
.46245 .26487 L
.50136 .26487 L
.54272 .26487 L
.58257 .26487 L
.6209 .26487 L
.66168 .26487 L
.70095 .26487 L
.7387 .26487 L
.7789 .26487 L
.81759 .26487 L
.85873 .26487 L
.89835 .26487 L
.93646 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool004Koool00`1Vooooooooo`0]oooo00<0000co`0c
o`002S?o0080002Koooo0016oooo00<0I_ooooooool0;?ooo`030000<ol0<ol000`co`020000V_oo
o`00AOooo`80I_l]oooo00<0000co`0co`003C?o00030000oooooooo09Woool004Goool206Ko;?oo
o`030000<ol0<ol000hco`020000V_ooo`00A?ooo`0306Kooooo06Ko02coool00`0003?o03?o000>
<ol000<0000co`000000VOooo`00@oooo`0406Kooooooooo06Ko:oooo`030000<ol0<ol000lco`02
000000<co`00003oool0Uoooo`00@_ooo`0506Kooooooooooooo06Ko02_oool00`0003?o03?o000?
<ol000@0000co`0co`00002Hoooo0012oooo00D0I_ooooooooooool0I_l0:_ooo`030000<ol0<ol0
010co`001@0003?o03?o03?o0000002Goooo0011oooo00<0I_ooooooool00_ooo`0306Kooooooooo
02Soool00`0003?o03?o000@<ol000<0000co`0co`000S?o00030000oooooooo09Coool0043oool0
0`1Vooooooooo`03oooo00<0I_ooooooool09oooo`030000<ol0<ol0014co`000`0003?o03?o0002
<ol000<0003oooooool0U?ooo`00@?ooo`0306Kooooooooo00?oool00`1Vooooooooo`0Voooo00<0
000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00?oooo`0306Kooooooooo00Coool0
0`1Vooooooooo`0Uoooo00<0000co`0co`004c?o00030000<ol0<ol000@co`000`000?ooooooo`2B
oooo000noooo00<0I_ooooooool01Oooo`0306Kooooooooo02Goool00`0003?o03?o000C<ol000<0
000co`0co`0013?o00030000oooooooo09;oool003goool00`1Vooooooooo`06oooo00<0I_oooooo
ool09?ooo`030000<ol0<ol001@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00??oo
o`0306Kooooooooo00Ooool00`1Vooooooooo`0Soooo00<0000co`0co`005C?o00800007<ol000<0
003oooooool0T?ooo`00??ooo`0306Kooooooooo00Ooool00`1Vooooooooo`0Roooo00<0000co`0c
o`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`2@oooo000koooo00<0I_ooooooool02?oo
o`0306Kooooooooo02;oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000oooooooo
08ooool003[oool00`1Vooooooooo`09oooo00<0I_ooooooool08Oooo`030000<ol0<ol000lco`05
00000c?o00030000<ol0<ol000Pco`000`000?ooooooo`2>oooo000ioooo00<0I_ooooooool02_oo
o`0306Kooooooooo023oool00`0003?o03?o000B<ol000<0000co`0co`000c?o00030000<ol0<ol0
00Pco`000`000?ooooooo`2>oooo000hoooo00<0I_ooooooool02oooo`0306Kooooooooo01ooool0
0`0003?o03?o000C<ol000<0000co`0co`000c?o00<00009<ol000<0003oooooool0SOooo`00=ooo
o`0306Kooooooooo00coool00`1Vooooooooo`0Ooooo00<0000co`0co`002c?o00@00004<ol000<0
000co`0co`000c?o00030000<ol0<ol000Xco`000`000?ooooooo`2<oooo000foooo00<0I_oooooo
ool03_ooo`0306Kooooooooo01goool00`0003?o03?o000D<ol000<0000co`0co`000c?o00030000
<ol0<ol000/co`000`000?ooooooo`2;oooo000eoooo00<0I_ooooooool03oooo`0306Kooooooooo
01coool00`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Rooo
o`00=?ooo`0306Kooooooooo013oool00`1Vooooooooo`0Loooo00<0000co`0co`006c?o0080000=
<ol000<0003oooooool0R_ooo`00<_ooo`80I_lCoooo00<0I_ooooooool06oooo`030000<ol0<ol0
01`co`000`0003?o03?o000=<ol000<0003oooooool0ROooo`00<Oooo`0306Kooooooooo01?oool0
0`1Vooooooooo`0Joooo00<0000co`0co`007C?o00030000<ol0<ol000hco`000`000?ooooooo`28
oooo000`oooo00<0I_ooooooool05?ooo`0306Kooooooooo01Woool00`0003?o03?o000N<ol000<0
000co`0co`003c?o00030000oooooooo08Ooool002koool206Ko5oooo`0306Kooooooooo01Woool0
0`0003?o03?o000N<ol000<0000co`0co`0043?o00030000oooooooo08Koool002coool206Ko6Ooo
o`0306Kooooooooo01Soool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25oooo000[
oooo00<0I_ooooooool06Oooo`0306Kooooooooo01Ooool00`0003?o03?o000P<ol000<0000co`0c
o`004S?o00030000oooooooo08Coool002Woool206Ko1?ooo`<0000Eoooo00<0I_ooooooool03ooo
o`@00002oooo0P0002<co`000`0003?o03?o000C<ol000<0003oooooool04Oooo`@0000Zoooo0`00
02Ooool300005oooo`009oooo`80I_l7oooo00<0003oooooool05?ooo`0306Kooooooooo00ooool0
0`000?ooooooo`02oooo00<0000co`0co`008c?o00030000<ol0<ol001@co`000`000?ooooooo`0@
oooo00<0003oooooool0;?ooo`030000oooooooo02Koool010000?ooooooo`0001Koool002Coool3
06Ko1_ooo`D0000Eoooo00<0I_ooooooool04?ooo`040000oooooooo00009S?o0080000F<ol00P00
017oool00`000?ooooooo`0Xoooo1@0002Ooool010000?ooooooo`0001Koool002;oool206Ko0ooo
o`@00002oooo00@0003oooooool0000Foooo00<0I_ooooooool02Oooo`@00004oooo0P0002Lco`00
0`0003?o03?o000G<ol000<0003oooooool03oooo`030000oooooooo02Ooool010000?ooooooo`00
02Soool300005oooo`007_ooo`@0I_l<oooo00<0003oool000005_ooo`0306Kooooooooo00ooool2
000000<co`00000co`009S?o00030000<ol0<ol001Pco`000`000?ooooooo`0<oooo00@0003ooooo
ool0000Yoooo00<0003oool00000:Oooo`030000oooooooo01Koool001[oool406Ko4Oooo`80000F
oooo00<0I_ooooooool03_ooo`@0000X<ol000<0000co`0co`006C?o00030000oooooooo00coool2
0000:oooo`80000Yoooo0`0001Koool001Soool206Ko;Oooo`0306Kooooooooo00coool20000;3?o
00030000<ol0<ol001Xco`020000OOooo`005_ooo`80I_l_oooo00<0I_ooooooool02_ooo`80000^
<ol00P0001dco`030000N_ooo`00Aoooo`0306Kooooooooo00Ooool30000<3?o00030000<ol0<ol0
01lco`060000M?ooo`00Aoooo`0406Kooooooooooooo1P0003<co`000`0003?o03?o000U<ol00`00
077oool0047oool6000000@0I_l000000000000i<ol000<0000co`0co`00:3?o00X0001Woooo000@
ooooo`00017oool001Koool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00D0003ooooooooooooo09T01_ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool05Oooo`00;?ooo`030000oooooooo01Ooool00ol0VOoo
ooooo`0?oooo00<0003oooooool0:Oooo`030000oooooooo02Woool00`000?ooooooo`0Yoooo00<0
003oooooool0:Oooo`030000oooooooo01Goool004Koool00ol0VOooooooo`0koooo00<0003ooooo
ool0VOooo`00A_ooo`03o`2Ioooooooo03_oool00`000?ooooooo`2Ioooo0016oooo00?o09Wooooo
ool0>oooo`80002Joooo0016oooo00?o09Woooooool0>oooo`030000oooooooo09Woool004Koool0
0ol0VOooooooo`0koooo00<0003oooooool0VOooo`00A_ooo`03o`2Ioooooooo03_oool00`000?oo
ooooo`2Ioooo0016oooo00?o09Woooooool0>oooo`80002Joooo0016oooo00?o09Woooooool0>ooo
o`030000oooooooo09Woool004Koool00ol0VOooooooo`0koooo00<0003oooooool0VOooo`00A_oo
o`03o`2Ioooooooo03_oool00`000?ooooooo`2Ioooo0016oooo00?o09Woooooool0>oooo`030000
oooooooo09Woool004Koool00ol0VOooooooo`0koooo0P0009[oool004Koool00ol0VOooooooo`0k
oooo00<0003oooooool0VOooo`00A_ooo`03o`2Ioooooooo03_oool00`000?ooooooo`2Ioooo0016
oooo00?o09Woooooool0>oooo`030000oooooooo09Woool004Koool00ol0VOooooooo`0koooo0P00
09[oool004Koool00ol0VOooooooo`0koooo00<0003oooooool0VOooo`00A_ooo`03o`2Ioooooooo
03_oool00`000?ooooooo`2Ioooo0016oooo00?o09Woooooool0<oooo`D00003oooo00<0003ooooo
ool0VOooo`00A_ooo`03o`2Ioooooooo03Goool00`000?ooooooo`03oooo00<0003oooooool0VOoo
o`00A_ooo`03o`2Ioooooooo03Goool00`000?ooooooo`03oooo0`0009Woool004Koool00ol0VOoo
ooooo`0eoooo00<0003oooooool00oooo`030000oooooooo09Woool004Koool00ol0VOooooooo`0e
oooo00<0003oooooool00oooo`030000oooooooo09Woool004Koool00ol0VOooooooo`0doooo0P00
00Goool00`000?ooooooo`2Ioooo0016oooo00?o09Woooooool0>oooo`80002Joooo0016oooo00?o
09Woooooool0>oooo`030000oooooooo09Woool004Koool00ol0VOooooooo`0koooo00<0003ooooo
ool0VOooo`00A_ooo`03o`2Ioooooooo03_oool00`000?ooooooo`2Ioooo0016oooo00?o09Wooooo
ool0>oooo`030000oooooooo09Woool004Koool00ol0VOooooooo`0koooo0P0009[oool004Koool0
0ol0VOooooooo`0koooo00<0003oooooool0VOooo`00A_ooo`03o`2Ioooooooo03_oool00`000?oo
ooooo`2Ioooo0016oooo00?o09Woooooool0>oooo`030000oooooooo09Woool004Koool00ol0VOoo
ooooo`0koooo0P0009[oool004Koool00ol0VOooooooo`0koooo00<0003oooooool0VOooo`00A_oo
o`03o`2Ioooooooo03_oool00`000?ooooooo`2Ioooo0016oooo00?o09Woooooool0>oooo`030000
oooooooo09Woool004Koool00ol0VOooooooo`0koooo00<0003oooooool0VOooo`00A_ooo`03o`2I
oooooooo03_oool20000V_ooo`00A_ooo`03o`2Ioooooooo03_oool00`000?ooooooo`2Ioooo0016
oooo00?o09Woooooool0<oooo`@00004oooo00<0003oooooool0VOooo`00A_ooo`03o`2Ioooooooo
03?oool00`000?ooooooo`05oooo00<0003oooooool0VOooo`00A_ooo`03o`2Ioooooooo03Coool0
0`000?ooooooo`04oooo0`0009Woool004Ooool00ol0VOooooooo`0doooo00<0003oooooool00ooo
o`030000oooooooo09Woool004Ooool00ol0VOooooooo`0boooo00@0003oooooool00004oooo00<0
003oooooool0VOooo`00Aoooo`03o`2Ioooooooo03?oool200001Oooo`030000oooooooo09Woool0
04Ooool00ol0VOooooooo`0joooo0P0009[oool004Ooool00ol0VOooooooo`0joooo00<0003ooooo
ool0VOooo`00Aoooo`03o`2Ioooooooo03[oool00`000?ooooooo`2Ioooo0017oooo00?o09Wooooo
ool0>_ooo`030000oooooooo09Woool004Ooool00ol0VOooooooo`0joooo00<0003oooooool0VOoo
o`00Aoooo`03o`2Ioooooooo03[oool20000V_ooo`00Aoooo`03o`2Ioooooooo03[oool00`000?oo
ooooo`2Ioooo0017oooo00?o09Woooooool0>_ooo`030000oooooooo09Woool004Ooool00ol0VOoo
ooooo`0joooo00<0003oooooool0VOooo`00Aoooo`03o`2Ioooooooo03[oool20000V_ooo`00Aooo
o`03o`2Ioooooooo03[oool00`000?ooooooo`2Ioooo0017oooo00?o09Woooooool0>_ooo`030000
oooooooo09Woool004Ooool00ol0VOooooooo`0joooo00<0003oooooool0VOooo`00Aoooo`03o`2I
oooooooo03[oool00`000?ooooooo`2Ioooo0017oooo00?o09Woooooool0>_ooo`80002Joooo0017
oooo00?o09Woooooool0>_ooo`030000oooooooo09Woool004Ooool00ol0VOooooooo`0coooo0P00
00Goool00`000?ooooooo`2Ioooo0017oooo00?o09Woooooool0<_ooo`040000oooooooo00001?oo
o`030000oooooooo09Woool004Ooool00ol0VOooooooo`0doooo00<0003oooooool00oooo`<0002I
oooo0017oooo00?o09Woooooool0=Oooo`030000oooooooo00;oool00`000?ooooooo`2Ioooo0017
oooo00?o09Woooooool0<_ooo`040000oooooooo00001?ooo`030000oooooooo09Woool004Ooool0
0ol0VOooooooo`0coooo0P0000Goool00`000?ooooooo`2Ioooo0017oooo00?o09Woooooool0>_oo
o`030000oooooooo09Woool004Ooool00ol0VOooooooo`0joooo0P0009[oool004Ooool00ol0VOoo
ooooo`0joooo00<0003oooooool0VOooo`00Aoooo`03o`2Ioooooooo03[oool00`000?ooooooo`2I
oooo0017oooo00?o09Woooooool0>_ooo`030000oooooooo09Woool004Ooool00ol0VOooooooo`0j
oooo0P0009[oool004Ooool00ol0VOooooooo`0joooo00<0003oooooool0VOooo`00Aoooo`03o`2I
oooooooo03[oool00`000?ooooooo`2Ioooo0017oooo00?o09Woooooool0>_ooo`030000oooooooo
09Woool004Ooool00ol0VOooooooo`0joooo00<0003oooooool0VOooo`00Aoooo`03o`2Ioooooooo
03[oool20000V_ooo`00Aoooo`03o`2Ioooooooo03[oool00`000?ooooooo`2Ioooo0017oooo00?o
09Woooooool0>_ooo`030000oooooooo09Woool004Ooool00ol0VOooooooo`0joooo00<0003ooooo
ool0VOooo`00Aoooo`03o`2Ioooooooo03[oool20000V_ooo`00Aoooo`03o`2Ioooooooo03[oool0
0`000?ooooooo`2Ioooo0017oooo00?o09Woooooool0>_ooo`030000oooooooo09Woool004Ooool0
0ol0VOooooooo`0doooo0`0000?oool00`000?ooooooo`2Ioooo0017oooo00?o09Woooooool0=Ooo
o`030000oooooooo00;oool00`000?ooooooo`2Ioooo0017oooo00?o09Woooooool0<_ooo`D00003
oooo0`0009Woool007coool010000?ooooooo`000:3oool007goool00`000?ooo`00002Poooo001n
oooo0P000:3oool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?oo
ooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P00
00Coool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003ooooo
ool05Oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001h
oooo00<0003oooooool01@0001Goool00`000?ooooooo`07oooo0P0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool200000ooo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.20342 .26487 L
.21345 .26487 L
.22272 .26487 L
.22738 .26487 L
.22974 .26487 L
.23038 .26487 L
.23107 .26487 L
s
.23107 .26487 m
.23158 .61803 L
s
0 .4 1 r
.02381 .24988 m
.04262 .24624 L
.06244 .24145 L
.08255 .23533 L
.10458 .22678 L
.12415 .21714 L
.14509 .20412 L
.16639 .18724 L
.18653 .16705 L
.20481 .1443 L
.21521 .12914 L
.2203 .12106 L
.22495 .11326 L
.22729 .10919 L
.22853 .10699 L
.22985 .10462 L
.23111 .10231 L
.23226 .26487 L
.23342 .26487 L
.2345 .26487 L
.24479 .26487 L
.26581 .26487 L
.30437 .26487 L
.34537 .26487 L
.38486 .26487 L
.42283 .26487 L
.46325 .26487 L
.50216 .26487 L
.54352 .26487 L
.58337 .26487 L
.6217 .26487 L
.66248 .26487 L
.70175 .26487 L
.7395 .26487 L
.7797 .26487 L
.81839 .26487 L
.85953 .26487 L
.89915 .26487 L
.93726 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool004_oool00`1Vooooooooo`0Xoooo00<0000co`0c
o`002S?o0080002Koooo001:oooo0P1VobWoool00`0003?o03?o000<<ol00P0009[oool004[oool2
06Ko:?ooo`030000<ol0<ol000dco`000`000?ooooooo`2Ioooo0019oooo00<0I_ooool0I_l09ooo
o`030000<ol0<ol000hco`020000V_ooo`00B?ooo`0406Kooooooooo06Ko9oooo`030000<ol0<ol0
00hco`000`0003?o0000002Ioooo0018oooo00@0I_ooooooool0I_lVoooo00<0000co`0co`003c?o
008000000c?o00000?ooo`2Goooo0017oooo00D0I_ooooooooooool0I_l09_ooo`030000<ol0<ol0
00lco`00100003?o03?o000009Soool004Ooool01@1Vooooooooooooo`1Vo`0Uoooo00<0000co`0c
o`0043?o00050000<ol0<ol0<ol0000009Ooool004Koool00`1Vooooooooo`02oooo00<0I_oooooo
ool08oooo`030000<ol0<ol0010co`000`0003?o03?o0002<ol000<0003oooooool0U?ooo`00AOoo
o`0306Kooooooooo00?oool00`1Vooooooooo`0Roooo00<0000co`0co`004C?o00030000<ol0<ol0
008co`000`000?ooooooo`2Doooo0015oooo00<0I_ooooooool00oooo`0306Kooooooooo027oool0
0`0003?o03?o000B<ol00P0000@co`000`000?ooooooo`2Coooo0014oooo00<0I_ooooooool01?oo
o`0306Kooooooooo023oool00`0003?o03?o000C<ol000<0000co`0co`0013?o00030000oooooooo
09;oool004?oool00`1Vooooooooo`05oooo00<0I_ooooooool08?ooo`030000<ol0<ol001<co`00
0`0003?o03?o0004<ol000<0003oooooool0T_ooo`00@_ooo`0306Kooooooooo00Koool00`1Voooo
ooooo`0Ooooo00<0000co`0co`0053?o00030000<ol0<ol000Dco`000`000?ooooooo`2Aoooo0011
oooo00<0I_ooooooool01oooo`0306Kooooooooo01koool00`0003?o03?o000E<ol00P0000Lco`00
0`000?ooooooo`2@oooo0010oooo00<0I_ooooooool02?ooo`0306Kooooooooo01goool00`0003?o
03?o000F<ol000<0000co`0co`001S?o00030000oooooooo093oool003ooool00`1Vooooooooo`09
oooo00<0I_ooooooool07Oooo`030000<ol0<ol001Hco`000`0003?o03?o0007<ol000<0003ooooo
ool0Soooo`00?_ooo`0306Kooooooooo00[oool00`1Vooooooooo`0Loooo00<0000co`0co`003c?o
00D00003<ol000<0000co`0co`0023?o00030000oooooooo08koool003goool00`1Vooooooooo`0;
oooo00<0I_ooooooool06oooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool003coool00`1Vooooooooo`0<oooo00<0I_ooooooool06_oo
o`030000<ol0<ol001<co`000`0003?o03?o0003<ol00`0000Tco`000`000?ooooooo`2=oooo000l
oooo00<0I_ooooooool03?ooo`0306Kooooooooo01[oool00`0003?o03?o000;<ol0100000@co`00
0`0003?o03?o0003<ol000<0000co`0co`002S?o00030000oooooooo08coool003_oool00`1Voooo
ooooo`0=oooo00<0I_ooooooool06Oooo`030000<ol0<ol001@co`000`0003?o03?o0003<ol000<0
000co`0co`002c?o00030000oooooooo08_oool003[oool00`1Vooooooooo`0>oooo00<0I_oooooo
ool06?ooo`030000<ol0<ol001@co`0200001C?o00030000<ol0<ol000/co`000`000?ooooooo`2;
oooo000ioooo00<0I_ooooooool03oooo`0306Kooooooooo01Soool00`0003?o03?o000K<ol00P00
00dco`000`000?ooooooo`2:oooo000goooo0P1Voa;oool00`1Vooooooooo`0Goooo00<0000co`0c
o`0073?o00030000<ol0<ol000dco`000`000?ooooooo`29oooo000foooo00<0I_ooooooool04_oo
o`0306Kooooooooo01Koool00`0003?o03?o000M<ol000<0000co`0co`003S?o00030000oooooooo
08Soool003Goool00`1Vooooooooo`0Coooo00<0I_ooooooool05Oooo`030000<ol0<ol001hco`00
0`0003?o03?o000?<ol000<0003oooooool0Qoooo`00<oooo`80I_lFoooo00<0I_ooooooool05Ooo
o`030000<ol0<ol001hco`000`0003?o03?o000@<ol000<0003oooooool0Q_ooo`00<Oooo`80I_lH
oooo00<0I_ooooooool05?ooo`030000<ol0<ol001lco`0200004S?o00030000oooooooo08Goool0
033oool00`1Vooooooooo`0Hoooo00<0I_ooooooool04oooo`030000<ol0<ol0020co`000`0003?o
03?o000B<ol000<0003oooooool0Q?ooo`00;_ooo`0406Ko0000000000006Oooo`0306Kooooooooo
00_oool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool40000:_oo
o`<0000Woooo0`0001Ooool002coool206Ko0_ooo`030000oooooooo01Soool00`1Vooooooooo`0;
oooo00<0003oooooool00_ooo`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003ooooo
ool04?ooo`030000oooooooo02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000Z
oooo0P1Vo`03oooo0000000000<0000Ioooo00<0I_ooooooool03?ooo`040000oooooooo00009S?o
0080000F<ol00P00017oool00`000?ooooooo`0Xoooo1@0002Ooool010000?ooooooo`0001Koool0
02Ooool400000_ooo`040000oooooooo00006_ooo`0306Kooooooooo00Goool400001?ooo`80000W
<ol000<0000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003ooooo
ool0000Xoooo0`0001Ooool002?oool406Ko1oooo`030000oooo000001[oool00`1Vooooooooo`0;
oooo0P000003<ol00000<ol002Hco`000`0003?o03?o000H<ol000<0003oooooool03?ooo`040000
oooooooo0000:Oooo`030000oooo000002Woool00`000?ooooooo`0Foooo000Noooo1@1Vo`coool2
00006_ooo`0306Kooooooooo00[oool40000:3?o00030000<ol0<ol001Tco`000`000?ooooooo`0<
oooo0P0002_oool20000:Oooo`<0000Foooo000Ioooo1@1Vobgoool00`1Vooooooooo`08oooo0P00
02`co`000`0003?o03?o000J<ol00P0007goool001Koool306Ko<_ooo`0306Kooooooooo00Koool2
0000;S?o0080000M<ol00`0007[oool004_oool00`1Vooooooooo`03oooo0`00030co`000`0003?o
03?o000O<ol01P0007Coool004_oool00`1Vo`00000000030000<c?o00030000<ol0<ol002Dco`03
0000LOooo`00@Oooo`X000000`1Voc?o03?o000f<ol000<0000co`0co`00:3?o00X0001Woooo000@
ooooo`00017oool001Koool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool01_ooo`03o`2Ioooo000000[oool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool05Oooo`00;?ooo`030000oooooooo01coool00ol0VOooooooo`0:
oooo00<0003oooooool0:Oooo`030000oooooooo02Woool00`000?ooooooo`0Yoooo00<0003ooooo
ool0:Oooo`030000oooooooo01Goool004_oool00ol0VOooooooo`0foooo00<0003oooooool0VOoo
o`00Boooo`03o`2Ioooooooo03Koool00`000?ooooooo`2Ioooo001;oooo00?o09Woooooool0=_oo
o`80002Joooo001;oooo00?o09Woooooool0=_ooo`030000oooooooo09Woool004_oool00ol0VOoo
ooooo`0foooo00<0003oooooool0VOooo`00Boooo`03o`2Ioooooooo03Koool00`000?ooooooo`2I
oooo001;oooo00?o09Woooooool0=_ooo`80002Joooo001;oooo00?o09Woooooool0=_ooo`030000
oooooooo09Woool004_oool00ol0VOooooooo`0foooo00<0003oooooool0VOooo`00Boooo`03o`2I
oooooooo03Koool00`000?ooooooo`2Ioooo001;oooo00?o09Woooooool0=_ooo`030000oooooooo
09Woool004_oool00ol0VOooooooo`0foooo0P0009[oool004_oool00ol0VOooooooo`0foooo00<0
003oooooool0VOooo`00Boooo`03o`2Ioooooooo03Koool00`000?ooooooo`2Ioooo001;oooo00?o
09Woooooool0=_ooo`030000oooooooo09Woool004_oool00ol0VOooooooo`0foooo0P0009[oool0
04_oool00ol0VOooooooo`0foooo00<0003oooooool0VOooo`00Boooo`03o`2Ioooooooo03Koool0
0`000?ooooooo`2Ioooo001;oooo00?o09Woooooool0;_ooo`D00003oooo00<0003oooooool0VOoo
o`00Boooo`03o`2Ioooooooo033oool00`000?ooooooo`03oooo00<0003oooooool0VOooo`00Booo
o`03o`2Ioooooooo033oool00`000?ooooooo`03oooo0`0009Woool004_oool00ol0VOooooooo`0`
oooo00<0003oooooool00oooo`030000oooooooo09Woool004_oool00ol0VOooooooo`0`oooo00<0
003oooooool00oooo`030000oooooooo09Woool004_oool00ol0VOooooooo`0_oooo0P0000Goool0
0`000?ooooooo`2Ioooo001;oooo00?o09Woooooool0=_ooo`80002Joooo001;oooo00?o09Wooooo
ool0=_ooo`030000oooooooo09Woool004_oool00ol0VOooooooo`0foooo00<0003oooooool0VOoo
o`00Boooo`03o`2Ioooooooo03Koool00`000?ooooooo`2Ioooo001;oooo00?o09Woooooool0=_oo
o`030000oooooooo09Woool004_oool00ol0VOooooooo`0foooo0P0009[oool004_oool00ol0VOoo
ooooo`0foooo00<0003oooooool0VOooo`00Boooo`03o`2Ioooooooo03Koool00`000?ooooooo`2I
oooo001;oooo00?o09Woooooool0=_ooo`030000oooooooo09Woool004_oool00ol0VOooooooo`0f
oooo0P0009[oool004_oool00ol0VOooooooo`0foooo00<0003oooooool0VOooo`00Boooo`03o`2I
oooooooo03Koool00`000?ooooooo`2Ioooo001;oooo00?o09Woooooool0=_ooo`030000oooooooo
09Woool004_oool00ol0VOooooooo`0foooo00<0003oooooool0VOooo`00Boooo`03o`2Ioooooooo
03Koool20000V_ooo`00Boooo`03o`2Ioooooooo03Koool00`000?ooooooo`2Ioooo001;oooo00?o
09Woooooool0;_ooo`@00004oooo00<0003oooooool0VOooo`00Boooo`03o`2Ioooooooo02koool0
0`000?ooooooo`05oooo00<0003oooooool0VOooo`00Boooo`03o`2Ioooooooo02ooool00`000?oo
ooooo`04oooo0`0009Woool004_oool00ol0VOooooooo`0`oooo00<0003oooooool00oooo`030000
oooooooo09Woool004_oool00ol0VOooooooo`0^oooo00@0003oooooool00004oooo00<0003ooooo
ool0VOooo`00Boooo`03o`2Ioooooooo02ooool200001Oooo`030000oooooooo09Woool004_oool0
0ol0VOooooooo`0foooo0P0009[oool004_oool00ol0VOooooooo`0foooo00<0003oooooool0VOoo
o`00Boooo`03o`2Ioooooooo03Koool00`000?ooooooo`2Ioooo001;oooo00?o09Woooooool0=_oo
o`030000oooooooo09Woool004_oool00ol0VOooooooo`0foooo00<0003oooooool0VOooo`00Booo
o`03o`2Ioooooooo03Koool20000V_ooo`00Boooo`03o`2Ioooooooo03Koool00`000?ooooooo`2I
oooo001;oooo00?o09Woooooool0=_ooo`030000oooooooo09Woool004_oool00ol0VOooooooo`0f
oooo00<0003oooooool0VOooo`00Boooo`03o`2Ioooooooo03Koool20000V_ooo`00Boooo`03o`2I
oooooooo03Koool00`000?ooooooo`2Ioooo001;oooo00?o09Woooooool0=_ooo`030000oooooooo
09Woool004_oool00ol0VOooooooo`0foooo00<0003oooooool0VOooo`00Boooo`03o`2Ioooooooo
03Koool00`000?ooooooo`2Ioooo001;oooo00?o09Woooooool0=_ooo`80002Joooo001;oooo00?o
09Woooooool0=_ooo`030000oooooooo09Woool004_oool00ol0VOooooooo`0_oooo0P0000Goool0
0`000?ooooooo`2Ioooo001;oooo00?o09Woooooool0;_ooo`040000oooooooo00001?ooo`030000
oooooooo09Woool004_oool00ol0VOooooooo`0`oooo00<0003oooooool00oooo`<0002Ioooo001;
oooo00?o09Woooooool0<Oooo`030000oooooooo00;oool00`000?ooooooo`2Ioooo001;oooo00?o
09Woooooool0;_ooo`040000oooooooo00001?ooo`030000oooooooo09Woool004_oool00ol0VOoo
ooooo`0_oooo0P0000Goool00`000?ooooooo`2Ioooo001;oooo00?o09Woooooool0=_ooo`030000
oooooooo09Woool004_oool00ol0VOooooooo`0foooo0P0009[oool004_oool00ol0VOooooooo`0f
oooo00<0003oooooool0VOooo`00Boooo`03o`2Ioooooooo03Koool00`000?ooooooo`2Ioooo001;
oooo00?o09Woooooool0=_ooo`030000oooooooo09Woool004_oool00ol0VOooooooo`0foooo0P00
09[oool004_oool00ol0VOooooooo`0foooo00<0003oooooool0VOooo`00Boooo`03o`2Ioooooooo
03Koool00`000?ooooooo`2Ioooo001;oooo00?o09Woooooool0=_ooo`030000oooooooo09Woool0
04_oool00ol0VOooooooo`0foooo00<0003oooooool0VOooo`00Boooo`03o`2Ioooooooo03Koool2
0000V_ooo`00Boooo`03o`2Ioooooooo03Koool00`000?ooooooo`2Ioooo001;oooo00?o09Wooooo
ool0=_ooo`030000oooooooo09Woool004_oool00ol0VOooooooo`0foooo00<0003oooooool0VOoo
o`00Boooo`03o`2Ioooooooo03Koool20000V_ooo`00Boooo`03o`2Ioooooooo03Koool00`000?oo
ooooo`2Ioooo001;oooo00?o09Woooooool0=_ooo`030000oooooooo09Woool004_oool00ol0VOoo
ooooo`0`oooo0`0000?oool00`000?ooooooo`2Ioooo001;oooo00?o09Woooooool0<Oooo`030000
oooooooo00;oool00`000?ooooooo`2Ioooo001;oooo00?o09Woooooool0;_ooo`D00003oooo0`00
09Woool007coool010000?ooooooo`000:3oool007goool00`000?ooo`00002Poooo001noooo0P00
0:3oool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1i
oooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001h
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000?oool3
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Ooo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0001Goool00`000?ooooooo`06oooo0`0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000005Oooo`040000oooooooo00002Oooo`030000oooooooo00?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0`0000;oool00`000?oo
ooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.20342 .26487 L
.22272 .26487 L
.23233 .26487 L
.23739 .26487 L
.24276 .26487 L
.24502 .26487 L
.24745 .26487 L
.24816 .26487 L
.24884 .26487 L
s
.24884 .26487 m
.24935 .61803 L
s
0 .4 1 r
.02381 .2526 m
.04262 .24963 L
.06244 .2457 L
.08255 .2407 L
.10458 .2337 L
.12415 .22581 L
.14509 .21515 L
.16639 .20134 L
.18653 .18481 L
.22495 .14079 L
.23519 .12556 L
.2402 .11747 L
.24479 .10969 L
.24597 .10762 L
.24726 .10533 L
.24848 .10314 L
.24961 .26487 L
.25092 .26487 L
.25212 .26487 L
.25479 .26487 L
.26581 .26487 L
.30588 .26487 L
.34443 .26487 L
.38544 .26487 L
.42492 .26487 L
.46289 .26487 L
.50332 .26487 L
.54223 .26487 L
.58359 .26487 L
.62343 .26487 L
.66176 .26487 L
.70255 .26487 L
.74181 .26487 L
.77956 .26487 L
.81977 .26487 L
.85845 .26487 L
.89959 .26487 L
.93922 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool004ooool00`1Vooooooooo`0Toooo00<0000co`0c
o`002S?o0080002Koooo001?oooo00<0I_ooooooool08oooo`030000<ol0<ol000`co`020000V_oo
o`00C_ooo`80I_lToooo00<0000co`0co`003C?o00030000oooooooo09Woool004goool00`1Voooo
o`1Vo`0Soooo00<0000co`0co`003S?o0080002Joooo001=oooo00<0I_ooool0I_l08oooo`030000
<ol0<ol000hco`000`0003?o0000002Ioooo001<oooo00@0I_ooooooool0I_lRoooo00<0000co`0c
o`003c?o008000000c?o00000?ooo`2Goooo001<oooo00@0I_ooooooool0I_lRoooo00<0000co`0c
o`003c?o00040000<ol0<ol00000V?ooo`00Boooo`0506Kooooooooooooo06Ko027oool00`0003?o
03?o000@<ol000D0000co`0co`0co`000000Uoooo`00B_ooo`0306Kooooooooo00;oool00`1Voooo
ooooo`0Ooooo00<0000co`0co`0043?o00030000<ol0<ol0008co`000`000?ooooooo`2Doooo001:
oooo00<0I_ooooooool00_ooo`0306Kooooooooo01koool00`0003?o03?o000A<ol000<0000co`0c
o`000S?o00030000oooooooo09Coool004Woool00`1Vooooooooo`03oooo00<0I_ooooooool07Ooo
o`030000<ol0<ol0018co`02000013?o00030000oooooooo09?oool004Soool00`1Vooooooooo`04
oooo00<0I_ooooooool07?ooo`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003ooooo
ool0T_ooo`00Aoooo`0306Kooooooooo00Goool00`1Vooooooooo`0Loooo00<0000co`0co`004c?o
00030000<ol0<ol000@co`000`000?ooooooo`2Boooo0016oooo00<0I_ooooooool01_ooo`0306Ko
oooooooo01_oool00`0003?o03?o000D<ol000<0000co`0co`001C?o00030000oooooooo097oool0
04Goool00`1Vooooooooo`07oooo00<0I_ooooooool06_ooo`030000<ol0<ol001Dco`0200001c?o
00030000oooooooo093oool004Coool00`1Vooooooooo`08oooo00<0I_ooooooool06Oooo`030000
<ol0<ol001Hco`000`0003?o03?o0006<ol000<0003oooooool0T?ooo`00A?ooo`0306Kooooooooo
00Soool00`1Vooooooooo`0Ioooo00<0000co`0co`005S?o00030000<ol0<ol000Lco`000`000?oo
ooooo`2?oooo0013oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Soool00`0003?o03?o000?
<ol01@0000<co`000`0003?o03?o0008<ol000<0003oooooool0S_ooo`00@_ooo`0306Kooooooooo
00[oool00`1Vooooooooo`0Goooo00<0000co`0co`004S?o00030000<ol0<ol000<co`000`0003?o
03?o0008<ol000<0003oooooool0S_ooo`00@Oooo`0306Kooooooooo00_oool00`1Vooooooooo`0F
oooo00<0000co`0co`004c?o00030000<ol0<ol000<co`0300002C?o00030000oooooooo08goool0
043oool00`1Vooooooooo`0<oooo00<0I_ooooooool05_ooo`030000<ol0<ol000/co`04000013?o
00030000<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00?oooo`0306Ko
oooooooo00goool00`1Vooooooooo`0Eoooo00<0000co`0co`0053?o00030000<ol0<ol000<co`00
0`0003?o03?o000;<ol000<0003oooooool0Roooo`00?_ooo`0306Kooooooooo00koool00`1Voooo
ooooo`0Doooo00<0000co`0co`0053?o00800005<ol000<0000co`0co`002c?o00030000oooooooo
08_oool003coool206Ko4Oooo`0306Kooooooooo01Coool00`0003?o03?o000K<ol00P0000dco`00
0`000?ooooooo`2:oooo000koooo00<0I_ooooooool04Oooo`0306Kooooooooo01?oool00`0003?o
03?o000L<ol000<0000co`0co`003C?o00030000oooooooo08Woool003[oool00`1Vooooooooo`0B
oooo00<0I_ooooooool04_ooo`030000<ol0<ol001dco`000`0003?o03?o000><ol000<0003ooooo
ool0R?ooo`00>Oooo`0306Kooooooooo01?oool00`1Vooooooooo`0Aoooo00<0000co`0co`007S?o
00030000<ol0<ol000lco`000`000?ooooooo`27oooo000goooo0P1VoaKoool00`1Vooooooooo`0A
oooo00<0000co`0co`007S?o00030000<ol0<ol0010co`000`000?ooooooo`26oooo000foooo00<0
I_ooooooool05_ooo`0306Kooooooooo013oool00`0003?o03?o000O<ol00P00018co`000`000?oo
ooooo`25oooo000doooo0P1VoaWoool00`1Vooooooooo`0?oooo00<0000co`0co`0083?o00030000
<ol0<ol0018co`000`000?ooooooo`24oooo000_oooo0`000080I_lKoooo00<0I_ooooooool01ooo
o`@00002oooo0P0002<co`000`0003?o03?o000C<ol000<0003oooooool04Oooo`@0000Zoooo0`00
02Ooool300005oooo`00;oooo`0306Ko000006Ko01goool00`1Vooooooooo`07oooo00<0003ooooo
ool00_ooo`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000
oooooooo02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0001goool0
0`1Vooooooooo`08oooo00@0003oooooool0000V<ol00P0001Hco`0200004Oooo`030000oooooooo
02Soool500009oooo`040000oooooooo00005_ooo`009oooo`@0000206Ko00@0003oooooool0000N
oooo00@0I_ooooooooooool400001?ooo`80000W<ol000<0000co`0co`005c?o00030000oooooooo
00ooool00`000?ooooooo`0Woooo00@0003oooooool0000Xoooo0`0001Ooool002Ooool306Ko1?oo
o`030000oooo000001koool00`1Vooooooooo`07oooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000Soooo101Vo`Soool200007_ooo`0306Kooooooooo00Koool40000:3?o
00030000<ol0<ol001Tco`000`000?ooooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo000N
oooo1@1Vobcoool00`1Vooooooooo`04oooo0P0002`co`000`0003?o03?o000J<ol00P0007goool0
01Woool506Ko<Oooo`0306Kooooooooo00;oool20000;S?o0080000M<ol00`0007[oool001Koool3
06Ko=_ooo`0306Kooooo00000080000`<ol000<0000co`0co`007c?o00H0001doooo001;oooo1000
000306Ko0000<ol0038co`000`0003?o03?o000U<ol00`00077oool0047oool:000013?o000306Ko
<ol0<ol0038co`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003ooooo09T02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0E
oooo000/oooo00<0003oooooool08?ooo`03o`2Ioooooooo00Koool00`000?ooooooo`0Yoooo00<0
003oooooool0:Oooo`030000oooooooo02Woool00`000?ooooooo`0Yoooo00<0003oooooool05Ooo
o`00Coooo`03o`2Ioooooooo03;oool00`000?ooooooo`2Ioooo001?oooo00?o09Woooooool0<_oo
o`030000oooooooo09Woool004ooool00ol0VOooooooo`0boooo0P0009[oool004ooool00ol0VOoo
ooooo`0boooo00<0003oooooool0VOooo`00Coooo`03o`2Ioooooooo03;oool00`000?ooooooo`2I
oooo001?oooo00?o09Woooooool0<_ooo`030000oooooooo09Woool004ooool00ol0VOooooooo`0b
oooo0P0009[oool004ooool00ol0VOooooooo`0boooo00<0003oooooool0VOooo`00Coooo`03o`2I
oooooooo03;oool00`000?ooooooo`2Ioooo001?oooo00?o09Woooooool0<_ooo`030000oooooooo
09Woool004ooool00ol0VOooooooo`0boooo00<0003oooooool0VOooo`00Coooo`03o`2Ioooooooo
03;oool20000V_ooo`00Coooo`03o`2Ioooooooo03;oool00`000?ooooooo`2Ioooo001?oooo00?o
09Woooooool0<_ooo`030000oooooooo09Woool004ooool00ol0VOooooooo`0boooo00<0003ooooo
ool0VOooo`00Coooo`03o`2Ioooooooo03;oool20000V_ooo`00Coooo`03o`2Ioooooooo03;oool0
0`000?ooooooo`2Ioooo001?oooo00?o09Woooooool0<_ooo`030000oooooooo09Woool004ooool0
0ol0VOooooooo`0Zoooo1@0000?oool00`000?ooooooo`2Ioooo001?oooo00?o09Woooooool0;?oo
o`030000oooooooo00?oool00`000?ooooooo`2Ioooo001?oooo00?o09Woooooool0;?ooo`030000
oooooooo00?oool30000VOooo`00Coooo`03o`2Ioooooooo02coool00`000?ooooooo`03oooo00<0
003oooooool0VOooo`00Coooo`03o`2Ioooooooo02coool00`000?ooooooo`03oooo00<0003ooooo
ool0VOooo`00Coooo`03o`2Ioooooooo02_oool200001Oooo`030000oooooooo09Woool004ooool0
0ol0VOooooooo`0boooo0P0009[oool004ooool00ol0VOooooooo`0boooo00<0003oooooool0VOoo
o`00Coooo`03o`2Ioooooooo03;oool00`000?ooooooo`2Ioooo001?oooo00?o09Woooooool0<_oo
o`030000oooooooo09Woool004ooool00ol0VOooooooo`0boooo00<0003oooooool0VOooo`00Cooo
o`03o`2Ioooooooo03;oool20000V_ooo`00Coooo`03o`2Ioooooooo03;oool00`000?ooooooo`2I
oooo001?oooo00?o09Woooooool0<_ooo`030000oooooooo09Woool004ooool00ol0VOooooooo`0b
oooo00<0003oooooool0VOooo`00Coooo`03o`2Ioooooooo03;oool20000V_ooo`00Coooo`03o`2I
oooooooo03;oool00`000?ooooooo`2Ioooo001?oooo00?o09Woooooool0<_ooo`030000oooooooo
09Woool004ooool00ol0VOooooooo`0boooo00<0003oooooool0VOooo`00Coooo`03o`2Ioooooooo
03;oool00`000?ooooooo`2Ioooo001?oooo00?o09Woooooool0<_ooo`80002Joooo001?oooo00?o
09Woooooool0<_ooo`030000oooooooo09Woool004ooool00ol0VOooooooo`0Zoooo100000Coool0
0`000?ooooooo`2Ioooo001?oooo00?o09Woooooool0:_ooo`030000oooooooo00Goool00`000?oo
ooooo`2Ioooo001?oooo00?o09Woooooool0:oooo`030000oooooooo00Coool30000VOooo`00Cooo
o`03o`2Ioooooooo02coool00`000?ooooooo`03oooo00<0003oooooool0VOooo`00Coooo`03o`2I
oooooooo02[oool010000?ooooooo`0000Coool00`000?ooooooo`2Ioooo001?oooo00?o09Wooooo
ool0:oooo`800005oooo00<0003oooooool0VOooo`00Coooo`03o`2Ioooooooo03;oool20000V_oo
o`00Coooo`03o`2Ioooooooo03;oool00`000?ooooooo`2Ioooo001?oooo00?o09Woooooool0<_oo
o`030000oooooooo09Woool004ooool00ol0VOooooooo`0boooo00<0003oooooool0VOooo`00Cooo
o`03o`2Ioooooooo03;oool00`000?ooooooo`2Ioooo001?oooo00?o09Woooooool0<_ooo`80002J
oooo001?oooo00?o09Woooooool0<_ooo`030000oooooooo09Woool004ooool00ol0VOooooooo`0b
oooo00<0003oooooool0VOooo`00Coooo`03o`2Ioooooooo03;oool00`000?ooooooo`2Ioooo001?
oooo00?o09Woooooool0<_ooo`80002Joooo001?oooo00?o09Woooooool0<_ooo`030000oooooooo
09Woool004ooool00ol0VOooooooo`0boooo00<0003oooooool0VOooo`00Coooo`03o`2Ioooooooo
03;oool00`000?ooooooo`2Ioooo001?oooo00?o09Woooooool0<_ooo`030000oooooooo09Woool0
04ooool00ol0VOooooooo`0boooo0P0009[oool004ooool00ol0VOooooooo`0boooo00<0003ooooo
ool0VOooo`00Coooo`03o`2Ioooooooo02_oool200001Oooo`030000oooooooo09Woool004ooool0
0ol0VOooooooo`0Zoooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00Coooo`03o`2I
oooooooo02coool00`000?ooooooo`03oooo0`0009Woool004ooool00ol0VOooooooo`0]oooo00<0
003oooooool00_ooo`030000oooooooo09Woool004ooool00ol0VOooooooo`0Zoooo00@0003ooooo
ool00004oooo00<0003oooooool0VOooo`00Coooo`03o`2Ioooooooo02_oool200001Oooo`030000
oooooooo09Woool004ooool00ol0VOooooooo`0boooo00<0003oooooool0VOooo`00Coooo`03o`2I
oooooooo03;oool20000V_ooo`00Coooo`03o`2Ioooooooo03;oool00`000?ooooooo`2Ioooo001?
oooo00?o09Woooooool0<_ooo`030000oooooooo09Woool004ooool00ol0VOooooooo`0boooo00<0
003oooooool0VOooo`00Coooo`03o`2Ioooooooo03;oool20000V_ooo`00Coooo`03o`2Ioooooooo
03;oool00`000?ooooooo`2Ioooo001?oooo00?o09Woooooool0<_ooo`030000oooooooo09Woool0
04ooool00ol0VOooooooo`0boooo00<0003oooooool0VOooo`00Coooo`03o`2Ioooooooo03;oool0
0`000?ooooooo`2Ioooo001?oooo00?o09Woooooool0<_ooo`80002Joooo001?oooo00?o09Wooooo
ool0<_ooo`030000oooooooo09Woool004ooool00ol0VOooooooo`0boooo00<0003oooooool0VOoo
o`00Coooo`03o`2Ioooooooo03;oool00`000?ooooooo`2Ioooo001?oooo00?o09Woooooool0<_oo
o`80002Joooo001?oooo00?o09Woooooool0<_ooo`030000oooooooo09Woool004ooool00ol0VOoo
ooooo`0boooo00<0003oooooool0VOooo`00Coooo`03o`2Ioooooooo02coool300000oooo`030000
oooooooo09Woool004ooool00ol0VOooooooo`0]oooo00<0003oooooool00_ooo`030000oooooooo
09Woool004ooool00ol0VOooooooo`0Zoooo1@0000?oool30000VOooo`00O?ooo`040000oooooooo
0000X?ooo`00OOooo`030000oooo00000:3oool007koool20000X?ooo`00ooooob7oool00?oooolQ
oooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`0=oooo0P0000Coool200001Oooo`<00002oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00003oooo00@0003oooooool0000;oooo00D0003oooooooooool00000N_ooo`00Moooo`030000
oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool01oooo`D00003oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000Eoooo00<0003oooooool01_ooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Eoooo00@0003ooooo
ool00009oooo00<0003oool000000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0G
oooo0P0000_oool200000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.24141 .26487 L
.25127 .26487 L
.25666 .26487 L
.26171 .26487 L
.26425 .26487 L
.26498 .26487 L
.26568 .26487 L
s
.26568 .26487 m
.2662 .61803 L
s
0 .4 1 r
.02381 .25483 m
.04262 .2524 L
.06244 .24919 L
.08255 .24509 L
.10458 .23936 L
.12415 .23291 L
.14509 .22418 L
.16639 .21288 L
.18653 .19936 L
.22495 .16334 L
.24479 .13789 L
.25492 .12268 L
.2605 .11359 L
.26326 .10891 L
.2646 .10659 L
.26581 .10446 L
.26703 .26487 L
.26818 .26487 L
.27069 .26487 L
.27602 .26487 L
.28535 .26487 L
.30365 .26487 L
.3422 .26487 L
.3832 .26487 L
.42269 .26487 L
.46066 .26487 L
.50109 .26487 L
.54 .26487 L
.58136 .26487 L
.6212 .26487 L
.65953 .26487 L
.70031 .26487 L
.73958 .26487 L
.77733 .26487 L
.81753 .26487 L
.85622 .26487 L
.89736 .26487 L
.93699 .26487 L
.97509 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
05?oool206Ko8?ooo`030000<ol0<ol000`co`020000V_ooo`00Doooo`80I_lOoooo00<0000co`0c
o`003C?o00030000oooooooo09Woool005;oool00`1Vooooo`1Vo`0Noooo00<0000co`0co`003S?o
0080002Joooo001Aoooo00@0I_ooooooool0I_lNoooo00<0000co`0co`003S?o00030000<ol00000
09Woool0057oool0101Vooooooooo`1Voagoool00`0003?o03?o000?<ol00P000003<ol00000oooo
09Ooool0053oool01@1Vooooooooooooo`1Vo`0Moooo00<0000co`0co`003c?o00040000<ol0<ol0
0000V?ooo`00Coooo`0306Kooooooooo00;oool00`1Vooooooooo`0Joooo00<0000co`0co`0043?o
00050000<ol0<ol0<ol0000009Ooool004ooool00`1Vooooooooo`02oooo00<0I_ooooooool06_oo
o`030000<ol0<ol0010co`000`0003?o03?o0002<ol000<0003oooooool0U?ooo`00C_ooo`0306Ko
oooooooo00?oool00`1Vooooooooo`0Ioooo00<0000co`0co`004C?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001=oooo00<0I_ooooooool01?ooo`0306Kooooooooo01Soool00`0003?o
03?o000B<ol00P0000@co`000`000?ooooooo`2Coooo001<oooo00<0I_ooooooool01Oooo`0306Ko
oooooooo01Ooool00`0003?o03?o000C<ol000<0000co`0co`0013?o00030000oooooooo09;oool0
04_oool00`1Vooooooooo`06oooo00<0I_ooooooool05oooo`030000<ol0<ol001<co`000`0003?o
03?o0004<ol000<0003oooooool0T_ooo`00Boooo`0306Kooooooooo00Koool00`1Vooooooooo`0F
oooo00<0000co`0co`0053?o00030000<ol0<ol000Dco`000`000?ooooooo`2Aoooo001:oooo00<0
I_ooooooool01oooo`0306Kooooooooo01Goool00`0003?o03?o000E<ol00P0000Lco`000`000?oo
ooooo`2@oooo0019oooo00<0I_ooooooool02?ooo`0306Kooooooooo01Coool00`0003?o03?o000F
<ol000<0000co`0co`001S?o00030000oooooooo093oool004Soool00`1Vooooooooo`09oooo00<0
I_ooooooool05?ooo`030000<ol0<ol001Hco`000`0003?o03?o0007<ol000<0003oooooool0Sooo
o`00Aoooo`0306Kooooooooo00[oool00`1Vooooooooo`0Coooo00<0000co`0co`003c?o00D00003
<ol000<0000co`0co`0023?o00030000oooooooo08koool004Koool00`1Vooooooooo`0;oooo00<0
I_ooooooool04_ooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0co`0023?o
00030000oooooooo08koool004Goool00`1Vooooooooo`0<oooo00<0I_ooooooool04Oooo`030000
<ol0<ol001<co`000`0003?o03?o0003<ol00`0000Tco`000`000?ooooooo`2=oooo0014oooo00<0
I_ooooooool03Oooo`0306Kooooooooo017oool00`0003?o03?o000;<ol0100000@co`000`0003?o
03?o0003<ol000<0000co`0co`002S?o00030000oooooooo08coool004?oool00`1Vooooooooo`0>
oooo00<0I_ooooooool04?ooo`030000<ol0<ol001@co`000`0003?o03?o0003<ol000<0000co`0c
o`002c?o00030000oooooooo08_oool004;oool00`1Vooooooooo`0?oooo00<0I_ooooooool03ooo
o`030000<ol0<ol001@co`0200001C?o00030000<ol0<ol000/co`000`000?ooooooo`2;oooo0011
oooo00<0I_ooooooool04?ooo`0306Kooooooooo00ooool00`0003?o03?o000K<ol00P0000dco`00
0`000?ooooooo`2:oooo0010oooo00<0I_ooooooool04Oooo`0306Kooooooooo00koool00`0003?o
03?o000L<ol000<0000co`0co`003C?o00030000oooooooo08Woool003ooool00`1Vooooooooo`0B
oooo00<0I_ooooooool03Oooo`030000<ol0<ol001dco`000`0003?o03?o000><ol000<0003ooooo
ool0R?ooo`00?Oooo`80I_lEoooo00<0I_ooooooool03?ooo`030000<ol0<ol001hco`000`0003?o
03?o000?<ol000<0003oooooool0Qoooo`00>oooo`80I_lGoooo00<0I_ooooooool03?ooo`030000
<ol0<ol001hco`000`0003?o03?o000@<ol000<0003oooooool0Q_ooo`00>_ooo`0306Kooooooooo
01Ooool00`1Vooooooooo`0;oooo00<0000co`0co`007c?o0080000B<ol000<0003oooooool0QOoo
o`00>?ooo`80I_lJoooo00<0I_ooooooool02_ooo`030000<ol0<ol0020co`000`0003?o03?o000B
<ol000<0003oooooool0Q?ooo`00;oooo`<00004oooo0P1Voacoool00`1Vooooooooo`02oooo1000
00;oool200008c?o00030000<ol0<ol001<co`000`000?ooooooo`0Aoooo100002[oool300009ooo
o`<0000Goooo000`oooo00@0003oooooooooool206Ko7_ooo`0306Kooooooooo00;oool00`000?oo
ooooo`02oooo00<0000co`0co`008c?o00030000<ol0<ol001@co`000`000?ooooooo`0@oooo00<0
003oooooool0;?ooo`030000oooooooo02Koool010000?ooooooo`0001Koool002goool500000P1V
ob3oool00`1Vooooooooo`03oooo00@0003oooooool0000V<ol00P0001Hco`0200004Oooo`030000
oooooooo02Soool500009oooo`040000oooooooo00005_ooo`009oooo`@00002oooo00D0003oool0
I_l00000I_l08Oooo`@00004oooo0P0002Lco`000`0003?o03?o000G<ol000<0003oooooool03ooo
o`030000oooooooo02Ooool010000?ooooooo`0002Soool300005oooo`00;Oooo`0406Ko0000oooo
00008oooo`0306Kooooooooo00;oool2000000<co`00000co`009S?o00030000<ol0<ol001Pco`00
0`000?ooooooo`0<oooo00@0003oooooool0000Yoooo00<0003oool00000:Oooo`030000oooooooo
01Koool002Woool406Ko0_ooo`80000Soooo00@0I_ooooooooooool40000:3?o00030000<ol0<ol0
01Tco`000`000?ooooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo000Soooo1P1Vob_oool0
101Vooooo`00000002`co`000`0003?o03?o000J<ol00P0007goool001koool506Ko<Oooo`0306Ko
0000<ol002dco`0200007C?o00<0001joooo000Ioooo1@1Voc?oool3000000<0I_lco`0co`00;C?o
00030000<ol0<ol001lco`060000M?ooo`005_ooo`<0I_lboooo1P0000<co`000`1Voc?o03?o000]
<ol000<0000co`0co`009C?o00<0001aoooo0011oooo2P0000Tco`000`1Voc?o03?o000]<ol000<0
000co`0co`00:3?o00X0001Woooo000@ooooo`00017oool001Koool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Coool01Ol0VOooooooooooo`00000:oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00;?oo
o`030000oooooooo02Goool01Ol0VOooooooooooo`00000[oooo00<0003oooooool0:Oooo`030000
oooooooo02Woool00`000?ooooooo`0Yoooo00<0003oooooool05Oooo`00E?ooo`03o`2Ioooooooo
02goool00`000?ooooooo`2Ioooo001Doooo00?o09Woooooool0;Oooo`030000oooooooo09Woool0
05Coool00ol0VOooooooo`0]oooo0P0009[oool005Coool00ol0VOooooooo`0]oooo00<0003ooooo
ool0VOooo`00E?ooo`03o`2Ioooooooo02goool00`000?ooooooo`2Ioooo001Doooo00?o09Wooooo
ool0;Oooo`030000oooooooo09Woool005Coool00ol0VOooooooo`0]oooo0P0009[oool005Coool0
0ol0VOooooooo`0]oooo00<0003oooooool0VOooo`00E?ooo`03o`2Ioooooooo02goool00`000?oo
ooooo`2Ioooo001Doooo00?o09Woooooool0;Oooo`030000oooooooo09Woool005Coool00ol0VOoo
ooooo`0]oooo00<0003oooooool0VOooo`00E?ooo`03o`2Ioooooooo02goool20000V_ooo`00E?oo
o`03o`2Ioooooooo02goool00`000?ooooooo`2Ioooo001Doooo00?o09Woooooool0;Oooo`030000
oooooooo09Woool005Coool00ol0VOooooooo`0]oooo00<0003oooooool0VOooo`00E?ooo`03o`2I
oooooooo02goool20000V_ooo`00E?ooo`03o`2Ioooooooo02goool00`000?ooooooo`2Ioooo001D
oooo00?o09Woooooool0;Oooo`030000oooooooo09Woool005Coool00ol0VOooooooo`0Uoooo1@00
00?oool00`000?ooooooo`2Ioooo001Doooo00?o09Woooooool09oooo`030000oooooooo00?oool0
0`000?ooooooo`2Ioooo001Doooo00?o09Woooooool09oooo`030000oooooooo00?oool30000VOoo
o`00E?ooo`03o`2Ioooooooo02Ooool00`000?ooooooo`03oooo00<0003oooooool0VOooo`00E?oo
o`03o`2Ioooooooo02Ooool00`000?ooooooo`03oooo00<0003oooooool0VOooo`00E?ooo`03o`2I
oooooooo02Koool200001Oooo`030000oooooooo09Woool005Coool00ol0VOooooooo`0]oooo0P00
09[oool005Coool00ol0VOooooooo`0]oooo00<0003oooooool0VOooo`00E?ooo`03o`2Ioooooooo
02goool00`000?ooooooo`2Ioooo001Doooo00?o09Woooooool0;Oooo`030000oooooooo09Woool0
05Coool00ol0VOooooooo`0]oooo00<0003oooooool0VOooo`00E?ooo`03o`2Ioooooooo02goool2
0000V_ooo`00E?ooo`03o`2Ioooooooo02goool00`000?ooooooo`2Ioooo001Doooo00?o09Wooooo
ool0;Oooo`030000oooooooo09Woool005Coool00ol0VOooooooo`0]oooo00<0003oooooool0VOoo
o`00E?ooo`03o`2Ioooooooo02goool20000V_ooo`00E?ooo`03o`2Ioooooooo02goool00`000?oo
ooooo`2Ioooo001Doooo00?o09Woooooool0;Oooo`030000oooooooo09Woool005Coool00ol0VOoo
ooooo`0]oooo00<0003oooooool0VOooo`00E?ooo`03o`2Ioooooooo02goool00`000?ooooooo`2I
oooo001Doooo00?o09Woooooool0;Oooo`80002Joooo001Doooo00?o09Woooooool0;Oooo`030000
oooooooo09Woool005Coool00ol0VOooooooo`0Uoooo100000Coool00`000?ooooooo`2Ioooo001D
oooo00?o09Woooooool09Oooo`030000oooooooo00Goool00`000?ooooooo`2Ioooo001Doooo00?o
09Woooooool09_ooo`030000oooooooo00Coool30000VOooo`00E?ooo`03o`2Ioooooooo02Ooool0
0`000?ooooooo`03oooo00<0003oooooool0VOooo`00E?ooo`03o`2Ioooooooo02Goool010000?oo
ooooo`0000Coool00`000?ooooooo`2Ioooo001Doooo00?o09Woooooool09_ooo`800005oooo00<0
003oooooool0VOooo`00E?ooo`03o`2Ioooooooo02goool20000V_ooo`00E?ooo`03o`2Ioooooooo
02goool00`000?ooooooo`2Ioooo001Doooo00?o09Woooooool0;Oooo`030000oooooooo09Woool0
05Coool00ol0VOooooooo`0]oooo00<0003oooooool0VOooo`00E?ooo`03o`2Ioooooooo02goool0
0`000?ooooooo`2Ioooo001Doooo00?o09Woooooool0;Oooo`80002Joooo001Doooo00?o09Wooooo
ool0;Oooo`030000oooooooo09Woool005Coool00ol0VOooooooo`0]oooo00<0003oooooool0VOoo
o`00E?ooo`03o`2Ioooooooo02goool00`000?ooooooo`2Ioooo001Doooo00?o09Woooooool0;Ooo
o`80002Joooo001Doooo00?o09Woooooool0;Oooo`030000oooooooo09Woool005Coool00ol0VOoo
ooooo`0]oooo00<0003oooooool0VOooo`00E?ooo`03o`2Ioooooooo02goool00`000?ooooooo`2I
oooo001Doooo00?o09Woooooool0;Oooo`030000oooooooo09Woool005Coool00ol0VOooooooo`0]
oooo0P0009[oool005Coool00ol0VOooooooo`0]oooo00<0003oooooool0VOooo`00E?ooo`03o`2I
oooooooo02Koool200001Oooo`030000oooooooo09Woool005Coool00ol0VOooooooo`0Uoooo00@0
003oooooool00004oooo00<0003oooooool0VOooo`00E?ooo`03o`2Ioooooooo02Ooool00`000?oo
ooooo`03oooo0`0009Woool005Coool00ol0VOooooooo`0Xoooo00<0003oooooool00_ooo`030000
oooooooo09Woool005Coool00ol0VOooooooo`0Uoooo00@0003oooooool00004oooo00<0003ooooo
ool0VOooo`00E?ooo`03o`2Ioooooooo02Koool200001Oooo`030000oooooooo09Woool005Coool0
0ol0VOooooooo`0]oooo00<0003oooooool0VOooo`00E?ooo`03o`2Ioooooooo02goool20000V_oo
o`00E?ooo`03o`2Ioooooooo02goool00`000?ooooooo`2Ioooo001Doooo00?o09Woooooool0;Ooo
o`030000oooooooo09Woool005Coool00ol0VOooooooo`0]oooo00<0003oooooool0VOooo`00E?oo
o`03o`2Ioooooooo02goool20000V_ooo`00E?ooo`03o`2Ioooooooo02goool00`000?ooooooo`2I
oooo001Doooo00?o09Woooooool0;Oooo`030000oooooooo09Woool005Coool00ol0VOooooooo`0]
oooo00<0003oooooool0VOooo`00E?ooo`03o`2Ioooooooo02goool00`000?ooooooo`2Ioooo001D
oooo00?o09Woooooool0;Oooo`80002Joooo001Doooo00?o09Woooooool0;Oooo`030000oooooooo
09Woool005Coool00ol0VOooooooo`0]oooo00<0003oooooool0VOooo`00E?ooo`03o`2Ioooooooo
02goool00`000?ooooooo`2Ioooo001Doooo00?o09Woooooool0;Oooo`80002Joooo001Doooo00?o
09Woooooool0;Oooo`030000oooooooo09Woool005Coool00ol0VOooooooo`0]oooo00<0003ooooo
ool0VOooo`00E?ooo`03o`2Ioooooooo02Ooool300000oooo`030000oooooooo09Woool005Coool0
0ol0VOooooooo`0Xoooo00<0003oooooool00_ooo`030000oooooooo09Woool005Coool00ol0VOoo
ooooo`0Uoooo1@0000?oool30000VOooo`00O?ooo`040000oooooooo0000X?ooo`00OOooo`030000
oooo00000:3oool007koool20000X?ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003ooooo
ool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=
oooo0P0000Coool200000oooo`@00003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003ooooo
ool00008oooo00<0003oooooool01?ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool05Oooo`030000oooooooo00Soool00`000?ooooooo`04oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000Eoooo00<0003oooooool02?ooo`030000oooooooo
00;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005Oooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0G
oooo0P0000[oool200000oooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.27193 .26487 L
.27731 .26487 L
.28025 .26487 L
.2817 .26487 L
.28302 .26487 L
s
.28302 .26487 m
.28351 .61803 L
s
0 .4 1 r
.02381 .25666 m
.04262 .25467 L
.06244 .25204 L
.08255 .24869 L
.10458 .24401 L
.12415 .23872 L
.14509 .23159 L
.16639 .22234 L
.18653 .21128 L
.22495 .18181 L
.24479 .16099 L
.25492 .14855 L
.26581 .13364 L
.27104 .12589 L
.27602 .11816 L
.28048 .1109 L
.2817 .10885 L
.283 .10665 L
.28423 .26487 L
.28535 .26487 L
.30365 .26487 L
.34372 .26487 L
.38227 .26487 L
.42327 .26487 L
.46276 .26487 L
.50073 .26487 L
.54115 .26487 L
.58006 .26487 L
.62142 .26487 L
.66127 .26487 L
.6996 .26487 L
.74038 .26487 L
.77965 .26487 L
.8174 .26487 L
.8576 .26487 L
.89629 .26487 L
.93743 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
05Soool00`1Vooooooooo`0Joooo00<0000co`0co`0033?o0080002Joooo001Goooo0P1Voa_oool0
0`0003?o03?o000=<ol000<0003oooooool0VOooo`00E_ooo`0306Kooooo06Ko01[oool00`0003?o
03?o000><ol00P0009[oool005Koool00`1Vooooo`1Vo`0Joooo00<0000co`0co`003S?o00030000
<ol0000009Woool005Goool0101Vooooooooo`1VoaWoool00`0003?o03?o000?<ol00P000003<ol0
0000oooo09Ooool005Goool0101Vooooooooo`1VoaWoool00`0003?o03?o000?<ol000@0000co`0c
o`00002Hoooo001Doooo00D0I_ooooooooooool0I_l06?ooo`030000<ol0<ol0010co`001@0003?o
03?o03?o0000002Goooo001Doooo00D0I_ooooooooooool0I_l06?ooo`030000<ol0<ol0010co`00
0`0003?o03?o0002<ol000<0003oooooool0U?ooo`00Doooo`0306Kooooooooo00;oool00`1Voooo
ooooo`0Eoooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?ooooooo`2Doooo001B
oooo00<0I_ooooooool00oooo`0306Kooooooooo01Coool00`0003?o03?o000B<ol00P0000@co`00
0`000?ooooooo`2Coooo001Boooo00<0I_ooooooool00oooo`0306Kooooooooo01?oool00`0003?o
03?o000C<ol000<0000co`0co`0013?o00030000oooooooo09;oool0057oool00`1Vooooooooo`04
oooo00<0I_ooooooool04oooo`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003ooooo
ool0T_ooo`00D?ooo`0306Kooooooooo00Goool00`1Vooooooooo`0Boooo00<0000co`0co`0053?o
00030000<ol0<ol000Dco`000`000?ooooooo`2Aoooo001?oooo00<0I_ooooooool01_ooo`0306Ko
oooooooo017oool00`0003?o03?o000E<ol00P0000Lco`000`000?ooooooo`2@oooo001>oooo00<0
I_ooooooool01oooo`0306Kooooooooo013oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool004goool00`1Vooooooooo`08oooo00<0I_ooooooool04?ooo`030000
<ol0<ol001Hco`000`0003?o03?o0007<ol000<0003oooooool0Soooo`00C?ooo`0306Kooooooooo
00Woool00`1Vooooooooo`0?oooo00<0000co`0co`003c?o00D00003<ol000<0000co`0co`0023?o
00030000oooooooo08koool004_oool00`1Vooooooooo`0:oooo00<0I_ooooooool03_ooo`030000
<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0co`0023?o00030000oooooooo08koool0
04[oool00`1Vooooooooo`0;oooo00<0I_ooooooool03Oooo`030000<ol0<ol001<co`000`0003?o
03?o0003<ol00`0000Tco`000`000?ooooooo`2=oooo0019oooo00<0I_ooooooool03?ooo`0306Ko
oooooooo00goool00`0003?o03?o000;<ol0100000@co`000`0003?o03?o0003<ol000<0000co`0c
o`002S?o00030000oooooooo08coool004Soool00`1Vooooooooo`0=oooo00<0I_ooooooool03?oo
o`030000<ol0<ol001@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo
08_oool004Koool206Ko4?ooo`0306Kooooooooo00_oool00`0003?o03?o000D<ol00P0000Dco`00
0`0003?o03?o000;<ol000<0003oooooool0Roooo`00AOooo`0306Kooooooooo013oool00`1Voooo
ooooo`0;oooo00<0000co`0co`006c?o0080000=<ol000<0003oooooool0R_ooo`00A?ooo`0306Ko
oooooooo017oool00`1Vooooooooo`0:oooo00<0000co`0co`0073?o00030000<ol0<ol000dco`00
0`000?ooooooo`29oooo0013oooo00<0I_ooooooool04_ooo`0306Kooooooooo00Woool00`0003?o
03?o000M<ol000<0000co`0co`003S?o00030000oooooooo08Soool0047oool206Ko5Oooo`0306Ko
oooooooo00Soool00`0003?o03?o000N<ol000<0000co`0co`003c?o00030000oooooooo08Ooool0
043oool00`1Vooooooooo`0Eoooo00<0I_ooooooool02?ooo`030000<ol0<ol001hco`000`0003?o
03?o000@<ol000<0003oooooool0Q_ooo`00?_ooo`80I_lHoooo00<0I_ooooooool01oooo`030000
<ol0<ol001lco`0200004S?o00030000oooooooo08Goool003coool206Ko6_ooo`0306Kooooooooo
00Koool00`0003?o03?o000P<ol000<0000co`0co`004S?o00030000oooooooo08Coool002ooool3
00002?ooo`80I_lLoooo00<0I_l0000000000P0000;oool200008c?o00030000<ol0<ol001<co`00
0`000?ooooooo`0Aoooo100002[oool300009oooo`<0000Goooo000`oooo00<0003oooooool01Ooo
o`80I_lNoooo00<0I_l0003oool00oooo`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0
003oooooool04?ooo`030000oooooooo02coool00`000?ooooooo`0Voooo00@0003oooooool0000F
oooo000]oooo1@0000Coool206Ko8?ooo`0306Kooooo000000;oool00`0003?o03?o000T<ol00P00
01Hco`0200004Oooo`030000oooooooo02Soool500009oooo`040000oooooooo00005_ooo`009ooo
o`@00002oooo00@0003oooooool00003oooo0P1Voagoool4000000Coool0I_ooooooool200009c?o
00030000<ol0<ol001Lco`000`000?ooooooo`0?oooo00<0003oooooool09oooo`040000oooooooo
0000:?ooo`<0000Goooo000^oooo00@0003oool0003oool206Ko9?ooo`0506Ko00000000<ol00000
02Lco`000`0003?o03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000
oooo000002Woool00`000?ooooooo`0Foooo000^oooo00@0I_l000000000I_lVoooo00@0I_l00000
0000000X<ol000<0000co`0co`006C?o00030000oooooooo00coool20000:oooo`80000Yoooo0`00
01Koool002Woool506Ko:?ooo`8000000`1Voc?o03?o000Y<ol000<0000co`0co`006S?o0080001m
oooo000Soooo1P1Vob_oool200000S?o000306Ko<ol0<ol002Tco`0200007C?o00<0001joooo000N
oooo1@1Vobkoool3000013?o000306Ko<ol0<ol002Tco`000`0003?o03?o000O<ol01P0007Coool0
01Koool806Ko;Oooo`H00007<ol000<0I_lco`0co`00:C?o00030000<ol0<ol002Dco`030000LOoo
o`00@Oooo`X0000=<ol000<0I_lco`0co`00:C?o00030000<ol0<ol002Pco`0:0000Ioooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo01Goool002coool00`000?ooooooo`0Yoooo00<0003oooooool0:Ooo
o`030000oooooooo02Woool00`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo
01Goool005Soool00ol0VOooooooo`0Yoooo00<0003oooooool0VOooo`00F?ooo`03o`2Ioooooooo
02Woool00`000?ooooooo`2Ioooo001Hoooo00?o09Woooooool0:Oooo`80002Joooo001Hoooo00?o
09Woooooool0:Oooo`030000oooooooo09Woool005Soool00ol0VOooooooo`0Yoooo00<0003ooooo
ool0VOooo`00F?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`2Ioooo001Hoooo00?o09Wooooo
ool0:Oooo`80002Joooo001Hoooo00?o09Woooooool0:Oooo`030000oooooooo09Woool005Soool0
0ol0VOooooooo`0Yoooo00<0003oooooool0VOooo`00F?ooo`03o`2Ioooooooo02Woool00`000?oo
ooooo`2Ioooo001Hoooo00?o09Woooooool0:Oooo`030000oooooooo09Woool005Soool00ol0VOoo
ooooo`0Yoooo0P0009[oool005Soool00ol0VOooooooo`0Yoooo00<0003oooooool0VOooo`00F?oo
o`03o`2Ioooooooo02Woool00`000?ooooooo`2Ioooo001Hoooo00?o09Woooooool0:Oooo`030000
oooooooo09Woool005Soool00ol0VOooooooo`0Yoooo0P0009[oool005Soool00ol0VOooooooo`0Y
oooo00<0003oooooool0VOooo`00F?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`2Ioooo001H
oooo00?o09Woooooool08Oooo`D00003oooo00<0003oooooool0VOooo`00F?ooo`03o`2Ioooooooo
02?oool00`000?ooooooo`03oooo00<0003oooooool0VOooo`00F?ooo`03o`2Ioooooooo02?oool0
0`000?ooooooo`03oooo0`0009Woool005Soool00ol0VOooooooo`0Soooo00<0003oooooool00ooo
o`030000oooooooo09Woool005Soool00ol0VOooooooo`0Soooo00<0003oooooool00oooo`030000
oooooooo09Woool005Soool00ol0VOooooooo`0Roooo0P0000Goool00`000?ooooooo`2Ioooo001H
oooo00?o09Woooooool0:Oooo`80002Joooo001Hoooo00?o09Woooooool0:Oooo`030000oooooooo
09Woool005Soool00ol0VOooooooo`0Yoooo00<0003oooooool0VOooo`00F?ooo`03o`2Ioooooooo
02Woool00`000?ooooooo`2Ioooo001Hoooo00?o09Woooooool0:Oooo`030000oooooooo09Woool0
05Soool00ol0VOooooooo`0Yoooo0P0009[oool005Soool00ol0VOooooooo`0Yoooo00<0003ooooo
ool0VOooo`00F?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`2Ioooo001Hoooo00?o09Wooooo
ool0:Oooo`030000oooooooo09Woool005Soool00ol0VOooooooo`0Yoooo0P0009[oool005Soool0
0ol0VOooooooo`0Yoooo00<0003oooooool0VOooo`00F?ooo`03o`2Ioooooooo02Woool00`000?oo
ooooo`2Ioooo001Hoooo00?o09Woooooool0:Oooo`030000oooooooo09Woool005Soool00ol0VOoo
ooooo`0Yoooo00<0003oooooool0VOooo`00F?ooo`03o`2Ioooooooo02Woool20000V_ooo`00F?oo
o`03o`2Ioooooooo02Woool00`000?ooooooo`2Ioooo001Hoooo00?o09Woooooool08Oooo`@00004
oooo00<0003oooooool0VOooo`00F?ooo`03o`2Ioooooooo027oool00`000?ooooooo`05oooo00<0
003oooooool0VOooo`00F?ooo`03o`2Ioooooooo02;oool00`000?ooooooo`04oooo0`0009Woool0
05Soool00ol0VOooooooo`0Soooo00<0003oooooool00oooo`030000oooooooo09Woool005Soool0
0ol0VOooooooo`0Qoooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00F?ooo`03o`2I
oooooooo02;oool200001Oooo`030000oooooooo09Woool005Soool00ol0VOooooooo`0Yoooo0P00
09[oool005Soool00ol0VOooooooo`0Yoooo00<0003oooooool0VOooo`00F?ooo`03o`2Ioooooooo
02Woool00`000?ooooooo`2Ioooo001Hoooo00?o09Woooooool0:Oooo`030000oooooooo09Woool0
05Soool00ol0VOooooooo`0Yoooo00<0003oooooool0VOooo`00F?ooo`03o`2Ioooooooo02Woool2
0000V_ooo`00F?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`2Ioooo001Hoooo00?o09Wooooo
ool0:Oooo`030000oooooooo09Woool005Soool00ol0VOooooooo`0Yoooo00<0003oooooool0VOoo
o`00F?ooo`03o`2Ioooooooo02Woool20000V_ooo`00F?ooo`03o`2Ioooooooo02Woool00`000?oo
ooooo`2Ioooo001Hoooo00?o09Woooooool0:Oooo`030000oooooooo09Woool005Soool00ol0VOoo
ooooo`0Yoooo00<0003oooooool0VOooo`00F?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`2I
oooo001Hoooo00?o09Woooooool0:Oooo`80002Joooo001Hoooo00?o09Woooooool0:Oooo`030000
oooooooo09Woool005Soool00ol0VOooooooo`0Roooo0P0000Goool00`000?ooooooo`2Ioooo001H
oooo00?o09Woooooool08Oooo`040000oooooooo00001?ooo`030000oooooooo09Woool005Soool0
0ol0VOooooooo`0Soooo00<0003oooooool00oooo`<0002Ioooo001Hoooo00?o09Woooooool09?oo
o`030000oooooooo00;oool00`000?ooooooo`2Ioooo001Hoooo00?o09Woooooool08Oooo`040000
oooooooo00001?ooo`030000oooooooo09Woool005Soool00ol0VOooooooo`0Roooo0P0000Goool0
0`000?ooooooo`2Ioooo001Hoooo00?o09Woooooool0:Oooo`030000oooooooo09Woool005Soool0
0ol0VOooooooo`0Yoooo0P0009[oool005Soool00ol0VOooooooo`0Yoooo00<0003oooooool0VOoo
o`00F?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`2Ioooo001Hoooo00?o09Woooooool0:Ooo
o`030000oooooooo09Woool005Soool00ol0VOooooooo`0Yoooo0P0009[oool005Soool00ol0VOoo
ooooo`0Yoooo00<0003oooooool0VOooo`00F?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`2I
oooo001Hoooo00?o09Woooooool0:Oooo`030000oooooooo09Woool005Soool00ol0VOooooooo`0Y
oooo00<0003oooooool0VOooo`00F?ooo`03o`2Ioooooooo02Woool20000V_ooo`00F?ooo`03o`2I
oooooooo02Woool00`000?ooooooo`2Ioooo001Hoooo00?o09Woooooool0:Oooo`030000oooooooo
09Woool005Soool00ol0VOooooooo`0Yoooo00<0003oooooool0VOooo`00F?ooo`03o`2Ioooooooo
02Woool20000V_ooo`00F?ooo`03o`2Ioooooooo02Woool00`000?ooooooo`2Ioooo001Hoooo00?o
09Woooooool0:Oooo`030000oooooooo09Woool005Soool00ol0VOooooooo`0Soooo0`0000?oool0
0`000?ooooooo`2Ioooo001Hoooo00?o09Woooooool09?ooo`030000oooooooo00;oool00`000?oo
ooooo`2Ioooo001Hoooo00?o09Woooooool08Oooo`D00003oooo0`0009Woool007coool010000?oo
ooooo`000:3oool007goool00`000?ooo`00002Poooo001noooo0P000:3oool00?oooolQoooo003o
oooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003ooooo
ool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Coool00`000?ooooooo`1koooo001k
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo1000
00?oool010000?ooooooo`0000Woool00`000?ooooooo`1koooo001joooo00<0003oooooool00_oo
o`030000oooooooo01Goool00`000?ooooooo`09oooo00<0003oooooool0N_ooo`00Noooo`030000
oooooooo00D0000Eoooo00<0003oooooool01oooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`00000Eoooo00@0003oooooool00009oooo00<0003oooooool0Noooo`00O?ooo`030000
oooooooo01Ooool200002Oooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.27193 .26487 L
.28302 .26487 L
.2881 .26487 L
.29349 .26487 L
.29809 .26487 L
.29935 .26487 L
.30004 .26487 L
.3007 .26487 L
s
.3007 .26487 m
.30122 .61803 L
s
0 .4 1 r
.02381 .25816 m
.04262 .25653 L
.06244 .25438 L
.08255 .25164 L
.10458 .24781 L
.12415 .24349 L
.14509 .23765 L
.16639 .23009 L
.18653 .22105 L
.22495 .19695 L
.24479 .17993 L
.26581 .15756 L
.27523 .14592 L
.28535 .1322 L
.29025 .12509 L
.29491 .11805 L
.29693 .1149 L
.29909 .11149 L
.30033 .1095 L
.30145 .26487 L
.30258 .26487 L
.30365 .26487 L
.3422 .26487 L
.3832 .26487 L
.42269 .26487 L
.46066 .26487 L
.50109 .26487 L
.54 .26487 L
.58136 .26487 L
.6212 .26487 L
.65953 .26487 L
.70031 .26487 L
.73958 .26487 L
.77733 .26487 L
.81753 .26487 L
.85622 .26487 L
.89736 .26487 L
.93699 .26487 L
.97509 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool005coool00`1Vooooooooo`0Eoooo00<0000co`0c
o`003C?o00030000oooooooo09Woool005_oool206Ko5_ooo`030000<ol0<ol000hco`020000V_oo
o`00Foooo`80I_lFoooo00<0000co`0co`003S?o00030000<ol0000009Woool005[oool00`1Voooo
o`1Vo`0Eoooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001Joooo00<0I_ooool0
I_l05Oooo`030000<ol0<ol000lco`00100003?o03?o000009Soool005Woool0101Vooooooooo`1V
oaCoool00`0003?o03?o000@<ol000D0000co`0co`0co`000000Uoooo`00FOooo`0406Kooooooooo
06Ko5?ooo`030000<ol0<ol0010co`000`0003?o03?o0002<ol000<0003oooooool0U?ooo`00F?oo
o`0506Kooooooooooooo06Ko01?oool00`0003?o03?o000A<ol000<0000co`0co`000S?o00030000
oooooooo09Coool005Ooool00`1Vooooooooo`02oooo00<0I_ooooooool04?ooo`030000<ol0<ol0
018co`02000013?o00030000oooooooo09?oool005Koool00`1Vooooooooo`03oooo00<0I_oooooo
ool03oooo`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00EOoo
o`0306Kooooooooo00Coool00`1Vooooooooo`0?oooo00<0000co`0co`004c?o00030000<ol0<ol0
00@co`000`000?ooooooo`2Boooo001Eoooo00<0I_ooooooool01?ooo`0306Kooooooooo00koool0
0`0003?o03?o000D<ol000<0000co`0co`001C?o00030000oooooooo097oool005Coool00`1Voooo
ooooo`05oooo00<0I_ooooooool03Oooo`030000<ol0<ol001Dco`0200001c?o00030000oooooooo
093oool005?oool00`1Vooooooooo`06oooo00<0I_ooooooool03?ooo`030000<ol0<ol001Hco`00
0`0003?o03?o0006<ol000<0003oooooool0T?ooo`00D_ooo`0306Kooooooooo00Ooool00`1Voooo
ooooo`0<oooo00<0000co`0co`005S?o00030000<ol0<ol000Lco`000`000?ooooooo`2?oooo001A
oooo00<0I_ooooooool02?ooo`0306Kooooooooo00_oool00`0003?o03?o000?<ol01@0000<co`00
0`0003?o03?o0008<ol000<0003oooooool0S_ooo`00D?ooo`0306Kooooooooo00Woool00`1Voooo
ooooo`0:oooo00<0000co`0co`004S?o00030000<ol0<ol000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00Coooo`0306Kooooooooo00[oool00`1Vooooooooo`09oooo00<0000co`0c
o`004c?o00030000<ol0<ol000<co`0300002C?o00030000oooooooo08goool004koool00`1Voooo
ooooo`0;oooo00<0I_ooooooool02Oooo`030000<ol0<ol000/co`04000013?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00COooo`0306Kooooooooo00coool0
0`1Vooooooooo`08oooo00<0000co`0co`0053?o00030000<ol0<ol000<co`000`0003?o03?o000;
<ol000<0003oooooool0Roooo`00Boooo`80I_l@oooo00<0I_ooooooool01_ooo`030000<ol0<ol0
01@co`0200001C?o00030000<ol0<ol000/co`000`000?ooooooo`2;oooo001:oooo00<0I_oooooo
ool04?ooo`0306Kooooooooo00Koool00`0003?o03?o000K<ol00P0000dco`000`000?ooooooo`2:
oooo0019oooo00<0I_ooooooool04Oooo`0306Kooooooooo00Goool00`0003?o03?o000L<ol000<0
000co`0co`003C?o00030000oooooooo08Woool004Ooool206Ko5?ooo`0306Kooooooooo00Coool0
0`0003?o03?o000M<ol000<0000co`0co`003S?o00030000oooooooo08Soool004Goool206Ko5_oo
o`0306Kooooooooo00?oool00`0003?o03?o000N<ol000<0000co`0co`003c?o00030000oooooooo
08Ooool004Coool00`1Vooooooooo`0Foooo00<0I_ooooooool00oooo`030000<ol0<ol001hco`00
0`0003?o03?o000@<ol000<0003oooooool0Q_ooo`00@_ooo`80I_lIoooo00<0I_ooooooool00_oo
o`030000<ol0<ol001lco`0200004S?o00030000oooooooo08Goool0043oool206Ko6oooo`0506Ko
oooooooooooo0000028co`000`0003?o03?o000B<ol000<0003oooooool0Q?ooo`00;oooo`<0000<
oooo0P1VoaWoool4000000@0I_ooool00000000S<ol000<0000co`0co`004c?o00030000oooooooo
017oool40000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`09oooo0P1Voa_oool0
1P000?ooooooooooo`1Vo`0002Dco`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000
oooooooo02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0000Ooool3
06Ko7_ooo`040000oooooooo06Ko9S?o0080000F<ol00P00017oool00`000?ooooooo`0Xoooo1@00
02Ooool010000?ooooooo`0001Koool002Ooool400000_ooo`040000oooooooo00001_ooo`80I_lJ
oooo100000Coool2000000<0I_lco`0co`0093?o00030000<ol0<ol001Lco`000`000?ooooooo`0?
oooo00<0003oooooool09oooo`040000oooooooo0000:?ooo`<0000Goooo000^oooo00<0003oool0
00000oooo`<0I_lRoooo0P000003<ol0000006Ko02Hco`000`0003?o03?o000H<ol000<0003ooooo
ool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool00`000?ooooooo`0Foooo000_
oooo0P000003oooo06Ko06Ko02Coool4000000<co`00I_lco`009C?o00030000<ol0<ol001Tco`00
0`000?ooooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo000^oooo101VobCoool200001C?o
000306Ko<ol0<ol002@co`000`0003?o03?o000J<ol00P0007goool002Woool506Ko9_ooo`800007
<ol000<0I_lco`0co`0093?o0080000M<ol00`0007[oool002?oool606Ko:?ooo`<00009<ol000<0
I_lco`0co`0093?o00030000<ol0<ol001lco`060000M?ooo`006Oooo`X0I_lXoooo1P0000`co`00
0`1Voc?o03?o000T<ol000<0000co`0co`009C?o00<0001aoooo000Foooo0`1VobSoool:00004S?o
000306Ko<ol0<ol002@co`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`050000ooooooooooooo`2I00Koool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`0Eoooo000/oooo00<0003oooooool0:Oooo`050000ooooooooooooo`2I02Ooool0
0`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo02Woool00`000?ooooooo`0E
oooo001Loooo00?o09Woooooool09Oooo`030000oooooooo09Woool005coool00ol0VOooooooo`0U
oooo00<0003oooooool0VOooo`00G?ooo`03o`2Ioooooooo02Goool20000V_ooo`00G?ooo`03o`2I
oooooooo02Goool00`000?ooooooo`2Ioooo001Loooo00?o09Woooooool09Oooo`030000oooooooo
09Woool005coool00ol0VOooooooo`0Uoooo00<0003oooooool0VOooo`00G?ooo`03o`2Ioooooooo
02Goool20000V_ooo`00G?ooo`03o`2Ioooooooo02Goool00`000?ooooooo`2Ioooo001Loooo00?o
09Woooooool09Oooo`030000oooooooo09Woool005coool00ol0VOooooooo`0Uoooo00<0003ooooo
ool0VOooo`00G?ooo`03o`2Ioooooooo02Goool00`000?ooooooo`2Ioooo001Loooo00?o09Wooooo
ool09Oooo`80002Joooo001Loooo00?o09Woooooool09Oooo`030000oooooooo09Woool005coool0
0ol0VOooooooo`0Uoooo00<0003oooooool0VOooo`00G?ooo`03o`2Ioooooooo02Goool00`000?oo
ooooo`2Ioooo001Loooo00?o09Woooooool09Oooo`80002Joooo001Loooo00?o09Woooooool09Ooo
o`030000oooooooo09Woool005coool00ol0VOooooooo`0Uoooo00<0003oooooool0VOooo`00G?oo
o`03o`2Ioooooooo01goool500000oooo`030000oooooooo09Woool005coool00ol0VOooooooo`0O
oooo00<0003oooooool00oooo`030000oooooooo09Woool005coool00ol0VOooooooo`0Ooooo00<0
003oooooool00oooo`<0002Ioooo001Loooo00?o09Woooooool07oooo`030000oooooooo00?oool0
0`000?ooooooo`2Ioooo001Loooo00?o09Woooooool07oooo`030000oooooooo00?oool00`000?oo
ooooo`2Ioooo001Loooo00?o09Woooooool07_ooo`800005oooo00<0003oooooool0VOooo`00G?oo
o`03o`2Ioooooooo02Goool20000V_ooo`00G?ooo`03o`2Ioooooooo02Goool00`000?ooooooo`2I
oooo001Loooo00?o09Woooooool09Oooo`030000oooooooo09Woool005coool00ol0VOooooooo`0U
oooo00<0003oooooool0VOooo`00G?ooo`03o`2Ioooooooo02Goool00`000?ooooooo`2Ioooo001L
oooo00?o09Woooooool09Oooo`80002Joooo001Loooo00?o09Woooooool09Oooo`030000oooooooo
09Woool005coool00ol0VOooooooo`0Uoooo00<0003oooooool0VOooo`00G?ooo`03o`2Ioooooooo
02Goool00`000?ooooooo`2Ioooo001Loooo00?o09Woooooool09Oooo`80002Joooo001Loooo00?o
09Woooooool09Oooo`030000oooooooo09Woool005coool00ol0VOooooooo`0Uoooo00<0003ooooo
ool0VOooo`00G?ooo`03o`2Ioooooooo02Goool00`000?ooooooo`2Ioooo001Loooo00?o09Wooooo
ool09Oooo`030000oooooooo09Woool005coool00ol0VOooooooo`0Uoooo0P0009[oool005coool0
0ol0VOooooooo`0Uoooo00<0003oooooool0VOooo`00G?ooo`03o`2Ioooooooo01goool400001?oo
o`030000oooooooo09Woool005coool00ol0VOooooooo`0Moooo00<0003oooooool01Oooo`030000
oooooooo09Woool005coool00ol0VOooooooo`0Noooo00<0003oooooool01?ooo`<0002Ioooo001M
oooo00?o09Woooooool07_ooo`030000oooooooo00?oool00`000?ooooooo`2Ioooo001Moooo00?o
09Woooooool07?ooo`040000oooooooo00001?ooo`030000oooooooo09Woool005goool00ol0VOoo
ooooo`0Moooo0P0000Goool00`000?ooooooo`2Ioooo001Moooo00?o09Woooooool09?ooo`80002J
oooo001Moooo00?o09Woooooool09?ooo`030000oooooooo09Woool005goool00ol0VOooooooo`0T
oooo00<0003oooooool0VOooo`00GOooo`03o`2Ioooooooo02Coool00`000?ooooooo`2Ioooo001M
oooo00?o09Woooooool09?ooo`030000oooooooo09Woool005goool00ol0VOooooooo`0Toooo0P00
09[oool005goool00ol0VOooooooo`0Toooo00<0003oooooool0VOooo`00GOooo`03o`2Ioooooooo
02Coool00`000?ooooooo`2Ioooo001Moooo00?o09Woooooool09?ooo`030000oooooooo09Woool0
05goool00ol0VOooooooo`0Toooo0P0009[oool005goool00ol0VOooooooo`0Toooo00<0003ooooo
ool0VOooo`00GOooo`03o`2Ioooooooo02Coool00`000?ooooooo`2Ioooo001Moooo00?o09Wooooo
ool09?ooo`030000oooooooo09Woool005goool00ol0VOooooooo`0Toooo00<0003oooooool0VOoo
o`00GOooo`03o`2Ioooooooo02Coool20000V_ooo`00GOooo`03o`2Ioooooooo02Coool00`000?oo
ooooo`2Ioooo001Moooo00?o09Woooooool07Oooo`800005oooo00<0003oooooool0VOooo`00GOoo
o`03o`2Ioooooooo01coool010000?ooooooo`0000Coool00`000?ooooooo`2Ioooo001Moooo00?o
09Woooooool07_ooo`030000oooooooo00?oool30000VOooo`00GOooo`03o`2Ioooooooo01ooool0
0`000?ooooooo`02oooo00<0003oooooool0VOooo`00GOooo`03o`2Ioooooooo01coool010000?oo
ooooo`0000Coool00`000?ooooooo`2Ioooo001Moooo00?o09Woooooool07Oooo`800005oooo00<0
003oooooool0VOooo`00GOooo`03o`2Ioooooooo02Coool00`000?ooooooo`2Ioooo001Moooo00?o
09Woooooool09?ooo`80002Joooo001Moooo00?o09Woooooool09?ooo`030000oooooooo09Woool0
05goool00ol0VOooooooo`0Toooo00<0003oooooool0VOooo`00GOooo`03o`2Ioooooooo02Coool0
0`000?ooooooo`2Ioooo001Moooo00?o09Woooooool09?ooo`80002Joooo001Moooo00?o09Wooooo
ool09?ooo`030000oooooooo09Woool005goool00ol0VOooooooo`0Toooo00<0003oooooool0VOoo
o`00GOooo`03o`2Ioooooooo02Coool00`000?ooooooo`2Ioooo001Moooo00?o09Woooooool09?oo
o`030000oooooooo09Woool005goool00ol0VOooooooo`0Toooo0P0009[oool005goool00ol0VOoo
ooooo`0Toooo00<0003oooooool0VOooo`00GOooo`03o`2Ioooooooo02Coool00`000?ooooooo`2I
oooo001Moooo00?o09Woooooool09?ooo`030000oooooooo09Woool005goool00ol0VOooooooo`0T
oooo0P0009[oool005goool00ol0VOooooooo`0Toooo00<0003oooooool0VOooo`00GOooo`03o`2I
oooooooo02Coool00`000?ooooooo`2Ioooo001Moooo00?o09Woooooool07_ooo`<00003oooo00<0
003oooooool0VOooo`00GOooo`03o`2Ioooooooo01ooool00`000?ooooooo`02oooo00<0003ooooo
ool0VOooo`00GOooo`03o`2Ioooooooo01coool500000oooo`<0002Ioooo001loooo00@0003ooooo
ool0002Poooo001moooo00<0003oool00000X?ooo`00O_ooo`80002Poooo003ooooo8Oooo`00oooo
ob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo
00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00coool400000oooo`800004oooo0P0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04
oooo100000?oool00`000?ooooooo`09oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Doooo00<0003oooooool02?ooo`040000
oooooooo00001?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500005?ooo`030000
oooooooo00Soool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000E
oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo01Ooool200002_ooo`800003oooo00<0003oooooool0NOooo`00ooooob7oool0
0?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.28158 .26487 L
.29205 .26487 L
.30316 .26487 L
.30791 .26487 L
.31304 .26487 L
.31454 .26487 L
.31597 .26487 L
.31725 .26487 L
.31798 .26487 L
s
.31798 .26487 m
.31825 .61803 L
s
0 .4 1 r
.02381 .25938 m
.04262 .25805 L
.06244 .2563 L
.08255 .25406 L
.10458 .25093 L
.12415 .2474 L
.14509 .24263 L
.16639 .23645 L
.18653 .22906 L
.22495 .20936 L
.24479 .19545 L
.26581 .17717 L
.28557 .15618 L
.30365 .13347 L
.30841 .12693 L
.31092 .12338 L
.3136 .11953 L
.31492 .1176 L
.31617 .11577 L
.31729 .11411 L
.31851 .26487 L
.31966 .26487 L
.32088 .26487 L
.32306 .26487 L
.34394 .26487 L
.38191 .26487 L
.42233 .26487 L
.46124 .26487 L
.5026 .26487 L
.54245 .26487 L
.58078 .26487 L
.62156 .26487 L
.66083 .26487 L
.69858 .26487 L
.73878 .26487 L
.77747 .26487 L
.81861 .26487 L
.85823 .26487 L
.89634 .26487 L
.9369 .26487 L
.97595 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00H?ooo`80I_lAoooo00<0000co`0co`003S?o0080002Joooo001Poooo0P1Voa7oool0
0`0003?o03?o000><ol000<0000co`000000VOooo`00Goooo`0306Kooooo06Ko013oool00`0003?o
03?o000?<ol00P000003<ol00000oooo09Ooool005koool0101Vooooooooo`1Voa3oool00`0003?o
03?o000?<ol000@0000co`0co`00002Hoooo001Moooo00D0I_ooooooooooool0I_l03oooo`030000
<ol0<ol0010co`001@0003?o03?o03?o0000002Goooo001Moooo00D0I_ooooooooooool0I_l03ooo
o`030000<ol0<ol0010co`000`0003?o03?o0002<ol000<0003oooooool0U?ooo`00G?ooo`0306Ko
oooooooo00;oool00`1Vooooooooo`0<oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001Loooo00<0I_ooooooool00_ooo`0306Kooooooooo00_oool00`0003?o
03?o000B<ol00P0000@co`000`000?ooooooo`2Coooo001Koooo00<0I_ooooooool00oooo`0306Ko
oooooooo00[oool00`0003?o03?o000C<ol000<0000co`0co`0013?o00030000oooooooo09;oool0
05[oool00`1Vooooooooo`04oooo00<0I_ooooooool02_ooo`030000<ol0<ol001<co`000`0003?o
03?o0004<ol000<0003oooooool0T_ooo`00F_ooo`0306Kooooooooo00Coool00`1Vooooooooo`09
oooo00<0000co`0co`0053?o00030000<ol0<ol000Dco`000`000?ooooooo`2Aoooo001Ioooo00<0
I_ooooooool01Oooo`0306Kooooooooo00Soool00`0003?o03?o000E<ol00P0000Lco`000`000?oo
ooooo`2@oooo001Hoooo00<0I_ooooooool01_ooo`0306Kooooooooo00Ooool00`0003?o03?o000F
<ol000<0000co`0co`001S?o00030000oooooooo093oool005Ooool00`1Vooooooooo`07oooo00<0
I_ooooooool01oooo`030000<ol0<ol001Hco`000`0003?o03?o0007<ol000<0003oooooool0Sooo
o`00E_ooo`0306Kooooooooo00Soool00`1Vooooooooo`06oooo00<0000co`0co`003c?o00D00003
<ol000<0000co`0co`0023?o00030000oooooooo08koool005Goool00`1Vooooooooo`09oooo00<0
I_ooooooool01Oooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0co`0023?o
00030000oooooooo08koool005Coool00`1Vooooooooo`0:oooo00<0I_ooooooool01?ooo`030000
<ol0<ol001<co`000`0003?o03?o0003<ol00`0000Tco`000`000?ooooooo`2=oooo001Coooo00<0
I_ooooooool02oooo`0306Kooooooooo00Coool00`0003?o03?o000;<ol0100000@co`000`0003?o
03?o0003<ol000<0000co`0co`002S?o00030000oooooooo08coool005;oool00`1Vooooooooo`0<
oooo00<0I_ooooooool00oooo`030000<ol0<ol001@co`000`0003?o03?o0003<ol000<0000co`0c
o`002c?o00030000oooooooo08_oool0053oool206Ko3oooo`0306Kooooooooo00;oool00`0003?o
03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00Coooo`0306Ko
oooooooo00ooool00`1Vooooooooo`02oooo00<0000co`0co`006c?o0080000=<ol000<0003ooooo
ool0R_ooo`00C_ooo`0306Kooooooooo013oool01@1Vooooooooooooo`00000N<ol000<0000co`0c
o`003C?o00030000oooooooo08Woool004coool206Ko4oooo`0406Kooooooooo00007c?o00030000
<ol0<ol000hco`000`000?ooooooo`28oooo001:oooo0P1VoaGoool00`1Vooooo`00000P<ol000<0
000co`0co`003c?o00030000oooooooo08Ooool004Woool00`1Vooooooooo`0Eoooo00<0I_ooool0
000083?o00030000<ol0<ol0010co`000`000?ooooooo`26oooo0017oooo0P1VoaSoool00`1Vo`00
03?o000P<ol00P00018co`000`000?ooooooo`25oooo0015oooo0P1Voa[oool00`1Voc?o03?o000P
<ol000<0000co`0co`004S?o00030000oooooooo08Coool002ooool300004Oooo`80I_lDoooo1000
00;oool2000000<0I_lco`0co`0083?o00030000<ol0<ol001<co`000`000?ooooooo`0Aoooo1000
02[oool300009oooo`<0000Goooo000`oooo00<0003oooooool03_ooo`80I_lFoooo00<0003ooooo
ool00_ooo`040000<ol0<ol006Ko8S?o00030000<ol0<ol001@co`000`000?ooooooo`0@oooo00<0
003oooooool0;?ooo`030000oooooooo02Koool010000?ooooooo`0001Koool002goool500003?oo
o`<0I_lIoooo00@0003oooooool00003<ol000<0I_lco`0co`0083?o0080000F<ol00P00017oool0
0`000?ooooooo`0Xoooo1@0002Ooool010000?ooooooo`0001Koool002Ooool400000_ooo`040000
oooooooo00002oooo`80I_lEoooo100000Coool2000013?o000306Ko<ol0<ol0020co`000`0003?o
03?o000G<ol000<0003oooooool03oooo`030000oooooooo02Ooool010000?ooooooo`0002Soool3
00005oooo`00;_ooo`030000oooo000000Soool306Ko7Oooo`8000000c?o000003?o0003<ol000<0
I_lco`0co`0083?o00030000<ol0<ol001Pco`000`000?ooooooo`0<oooo00@0003oooooool0000Y
oooo00<0003oool00000:Oooo`030000oooooooo01Koool002ooool200001_ooo`80I_lOoooo1000
00Dco`000`1Voc?o03?o000P<ol000<0000co`0co`006C?o00030000oooooooo00coool20000:ooo
o`80000Yoooo0`0001Koool003?oool406Ko7oooo`800009<ol000<0I_lco`0co`0083?o00030000
<ol0<ol001Xco`020000OOooo`00;_ooo`D0I_lQoooo0P0000/co`000`1Voc?o03?o000P<ol00P00
01dco`030000N_ooo`008oooo`/0I_lSoooo0`0000dco`000`1Voc?o03?o000P<ol000<0000co`0c
o`007c?o00H0001doooo000Ioooo2P1VobSoool6000043?o000306Ko<ol0<ol0020co`000`0003?o
03?o000U<ol00`00077oool001Koool306Ko:?ooo`X0000F<ol000<0I_lco`0co`0083?o00030000
<ol0<ol002Pco`0:0000Ioooo`004?ooool0000Aoooo000Foooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool01_ooo`03o`2Ioooo000000[oool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool002coool00`000?oo
ooooo`0Yoooo00<0003oooooool01_ooo`03o`2Ioooooooo023oool00`000?ooooooo`0Yoooo00<0
003oooooool0:Oooo`030000oooooooo02Woool00`000?ooooooo`0Eoooo001Qoooo00?o09Wooooo
ool08?ooo`030000oooooooo09Woool0067oool00ol0VOooooooo`0Poooo00<0003oooooool0VOoo
o`00HOooo`03o`2Ioooooooo023oool20000V_ooo`00HOooo`03o`2Ioooooooo023oool00`000?oo
ooooo`2Ioooo001Qoooo00?o09Woooooool08?ooo`030000oooooooo09Woool0067oool00ol0VOoo
ooooo`0Poooo00<0003oooooool0VOooo`00HOooo`03o`2Ioooooooo023oool20000V_ooo`00HOoo
o`03o`2Ioooooooo023oool00`000?ooooooo`2Ioooo001Qoooo00?o09Woooooool08?ooo`030000
oooooooo09Woool0067oool00ol0VOooooooo`0Poooo00<0003oooooool0VOooo`00HOooo`03o`2I
oooooooo023oool00`000?ooooooo`2Ioooo001Qoooo00?o09Woooooool08?ooo`80002Joooo001Q
oooo00?o09Woooooool08?ooo`030000oooooooo09Woool0067oool00ol0VOooooooo`0Poooo00<0
003oooooool0VOooo`00HOooo`03o`2Ioooooooo023oool00`000?ooooooo`2Ioooo001Qoooo00?o
09Woooooool08?ooo`80002Joooo001Qoooo00?o09Woooooool08?ooo`030000oooooooo09Woool0
067oool00ol0VOooooooo`0Poooo00<0003oooooool0VOooo`00HOooo`03o`2Ioooooooo01Soool5
00000oooo`030000oooooooo09Woool0067oool00ol0VOooooooo`0Joooo00<0003oooooool00ooo
o`030000oooooooo09Woool0067oool00ol0VOooooooo`0Joooo00<0003oooooool00oooo`<0002I
oooo001Qoooo00?o09Woooooool06_ooo`030000oooooooo00?oool00`000?ooooooo`2Ioooo001Q
oooo00?o09Woooooool06_ooo`030000oooooooo00?oool00`000?ooooooo`2Ioooo001Qoooo00?o
09Woooooool06Oooo`800005oooo00<0003oooooool0VOooo`00HOooo`03o`2Ioooooooo023oool2
0000V_ooo`00HOooo`03o`2Ioooooooo023oool00`000?ooooooo`2Ioooo001Qoooo00?o09Wooooo
ool08?ooo`030000oooooooo09Woool0067oool00ol0VOooooooo`0Poooo00<0003oooooool0VOoo
o`00HOooo`03o`2Ioooooooo023oool00`000?ooooooo`2Ioooo001Qoooo00?o09Woooooool08?oo
o`80002Joooo001Qoooo00?o09Woooooool08?ooo`030000oooooooo09Woool0067oool00ol0VOoo
ooooo`0Poooo00<0003oooooool0VOooo`00HOooo`03o`2Ioooooooo023oool00`000?ooooooo`2I
oooo001Qoooo00?o09Woooooool08?ooo`80002Joooo001Qoooo00?o09Woooooool08?ooo`030000
oooooooo09Woool0067oool00ol0VOooooooo`0Poooo00<0003oooooool0VOooo`00HOooo`03o`2I
oooooooo023oool00`000?ooooooo`2Ioooo001Qoooo00?o09Woooooool08?ooo`030000oooooooo
09Woool0067oool00ol0VOooooooo`0Poooo0P0009[oool0067oool00ol0VOooooooo`0Poooo00<0
003oooooool0VOooo`00HOooo`03o`2Ioooooooo01Soool400001?ooo`030000oooooooo09Woool0
067oool00ol0VOooooooo`0Hoooo00<0003oooooool01Oooo`030000oooooooo09Woool0067oool0
0ol0VOooooooo`0Ioooo00<0003oooooool01?ooo`<0002Ioooo001Qoooo00?o09Woooooool06_oo
o`030000oooooooo00?oool00`000?ooooooo`2Ioooo001Qoooo00?o09Woooooool06?ooo`040000
oooooooo00001?ooo`030000oooooooo09Woool0067oool00ol0VOooooooo`0Ioooo0P0000Goool0
0`000?ooooooo`2Ioooo001Qoooo00?o09Woooooool08?ooo`80002Joooo001Qoooo00?o09Wooooo
ool08?ooo`030000oooooooo09Woool0067oool00ol0VOooooooo`0Poooo00<0003oooooool0VOoo
o`00HOooo`03o`2Ioooooooo023oool00`000?ooooooo`2Ioooo001Qoooo00?o09Woooooool08?oo
o`030000oooooooo09Woool0067oool00ol0VOooooooo`0Poooo0P0009[oool0067oool00ol0VOoo
ooooo`0Poooo00<0003oooooool0VOooo`00HOooo`03o`2Ioooooooo023oool00`000?ooooooo`2I
oooo001Qoooo00?o09Woooooool08?ooo`030000oooooooo09Woool0067oool00ol0VOooooooo`0P
oooo0P0009[oool0067oool00ol0VOooooooo`0Poooo00<0003oooooool0VOooo`00HOooo`03o`2I
oooooooo023oool00`000?ooooooo`2Ioooo001Qoooo00?o09Woooooool08?ooo`030000oooooooo
09Woool0067oool00ol0VOooooooo`0Poooo00<0003oooooool0VOooo`00HOooo`03o`2Ioooooooo
023oool20000V_ooo`00HOooo`03o`2Ioooooooo023oool00`000?ooooooo`2Ioooo001Qoooo00?o
09Woooooool06Oooo`800005oooo00<0003oooooool0VOooo`00HOooo`03o`2Ioooooooo01Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2Ioooo001Qoooo00?o09Woooooool06_ooo`030000
oooooooo00?oool30000VOooo`00HOooo`03o`2Ioooooooo01_oool00`000?ooooooo`02oooo00<0
003oooooool0VOooo`00HOooo`03o`2Ioooooooo01Soool010000?ooooooo`0000Coool00`000?oo
ooooo`2Ioooo001Qoooo00?o09Woooooool06Oooo`800005oooo00<0003oooooool0VOooo`00HOoo
o`03o`2Ioooooooo023oool00`000?ooooooo`2Ioooo001Qoooo00?o09Woooooool08?ooo`80002J
oooo001Qoooo00?o09Woooooool08?ooo`030000oooooooo09Woool0067oool00ol0VOooooooo`0P
oooo00<0003oooooool0VOooo`00HOooo`03o`2Ioooooooo023oool00`000?ooooooo`2Ioooo001Q
oooo00?o09Woooooool08?ooo`80002Joooo001Qoooo00?o09Woooooool08?ooo`030000oooooooo
09Woool0067oool00ol0VOooooooo`0Poooo00<0003oooooool0VOooo`00HOooo`03o`2Ioooooooo
023oool00`000?ooooooo`2Ioooo001Qoooo00?o09Woooooool08?ooo`030000oooooooo09Woool0
067oool00ol0VOooooooo`0Poooo0P0009[oool0067oool00ol0VOooooooo`0Poooo00<0003ooooo
ool0VOooo`00HOooo`03o`2Ioooooooo023oool00`000?ooooooo`2Ioooo001Qoooo00?o09Wooooo
ool08?ooo`030000oooooooo09Woool0067oool00ol0VOooooooo`0Poooo0P0009[oool0067oool0
0ol0VOooooooo`0Poooo00<0003oooooool0VOooo`00HOooo`03o`2Ioooooooo023oool00`000?oo
ooooo`2Ioooo001Qoooo00?o09Woooooool06_ooo`<00003oooo00<0003oooooool0VOooo`00HOoo
o`03o`2Ioooooooo01_oool00`000?ooooooo`02oooo00<0003oooooool0VOooo`00HOooo`03o`2I
oooooooo01Soool500000oooo`<0002Ioooo001loooo00@0003oooooool0002Poooo001moooo00<0
003oool00000X?ooo`00O_ooo`80002Poooo003ooooo8Oooo`00ooooob7oool007Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00coool400000oooo`800003oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool00`000?oo
ooooo`09oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0Doooo00<0003oooooool02?ooo`040000oooooooo00001?ooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500005?ooo`030000oooooooo00Ooool300001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool00009
oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P00
00[oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.28158 .26487 L
.30316 .26487 L
.31323 .26487 L
.32392 .26487 L
.32831 .26487 L
.33073 .26487 L
.33304 .26487 L
.33433 .26487 L
.33507 .26487 L
s
.33507 .26487 m
.33534 .61803 L
s
0 .4 1 r
.02381 .26039 m
.04262 .2593 L
.06244 .25787 L
.08255 .25604 L
.10458 .25349 L
.12415 .2506 L
.14509 .24671 L
.16639 .24166 L
.18653 .23563 L
.22495 .21955 L
.24479 .20819 L
.26581 .19327 L
.30365 .15758 L
.32306 .13467 L
.32865 .12757 L
.3314 .12401 L
.33275 .12225 L
.33396 .12066 L
.33515 .11909 L
.33627 .26487 L
.33745 .26487 L
.33873 .26487 L
.34394 .26487 L
.38494 .26487 L
.42443 .26487 L
.4624 .26487 L
.50282 .26487 L
.54173 .26487 L
.58309 .26487 L
.62294 .26487 L
.66127 .26487 L
.70205 .26487 L
.74132 .26487 L
.77907 .26487 L
.81927 .26487 L
.85796 .26487 L
.8991 .26487 L
.93872 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00IOooo`0306Kooooooooo00_oool0
0`0003?o03?o000><ol000<0000co`000000VOooo`00IOooo`0306Kooooooooo00[oool00`0003?o
03?o000?<ol00P000003<ol00000oooo09Ooool006Coool206Ko3?ooo`030000<ol0<ol000lco`00
100003?o03?o000009Soool006?oool00`1Vooooo`1Vo`0;oooo00<0000co`0co`0043?o00050000
<ol0<ol0<ol0000009Ooool006;oool0101Vooooooooo`1Vo`_oool00`0003?o03?o000@<ol000<0
000co`0co`000S?o00030000oooooooo09Coool0067oool01@1Vooooooooooooo`1Vo`0:oooo00<0
000co`0co`004C?o00030000<ol0<ol0008co`000`000?ooooooo`2Doooo001Poooo00<0I_oooooo
ool00_ooo`0306Kooooooooo00Ooool00`0003?o03?o000B<ol00P0000@co`000`000?ooooooo`2C
oooo001Ooooo00<0I_ooooooool00oooo`0306Kooooooooo00Koool00`0003?o03?o000C<ol000<0
000co`0co`0013?o00030000oooooooo09;oool005ooool00`1Vooooooooo`03oooo00<0I_oooooo
ool01_ooo`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00G_oo
o`0306Kooooooooo00Coool00`1Vooooooooo`05oooo00<0000co`0co`0053?o00030000<ol0<ol0
00Dco`000`000?ooooooo`2Aoooo001Moooo00<0I_ooooooool01Oooo`0306Kooooooooo00Coool0
0`0003?o03?o000E<ol00P0000Lco`000`000?ooooooo`2@oooo001Loooo00<0I_ooooooool01_oo
o`0306Kooooooooo00?oool00`0003?o03?o000F<ol000<0000co`0co`001S?o00030000oooooooo
093oool005_oool00`1Vooooooooo`07oooo00<0I_ooooooool00oooo`030000<ol0<ol001Hco`00
0`0003?o03?o0007<ol000<0003oooooool0Soooo`00F_ooo`0306Kooooooooo00Soool00`1Voooo
ooooo`02oooo00<0000co`0co`003c?o00D00003<ol000<0000co`0co`0023?o00030000oooooooo
08koool005Woool00`1Vooooooooo`09oooo00D0I_ooooooooooool0000053?o00030000<ol0<ol0
00<co`000`0003?o03?o0008<ol000<0003oooooool0S_ooo`00F?ooo`0306Kooooooooo00[oool0
101Vooooooooo`0001Dco`000`0003?o03?o0003<ol00`0000Tco`000`000?ooooooo`2=oooo001G
oooo00<0I_ooooooool02oooo`0406Kooooooooo00003C?o00@00004<ol000<0000co`0co`000c?o
00030000<ol0<ol000Xco`000`000?ooooooo`2<oooo001Foooo00<0I_ooooooool03?ooo`0306Ko
oooo000001Hco`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool0
05Goool00`1Vooooooooo`0=oooo00<0I_l0000co`005C?o00800005<ol000<0000co`0co`002c?o
00030000oooooooo08_oool005Coool00`1Vooooooooo`0>oooo00<0I_l0000co`0073?o0080000=
<ol000<0003oooooool0R_ooo`00D_ooo`80I_lAoooo00<0I_lco`0co`0073?o00030000<ol0<ol0
00dco`000`000?ooooooo`29oooo001Aoooo00<0I_ooooooool04?ooo`03000006Ko<ol001dco`00
0`0003?o03?o000><ol000<0003oooooool0R?ooo`00Coooo`80I_lBoooo00<0000co`00I_l07S?o
00030000<ol0<ol000lco`000`000?ooooooo`27oooo001>oooo00<0I_ooooooool04_ooo`030000
<ol006Ko01hco`000`0003?o03?o000@<ol000<0003oooooool0Q_ooo`00C?ooo`80I_lDoooo00@0
000co`0co`00I_lN<ol00P00018co`000`000?ooooooo`25oooo001:oooo0P1VoaGoool01@0003?o
03?o03?o001Vo`0N<ol000<0000co`0co`004S?o00030000oooooooo08Coool002ooool300005_oo
o`80I_l?oooo100000;oool2000013?o000306Ko<ol0<ol001`co`000`0003?o03?o000C<ol000<0
003oooooool04Oooo`@0000Zoooo0`0002Ooool300005oooo`00<?ooo`030000oooooooo01?oool2
06Ko4Oooo`030000oooooooo00;oool00`0003?o03?o0004<ol000<0I_lco`0co`0073?o00030000
<ol0<ol001@co`000`000?ooooooo`0@oooo00<0003oooooool0;?ooo`030000oooooooo02Koool0
10000?ooooooo`0001Koool002goool500004Oooo`<0I_lDoooo00@0003oooooool00007<ol000<0
I_lco`0co`0073?o0080000F<ol00P00017oool00`000?ooooooo`0Xoooo1@0002Ooool010000?oo
ooooo`0001Koool002Ooool400000_ooo`040000oooooooo00004?ooo`80I_l@oooo100000Coool2
000023?o000306Ko<ol0<ol001`co`000`0003?o03?o000G<ol000<0003oooooool03oooo`030000
oooooooo02Ooool010000?ooooooo`0002Soool300005oooo`00;_ooo`030000oooo000000coool4
06Ko6?ooo`8000000c?o000003?o0007<ol000<0I_lco`0co`0073?o00030000<ol0<ol001Pco`00
0`000?ooooooo`0<oooo00@0003oooooool0000Yoooo00<0003oool00000:Oooo`030000oooooooo
01Koool002ooool200002?ooo`@0I_lKoooo100000Tco`000`1Voc?o03?o000L<ol000<0000co`0c
o`006C?o00030000oooooooo00coool20000:oooo`80000Yoooo0`0001Koool003Ooool206Ko7Ooo
o`80000=<ol000<0I_lco`0co`0073?o00030000<ol0<ol001Xco`020000OOooo`00<oooo`@0I_lM
oooo0P0000lco`000`1Voc?o03?o000L<ol00P0001dco`030000N_ooo`00:Oooo`X0I_lNoooo0`00
014co`000`1Voc?o03?o000L<ol000<0000co`0co`007c?o00H0001doooo000Noooo2`1Vob;oool6
000053?o000306Ko<ol0<ol001`co`000`0003?o03?o000U<ol00`00077oool001Koool806Ko8ooo
o`X0000J<ol000<0I_lco`0co`0073?o00030000<ol0<ol002Pco`0:0000Ioooo`004?ooool0000A
oooo000Foooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000ooooo`2I00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo01Goool002coool00`000?ooooooo`0Yoooo00<0003oooooool02_ooo`03o`2I
oooooooo01coool00`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo02Woool0
0`000?ooooooo`0Eoooo001Uoooo00?o09Woooooool07?ooo`030000oooooooo09Woool006Goool0
0ol0VOooooooo`0Loooo00<0003oooooool0VOooo`00IOooo`03o`2Ioooooooo01coool20000V_oo
o`00IOooo`03o`2Ioooooooo01coool00`000?ooooooo`2Ioooo001Uoooo00?o09Woooooool07?oo
o`030000oooooooo09Woool006Goool00ol0VOooooooo`0Loooo00<0003oooooool0VOooo`00IOoo
o`03o`2Ioooooooo01coool20000V_ooo`00IOooo`03o`2Ioooooooo01coool00`000?ooooooo`2I
oooo001Uoooo00?o09Woooooool07?ooo`030000oooooooo09Woool006Goool00ol0VOooooooo`0L
oooo00<0003oooooool0VOooo`00IOooo`03o`2Ioooooooo01coool00`000?ooooooo`2Ioooo001U
oooo00?o09Woooooool07?ooo`80002Joooo001Uoooo00?o09Woooooool07?ooo`030000oooooooo
09Woool006Goool00ol0VOooooooo`0Loooo00<0003oooooool0VOooo`00IOooo`03o`2Ioooooooo
01coool00`000?ooooooo`2Ioooo001Uoooo00?o09Woooooool07?ooo`80002Joooo001Uoooo00?o
09Woooooool07?ooo`030000oooooooo09Woool006Goool00ol0VOooooooo`0Loooo00<0003ooooo
ool0VOooo`00IOooo`03o`2Ioooooooo01Coool500000oooo`030000oooooooo09Woool006Goool0
0ol0VOooooooo`0Foooo00<0003oooooool00oooo`030000oooooooo09Woool006Goool00ol0VOoo
ooooo`0Foooo00<0003oooooool00oooo`<0002Ioooo001Uoooo00?o09Woooooool05_ooo`030000
oooooooo00?oool00`000?ooooooo`2Ioooo001Uoooo00?o09Woooooool05_ooo`030000oooooooo
00?oool00`000?ooooooo`2Ioooo001Uoooo00?o09Woooooool05Oooo`800005oooo00<0003ooooo
ool0VOooo`00IOooo`03o`2Ioooooooo01coool20000V_ooo`00IOooo`03o`2Ioooooooo01coool0
0`000?ooooooo`2Ioooo001Uoooo00?o09Woooooool07?ooo`030000oooooooo09Woool006Goool0
0ol0VOooooooo`0Loooo00<0003oooooool0VOooo`00IOooo`03o`2Ioooooooo01coool00`000?oo
ooooo`2Ioooo001Uoooo00?o09Woooooool07?ooo`80002Joooo001Uoooo00?o09Woooooool07?oo
o`030000oooooooo09Woool006Goool00ol0VOooooooo`0Loooo00<0003oooooool0VOooo`00IOoo
o`03o`2Ioooooooo01coool00`000?ooooooo`2Ioooo001Uoooo00?o09Woooooool07?ooo`80002J
oooo001Uoooo00?o09Woooooool07?ooo`030000oooooooo09Woool006Goool00ol0VOooooooo`0L
oooo00<0003oooooool0VOooo`00IOooo`03o`2Ioooooooo01coool00`000?ooooooo`2Ioooo001U
oooo00?o09Woooooool07?ooo`030000oooooooo09Woool006Goool00ol0VOooooooo`0Loooo0P00
09[oool006Goool00ol0VOooooooo`0Loooo00<0003oooooool0VOooo`00IOooo`03o`2Ioooooooo
01Coool400001?ooo`030000oooooooo09Woool006Goool00ol0VOooooooo`0Doooo00<0003ooooo
ool01Oooo`030000oooooooo09Woool006Goool00ol0VOooooooo`0Eoooo00<0003oooooool01?oo
o`<0002Ioooo001Uoooo00?o09Woooooool05_ooo`030000oooooooo00?oool00`000?ooooooo`2I
oooo001Uoooo00?o09Woooooool05?ooo`040000oooooooo00001?ooo`030000oooooooo09Woool0
06Goool00ol0VOooooooo`0Eoooo0P0000Goool00`000?ooooooo`2Ioooo001Uoooo00?o09Wooooo
ool07?ooo`80002Joooo001Uoooo00?o09Woooooool07?ooo`030000oooooooo09Woool006Goool0
0ol0VOooooooo`0Loooo00<0003oooooool0VOooo`00IOooo`03o`2Ioooooooo01coool00`000?oo
ooooo`2Ioooo001Uoooo00?o09Woooooool07?ooo`030000oooooooo09Woool006Goool00ol0VOoo
ooooo`0Loooo0P0009[oool006Goool00ol0VOooooooo`0Loooo00<0003oooooool0VOooo`00IOoo
o`03o`2Ioooooooo01coool00`000?ooooooo`2Ioooo001Uoooo00?o09Woooooool07?ooo`030000
oooooooo09Woool006Goool00ol0VOooooooo`0Loooo0P0009[oool006Goool00ol0VOooooooo`0L
oooo00<0003oooooool0VOooo`00IOooo`03o`2Ioooooooo01coool00`000?ooooooo`2Ioooo001U
oooo00?o09Woooooool07?ooo`030000oooooooo09Woool006Goool00ol0VOooooooo`0Loooo00<0
003oooooool0VOooo`00IOooo`03o`2Ioooooooo01coool20000V_ooo`00IOooo`03o`2Ioooooooo
01coool00`000?ooooooo`2Ioooo001Uoooo00?o09Woooooool05Oooo`800005oooo00<0003ooooo
ool0VOooo`00IOooo`03o`2Ioooooooo01Coool010000?ooooooo`0000Coool00`000?ooooooo`2I
oooo001Uoooo00?o09Woooooool05_ooo`030000oooooooo00?oool30000VOooo`00IOooo`03o`2I
oooooooo01Ooool00`000?ooooooo`02oooo00<0003oooooool0VOooo`00IOooo`03o`2Ioooooooo
01Coool010000?ooooooo`0000Coool00`000?ooooooo`2Ioooo001Uoooo00?o09Woooooool05Ooo
o`800005oooo00<0003oooooool0VOooo`00IOooo`03o`2Ioooooooo01coool00`000?ooooooo`2I
oooo001Uoooo00?o09Woooooool07?ooo`80002Joooo001Uoooo00?o09Woooooool07?ooo`030000
oooooooo09Woool006Goool00ol0VOooooooo`0Loooo00<0003oooooool0VOooo`00IOooo`03o`2I
oooooooo01coool00`000?ooooooo`2Ioooo001Uoooo00?o09Woooooool07?ooo`80002Joooo001U
oooo00?o09Woooooool07?ooo`030000oooooooo09Woool006Goool00ol0VOooooooo`0Loooo00<0
003oooooool0VOooo`00IOooo`03o`2Ioooooooo01coool00`000?ooooooo`2Ioooo001Uoooo00?o
09Woooooool07?ooo`030000oooooooo09Woool006Goool00ol0VOooooooo`0Loooo0P0009[oool0
06Goool00ol0VOooooooo`0Loooo00<0003oooooool0VOooo`00IOooo`03o`2Ioooooooo01coool0
0`000?ooooooo`2Ioooo001Uoooo00?o09Woooooool07?ooo`030000oooooooo09Woool006Goool0
0ol0VOooooooo`0Loooo0P0009[oool006Goool00ol0VOooooooo`0Loooo00<0003oooooool0VOoo
o`00IOooo`03o`2Ioooooooo01coool00`000?ooooooo`2Ioooo001Uoooo00?o09Woooooool05_oo
o`<00003oooo00<0003oooooool0VOooo`00IOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`02
oooo00<0003oooooool0VOooo`00IOooo`03o`2Ioooooooo01Coool500000oooo`<0002Ioooo001l
oooo00@0003oooooool0002Poooo001moooo00<0003oool00000X?ooo`00O_ooo`80002Poooo003o
oooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?oo
o`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00coool400000oooo`800005oooo0`0000;oool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`04oooo100000?oool00`000?ooooooo`0<oooo00D0003oooooooooool00000N_oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Doooo00<0003oooooool02?ooo`D00003
oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Doooo00<0003oooooool01ooo
o`040000oooooooo00000oooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000E
oooo00@0003oooooool00009oooo00<0003oool000000oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Goooo0P0000_oool200000_ooo`030000oooooooo07Woool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.32392 .26487 L
.33304 .26487 L
.34309 .26487 L
.34772 .26487 L
.35028 .26487 L
.35154 .26487 L
.35271 .26487 L
s
.35271 .26487 m
.35315 .61803 L
s
0 .4 1 r
.02381 .26122 m
.04262 .26033 L
.06244 .25916 L
.08255 .25767 L
.10458 .25559 L
.12415 .25324 L
.14509 .25006 L
.16639 .24595 L
.18653 .24103 L
.22495 .22792 L
.24479 .21865 L
.26581 .20649 L
.30365 .17739 L
.32469 .15704 L
.33467 .14652 L
.34394 .13642 L
.34854 .13133 L
.34986 .12987 L
.35111 .12849 L
.35223 .12725 L
.35344 .26487 L
.35469 .26487 L
.35607 .26487 L
.35884 .26487 L
.36381 .26487 L
.38271 .26487 L
.42313 .26487 L
.46204 .26487 L
.5034 .26487 L
.54325 .26487 L
.58158 .26487 L
.62236 .26487 L
.66163 .26487 L
.69938 .26487 L
.73958 .26487 L
.77827 .26487 L
.81941 .26487 L
.85903 .26487 L
.89714 .26487 L
.9377 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001Z
oooo00<0I_ooooooool01Oooo`030000<ol0<ol000lco`00100003?o03?o000009Soool006Woool2
06Ko1_ooo`030000<ol0<ol0010co`001@0003?o03?o03?o0000002Goooo001Xoooo00<0I_ooool0
I_l01_ooo`030000<ol0<ol0010co`000`0003?o03?o0002<ol000<0003oooooool0U?ooo`00Iooo
o`0406Kooooooooo06Ko1Oooo`030000<ol0<ol0014co`000`0003?o03?o0002<ol000<0003ooooo
ool0U?ooo`00I_ooo`0506Kooooooooooooo06Ko00Coool00`0003?o03?o000B<ol00P0000@co`00
0`000?ooooooo`2Coooo001Uoooo00<0I_ooooooool00_ooo`0506Kooooooooooooo000001Dco`00
0`0003?o03?o0004<ol000<0003oooooool0T_ooo`00I?ooo`0306Kooooooooo00?oool01@1Voooo
ooooooooo`00000E<ol000<0000co`0co`0013?o00030000oooooooo09;oool006Coool00`1Voooo
ooooo`03oooo00@0I_ooooooool0000F<ol000<0000co`0co`001C?o00030000oooooooo097oool0
06?oool00`1Vooooooooo`04oooo00<0I_ooool000005c?o00800007<ol000<0003oooooool0T?oo
o`00H_ooo`0306Kooooooooo00Goool00`1Vo`0003?o000G<ol000<0000co`0co`001S?o00030000
oooooooo093oool0067oool00`1Vooooooooo`06oooo00<0I_l0000co`005c?o00030000<ol0<ol0
00Lco`000`000?ooooooo`2?oooo001Ooooo0P1Vo`Woool00`1Voc?o03?o000?<ol01@0000<co`00
0`0003?o03?o0008<ol000<0003oooooool0S_ooo`00G_ooo`0306Kooooooooo00Soool00`00001V
oc?o000B<ol000<0000co`0co`000c?o00030000<ol0<ol000Pco`000`000?ooooooo`2>oooo001M
oooo00<0I_ooooooool02?ooo`030000<ol006Ko01<co`000`0003?o03?o0003<ol00`0000Tco`00
0`000?ooooooo`2=oooo001Loooo00<0I_ooooooool02Oooo`030000<ol006Ko00/co`04000013?o
00030000<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00F_ooo`80I_l;
oooo00@0000co`0co`00I_lC<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?oo
ooooo`2;oooo001Ioooo00<0I_ooooooool02_ooo`050000<ol0<ol0<ol006Ko018co`0200001C?o
00030000<ol0<ol000/co`000`000?ooooooo`2;oooo001Hoooo00<0I_ooooooool02oooo`050000
<ol0<ol0<ol006Ko01Tco`0200003C?o00030000oooooooo08[oool005Koool206Ko3Oooo`030000
<ol0<ol0008co`000`1Voc?o03?o000G<ol000<0000co`0co`003C?o00030000oooooooo08Woool0
05Goool00`1Vooooooooo`0<oooo00<0000co`0co`000c?o000306Ko<ol0<ol001Lco`000`0003?o
03?o000><ol000<0003oooooool0R?ooo`00E?ooo`0306Kooooooooo00coool00`0003?o03?o0004
<ol000<0I_lco`0co`005c?o00030000<ol0<ol000lco`000`000?ooooooo`27oooo001Boooo0P1V
o`ooool00`0003?o03?o0004<ol000<0I_lco`0co`005c?o00030000<ol0<ol0010co`000`000?oo
ooooo`26oooo001Aoooo00<0I_ooooooool03_ooo`030000<ol0<ol000Dco`000`1Voc?o03?o000G
<ol00P00018co`000`000?ooooooo`25oooo001?oooo0P1Voa3oool00`0003?o03?o0006<ol000<0
I_lco`0co`005c?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_oooo0`0001_oool2
06Ko2_ooo`@00002oooo0P0000Tco`000`1Voc?o03?o000G<ol000<0000co`0co`004c?o00030000
oooooooo017oool40000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Hoooo0P1V
o`coool00`000?ooooooo`02oooo00<0000co`0co`002C?o000306Ko<ol0<ol001Lco`000`0003?o
03?o000D<ol000<0003oooooool04?ooo`030000oooooooo02coool00`000?ooooooo`0Voooo00@0
003oooooool0000Foooo000]oooo1@0001Koool306Ko3oooo`040000oooooooo000033?o000306Ko
<ol0<ol001Lco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0001Coool306Ko2oooo`@00004oooo0P00
00dco`000`1Voc?o03?o000G<ol000<0000co`0co`005c?o00030000oooooooo00ooool00`000?oo
ooooo`0Woooo00@0003oooooool0000Xoooo0`0001Ooool002koool00`000?ooo`00000@oooo101V
oaCoool2000000<co`00000co`0033?o000306Ko<ol0<ol001Lco`000`0003?o03?o000H<ol000<0
003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool00`000?ooooooo`0F
oooo000_oooo0P0000coool406Ko5oooo`@0000><ol000<0I_lco`0co`005c?o00030000<ol0<ol0
01Tco`000`000?ooooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo000hoooo1@1VoaWoool2
00004S?o000306Ko<ol0<ol001Lco`000`0003?o03?o000J<ol00P0007goool003?oool506Ko7?oo
o`80000D<ol000<0I_lco`0co`005c?o0080000M<ol00`0007[oool002koool506Ko7_ooo`<0000F
<ol000<0I_lco`0co`005c?o00030000<ol0<ol001lco`060000M?ooo`008oooo`/0I_lMoooo1P00
01Tco`000`1Voc?o03?o000G<ol000<0000co`0co`009C?o00<0001aoooo000Foooo3@1Voakoool:
00007c?o000306Ko<ol0<ol001Lco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Ooo
o`005_ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`04oooo00Go09Woooooooooool000002_ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`0Eoooo000/oooo00<0003oooooool0:Oooo`030000oooooooo00ooool0
0ol0VOooooooo`0Goooo00<0003oooooool0:Oooo`030000oooooooo02Woool00`000?ooooooo`0Y
oooo00<0003oooooool05Oooo`00J_ooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2Ioooo001Z
oooo00?o09Woooooool05oooo`030000oooooooo09Woool006[oool00ol0VOooooooo`0Goooo0P00
09[oool006[oool00ol0VOooooooo`0Goooo00<0003oooooool0VOooo`00J_ooo`03o`2Ioooooooo
01Ooool00`000?ooooooo`2Ioooo001Zoooo00?o09Woooooool05oooo`030000oooooooo09Woool0
06[oool00ol0VOooooooo`0Goooo0P0009[oool006[oool00ol0VOooooooo`0Goooo00<0003ooooo
ool0VOooo`00J_ooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2Ioooo001Zoooo00?o09Wooooo
ool05oooo`030000oooooooo09Woool006[oool00ol0VOooooooo`0Goooo00<0003oooooool0VOoo
o`00J_ooo`03o`2Ioooooooo01Ooool20000V_ooo`00J_ooo`03o`2Ioooooooo01Ooool00`000?oo
ooooo`2Ioooo001Zoooo00?o09Woooooool05oooo`030000oooooooo09Woool006[oool00ol0VOoo
ooooo`0Goooo00<0003oooooool0VOooo`00J_ooo`03o`2Ioooooooo01Ooool20000V_ooo`00J_oo
o`03o`2Ioooooooo01Ooool00`000?ooooooo`2Ioooo001Zoooo00?o09Woooooool05oooo`030000
oooooooo09Woool006[oool00ol0VOooooooo`0?oooo1@0000?oool00`000?ooooooo`2Ioooo001Z
oooo00?o09Woooooool04Oooo`030000oooooooo00?oool00`000?ooooooo`2Ioooo001Zoooo00?o
09Woooooool04Oooo`030000oooooooo00?oool30000VOooo`00J_ooo`03o`2Ioooooooo017oool0
0`000?ooooooo`03oooo00<0003oooooool0VOooo`00J_ooo`03o`2Ioooooooo017oool00`000?oo
ooooo`03oooo00<0003oooooool0VOooo`00J_ooo`03o`2Ioooooooo013oool200001Oooo`030000
oooooooo09Woool006[oool00ol0VOooooooo`0Goooo0P0009[oool006[oool00ol0VOooooooo`0G
oooo00<0003oooooool0VOooo`00J_ooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2Ioooo001Z
oooo00?o09Woooooool05oooo`030000oooooooo09Woool006[oool00ol0VOooooooo`0Goooo00<0
003oooooool0VOooo`00J_ooo`03o`2Ioooooooo01Ooool20000V_ooo`00J_ooo`03o`2Ioooooooo
01Ooool00`000?ooooooo`2Ioooo001Zoooo00?o09Woooooool05oooo`030000oooooooo09Woool0
06[oool00ol0VOooooooo`0Goooo00<0003oooooool0VOooo`00J_ooo`03o`2Ioooooooo01Ooool2
0000V_ooo`00J_ooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2Ioooo001Zoooo00?o09Wooooo
ool05oooo`030000oooooooo09Woool006[oool00ol0VOooooooo`0Goooo00<0003oooooool0VOoo
o`00J_ooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2Ioooo001Zoooo00?o09Woooooool05ooo
o`80002Joooo001Zoooo00?o09Woooooool05oooo`030000oooooooo09Woool006[oool00ol0VOoo
ooooo`0?oooo100000Coool00`000?ooooooo`2Ioooo001Zoooo00?o09Woooooool03oooo`030000
oooooooo00Goool00`000?ooooooo`2Ioooo001Zoooo00?o09Woooooool04?ooo`030000oooooooo
00Coool30000VOooo`00J_ooo`03o`2Ioooooooo017oool00`000?ooooooo`03oooo00<0003ooooo
ool0VOooo`00J_ooo`03o`2Ioooooooo00ooool010000?ooooooo`0000Coool00`000?ooooooo`2I
oooo001Zoooo00?o09Woooooool04?ooo`800005oooo00<0003oooooool0VOooo`00J_ooo`03o`2I
oooooooo01Ooool20000V_ooo`00J_ooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2Ioooo001Z
oooo00?o09Woooooool05oooo`030000oooooooo09Woool006[oool00ol0VOooooooo`0Goooo00<0
003oooooool0VOooo`00J_ooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2Ioooo001Zoooo00?o
09Woooooool05oooo`80002Joooo001Zoooo00?o09Woooooool05oooo`030000oooooooo09Woool0
06[oool00ol0VOooooooo`0Goooo00<0003oooooool0VOooo`00J_ooo`03o`2Ioooooooo01Ooool0
0`000?ooooooo`2Ioooo001Zoooo00?o09Woooooool05oooo`80002Joooo001Zoooo00?o09Wooooo
ool05oooo`030000oooooooo09Woool006[oool00ol0VOooooooo`0Goooo00<0003oooooool0VOoo
o`00J_ooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2Ioooo001Zoooo00?o09Woooooool05ooo
o`030000oooooooo09Woool006[oool00ol0VOooooooo`0Goooo0P0009[oool006[oool00ol0VOoo
ooooo`0Goooo00<0003oooooool0VOooo`00J_ooo`03o`2Ioooooooo013oool200001Oooo`030000
oooooooo09Woool006[oool00ol0VOooooooo`0?oooo00@0003oooooool00004oooo00<0003ooooo
ool0VOooo`00J_ooo`03o`2Ioooooooo017oool00`000?ooooooo`03oooo0`0009Woool006[oool0
0ol0VOooooooo`0Boooo00<0003oooooool00_ooo`030000oooooooo09Woool006[oool00ol0VOoo
ooooo`0?oooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00J_ooo`03o`2Ioooooooo
013oool200001Oooo`030000oooooooo09Woool006[oool00ol0VOooooooo`0Goooo00<0003ooooo
ool0VOooo`00J_ooo`03o`2Ioooooooo01Ooool20000V_ooo`00J_ooo`03o`2Ioooooooo01Ooool0
0`000?ooooooo`2Ioooo001Zoooo00?o09Woooooool05oooo`030000oooooooo09Woool006[oool0
0ol0VOooooooo`0Goooo00<0003oooooool0VOooo`00J_ooo`03o`2Ioooooooo01Ooool20000V_oo
o`00J_ooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2Ioooo001Zoooo00?o09Woooooool05ooo
o`030000oooooooo09Woool006[oool00ol0VOooooooo`0Goooo00<0003oooooool0VOooo`00J_oo
o`03o`2Ioooooooo01Ooool00`000?ooooooo`2Ioooo001Zoooo00?o09Woooooool05oooo`80002J
oooo001Zoooo00?o09Woooooool05oooo`030000oooooooo09Woool006[oool00ol0VOooooooo`0G
oooo00<0003oooooool0VOooo`00J_ooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2Ioooo001Z
oooo00?o09Woooooool05oooo`80002Joooo001Zoooo00?o09Woooooool05oooo`030000oooooooo
09Woool006[oool00ol0VOooooooo`0Goooo00<0003oooooool0VOooo`00J_ooo`03o`2Ioooooooo
017oool300000oooo`030000oooooooo09Woool006[oool00ol0VOooooooo`0Boooo00<0003ooooo
ool00_ooo`030000oooooooo09Woool006[oool00ol0VOooooooo`0?oooo1@0000?oool30000VOoo
o`00O?ooo`040000oooooooo0000X?ooo`00OOooo`030000oooo00000:3oool007koool20000X?oo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo100000?oool200000oooo`@00003
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`@00003oooo00<0003oooooool02Oooo`030000oooooooo00Coool0
0`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01Coool00`000?oo
ooooo`09oooo00<0003oooooool01?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00005?ooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000001Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0P0000?oool00`000?oo
ooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.32392 .26487 L
.34309 .26487 L
.35271 .26487 L
.36173 .26487 L
.36626 .26487 L
.36757 .26487 L
.36881 .26487 L
.36992 .26487 L
s
.36992 .26487 m
.37041 .61803 L
s
0 .4 1 r
.02381 .2619 m
.04262 .26118 L
.06244 .26023 L
.08255 .25901 L
.10458 .25732 L
.12415 .2554 L
.14509 .25282 L
.16639 .24947 L
.18653 .24547 L
.22495 .2348 L
.24479 .22726 L
.26581 .21736 L
.30365 .19368 L
.32469 .17713 L
.34394 .16034 L
.35344 .15179 L
.35846 .14729 L
.36381 .14255 L
.36646 .14024 L
.36776 .13912 L
.36895 .1381 L
.37004 .13717 L
.37119 .26487 L
.37235 .26487 L
.37361 .26487 L
.38271 .26487 L
.42313 .26487 L
.46204 .26487 L
.5034 .26487 L
.54325 .26487 L
.58158 .26487 L
.62236 .26487 L
.66163 .26487 L
.69938 .26487 L
.73958 .26487 L
.77827 .26487 L
.81941 .26487 L
.85903 .26487 L
.89714 .26487 L
.9377 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001]oooo0P1Vo`03oooo0000<ol0018co`000`0003?o03?o0002<ol000<0
003oooooool0U?ooo`00K?ooo`<0I_l00`0003?o03?o000B<ol00P0000@co`000`000?ooooooo`2C
oooo001[oooo00@0I_ooooooool0I_lE<ol000<0000co`0co`0013?o00030000oooooooo09;oool0
06[oool01@1Vooooooooooooo`1Vo`0E<ol000<0000co`0co`0013?o00030000oooooooo09;oool0
06[oool01@1Vooooooooo`00001Vo`0E<ol000<0000co`0co`001C?o00030000oooooooo097oool0
06Soool206Ko0_ooo`030000<ol006Ko01Dco`0200001c?o00030000oooooooo093oool006Ooool0
1@1Vooooooooooooo`000002<ol000<0I_lco`0co`004c?o00030000<ol0<ol000Hco`000`000?oo
ooooo`2@oooo001Voooo00<0I_ooooooool00_ooo`040000<ol0<ol006Ko5C?o00030000<ol0<ol0
00Lco`000`000?ooooooo`2?oooo001Uoooo00<0I_ooooooool00_ooo`050000<ol0<ol0<ol006Ko
00dco`0500000c?o00030000<ol0<ol000Pco`000`000?ooooooo`2>oooo001Toooo00<0I_oooooo
ool00_ooo`030000<ol0<ol0008co`000`1Voc?o03?o000=<ol000<0000co`0co`000c?o00030000
<ol0<ol000Pco`000`000?ooooooo`2>oooo001Soooo00<0I_ooooooool00_ooo`030000<ol0<ol0
00<co`000`1Voc?o03?o000=<ol000<0000co`0co`000c?o00<00009<ol000<0003oooooool0SOoo
o`00HOooo`80I_l5oooo00<0000co`0co`000c?o000306Ko<ol0<ol000Dco`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00H?ooo`0306Kooooooooo
00Coool00`0003?o03?o0004<ol000<0I_lco`0co`003C?o00030000<ol0<ol000<co`000`0003?o
03?o000;<ol000<0003oooooool0Roooo`00G_ooo`80I_l6oooo00<0000co`0co`001C?o000306Ko
<ol0<ol000`co`0200001C?o00030000<ol0<ol000/co`000`000?ooooooo`2;oooo001Moooo00<0
I_ooooooool01_ooo`030000<ol0<ol000Dco`000`1Voc?o03?o000C<ol00P0000dco`000`000?oo
ooooo`2:oooo001Koooo0P1Vo`Soool00`0003?o03?o0006<ol000<0I_lco`0co`004c?o00030000
<ol0<ol000dco`000`000?ooooooo`29oooo001Joooo00<0I_ooooooool01oooo`030000<ol0<ol0
00Lco`000`1Voc?o03?o000C<ol000<0000co`0co`003S?o00030000oooooooo08Soool005Soool2
06Ko2Oooo`030000<ol0<ol000Pco`000`1Voc?o03?o000C<ol000<0000co`0co`003c?o00030000
oooooooo08Ooool005Ooool00`1Vooooooooo`09oooo00<0000co`0co`0023?o000306Ko<ol0<ol0
01<co`000`0003?o03?o000@<ol000<0003oooooool0Q_ooo`00EOooo`80I_l;oooo00<0000co`0c
o`002C?o000306Ko<ol0<ol001<co`0200004S?o00030000oooooooo08Goool005Coool00`1Voooo
ooooo`0:oooo00<0000co`0co`002S?o000306Ko<ol0<ol001<co`000`0003?o03?o000B<ol000<0
003oooooool0Q?ooo`00;oooo`<0000Poooo0P1Vo`Goool400000_ooo`80000=<ol000<0I_lco`0c
o`004c?o00030000<ol0<ol001<co`000`000?ooooooo`0Aoooo100002[oool300009oooo`<0000G
oooo000`oooo00<0003oooooool07Oooo`80I_l7oooo00<0003oooooool00_ooo`030000<ol0<ol0
00dco`000`1Voc?o03?o000C<ol000<0000co`0co`0053?o00030000oooooooo013oool00`000?oo
ooooo`0/oooo00<0003oooooool09_ooo`040000oooooooo00005_ooo`00;Oooo`D0000Koooo0`1V
o`[oool010000?ooooooo`00010co`000`1Voc?o03?o000C<ol00P0001Hco`0200004Oooo`030000
oooooooo02Soool500009oooo`040000oooooooo00005_ooo`009oooo`@00002oooo00@0003ooooo
ool0000Joooo0P1Vo`Koool400001?ooo`80000A<ol000<0I_lco`0co`004c?o00030000<ol0<ol0
01Lco`000`000?ooooooo`0?oooo00<0003oooooool09oooo`040000oooooooo0000:?ooo`<0000G
oooo000^oooo00<0003oool000005_ooo`@0I_l>oooo0P000003<ol00000<ol0010co`000`1Voc?o
03?o000C<ol000<0000co`0co`0063?o00030000oooooooo00coool010000?ooooooo`0002Woool0
0`000?ooo`00000Yoooo00<0003oooooool05_ooo`00;oooo`80000Aoooo1@1Voa7oool400004S?o
000306Ko<ol0<ol001<co`000`0003?o03?o000I<ol000<0003oooooool03?ooo`80000[oooo0P00
02Woool300005_ooo`00?Oooo`D0I_lDoooo0P0001Hco`000`1Voc?o03?o000C<ol000<0000co`0c
o`006S?o0080001moooo000hoooo1@1VoaOoool2000063?o000306Ko<ol0<ol001<co`0200007C?o
00<0001joooo000coooo1@1VoaWoool300006S?o000306Ko<ol0<ol001<co`000`0003?o03?o000O
<ol01P0007Coool002Woool:06Ko6?ooo`H0000M<ol000<0I_lco`0co`004c?o00030000<ol0<ol0
02Dco`030000LOooo`005_oooa<0I_lHoooo2P0002<co`000`1Voc?o03?o000C<ol000<0000co`0c
o`00:3?o00X0001Woooo000@ooooo`00017oool001Koool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00;?ooo`030000oooooooo
02Woool00`000?ooooooo`0Coooo00?o09Woooooool04oooo`030000oooooooo02Woool00`000?oo
ooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo01Goool006koool00ol0VOooooooo`0C
oooo00<0003oooooool0VOooo`00K_ooo`03o`2Ioooooooo01?oool00`000?ooooooo`2Ioooo001^
oooo00?o09Woooooool04oooo`80002Joooo001^oooo00?o09Woooooool04oooo`030000oooooooo
09Woool006koool00ol0VOooooooo`0Coooo00<0003oooooool0VOooo`00K_ooo`03o`2Ioooooooo
01?oool00`000?ooooooo`2Ioooo001^oooo00?o09Woooooool04oooo`80002Joooo001^oooo00?o
09Woooooool04oooo`030000oooooooo09Woool006koool00ol0VOooooooo`0Coooo00<0003ooooo
ool0VOooo`00K_ooo`03o`2Ioooooooo01?oool00`000?ooooooo`2Ioooo001^oooo00?o09Wooooo
ool04oooo`030000oooooooo09Woool006koool00ol0VOooooooo`0Coooo0P0009[oool006koool0
0ol0VOooooooo`0Coooo00<0003oooooool0VOooo`00K_ooo`03o`2Ioooooooo01?oool00`000?oo
ooooo`2Ioooo001^oooo00?o09Woooooool04oooo`030000oooooooo09Woool006koool00ol0VOoo
ooooo`0Coooo0P0009[oool006koool00ol0VOooooooo`0Coooo00<0003oooooool0VOooo`00K_oo
o`03o`2Ioooooooo01?oool00`000?ooooooo`2Ioooo001^oooo00?o09Woooooool02oooo`D00003
oooo00<0003oooooool0VOooo`00K_ooo`03o`2Ioooooooo00goool00`000?ooooooo`03oooo00<0
003oooooool0VOooo`00K_ooo`03o`2Ioooooooo00goool00`000?ooooooo`03oooo0`0009Woool0
06koool00ol0VOooooooo`0=oooo00<0003oooooool00oooo`030000oooooooo09Woool006koool0
0ol0VOooooooo`0=oooo00<0003oooooool00oooo`030000oooooooo09Woool006koool00ol0VOoo
ooooo`0<oooo0P0000Goool00`000?ooooooo`2Ioooo001^oooo00?o09Woooooool04oooo`80002J
oooo001^oooo00?o09Woooooool04oooo`030000oooooooo09Woool006koool00ol0VOooooooo`0C
oooo00<0003oooooool0VOooo`00K_ooo`03o`2Ioooooooo01?oool00`000?ooooooo`2Ioooo001^
oooo00?o09Woooooool04oooo`030000oooooooo09Woool006koool00ol0VOooooooo`0Coooo0P00
09[oool006koool00ol0VOooooooo`0Coooo00<0003oooooool0VOooo`00K_ooo`03o`2Ioooooooo
01?oool00`000?ooooooo`2Ioooo001^oooo00?o09Woooooool04oooo`030000oooooooo09Woool0
06koool00ol0VOooooooo`0Coooo0P0009[oool006koool00ol0VOooooooo`0Coooo00<0003ooooo
ool0VOooo`00K_ooo`03o`2Ioooooooo01?oool00`000?ooooooo`2Ioooo001^oooo00?o09Wooooo
ool04oooo`030000oooooooo09Woool006koool00ol0VOooooooo`0Coooo00<0003oooooool0VOoo
o`00K_ooo`03o`2Ioooooooo01?oool20000V_ooo`00K_ooo`03o`2Ioooooooo01?oool00`000?oo
ooooo`2Ioooo001^oooo00?o09Woooooool02oooo`@00004oooo00<0003oooooool0VOooo`00K_oo
o`03o`2Ioooooooo00_oool00`000?ooooooo`05oooo00<0003oooooool0VOooo`00K_ooo`03o`2I
oooooooo00coool00`000?ooooooo`04oooo0`0009Woool006koool00ol0VOooooooo`0=oooo00<0
003oooooool00oooo`030000oooooooo09Woool006koool00ol0VOooooooo`0;oooo00@0003ooooo
ool00004oooo00<0003oooooool0VOooo`00K_ooo`03o`2Ioooooooo00coool200001Oooo`030000
oooooooo09Woool006koool00ol0VOooooooo`0Coooo0P0009[oool006koool00ol0VOooooooo`0C
oooo00<0003oooooool0VOooo`00K_ooo`03o`2Ioooooooo01?oool00`000?ooooooo`2Ioooo001^
oooo00?o09Woooooool04oooo`030000oooooooo09Woool006koool00ol0VOooooooo`0Coooo00<0
003oooooool0VOooo`00K_ooo`03o`2Ioooooooo01?oool20000V_ooo`00K_ooo`03o`2Ioooooooo
01?oool00`000?ooooooo`2Ioooo001^oooo00?o09Woooooool04oooo`030000oooooooo09Woool0
06koool00ol0VOooooooo`0Coooo00<0003oooooool0VOooo`00K_ooo`03o`2Ioooooooo01?oool2
0000V_ooo`00K_ooo`03o`2Ioooooooo01?oool00`000?ooooooo`2Ioooo001^oooo00?o09Wooooo
ool04oooo`030000oooooooo09Woool006koool00ol0VOooooooo`0Coooo00<0003oooooool0VOoo
o`00K_ooo`03o`2Ioooooooo01?oool00`000?ooooooo`2Ioooo001^oooo00?o09Woooooool04ooo
o`80002Joooo001^oooo00?o09Woooooool04oooo`030000oooooooo09Woool006koool00ol0VOoo
ooooo`0<oooo0P0000Goool00`000?ooooooo`2Ioooo001^oooo00?o09Woooooool02oooo`040000
oooooooo00001?ooo`030000oooooooo09Woool006koool00ol0VOooooooo`0=oooo00<0003ooooo
ool00oooo`<0002Ioooo001^oooo00?o09Woooooool03_ooo`030000oooooooo00;oool00`000?oo
ooooo`2Ioooo001^oooo00?o09Woooooool02oooo`040000oooooooo00001?ooo`030000oooooooo
09Woool006koool00ol0VOooooooo`0<oooo0P0000Goool00`000?ooooooo`2Ioooo001^oooo00?o
09Woooooool04oooo`030000oooooooo09Woool006koool00ol0VOooooooo`0Coooo0P0009[oool0
06koool00ol0VOooooooo`0Coooo00<0003oooooool0VOooo`00K_ooo`03o`2Ioooooooo01?oool0
0`000?ooooooo`2Ioooo001^oooo00?o09Woooooool04oooo`030000oooooooo09Woool006koool0
0ol0VOooooooo`0Coooo0P0009[oool006koool00ol0VOooooooo`0Coooo00<0003oooooool0VOoo
o`00K_ooo`03o`2Ioooooooo01?oool00`000?ooooooo`2Ioooo001^oooo00?o09Woooooool04ooo
o`030000oooooooo09Woool006koool00ol0VOooooooo`0Coooo00<0003oooooool0VOooo`00K_oo
o`03o`2Ioooooooo01?oool20000V_ooo`00K_ooo`03o`2Ioooooooo01?oool00`000?ooooooo`2I
oooo001^oooo00?o09Woooooool04oooo`030000oooooooo09Woool006koool00ol0VOooooooo`0C
oooo00<0003oooooool0VOooo`00K_ooo`03o`2Ioooooooo01?oool20000V_ooo`00K_ooo`03o`2I
oooooooo01?oool00`000?ooooooo`2Ioooo001^oooo00?o09Woooooool04oooo`030000oooooooo
09Woool006koool00ol0VOooooooo`0=oooo0`0000?oool00`000?ooooooo`2Ioooo001^oooo00?o
09Woooooool03_ooo`030000oooooooo00;oool00`000?ooooooo`2Ioooo001^oooo00?o09Wooooo
ool02oooo`D00003oooo0`0009Woool007coool010000?ooooooo`000:3oool007goool00`000?oo
o`00002Poooo001noooo0P000:3oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo
02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool0
0`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03?oo
o`@00003oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool00`000?ooooooo`0:oooo00<0
003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0Doooo00<0003ooooo
ool02_ooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500005?ooo`030000oooooooo
00Soool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000005Oooo`040000oooooooo
00002Oooo`030000oooooooo07_oool007coool00`000?ooooooo`0Goooo0P0000Woool00`000?oo
ooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.36136 .26487 L
.37176 .26487 L
.37685 .26487 L
.3815 .26487 L
.38384 .26487 L
.38508 .26487 L
.3864 .26487 L
s
.3864 .26487 m
.38691 .61803 L
s
0 .4 1 r
.02381 .26246 m
.04262 .26187 L
.06244 .2611 L
.08255 .26012 L
.10458 .25874 L
.12415 .25719 L
.14509 .2551 L
.16639 .25238 L
.18653 .24913 L
.22495 .24048 L
.24479 .23436 L
.26581 .22633 L
.30365 .20712 L
.34394 .18008 L
.36247 .1666 L
.37227 .15976 L
.37764 .15621 L
.38271 .15304 L
.38547 .1514 L
.38623 .15097 L
.38703 .15051 L
.38771 .26487 L
.38846 .26487 L
.39367 .26487 L
.40384 .26487 L
.42393 .26487 L
.46436 .26487 L
.50327 .26487 L
.54463 .26487 L
.58447 .26487 L
.6228 .26487 L
.66358 .26487 L
.70285 .26487 L
.7406 .26487 L
.7808 .26487 L
.81949 .26487 L
.86063 .26487 L
.90026 .26487 L
.93836 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`050000
<ol0<ol0<ol006Ko014co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`040000
<ol0<ol0<ol00P1Voa4co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`070000
<ol0<ol0<ol006Ko<ol006Ko014co`0200001c?o00030000oooooooo093oool006_oool00`0003?o
03?o000206Ko0S?o000306Ko<ol0<ol000lco`000`0003?o03?o0006<ol000<0003oooooool0T?oo
o`00Joooo`03000006Ko06Ko00@co`000`1Voc?o03?o000?<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`00001Voc?o0005<ol000<0I_lco`0co`001c?o00D00003<ol000<0
000co`0co`0023?o00030000oooooooo08koool006Woool206Ko1c?o000306Ko<ol0<ol000Tco`00
0`0003?o03?o0003<ol000<0000co`0co`0023?o00030000oooooooo08koool006Soool00`1Voc?o
03?o0007<ol000<0I_lco`0co`002C?o00030000<ol0<ol000<co`0300002C?o00030000oooooooo
08goool006Ooool00`1Vo`0003?o0008<ol000@0I_lco`0co`0co`04000013?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00IOooo`80I_l00`0003?o03?o0008
<ol000<0I_lco`0co`002C?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0Roooo`00I?ooo`0306Kooooo000000/co`000`1Voc?o03?o0008<ol00P0000Dco`000`0003?o
03?o000;<ol000<0003oooooool0Roooo`00Hoooo`0406Kooooooooo00002c?o000306Ko<ol0<ol0
00lco`0200003C?o00030000oooooooo08[oool0067oool206Ko0_ooo`030000<ol0<ol000Xco`00
0`1Voc?o03?o000?<ol000<0000co`0co`003C?o00030000oooooooo08Woool0063oool01@1Voooo
ooooooooo`00000=<ol000<0I_lco`0co`003c?o00030000<ol0<ol000hco`000`000?ooooooo`28
oooo001Noooo0P1Vo`?oool00`0003?o03?o000<<ol000<0I_lco`0co`003c?o00030000<ol0<ol0
00lco`000`000?ooooooo`27oooo001Loooo0P1Vo`Goool00`0003?o03?o000<<ol000<0I_lco`0c
o`003c?o00030000<ol0<ol0010co`000`000?ooooooo`26oooo001Joooo0P1Vo`Koool00`0003?o
03?o000=<ol000<0I_lco`0co`003c?o0080000B<ol000<0003oooooool0QOooo`00F?ooo`80I_l7
oooo00<0000co`0co`003S?o000306Ko<ol0<ol000lco`000`0003?o03?o000B<ol000<0003ooooo
ool0Q?ooo`00;oooo`<0000Toooo0P1Vo`03oooo0000000000800002oooo0P00014co`000`1Voc?o
03?o000?<ol000<0000co`0co`004c?o00030000oooooooo017oool40000:_ooo`<0000Woooo0`00
01Ooool0033oool00`000?ooooooo`0Poooo0`1Vo`?oool00`000?ooooooo`02oooo00<0000co`0c
o`004C?o000306Ko<ol0<ol000lco`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000
oooooooo02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0001koool3
06Ko1oooo`040000oooooooo000053?o000306Ko<ol0<ol000lco`0200005S?o0080000Aoooo00<0
003oooooool0:?ooo`D0000Woooo00@0003oooooool0000Foooo000Woooo100000;oool010000?oo
ooooo`0001coool306Ko0oooo`@00004oooo0P0001Dco`000`1Voc?o03?o000?<ol000<0000co`0c
o`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000Xoooo0`00
01Ooool002koool00`000?ooo`00000Joooo0P1Vo`coool2000000<co`00000co`0053?o000306Ko
<ol0<ol000lco`000`0003?o03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Ooo
o`030000oooo000002Woool00`000?ooooooo`0Foooo000_oooo0P0001Koool406Ko3Oooo`@0000F
<ol000<0I_lco`0co`003c?o00030000<ol0<ol001Tco`000`000?ooooooo`0<oooo0P0002_oool2
0000:Oooo`<0000Foooo0012oooo1@1Vo`ooool200006S?o000306Ko<ol0<ol000lco`000`0003?o
03?o000J<ol00P0007goool003goool506Ko4_ooo`80000L<ol000<0I_lco`0co`003c?o0080000M
<ol00`0007[oool003Soool506Ko5?ooo`<0000N<ol000<0I_lco`0co`003c?o00030000<ol0<ol0
01lco`060000M?ooo`00;_ooo`X0I_lCoooo1P00024co`000`1Voc?o03?o000?<ol000<0000co`0c
o`009C?o00<0001aoooo000Ioooo5@1Voa?oool:00009c?o000306Ko<ol0<ol000lco`000`0003?o
03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00D0003ooooooooooooo
09T01_ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0Eoooo000/oooo00<0
003oooooool0:Oooo`030000oooooooo01Ooool00ol0VOooooooo`0?oooo00<0003oooooool0:Ooo
o`030000oooooooo02Woool00`000?ooooooo`0Yoooo00<0003oooooool05Oooo`00L_ooo`03o`2I
oooooooo00ooool00`000?ooooooo`2Ioooo001boooo00?o09Woooooool03oooo`030000oooooooo
09Woool007;oool00ol0VOooooooo`0?oooo0P0009[oool007;oool00ol0VOooooooo`0?oooo00<0
003oooooool0VOooo`00L_ooo`03o`2Ioooooooo00ooool00`000?ooooooo`2Ioooo001boooo00?o
09Woooooool03oooo`030000oooooooo09Woool007;oool00ol0VOooooooo`0?oooo0P0009[oool0
07;oool00ol0VOooooooo`0?oooo00<0003oooooool0VOooo`00L_ooo`03o`2Ioooooooo00ooool0
0`000?ooooooo`2Ioooo001boooo00?o09Woooooool03oooo`030000oooooooo09Woool007;oool0
0ol0VOooooooo`0?oooo00<0003oooooool0VOooo`00L_ooo`03o`2Ioooooooo00ooool20000V_oo
o`00L_ooo`03o`2Ioooooooo00ooool00`000?ooooooo`2Ioooo001boooo00?o09Woooooool03ooo
o`030000oooooooo09Woool007;oool00ol0VOooooooo`0?oooo00<0003oooooool0VOooo`00L_oo
o`03o`2Ioooooooo00ooool20000V_ooo`00L_ooo`03o`2Ioooooooo00ooool00`000?ooooooo`2I
oooo001boooo00?o09Woooooool03oooo`030000oooooooo09Woool007;oool00ol0VOooooooo`07
oooo1@0000?oool00`000?ooooooo`2Ioooo001boooo00?o09Woooooool02Oooo`030000oooooooo
00?oool00`000?ooooooo`2Ioooo001boooo00?o09Woooooool02Oooo`030000oooooooo00?oool3
0000VOooo`00L_ooo`03o`2Ioooooooo00Woool00`000?ooooooo`03oooo00<0003oooooool0VOoo
o`00L_ooo`03o`2Ioooooooo00Woool00`000?ooooooo`03oooo00<0003oooooool0VOooo`00L_oo
o`03o`2Ioooooooo00Soool200001Oooo`030000oooooooo09Woool007;oool00ol0VOooooooo`0?
oooo0P0009[oool007;oool00ol0VOooooooo`0?oooo00<0003oooooool0VOooo`00L_ooo`03o`2I
oooooooo00ooool00`000?ooooooo`2Ioooo001boooo00?o09Woooooool03oooo`030000oooooooo
09Woool007;oool00ol0VOooooooo`0?oooo00<0003oooooool0VOooo`00L_ooo`03o`2Ioooooooo
00ooool20000V_ooo`00L_ooo`03o`2Ioooooooo00ooool00`000?ooooooo`2Ioooo001boooo00?o
09Woooooool03oooo`030000oooooooo09Woool007;oool00ol0VOooooooo`0?oooo00<0003ooooo
ool0VOooo`00L_ooo`03o`2Ioooooooo00ooool20000V_ooo`00L_ooo`03o`2Ioooooooo00ooool0
0`000?ooooooo`2Ioooo001boooo00?o09Woooooool03oooo`030000oooooooo09Woool007;oool0
0ol0VOooooooo`0?oooo00<0003oooooool0VOooo`00L_ooo`03o`2Ioooooooo00ooool00`000?oo
ooooo`2Ioooo001boooo00?o09Woooooool03oooo`80002Joooo001boooo00?o09Woooooool03ooo
o`030000oooooooo09Woool007;oool00ol0VOooooooo`07oooo100000Coool00`000?ooooooo`2I
oooo001boooo00?o09Woooooool01oooo`030000oooooooo00Goool00`000?ooooooo`2Ioooo001b
oooo00?o09Woooooool02?ooo`030000oooooooo00Coool30000VOooo`00L_ooo`03o`2Ioooooooo
00Woool00`000?ooooooo`03oooo00<0003oooooool0VOooo`00L_ooo`03o`2Ioooooooo00Ooool0
10000?ooooooo`0000Coool00`000?ooooooo`2Ioooo001boooo00?o09Woooooool02?ooo`800005
oooo00<0003oooooool0VOooo`00L_ooo`03o`2Ioooooooo00ooool20000V_ooo`00L_ooo`03o`2I
oooooooo00ooool00`000?ooooooo`2Ioooo001boooo00?o09Woooooool03oooo`030000oooooooo
09Woool007;oool00ol0VOooooooo`0?oooo00<0003oooooool0VOooo`00L_ooo`03o`2Ioooooooo
00ooool00`000?ooooooo`2Ioooo001boooo00?o09Woooooool03oooo`80002Joooo001boooo00?o
09Woooooool03oooo`030000oooooooo09Woool007;oool00ol0VOooooooo`0?oooo00<0003ooooo
ool0VOooo`00L_ooo`03o`2Ioooooooo00ooool00`000?ooooooo`2Ioooo001boooo00?o09Wooooo
ool03oooo`80002Joooo001boooo00?o09Woooooool03oooo`030000oooooooo09Woool007;oool0
0ol0VOooooooo`0?oooo00<0003oooooool0VOooo`00L_ooo`03o`2Ioooooooo00ooool00`000?oo
ooooo`2Ioooo001boooo00?o09Woooooool03oooo`030000oooooooo09Woool007;oool00ol0VOoo
ooooo`0?oooo0P0009[oool007;oool00ol0VOooooooo`0?oooo00<0003oooooool0VOooo`00L_oo
o`03o`2Ioooooooo00Soool200001Oooo`030000oooooooo09Woool007;oool00ol0VOooooooo`07
oooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00L_ooo`03o`2Ioooooooo00Woool0
0`000?ooooooo`03oooo0`0009Woool007;oool00ol0VOooooooo`0:oooo00<0003oooooool00_oo
o`030000oooooooo09Woool007;oool00ol0VOooooooo`07oooo00@0003oooooool00004oooo00<0
003oooooool0VOooo`00L_ooo`03o`2Ioooooooo00Soool200001Oooo`030000oooooooo09Woool0
07;oool00ol0VOooooooo`0?oooo00<0003oooooool0VOooo`00L_ooo`03o`2Ioooooooo00ooool2
0000V_ooo`00L_ooo`03o`2Ioooooooo00ooool00`000?ooooooo`2Ioooo001boooo00?o09Wooooo
ool03oooo`030000oooooooo09Woool007;oool00ol0VOooooooo`0?oooo00<0003oooooool0VOoo
o`00L_ooo`03o`2Ioooooooo00ooool20000V_ooo`00L_ooo`03o`2Ioooooooo00ooool00`000?oo
ooooo`2Ioooo001boooo00?o09Woooooool03oooo`030000oooooooo09Woool007;oool00ol0VOoo
ooooo`0?oooo00<0003oooooool0VOooo`00L_ooo`03o`2Ioooooooo00ooool00`000?ooooooo`2I
oooo001boooo00?o09Woooooool03oooo`80002Joooo001boooo00?o09Woooooool03oooo`030000
oooooooo09Woool007;oool00ol0VOooooooo`0?oooo00<0003oooooool0VOooo`00L_ooo`03o`2I
oooooooo00ooool00`000?ooooooo`2Ioooo001boooo00?o09Woooooool03oooo`80002Joooo001b
oooo00?o09Woooooool03oooo`030000oooooooo09Woool007;oool00ol0VOooooooo`0?oooo00<0
003oooooool0VOooo`00L_ooo`03o`2Ioooooooo00Woool300000oooo`030000oooooooo09Woool0
07;oool00ol0VOooooooo`0:oooo00<0003oooooool00_ooo`030000oooooooo09Woool007;oool0
0ol0VOooooooo`07oooo1@0000?oool30000VOooo`00O?ooo`040000oooooooo0000X?ooo`00OOoo
o`030000oooo00000:3oool007koool20000X?ooo`00ooooob7oool00?oooolQoooo001ioooo00<0
003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`0<oooo1@0000;oool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0
003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?oo
ooooo`02oooo00<0003oooooool05Oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool0
0`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001Coool00`000?ooooooo`08oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005oooo`030000oooooooo
00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05ooo
o`80000:oooo0P0000?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.39174 .26487 L
.39675 .26487 L
.40134 .26487 L
.40252 .26487 L
.40381 .26487 L
s
.40381 .26487 m
.4043 .61803 L
s
0 .4 1 r
.02381 .26292 m
.04262 .26245 L
.06244 .26183 L
.08255 .26103 L
.10458 .25992 L
.12415 .25867 L
.14509 .25698 L
.16639 .25479 L
.18653 .25216 L
.22495 .24518 L
.24479 .24024 L
.26581 .23375 L
.30365 .21824 L
.34394 .19641 L
.38271 .17458 L
.39281 .17003 L
.39815 .16798 L
.40108 .16699 L
.40252 .16653 L
.40315 .16634 L
.40384 .16613 L
.40512 .26487 L
.40582 .26487 L
.40647 .26487 L
.40931 .26487 L
.41426 .26487 L
.42393 .26487 L
.46284 .26487 L
.5042 .26487 L
.54405 .26487 L
.58238 .26487 L
.62316 .26487 L
.66243 .26487 L
.70018 .26487 L
.74038 .26487 L
.77907 .26487 L
.82021 .26487 L
.85983 .26487 L
.89794 .26487 L
.9385 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o0008<ol00P1Vo``co`000`0003?o03?o0007
<ol000<0003oooooool0Soooo`00J_ooo`030000<ol0<ol000Hco`0306Ko00<co`00I_lco`000c?o
00D00003<ol000<0000co`0co`0023?o00030000oooooooo08koool006Woool00`0003?o03?o0005
<ol00P1Vo`@co`000`1Voc?o03?o0004<ol000<0000co`0co`000c?o00030000<ol0<ol000Pco`00
0`000?ooooooo`2>oooo001Xoooo00<0000co`0co`0013?o0080I_l6<ol000<0I_lco`0co`0013?o
00030000<ol0<ol000<co`0300002C?o00030000oooooooo08goool006Soool00`0003?o03?o0002
<ol00P1Vo`Lco`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000:<ol000<0003ooooo
ool0S?ooo`00Ioooo`030000<ol0<ol0008co`000`1Voc?o03?o0008<ol000<0I_lco`0co`0013?o
00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_ooo`040000
<ol0<ol0<ol00P1Vo`/co`000`1Voc?o03?o0003<ol00P0000Dco`000`0003?o03?o000;<ol000<0
003oooooool0Roooo`00I_ooo`040000<ol006Ko06Ko3C?o000306Ko<ol0<ol000Xco`0200003C?o
00030000oooooooo08[oool006Goool00`0003?o001Vo`0?<ol000<0I_lco`0co`002S?o00030000
<ol0<ol000dco`000`000?ooooooo`29oooo001Toooo00<00000I_l0I_l043?o000306Ko<ol0<ol0
00Xco`000`0003?o03?o000><ol000<0003oooooool0R?ooo`00Hoooo`80I_lB<ol000<0I_lco`0c
o`002S?o00030000<ol0<ol000lco`000`000?ooooooo`27oooo001Qoooo0P1Vo`030000<ol0<ol0
014co`000`1Voc?o03?o000:<ol000<0000co`0co`0043?o00030000oooooooo08Koool005ooool2
06Ko00?oool0000co`004c?o000306Ko<ol0<ol000Xco`0200004S?o00030000oooooooo08Goool0
05coool306Ko0_ooo`030000<ol0<ol001<co`000`1Voc?o03?o000:<ol000<0000co`0co`004S?o
00030000oooooooo08Coool002ooool300009oooo`@00002oooo0P0001Hco`000`1Voc?o03?o000:
<ol000<0000co`0co`004c?o00030000oooooooo017oool40000:_ooo`<0000Woooo0`0001Ooool0
033oool00`000?ooooooo`0Uoooo00<0I_l0003oool00oooo`030000<ol0<ol001Hco`000`1Voc?o
03?o000:<ol000<0000co`0co`0053?o00030000oooooooo013oool00`000?ooooooo`0/oooo00<0
003oooooool09_ooo`040000oooooooo00005_ooo`00;Oooo`D0000Toooo0P1Vo`;oool010000?oo
ooooo`0001Tco`000`1Voc?o03?o000:<ol00P0001Hco`0200004Oooo`030000oooooooo02Soool5
00009oooo`040000oooooooo00005_ooo`009oooo`@00002oooo00@0003oooooool0000Roooo1000
00Coool200006S?o000306Ko<ol0<ol000Xco`000`0003?o03?o000G<ol000<0003oooooool03ooo
o`030000oooooooo02Ooool010000?ooooooo`0002Soool300005oooo`00;_ooo`030000oooo0000
01ooool306Ko1_ooo`8000000c?o000003?o000I<ol000<0I_lco`0co`002S?o00030000<ol0<ol0
01Pco`000`000?ooooooo`0<oooo00@0003oooooool0000Yoooo00<0003oool00000:Oooo`030000
oooooooo01Koool002ooool200006oooo`@0I_l8oooo100001/co`000`1Voc?o03?o000:<ol000<0
000co`0co`006C?o00030000oooooooo00coool20000:oooo`80000Yoooo0`0001Koool004Ooool5
06Ko2_ooo`80000O<ol000<0I_lco`0co`002S?o00030000<ol0<ol001Xco`020000OOooo`00@_oo
o`D0I_l=oooo0P00024co`000`1Voc?o03?o000:<ol00P0001dco`030000N_ooo`00?Oooo`D0I_l?
oooo0`0002<co`000`1Voc?o03?o000:<ol000<0000co`0co`007c?o00H0001doooo000coooo2P1V
o`koool600009S?o000306Ko<ol0<ol000Xco`000`0003?o03?o000U<ol00`00077oool001kooolE
06Ko3_ooo`X0000/<ol000<0I_lco`0co`002S?o00030000<ol0<ol002Pco`0:0000Ioooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`06oooo00?o09Woool000002_ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo01Goool002coool00`000?ooooooo`0Yoooo00<0003oooooool07?oo
o`03o`2Ioooooooo00[oool00`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo
02Woool00`000?ooooooo`0Eoooo001goooo00?o09Woooooool02_ooo`030000oooooooo09Woool0
07Ooool00ol0VOooooooo`0:oooo00<0003oooooool0VOooo`00Moooo`03o`2Ioooooooo00[oool2
0000V_ooo`00Moooo`03o`2Ioooooooo00[oool00`000?ooooooo`2Ioooo001goooo00?o09Wooooo
ool02_ooo`030000oooooooo09Woool007Ooool00ol0VOooooooo`0:oooo00<0003oooooool0VOoo
o`00Moooo`03o`2Ioooooooo00[oool20000V_ooo`00Moooo`03o`2Ioooooooo00[oool00`000?oo
ooooo`2Ioooo001goooo00?o09Woooooool02_ooo`030000oooooooo09Woool007Ooool00ol0VOoo
ooooo`0:oooo00<0003oooooool0VOooo`00Moooo`03o`2Ioooooooo00[oool00`000?ooooooo`2I
oooo001goooo00?o09Woooooool02_ooo`80002Joooo001goooo00?o09Woooooool02_ooo`030000
oooooooo09Woool007Ooool00ol0VOooooooo`0:oooo00<0003oooooool0VOooo`00Moooo`03o`2I
oooooooo00[oool00`000?ooooooo`2Ioooo001goooo00?o09Woooooool02_ooo`80002Joooo001g
oooo00?o09Woooooool02_ooo`030000oooooooo09Woool007Ooool00ol0VOooooooo`0:oooo00<0
003oooooool0VOooo`00Moooo`03o`2Ioooooooo00;oool500000oooo`030000oooooooo09Woool0
07Ooool00ol0VOooooooo`04oooo00<0003oooooool00oooo`030000oooooooo09Woool007Ooool0
0ol0VOooooooo`04oooo00<0003oooooool00oooo`<0002Ioooo001goooo00?o09Woooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`2Ioooo001goooo00?o09Woooooool01?ooo`030000
oooooooo00?oool00`000?ooooooo`2Ioooo001goooo00?o09Woooooool00oooo`800005oooo00<0
003oooooool0VOooo`00Moooo`03o`2Ioooooooo00[oool20000V_ooo`00Moooo`03o`2Ioooooooo
00[oool00`000?ooooooo`2Ioooo001goooo00?o09Woooooool02_ooo`030000oooooooo09Woool0
07Ooool00ol0VOooooooo`0:oooo00<0003oooooool0VOooo`00Moooo`03o`2Ioooooooo00[oool0
0`000?ooooooo`2Ioooo001goooo00?o09Woooooool02_ooo`80002Joooo001goooo00?o09Wooooo
ool02_ooo`030000oooooooo09Woool007Ooool00ol0VOooooooo`0:oooo00<0003oooooool0VOoo
o`00Moooo`03o`2Ioooooooo00[oool00`000?ooooooo`2Ioooo001goooo00?o09Woooooool02_oo
o`80002Joooo001goooo00?o09Woooooool02_ooo`030000oooooooo09Woool007Ooool00ol0VOoo
ooooo`0:oooo00<0003oooooool0VOooo`00Moooo`03o`2Ioooooooo00[oool00`000?ooooooo`2I
oooo001goooo00?o09Woooooool02_ooo`030000oooooooo09Woool007Ooool00ol0VOooooooo`0:
oooo0P0009[oool007Ooool00ol0VOooooooo`0:oooo00<0003oooooool0VOooo`00Moooo`03o`2I
oooooooo00;oool400001?ooo`030000oooooooo09Woool007Ooool00ol0VOooooooo`02oooo00<0
003oooooool01Oooo`030000oooooooo09Woool007Ooool00ol0VOooooooo`03oooo00<0003ooooo
ool01?ooo`<0002Ioooo001goooo00?o09Woooooool01?ooo`030000oooooooo00?oool00`000?oo
ooooo`2Ioooo001goooo00?o09Woooooool00_ooo`040000oooooooo00001?ooo`030000oooooooo
09Woool007Ooool00ol0VOooooooo`03oooo0P0000Goool00`000?ooooooo`2Ioooo001goooo00?o
09Woooooool02_ooo`80002Joooo001goooo00?o09Woooooool02_ooo`030000oooooooo09Woool0
07Ooool00ol0VOooooooo`0:oooo00<0003oooooool0VOooo`00Moooo`03o`2Ioooooooo00[oool0
0`000?ooooooo`2Ioooo001goooo00?o09Woooooool02_ooo`030000oooooooo09Woool007Ooool0
0ol0VOooooooo`0:oooo0P0009[oool007Ooool00ol0VOooooooo`0:oooo00<0003oooooool0VOoo
o`00Moooo`03o`2Ioooooooo00[oool00`000?ooooooo`2Ioooo001goooo00?o09Woooooool02_oo
o`030000oooooooo09Woool007Ooool00ol0VOooooooo`0:oooo0P0009[oool007Ooool00ol0VOoo
ooooo`0:oooo00<0003oooooool0VOooo`00Moooo`03o`2Ioooooooo00[oool00`000?ooooooo`2I
oooo001goooo00?o09Woooooool02_ooo`030000oooooooo09Woool007Ooool00ol0VOooooooo`0:
oooo00<0003oooooool0VOooo`00Moooo`03o`2Ioooooooo00[oool20000V_ooo`00Moooo`03o`2I
oooooooo00[oool00`000?ooooooo`2Ioooo001goooo00?o09Woooooool00oooo`800005oooo00<0
003oooooool0VOooo`00Moooo`03o`2Ioooooooo00;oool010000?ooooooo`0000Coool00`000?oo
ooooo`2Ioooo001goooo00?o09Woooooool01?ooo`030000oooooooo00?oool30000VOooo`00Mooo
o`03o`2Ioooooooo00Goool00`000?ooooooo`02oooo00<0003oooooool0VOooo`00Moooo`03o`2I
oooooooo00;oool010000?ooooooo`0000Coool00`000?ooooooo`2Ioooo001goooo00?o09Wooooo
ool00oooo`800005oooo00<0003oooooool0VOooo`00Moooo`03o`2Ioooooooo00[oool00`000?oo
ooooo`2Ioooo001goooo00?o09Woooooool02_ooo`80002Joooo001goooo00?o09Woooooool02_oo
o`030000oooooooo09Woool007Ooool00ol0VOooooooo`0:oooo00<0003oooooool0VOooo`00Mooo
o`03o`2Ioooooooo00[oool00`000?ooooooo`2Ioooo001goooo00?o09Woooooool02_ooo`80002J
oooo001goooo00?o09Woooooool02_ooo`030000oooooooo09Woool007Ooool00ol0VOooooooo`0:
oooo00<0003oooooool0VOooo`00Moooo`03o`2Ioooooooo00[oool00`000?ooooooo`2Ioooo001g
oooo00?o09Woooooool02_ooo`030000oooooooo09Woool007Ooool00ol0VOooooooo`0:oooo0P00
09[oool007Ooool00ol0VOooooooo`0:oooo00<0003oooooool0VOooo`00Moooo`03o`2Ioooooooo
00[oool00`000?ooooooo`2Ioooo001goooo00?o09Woooooool02_ooo`030000oooooooo09Woool0
07Ooool00ol0VOooooooo`0:oooo0P0009[oool007Ooool00ol0VOooooooo`0:oooo00<0003ooooo
ool0VOooo`00Moooo`03o`2Ioooooooo00[oool00`000?ooooooo`2Ioooo001goooo00?o09Wooooo
ool01?ooo`<00003oooo00<0003oooooool0VOooo`00Moooo`03o`2Ioooooooo00Goool00`000?oo
ooooo`02oooo00<0003oooooool0VOooo`00Moooo`03o`2Ioooooooo00;oool500000oooo`<0002I
oooo001loooo00@0003oooooool0002Poooo001moooo00<0003oool00000X?ooo`00O_ooo`80002P
oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00coool500000_ooo`800003oooo0`00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Eoooo00<0
003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500005?ooo`030000oooooooo00Ooool300001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000Goooo00<0003oooooool02?ooo`030000oooooooo00?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0`0000;oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.40134 .26487 L
.41134 .26487 L
.41408 .26487 L
.41703 .26487 L
.41846 .26487 L
.41982 .26487 L
.42104 .26487 L
.42173 .26487 L
s
.42173 .26487 m
.42198 .61803 L
s
0 .4 1 r
.02381 .26331 m
.04262 .26293 L
.06244 .26243 L
.08255 .2618 L
.10458 .26091 L
.12415 .2599 L
.14509 .25854 L
.16639 .25679 L
.18653 .25468 L
.22495 .24908 L
.24479 .24513 L
.26581 .23993 L
.30365 .22749 L
.34394 .20999 L
.38271 .19249 L
.39281 .18884 L
.39815 .1872 L
.40384 .18572 L
.40931 .18457 L
.41426 .18378 L
.41665 .18349 L
.41924 .18325 L
.42043 .18316 L
.42169 .18308 L
.42276 .26487 L
.42393 .26487 L
.46436 .26487 L
.50327 .26487 L
.54463 .26487 L
.58447 .26487 L
.6228 .26487 L
.66358 .26487 L
.70285 .26487 L
.7406 .26487 L
.7808 .26487 L
.81949 .26487 L
.86063 .26487 L
.90026 .26487 L
.93836 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000000Dco`00I_lc
o`0co`0000001C?o00030000<ol0<ol000Xco`000`000?ooooooo`2<oooo001Woooo00<0000co`0c
o`003C?o00D0I_l2<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`2;
oooo001Voooo00<0000co`0co`002S?o00@0I_l4<ol000@0I_lco`0000000005<ol000<0000co`0c
o`002c?o00030000oooooooo08_oool006Koool00`0003?o03?o0007<ol00`1Vo`Pco`000`1Voc?o
03?o0006<ol00P0000dco`000`000?ooooooo`2:oooo001Uoooo00<0000co`0co`001S?o0080I_l;
<ol000<0I_lco`0co`001S?o00030000<ol0<ol000dco`000`000?ooooooo`29oooo001Toooo00<0
000co`0co`0013?o00<0I_l=<ol000<0I_lco`0co`001S?o00030000<ol0<ol000hco`000`000?oo
ooooo`28oooo001Soooo00<0000co`0co`000c?o0080I_l@<ol000<0I_lco`0co`001S?o00030000
<ol0<ol000lco`000`000?ooooooo`27oooo001Soooo00@0000co`0co`0co`0206Ko4S?o000306Ko
<ol0<ol000Hco`000`0003?o03?o000@<ol000<0003oooooool0Q_ooo`00H_ooo`030000<ol0<ol0
0080I_lD<ol000<0I_lco`0co`001S?o0080000B<ol000<0003oooooool0QOooo`00HOooo`040000
<ol006Ko06Ko5S?o000306Ko<ol0<ol000Hco`000`0003?o03?o000B<ol000<0003oooooool0Q?oo
o`00;oooo`<0000Woooo100000;oool200000P1VoaPco`000`1Voc?o03?o0006<ol000<0000co`0c
o`004c?o00030000oooooooo017oool40000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?oo
ooooo`0Voooo00<0003oooooool00_ooo`03000006Ko06Ko01Xco`000`1Voc?o03?o0006<ol000<0
000co`0co`0053?o00030000oooooooo013oool00`000?ooooooo`0/oooo00<0003oooooool09_oo
o`040000oooooooo00005_ooo`00;Oooo`D0000Xoooo00<0003oool0I_l00P1Voa`co`000`1Voc?o
03?o0006<ol00P0001Hco`0200004Oooo`030000oooooooo02Soool500009oooo`040000oooooooo
00005_ooo`009oooo`@00002oooo00@0003oooooool0000Roooo100000;oool206Ko0P0001hco`00
0`1Voc?o03?o0006<ol000<0000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0W
oooo00@0003oooooool0000Xoooo0`0001Ooool002koool00`000?ooo`00000Uoooo0`1Vo`800000
0c?o000003?o000M<ol000<0I_lco`0co`001S?o00030000<ol0<ol001Pco`000`000?ooooooo`0<
oooo00@0003oooooool0000Yoooo00<0003oool00000:Oooo`030000oooooooo01Koool002ooool2
00008Oooo`@0I_l2oooo100001lco`000`1Voc?o03?o0006<ol000<0000co`0co`006C?o00030000
oooooooo00coool20000:oooo`80000Yoooo0`0001Koool004coool606Ko1?ooo`80000S<ol000<0
I_lco`0co`001S?o00030000<ol0<ol001Xco`020000OOooo`00Aoooo`D0I_l8oooo0P0002Dco`00
0`1Voc?o03?o0006<ol00P0001dco`030000N_ooo`00@_ooo`D0I_l:oooo0`0002Lco`000`1Voc?o
03?o0006<ol000<0000co`0co`007c?o00H0001doooo000hoooo2P1Vo`Woool60000:S?o000306Ko
<ol0<ol000Hco`000`0003?o03?o000U<ol00`00077oool002?ooolE06Ko2Oooo`X0000`<ol000<0
I_lco`0co`001S?o00030000<ol0<ol002Pco`0:0000Ioooo`004?ooool0000Aoooo000Foooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003ooooo09T02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
01Goool002coool00`000?ooooooo`0Yoooo00<0003oooooool08?ooo`03o`2Ioooooooo00Koool0
0`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo02Woool00`000?ooooooo`0E
oooo001koooo00?o09Woooooool01_ooo`030000oooooooo09Woool007_oool00ol0VOooooooo`06
oooo00<0003oooooool0VOooo`00Noooo`03o`2Ioooooooo00Koool20000V_ooo`00Noooo`03o`2I
oooooooo00Koool00`000?ooooooo`2Ioooo001koooo00?o09Woooooool01_ooo`030000oooooooo
09Woool007_oool00ol0VOooooooo`06oooo00<0003oooooool0VOooo`00Noooo`03o`2Ioooooooo
00Koool20000V_ooo`00Noooo`03o`2Ioooooooo00Koool00`000?ooooooo`2Ioooo001koooo00?o
09Woooooool01_ooo`030000oooooooo09Woool007_oool00ol0VOooooooo`06oooo00<0003ooooo
ool0VOooo`00Noooo`03o`2Ioooooooo00Koool00`000?ooooooo`2Ioooo001koooo00?o09Wooooo
ool01_ooo`80002Joooo001koooo00?o09Woooooool01_ooo`030000oooooooo09Woool007_oool0
0ol0VOooooooo`06oooo00<0003oooooool0VOooo`00Noooo`03o`2Ioooooooo00Koool00`000?oo
ooooo`2Ioooo001koooo00?o09Woooooool01_ooo`80002Joooo001koooo00?o09Woooooool01_oo
o`030000oooooooo09Woool007_oool00ol0VOooooooo`06oooo00<0003oooooool0VOooo`00Nooo
o`03o`2I0000000000<00003oooo00<0003oooooool0VOooo`00Noooo`04o`2Ioooooooo00001Ooo
o`030000oooooooo09Woool007_oool01?l0VOooooooo`0000Goool30000VOooo`00Noooo`04o`2I
oooooooo00001Oooo`030000oooooooo09Woool007_oool01?l0VOooooooo`0000Goool00`000?oo
ooooo`2Ioooo001koooo00Co09Woool000000005oooo00<0003oooooool0VOooo`00Noooo`03o`2I
oooooooo00Koool20000V_ooo`00Noooo`03o`2Ioooooooo00Koool00`000?ooooooo`2Ioooo001k
oooo00?o09Woooooool01_ooo`030000oooooooo09Woool007_oool00ol0VOooooooo`06oooo00<0
003oooooool0VOooo`00Noooo`03o`2Ioooooooo00Koool00`000?ooooooo`2Ioooo001koooo00?o
09Woooooool01_ooo`80002Joooo001koooo00?o09Woooooool01_ooo`030000oooooooo09Woool0
07_oool00ol0VOooooooo`06oooo00<0003oooooool0VOooo`00Noooo`03o`2Ioooooooo00Koool0
0`000?ooooooo`2Ioooo001koooo00?o09Woooooool01_ooo`80002Joooo001koooo00?o09Wooooo
ool01_ooo`030000oooooooo09Woool007_oool00ol0VOooooooo`06oooo00<0003oooooool0VOoo
o`00Noooo`03o`2Ioooooooo00Koool00`000?ooooooo`2Ioooo001koooo00?o09Woooooool01_oo
o`030000oooooooo09Woool007_oool00ol0VOooooooo`06oooo0P0009[oool007_oool00ol0VOoo
ooooo`06oooo00<0003oooooool0VOooo`00Noooo`03o`2I0000000000800004oooo00<0003ooooo
ool0VOooo`00Noooo`03o`2I0000oooo00Koool00`000?ooooooo`2Ioooo001koooo00?o09Woool0
00001_ooo`<0002Ioooo001koooo00Co09Woooooool00005oooo00<0003oooooool0VOooo`00Nooo
o`05o`2I0000oooooooo000000Coool00`000?ooooooo`2Ioooo001koooo00Co09Woool000000005
oooo00<0003oooooool0VOooo`00Noooo`03o`2Ioooooooo00Koool20000V_ooo`00Noooo`03o`2I
oooooooo00Koool00`000?ooooooo`2Ioooo001koooo00?o09Woooooool01_ooo`030000oooooooo
09Woool007_oool00ol0VOooooooo`06oooo00<0003oooooool0VOooo`00Noooo`03o`2Ioooooooo
00Koool00`000?ooooooo`2Ioooo001koooo00?o09Woooooool01_ooo`80002Joooo001koooo00?o
09Woooooool01_ooo`030000oooooooo09Woool007_oool00ol0VOooooooo`06oooo00<0003ooooo
ool0VOooo`00Noooo`03o`2Ioooooooo00Koool00`000?ooooooo`2Ioooo001koooo00?o09Wooooo
ool01_ooo`80002Joooo001koooo00?o09Woooooool01_ooo`030000oooooooo09Woool007_oool0
0ol0VOooooooo`06oooo00<0003oooooool0VOooo`00Noooo`03o`2Ioooooooo00Koool00`000?oo
ooooo`2Ioooo001koooo00?o09Woooooool01_ooo`030000oooooooo09Woool007_oool00ol0VOoo
ooooo`06oooo0P0009[oool007_oool00ol0VOooooooo`06oooo00<0003oooooool0VOooo`00Nooo
o`04o`2Ioooo000000001Oooo`030000oooooooo09Woool007_oool01Ol0V@000?ooooooo`000004
oooo00<0003oooooool0VOooo`00Noooo`04o`2Ioooooooo00001Oooo`<0002Ioooo001koooo00Go
09Woooooooooool000001?ooo`030000oooooooo09Woool007_oool01Ol0V@000?ooooooo`000004
oooo00<0003oooooool0VOooo`00Noooo`04o`2Ioooo000000001Oooo`030000oooooooo09Woool0
07_oool00ol0VOooooooo`06oooo00<0003oooooool0VOooo`00Noooo`03o`2Ioooooooo00Koool2
0000V_ooo`00Noooo`03o`2Ioooooooo00Koool00`000?ooooooo`2Ioooo001koooo00?o09Wooooo
ool01_ooo`030000oooooooo09Woool007_oool00ol0VOooooooo`06oooo00<0003oooooool0VOoo
o`00Noooo`03o`2Ioooooooo00Koool20000V_ooo`00Noooo`03o`2Ioooooooo00Koool00`000?oo
ooooo`2Ioooo001koooo00?o09Woooooool01_ooo`030000oooooooo09Woool007_oool00ol0VOoo
ooooo`06oooo00<0003oooooool0VOooo`00Noooo`03o`2Ioooooooo00Koool00`000?ooooooo`2I
oooo001koooo00?o09Woooooool01_ooo`80002Joooo001koooo00?o09Woooooool01_ooo`030000
oooooooo09Woool007_oool00ol0VOooooooo`06oooo00<0003oooooool0VOooo`00Noooo`03o`2I
oooooooo00Koool00`000?ooooooo`2Ioooo001koooo00?o09Woooooool01_ooo`80002Joooo001k
oooo00?o09Woooooool01_ooo`030000oooooooo09Woool007_oool00ol0VOooooooo`06oooo00<0
003oooooool0VOooo`00Noooo`03o`2Ioooooooo00<00003oooo00<0003oooooool0VOooo`00Nooo
o`05o`2Ioooooooooooo000000Coool00`000?ooooooo`2Ioooo001koooo00?o09T0000000000`00
00?oool30000VOooo`00O?ooo`040000oooooooo0000X?ooo`00OOooo`030000oooo00000:3oool0
07koool20000X?ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000
oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo
07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool2
00001Oooo`<00002oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool02_ooo`050000
oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Oooo`030000
oooooooo00Ooool500000oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500005?oo
o`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000005oooo`030000oooooooo00Soool00`000?ooo`000003oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo01Ooool200002oooo`800002oooo00<0003oooooool0NOoo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.40095 .26487 L
.41127 .26487 L
.42237 .26487 L
.42781 .26487 L
.43298 .26487 L
.43522 .26487 L
.43762 .26487 L
.43833 .26487 L
.43899 .26487 L
s
.43899 .26487 m
.43949 .61803 L
s
0 .4 1 r
.02381 .26363 m
.04262 .26333 L
.06244 .26294 L
.08255 .26243 L
.10458 .26173 L
.12415 .26093 L
.14509 .25986 L
.16639 .25846 L
.18653 .2568 L
.22495 .25236 L
.24479 .24922 L
.26581 .2451 L
.30365 .23524 L
.34394 .22137 L
.38271 .2075 L
.39281 .20461 L
.39815 .20331 L
.40384 .20213 L
.40931 .20122 L
.41426 .2006 L
.41665 .20037 L
.41924 .20017 L
.42043 .2001 L
.42169 .20004 L
.42276 .2 L
.42393 .19996 L
.42524 .19994 L
.42644 .19993 L
.42707 .19993 L
.42777 .19994 L
.42849 .19994 L
.42917 .19996 L
.43042 .19999 L
.43156 .20003 L
.43282 .20009 L
.43414 .20017 L
.43629 .20033 L
.43747 .20043 L
.43858 .20054 L
.4399 .26487 L
.4411 .26487 L
.44344 .26487 L
.46436 .26487 L
.50282 .26487 L
.54374 .26487 L
.58315 .26487 L
.62103 .26487 L
.66137 .26487 L
.7002 .26487 L
.74147 .26487 L
Mistroke
.78123 .26487 L
.81948 .26487 L
.86018 .26487 L
.89936 .26487 L
.94099 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000@<ol02@1V
o`@co`000`0003?o03?o000><ol000<0003oooooool0R?ooo`00Hoooo`030000<ol0<ol000dco`04
06Ko23?o000306Ko<ol0<ol0008co`000`0003?o03?o000?<ol000<0003oooooool0Qoooo`00Hooo
o`030000<ol0<ol000Xco`0306Ko33?o000306Ko<ol0<ol0008co`000`0003?o03?o000@<ol000<0
003oooooool0Q_ooo`00H_ooo`030000<ol0<ol000Pco`0306Ko3c?o000306Ko<ol0<ol0008co`02
00004S?o00030000oooooooo08Goool0067oool00`0003?o03?o0005<ol0101Voa8co`000`1Voc?o
03?o0002<ol000<0000co`0co`004S?o00030000oooooooo08Coool002ooool300009oooo`@00002
oooo0P0000Dco`0306Ko5S?o000306Ko<ol0<ol0008co`000`0003?o03?o000C<ol000<0003ooooo
ool04Oooo`@0000Zoooo0`0002Ooool300005oooo`00<?ooo`030000oooooooo02Koool00`000?oo
ooooo`02oooo00<0000co`0co`000c?o0080I_lI<ol000<0I_lco`0co`000S?o00030000<ol0<ol0
01@co`000`000?ooooooo`0@oooo00<0003oooooool0;?ooo`030000oooooooo02Koool010000?oo
ooooo`0001Koool002goool50000:?ooo`040000oooooooo00000c?o00<0I_lK<ol000<0I_lco`0c
o`000S?o0080000F<ol00P00017oool00`000?ooooooo`0Xoooo1@0002Ooool010000?ooooooo`00
01Koool002Ooool400000_ooo`040000oooooooo00008_ooo`@00004oooo0P00008co`0206Ko7S?o
000306Ko<ol0<ol0008co`000`0003?o03?o000G<ol000<0003oooooool03oooo`030000oooooooo
02Ooool010000?ooooooo`0002Soool300005oooo`00;_ooo`030000oooo000002Soool2000000@0
I_l00000I_l0I_lQ<ol000D0I_lco`0co`0co`0000006S?o00030000oooooooo00coool010000?oo
ooooo`0002Woool00`000?ooo`00000Yoooo00<0003oooooool05_ooo`00;oooo`80000Voooo0`1V
o`80000T<ol000D0I_lco`0co`0co`0000006c?o00030000oooooooo00coool20000:oooo`80000Y
oooo0`0001Koool005;oool506Ko00<0000co`0co`009S?o000506Ko<ol0<ol0<ol0000001`co`02
0000OOooo`00C?ooo`H0I_l2oooo0P0002Xco`00101Voc?o03?o03?o0080000M<ol00`0007[oool0
04Goool706Ko1Oooo`<0000/<ol000D0I_lco`0co`0co`0000008C?o00H0001doooo000moooo201V
o`Koool60000;c?o000506Ko<ol0<ol0<ol0000002Lco`030000LOooo`00:Ooooa@0I_l4oooo2P00
03Dco`001@1Voc?o03?o03?o0000000Z<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Coool01Ol0VOooooooooooo`00000:oooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`0Eoooo000/oooo00<0003oooooool0:Oooo`030000oooooooo02Goool01Ol0VOoooooooooo
o`00000[oooo00<0003oooooool0:Oooo`030000oooooooo02Woool00`000?ooooooo`0Eoooo0020
oooo00Go09Woooooooooool00000Voooo`00P?ooo`05o`2Ioooooooooooo000009_oool0083oool0
1?l0VOooooooooooo`80002Joooo0020oooo00Go09Woooooooooool00000Voooo`00P?ooo`05o`2I
oooooooooooo000009_oool0083oool01Ol0VOooooooooooo`00002Koooo0020oooo00Co09Wooooo
ooooool20000V_ooo`00P?ooo`05o`2Ioooooooooooo000009_oool0083oool01Ol0VOoooooooooo
o`00002Koooo0020oooo00Go09Woooooooooool00000Voooo`00P?ooo`05o`2Ioooooooooooo0000
09_oool0083oool01?l0VOooooooooooo`80002Joooo0020oooo00Go09Woooooooooool00000Vooo
o`00P?ooo`05o`2Ioooooooooooo000009_oool0083oool01Ol0VOooooooooooo`00002Koooo0020
oooo00Co09Woooooooooool20000V_ooo`00P?ooo`05o`2Ioooooooooooo000009_oool0083oool0
1Ol0VOooooooooooo`00002Koooo001loooo1@0000?oool00`000?ooooooo`2Ioooo001noooo00<0
003ooooo09T00oooo`030000oooooooo09Woool007koool00`000?ooool0V@03oooo0`0009Woool0
07koool00`000?ooool0V@03oooo00<0003oooooool0VOooo`00O_ooo`030000ooooo`2I00?oool0
0`000?ooooooo`2Ioooo001moooo0P000003ooooo`2Ioooo00;oool00`000?ooooooo`2Ioooo0020
oooo00Co09Woooooooooool20000V_ooo`00P?ooo`05o`2Ioooooooooooo000009_oool0083oool0
1Ol0VOooooooooooo`00002Koooo0020oooo00Go09Woooooooooool00000Voooo`00P?ooo`05o`2I
oooooooooooo000009_oool0083oool01?l0VOooooooooooo`80002Joooo0020oooo00Go09Wooooo
ooooool00000Voooo`00P?ooo`05o`2Ioooooooooooo000009_oool0083oool01Ol0VOoooooooooo
o`00002Koooo0020oooo00Co09Woooooooooool20000V_ooo`00P?ooo`05o`2Ioooooooooooo0000
09_oool0083oool01Ol0VOooooooooooo`00002Koooo0020oooo00Go09Woooooooooool00000Vooo
o`00P?ooo`05o`2Ioooooooooooo000009_oool0083oool01?l0VOooooooooooo`80002Joooo0020
oooo00Go09Woooooooooool00000Voooo`00O?ooo`@000001Ol0VOooooooooooo`00002Koooo001l
oooo00D0003ooooooooooooo09T00oooo`030000oooooooo09Woool007goool010000?ooooooool0
V@?oool30000VOooo`00O_ooo`030000ooooo`2I00?oool00`000?ooooooo`2Ioooo001loooo00D0
003oooooool0003o09T00oooo`030000oooooooo09Woool007goool2000000?ooooo09Woool00_oo
o`030000oooooooo09Woool0083oool01?l0VOooooooooooo`80002Joooo0020oooo00Go09Wooooo
ooooool00000Voooo`00P?ooo`05o`2Ioooooooooooo000009_oool0083oool01Ol0VOoooooooooo
o`00002Koooo0020oooo00Go09Woooooooooool00000Voooo`00P?ooo`04o`2Ioooooooooooo0P00
09[oool0083oool01Ol0VOooooooooooo`00002Koooo0020oooo00Go09Woooooooooool00000Vooo
o`00P?ooo`05o`2Ioooooooooooo000009_oool0083oool01?l0VOooooooooooo`80002Joooo0020
oooo00Go09Woooooooooool00000Voooo`00P?ooo`05o`2Ioooooooooooo000009_oool0083oool0
1Ol0VOooooooooooo`00002Koooo0020oooo00Go09Woooooooooool00000Voooo`00P?ooo`04o`2I
oooooooooooo0P0009[oool0083oool01Ol0VOooooooooooo`00002Koooo001moooo0P000003oooo
o`2Ioooo00;oool00`000?ooooooo`2Ioooo001loooo00D0003oooooool0003o09T00oooo`030000
oooooooo09Woool007koool00`000?ooool0V@03oooo0`0009Woool007ooool00`000?l0VOooo`02
oooo00<0003oooooool0VOooo`00O?ooo`050000oooooooo0000o`2I00?oool00`000?ooooooo`2I
oooo001moooo0P000003ooooo`2Ioooo00;oool00`000?ooooooo`2Ioooo0020oooo00Go09Wooooo
ooooool00000Voooo`00P?ooo`04o`2Ioooooooooooo0P0009[oool0083oool01Ol0VOoooooooooo
o`00002Koooo0020oooo00Go09Woooooooooool00000Voooo`00P?ooo`05o`2Ioooooooooooo0000
09_oool0083oool01?l0VOooooooooooo`80002Joooo0020oooo00Go09Woooooooooool00000Vooo
o`00P?ooo`05o`2Ioooooooooooo000009_oool0083oool01Ol0VOooooooooooo`00002Koooo0020
oooo00Go09Woooooooooool00000Voooo`00P?ooo`04o`2Ioooooooooooo0P0009[oool0083oool0
1Ol0VOooooooooooo`00002Koooo0020oooo00Go09Woooooooooool00000Voooo`00P?ooo`05o`2I
oooooooooooo000009_oool0083oool01?l0VOooooooooooo`80002Joooo0020oooo00Go09Wooooo
ooooool00000Voooo`00P?ooo`05o`2Ioooooooooooo000009_oool007koool300000oooo`030000
oooooooo09Woool007ooool00`000?l0VOooo`02oooo00<0003oooooool0VOooo`00O?ooo`D00003
oooo0`0009Woool007coool010000?ooooooo`000:3oool007goool00`000?ooo`00002Poooo001n
oooo0P000:3oool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?oo
ooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`D00002oooo0P00
00?oool400000oooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Coool400001Oooo`030000oooooooo00Ooool00`000?oo
ooooo`04oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0E
oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0001Coool00`000?ooooooo`09oooo00<0003oooooool00_ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`00000Goooo00<0003oooooool01oooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool200000ooo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.40095 .26487 L
.42237 .26487 L
.43215 .26487 L
.44268 .26487 L
.44778 .26487 L
.45029 .26487 L
.45262 .26487 L
.45473 .26487 L
.4559 .26487 L
s
.4559 .26487 m
.45633 .61803 L
s
0 .4 1 r
.02381 .26391 m
.04262 .26367 L
.06244 .26337 L
.08255 .26297 L
.10458 .26242 L
.12415 .2618 L
.14509 .26097 L
.16639 .25988 L
.18653 .25858 L
.22495 .25513 L
.24479 .25269 L
.26581 .24948 L
.30365 .2418 L
.34394 .231 L
.38271 .2202 L
.39281 .21795 L
.39815 .21694 L
.40384 .21602 L
.40931 .21531 L
.41426 .21483 L
.41665 .21465 L
.41924 .2145 L
.42043 .21444 L
.42169 .2144 L
.42276 .21436 L
.42393 .21434 L
.42524 .21432 L
.42644 .21431 L
.42707 .21431 L
.42777 .21432 L
.42849 .21432 L
.42917 .21433 L
.43042 .21436 L
.43156 .21439 L
.43282 .21444 L
.43414 .2145 L
.43858 .21478 L
.4411 .215 L
.44344 .21524 L
.44864 .21589 L
.45356 .21665 L
.45487 .21687 L
.4556 .217 L
.45627 .21712 L
.457 .26487 L
.4578 .26487 L
.45922 .26487 L
.46436 .26487 L
.50318 .26487 L
.54446 .26487 L
Mistroke
.58422 .26487 L
.62246 .26487 L
.66316 .26487 L
.70234 .26487 L
.74398 .26487 L
.7841 .26487 L
.8227 .26487 L
.86376 .26487 L
.9033 .26487 L
.94132 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000E<ol01@1Vo`Dco`0200004S?o00030000
oooooooo08Goool0067oool00`0003?o03?o000?<ol01`1Vo`Dco`0506Ko00<0000co`0co`004S?o
00030000oooooooo08Coool002ooool300009oooo`@00002oooo0P0000lco`0306Ko4C?o00030000
<ol0<ol001<co`000`000?ooooooo`0Aoooo100002[oool300009oooo`<0000Goooo000`oooo00<0
003oooooool09_ooo`030000oooooooo00;oool00`0003?o03?o000<<ol00`1Voa@co`000`0003?o
03?o000D<ol000<0003oooooool04?ooo`030000oooooooo02coool00`000?ooooooo`0Voooo00@0
003oooooool0000Foooo000]oooo1@0002Soool010000?ooooooo`0000/co`0406Ko5c?o0080000F
<ol00P00017oool00`000?ooooooo`0Xoooo1@0002Ooool010000?ooooooo`0001Koool002Ooool4
00000_ooo`040000oooooooo00008_ooo`@00004oooo0P0000Pco`0406Ko6c?o00030000<ol0<ol0
01Lco`000`000?ooooooo`0?oooo00<0003oooooool09oooo`040000oooooooo0000:?ooo`<0000G
oooo000^oooo00<0003oool00000:?ooo`8000000c?o000003?o0002<ol01@1Voalco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000101Vob@co`000`0003?o03?o000I<ol000<0
003oooooool03?ooo`80000[oooo0P0002Woool300005_ooo`00E_ooo`03000006Ko06Ko0080I_lY
<ol000<0000co`0co`006S?o0080001moooo001Boooo1@1Vobdco`0200007C?o00<0001joooo001<
oooo1P1Vo`80000`<ol000<0000co`0co`007c?o00H0001doooo0015oooo1`1Vo`D0000c<ol000<0
000co`0co`009C?o00<0001aoooo000^oooo5`1Vo`H0000i<ol000<0000co`0co`00:3?o00X0001W
oooo000@ooooo`00017oool001Koool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool05Oooo`00;?ooo`030000oooooooo02Woool00`000?oo
ooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo02Woool00`000?ooooooo`0Yoooo00<0
003oooooool05Oooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool0
08Coool20000V_ooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo00<0003oooooool0VOooo`00Q?ooo`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`030000oooooooo09Woool007coool500000oooo`030000oooooooo09Woool007koool00`000?oo
ooooo`03oooo00<0003oooooool0VOooo`00O_ooo`030000oooooooo00?oool30000VOooo`00O_oo
o`030000oooooooo00?oool00`000?ooooooo`2Ioooo001noooo00<0003oooooool00oooo`030000
oooooooo09Woool007goool200001Oooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?oo
o`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOoo
o`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000oooooooo09Woool0
08Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?ooo`80002Joooo0024
oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2I
oooo0024oooo00<0003oooooool0VOooo`00Q?ooo`80002Joooo0024oooo00<0003oooooool0VOoo
o`00O?ooo`@00004oooo00<0003oooooool0VOooo`00O?ooo`030000oooooooo00Goool00`000?oo
ooooo`2Ioooo001moooo00<0003oooooool01?ooo`<0002Ioooo001noooo00<0003oooooool00ooo
o`030000oooooooo09Woool007coool010000?ooooooo`0000Coool00`000?ooooooo`2Ioooo001m
oooo0P0000Goool00`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2I
oooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?oo
ooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003ooooo
ool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000oooooooo
09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000
oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000oooooooo09Woool007goool200001Ooo
o`030000oooooooo09Woool007coool010000?ooooooo`0000Coool00`000?ooooooo`2Ioooo001n
oooo00<0003oooooool00oooo`<0002Ioooo001ooooo00<0003oooooool00_ooo`030000oooooooo
09Woool007coool010000?ooooooo`0000Coool00`000?ooooooo`2Ioooo001moooo0P0000Goool0
0`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?ooo`80002Joooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool0
0`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool0
08Coool20000V_ooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo001n
oooo0`0000?oool00`000?ooooooo`2Ioooo001ooooo00<0003oooooool00_ooo`030000oooooooo
09Woool007coool500000oooo`<0002Ioooo001loooo00@0003oooooool0002Poooo001moooo00<0
003oool00000X?ooo`00O_ooo`80002Poooo003ooooo8Oooo`00ooooob7oool007coool00`000?oo
ooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0I
oooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00coool500000_ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool02?oo
o`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool05Oooo`030000
oooooooo00Woool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0001Coool00`000?oo
ooooo`08oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000001Ooool00`000?oo
ooooo`08oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo01Ooool200002Oooo`030000
oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.44268 .26487 L
.45262 .26487 L
.46172 .26487 L
.46618 .26487 L
.46854 .26487 L
.47106 .26487 L
.47231 .26487 L
.47348 .26487 L
s
.47348 .26487 m
.4739 .61803 L
s
0 .4 1 r
.02381 .26414 m
.04262 .26397 L
.06244 .26373 L
.08255 .26344 L
.10458 .26302 L
.12415 .26255 L
.14509 .26192 L
.16639 .2611 L
.18653 .26012 L
.22495 .25751 L
.24479 .25566 L
.26581 .25324 L
.30365 .24744 L
.34394 .23928 L
.38271 .23112 L
.39281 .22941 L
.39815 .22865 L
.40384 .22796 L
.40931 .22742 L
.41426 .22705 L
.41665 .22692 L
.41924 .2268 L
.42043 .22676 L
.42169 .22673 L
.42276 .2267 L
.42393 .22668 L
.42524 .22667 L
.42644 .22666 L
.42707 .22666 L
.42777 .22667 L
.42849 .22667 L
.42917 .22668 L
.43042 .2267 L
.43156 .22672 L
.43282 .22676 L
.43414 .2268 L
.43858 .22702 L
.4411 .22719 L
.44344 .22737 L
.45356 .22843 L
.45918 .2292 L
.46436 .23001 L
.46933 .23087 L
.47184 .23133 L
.47253 .23145 L
.47327 .23159 L
.47396 .23172 L
.4746 .26487 L
.47529 .26487 L
.47601 .26487 L
Mistroke
.47733 .26487 L
.4803 .26487 L
.4857 .26487 L
.50586 .26487 L
.54749 .26487 L
.58761 .26487 L
.62621 .26487 L
.66727 .26487 L
.70681 .26487 L
.74483 .26487 L
.78531 .26487 L
.82427 .26487 L
.86568 .26487 L
.90558 .26487 L
.94396 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0001Dco`0A06Ko0P00000306Ko<ol0<ol001<co`0200004Oooo`030000oooooooo02Soool5
00009oooo`040000oooooooo00005_ooo`009oooo`@00002oooo00@0003oooooool0000Roooo1000
00Coool200004S?o00@0I_lA<ol000<0000co`0co`000P1VoaDco`000`000?ooooooo`0?oooo00<0
003oooooool09oooo`040000oooooooo0000:?ooo`<0000Goooo000^oooo00<0003oool00000:?oo
o`8000000c?o000003?o000<<ol01@1VoaDco`001@0003?o03?o03?o001Vo`0F<ol000<0003ooooo
ool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool00`000?ooooooo`0Foooo000_
oooo0P0002Ooool400002C?o00D0I_lJ<ol000D0000co`0co`0co`00I_l05c?o00030000oooooooo
00coool20000:oooo`80000Yoooo0`0001Koool005Koool2000023?o00D0I_lO<ol000D0000co`0c
o`0co`00I_l063?o0080001moooo001Doooo0P0000<co`0706Ko93?o00800002<ol000<0I_lco`0c
o`0063?o00<0001joooo001Aoooo00<00000I_l0I_l01@1Vob/co`000`0003?o03?o0002<ol000<0
I_lco`0co`006S?o00H0001doooo0015oooo3@1Voc8co`000`0003?o03?o0002<ol000<0I_lco`0c
o`0083?o00<0001aoooo000coooo4P1Vo`H0000i<ol000<0000co`0co`000S?o000306Ko<ol0<ol0
02<co`0:0000Ioooo`004?ooool0000Aoooo000Foooo00<0003oooooool02?ooo`030000oooooooo
00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`050000ooooooooooooo`2I00Koool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo01Goool002coool00`000?oo
ooooo`0Yoooo00<0003oooooool0:Oooo`050000ooooooooooooo`2I02Ooool00`000?ooooooo`0Y
oooo00<0003oooooool0:Oooo`030000oooooooo01Goool008Coool01@000?ooooooooooool0V@2G
oooo0024oooo00D0003ooooooooooooo09T0Uoooo`00Q?ooo`800002oooo00?o09Woooooool0UOoo
o`00Q?ooo`050000ooooooooooooo`2I09Ooool008Coool01@000?ooooooooooool0V@2Goooo0024
oooo00D0003ooooooooooooo09T0Uoooo`00Q?ooo`800002oooo00?o09Woooooool0UOooo`00Q?oo
o`050000ooooooooooooo`2I09Ooool008Coool01@000?ooooooooooool0V@2Goooo0024oooo00D0
003ooooooooooooo09T0Uoooo`00Q?ooo`050000ooooooooooooo`2I09Ooool008Coool200000_oo
o`03o`2Ioooooooo09Goool008Coool01@000?ooooooooooool0V@2Goooo0024oooo00D0003ooooo
oooooooo09T0Uoooo`00Q?ooo`050000ooooooooooooo`2I09Ooool008Coool200000_ooo`03o`2I
oooooooo09Goool008Coool01@000?ooooooooooool0V@2Goooo0024oooo00D0003ooooooooooooo
09T0Uoooo`00O?ooo`D00003oooo00D0003ooooooooooooo09T0Uoooo`00O_ooo`030000oooooooo
00?oool01@000?ooooooooooool0V@2Goooo001noooo00<0003oooooool00oooo`<000000oooool0
VOooo`2Foooo001noooo00<0003oooooool00oooo`050000ooooooooooooo`2I09Ooool007koool0
0`000?ooooooo`03oooo00D0003ooooooooooooo09T0Uoooo`00OOooo`800005oooo00D0003ooooo
oooooooo09T0Uoooo`00Q?ooo`800002oooo00?o09Woooooool0UOooo`00Q?ooo`050000oooooooo
ooooo`2I09Ooool008Coool01@000?ooooooooooool0V@2Goooo0024oooo00D0003ooooooooooooo
09T0Uoooo`00Q?ooo`050000ooooooooooooo`2I09Ooool008Coool200000_ooo`03o`2Ioooooooo
09Goool008Coool01@000?ooooooooooool0V@2Goooo0024oooo00D0003ooooooooooooo09T0Uooo
o`00Q?ooo`050000ooooooooooooo`2I09Ooool008Coool200000_ooo`03o`2Ioooooooo09Goool0
08Coool01@000?ooooooooooool0V@2Goooo0024oooo00D0003ooooooooooooo09T0Uoooo`00Q?oo
o`050000ooooooooooooo`2I09Ooool008Coool01@000?ooooooooooool0V@2Goooo0024oooo0P00
00;oool00ol0VOooooooo`2Eoooo0024oooo00D0003ooooooooooooo09T0Uoooo`00O?ooo`@00004
oooo00D0003ooooooooooooo09T0Uoooo`00O?ooo`030000oooooooo00Goool01@000?oooooooooo
ool0V@2Goooo001moooo00<0003oooooool01?ooo`<000000oooool0VOooo`2Foooo001noooo00<0
003oooooool00oooo`050000ooooooooooooo`2I09Ooool007coool010000?ooooooo`0000Coool0
1@000?ooooooooooool0V@2Goooo001moooo0P0000Goool01@000?ooooooooooool0V@2Goooo0024
oooo0P0000;oool00ol0VOooooooo`2Eoooo0024oooo00D0003ooooooooooooo09T0Uoooo`00Q?oo
o`050000ooooooooooooo`2I09Ooool008Coool01@000?ooooooooooool0V@2Goooo0024oooo00D0
003ooooooooooooo09T0Uoooo`00Q?ooo`800002oooo00?o09Woooooool0UOooo`00Q?ooo`050000
ooooooooooooo`2I09Ooool008Coool01@000?ooooooooooool0V@2Goooo0024oooo00D0003ooooo
oooooooo09T0Uoooo`00Q?ooo`800002oooo00?o09Woooooool0UOooo`00Q?ooo`050000oooooooo
ooooo`2I09Ooool008Coool01@000?ooooooooooool0V@2Goooo0024oooo00D0003ooooooooooooo
09T0Uoooo`00Q?ooo`050000ooooooooooooo`2I09Ooool008Coool200000_ooo`03o`2Ioooooooo
09Goool008Coool01@000?ooooooooooool0V@2Goooo001moooo0P0000Goool01@000?oooooooooo
ool0V@2Goooo001loooo00@0003oooooool00004oooo00D0003ooooooooooooo09T0Uoooo`00O_oo
o`030000oooooooo00?oool3000000?ooooo09Woool0U_ooo`00Ooooo`030000oooooooo00;oool0
1@000?ooooooooooool0V@2Goooo001loooo00@0003oooooool00004oooo00D0003ooooooooooooo
09T0Uoooo`00OOooo`800005oooo00D0003ooooooooooooo09T0Uoooo`00Q?ooo`050000oooooooo
ooooo`2I09Ooool008Coool200000_ooo`03o`2Ioooooooo09Goool008Coool01@000?oooooooooo
ool0V@2Goooo0024oooo00D0003ooooooooooooo09T0Uoooo`00Q?ooo`050000ooooooooooooo`2I
09Ooool008Coool200000_ooo`03o`2Ioooooooo09Goool008Coool01@000?ooooooooooool0V@2G
oooo0024oooo00D0003ooooooooooooo09T0Uoooo`00Q?ooo`050000ooooooooooooo`2I09Ooool0
08Coool01@000?ooooooooooool0V@2Goooo0024oooo0P0000;oool00ol0VOooooooo`2Eoooo0024
oooo00D0003ooooooooooooo09T0Uoooo`00Q?ooo`050000ooooooooooooo`2I09Ooool008Coool0
1@000?ooooooooooool0V@2Goooo0024oooo0P0000;oool00ol0VOooooooo`2Eoooo0024oooo00D0
003ooooooooooooo09T0Uoooo`00Q?ooo`050000ooooooooooooo`2I09Ooool007koool300000ooo
o`050000ooooooooooooo`2I09Ooool007ooool00`000?ooooooo`02oooo00D0003ooooooooooooo
09T0Uoooo`00O?ooo`D00003oooo0`000003ooooo`2Ioooo09Koool007coool010000?ooooooo`00
0:3oool007goool00`000?ooo`00002Poooo001noooo0P000:3oool00?oooolQoooo003ooooo8Ooo
o`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?oo
o`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool03Oooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool4
00000oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool0
07Ooool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002?ooo`040000
oooooooo00001?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500004_ooo`040000
oooooooo00002Oooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
01Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool05oooo`80000:oooo0P0000?oool00`000?ooooooo`1ioooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.44268 .26487 L
.46172 .26487 L
.47994 .26487 L
.48519 .26487 L
.48778 .26487 L
.48904 .26487 L
.49018 .26487 L
.4913 .26487 L
s
.4913 .26487 m
.49172 .61803 L
s
0 .4 1 r
.02381 .26435 m
.04262 .26422 L
.06244 .26406 L
.08255 .26384 L
.10458 .26355 L
.12415 .26321 L
.14509 .26276 L
.16639 .26217 L
.18653 .26147 L
.22495 .25959 L
.24479 .25827 L
.26581 .25653 L
.30365 .25238 L
.34394 .24652 L
.38271 .24067 L
.39281 .23945 L
.39815 .23891 L
.40384 .23841 L
.40931 .23802 L
.41426 .23776 L
.41665 .23766 L
.41924 .23758 L
.42043 .23755 L
.42169 .23753 L
.42276 .23751 L
.42393 .2375 L
.42524 .23749 L
.42644 .23748 L
.42707 .23748 L
.42777 .23748 L
.42849 .23749 L
.42917 .23749 L
.43042 .23751 L
.43156 .23752 L
.43282 .23755 L
.43414 .23758 L
.43858 .23774 L
.4411 .23786 L
.44344 .23799 L
.45356 .23875 L
.46436 .23988 L
.4746 .2412 L
.47999 .24196 L
.4857 .24281 L
.48811 .24317 L
.48944 .24338 L
.4907 .24357 L
.49141 .26487 L
.49218 .26487 L
.49353 .26487 L
Mistroke
.49619 .26487 L
.50586 .26487 L
.54655 .26487 L
.58574 .26487 L
.62737 .26487 L
.66749 .26487 L
.70609 .26487 L
.74715 .26487 L
.78669 .26487 L
.82471 .26487 L
.86519 .26487 L
.90415 .26487 L
.94556 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol001Xco`0:06Ko0S?o
00030000<ol0<ol001Pco`000`000?ooooooo`0<oooo00@0003oooooool0000Yoooo00<0003oool0
0000:Oooo`030000oooooooo01Koool002ooool200009oooo`@0000C<ol02@1Vo`Xco`0206Ko00<0
0000I_l0I_l0101VoaDco`000`000?ooooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001F
oooo0P00018co`0506Ko5C?o00030000<ol0<ol000@co`0306Ko4c?o0080001moooo001Doooo0P00
00dco`0706Ko6S?o00800007<ol000<0I_lco`0co`004c?o00<0001joooo001Aoooo0`0000Dco`0:
06Ko8C?o00030000<ol0<ol000Hco`000`1Voc?o03?o000F<ol01P0007Coool004_oool6000000<c
o`00I_l0I_l01@1Vob/co`000`0003?o03?o0006<ol000<0I_lco`0co`0073?o00<0001aoooo000m
oooo5@1Voc8co`000`0003?o03?o0006<ol000<0I_lco`0co`007c?o00X0001Woooo000@ooooo`00
017oool001Koool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool01_ooo`03o`2Ioooo000000[oool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool05Oooo`00;?ooo`030000oooooooo02Woool00`000?ooooooo`0Yoooo00<0
003oooooool01_ooo`03o`2Ioooooooo023oool00`000?ooooooo`0Yoooo00<0003oooooool0:Ooo
o`030000oooooooo01Goool008Coool00`000?ooooooo`06oooo00?o09Woooooool0T?ooo`00Q?oo
o`030000oooooooo00Koool00ol0VOooooooo`2@oooo0024oooo0P0000Ooool00ol0VOooooooo`2@
oooo0024oooo00<0003oooooool01_ooo`03o`2Ioooooooo093oool008Coool00`000?ooooooo`06
oooo00?o09Woooooool0T?ooo`00Q?ooo`030000oooooooo00Koool00ol0VOooooooo`2@oooo0024
oooo0P0000Ooool00ol0VOooooooo`2@oooo0024oooo00<0003oooooool01_ooo`03o`2Ioooooooo
093oool008Coool00`000?ooooooo`06oooo00?o09Woooooool0T?ooo`00Q?ooo`030000oooooooo
00Koool00ol0VOooooooo`2@oooo0024oooo00<0003oooooool01_ooo`03o`2Ioooooooo093oool0
08Coool200001oooo`03o`2Ioooooooo093oool008Coool00`000?ooooooo`06oooo00?o09Wooooo
ool0T?ooo`00Q?ooo`030000oooooooo00Koool00ol0VOooooooo`2@oooo0024oooo00<0003ooooo
ool01_ooo`03o`2Ioooooooo093oool008Coool200001oooo`03o`2Ioooooooo093oool008Coool0
0`000?ooooooo`06oooo00?o09Woooooool0T?ooo`00Q?ooo`030000oooooooo00Koool00ol0VOoo
ooooo`2@oooo001loooo1@0000?oool00`000?ooooooo`06oooo00?o09Woooooool0T?ooo`00O_oo
o`030000oooooooo00?oool00`000?ooooooo`06oooo00?o09Woooooool0T?ooo`00O_ooo`030000
oooooooo00?oool300001_ooo`03o`2Ioooooooo093oool007koool00`000?ooooooo`03oooo00<0
003oooooool01_ooo`03o`2Ioooooooo093oool007koool00`000?ooooooo`03oooo00<0003ooooo
ool01_ooo`03o`2Ioooooooo093oool007goool200001Oooo`030000oooooooo00Koool00ol0VOoo
ooooo`2@oooo0024oooo0P0000Ooool00ol0VOooooooo`2@oooo0024oooo00<0003oooooool01_oo
o`03o`2Ioooooooo093oool008Coool00`000?ooooooo`06oooo00?o09Woooooool0T?ooo`00Q?oo
o`030000oooooooo00Koool00ol0VOooooooo`2@oooo0024oooo00<0003oooooool01_ooo`03o`2I
oooooooo093oool008Coool200001oooo`03o`2Ioooooooo093oool008Coool00`000?ooooooo`06
oooo00?o09Woooooool0T?ooo`00Q?ooo`030000oooooooo00Koool00ol0VOooooooo`2@oooo0024
oooo00<0003oooooool01_ooo`03o`2Ioooooooo093oool008Coool200001oooo`03o`2Ioooooooo
093oool008Coool00`000?ooooooo`06oooo00?o09Woooooool0T?ooo`00Q?ooo`030000oooooooo
00Koool00ol0VOooooooo`2@oooo0024oooo00<0003oooooool01_ooo`03o`2Ioooooooo093oool0
08Coool00`000?ooooooo`06oooo00?o09Woooooool0T?ooo`00Q?ooo`800007oooo00?o09Wooooo
ool0T?ooo`00Q?ooo`030000oooooooo00Koool00ol0VOooooooo`2@oooo001loooo100000Coool0
0`000?ooooooo`06oooo00?o09Woooooool0T?ooo`00O?ooo`030000oooooooo00Goool00`000?oo
ooooo`06oooo00?o09Woooooool0T?ooo`00OOooo`030000oooooooo00Coool300001_ooo`03o`2I
oooooooo093oool007koool00`000?ooooooo`03oooo00<0003oooooool01_ooo`03o`2Ioooooooo
093oool007coool010000?ooooooo`0000Coool00`000?ooooooo`06oooo00?o09Woooooool0T?oo
o`00OOooo`800005oooo00<0003oooooool01_ooo`03o`2Ioooooooo093oool008Coool200001ooo
o`03o`2Ioooooooo093oool008Coool00`000?ooooooo`06oooo00?o09Woooooool0T?ooo`00Q?oo
o`030000oooooooo00Koool00ol0VOooooooo`2@oooo0024oooo00<0003oooooool01_ooo`03o`2I
oooooooo093oool008Coool00`000?ooooooo`06oooo00?o09Woooooool0T?ooo`00Q?ooo`800007
oooo00?o09Woooooool0T?ooo`00Q?ooo`030000oooooooo00Koool00ol0VOooooooo`2@oooo0024
oooo00<0003oooooool01_ooo`03o`2Ioooooooo093oool008Coool00`000?ooooooo`06oooo00?o
09Woooooool0T?ooo`00Q?ooo`800007oooo00?o09Woooooool0T?ooo`00Q?ooo`030000oooooooo
00Koool00ol0VOooooooo`2@oooo0024oooo00<0003oooooool01_ooo`03o`2Ioooooooo093oool0
08Coool00`000?ooooooo`06oooo00?o09Woooooool0T?ooo`00Q?ooo`030000oooooooo00Koool0
0ol0VOooooooo`2@oooo0024oooo0P0000Ooool00ol0VOooooooo`2@oooo0024oooo00<0003ooooo
ool01_ooo`03o`2Ioooooooo093oool007goool200001Oooo`030000oooooooo00Koool00ol0VOoo
ooooo`2@oooo001loooo00@0003oooooool00004oooo00<0003oooooool01_ooo`03o`2Ioooooooo
093oool007koool00`000?ooooooo`03oooo0`0000Koool00ol0VOooooooo`2@oooo001ooooo00<0
003oooooool00_ooo`030000oooooooo00Koool00ol0VOooooooo`2@oooo001loooo00@0003ooooo
ool00004oooo00<0003oooooool01_ooo`03o`2Ioooooooo093oool007goool200001Oooo`030000
oooooooo00Koool00ol0VOooooooo`2@oooo0024oooo00<0003oooooool01_ooo`03o`2Ioooooooo
093oool008Coool200001oooo`03o`2Ioooooooo093oool008Coool00`000?ooooooo`06oooo00?o
09Woooooool0T?ooo`00Q?ooo`030000oooooooo00Koool00ol0VOooooooo`2@oooo0024oooo00<0
003oooooool01_ooo`03o`2Ioooooooo093oool008Coool200001oooo`03o`2Ioooooooo093oool0
08Coool00`000?ooooooo`06oooo00?o09Woooooool0T?ooo`00Q?ooo`030000oooooooo00Koool0
0ol0VOooooooo`2@oooo0024oooo00<0003oooooool01_ooo`03o`2Ioooooooo093oool008Coool0
0`000?ooooooo`06oooo00?o09Woooooool0T?ooo`00Q?ooo`800007oooo00?o09Woooooool0T?oo
o`00Q?ooo`030000oooooooo00Koool00ol0VOooooooo`2@oooo0024oooo00<0003oooooool01_oo
o`03o`2Ioooooooo093oool008Coool00`000?ooooooo`06oooo00?o09Woooooool0T?ooo`00Q?oo
o`800007oooo00?o09Woooooool0T?ooo`00Q?ooo`030000oooooooo00Koool00ol0VOooooooo`2@
oooo0024oooo00<0003oooooool01_ooo`03o`2Ioooooooo093oool007koool300000oooo`030000
oooooooo00Koool00ol0VOooooooo`2@oooo001ooooo00<0003oooooool00_ooo`030000oooooooo
00Koool00ol0VOooooooo`2@oooo001loooo1@0000?oool300001_ooo`03o`2Ioooooooo093oool0
07coool010000?ooooooo`000:3oool007goool00`000?ooo`00002Poooo001noooo0P000:3oool0
0?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000?oool300001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500004_ooo`040000oooooooo00002?ooo`<00004oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?ooooooo`03oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`<00002oooo00<0003ooooo
ool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.48147 .26487 L
.49012 .26487 L
.49955 .26487 L
.50205 .26487 L
.50471 .26487 L
.50601 .26487 L
.50722 .26487 L
.50832 .26487 L
s
.50832 .26487 m
.50879 .61803 L
s
0 .4 1 r
.02381 .26453 m
.04262 .26445 L
.06244 .26435 L
.08255 .26421 L
.10458 .26402 L
.12415 .2638 L
.14509 .26351 L
.16639 .26313 L
.18653 .26267 L
.22495 .26147 L
.24479 .26061 L
.26581 .25949 L
.30365 .25681 L
.34394 .25303 L
.38271 .24926 L
.39281 .24847 L
.39815 .24812 L
.40384 .2478 L
.40931 .24755 L
.41426 .24738 L
.41665 .24732 L
.41924 .24727 L
.42043 .24725 L
.42169 .24723 L
.42276 .24722 L
.42393 .24721 L
.42524 .2472 L
.42644 .2472 L
.42707 .2472 L
.42777 .2472 L
.42849 .2472 L
.42917 .24721 L
.43042 .24722 L
.43156 .24723 L
.43282 .24724 L
.43414 .24726 L
.43858 .24737 L
.4411 .24744 L
.44344 .24753 L
.45356 .24802 L
.46436 .24875 L
.48427 .2505 L
.49476 .25154 L
.50049 .25212 L
.50329 .2524 L
.50586 .25267 L
.50703 .25279 L
.50831 .25292 L
.50951 .26487 L
.51063 .26487 L
Mistroke
.51576 .26487 L
.52666 .26487 L
.54584 .26487 L
.58502 .26487 L
.62665 .26487 L
.66677 .26487 L
.70538 .26487 L
.74643 .26487 L
.78597 .26487 L
.82399 .26487 L
.86447 .26487 L
.90343 .26487 L
.94485 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool200005c?o01L0I_l200000`1VoaXco`030000N_ooo`00DOooo`<0000?
<ol02P1VoaLco`000`0003?o03?o0002<ol02@1Voa@co`060000M?ooo`00Boooo`H00008<ol02P1V
ob4co`000`0003?o03?o000:<ol000<0I_lco`0co`0063?o00<0001aoooo0011oooo100001@0I_l[
<ol000<0000co`0co`002S?o000306Ko<ol0<ol001/co`0:0000Ioooo`004?ooool0000Aoooo000F
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooool0V@08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo01Goool002coool00`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo
00[oool00ol0VOooooooo`0Loooo00<0003oooooool0:Oooo`030000oooooooo02Woool00`000?oo
ooooo`0Eoooo0024oooo00<0003oooooool02_ooo`03o`2Ioooooooo08coool008Coool00`000?oo
ooooo`0:oooo00?o09Woooooool0S?ooo`00Q?ooo`80000;oooo00?o09Woooooool0S?ooo`00Q?oo
o`030000oooooooo00[oool00ol0VOooooooo`2<oooo0024oooo00<0003oooooool02_ooo`03o`2I
oooooooo08coool008Coool00`000?ooooooo`0:oooo00?o09Woooooool0S?ooo`00Q?ooo`80000;
oooo00?o09Woooooool0S?ooo`00Q?ooo`030000oooooooo00[oool00ol0VOooooooo`2<oooo0024
oooo00<0003oooooool02_ooo`03o`2Ioooooooo08coool008Coool00`000?ooooooo`0:oooo00?o
09Woooooool0S?ooo`00Q?ooo`030000oooooooo00[oool00ol0VOooooooo`2<oooo0024oooo0P00
00_oool00ol0VOooooooo`2<oooo0024oooo00<0003oooooool02_ooo`03o`2Ioooooooo08coool0
08Coool00`000?ooooooo`0:oooo00?o09Woooooool0S?ooo`00Q?ooo`030000oooooooo00[oool0
0ol0VOooooooo`2<oooo0024oooo0P0000_oool00ol0VOooooooo`2<oooo0024oooo00<0003ooooo
ool02_ooo`03o`2Ioooooooo08coool008Coool00`000?ooooooo`0:oooo00?o09Woooooool0S?oo
o`00O?ooo`D00003oooo00<0003oooooool02_ooo`03o`2Ioooooooo08coool007koool00`000?oo
ooooo`03oooo00<0003oooooool02_ooo`03o`2Ioooooooo08coool007koool00`000?ooooooo`03
oooo0`0000[oool00ol0VOooooooo`2<oooo001noooo00<0003oooooool00oooo`030000oooooooo
00[oool00ol0VOooooooo`2<oooo001noooo00<0003oooooool00oooo`030000oooooooo00[oool0
0ol0VOooooooo`2<oooo001moooo0P0000Goool00`000?ooooooo`0:oooo00?o09Woooooool0S?oo
o`00Q?ooo`80000;oooo00?o09Woooooool0S?ooo`00Q?ooo`030000oooooooo00[oool00ol0VOoo
ooooo`2<oooo0024oooo00<0003oooooool02_ooo`03o`2Ioooooooo08coool008Coool00`000?oo
ooooo`0:oooo00?o09Woooooool0S?ooo`00Q?ooo`030000oooooooo00[oool00ol0VOooooooo`2<
oooo0024oooo0P0000_oool00ol0VOooooooo`2<oooo0024oooo00<0003oooooool02_ooo`03o`2I
oooooooo08coool008Coool00`000?ooooooo`0:oooo00?o09Woooooool0S?ooo`00Q?ooo`030000
oooooooo00[oool00ol0VOooooooo`2<oooo0024oooo0P0000_oool00ol0VOooooooo`2<oooo0024
oooo00<0003oooooool02_ooo`03o`2Ioooooooo08coool008Coool00`000?ooooooo`0:oooo00?o
09Woooooool0S?ooo`00Q?ooo`030000oooooooo00[oool00ol0VOooooooo`2<oooo0024oooo00<0
003oooooool02_ooo`03o`2Ioooooooo08coool008Coool200002oooo`03o`2Ioooooooo08coool0
08Coool00`000?ooooooo`0:oooo00?o09Woooooool0S?ooo`00O?ooo`@00004oooo00<0003ooooo
ool02_ooo`03o`2Ioooooooo08coool007coool00`000?ooooooo`05oooo00<0003oooooool02_oo
o`03o`2Ioooooooo08coool007goool00`000?ooooooo`04oooo0`0000[oool00ol0VOooooooo`2<
oooo001noooo00<0003oooooool00oooo`030000oooooooo00[oool00ol0VOooooooo`2<oooo001l
oooo00@0003oooooool00004oooo00<0003oooooool02_ooo`03o`2Ioooooooo08coool007goool2
00001Oooo`030000oooooooo00[oool00ol0VOooooooo`2<oooo0024oooo0P0000_oool00ol0VOoo
ooooo`2<oooo0024oooo00<0003oooooool02_ooo`03o`2Ioooooooo08coool008Coool00`000?oo
ooooo`0:oooo00?o09Woooooool0S?ooo`00Q?ooo`030000oooooooo00[oool00ol0VOooooooo`2<
oooo0024oooo00<0003oooooool02_ooo`03o`2Ioooooooo08coool008Coool200002oooo`03o`2I
oooooooo08coool008Coool00`000?ooooooo`0:oooo00?o09Woooooool0S?ooo`00Q?ooo`030000
oooooooo00[oool00ol0VOooooooo`2<oooo0024oooo00<0003oooooool02_ooo`03o`2Ioooooooo
08coool008Coool200002oooo`03o`2Ioooooooo08coool008Coool00`000?ooooooo`0:oooo00?o
09Woooooool0S?ooo`00Q?ooo`030000oooooooo00[oool00ol0VOooooooo`2<oooo0024oooo00<0
003oooooool02_ooo`03o`2Ioooooooo08coool008Coool00`000?ooooooo`0:oooo00?o09Wooooo
ool0S?ooo`00Q?ooo`80000;oooo00?o09Woooooool0S?ooo`00Q?ooo`030000oooooooo00[oool0
0ol0VOooooooo`2<oooo001moooo0P0000Goool00`000?ooooooo`0:oooo00?o09Woooooool0S?oo
o`00O?ooo`040000oooooooo00001?ooo`030000oooooooo00[oool00ol0VOooooooo`2<oooo001n
oooo00<0003oooooool00oooo`<0000:oooo00?o09Woooooool0S?ooo`00Ooooo`030000oooooooo
00;oool00`000?ooooooo`0:oooo00?o09Woooooool0S?ooo`00O?ooo`040000oooooooo00001?oo
o`030000oooooooo00[oool00ol0VOooooooo`2<oooo001moooo0P0000Goool00`000?ooooooo`0:
oooo00?o09Woooooool0S?ooo`00Q?ooo`030000oooooooo00[oool00ol0VOooooooo`2<oooo0024
oooo0P0000_oool00ol0VOooooooo`2<oooo0024oooo00<0003oooooool02_ooo`03o`2Ioooooooo
08coool008Coool00`000?ooooooo`0:oooo00?o09Woooooool0S?ooo`00Q?ooo`030000oooooooo
00[oool00ol0VOooooooo`2<oooo0024oooo0P0000_oool00ol0VOooooooo`2<oooo0024oooo00<0
003oooooool02_ooo`03o`2Ioooooooo08coool008Coool00`000?ooooooo`0:oooo00?o09Wooooo
ool0S?ooo`00Q?ooo`030000oooooooo00[oool00ol0VOooooooo`2<oooo0024oooo00<0003ooooo
ool02_ooo`03o`2Ioooooooo08coool008Coool200002oooo`03o`2Ioooooooo08coool008Coool0
0`000?ooooooo`0:oooo00?o09Woooooool0S?ooo`00Q?ooo`030000oooooooo00[oool00ol0VOoo
ooooo`2<oooo0024oooo00<0003oooooool02_ooo`03o`2Ioooooooo08coool008Coool200002ooo
o`03o`2Ioooooooo08coool008Coool00`000?ooooooo`0:oooo00?o09Woooooool0S?ooo`00Q?oo
o`030000oooooooo00[oool00ol0VOooooooo`2<oooo001noooo0`0000?oool00`000?ooooooo`0:
oooo00?o09Woooooool0S?ooo`00Ooooo`030000oooooooo00;oool00`000?ooooooo`0:oooo00?o
09Woooooool0S?ooo`00O?ooo`D00003oooo0`0000[oool00ol0VOooooooo`2<oooo001loooo00@0
003oooooool0002Poooo001moooo00<0003oool00000X?ooo`00O_ooo`80002Poooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800005oooo0`0000;oool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`04oooo100000?oool010000?ooooooo`0000_oool01@000?ooooooooooo`00001joooo001g
oooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Soool500000ooo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500004_ooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000E
oooo00@0003oooooool00009oooo00<0003oool000000oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Goooo0P0000_oool200000_ooo`030000oooooooo07Woool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.5095 .26487 L
.51896 .26487 L
.52148 .26487 L
.52417 .26487 L
.52497 .26487 L
.52572 .26487 L
s
.52572 .26487 m
.52599 .61803 L
s
0 .4 1 r
.02381 .26471 m
.04262 .26467 L
.06244 .26461 L
.08255 .26455 L
.10458 .26445 L
.12415 .26435 L
.14509 .2642 L
.16639 .26402 L
.18653 .26379 L
.22495 .2632 L
.24479 .26278 L
.26581 .26223 L
.30365 .26092 L
.34394 .25907 L
.38271 .25722 L
.39281 .25683 L
.39815 .25666 L
.40384 .2565 L
.40931 .25638 L
.41426 .2563 L
.41665 .25627 L
.41924 .25624 L
.42043 .25623 L
.42169 .25622 L
.42276 .25622 L
.42393 .25621 L
.42524 .25621 L
.42644 .25621 L
.42707 .25621 L
.42777 .25621 L
.42849 .25621 L
.42917 .25621 L
.43042 .25622 L
.43156 .25622 L
.43282 .25623 L
.43414 .25624 L
.43858 .25629 L
.4411 .25633 L
.44344 .25637 L
.45356 .25661 L
.46436 .25697 L
.48427 .25783 L
.49476 .25833 L
.50586 .25889 L
.51576 .25938 L
.51848 .25951 L
.52139 .25965 L
.5228 .25972 L
.52414 .25979 L
.52535 .25984 L
Mistroke
.52666 .26487 L
.52796 .26487 L
.52919 .26487 L
.53148 .26487 L
.53661 .26487 L
.54584 .26487 L
.58444 .26487 L
.6255 .26487 L
.66504 .26487 L
.70306 .26487 L
.74354 .26487 L
.7825 .26487 L
.82391 .26487 L
.86381 .26487 L
.90219 .26487 L
.94302 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000L<ol05`1Vo`03000006Ko06Ko00H0I_lO<ol00`00
077oool0047oool:00003S?o01@0I_lG<ol000<0000co`0co`001S?o00T0I_lI<ol02P0006Ooool0
013ooooo00004Oooo`005_ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool00oooo`03o`2Ioooooooo00;oool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool05Oooo`00;?ooo`030000oooooooo
02Woool00`000?ooooooo`0Yoooo00<0003oooooool03_ooo`03o`2Ioooooooo01Soool00`000?oo
ooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo01Goool008Coool00`000?ooooooo`0>
oooo00?o09Woooooool0R?ooo`00Q?ooo`030000oooooooo00koool00ol0VOooooooo`28oooo0024
oooo0P0000ooool00ol0VOooooooo`28oooo0024oooo00<0003oooooool03_ooo`03o`2Ioooooooo
08Soool008Coool00`000?ooooooo`0>oooo00?o09Woooooool0R?ooo`00Q?ooo`030000oooooooo
00koool00ol0VOooooooo`28oooo0024oooo0P0000ooool00ol0VOooooooo`28oooo0024oooo00<0
003oooooool03_ooo`03o`2Ioooooooo08Soool008Coool00`000?ooooooo`0>oooo00?o09Wooooo
ool0R?ooo`00Q?ooo`030000oooooooo00koool00ol0VOooooooo`28oooo0024oooo00<0003ooooo
ool03_ooo`03o`2Ioooooooo08Soool008Coool200003oooo`03o`2Ioooooooo08Soool008Coool0
0`000?ooooooo`0>oooo00?o09Woooooool0R?ooo`00Q?ooo`030000oooooooo00koool00ol0VOoo
ooooo`28oooo0024oooo00<0003oooooool03_ooo`03o`2Ioooooooo08Soool008Coool200003ooo
o`03o`2Ioooooooo08Soool008Coool00`000?ooooooo`0>oooo00?o09Woooooool0R?ooo`00Q?oo
o`030000oooooooo00koool00ol0VOooooooo`28oooo001loooo1@0000?oool00`000?ooooooo`0>
oooo00?o09Woooooool0R?ooo`00O_ooo`030000oooooooo00?oool00`000?ooooooo`0>oooo00?o
09Woooooool0R?ooo`00O_ooo`030000oooooooo00?oool300003_ooo`03o`2Ioooooooo08Soool0
07koool00`000?ooooooo`03oooo00<0003oooooool03_ooo`03o`2Ioooooooo08Soool007koool0
0`000?ooooooo`03oooo00<0003oooooool03_ooo`03o`2Ioooooooo08Soool007goool200001Ooo
o`030000oooooooo00koool00ol0VOooooooo`28oooo0024oooo0P0000ooool00ol0VOooooooo`28
oooo0024oooo00<0003oooooool03_ooo`03o`2Ioooooooo08Soool008Coool00`000?ooooooo`0>
oooo00?o09Woooooool0R?ooo`00Q?ooo`030000oooooooo00koool00ol0VOooooooo`28oooo0024
oooo00<0003oooooool03_ooo`03o`2Ioooooooo08Soool008Coool200003oooo`03o`2Ioooooooo
08Soool008Coool00`000?ooooooo`0>oooo00?o09Woooooool0R?ooo`00Q?ooo`030000oooooooo
00koool00ol0VOooooooo`28oooo0024oooo00<0003oooooool03_ooo`03o`2Ioooooooo08Soool0
08Coool200003oooo`03o`2Ioooooooo08Soool008Coool00`000?ooooooo`0>oooo00?o09Wooooo
ool0R?ooo`00Q?ooo`030000oooooooo00koool00ol0VOooooooo`28oooo0024oooo00<0003ooooo
ool03_ooo`03o`2Ioooooooo08Soool008Coool00`000?ooooooo`0>oooo00?o09Woooooool0R?oo
o`00Q?ooo`80000?oooo00?o09Woooooool0R?ooo`00Q?ooo`030000oooooooo00koool00ol0VOoo
ooooo`28oooo001loooo100000Coool00`000?ooooooo`0>oooo00?o09Woooooool0R?ooo`00O?oo
o`030000oooooooo00Goool00`000?ooooooo`0>oooo00?o09Woooooool0R?ooo`00OOooo`030000
oooooooo00Coool300003_ooo`03o`2Ioooooooo08Soool007koool00`000?ooooooo`03oooo00<0
003oooooool03oooo`03o`2Ioooooooo08Ooool007coool010000?ooooooo`0000Coool00`000?oo
ooooo`0?oooo00?o09Woooooool0Qoooo`00OOooo`800005oooo00<0003oooooool03oooo`03o`2I
oooooooo08Ooool008Coool200004?ooo`03o`2Ioooooooo08Ooool008Coool00`000?ooooooo`0?
oooo00?o09Woooooool0Qoooo`00Q?ooo`030000oooooooo00ooool00ol0VOooooooo`27oooo0024
oooo00<0003oooooool03oooo`03o`2Ioooooooo08Ooool008Coool00`000?ooooooo`0?oooo00?o
09Woooooool0Qoooo`00Q?ooo`80000@oooo00?o09Woooooool0Qoooo`00Q?ooo`030000oooooooo
00ooool00ol0VOooooooo`27oooo0024oooo00<0003oooooool03oooo`03o`2Ioooooooo08Ooool0
08Coool00`000?ooooooo`0?oooo00?o09Woooooool0Qoooo`00Q?ooo`80000@oooo00?o09Wooooo
ool0Qoooo`00Q?ooo`030000oooooooo00ooool00ol0VOooooooo`27oooo0024oooo00<0003ooooo
ool03oooo`03o`2Ioooooooo08Ooool008Coool00`000?ooooooo`0?oooo00?o09Woooooool0Qooo
o`00Q?ooo`030000oooooooo00ooool00ol0VOooooooo`27oooo0024oooo0P00013oool00ol0VOoo
ooooo`27oooo0024oooo00<0003oooooool03oooo`03o`2Ioooooooo08Ooool007goool200001Ooo
o`030000oooooooo00ooool00ol0VOooooooo`27oooo001loooo00@0003oooooool00004oooo00<0
003oooooool03oooo`03o`2Ioooooooo08Ooool007koool00`000?ooooooo`03oooo0`0000ooool0
0ol0VOooooooo`27oooo001ooooo00<0003oooooool00_ooo`030000oooooooo00ooool00ol0VOoo
ooooo`27oooo001loooo00@0003oooooool00004oooo00<0003oooooool03oooo`03o`2Ioooooooo
08Ooool007goool200001Oooo`030000oooooooo00ooool00ol0VOooooooo`27oooo0024oooo00<0
003oooooool03oooo`03o`2Ioooooooo08Ooool008Coool200004?ooo`03o`2Ioooooooo08Ooool0
08Coool00`000?ooooooo`0?oooo00?o09Woooooool0Qoooo`00Q?ooo`030000oooooooo00ooool0
0ol0VOooooooo`27oooo0024oooo00<0003oooooool03oooo`03o`2Ioooooooo08Ooool008Coool2
00004?ooo`03o`2Ioooooooo08Ooool008Coool00`000?ooooooo`0?oooo00?o09Woooooool0Qooo
o`00Q?ooo`030000oooooooo00ooool00ol0VOooooooo`27oooo0024oooo00<0003oooooool03ooo
o`03o`2Ioooooooo08Ooool008Coool00`000?ooooooo`0?oooo00?o09Woooooool0Qoooo`00Q?oo
o`80000@oooo00?o09Woooooool0Qoooo`00Q?ooo`030000oooooooo00ooool00ol0VOooooooo`27
oooo0024oooo00<0003oooooool03oooo`03o`2Ioooooooo08Ooool008Coool00`000?ooooooo`0?
oooo00?o09Woooooool0Qoooo`00Q?ooo`80000@oooo00?o09Woooooool0Qoooo`00Q?ooo`030000
oooooooo00ooool00ol0VOooooooo`27oooo0024oooo00<0003oooooool03oooo`03o`2Ioooooooo
08Ooool007koool300000oooo`030000oooooooo00ooool00ol0VOooooooo`27oooo001ooooo00<0
003oooooool00_ooo`030000oooooooo00ooool00ol0VOooooooo`27oooo001loooo1@0000?oool3
00003oooo`03o`2Ioooooooo08Ooool007coool010000?ooooooo`000:3oool007goool00`000?oo
o`00002Poooo001noooo0P000:3oool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Ooo
o`800004oooo0P0000?oool400000oooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo
00002?ooo`030000oooooooo00Coool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_oo
o`030000oooooooo01?oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000Boooo00@0003oooooool0000:oooo00<0003ooooo
ool00_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Eoooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo
01Ooool200002_ooo`800003oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.52059 .26487 L
.53057 .26487 L
.53543 .26487 L
.53984 .26487 L
.54098 .26487 L
.54221 .26487 L
s
.54221 .26487 m
.54267 .61803 L
s
0 .4 1 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.69774 .26487 L
.73838 .26487 L
.77751 .26487 L
.81909 .26487 L
.85916 .26487 L
.89771 .26487 L
.93871 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo0011
oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0E
oooo000/oooo00<0003oooooool0:Oooo`030000oooooooo02Woool00`000?ooooooo`0Coooo00?o
09Woooooool04oooo`030000oooooooo02Woool00`000?ooooooo`0Yoooo00<0003oooooool05Ooo
o`00Q?ooo`030000oooooooo01?oool00ol0VOooooooo`23oooo0024oooo00<0003oooooool04ooo
o`03o`2Ioooooooo08?oool008Coool200005?ooo`03o`2Ioooooooo08?oool008Coool00`000?oo
ooooo`0Coooo00?o09Woooooool0Poooo`00Q?ooo`030000oooooooo01?oool00ol0VOooooooo`23
oooo0024oooo00<0003oooooool04oooo`03o`2Ioooooooo08?oool008Coool200005?ooo`03o`2I
oooooooo08?oool008Coool00`000?ooooooo`0Coooo00?o09Woooooool0Poooo`00Q?ooo`030000
oooooooo01?oool00ol0VOooooooo`23oooo0024oooo00<0003oooooool04oooo`03o`2Ioooooooo
08?oool008Coool00`000?ooooooo`0Coooo00?o09Woooooool0Poooo`00Q?ooo`80000Doooo00?o
09Woooooool0Poooo`00Q?ooo`030000oooooooo01?oool00ol0VOooooooo`23oooo0024oooo00<0
003oooooool04oooo`03o`2Ioooooooo08?oool008Coool00`000?ooooooo`0Coooo00?o09Wooooo
ool0Poooo`00Q?ooo`80000Doooo00?o09Woooooool0Poooo`00Q?ooo`030000oooooooo01?oool0
0ol0VOooooooo`23oooo0024oooo00<0003oooooool04oooo`03o`2Ioooooooo08?oool007coool5
00000oooo`030000oooooooo01?oool00ol0VOooooooo`23oooo001noooo00<0003oooooool00ooo
o`030000oooooooo01?oool00ol0VOooooooo`23oooo001noooo00<0003oooooool00oooo`<0000C
oooo00?o09Woooooool0Poooo`00O_ooo`030000oooooooo00?oool00`000?ooooooo`0Coooo00?o
09Woooooool0Poooo`00O_ooo`030000oooooooo00?oool00`000?ooooooo`0Coooo00?o09Wooooo
ool0Poooo`00OOooo`800005oooo00<0003oooooool04oooo`03o`2Ioooooooo08?oool008Coool2
00005?ooo`03o`2Ioooooooo08?oool008Coool00`000?ooooooo`0Coooo00?o09Woooooool0Pooo
o`00Q?ooo`030000oooooooo01?oool00ol0VOooooooo`23oooo0024oooo00<0003oooooool04ooo
o`03o`2Ioooooooo08?oool008Coool00`000?ooooooo`0Coooo00?o09Woooooool0Poooo`00Q?oo
o`80000Doooo00?o09Woooooool0Poooo`00Q?ooo`030000oooooooo01?oool00ol0VOooooooo`23
oooo0024oooo00<0003oooooool04oooo`03o`2Ioooooooo08?oool008Coool00`000?ooooooo`0C
oooo00?o09Woooooool0Poooo`00Q?ooo`80000Doooo00?o09Woooooool0Poooo`00Q?ooo`030000
oooooooo01?oool00ol0VOooooooo`23oooo0024oooo00<0003oooooool04oooo`03o`2Ioooooooo
08?oool008Coool00`000?ooooooo`0Coooo00?o09Woooooool0Poooo`00Q?ooo`030000oooooooo
01?oool00ol0VOooooooo`23oooo0024oooo0P0001Coool00ol0VOooooooo`23oooo0024oooo00<0
003oooooool04oooo`03o`2Ioooooooo08?oool007coool400001?ooo`030000oooooooo01?oool0
0ol0VOooooooo`23oooo001loooo00<0003oooooool01Oooo`030000oooooooo01?oool00ol0VOoo
ooooo`23oooo001moooo00<0003oooooool01?ooo`<0000Coooo00?o09Woooooool0Poooo`00O_oo
o`030000oooooooo00?oool00`000?ooooooo`0Coooo00?o09Woooooool0Poooo`00O?ooo`040000
oooooooo00001?ooo`030000oooooooo01?oool00ol0VOooooooo`23oooo001moooo0P0000Goool0
0`000?ooooooo`0Coooo00?o09Woooooool0Poooo`00Q?ooo`80000Doooo00?o09Woooooool0Pooo
o`00Q?ooo`030000oooooooo01?oool00ol0VOooooooo`23oooo0024oooo00<0003oooooool04ooo
o`03o`2Ioooooooo08?oool008Coool00`000?ooooooo`0Coooo00?o09Woooooool0Poooo`00Q?oo
o`030000oooooooo01?oool00ol0VOooooooo`23oooo0024oooo0P0001Coool00ol0VOooooooo`23
oooo0024oooo00<0003oooooool04oooo`03o`2Ioooooooo08?oool008Coool00`000?ooooooo`0C
oooo00?o09Woooooool0Poooo`00Q?ooo`030000oooooooo01?oool00ol0VOooooooo`23oooo0024
oooo0P0001Coool00ol0VOooooooo`23oooo0024oooo00<0003oooooool04oooo`03o`2Ioooooooo
08?oool008Coool00`000?ooooooo`0Coooo00?o09Woooooool0Poooo`00Q?ooo`030000oooooooo
01?oool00ol0VOooooooo`23oooo0024oooo00<0003oooooool04oooo`03o`2Ioooooooo08?oool0
08Coool200005?ooo`03o`2Ioooooooo08?oool008Coool00`000?ooooooo`0Coooo00?o09Wooooo
ool0Poooo`00OOooo`800005oooo00<0003oooooool04oooo`03o`2Ioooooooo08?oool007coool0
10000?ooooooo`0000Coool00`000?ooooooo`0Coooo00?o09Woooooool0Poooo`00O_ooo`030000
oooooooo00?oool300004oooo`03o`2Ioooooooo08?oool007ooool00`000?ooooooo`02oooo00<0
003oooooool04oooo`03o`2Ioooooooo08?oool007coool010000?ooooooo`0000Coool00`000?oo
ooooo`0Coooo00?o09Woooooool0Poooo`00OOooo`800005oooo00<0003oooooool04oooo`03o`2I
oooooooo08?oool008Coool00`000?ooooooo`0Coooo00?o09Woooooool0Poooo`00Q?ooo`80000D
oooo00?o09Woooooool0Poooo`00Q?ooo`030000oooooooo01?oool00ol0VOooooooo`23oooo0024
oooo00<0003oooooool04oooo`03o`2Ioooooooo08?oool008Coool00`000?ooooooo`0Coooo00?o
09Woooooool0Poooo`00Q?ooo`80000Doooo00?o09Woooooool0Poooo`00Q?ooo`030000oooooooo
01?oool00ol0VOooooooo`23oooo0024oooo00<0003oooooool04oooo`03o`2Ioooooooo08?oool0
08Coool00`000?ooooooo`0Coooo00?o09Woooooool0Poooo`00Q?ooo`030000oooooooo01?oool0
0ol0VOooooooo`23oooo0024oooo0P0001Coool00ol0VOooooooo`23oooo0024oooo00<0003ooooo
ool04oooo`03o`2Ioooooooo08?oool008Coool00`000?ooooooo`0Coooo00?o09Woooooool0Pooo
o`00Q?ooo`030000oooooooo01?oool00ol0VOooooooo`23oooo0024oooo0P0001Coool00ol0VOoo
ooooo`23oooo0024oooo00<0003oooooool04oooo`03o`2Ioooooooo08?oool008Coool00`000?oo
ooooo`0Coooo00?o09Woooooool0Poooo`00O_ooo`<00003oooo00<0003oooooool04oooo`03o`2I
oooooooo08?oool007ooool00`000?ooooooo`02oooo00<0003oooooool04oooo`03o`2Ioooooooo
08?oool007coool500000oooo`<0000Coooo00?o09Woooooool0Poooo`00O?ooo`040000oooooooo
0000X?ooo`00OOooo`030000oooo00000:3oool007koool20000X?ooo`00ooooob7oool00?oooolQ
oooo001ooooo00<0003oooooool07?ooo`030000oooooooo07ooool007koool00`000?ooooooo`08
oooo00<0003oooooool04oooo`030000oooooooo07koool007koool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`030000oooooooo07koool007koool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?oo
ooooo`0000Woool00`000?ooooooo`1noooo001moooo00<0003oooooool00_ooo`030000oooooooo
00goool010000?ooooooo`0000[oool00`000?ooooooo`1moooo001noooo00<0003oooooool01@00
00coool010000?ooooooo`0000Woool00`000?ooooooo`1noooo001noooo00D0003oooooooooool0
00003oooo`040000oooooooo00002Oooo`030000oooooooo07koool007ooool00`000?ooooooo`0A
oooo0P0000Woool00`000?ooooooo`1ooooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.52059 .26487 L
.53984 .26487 L
.54934 .26487 L
.55436 .26487 L
.55712 .26487 L
.55847 .26487 L
.55972 .26487 L
s
.55972 .26487 m
.5602 .61803 L
s
0 .4 1 r
.02381 .26504 m
.04262 .26508 L
.06244 .26513 L
.08255 .2652 L
.10458 .26529 L
.12415 .2654 L
.14509 .26554 L
.16639 .26573 L
.18653 .26595 L
.22495 .26654 L
.24479 .26696 L
.26581 .26751 L
.30365 .26882 L
.34394 .27067 L
.38271 .27252 L
.39281 .27291 L
.39815 .27308 L
.40384 .27324 L
.40931 .27336 L
.41426 .27345 L
.41665 .27348 L
.41924 .2735 L
.42043 .27351 L
.42169 .27352 L
.42276 .27352 L
.42393 .27353 L
.42524 .27353 L
.42644 .27353 L
.42707 .27353 L
.42777 .27353 L
.42849 .27353 L
.42917 .27353 L
.43042 .27353 L
.43156 .27352 L
.43282 .27351 L
.43414 .2735 L
.43858 .27345 L
.4411 .27342 L
.44344 .27337 L
.45356 .27313 L
.46436 .27277 L
.50586 .27085 L
.52666 .26984 L
.53579 .26942 L
.54584 .26899 L
.55049 .26879 L
.55549 .2686 L
.55791 .2685 L
.5591 .26846 L
.56021 .26842 L
Mistroke
.56121 .26487 L
.56227 .26487 L
.56452 .26487 L
.5843 .26487 L
.62594 .26487 L
.66606 .26487 L
.70466 .26487 L
.74572 .26487 L
.78526 .26487 L
.82328 .26487 L
.86376 .26487 L
.90272 .26487 L
.94413 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo0011
oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooo`1Vo`0806Ko00<00000I_l0I_l0201Vo`03000006Ko06Ko00L0I_l00oooo`000?ooo`09
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool00_ooo`H0I_l00`00001Vo`1Vo`0206Ko1_ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo01Goool002coool00`000?ooooooo`0Yoooo00<0003oooooool01oooob80I_l00`00001V
o`1Vo`0=06Ko2_ooo`03o`2Ioooooooo00ooool00`000?ooooooo`0Yoooo00<0003oooooool0:Ooo
o`030000oooooooo01Goool008Coool00`000?ooooooo`0Goooo00?o09Woooooool0Ooooo`00Q?oo
o`030000oooooooo01Ooool00ol0VOooooooo`1ooooo0024oooo0P0001Soool00ol0VOooooooo`1o
oooo0024oooo00<0003oooooool05oooo`03o`2Ioooooooo07ooool008Coool00`000?ooooooo`0G
oooo00?o09Woooooool0Ooooo`00Q?ooo`030000oooooooo01Ooool00ol0VOooooooo`1ooooo0024
oooo0P0001Soool00ol0VOooooooo`1ooooo0024oooo00<0003oooooool05oooo`03o`2Ioooooooo
07ooool008Coool00`000?ooooooo`0Goooo00?o09Woooooool0Ooooo`00Q?ooo`030000oooooooo
01Ooool00ol0VOooooooo`1ooooo0024oooo00<0003oooooool05oooo`03o`2Ioooooooo07ooool0
08Coool200006?ooo`03o`2Ioooooooo07ooool008Coool00`000?ooooooo`0Goooo00?o09Wooooo
ool0Ooooo`00Q?ooo`030000oooooooo01Ooool00ol0VOooooooo`1ooooo0024oooo00<0003ooooo
ool05oooo`03o`2Ioooooooo07ooool008Coool200006?ooo`03o`2Ioooooooo07ooool008Coool0
0`000?ooooooo`0Goooo00?o09Woooooool0Ooooo`00Q?ooo`030000oooooooo01Ooool00ol0VOoo
ooooo`1ooooo001loooo1@0000?oool00`000?ooooooo`0Goooo00?o09Woooooool0Ooooo`00O_oo
o`030000oooooooo00?oool00`000?ooooooo`0Goooo00?o09Woooooool0Ooooo`00O_ooo`030000
oooooooo00?oool300005oooo`03o`2Ioooooooo07ooool007koool00`000?ooooooo`03oooo00<0
003oooooool05oooo`03o`2Ioooooooo07ooool007koool00`000?ooooooo`03oooo00<0003ooooo
ool05oooo`03o`2Ioooooooo07ooool007goool200001Oooo`030000oooooooo01Ooool00ol0VOoo
ooooo`1ooooo0024oooo0P0001Soool00ol0VOooooooo`1ooooo0024oooo00<0003oooooool05ooo
o`03o`2Ioooooooo07ooool008Coool00`000?ooooooo`0Goooo00?o09Woooooool0Ooooo`00Q?oo
o`030000oooooooo01Ooool00ol0VOooooooo`1ooooo0024oooo00<0003oooooool05oooo`03o`2I
oooooooo07ooool008Coool200006?ooo`03o`2Ioooooooo07ooool008Coool00`000?ooooooo`0G
oooo00?o09Woooooool0Ooooo`00Q?ooo`030000oooooooo01Ooool00ol0VOooooooo`1ooooo0024
oooo00<0003oooooool05oooo`03o`2Ioooooooo07ooool008Coool200006?ooo`03o`2Ioooooooo
07ooool008Coool00`000?ooooooo`0Goooo00?o09Woooooool0Ooooo`00Q?ooo`030000oooooooo
01Ooool00ol0VOooooooo`1ooooo0024oooo00<0003oooooool05oooo`03o`2Ioooooooo07ooool0
08Coool00`000?ooooooo`0Goooo00?o09Woooooool0Ooooo`00Q?ooo`80000Hoooo00?o09Wooooo
ool0Ooooo`00Q?ooo`030000oooooooo01Ooool00ol0VOooooooo`1ooooo001loooo100000Coool0
0`000?ooooooo`0Goooo00?o09Woooooool0Ooooo`00O?ooo`030000oooooooo00Goool00`000?oo
ooooo`0Goooo00?o09Woooooool0Ooooo`00OOooo`030000oooooooo00Coool300005oooo`03o`2I
oooooooo07ooool007koool00`000?ooooooo`03oooo00<0003oooooool05oooo`03o`2Ioooooooo
07ooool007coool010000?ooooooo`0000Coool00`000?ooooooo`0Goooo00?o09Woooooool0Oooo
o`00OOooo`800005oooo00<0003oooooool05oooo`03o`2Ioooooooo07ooool008Coool200006?oo
o`03o`2Ioooooooo07ooool008Coool00`000?ooooooo`0Goooo00?o09Woooooool0Ooooo`00Q?oo
o`030000oooooooo01Ooool00ol0VOooooooo`1ooooo0024oooo00<0003oooooool05oooo`03o`2I
oooooooo07ooool008Coool00`000?ooooooo`0Goooo00?o09Woooooool0Ooooo`00Q?ooo`80000H
oooo00?o09Woooooool0Ooooo`00Q?ooo`030000oooooooo01Ooool00ol0VOooooooo`1ooooo0024
oooo00<0003oooooool05oooo`03o`2Ioooooooo07ooool008Coool00`000?ooooooo`0Goooo00?o
09Woooooool0Ooooo`00Q?ooo`80000Hoooo00?o09Woooooool0Ooooo`00Q?ooo`030000oooooooo
01Ooool00ol0VOooooooo`1ooooo0024oooo00<0003oooooool05oooo`03o`2Ioooooooo07ooool0
08Coool00`000?ooooooo`0Goooo00?o09Woooooool0Ooooo`00Q?ooo`030000oooooooo01Ooool0
0ol0VOooooooo`1ooooo0024oooo0P0001Soool00ol0VOooooooo`1ooooo0024oooo00<0003ooooo
ool05oooo`03o`2Ioooooooo07ooool007goool200001Oooo`030000oooooooo01Ooool00ol0VOoo
ooooo`1ooooo001loooo00@0003oooooool00004oooo00<0003oooooool05oooo`03o`2Ioooooooo
07ooool007koool00`000?ooooooo`03oooo0`0001Ooool00ol0VOooooooo`1ooooo001ooooo00<0
003oooooool00_ooo`030000oooooooo01Ooool00ol0VOooooooo`1ooooo001loooo00@0003ooooo
ool00004oooo00<0003oooooool05oooo`03o`2Ioooooooo07ooool007goool200001Oooo`030000
oooooooo01Ooool00ol0VOooooooo`1ooooo0024oooo00<0003oooooool05oooo`03o`2Ioooooooo
07ooool008Coool200006?ooo`03o`2Ioooooooo07ooool008Coool00`000?ooooooo`0Goooo00?o
09Woooooool0Ooooo`00Q?ooo`030000oooooooo01Ooool00ol0VOooooooo`1ooooo0024oooo00<0
003oooooool05oooo`03o`2Ioooooooo07ooool008Coool200006?ooo`03o`2Ioooooooo07ooool0
08Coool00`000?ooooooo`0Goooo00?o09Woooooool0Ooooo`00Q?ooo`030000oooooooo01Ooool0
0ol0VOooooooo`1ooooo0024oooo00<0003oooooool05oooo`03o`2Ioooooooo07ooool008Coool0
0`000?ooooooo`0Goooo00?o09Woooooool0Ooooo`00Q?ooo`80000Hoooo00?o09Woooooool0Oooo
o`00Q?ooo`030000oooooooo01Ooool00ol0VOooooooo`1ooooo0024oooo00<0003oooooool05ooo
o`03o`2Ioooooooo07ooool008Coool00`000?ooooooo`0Goooo00?o09Woooooool0Ooooo`00Q?oo
o`80000Hoooo00?o09Woooooool0Ooooo`00Q?ooo`030000oooooooo01Ooool00ol0VOooooooo`1o
oooo0024oooo00<0003oooooool05oooo`03o`2Ioooooooo07ooool007koool300000oooo`030000
oooooooo01Ooool00ol0VOooooooo`1ooooo001ooooo00<0003oooooool00_ooo`030000oooooooo
01Ooool00ol0VOooooooo`1ooooo001loooo1@0000?oool300005oooo`03o`2Ioooooooo07ooool0
07coool010000?ooooooo`000:3oool007goool00`000?ooo`00002Poooo001noooo0P000:3oool0
0?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001k
oooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000?oool400000ooo
o`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool010000?ooooooo`0000Soool00`000?ooooooo`04oooo00<0003ooooo
ool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00009
oooo00<0003oooooool01?ooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003?oo
o`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`1koooo001koooo00D0
003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000oooooooo
07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.52059 .26487 L
.53984 .26487 L
.54934 .26487 L
.55972 .26487 L
.56446 .26487 L
.56951 .26487 L
.57197 .26487 L
.57429 .26487 L
.57636 .26487 L
.57753 .26487 L
s
.57753 .26487 m
.57796 .61803 L
s
0 .4 1 r
.02381 .26521 m
.04262 .26529 L
.06244 .2654 L
.08255 .26554 L
.10458 .26573 L
.12415 .26594 L
.14509 .26624 L
.16639 .26662 L
.18653 .26707 L
.22495 .26828 L
.24479 .26913 L
.26581 .27025 L
.30365 .27293 L
.34394 .27671 L
.38271 .28048 L
.39281 .28127 L
.39815 .28162 L
.40384 .28194 L
.40931 .28219 L
.41426 .28236 L
.41665 .28243 L
.41924 .28248 L
.42043 .2825 L
.42169 .28251 L
.42276 .28253 L
.42393 .28253 L
.42524 .28254 L
.42644 .28254 L
.42707 .28254 L
.42777 .28254 L
.42849 .28254 L
.42917 .28254 L
.43042 .28253 L
.43156 .28252 L
.43282 .2825 L
.43414 .28248 L
.43858 .28238 L
.4411 .2823 L
.44344 .28222 L
.45356 .28173 L
.46436 .28099 L
.50586 .27708 L
.52666 .27501 L
.54584 .27326 L
.56452 .27178 L
.56906 .27145 L
.57394 .27112 L
.57538 .27102 L
.57608 .27097 L
.57674 .27093 L
Mistroke
.57796 .26487 L
.57861 .26487 L
.5793 .26487 L
.5843 .26487 L
.62594 .26487 L
.66606 .26487 L
.70466 .26487 L
.74572 .26487 L
.78526 .26487 L
.82328 .26487 L
.86376 .26487 L
.90272 .26487 L
.94413 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo0011
oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool01?ooo`@0I_l00`00001Vo`1Vo`08
06Ko00<00000I_l0I_l0201Vo`04000006Ko06Ko06Ko1oooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool02?ooo`030000oooooooo00Goool0101Vool0VOooo`0000[oool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo01Goool002coool00`000?ooooooo`0Roooo1`1Vo`03000006Ko06Ko00L0I_lRoooo00<0
003oooooool04_ooo`X0I_l00ol0VOooooooo`0:oooo00<0003oooooool0:Oooo`030000oooooooo
02Woool00`000?ooooooo`0Eoooo001Roooo2P1VoaSoool00`000?ooooooo`05oooo3@1Vo`[oool0
0ol0VOooooooo`1joooo001/oooo2P1Vo`goool00`1Vo`00001Vo`0606Ko5oooo`03o`2Ioooooooo
07[oool007Koool=06Ko00?oool0000000007Oooo`03o`2Ioooooooo07[oool008Coool00`000?oo
ooooo`0Loooo00?o09Woooooool0N_ooo`00Q?ooo`030000oooooooo01coool00ol0VOooooooo`1j
oooo0024oooo00<0003oooooool07?ooo`03o`2Ioooooooo07[oool008Coool200007Oooo`03o`2I
oooooooo07[oool008Coool00`000?ooooooo`0Loooo00?o09Woooooool0N_ooo`00Q?ooo`030000
oooooooo01coool00ol0VOooooooo`1joooo0024oooo00<0003oooooool07?ooo`03o`2Ioooooooo
07[oool008Coool00`000?ooooooo`0Loooo00?o09Woooooool0N_ooo`00Q?ooo`80000Moooo00?o
09Woooooool0N_ooo`00Q?ooo`030000oooooooo01coool00ol0VOooooooo`1joooo0024oooo00<0
003oooooool07?ooo`03o`2Ioooooooo07[oool008Coool00`000?ooooooo`0Loooo00?o09Wooooo
ool0N_ooo`00Q?ooo`80000Moooo00?o09Woooooool0N_ooo`00Q?ooo`030000oooooooo01coool0
0ol0VOooooooo`1joooo0024oooo00<0003oooooool07?ooo`03o`2Ioooooooo07[oool007coool5
00000oooo`030000oooooooo01coool00ol0VOooooooo`1joooo001noooo00<0003oooooool00ooo
o`030000oooooooo01coool00ol0VOooooooo`1joooo001noooo00<0003oooooool00oooo`<0000L
oooo00?o09Woooooool0N_ooo`00O_ooo`030000oooooooo00?oool00`000?ooooooo`0Loooo00?o
09Woooooool0N_ooo`00O_ooo`030000oooooooo00?oool00`000?ooooooo`0Loooo00?o09Wooooo
ool0N_ooo`00OOooo`800005oooo00<0003oooooool07?ooo`03o`2Ioooooooo07[oool008Coool2
00007Oooo`03o`2Ioooooooo07[oool008Coool00`000?ooooooo`0Loooo00?o09Woooooool0N_oo
o`00Q?ooo`030000oooooooo01coool00ol0VOooooooo`1joooo0024oooo00<0003oooooool07?oo
o`03o`2Ioooooooo07[oool008Coool00`000?ooooooo`0Loooo00?o09Woooooool0N_ooo`00Q?oo
o`80000Moooo00?o09Woooooool0N_ooo`00Q?ooo`030000oooooooo01coool00ol0VOooooooo`1j
oooo0024oooo00<0003oooooool07?ooo`03o`2Ioooooooo07[oool008Coool00`000?ooooooo`0L
oooo00?o09Woooooool0N_ooo`00Q?ooo`80000Moooo00?o09Woooooool0N_ooo`00Q?ooo`030000
oooooooo01coool00ol0VOooooooo`1joooo0024oooo00<0003oooooool07?ooo`03o`2Ioooooooo
07[oool008Coool00`000?ooooooo`0Loooo00?o09Woooooool0N_ooo`00Q?ooo`030000oooooooo
01coool00ol0VOooooooo`1joooo0024oooo0P0001goool00ol0VOooooooo`1joooo0024oooo00<0
003oooooool07?ooo`03o`2Ioooooooo07[oool007coool400001?ooo`030000oooooooo01coool0
0ol0VOooooooo`1joooo001loooo00<0003oooooool01Oooo`030000oooooooo01coool00ol0VOoo
ooooo`1joooo001moooo00<0003oooooool01?ooo`<0000Loooo00?o09Woooooool0N_ooo`00O_oo
o`030000oooooooo00?oool00`000?ooooooo`0Loooo00?o09Woooooool0N_ooo`00O?ooo`040000
oooooooo00001?ooo`030000oooooooo01coool00ol0VOooooooo`1joooo001moooo0P0000Goool0
0`000?ooooooo`0Loooo00?o09Woooooool0N_ooo`00Q?ooo`80000Moooo00?o09Woooooool0N_oo
o`00Q?ooo`030000oooooooo01coool00ol0VOooooooo`1joooo0024oooo00<0003oooooool07?oo
o`03o`2Ioooooooo07[oool008Coool00`000?ooooooo`0Loooo00?o09Woooooool0N_ooo`00Q?oo
o`030000oooooooo01coool00ol0VOooooooo`1joooo0024oooo0P0001goool00ol0VOooooooo`1j
oooo0024oooo00<0003oooooool07?ooo`03o`2Ioooooooo07[oool008Coool00`000?ooooooo`0L
oooo00?o09Woooooool0N_ooo`00Q?ooo`030000oooooooo01coool00ol0VOooooooo`1joooo0024
oooo0P0001goool00ol0VOooooooo`1joooo0024oooo00<0003oooooool07?ooo`03o`2Ioooooooo
07[oool008Coool00`000?ooooooo`0Loooo00?o09Woooooool0N_ooo`00Q?ooo`030000oooooooo
01coool00ol0VOooooooo`1joooo0024oooo00<0003oooooool07?ooo`03o`2Ioooooooo07[oool0
08Coool200007Oooo`03o`2Ioooooooo07[oool008Coool00`000?ooooooo`0Loooo00?o09Wooooo
ool0N_ooo`00OOooo`800005oooo00<0003oooooool07?ooo`03o`2Ioooooooo07[oool007coool0
10000?ooooooo`0000Coool00`000?ooooooo`0Loooo00?o09Woooooool0N_ooo`00O_ooo`030000
oooooooo00?oool300007?ooo`03o`2Ioooooooo07[oool007ooool00`000?ooooooo`02oooo00<0
003oooooool07?ooo`03o`2Ioooooooo07[oool007coool010000?ooooooo`0000Coool00`000?oo
ooooo`0Loooo00?o09Woooooool0N_ooo`00OOooo`800005oooo00<0003oooooool07?ooo`03o`2I
oooooooo07[oool008Coool00`000?ooooooo`0Loooo00?o09Woooooool0N_ooo`00Q?ooo`80000M
oooo00?o09Woooooool0N_ooo`00Q?ooo`030000oooooooo01coool00ol0VOooooooo`1joooo0024
oooo00<0003oooooool07?ooo`03o`2Ioooooooo07[oool008Coool00`000?ooooooo`0Loooo00?o
09Woooooool0N_ooo`00Q?ooo`80000Moooo00?o09Woooooool0N_ooo`00Q?ooo`030000oooooooo
01coool00ol0VOooooooo`1joooo0024oooo00<0003oooooool07?ooo`03o`2Ioooooooo07[oool0
08Coool00`000?ooooooo`0Loooo00?o09Woooooool0N_ooo`00Q?ooo`030000oooooooo01coool0
0ol0VOooooooo`1joooo0024oooo0P0001goool00ol0VOooooooo`1joooo0024oooo00<0003ooooo
ool07?ooo`03o`2Ioooooooo07[oool008Coool00`000?ooooooo`0Loooo00?o09Woooooool0N_oo
o`00Q?ooo`030000oooooooo01coool00ol0VOooooooo`1joooo0024oooo0P0001goool00ol0VOoo
ooooo`1joooo0024oooo00<0003oooooool07?ooo`03o`2Ioooooooo07[oool008Coool00`000?oo
ooooo`0Loooo00?o09Woooooool0N_ooo`00O_ooo`<00003oooo00<0003oooooool07?ooo`03o`2I
oooooooo07[oool007ooool00`000?ooooooo`02oooo00<0003oooooool07?ooo`03o`2Ioooooooo
07[oool007coool500000oooo`<0000Loooo00?o09Woooooool0N_ooo`00O?ooo`040000oooooooo
0000X?ooo`00OOooo`030000oooo00000:3oool007koool20000X?ooo`00ooooob7oool00?oooolQ
oooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08
oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`07oooo0P0000Coool200001Oooo`<00002oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo00002oooo`050000oooooooooooo000007goool007[oool00`000?ooooooo`02
oooo00<0003oooooool03Oooo`040000oooooooo00002?ooo`D00003oooo00<0003oooooool0N_oo
o`00Noooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Woool00`000?ooo`000003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool2
00002oooo`800002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.55838 .26487 L
.57861 .26487 L
.58392 .26487 L
.58957 .26487 L
.59232 .26487 L
.59367 .26487 L
.59491 .26487 L
s
.59491 .26487 m
.59536 .61803 L
s
0 .4 1 r
.02381 .26539 m
.04262 .26552 L
.06244 .26569 L
.08255 .2659 L
.10458 .2662 L
.12415 .26653 L
.14509 .26699 L
.16639 .26757 L
.18653 .26828 L
.22495 .27015 L
.24479 .27147 L
.26581 .27321 L
.30365 .27737 L
.34394 .28322 L
.38271 .28907 L
.39281 .29029 L
.39815 .29084 L
.40384 .29133 L
.40931 .29172 L
.41426 .29198 L
.41665 .29208 L
.41924 .29216 L
.42043 .29219 L
.42169 .29222 L
.42276 .29223 L
.42393 .29225 L
.42524 .29226 L
.42644 .29226 L
.42707 .29226 L
.42777 .29226 L
.42849 .29226 L
.42917 .29225 L
.43042 .29224 L
.43156 .29222 L
.43282 .29219 L
.43414 .29216 L
.43858 .29201 L
.4411 .29189 L
.44344 .29176 L
.45356 .291 L
.46436 .28986 L
.50586 .28379 L
.54584 .27788 L
.56415 .27562 L
.57456 .27449 L
.5843 .27352 L
.58922 .27306 L
.59164 .27285 L
.59389 .27265 L
.59513 .27255 L
Mistroke
.59583 .26487 L
.59646 .26487 L
.59926 .26487 L
.60418 .26487 L
.62522 .26487 L
.66534 .26487 L
.70394 .26487 L
.745 .26487 L
.78454 .26487 L
.82256 .26487 L
.86304 .26487 L
.902 .26487 L
.94341 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo0011
oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Soool00`000?ooooooo`04oooo101Vo`03000006Ko06Ko00P0I_l00`00001Vo`1Vo`08
06Ko00<00000I_ooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oool0I_l02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool05Oooo`00;?ooo`030000oooooooo01GooolD06Ko00<0003oooooool0:Oooo`030000oooooooo
01goool406Ko2?ooo`030000oooooooo02Woool00`000?ooooooo`0Yoooo00<0003oooooool05Ooo
o`00FOooo`L0I_lToooo00<0003oooooool05oooo`H0I_l3oooo00?o09Woooooool0M_ooo`00H?oo
o`D0I_lOoooo00<0003oooooool03oooo`P0I_l9oooo00?o09Woooooool0M_ooo`00IOooo`L0I_lH
oooo0P0000Soool806Ko4Oooo`03o`2Ioooooooo07Koool006coool706Ko4Oooo`030000oooooooo
00;oool506Ko6Oooo`03o`2Ioooooooo07Koool007?ooolA06Ko00<00000I_l0I_l00P1Voakoool0
0ol0VOooooooo`1foooo0024oooo00<0003oooooool08?ooo`03o`2Ioooooooo07Koool008Coool2
00008Oooo`03o`2Ioooooooo07Koool008Coool00`000?ooooooo`0Poooo00?o09Woooooool0M_oo
o`00Q?ooo`030000oooooooo023oool00ol0VOooooooo`1foooo0024oooo00<0003oooooool08?oo
o`03o`2Ioooooooo07Koool008Coool00`000?ooooooo`0Poooo00?o09Woooooool0M_ooo`00Q?oo
o`80000Qoooo00?o09Woooooool0M_ooo`00Q?ooo`030000oooooooo023oool00ol0VOooooooo`1f
oooo0024oooo00<0003oooooool08?ooo`03o`2Ioooooooo07Koool008Coool00`000?ooooooo`0P
oooo00?o09Woooooool0M_ooo`00Q?ooo`80000Qoooo00?o09Woooooool0M_ooo`00Q?ooo`030000
oooooooo023oool00ol0VOooooooo`1foooo0024oooo00<0003oooooool08?ooo`03o`2Ioooooooo
07Koool007coool500000oooo`030000oooooooo023oool00ol0VOooooooo`1foooo001noooo00<0
003oooooool00oooo`030000oooooooo023oool00ol0VOooooooo`1foooo001noooo00<0003ooooo
ool00oooo`<0000Poooo00?o09Woooooool0M_ooo`00O_ooo`030000oooooooo00?oool00`000?oo
ooooo`0Poooo00?o09Woooooool0M_ooo`00O_ooo`030000oooooooo00?oool00`000?ooooooo`0P
oooo00?o09Woooooool0M_ooo`00OOooo`800005oooo00<0003oooooool08?ooo`03o`2Ioooooooo
07Koool008Coool200008Oooo`03o`2Ioooooooo07Koool008Coool00`000?ooooooo`0Poooo00?o
09Woooooool0M_ooo`00Q?ooo`030000oooooooo023oool00ol0VOooooooo`1foooo0024oooo00<0
003oooooool08?ooo`03o`2Ioooooooo07Koool008Coool00`000?ooooooo`0Poooo00?o09Wooooo
ool0M_ooo`00Q?ooo`80000Qoooo00?o09Woooooool0M_ooo`00Q?ooo`030000oooooooo023oool0
0ol0VOooooooo`1foooo0024oooo00<0003oooooool08?ooo`03o`2Ioooooooo07Koool008Coool0
0`000?ooooooo`0Poooo00?o09Woooooool0M_ooo`00Q?ooo`80000Qoooo00?o09Woooooool0M_oo
o`00Q?ooo`030000oooooooo023oool00ol0VOooooooo`1foooo0024oooo00<0003oooooool08?oo
o`03o`2Ioooooooo07Koool008Coool00`000?ooooooo`0Poooo00?o09Woooooool0M_ooo`00Q?oo
o`030000oooooooo023oool00ol0VOooooooo`1foooo0024oooo0P00027oool00ol0VOooooooo`1f
oooo0024oooo00<0003oooooool08?ooo`03o`2Ioooooooo07Koool007coool400001?ooo`030000
oooooooo023oool00ol0VOooooooo`1foooo001loooo00<0003oooooool01Oooo`030000oooooooo
023oool00ol0VOooooooo`1foooo001moooo00<0003oooooool01?ooo`<0000Poooo00?o09Wooooo
ool0M_ooo`00O_ooo`030000oooooooo00?oool00`000?ooooooo`0Poooo00?o09Woooooool0M_oo
o`00O?ooo`040000oooooooo00001?ooo`030000oooooooo023oool00ol0VOooooooo`1foooo001m
oooo0P0000Goool00`000?ooooooo`0Poooo00?o09Woooooool0M_ooo`00Q?ooo`80000Qoooo00?o
09Woooooool0M_ooo`00Q?ooo`030000oooooooo023oool00ol0VOooooooo`1foooo0024oooo00<0
003oooooool08?ooo`03o`2Ioooooooo07Koool008Coool00`000?ooooooo`0Poooo00?o09Wooooo
ool0M_ooo`00Q?ooo`030000oooooooo023oool00ol0VOooooooo`1foooo0024oooo0P00027oool0
0ol0VOooooooo`1foooo0024oooo00<0003oooooool08?ooo`03o`2Ioooooooo07Koool008Coool0
0`000?ooooooo`0Poooo00?o09Woooooool0M_ooo`00Q?ooo`030000oooooooo023oool00ol0VOoo
ooooo`1foooo0024oooo0P00027oool00ol0VOooooooo`1foooo0024oooo00<0003oooooool08?oo
o`03o`2Ioooooooo07Koool008Coool00`000?ooooooo`0Poooo00?o09Woooooool0M_ooo`00Q?oo
o`030000oooooooo023oool00ol0VOooooooo`1foooo0024oooo00<0003oooooool08?ooo`03o`2I
oooooooo07Koool008Coool200008Oooo`03o`2Ioooooooo07Koool008Coool00`000?ooooooo`0P
oooo00?o09Woooooool0M_ooo`00OOooo`800005oooo00<0003oooooool08?ooo`03o`2Ioooooooo
07Koool007coool010000?ooooooo`0000Coool00`000?ooooooo`0Poooo00?o09Woooooool0M_oo
o`00O_ooo`030000oooooooo00?oool300008?ooo`03o`2Ioooooooo07Koool007ooool00`000?oo
ooooo`02oooo00<0003oooooool08?ooo`03o`2Ioooooooo07Koool007coool010000?ooooooo`00
00Coool00`000?ooooooo`0Poooo00?o09Woooooool0M_ooo`00OOooo`800005oooo00<0003ooooo
ool08?ooo`03o`2Ioooooooo07Koool008Coool00`000?ooooooo`0Poooo00?o09Woooooool0M_oo
o`00Q?ooo`80000Qoooo00?o09Woooooool0M_ooo`00Q?ooo`030000oooooooo023oool00ol0VOoo
ooooo`1foooo0024oooo00<0003oooooool08?ooo`03o`2Ioooooooo07Koool008Coool00`000?oo
ooooo`0Poooo00?o09Woooooool0M_ooo`00Q?ooo`80000Qoooo00?o09Woooooool0M_ooo`00Q?oo
o`030000oooooooo023oool00ol0VOooooooo`1foooo0024oooo00<0003oooooool08?ooo`03o`2I
oooooooo07Koool008Coool00`000?ooooooo`0Poooo00?o09Woooooool0M_ooo`00Q?ooo`030000
oooooooo023oool00ol0VOooooooo`1foooo0024oooo0P00027oool00ol0VOooooooo`1foooo0024
oooo00<0003oooooool08?ooo`03o`2Ioooooooo07Koool008Coool00`000?ooooooo`0Poooo00?o
09Woooooool0M_ooo`00Q?ooo`030000oooooooo023oool00ol0VOooooooo`1foooo0024oooo0P00
027oool00ol0VOooooooo`1foooo0024oooo00<0003oooooool08?ooo`03o`2Ioooooooo07Koool0
08Coool00`000?ooooooo`0Poooo00?o09Woooooool0M_ooo`00O_ooo`<00003oooo00<0003ooooo
ool08?ooo`03o`2Ioooooooo07Koool007ooool00`000?ooooooo`02oooo00<0003oooooool08?oo
o`03o`2Ioooooooo07Koool007coool500000oooo`<0000Poooo00?o09Woooooool0M_ooo`00O?oo
o`040000oooooooo0000X?ooo`00OOooo`030000oooo00000:3oool007koool20000X?ooo`00oooo
ob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool0
0`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`<00004oooo00<0
003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002?oo
o`040000oooooooo00001?ooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003?oo
o`040000oooooooo00002?ooo`<00004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Woool00`000?ooooooo`03oooo00<0003oooooool0Nooo
o`00O?ooo`030000oooooooo017oool200002_ooo`<00002oooo00<0003oooooool0O?ooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.58872 .26487 L
.59975 .26487 L
.60479 .26487 L
.60756 .26487 L
.60891 .26487 L
.61016 .26487 L
.61135 .26487 L
s
.61135 .26487 m
.61185 .61803 L
s
0 .4 1 r
.02381 .2656 m
.04262 .26578 L
.06244 .26601 L
.08255 .26631 L
.10458 .26672 L
.12415 .26719 L
.14509 .26782 L
.16639 .26864 L
.18653 .26962 L
.22495 .27224 L
.24479 .27408 L
.26581 .27651 L
.30365 .2823 L
.34394 .29047 L
.38271 .29863 L
.39281 .30033 L
.39815 .30109 L
.40384 .30179 L
.40931 .30232 L
.41426 .30269 L
.41665 .30282 L
.41924 .30294 L
.42043 .30298 L
.42169 .30302 L
.42276 .30304 L
.42393 .30306 L
.42524 .30308 L
.42644 .30308 L
.42707 .30308 L
.42777 .30308 L
.42849 .30307 L
.42917 .30306 L
.43042 .30305 L
.43156 .30302 L
.43282 .30299 L
.43414 .30294 L
.43858 .30272 L
.4411 .30256 L
.44344 .30238 L
.45356 .30131 L
.46436 .29973 L
.50586 .29126 L
.54584 .28302 L
.5843 .27693 L
.59457 .27564 L
.60418 .27455 L
.60901 .27404 L
.6104 .2739 L
.61172 .27377 L
.61291 .26487 L
Mistroke
.6142 .26487 L
.62522 .26487 L
.66592 .26487 L
.7051 .26487 L
.74674 .26487 L
.78686 .26487 L
.82546 .26487 L
.86651 .26487 L
.90605 .26487 L
.94408 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo0011
oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Goool306Ko00<00000I_l0I_l0201Vo`03000006Ko06Ko00P0I_l00`00001Vo`1Vo`08
06Ko00<00000I_ooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool00oooo`0306Kooooooooo00;oool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo01Goool002coool00`000?ooooooo`0Eoooo201Vo`coool00`000?oo
ooooo`0Yoooo00<0003oooooool09?ooo`0306Kooooooooo00;oool00`000?ooooooo`0Yoooo00<0
003oooooool0:Oooo`030000oooooooo01Goool004coool;06Ko;Oooo`030000oooooooo01_oool:
06KoM?ooo`00Eoooo`@0I_lYoooo00<0003oooooool05oooo`@0I_l9oooo00?o09Woooooool0L_oo
o`00Foooo`D0I_lToooo0P0001?oool506Ko3Oooo`03o`2Ioooooooo07;oool0063oool506Ko7ooo
o`030000oooooooo00coool606Ko4_ooo`03o`2Ioooooooo07;oool006Goool506Ko6_ooo`030000
oooooooo00Ooool506Ko6?ooo`03o`2Ioooooooo07;oool006[oool506Ko5Oooo`030000oooooooo
00;oool506Ko7Oooo`03o`2Ioooooooo07;oool006ooool706Ko3Oooo`0306Ko0000000000<0I_lR
oooo00?o09Woooooool0L_ooo`00M_ooo`d0I_l00oooo`000?ooo`0Uoooo00?o09Woooooool0L_oo
o`00Q?ooo`030000oooooooo02Coool00ol0VOooooooo`1boooo0024oooo00<0003oooooool09?oo
o`03o`2Ioooooooo07;oool008Coool00`000?ooooooo`0Toooo00?o09Woooooool0L_ooo`00Q?oo
o`80000Uoooo00?o09Woooooool0L_ooo`00Q?ooo`030000oooooooo02Coool00ol0VOooooooo`1b
oooo0024oooo00<0003oooooool09?ooo`03o`2Ioooooooo07;oool008Coool00`000?ooooooo`0T
oooo00?o09Woooooool0L_ooo`00Q?ooo`80000Uoooo00?o09Woooooool0L_ooo`00Q?ooo`030000
oooooooo02Coool00ol0VOooooooo`1boooo0024oooo00<0003oooooool09?ooo`03o`2Ioooooooo
07;oool007coool500000oooo`030000oooooooo02Coool00ol0VOooooooo`1boooo001noooo00<0
003oooooool00oooo`030000oooooooo02Coool00ol0VOooooooo`1boooo001noooo00<0003ooooo
ool00oooo`<0000Toooo00?o09Woooooool0L_ooo`00O_ooo`030000oooooooo00?oool00`000?oo
ooooo`0Toooo00?o09Woooooool0L_ooo`00O_ooo`030000oooooooo00?oool00`000?ooooooo`0T
oooo00?o09Woooooool0L_ooo`00OOooo`800005oooo00<0003oooooool09?ooo`03o`2Ioooooooo
07;oool008Coool200009Oooo`03o`2Ioooooooo07;oool008Coool00`000?ooooooo`0Toooo00?o
09Woooooool0L_ooo`00Q?ooo`030000oooooooo02Coool00ol0VOooooooo`1boooo0024oooo00<0
003oooooool09?ooo`03o`2Ioooooooo07;oool008Coool00`000?ooooooo`0Toooo00?o09Wooooo
ool0L_ooo`00Q?ooo`80000Uoooo00?o09Woooooool0L_ooo`00Q?ooo`030000oooooooo02Coool0
0ol0VOooooooo`1boooo0024oooo00<0003oooooool09?ooo`03o`2Ioooooooo07;oool008Coool0
0`000?ooooooo`0Toooo00?o09Woooooool0L_ooo`00Q?ooo`80000Uoooo00?o09Woooooool0L_oo
o`00Q?ooo`030000oooooooo02Coool00ol0VOooooooo`1boooo0024oooo00<0003oooooool09?oo
o`03o`2Ioooooooo07;oool008Coool00`000?ooooooo`0Toooo00?o09Woooooool0L_ooo`00Q?oo
o`030000oooooooo02Coool00ol0VOooooooo`1boooo0024oooo0P0002Goool00ol0VOooooooo`1b
oooo0024oooo00<0003oooooool09?ooo`03o`2Ioooooooo07;oool007coool400001?ooo`030000
oooooooo02Coool00ol0VOooooooo`1boooo001loooo00<0003oooooool01Oooo`030000oooooooo
02Coool00ol0VOooooooo`1boooo001moooo00<0003oooooool01?ooo`<0000Toooo00?o09Wooooo
ool0L_ooo`00O_ooo`030000oooooooo00?oool00`000?ooooooo`0Toooo00?o09Woooooool0L_oo
o`00O?ooo`040000oooooooo00001?ooo`030000oooooooo02Coool00ol0VOooooooo`1boooo001m
oooo0P0000Goool00`000?ooooooo`0Toooo00?o09Woooooool0L_ooo`00Q?ooo`80000Uoooo00?o
09Woooooool0L_ooo`00Q?ooo`030000oooooooo02Coool00ol0VOooooooo`1boooo0024oooo00<0
003oooooool09?ooo`03o`2Ioooooooo07;oool008Coool00`000?ooooooo`0Toooo00?o09Wooooo
ool0L_ooo`00Q?ooo`030000oooooooo02Coool00ol0VOooooooo`1boooo0024oooo0P0002Goool0
0ol0VOooooooo`1boooo0024oooo00<0003oooooool09?ooo`03o`2Ioooooooo07;oool008Coool0
0`000?ooooooo`0Toooo00?o09Woooooool0L_ooo`00Q?ooo`030000oooooooo02Coool00ol0VOoo
ooooo`1boooo0024oooo0P0002Goool00ol0VOooooooo`1boooo0024oooo00<0003oooooool09?oo
o`03o`2Ioooooooo07;oool008Coool00`000?ooooooo`0Toooo00?o09Woooooool0L_ooo`00Q?oo
o`030000oooooooo02Coool00ol0VOooooooo`1boooo0024oooo00<0003oooooool09?ooo`03o`2I
oooooooo07;oool008Coool200009Oooo`03o`2Ioooooooo07;oool008Coool00`000?ooooooo`0T
oooo00?o09Woooooool0L_ooo`00OOooo`800005oooo00<0003oooooool09?ooo`03o`2Ioooooooo
07;oool007coool010000?ooooooo`0000Coool00`000?ooooooo`0Toooo00?o09Woooooool0L_oo
o`00O_ooo`030000oooooooo00?oool300009?ooo`03o`2Ioooooooo07;oool007ooool00`000?oo
ooooo`02oooo00<0003oooooool09?ooo`03o`2Ioooooooo07;oool007coool010000?ooooooo`00
00Coool00`000?ooooooo`0Toooo00?o09Woooooool0L_ooo`00OOooo`800005oooo00<0003ooooo
ool09?ooo`03o`2Ioooooooo07;oool008Coool00`000?ooooooo`0Toooo00?o09Woooooool0L_oo
o`00Q?ooo`80000Uoooo00?o09Woooooool0L_ooo`00Q?ooo`030000oooooooo02Coool00ol0VOoo
ooooo`1boooo0024oooo00<0003oooooool09?ooo`03o`2Ioooooooo07;oool008Coool00`000?oo
ooooo`0Toooo00?o09Woooooool0L_ooo`00Q?ooo`80000Uoooo00?o09Woooooool0L_ooo`00Q?oo
o`030000oooooooo02Coool00ol0VOooooooo`1boooo0024oooo00<0003oooooool09?ooo`03o`2I
oooooooo07;oool008Coool00`000?ooooooo`0Toooo00?o09Woooooool0L_ooo`00Q?ooo`030000
oooooooo02Coool00ol0VOooooooo`1boooo0024oooo0P0002Goool00ol0VOooooooo`1boooo0024
oooo00<0003oooooool09?ooo`03o`2Ioooooooo07;oool008Coool00`000?ooooooo`0Toooo00?o
09Woooooool0L_ooo`00Q?ooo`030000oooooooo02Coool00ol0VOooooooo`1boooo0024oooo0P00
02Goool00ol0VOooooooo`1boooo0024oooo00<0003oooooool09?ooo`03o`2Ioooooooo07;oool0
08Coool00`000?ooooooo`0Toooo00?o09Woooooool0L_ooo`00O_ooo`<00003oooo00<0003ooooo
ool09?ooo`03o`2Ioooooooo07;oool007ooool00`000?ooooooo`02oooo00<0003oooooool09?oo
o`03o`2Ioooooooo07;oool007coool500000oooo`<0000Toooo00?o09Woooooool0L_ooo`00O?oo
o`040000oooooooo0000X?ooo`00OOooo`030000oooo00000:3oool007koool20000X?ooo`00oooo
ob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool0
0`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`800004oooo00<0
003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo
07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002?oo
o`040000oooooooo00001?ooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003?oo
o`040000oooooooo00002Oooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1k
oooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.59832 .26487 L
.60873 .26487 L
.61445 .26487 L
.61984 .26487 L
.62502 .26487 L
.62644 .26487 L
.62795 .26487 L
.62923 .26487 L
s
.62923 .26487 m
.62952 .61803 L
s
0 .4 1 r
.02381 .26584 m
.04262 .26607 L
.06244 .26638 L
.08255 .26677 L
.10458 .26732 L
.12415 .26794 L
.14509 .26878 L
.16639 .26986 L
.18653 .27116 L
.22495 .27462 L
.24479 .27706 L
.26581 .28027 L
.30365 .28794 L
.34394 .29874 L
.38271 .30954 L
.39281 .31179 L
.39815 .3128 L
.40384 .31372 L
.40931 .31443 L
.41426 .31491 L
.41665 .31509 L
.41924 .31524 L
.42043 .3153 L
.42169 .31535 L
.42276 .31538 L
.42393 .31541 L
.42524 .31542 L
.42644 .31543 L
.42707 .31543 L
.42777 .31543 L
.42849 .31542 L
.42917 .31541 L
.43042 .31539 L
.43156 .31535 L
.43282 .31531 L
.43414 .31525 L
.43858 .31496 L
.4411 .31474 L
.44344 .3145 L
.45356 .31309 L
.46436 .311 L
.50586 .29979 L
.54584 .28888 L
.5843 .28083 L
.60418 .27768 L
.61432 .2763 L
.61992 .2756 L
.62267 .27528 L
.62522 .27498 L
.62759 .27471 L
Mistroke
.62828 .27464 L
.62892 .27456 L
.63012 .26487 L
.63077 .26487 L
.63145 .26487 L
.63268 .26487 L
.63545 .26487 L
.6448 .26487 L
.66311 .26487 L
.70113 .26487 L
.74161 .26487 L
.78057 .26487 L
.82198 .26487 L
.86188 .26487 L
.90026 .26487 L
.9411 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo0011
oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
oooooooo00P0I_l00`00001Vo`1Vo`0806Ko00<00000I_l0I_l0201Vo`03000006Ko06Ko00<0I_l5
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool05Oooo`00;?ooo`030000oooooooo00koool706Ko5?ooo`030000oooooooo02Woool00`000?oo
ooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo02Woool00`000?ooooooo`0Eoooo0014
oooo3@1Voc?oool00`000?ooooooo`0Poooo2P1Vofooool0057oool606Ko;Oooo`030000oooooooo
01_oool506Ko2Oooo`03o`2Ioooooooo06goool005Ooool406Ko:Oooo`80000Hoooo101Vo`koool0
0ol0VOooooooo`1]oooo001Koooo101VobGoool00`000?ooooooo`0Coooo101Voa;oool00ol0VOoo
ooooo`1]oooo001Ooooo0`1Vob;oool00`000?ooooooo`0?oooo101VoaKoool00ol0VOooooooo`1]
oooo001Roooo101Voakoool00`000?ooooooo`0;oooo101Voa[oool00ol0VOooooooo`1]oooo001V
oooo0`1Voa_oool200002Oooo`<0I_lNoooo00?o09Woooooool0KOooo`00JOooo`<0I_lHoooo00<0
003oooooool01Oooo`<0I_lQoooo00?o09Woooooool0KOooo`00K?ooo`@0I_lDoooo00@0003ooooo
ooooool406Ko9?ooo`03o`2Ioooooooo06goool0073oool606Ko3Oooo`0306Ko000006Ko0080I_lX
oooo00?o09Woooooool0KOooo`00M_ooo`d0I_l00oooo`000?ooo`0Zoooo00?o09Woooooool0KOoo
o`00Q?ooo`80000Zoooo00?o09Woooooool0KOooo`00Q?ooo`030000oooooooo02Woool00ol0VOoo
ooooo`1]oooo0024oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06goool008Coool00`000?oo
ooooo`0Yoooo00?o09Woooooool0KOooo`00Q?ooo`80000Zoooo00?o09Woooooool0KOooo`00Q?oo
o`030000oooooooo02Woool00ol0VOooooooo`1]oooo0024oooo00<0003oooooool0:Oooo`03o`2I
oooooooo06goool007coool500000oooo`030000oooooooo02Woool00ol0VOooooooo`1]oooo001n
oooo00<0003oooooool00oooo`030000oooooooo02Woool00ol0VOooooooo`1]oooo001noooo00<0
003oooooool00oooo`<0000Yoooo00?o09Woooooool0KOooo`00O_ooo`030000oooooooo00?oool0
0`000?ooooooo`0Yoooo00?o09Woooooool0KOooo`00O_ooo`030000oooooooo00?oool00`000?oo
ooooo`0Yoooo00?o09Woooooool0KOooo`00OOooo`800005oooo00<0003oooooool0:Oooo`03o`2I
oooooooo06goool008Coool20000:_ooo`03o`2Ioooooooo06goool008Coool00`000?ooooooo`0Y
oooo00?o09Woooooool0KOooo`00Q?ooo`030000oooooooo02Woool00ol0VOooooooo`1]oooo0024
oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06goool008Coool00`000?ooooooo`0Yoooo00?o
09Woooooool0KOooo`00Q?ooo`80000Zoooo00?o09Woooooool0KOooo`00Q?ooo`030000oooooooo
02Woool00ol0VOooooooo`1]oooo0024oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06goool0
08Coool00`000?ooooooo`0Yoooo00?o09Woooooool0KOooo`00Q?ooo`80000Zoooo00?o09Wooooo
ool0KOooo`00Q?ooo`030000oooooooo02Woool00ol0VOooooooo`1]oooo0024oooo00<0003ooooo
ool0:Oooo`03o`2Ioooooooo06goool008Coool00`000?ooooooo`0Yoooo00?o09Woooooool0KOoo
o`00Q?ooo`030000oooooooo02Woool00ol0VOooooooo`1]oooo0024oooo0P0002[oool00ol0VOoo
ooooo`1]oooo0024oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06goool007coool400001?oo
o`030000oooooooo02Woool00ol0VOooooooo`1]oooo001loooo00<0003oooooool01Oooo`030000
oooooooo02Woool00ol0VOooooooo`1]oooo001moooo00<0003oooooool01?ooo`<0000Yoooo00?o
09Woooooool0KOooo`00O_ooo`030000oooooooo00?oool00`000?ooooooo`0Yoooo00?o09Wooooo
ool0KOooo`00O?ooo`040000oooooooo00001?ooo`030000oooooooo02Woool00ol0VOooooooo`1]
oooo001moooo0P0000Goool00`000?ooooooo`0Yoooo00?o09Woooooool0KOooo`00Q?ooo`80000Z
oooo00?o09Woooooool0KOooo`00Q?ooo`030000oooooooo02Woool00ol0VOooooooo`1]oooo0024
oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06goool008Coool00`000?ooooooo`0Yoooo00?o
09Woooooool0KOooo`00Q?ooo`030000oooooooo02Woool00ol0VOooooooo`1]oooo0024oooo0P00
02[oool00ol0VOooooooo`1]oooo0024oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06goool0
08Coool00`000?ooooooo`0Yoooo00?o09Woooooool0KOooo`00Q?ooo`030000oooooooo02Woool0
0ol0VOooooooo`1]oooo0024oooo0P0002[oool00ol0VOooooooo`1]oooo0024oooo00<0003ooooo
ool0:Oooo`03o`2Ioooooooo06goool008Coool00`000?ooooooo`0Yoooo00?o09Woooooool0KOoo
o`00Q?ooo`030000oooooooo02Woool00ol0VOooooooo`1]oooo0024oooo00<0003oooooool0:Ooo
o`03o`2Ioooooooo06goool008Coool20000:_ooo`03o`2Ioooooooo06goool008Coool00`000?oo
ooooo`0Yoooo00?o09Woooooool0KOooo`00OOooo`800005oooo00<0003oooooool0:Oooo`03o`2I
oooooooo06goool007coool010000?ooooooo`0000Coool00`000?ooooooo`0Yoooo00?o09Wooooo
ool0KOooo`00O_ooo`030000oooooooo00?oool30000:Oooo`03o`2Ioooooooo06goool007ooool0
0`000?ooooooo`02oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06goool007coool010000?oo
ooooo`0000Coool00`000?ooooooo`0Yoooo00?o09Woooooool0KOooo`00OOooo`800005oooo00<0
003oooooool0:Oooo`03o`2Ioooooooo06goool008Coool00`000?ooooooo`0Yoooo00?o09Wooooo
ool0KOooo`00Q?ooo`80000Zoooo00?o09Woooooool0KOooo`00Q?ooo`030000oooooooo02Woool0
0ol0VOooooooo`1]oooo0024oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06goool008Coool0
0`000?ooooooo`0Yoooo00?o09Woooooool0KOooo`00Q?ooo`80000Zoooo00?o09Woooooool0KOoo
o`00Q?ooo`030000oooooooo02Woool00ol0VOooooooo`1]oooo0024oooo00<0003oooooool0:Ooo
o`03o`2Ioooooooo06goool008Coool00`000?ooooooo`0Yoooo00?o09Woooooool0KOooo`00Q?oo
o`030000oooooooo02Woool00ol0VOooooooo`1]oooo0024oooo0P0002[oool00ol0VOooooooo`1]
oooo0024oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06goool008Coool00`000?ooooooo`0Y
oooo00?o09Woooooool0KOooo`00Q?ooo`030000oooooooo02Woool00ol0VOooooooo`1]oooo0024
oooo0P0002[oool00ol0VOooooooo`1]oooo0024oooo00<0003oooooool0:Oooo`03o`2Ioooooooo
06goool008Coool00`000?ooooooo`0Yoooo00?o09Woooooool0KOooo`00O_ooo`<00003oooo00<0
003oooooool0:Oooo`03o`2Ioooooooo06goool007ooool00`000?ooooooo`02oooo00<0003ooooo
ool0:Oooo`03o`2Ioooooooo06goool007coool500000oooo`<0000Yoooo00?o09Woooooool0KOoo
o`00O?ooo`040000oooooooo0000X?ooo`00OOooo`030000oooo00000:3oool007koool20000X?oo
o`00ooooob7oool00?oooolQoooo001ooooo00<0003oooooool07?ooo`030000oooooooo07ooool0
07koool00`000?ooooooo`08oooo00<0003oooooool04oooo`030000oooooooo07koool007koool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200001?ooo`030000
oooooooo07koool007koool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool0O_ooo`00OOooo`030000oooooooo
00;oool00`000?ooooooo`0?oooo00<0003oooooool02Oooo`030000oooooooo07goool007koool0
0`000?ooooooo`0500003_ooo`030000oooooooo00Soool00`000?ooooooo`1noooo001noooo00D0
003oooooooooool000004Oooo`030000oooooooo00Soool00`000?ooooooo`1noooo001ooooo00<0
003oooooool04Oooo`800009oooo00<0003oooooool0Ooooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.59832 .26487 L
.61984 .26487 L
.6298 .26487 L
.63527 .26487 L
.64043 .26487 L
.64277 .26487 L
.64524 .26487 L
.64654 .26487 L
s
.64654 .26487 m
.64683 .61803 L
s
0 .4 1 r
.02381 .26611 m
.04262 .26641 L
.06244 .2668 L
.08255 .26731 L
.10458 .26802 L
.12415 .26881 L
.14509 .26989 L
.16639 .27128 L
.18653 .27295 L
.22495 .27739 L
.24479 .28052 L
.26581 .28465 L
.30365 .2945 L
.34394 .30837 L
.38271 .32225 L
.39281 .32514 L
.39815 .32644 L
.40384 .32761 L
.40931 .32852 L
.41426 .32915 L
.41665 .32938 L
.41924 .32957 L
.42043 .32964 L
.42169 .3297 L
.42276 .32975 L
.42393 .32978 L
.42524 .3298 L
.42644 .32981 L
.42707 .32981 L
.42777 .32981 L
.42849 .3298 L
.42917 .32979 L
.43042 .32975 L
.43156 .32971 L
.43282 .32965 L
.43414 .32957 L
.43858 .32921 L
.4411 .32893 L
.44344 .32862 L
.45356 .32681 L
.46436 .32412 L
.50586 .30973 L
.54584 .29571 L
.5843 .28537 L
.60418 .28132 L
.62522 .27785 L
.63466 .27654 L
.63986 .27587 L
.64242 .27555 L
.6448 .27527 L
Mistroke
.64594 .27513 L
.64701 .27501 L
.64825 .26487 L
.64938 .26487 L
.65437 .26487 L
.66311 .26487 L
.70171 .26487 L
.74277 .26487 L
.78231 .26487 L
.82033 .26487 L
.86081 .26487 L
.89977 .26487 L
.94118 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo0011
oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
06Ko06Ko00P0I_l00`00001Vo`1Vo`0806Ko00<00000I_l0I_l0201Vo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00H0003ooooooooooooo09T0I_l5
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo01Goool002coool00`000?ooooooo`09oooo301VoaCoool00`000?ooooooo`0Yoooo00<0
003oooooool0:Oooo`050000oooooooooooo06Ko02Ooool00`000?ooooooo`0Yoooo00<0003ooooo
ool05Oooo`00A?ooo`P0I_lhoooo00<0003oooooool0:_ooo`@0I_m[oooo001<oooo1@1Voc?oool0
0`000?ooooooo`0Poooo2P1Vo`?oool00ol0VOooooooo`1Yoooo001Aoooo1@1Vobkoool200007Ooo
o`@0I_l=oooo00?o09Woooooool0JOooo`00E_ooo`<0I_l[oooo00<0003oooooool06Oooo`<0I_lA
oooo00?o09Woooooool0JOooo`00FOooo`<0I_lXoooo00<0003oooooool05_ooo`<0I_lDoooo00?o
09Woooooool0JOooo`00G?ooo`<0I_lUoooo00<0003oooooool04oooo`<0I_lGoooo00?o09Wooooo
ool0JOooo`00Goooo`<0I_lRoooo0P00017oool306Ko6_ooo`03o`2Ioooooooo06Woool006;oool4
06Ko7_ooo`030000oooooooo00koool206Ko7Oooo`03o`2Ioooooooo06Woool006Koool306Ko6ooo
o`030000oooooooo00_oool306Ko7oooo`03o`2Ioooooooo06Woool006Woool206Ko6Oooo`030000
oooooooo00Soool306Ko8_ooo`03o`2Ioooooooo06Woool006_oool306Ko5_ooo`030000oooooooo
00Goool306Ko9Oooo`03o`2Ioooooooo06Woool006koool206Ko5?ooo`800002oooo101VobSoool0
0ol0VOooooooo`1Yoooo001`oooo0`1Voa7oool01000001Vo`1Vo`1Vobcoool00ol0VOooooooo`1Y
oooo001coooo1P1Vo`Ooool406Ko00<0003oooooool0;Oooo`03o`2Ioooooooo06Woool007Woool7
06Ko1?ooo`030000oooooooo02goool00ol0VOooooooo`1Yoooo0024oooo0P0002koool00ol0VOoo
ooooo`1Yoooo0024oooo00<0003oooooool0;Oooo`03o`2Ioooooooo06Woool008Coool00`000?oo
ooooo`0]oooo00?o09Woooooool0JOooo`00O?ooo`D00003oooo00<0003oooooool0;Oooo`03o`2I
oooooooo06Woool007koool00`000?ooooooo`03oooo00<0003oooooool0;Oooo`03o`2Ioooooooo
06Woool007koool00`000?ooooooo`03oooo0`0002goool00ol0VOooooooo`1Yoooo001noooo00<0
003oooooool00oooo`030000oooooooo02goool00ol0VOooooooo`1Yoooo001noooo00<0003ooooo
ool00oooo`030000oooooooo02goool00ol0VOooooooo`1Yoooo001moooo0P0000Goool00`000?oo
ooooo`0]oooo00?o09Woooooool0JOooo`00Q?ooo`80000^oooo00?o09Woooooool0JOooo`00Q?oo
o`030000oooooooo02goool00ol0VOooooooo`1Yoooo0024oooo00<0003oooooool0;Oooo`03o`2I
oooooooo06Woool008Coool00`000?ooooooo`0]oooo00?o09Woooooool0JOooo`00Q?ooo`030000
oooooooo02goool00ol0VOooooooo`1Yoooo0024oooo0P0002koool00ol0VOooooooo`1Yoooo0024
oooo00<0003oooooool0;Oooo`03o`2Ioooooooo06Woool008Coool00`000?ooooooo`0]oooo00?o
09Woooooool0JOooo`00Q?ooo`030000oooooooo02goool00ol0VOooooooo`1Yoooo0024oooo0P00
02koool00ol0VOooooooo`1Yoooo0024oooo00<0003oooooool0;Oooo`03o`2Ioooooooo06Woool0
08Coool00`000?ooooooo`0]oooo00?o09Woooooool0JOooo`00Q?ooo`030000oooooooo02goool0
0ol0VOooooooo`1Yoooo0024oooo00<0003oooooool0;Oooo`03o`2Ioooooooo06Woool008Coool2
0000;_ooo`03o`2Ioooooooo06Woool008Coool00`000?ooooooo`0]oooo00?o09Woooooool0JOoo
o`00O?ooo`@00004oooo00<0003oooooool0;Oooo`03o`2Ioooooooo06Woool007coool00`000?oo
ooooo`05oooo00<0003oooooool0;Oooo`03o`2Ioooooooo06Woool007goool00`000?ooooooo`04
oooo0`0002goool00ol0VOooooooo`1Yoooo001noooo00<0003oooooool00oooo`030000oooooooo
02goool00ol0VOooooooo`1Yoooo001loooo00@0003oooooool00004oooo00<0003oooooool0;Ooo
o`03o`2Ioooooooo06Woool007goool200001Oooo`030000oooooooo02goool00ol0VOooooooo`1Y
oooo0024oooo0P0002koool00ol0VOooooooo`1Yoooo0024oooo00<0003oooooool0;Oooo`03o`2I
oooooooo06Woool008Coool00`000?ooooooo`0]oooo00?o09Woooooool0JOooo`00Q?ooo`030000
oooooooo02goool00ol0VOooooooo`1Yoooo0024oooo00<0003oooooool0;Oooo`03o`2Ioooooooo
06Woool008Coool20000;_ooo`03o`2Ioooooooo06Woool008Coool00`000?ooooooo`0]oooo00?o
09Woooooool0JOooo`00Q?ooo`030000oooooooo02goool00ol0VOooooooo`1Yoooo0024oooo00<0
003oooooool0;Oooo`03o`2Ioooooooo06Woool008Coool20000;_ooo`03o`2Ioooooooo06Woool0
08Coool00`000?ooooooo`0]oooo00?o09Woooooool0JOooo`00Q?ooo`030000oooooooo02goool0
0ol0VOooooooo`1Yoooo0024oooo00<0003oooooool0;Oooo`03o`2Ioooooooo06Woool008Coool0
0`000?ooooooo`0]oooo00?o09Woooooool0JOooo`00Q?ooo`80000^oooo00?o09Woooooool0JOoo
o`00Q?ooo`030000oooooooo02goool00ol0VOooooooo`1Yoooo001moooo0P0000Goool00`000?oo
ooooo`0]oooo00?o09Woooooool0JOooo`00O?ooo`040000oooooooo00001?ooo`030000oooooooo
02goool00ol0VOooooooo`1Yoooo001noooo00<0003oooooool00oooo`<0000]oooo00?o09Wooooo
ool0JOooo`00Ooooo`030000oooooooo00;oool00`000?ooooooo`0]oooo00?o09Woooooool0JOoo
o`00O?ooo`040000oooooooo00001?ooo`030000oooooooo02goool00ol0VOooooooo`1Yoooo001m
oooo0P0000Goool00`000?ooooooo`0]oooo00?o09Woooooool0JOooo`00Q?ooo`030000oooooooo
02goool00ol0VOooooooo`1Yoooo0024oooo0P0002koool00ol0VOooooooo`1Yoooo0024oooo00<0
003oooooool0;Oooo`03o`2Ioooooooo06Woool008Coool00`000?ooooooo`0]oooo00?o09Wooooo
ool0JOooo`00Q?ooo`030000oooooooo02goool00ol0VOooooooo`1Yoooo0024oooo0P0002koool0
0ol0VOooooooo`1Yoooo0024oooo00<0003oooooool0;Oooo`03o`2Ioooooooo06Woool008Coool0
0`000?ooooooo`0]oooo00?o09Woooooool0JOooo`00Q?ooo`030000oooooooo02goool00ol0VOoo
ooooo`1Yoooo0024oooo00<0003oooooool0;Oooo`03o`2Ioooooooo06Woool008Coool20000;_oo
o`03o`2Ioooooooo06Woool008Coool00`000?ooooooo`0]oooo00?o09Woooooool0JOooo`00Q?oo
o`030000oooooooo02goool00ol0VOooooooo`1Yoooo0024oooo00<0003oooooool0;Oooo`03o`2I
oooooooo06Woool008Coool20000;_ooo`03o`2Ioooooooo06Woool008Coool00`000?ooooooo`0]
oooo00?o09Woooooool0JOooo`00Q?ooo`030000oooooooo02goool00ol0VOooooooo`1Yoooo001n
oooo0`0000?oool00`000?ooooooo`0]oooo00?o09Woooooool0JOooo`00Ooooo`030000oooooooo
00;oool00`000?ooooooo`0]oooo00?o09Woooooool0JOooo`00O?ooo`D00003oooo0`0002goool0
0ol0VOooooooo`1Yoooo001loooo00@0003oooooool0002Poooo001moooo00<0003oool00000X?oo
o`00O_ooo`80002Poooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0
003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003ooooo
ool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_oo
o`800003oooo100000?oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000oooooooo
00Coool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00ooool0
0`000?ooooooo`08oooo00<0003oooooool01?ooo`030000oooooooo07[oool007_oool00`000?oo
ooooo`0500003_ooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo0000017oool00`000?ooooooo`07oooo00@0003oooooool00003
oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0
003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.64043 .26487 L
.65045 .26487 L
.65954 .26487 L
.66177 .26487 L
.66298 .26487 L
.66412 .26487 L
s
.66412 .26487 m
.66461 .61803 L
s
0 .4 1 r
.02381 .26643 m
.04262 .26681 L
.06244 .26731 L
.08255 .26795 L
.10458 .26884 L
.12415 .26984 L
.14509 .2712 L
.16639 .27296 L
.18653 .27506 L
.22495 .28066 L
.24479 .28462 L
.26581 .28982 L
.30365 .30225 L
.34394 .31975 L
.38271 .33725 L
.39281 .3409 L
.39815 .34254 L
.40384 .34403 L
.40931 .34517 L
.41426 .34596 L
.41665 .34625 L
.41924 .3465 L
.42043 .34659 L
.42169 .34666 L
.42276 .34672 L
.42393 .34676 L
.42524 .34679 L
.42644 .3468 L
.42707 .3468 L
.42777 .34679 L
.42849 .34678 L
.42917 .34677 L
.43042 .34672 L
.43156 .34667 L
.43282 .3466 L
.43414 .3465 L
.43858 .34604 L
.4411 .34568 L
.44344 .34529 L
.45356 .34301 L
.46436 .33962 L
.50586 .32146 L
.54584 .30378 L
.5843 .29073 L
.60418 .28562 L
.62522 .28125 L
.64502 .27795 L
.65368 .27672 L
.65824 .27612 L
.66075 .2758 L
Mistroke
.66311 .27551 L
.66442 .27535 L
.66515 .26487 L
.66583 .26487 L
.66829 .26487 L
.67309 .26487 L
.68256 .26487 L
.70345 .26487 L
.74299 .26487 L
.78101 .26487 L
.82149 .26487 L
.86045 .26487 L
.90186 .26487 L
.94176 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo0011
oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
06Ko06Ko00P0I_l00`00001Vo`1Vo`0806Ko00<00000I_l0I_l0101Vo`Coool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Koool0
0`1Vooooo`00000:oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool05Oooo`00;?ooo`030000oooooooo00Coool:06Ko6oooo`030000oooooooo02Woool00`000?oo
ooooo`0Yoooo00<0003oooooool01_ooo`0306Kooooooooo023oool00`000?ooooooo`0Yoooo00<0
003oooooool05Oooo`00?Oooo`L0I_m0oooo00<0003oooooool0;oooo`@0I_mVoooo0014oooo201V
ocSoool00`000?ooooooo`0Voooo2@1Vo`?oool00ol0VOooooooo`1Toooo001<oooo101VocCoool2
00008_ooo`D0I_l<oooo00?o09Woooooool0I?ooo`00D?ooo`<0I_laoooo00<0003oooooool07ooo
o`80I_lAoooo00?o09Woooooool0I?ooo`00Doooo`<0I_l^oooo00<0003oooooool07?ooo`<0I_lC
oooo00?o09Woooooool0I?ooo`00E_ooo`<0I_l[oooo00<0003oooooool06Oooo`<0I_lFoooo00?o
09Woooooool0I?ooo`00FOooo`<0I_lXoooo0P0001Ooool306Ko6Oooo`03o`2Ioooooooo06Coool0
05coool306Ko9Oooo`030000oooooooo01?oool306Ko7?ooo`03o`2Ioooooooo06Coool005ooool2
06Ko8oooo`030000oooooooo017oool206Ko7oooo`03o`2Ioooooooo06Coool0067oool306Ko8?oo
o`030000oooooooo00ooool206Ko8Oooo`03o`2Ioooooooo06Coool006Coool206Ko7_ooo`030000
oooooooo00goool206Ko8oooo`03o`2Ioooooooo06Coool006Koool206Ko7?ooo`80000<oooo0P1V
obGoool00ol0VOooooooo`1Toooo001Xoooo0P1Voa[oool00`000?ooooooo`08oooo0`1VobOoool0
0ol0VOooooooo`1Toooo001Zoooo0P1VoaSoool00`000?ooooooo`06oooo0P1Vob[oool00ol0VOoo
ooooo`1Toooo001/oooo0P1VoaKoool00`000?ooooooo`03oooo0`1Vobcoool00ol0VOooooooo`1T
oooo001^oooo0P1VoaCoool200000_ooo`80I_l_oooo00?o09Woooooool0I?ooo`00L?ooo`D0I_l?
oooo00@00000I_l0I_l0I_laoooo00?o09Woooooool0I?ooo`00MOooo`<0I_l;oooo00<0I_l0003o
ool0<oooo`03o`2Ioooooooo06Coool007Soool406Ko1@000080I_l00oooo`000?ooo`0coooo00?o
09Woooooool0I?ooo`00O_ooo`030000oooooooo00?oool00`000?ooooooo`0boooo00?o09Wooooo
ool0I?ooo`00O_ooo`030000oooooooo00?oool30000<_ooo`03o`2Ioooooooo06Coool007koool0
0`000?ooooooo`03oooo00<0003oooooool0<_ooo`03o`2Ioooooooo06Coool007koool00`000?oo
ooooo`03oooo00<0003oooooool0<_ooo`03o`2Ioooooooo06Coool007goool200001Oooo`030000
oooooooo03;oool00ol0VOooooooo`1Toooo0024oooo0P0003?oool00ol0VOooooooo`1Toooo0024
oooo00<0003oooooool0<_ooo`03o`2Ioooooooo06Coool008Coool00`000?ooooooo`0boooo00?o
09Woooooool0I?ooo`00Q?ooo`030000oooooooo03;oool00ol0VOooooooo`1Toooo0024oooo00<0
003oooooool0<_ooo`03o`2Ioooooooo06Coool008Coool20000<oooo`03o`2Ioooooooo06Coool0
08Coool00`000?ooooooo`0boooo00?o09Woooooool0I?ooo`00Q?ooo`030000oooooooo03;oool0
0ol0VOooooooo`1Toooo0024oooo00<0003oooooool0<_ooo`03o`2Ioooooooo06Coool008Coool2
0000<oooo`03o`2Ioooooooo06Coool008Coool00`000?ooooooo`0boooo00?o09Woooooool0I?oo
o`00Q?ooo`030000oooooooo03;oool00ol0VOooooooo`1Toooo0024oooo00<0003oooooool0<_oo
o`03o`2Ioooooooo06Coool008Coool00`000?ooooooo`0boooo00?o09Woooooool0I?ooo`00Q?oo
o`80000coooo00?o09Woooooool0I?ooo`00Q?ooo`030000oooooooo03;oool00ol0VOooooooo`1T
oooo001loooo100000Coool00`000?ooooooo`0boooo00?o09Woooooool0I?ooo`00O?ooo`030000
oooooooo00Goool00`000?ooooooo`0boooo00?o09Woooooool0I?ooo`00OOooo`030000oooooooo
00Coool30000<_ooo`03o`2Ioooooooo06Coool007koool00`000?ooooooo`03oooo00<0003ooooo
ool0<_ooo`03o`2Ioooooooo06Coool007coool010000?ooooooo`0000Coool00`000?ooooooo`0b
oooo00?o09Woooooool0I?ooo`00OOooo`800005oooo00<0003oooooool0<_ooo`03o`2Ioooooooo
06Coool008Coool20000<oooo`03o`2Ioooooooo06Coool008Coool00`000?ooooooo`0boooo00?o
09Woooooool0I?ooo`00Q?ooo`030000oooooooo03;oool00ol0VOooooooo`1Toooo0024oooo00<0
003oooooool0<_ooo`03o`2Ioooooooo06Coool008Coool00`000?ooooooo`0boooo00?o09Wooooo
ool0I?ooo`00Q?ooo`80000coooo00?o09Woooooool0I?ooo`00Q?ooo`030000oooooooo03;oool0
0ol0VOooooooo`1Toooo0024oooo00<0003oooooool0<_ooo`03o`2Ioooooooo06Coool008Coool0
0`000?ooooooo`0boooo00?o09Woooooool0I?ooo`00Q?ooo`80000coooo00?o09Woooooool0I?oo
o`00Q?ooo`030000oooooooo03;oool00ol0VOooooooo`1Toooo0024oooo00<0003oooooool0<_oo
o`03o`2Ioooooooo06Coool008Coool00`000?ooooooo`0boooo00?o09Woooooool0I?ooo`00Q?oo
o`030000oooooooo03;oool00ol0VOooooooo`1Toooo0024oooo0P0003?oool00ol0VOooooooo`1T
oooo0024oooo00<0003oooooool0<_ooo`03o`2Ioooooooo06Coool007goool200001Oooo`030000
oooooooo03;oool00ol0VOooooooo`1Toooo001loooo00@0003oooooool00004oooo00<0003ooooo
ool0<_ooo`03o`2Ioooooooo06Coool007koool00`000?ooooooo`03oooo0`0003;oool00ol0VOoo
ooooo`1Toooo001ooooo00<0003oooooool00_ooo`030000oooooooo03;oool00ol0VOooooooo`1T
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0<_ooo`03o`2Ioooooooo06Coool0
07goool200001Oooo`030000oooooooo03;oool00ol0VOooooooo`1Toooo0024oooo00<0003ooooo
ool0<_ooo`03o`2Ioooooooo06Coool008Coool20000<oooo`03o`2Ioooooooo06Coool008Coool0
0`000?ooooooo`0boooo00?o09Woooooool0I?ooo`00Q?ooo`030000oooooooo03;oool00ol0VOoo
ooooo`1Toooo0024oooo00<0003oooooool0<_ooo`03o`2Ioooooooo06Coool008Coool20000<ooo
o`03o`2Ioooooooo06Coool008Coool00`000?ooooooo`0boooo00?o09Woooooool0I?ooo`00Q?oo
o`030000oooooooo03;oool00ol0VOooooooo`1Toooo0024oooo00<0003oooooool0<_ooo`03o`2I
oooooooo06Coool008Coool00`000?ooooooo`0boooo00?o09Woooooool0I?ooo`00Q?ooo`80000c
oooo00?o09Woooooool0I?ooo`00Q?ooo`030000oooooooo03;oool00ol0VOooooooo`1Toooo0024
oooo00<0003oooooool0<_ooo`03o`2Ioooooooo06Coool008Coool00`000?ooooooo`0boooo00?o
09Woooooool0I?ooo`00Q?ooo`80000coooo00?o09Woooooool0I?ooo`00Q?ooo`030000oooooooo
03;oool00ol0VOooooooo`1Toooo0024oooo00<0003oooooool0<_ooo`03o`2Ioooooooo06Coool0
07koool300000oooo`030000oooooooo03;oool00ol0VOooooooo`1Toooo001ooooo00<0003ooooo
ool00_ooo`030000oooooooo03;oool00ol0VOooooooo`1Toooo001loooo1@0000?oool30000<_oo
o`03o`2Ioooooooo06Coool007coool010000?ooooooo`000:3oool007goool00`000?ooo`00002P
oooo001noooo0P000:3oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool0
0`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?oo
ooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002
oooo0P0000Goool300000_ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`0:oooo00D0003ooooo
ooooool00000OOooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003ooooo
ool01oooo`D00003oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0
003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`00000Aoooo00<0003oooooool02?ooo`030000oooo000000?oool00`000?ooooooo`1k
oooo001loooo00<0003oooooool04Oooo`80000;oooo0P0000;oool00`000?ooooooo`1loooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.64043 .26487 L
.65954 .26487 L
.66906 .26487 L
.67373 .26487 L
.67803 .26487 L
.68044 .26487 L
.68166 .26487 L
s
.68166 .26487 m
.68194 .61803 L
s
0 .4 1 r
.02381 .26682 m
.04262 .26729 L
.06244 .26791 L
.08255 .26871 L
.10458 .26982 L
.12415 .27107 L
.14509 .27276 L
.16639 .27496 L
.18653 .27758 L
.22495 .28457 L
.24479 .28951 L
.26581 .29599 L
.30365 .3115 L
.34394 .33334 L
.38271 .35517 L
.39281 .35972 L
.39815 .36176 L
.40384 .36361 L
.40931 .36505 L
.41426 .36603 L
.41665 .36639 L
.41924 .3667 L
.42043 .36681 L
.42169 .3669 L
.42276 .36697 L
.42393 .36702 L
.42524 .36706 L
.42644 .36707 L
.42707 .36707 L
.42777 .36707 L
.42849 .36705 L
.42917 .36703 L
.43042 .36698 L
.43156 .36691 L
.43282 .36682 L
.43414 .3667 L
.43858 .36612 L
.4411 .36568 L
.44344 .36519 L
.45356 .36235 L
.46436 .35812 L
.50586 .33546 L
.54584 .31341 L
.5843 .29714 L
.60418 .29076 L
.62522 .2853 L
.64502 .28119 L
.66311 .27814 L
.66788 .27743 L
.67309 .27671 L
Mistroke
.67547 .27639 L
.678 .27606 L
.67923 .2759 L
.68039 .27575 L
.68143 .27562 L
.68256 .26487 L
.68387 .26487 L
.68508 .26487 L
.68786 .26487 L
.69345 .26487 L
.70345 .26487 L
.74241 .26487 L
.78382 .26487 L
.82372 .26487 L
.8621 .26487 L
.90294 .26487 L
.94226 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo0011
oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
06Ko06Ko00P0I_l00`00001Vo`1Vo`0806Ko00<00000I_ooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooo06Ko00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0E
oooo000/oooo00<0003oool0I_l02@1Vob3oool00`000?ooooooo`0Yoooo00<0003oooooool0:Ooo
o`030000oooooooo00[oool00`1Vooooooooo`0Loooo00<0003oooooool0:Oooo`030000oooooooo
01Goool003Soool:06Ko@_ooo`030000oooooooo03?oool406KoH_ooo`00@_ooo`D0I_lmoooo00<0
003oooooool0:oooo`P0I_l3oooo00?o09Woooooool0H?ooo`00Aoooo`D0I_lhoooo0P0002Soool4
06Ko2oooo`03o`2Ioooooooo063oool004coool406Ko=?ooo`030000oooooooo02Coool306Ko3ooo
o`03o`2Ioooooooo063oool0053oool306Ko<Oooo`030000oooooooo023oool406Ko4_ooo`03o`2I
oooooooo063oool005?oool306Ko;_ooo`030000oooooooo01goool306Ko5_ooo`03o`2Ioooooooo
063oool005Koool206Ko;?ooo`80000Loooo0P1VoaWoool00ol0VOooooooo`1Poooo001Hoooo0P1V
ob[oool00`000?ooooooo`0Ioooo0P1Voa_oool00ol0VOooooooo`1Poooo001Joooo0P1VobSoool0
0`000?ooooooo`0Goooo0P1Voagoool00ol0VOooooooo`1Poooo001Loooo0P1VobKoool00`000?oo
ooooo`0Eoooo0P1Voaooool00ol0VOooooooo`1Poooo001Noooo0P1VobCoool00`000?ooooooo`0C
oooo0P1Vob7oool00ol0VOooooooo`1Poooo001Poooo0P1Vob;oool200004_ooo`80I_lSoooo00?o
09Woooooool0H?ooo`00H_ooo`0306Kooooooooo01ooool00`000?ooooooo`0?oooo0P1VobGoool0
0ol0VOooooooo`1Poooo001Soooo0P1Voaooool00`000?ooooooo`0=oooo0P1VobOoool00ol0VOoo
ooooo`1Poooo001Uoooo0P1Voagoool00`000?ooooooo`0;oooo0P1VobWoool00ol0VOooooooo`1P
oooo001Woooo00<0I_ooooooool06_ooo`80000:oooo0P1Vob_oool00ol0VOooooooo`1Poooo001X
oooo0P1Voa[oool00`000?ooooooo`07oooo0P1Vobgoool00ol0VOooooooo`1Poooo001Zoooo0P1V
oaSoool00`000?ooooooo`05oooo0P1Vobooool00ol0VOooooooo`1Poooo001/oooo0P1Vo`koool5
00000oooo`030000oooooooo00Coool00`1Vooooooooo`0_oooo00?o09Woooooool0H?ooo`00K_oo
o`80I_l>oooo00<0003oooooool00oooo`030000oooooooo00;oool206Ko<_ooo`03o`2Ioooooooo
063oool0073oool306Ko2oooo`030000oooooooo00?oool300000P1VocCoool00ol0VOooooooo`1P
oooo001coooo0P1Vo`Woool00`000?ooooooo`03oooo00<00000I_l0I_l0=_ooo`03o`2Ioooooooo
063oool007Goool306Ko1_ooo`030000oooooooo00;oool00`1Vo`000?ooo`0goooo00?o09Wooooo
ool0H?ooo`00N?ooo`D0I_l20000101Vo`03oooo0000oooo03Ooool00ol0VOooooooo`1Poooo0024
oooo0P0003Ooool00ol0VOooooooo`1Poooo0024oooo00<0003oooooool0=_ooo`03o`2Ioooooooo
063oool008Coool00`000?ooooooo`0foooo00?o09Woooooool0H?ooo`00Q?ooo`030000oooooooo
03Koool00ol0VOooooooo`1Poooo0024oooo00<0003oooooool0=_ooo`03o`2Ioooooooo063oool0
08Coool20000=oooo`03o`2Ioooooooo063oool008Coool00`000?ooooooo`0foooo00?o09Wooooo
ool0H?ooo`00Q?ooo`030000oooooooo03Koool00ol0VOooooooo`1Poooo0024oooo00<0003ooooo
ool0=_ooo`03o`2Ioooooooo063oool008Coool20000=oooo`03o`2Ioooooooo063oool008Coool0
0`000?ooooooo`0foooo00?o09Woooooool0H?ooo`00Q?ooo`030000oooooooo03Koool00ol0VOoo
ooooo`1Poooo0024oooo00<0003oooooool0=_ooo`03o`2Ioooooooo063oool008Coool00`000?oo
ooooo`0foooo00?o09Woooooool0H?ooo`00Q?ooo`80000goooo00?o09Woooooool0H?ooo`00Q?oo
o`030000oooooooo03Koool00ol0VOooooooo`1Poooo001loooo100000Coool00`000?ooooooo`0f
oooo00?o09Woooooool0H?ooo`00O?ooo`030000oooooooo00Goool00`000?ooooooo`0foooo00?o
09Woooooool0H?ooo`00OOooo`030000oooooooo00Coool30000=_ooo`03o`2Ioooooooo063oool0
07koool00`000?ooooooo`03oooo00<0003oooooool0=_ooo`03o`2Ioooooooo063oool007coool0
10000?ooooooo`0000Coool00`000?ooooooo`0foooo00?o09Woooooool0H?ooo`00OOooo`800005
oooo00<0003oooooool0=_ooo`03o`2Ioooooooo063oool008Coool20000=oooo`03o`2Ioooooooo
063oool008Coool00`000?ooooooo`0foooo00?o09Woooooool0H?ooo`00Q?ooo`030000oooooooo
03Koool00ol0VOooooooo`1Poooo0024oooo00<0003oooooool0=_ooo`03o`2Ioooooooo063oool0
08Coool00`000?ooooooo`0foooo00?o09Woooooool0H?ooo`00Q?ooo`80000goooo00?o09Wooooo
ool0H?ooo`00Q?ooo`030000oooooooo03Koool00ol0VOooooooo`1Poooo0024oooo00<0003ooooo
ool0=_ooo`03o`2Ioooooooo063oool008Coool00`000?ooooooo`0foooo00?o09Woooooool0H?oo
o`00Q?ooo`80000goooo00?o09Woooooool0H?ooo`00Q?ooo`030000oooooooo03Koool00ol0VOoo
ooooo`1Poooo0024oooo00<0003oooooool0=_ooo`03o`2Ioooooooo063oool008Coool00`000?oo
ooooo`0foooo00?o09Woooooool0H?ooo`00Q?ooo`030000oooooooo03Koool00ol0VOooooooo`1P
oooo0024oooo0P0003Ooool00ol0VOooooooo`1Poooo0024oooo00<0003oooooool0=_ooo`03o`2I
oooooooo063oool007goool200001Oooo`030000oooooooo03Koool00ol0VOooooooo`1Poooo001l
oooo00@0003oooooool00004oooo00<0003oooooool0=_ooo`03o`2Ioooooooo063oool007koool0
0`000?ooooooo`03oooo0`0003Koool00ol0VOooooooo`1Poooo001ooooo00<0003oooooool00_oo
o`030000oooooooo03Koool00ol0VOooooooo`1Poooo001loooo00@0003oooooool00004oooo00<0
003oooooool0=_ooo`03o`2Ioooooooo063oool007goool200001Oooo`030000oooooooo03Koool0
0ol0VOooooooo`1Poooo0024oooo00<0003oooooool0=_ooo`03o`2Ioooooooo063oool008Coool2
0000=oooo`03o`2Ioooooooo063oool008Coool00`000?ooooooo`0foooo00?o09Woooooool0H?oo
o`00Q?ooo`030000oooooooo03Koool00ol0VOooooooo`1Poooo0024oooo00<0003oooooool0=_oo
o`03o`2Ioooooooo063oool008Coool20000=oooo`03o`2Ioooooooo063oool008Coool00`000?oo
ooooo`0foooo00?o09Woooooool0H?ooo`00Q?ooo`030000oooooooo03Koool00ol0VOooooooo`1P
oooo0024oooo00<0003oooooool0=_ooo`03o`2Ioooooooo063oool008Coool00`000?ooooooo`0f
oooo00?o09Woooooool0H?ooo`00Q?ooo`80000goooo00?o09Woooooool0H?ooo`00Q?ooo`030000
oooooooo03Koool00ol0VOooooooo`1Poooo0024oooo00<0003oooooool0=_ooo`03o`2Ioooooooo
063oool008Coool00`000?ooooooo`0foooo00?o09Woooooool0H?ooo`00Q?ooo`80000goooo00?o
09Woooooool0H?ooo`00Q?ooo`030000oooooooo03Koool00ol0VOooooooo`1Poooo0024oooo00<0
003oooooool0=_ooo`03o`2Ioooooooo063oool007koool300000oooo`030000oooooooo03Koool0
0ol0VOooooooo`1Poooo001ooooo00<0003oooooool00_ooo`030000oooooooo03Koool00ol0VOoo
ooooo`1Poooo001loooo1@0000?oool30000=_ooo`03o`2Ioooooooo063oool007coool010000?oo
ooooo`000:3oool007goool00`000?ooo`00002Poooo001noooo0P000:3oool00?oooolQoooo003o
oooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003ooooo
ool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000?oool300001?ooo`030000oooooooo
07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_oo
o`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`040000oooooooo
00001?ooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo
00Ooool300001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000Aoooo00<0
003oooooool02?ooo`030000oooooooo00?oool00`000?ooooooo`1koooo001loooo00<0003ooooo
ool04Oooo`80000:oooo0`0000;oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.67958 .26487 L
.6883 .26487 L
.69289 .26487 L
.6954 .26487 L
.69774 .26487 L
.69895 .26487 L
s
.69895 .26487 m
.69947 .61803 L
s
0 .4 1 r
.02381 .26728 m
.04262 .26787 L
.06244 .26864 L
.08255 .26962 L
.10458 .271 L
.12415 .27255 L
.14509 .27465 L
.16639 .27736 L
.18653 .28061 L
.22495 .28927 L
.24479 .29538 L
.26581 .30341 L
.30365 .32262 L
.34394 .34967 L
.38271 .3767 L
.39281 .38234 L
.39815 .38487 L
.40384 .38716 L
.40931 .38894 L
.41426 .39016 L
.41665 .3906 L
.41924 .39098 L
.42043 .39112 L
.42169 .39124 L
.42276 .39132 L
.42393 .39139 L
.42524 .39143 L
.42644 .39145 L
.42707 .39145 L
.42777 .39144 L
.42849 .39143 L
.42917 .3914 L
.43042 .39134 L
.43156 .39125 L
.43282 .39114 L
.43414 .39099 L
.43858 .39027 L
.4411 .38972 L
.44344 .38912 L
.45356 .3856 L
.46436 .38036 L
.50586 .3523 L
.54584 .32498 L
.5843 .30483 L
.60418 .29694 L
.62522 .29018 L
.66311 .2813 L
.68256 .27802 L
.68816 .2772 L
.69347 .27647 L
Mistroke
.69579 .27616 L
.69705 .276 L
.69825 .27585 L
.69893 .27576 L
.69966 .26487 L
.70095 .26487 L
.70345 .26487 L
.74451 .26487 L
.78404 .26487 L
.82207 .26487 L
.86255 .26487 L
.90151 .26487 L
.94292 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo0011
oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
06Ko06Ko00P0I_l00`00001Vo`1Vo`0406Ko1?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`03oooo00?o09T0I_ooool00_ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo01Goool002Soool406Ko00<00000I_l0I_l0101VobGoool00`000?oo
ooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo00koool00`1Vooooooooo`0Hoooo00<0
003oooooool0:Oooo`030000oooooooo01Goool003?oool:06KoAoooo`030000oooooooo03Soool3
06KoG_ooo`00?Oooo`D0I_m2oooo00<0003oooooool0<?ooo`P0I_l2oooo00?o09Woooooool0G?oo
o`00@_ooo`D0I_lmoooo0P0002koool306Ko2_ooo`03o`2Ioooooooo05coool004Ooool406Ko>Ooo
o`030000oooooooo02[oool306Ko3Oooo`03o`2Ioooooooo05coool004_oool206Ko=oooo`030000
oooooooo02Koool406Ko4?ooo`03o`2Ioooooooo05coool004goool306Ko=?ooo`030000oooooooo
027oool506Ko5?ooo`03o`2Ioooooooo05coool0053oool306Ko<Oooo`80000Poooo0P1VoaWoool0
0ol0VOooooooo`1Loooo001Coooo0P1Vobooool00`000?ooooooo`0Moooo0P1Voa_oool00ol0VOoo
ooooo`1Loooo001Eoooo0P1Vobgoool00`000?ooooooo`0Koooo0P1Voagoool00ol0VOooooooo`1L
oooo001Goooo0P1Vob_oool00`000?ooooooo`0Ioooo0P1Voaooool00ol0VOooooooo`1Loooo001I
oooo0P1VobWoool00`000?ooooooo`0Goooo0P1Vob7oool00ol0VOooooooo`1Loooo001Koooo0P1V
obOoool200005_ooo`80I_lSoooo00?o09Woooooool0G?ooo`00GOooo`0306Kooooooooo02Coool0
0`000?ooooooo`0Doooo00<0I_ooooooool08oooo`03o`2Ioooooooo05coool005koool206Ko9?oo
o`030000oooooooo01;oool206Ko9_ooo`03o`2Ioooooooo05coool0063oool00`1Vooooooooo`0Q
oooo00<0003oooooool04Oooo`0306Kooooooooo02Koool00ol0VOooooooo`1Loooo001Qoooo00<0
I_ooooooool08?ooo`80000@oooo0P1VobWoool00ol0VOooooooo`1Loooo001Roooo0P1Vob3oool0
0`000?ooooooo`0=oooo0P1Vob_oool00ol0VOooooooo`1Loooo001Toooo00<0I_ooooooool07Ooo
o`030000oooooooo00coool00`1Vooooooooo`0[oooo00?o09Woooooool0G?ooo`00IOooo`80I_lE
oooo1@0000?oool00`000?ooooooo`0:oooo0P1Vobkoool00ol0VOooooooo`1Loooo001Woooo00<0
I_ooooooool05?ooo`030000oooooooo00?oool00`000?ooooooo`09oooo00<0I_ooooooool0;_oo
o`03o`2Ioooooooo05coool006Soool206Ko5?ooo`030000oooooooo00?oool300002?ooo`0306Ko
oooooooo02ooool00ol0VOooooooo`1Loooo001Zoooo00<0I_ooooooool04Oooo`030000oooooooo
00?oool00`000?ooooooo`06oooo0P1Voc;oool00ol0VOooooooo`1Loooo001[oooo00<0I_oooooo
ool04?ooo`030000oooooooo00?oool00`000?ooooooo`05oooo00<0I_ooooooool0<_ooo`03o`2I
oooooooo05coool006coool206Ko3oooo`800005oooo00<0003oooooool01?ooo`0306Kooooooooo
03?oool00ol0VOooooooo`1Loooo001^oooo00<0I_ooooooool04oooo`800004oooo00<0I_oooooo
ool0=?ooo`03o`2Ioooooooo05coool006ooool206Ko4oooo`040000oooooooooooo0P1VocOoool0
0ol0VOooooooo`1Loooo001aoooo0P1Voa7oool010000?ooooooo`1VocWoool00ol0VOooooooo`1L
oooo001coooo0P1Vo`ooool00`00001Vo`1Vo`0joooo00?o09Woooooool0G?ooo`00MOooo`<0I_l;
oooo00<0I_l0003oool0>oooo`03o`2Ioooooooo05coool007Soool;06Ko00?oool000000000>ooo
o`03o`2Ioooooooo05coool008Coool00`000?ooooooo`0joooo00?o09Woooooool0G?ooo`00Q?oo
o`030000oooooooo03[oool00ol0VOooooooo`1Loooo0024oooo00<0003oooooool0>_ooo`03o`2I
oooooooo05coool008Coool20000>oooo`03o`2Ioooooooo05coool008Coool00`000?ooooooo`0j
oooo00?o09Woooooool0G?ooo`00Q?ooo`030000oooooooo03[oool00ol0VOooooooo`1Loooo0024
oooo00<0003oooooool0>_ooo`03o`2Ioooooooo05coool008Coool00`000?ooooooo`0joooo00?o
09Woooooool0G?ooo`00Q?ooo`80000koooo00?o09Woooooool0G?ooo`00Q?ooo`030000oooooooo
03[oool00ol0VOooooooo`1Loooo001loooo100000Coool00`000?ooooooo`0joooo00?o09Wooooo
ool0G?ooo`00O?ooo`030000oooooooo00Goool00`000?ooooooo`0joooo00?o09Woooooool0G?oo
o`00OOooo`030000oooooooo00Coool30000>_ooo`03o`2Ioooooooo05coool007koool00`000?oo
ooooo`03oooo00<0003oooooool0>oooo`03o`2Ioooooooo05_oool007coool010000?ooooooo`00
00Coool00`000?ooooooo`0koooo00?o09Woooooool0Foooo`00OOooo`800005oooo00<0003ooooo
ool0>oooo`03o`2Ioooooooo05_oool008Coool20000??ooo`03o`2Ioooooooo05_oool008Coool0
0`000?ooooooo`0koooo00?o09Woooooool0Foooo`00Q?ooo`030000oooooooo03_oool00ol0VOoo
ooooo`1Koooo0024oooo00<0003oooooool0>oooo`03o`2Ioooooooo05_oool008Coool00`000?oo
ooooo`0koooo00?o09Woooooool0Foooo`00Q?ooo`80000loooo00?o09Woooooool0Foooo`00Q?oo
o`030000oooooooo03_oool00ol0VOooooooo`1Koooo0024oooo00<0003oooooool0>oooo`03o`2I
oooooooo05_oool008Coool00`000?ooooooo`0koooo00?o09Woooooool0Foooo`00Q?ooo`80000l
oooo00?o09Woooooool0Foooo`00Q?ooo`030000oooooooo03_oool00ol0VOooooooo`1Koooo0024
oooo00<0003oooooool0>oooo`03o`2Ioooooooo05_oool008Coool00`000?ooooooo`0koooo00?o
09Woooooool0Foooo`00Q?ooo`030000oooooooo03_oool00ol0VOooooooo`1Koooo0024oooo0P00
03coool00ol0VOooooooo`1Koooo0024oooo00<0003oooooool0>oooo`03o`2Ioooooooo05_oool0
07goool200001Oooo`030000oooooooo03_oool00ol0VOooooooo`1Koooo001loooo00@0003ooooo
ool00004oooo00<0003oooooool0>oooo`03o`2Ioooooooo05_oool007koool00`000?ooooooo`03
oooo0`0003_oool00ol0VOooooooo`1Koooo001ooooo00<0003oooooool00_ooo`030000oooooooo
03_oool00ol0VOooooooo`1Koooo001loooo00@0003oooooool00004oooo00<0003oooooool0>ooo
o`03o`2Ioooooooo05_oool007goool200001Oooo`030000oooooooo03_oool00ol0VOooooooo`1K
oooo0024oooo00<0003oooooool0>oooo`03o`2Ioooooooo05_oool008Coool20000??ooo`03o`2I
oooooooo05_oool008Coool00`000?ooooooo`0koooo00?o09Woooooool0Foooo`00Q?ooo`030000
oooooooo03_oool00ol0VOooooooo`1Koooo0024oooo00<0003oooooool0>oooo`03o`2Ioooooooo
05_oool008Coool20000??ooo`03o`2Ioooooooo05_oool008Coool00`000?ooooooo`0koooo00?o
09Woooooool0Foooo`00Q?ooo`030000oooooooo03_oool00ol0VOooooooo`1Koooo0024oooo00<0
003oooooool0>oooo`03o`2Ioooooooo05_oool008Coool00`000?ooooooo`0koooo00?o09Wooooo
ool0Foooo`00Q?ooo`80000loooo00?o09Woooooool0Foooo`00Q?ooo`030000oooooooo03_oool0
0ol0VOooooooo`1Koooo0024oooo00<0003oooooool0>oooo`03o`2Ioooooooo05_oool008Coool0
0`000?ooooooo`0koooo00?o09Woooooool0Foooo`00Q?ooo`80000loooo00?o09Woooooool0Fooo
o`00Q?ooo`030000oooooooo03_oool00ol0VOooooooo`1Koooo0024oooo00<0003oooooool0>ooo
o`03o`2Ioooooooo05_oool007koool300000oooo`030000oooooooo03_oool00ol0VOooooooo`1K
oooo001ooooo00<0003oooooool00_ooo`030000oooooooo03_oool00ol0VOooooooo`1Koooo001l
oooo1@0000?oool30000>oooo`03o`2Ioooooooo05_oool007coool010000?ooooooo`000:3oool0
07goool00`000?ooo`00002Poooo001noooo0P000:3oool00?oooolQoooo003ooooo8Oooo`00O?oo
o`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000
oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01_ooo`D00002oooo0P0000Coool200001?ooo`030000oooooooo07_oool007_oool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo
00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000
oooooooo07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo00Soool200001?oo
o`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000Aoooo00<0003oooooool01ooo
o`040000oooooooo00000oooo`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P00
00[oool200000oooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.67958 .26487 L
.69774 .26487 L
.7026 .26487 L
.70787 .26487 L
.71028 .26487 L
.71284 .26487 L
.71502 .26487 L
.71625 .26487 L
s
.71625 .26487 m
.71672 .61803 L
s
0 .4 1 r
.02381 .26785 m
.04262 .26857 L
.06244 .26952 L
.08255 .27073 L
.10458 .27243 L
.12415 .27434 L
.14509 .27692 L
.16639 .28027 L
.18653 .28427 L
.22495 .29494 L
.24479 .30248 L
.26581 .31238 L
.30365 .33606 L
.34394 .3694 L
.38271 .40273 L
.39281 .40967 L
.39815 .41279 L
.40384 .41562 L
.40931 .41781 L
.41426 .41931 L
.41665 .41986 L
.41924 .42033 L
.42043 .4205 L
.42169 .42065 L
.42276 .42075 L
.42393 .42083 L
.42524 .42089 L
.42644 .42091 L
.42707 .42091 L
.42777 .4209 L
.42849 .42088 L
.42917 .42085 L
.43042 .42077 L
.43156 .42066 L
.43282 .42052 L
.43414 .42034 L
.43858 .41945 L
.4411 .41878 L
.44344 .41804 L
.45356 .41369 L
.46436 .40723 L
.50586 .37265 L
.54584 .33897 L
.5843 .31413 L
.60418 .3044 L
.62522 .29607 L
.66311 .28513 L
.68256 .28108 L
.70345 .27762 L
.70836 .27692 L
Mistroke
.71105 .27655 L
.71358 .27621 L
.71503 .27603 L
.71584 .27592 L
.71659 .26487 L
.71722 .26487 L
.71791 .26487 L
.71931 .26487 L
.72462 .26487 L
.74473 .26487 L
.7852 .26487 L
.82416 .26487 L
.86558 .26487 L
.90547 .26487 L
.94386 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo0011
oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
06Ko06Ko00P0I_l00`00001Vooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0E
oooo000Soooo2@1Vo`03000006Kooooo02Woool00`000?ooooooo`0Yoooo00<0003oooooool0:Ooo
o`030000oooooooo01?oool00`1Vooooooooo`0Coooo00<0003oooooool0:Oooo`030000oooooooo
01Goool002koool:06KoC?ooo`030000oooooooo03[oool606KoFOooo`00>?ooo`D0I_m7oooo00<0
003oooooool0=?ooo`H0I_l5oooo00?o09Woooooool0Eoooo`00?Oooo`@0I_m3oooo0P00037oool4
06Ko2oooo`03o`2Ioooooooo05Ooool0047oool306Ko@?ooo`030000oooooooo02goool306Ko3ooo
o`03o`2Ioooooooo05Ooool004Coool406Ko??ooo`030000oooooooo02[oool306Ko4_ooo`03o`2I
oooooooo05Ooool004Soool306Ko>Oooo`030000oooooooo02Ooool306Ko5Oooo`03o`2Ioooooooo
05Ooool004_oool206Ko=oooo`80000Uoooo0`1VoaSoool00ol0VOooooooo`1Goooo001=oooo0`1V
ocCoool00`000?ooooooo`0Roooo0P1Voa_oool00ol0VOooooooo`1Goooo001@oooo0`1Voc7oool0
0`000?ooooooo`0Poooo0P1Voagoool00ol0VOooooooo`1Goooo001Coooo0P1Vobooool00`000?oo
ooooo`0Noooo0P1Voaooool00ol0VOooooooo`1Goooo001Eoooo0P1Vobgoool00`000?ooooooo`0M
oooo00<0I_ooooooool07oooo`03o`2Ioooooooo05Ooool005Ooool00`1Vooooooooo`0Zoooo0P00
01coool206Ko8_ooo`03o`2Ioooooooo05Ooool005Soool206Ko:_ooo`030000oooooooo01[oool0
0`1Vooooooooo`0Roooo00?o09Woooooool0Eoooo`00F_ooo`0306Kooooooooo02Ooool00`000?oo
ooooo`0Hoooo0P1VobGoool00ol0VOooooooo`1Goooo001Koooo0P1VobOoool00`000?ooooooo`0G
oooo00<0I_ooooooool09Oooo`03o`2Ioooooooo05Ooool005goool00`1Vooooooooo`0Toooo0P00
01Koool206Ko:?ooo`03o`2Ioooooooo05Ooool005koool00`1Vooooooooo`0Soooo00<0003ooooo
ool05?ooo`0306Kooooooooo02Soool00ol0VOooooooo`1Goooo001Ooooo00<0I_ooooooool08_oo
o`030000oooooooo01?oool00`1Vooooooooo`0Yoooo00?o09Woooooool0Eoooo`00H?ooo`0306Ko
oooooooo01Woool500000oooo`030000oooooooo017oool206Ko;?ooo`03o`2Ioooooooo05Ooool0
067oool00`1Vooooooooo`0Joooo00<0003oooooool00oooo`030000oooooooo013oool00`1Voooo
ooooo`0/oooo00?o09Woooooool0Eoooo`00H_ooo`80I_lJoooo00<0003oooooool00oooo`<0000?
oooo00<0I_ooooooool0;Oooo`03o`2Ioooooooo05Ooool006Coool00`1Vooooooooo`0Goooo00<0
003oooooool00oooo`030000oooooooo00koool00`1Vooooooooo`0^oooo00?o09Woooooool0Eooo
o`00IOooo`0306Kooooooooo01Koool00`000?ooooooo`03oooo00<0003oooooool03Oooo`0306Ko
oooooooo02ooool00ol0VOooooooo`1Goooo001Voooo00<0I_ooooooool05?ooo`800005oooo00<0
003oooooool02oooo`80I_lboooo00?o09Woooooool0Eoooo`00Ioooo`0306Kooooooooo01[oool2
00002oooo`0306Kooooooooo03;oool00ol0VOooooooo`1Goooo001Xoooo00<0I_ooooooool06Ooo
o`030000oooooooo00Woool00`1Vooooooooo`0coooo00?o09Woooooool0Eoooo`00JOooo`80I_lI
oooo00<0003oooooool02?ooo`0306Kooooooooo03Coool00ol0VOooooooo`1Goooo001[oooo00<0
I_ooooooool05_ooo`030000oooooooo00Koool206Ko=oooo`03o`2Ioooooooo05Ooool006coool0
0`1Vooooooooo`0Eoooo00<0003oooooool01Oooo`0306Kooooooooo03Ooool00ol0VOooooooo`1G
oooo001]oooo00<0I_ooooooool05?ooo`800005oooo00<0I_ooooooool0>?ooo`03o`2Ioooooooo
05Ooool006koool206Ko5?ooo`030000oooooooo00?oool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0Eoooo`00L?ooo`0306Kooooooooo017oool010000?ooooooooooo`80I_lloooo00?o09Wooooo
ool0Eoooo`00LOooo`0306Kooooooooo013oool010000?ooooooo`1Vockoool00ol0VOooooooo`1G
oooo001boooo0P1Voa3oool2000000<0I_ooooooool0?Oooo`03o`2Ioooooooo05Ooool007Coool0
0`1Vooooooooo`0=oooo00<00000I_ooool0?oooo`03o`2Ioooooooo05Ooool007Goool306Ko2ooo
o`0306Ko0000oooo043oool00ol0VOooooooo`1Goooo001hoooo0P1Vo`Goool406Ko00?oool0003o
ool0@?ooo`03o`2Ioooooooo05Ooool007[oool506Ko1Oooo`030000oooooooo03ooool00ol0VOoo
ooooo`1Goooo0024oooo0P00043oool00ol0VOooooooo`1Goooo0024oooo00<0003oooooool0?ooo
o`03o`2Ioooooooo05Ooool007coool400001?ooo`030000oooooooo03ooool00ol0VOooooooo`1G
oooo001loooo00<0003oooooool01Oooo`030000oooooooo03ooool00ol0VOooooooo`1Goooo001m
oooo00<0003oooooool01?ooo`<0000ooooo00?o09Woooooool0Eoooo`00O_ooo`030000oooooooo
00?oool00`000?ooooooo`0ooooo00?o09Woooooool0Eoooo`00O?ooo`040000oooooooo00001?oo
o`030000oooooooo03ooool00ol0VOooooooo`1Goooo001moooo0P0000Goool00`000?ooooooo`0o
oooo00?o09Woooooool0Eoooo`00Q?ooo`800010oooo00?o09Woooooool0Eoooo`00Q?ooo`030000
oooooooo03ooool00ol0VOooooooo`1Goooo0024oooo00<0003oooooool0?oooo`03o`2Ioooooooo
05Ooool008Coool00`000?ooooooo`0ooooo00?o09Woooooool0Eoooo`00Q?ooo`030000oooooooo
03ooool00ol0VOooooooo`1Goooo0024oooo0P00043oool00ol0VOooooooo`1Goooo0024oooo00<0
003oooooool0?oooo`03o`2Ioooooooo05Ooool008Coool00`000?ooooooo`0ooooo00?o09Wooooo
ool0Eoooo`00Q?ooo`030000oooooooo03ooool00ol0VOooooooo`1Goooo0024oooo0P00043oool0
0ol0VOooooooo`1Goooo0024oooo00<0003oooooool0?oooo`03o`2Ioooooooo05Ooool008Coool0
0`000?ooooooo`0ooooo00?o09Woooooool0Eoooo`00Q?ooo`030000oooooooo03ooool00ol0VOoo
ooooo`1Goooo0024oooo00<0003oooooool0?oooo`03o`2Ioooooooo05Ooool008Coool20000@?oo
o`03o`2Ioooooooo05Ooool008Coool00`000?ooooooo`0ooooo00?o09Woooooool0Eoooo`00OOoo
o`800005oooo00<0003oooooool0?oooo`03o`2Ioooooooo05Ooool007coool010000?ooooooo`00
00Coool00`000?ooooooo`0ooooo00?o09Woooooool0Eoooo`00O_ooo`030000oooooooo00?oool3
0000?oooo`03o`2Ioooooooo05Ooool007ooool00`000?ooooooo`02oooo00<0003oooooool0?ooo
o`03o`2Ioooooooo05Ooool007coool010000?ooooooo`0000Coool00`000?ooooooo`0ooooo00?o
09Woooooool0Eoooo`00OOooo`800005oooo00<0003oooooool0?oooo`03o`2Ioooooooo05Ooool0
08Coool00`000?ooooooo`0ooooo00?o09Woooooool0Eoooo`00Q?ooo`800010oooo00?o09Wooooo
ool0Eoooo`00Q?ooo`030000oooooooo03ooool00ol0VOooooooo`1Goooo0024oooo00<0003ooooo
ool0?oooo`03o`2Ioooooooo05Ooool008Coool00`000?ooooooo`0ooooo00?o09Woooooool0Eooo
o`00Q?ooo`800010oooo00?o09Woooooool0Eoooo`00Q?ooo`030000oooooooo03ooool00ol0VOoo
ooooo`1Goooo0024oooo00<0003oooooool0?oooo`03o`2Ioooooooo05Ooool008Coool00`000?oo
ooooo`0ooooo00?o09Woooooool0Eoooo`00Q?ooo`030000oooooooo03ooool00ol0VOooooooo`1G
oooo0024oooo0P00043oool00ol0VOooooooo`1Goooo0024oooo00<0003oooooool0?oooo`03o`2I
oooooooo05Ooool008Coool00`000?ooooooo`0ooooo00?o09Woooooool0Eoooo`00Q?ooo`030000
oooooooo03ooool00ol0VOooooooo`1Goooo0024oooo0P00043oool00ol0VOooooooo`1Goooo0024
oooo00<0003oooooool0?oooo`03o`2Ioooooooo05Ooool008Coool00`000?ooooooo`0ooooo00?o
09Woooooool0Eoooo`00O_ooo`<00003oooo00<0003oooooool0?oooo`03o`2Ioooooooo05Ooool0
07ooool00`000?ooooooo`02oooo00<0003oooooool0?oooo`03o`2Ioooooooo05Ooool007coool5
00000oooo`<0000ooooo00?o09Woooooool0Eoooo`00O?ooo`040000oooooooo0000X?ooo`00OOoo
o`030000oooo00000:3oool007koool20000X?ooo`00ooooob7oool00?oooolQoooo001ooooo00<0
003oooooool07?ooo`030000oooooooo07ooool007koool00`000?ooooooo`08oooo00<0003ooooo
ool04oooo`030000oooooooo07koool007koool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`06oooo100000?oool200001?ooo`030000oooooooo07koool007koool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`0:oooo00<0
003oooooool0O_ooo`00OOooo`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0003ooooo
ool02_ooo`030000oooooooo07goool007koool00`000?ooooooo`0500003_ooo`030000oooooooo
00Soool00`000?ooooooo`1noooo001noooo00D0003oooooooooool000003oooo`040000oooooooo
00002Oooo`030000oooooooo07koool007ooool00`000?ooooooo`0Aoooo0P0000Woool00`000?oo
ooooo`1ooooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.69774 .26487 L
.71741 .26487 L
.72307 .26487 L
.72841 .26487 L
.73074 .26487 L
.73201 .26487 L
.7332 .26487 L
s
.7332 .26487 m
.73371 .61803 L
s
0 .4 1 r
.02381 .26853 m
.04262 .26941 L
.06244 .27058 L
.08255 .27207 L
.10458 .27416 L
.12415 .27651 L
.14509 .27968 L
.16639 .28379 L
.18653 .28872 L
.22495 .30183 L
.24479 .31109 L
.26581 .32326 L
.30365 .35236 L
.34394 .39333 L
.38271 .43428 L
.39281 .44282 L
.39815 .44665 L
.40384 .45013 L
.40931 .45282 L
.41426 .45467 L
.41665 .45534 L
.41924 .45592 L
.42043 .45613 L
.42169 .45631 L
.42276 .45643 L
.42393 .45653 L
.42524 .4566 L
.42644 .45663 L
.42707 .45663 L
.42777 .45661 L
.42849 .45659 L
.42917 .45655 L
.43042 .45645 L
.43156 .45633 L
.43282 .45615 L
.43414 .45592 L
.43858 .45484 L
.4411 .45401 L
.44344 .4531 L
.45356 .44776 L
.46436 .43982 L
.50586 .39732 L
.54584 .35593 L
.5843 .32541 L
.60418 .31345 L
.62522 .30321 L
.66311 .28977 L
.68256 .28479 L
.70345 .28053 L
.71358 .27881 L
Mistroke
.71893 .27798 L
.72462 .27714 L
.72744 .27675 L
.7301 .27639 L
.73126 .27624 L
.73248 .27608 L
.73312 .276 L
.73382 .26487 L
.73506 .26487 L
.74473 .26487 L
.7852 .26487 L
.82416 .26487 L
.86558 .26487 L
.90547 .26487 L
.94386 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo0011
oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
06Ko06Ko00D0I_l3oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00D0003oooooooooool0I_l01_ooo`030000oooooooo00Soool00`000?oo
ooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0
003oooooool05Oooo`007_ooo`X0I_l4oooo00<0003oooooool0:Oooo`030000oooooooo02Woool0
0`000?ooooooo`0Yoooo00<0003oooooool05oooo`0306Kooooooooo00ooool00`000?ooooooo`0Y
oooo00<0003oooooool05Oooo`00:?ooo`/0I_mAoooo00<0003oooooool0@Oooo`<0I_mEoooo000c
oooo1@1Vodcoool00`000?ooooooo`0joooo1`1Vo`;oool00ol0VOooooooo`1Coooo000hoooo1@1V
odOoool20000=_ooo`D0I_l9oooo00?o09Woooooool0Doooo`00?Oooo`@0I_m3oooo00<0003ooooo
ool0<oooo`80I_l>oooo00?o09Woooooool0Doooo`00@Oooo`80I_m1oooo00<0003oooooool0<?oo
o`<0I_l@oooo00?o09Woooooool0Doooo`00@oooo`<0I_lnoooo00<0003oooooool0;Oooo`<0I_lC
oooo00?o09Woooooool0Doooo`00A_ooo`80I_lloooo0P0002_oool306Ko5_ooo`03o`2Ioooooooo
05?oool004Soool306Ko>Oooo`030000oooooooo02Soool206Ko6Oooo`03o`2Ioooooooo05?oool0
04_oool206Ko=oooo`030000oooooooo02Koool206Ko6oooo`03o`2Ioooooooo05?oool004goool2
06Ko=Oooo`030000oooooooo02Coool206Ko7Oooo`03o`2Ioooooooo05?oool004ooool206Ko<ooo
o`030000oooooooo02;oool206Ko7oooo`03o`2Ioooooooo05?oool0057oool206Ko<Oooo`80000Q
oooo0P1Vob7oool00ol0VOooooooo`1Coooo001Coooo0P1Vobooool00`000?ooooooo`0Noooo0P1V
ob?oool00ol0VOooooooo`1Coooo001Eoooo00<0I_ooooooool0;?ooo`030000oooooooo01goool0
0`1Vooooooooo`0Soooo00?o09Woooooool0Doooo`00E_ooo`80I_l/oooo00<0003oooooool07?oo
o`0306Kooooooooo02Coool00ol0VOooooooo`1Coooo001Hoooo00<0I_ooooooool0:Oooo`80000K
oooo0P1VobOoool00ol0VOooooooo`1Coooo001Ioooo00<0I_ooooooool0:?ooo`030000oooooooo
01Woool00`1Vooooooooo`0Woooo00?o09Woooooool0Doooo`00F_ooo`80I_lXoooo00<0003ooooo
ool06?ooo`0306Kooooooooo02Soool00ol0VOooooooo`1Coooo001Loooo00<0I_ooooooool07Ooo
o`D00003oooo00<0003oooooool05_ooo`80I_l[oooo00?o09Woooooool0Doooo`00GOooo`0306Ko
oooooooo01koool00`000?ooooooo`03oooo00<0003oooooool05Oooo`0306Kooooooooo02_oool0
0ol0VOooooooo`1Coooo001Noooo00<0I_ooooooool07Oooo`030000oooooooo00?oool300005?oo
o`0306Kooooooooo02coool00ol0VOooooooo`1Coooo001Ooooo00<0I_ooooooool07?ooo`030000
oooooooo00?oool00`000?ooooooo`0Coooo00<0I_ooooooool0;Oooo`03o`2Ioooooooo05?oool0
063oool00`1Vooooooooo`0Koooo00<0003oooooool00oooo`030000oooooooo01;oool00`1Voooo
ooooo`0^oooo00?o09Woooooool0Doooo`00HOooo`0306Kooooooooo01Woool200001Oooo`030000
oooooooo017oool00`1Vooooooooo`0_oooo00?o09Woooooool0Doooo`00H_ooo`0306Kooooooooo
01ooool200004Oooo`0306Kooooooooo033oool00ol0VOooooooo`1Coooo001Roooo00<0I_oooooo
ool07oooo`030000oooooooo00ooool00`1Vooooooooo`0aoooo00?o09Woooooool0Doooo`00Hooo
o`0306Kooooooooo01koool00`000?ooooooo`0>oooo00<0I_ooooooool0<_ooo`03o`2Ioooooooo
05?oool006Coool00`1Vooooooooo`0Moooo00<0003oooooool03Oooo`0306Kooooooooo03?oool0
0ol0VOooooooo`1Coooo001Uoooo00<0I_ooooooool07?ooo`030000oooooooo00coool00`1Voooo
ooooo`0doooo00?o09Woooooool0Doooo`00I_ooo`0306Kooooooooo01_oool200003?ooo`0306Ko
oooooooo03Goool00ol0VOooooooo`1Coooo001Woooo00<0I_ooooooool06_ooo`030000oooooooo
00[oool00`1Vooooooooo`0foooo00?o09Woooooool0Doooo`00J?ooo`0306Kooooooooo01Woool0
0`000?ooooooo`09oooo00<0I_ooooooool0=oooo`03o`2Ioooooooo05?oool006Woool00`1Voooo
ooooo`0Hoooo00<0003oooooool02?ooo`0306Kooooooooo03Soool00ol0VOooooooo`1Coooo001Z
oooo00<0I_ooooooool05oooo`800008oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo05?oool0
06_oool00`1Vooooooooo`0Foooo00<0003oooooool01_ooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`1Coooo001/oooo00<0I_ooooooool05Oooo`030000oooooooo00Goool00`1Vooooooooo`0k
oooo00?o09Woooooool0Doooo`00KOooo`0306Kooooooooo01Coool00`000?ooooooo`04oooo00<0
I_ooooooool0??ooo`03o`2Ioooooooo05?oool006koool00`1Vooooooooo`0Coooo00<0003ooooo
ool01?ooo`0306Kooooooooo03coool00ol0VOooooooo`1Coooo001_oooo00<0I_ooooooool04_oo
o`800004oooo00<0I_ooooooool0?Oooo`03o`2Ioooooooo05?oool0073oool00`1Vooooooooo`0A
oooo00<0003oooooool00_ooo`0306Kooooooooo03koool00ol0VOooooooo`1Coooo001aoooo00<0
I_ooooooool02?ooo`@00004oooo00D0003oooooooooool0I_l0@Oooo`03o`2Ioooooooo05?oool0
07;oool206Ko2?ooo`030000oooooooo00Goool010000?ooooooo`1Vod;oool00ol0VOooooooo`1C
oooo001doooo00<0I_ooooooool01_ooo`030000oooooooo00Coool30000@oooo`03o`2Ioooooooo
05?oool007Goool00`1Vooooooooo`06oooo00<0003oooooool00oooo`03000006Kooooo04?oool0
0ol0VOooooooo`1Coooo001foooo0P1Vo`Coool010000?ooooooo`0000?oool00`1Vo`000?ooo`14
oooo00?o09Woooooool0Doooo`00N?ooo`80I_l3oooo0P0000@0I_l00oooo`000?ooo`14oooo00?o
09Woooooool0Doooo`00N_ooo`D0I_l5oooo0P0004Coool00ol0VOooooooo`1Coooo0024oooo00<0
003oooooool0@oooo`03o`2Ioooooooo05?oool008Coool00`000?ooooooo`13oooo00?o09Wooooo
ool0Doooo`00Q?ooo`030000oooooooo04?oool00ol0VOooooooo`1Coooo0024oooo00<0003ooooo
ool0@oooo`03o`2Ioooooooo05?oool008Coool20000A?ooo`03o`2Ioooooooo05?oool008Coool0
0`000?ooooooo`13oooo00?o09Woooooool0Doooo`00Q?ooo`030000oooooooo04?oool00ol0VOoo
ooooo`1Coooo0024oooo00<0003oooooool0@oooo`03o`2Ioooooooo05?oool008Coool20000A?oo
o`03o`2Ioooooooo05?oool008Coool00`000?ooooooo`13oooo00?o09Woooooool0Doooo`00Q?oo
o`030000oooooooo04?oool00ol0VOooooooo`1Coooo0024oooo00<0003oooooool0@oooo`03o`2I
oooooooo05?oool008Coool00`000?ooooooo`13oooo00?o09Woooooool0Doooo`00Q?ooo`800014
oooo00?o09Woooooool0Doooo`00Q?ooo`030000oooooooo04?oool00ol0VOooooooo`1Coooo001m
oooo0P0000Goool00`000?ooooooo`13oooo00?o09Woooooool0Doooo`00O?ooo`040000oooooooo
00001?ooo`030000oooooooo04?oool00ol0VOooooooo`1Coooo001noooo00<0003oooooool00ooo
o`<00013oooo00?o09Woooooool0Doooo`00Ooooo`030000oooooooo00;oool00`000?ooooooo`13
oooo00?o09Woooooool0Doooo`00O?ooo`040000oooooooo00001?ooo`030000oooooooo04?oool0
0ol0VOooooooo`1Coooo001moooo0P0000Goool00`000?ooooooo`13oooo00?o09Woooooool0Dooo
o`00Q?ooo`030000oooooooo04?oool00ol0VOooooooo`1Coooo0024oooo0P0004Coool00ol0VOoo
ooooo`1Coooo0024oooo00<0003oooooool0@oooo`03o`2Ioooooooo05?oool008Coool00`000?oo
ooooo`13oooo00?o09Woooooool0Doooo`00Q?ooo`030000oooooooo04?oool00ol0VOooooooo`1C
oooo0024oooo0P0004Coool00ol0VOooooooo`1Coooo0024oooo00<0003oooooool0@oooo`03o`2I
oooooooo05?oool008Coool00`000?ooooooo`13oooo00?o09Woooooool0Doooo`00Q?ooo`030000
oooooooo04?oool00ol0VOooooooo`1Coooo0024oooo00<0003oooooool0@oooo`03o`2Ioooooooo
05?oool008Coool20000A?ooo`03o`2Ioooooooo05?oool008Coool00`000?ooooooo`13oooo00?o
09Woooooool0Doooo`00Q?ooo`030000oooooooo04?oool00ol0VOooooooo`1Coooo0024oooo00<0
003oooooool0@oooo`03o`2Ioooooooo05?oool008Coool20000A?ooo`03o`2Ioooooooo05?oool0
08Coool00`000?ooooooo`13oooo00?o09Woooooool0Doooo`00Q?ooo`030000oooooooo04?oool0
0ol0VOooooooo`1Coooo001noooo0`0000?oool00`000?ooooooo`13oooo00?o09Woooooool0Dooo
o`00Ooooo`030000oooooooo00;oool00`000?ooooooo`13oooo00?o09Woooooool0Doooo`00O?oo
o`D00003oooo0`0004?oool00ol0VOooooooo`1Coooo001loooo00@0003oooooool0002Poooo001m
oooo00<0003oool00000X?ooo`00O_ooo`80002Poooo003ooooo8Oooo`00ooooob7oool007coool0
0`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?oo
ooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Koool400000oooo`800003oooo100000?oool00`000?ooooooo`1koooo001koooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003ooooo
ool02Oooo`030000oooooooo00Coool00`000?ooooooo`1koooo001joooo00<0003oooooool00_oo
o`030000oooooooo00koool00`000?ooooooo`09oooo00<0003oooooool01?ooo`030000oooooooo
07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo00Woool00`000?ooooooo`02
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Ooo
o`80000:oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.69774 .26487 L
.71905 .26487 L
.73838 .26487 L
.74309 .26487 L
.74806 .26487 L
.74932 .26487 L
.75001 .26487 L
.75066 .26487 L
s
.75066 .26487 m
.75097 .61803 L
s
0 .4 1 r
.02381 .26935 m
.04262 .27044 L
.06244 .27187 L
.08255 .2737 L
.10458 .27626 L
.12415 .27914 L
.14509 .28303 L
.16639 .28808 L
.18653 .29411 L
.22495 .31019 L
.24479 .32155 L
.26581 .33648 L
.30365 .37216 L
.34394 .42241 L
.38271 .47264 L
.39281 .48311 L
.39815 .48781 L
.40384 .49208 L
.40931 .49538 L
.41426 .49764 L
.41665 .49847 L
.41924 .49917 L
.42043 .49943 L
.42169 .49965 L
.42276 .4998 L
.42393 .49992 L
.42524 .50001 L
.42644 .50004 L
.42707 .50004 L
.42777 .50003 L
.42849 .49999 L
.42917 .49995 L
.43042 .49983 L
.43156 .49967 L
.43282 .49946 L
.43414 .49918 L
.43858 .49785 L
.4411 .49683 L
.44344 .49572 L
.45356 .48917 L
.46436 .47943 L
.50586 .4273 L
.54584 .37655 L
.5843 .33911 L
.60418 .32444 L
.62522 .31188 L
.66311 .2954 L
.68256 .2893 L
.70345 .28408 L
.7232 .28017 L
Mistroke
.73363 .27844 L
.73935 .27757 L
.74473 .27681 L
.74726 .27647 L
.74864 .27628 L
.74993 .27611 L
.75061 .27603 L
.75133 .26487 L
.75213 .26487 L
.75286 .26487 L
.75555 .26487 L
.76536 .26487 L
.78449 .26487 L
.82438 .26487 L
.86277 .26487 L
.9036 .26487 L
.94292 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo0011
oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
06Ko06Ko00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`06oooo00<0I_ooool000002_ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0E
oooo000Ioooo3`1Vo`Coool00`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo
02Woool00`000?ooooooo`0Loooo00<0I_ooooooool02_ooo`030000oooooooo02Woool00`000?oo
ooooo`0Eoooo000Xoooo1P1VoeKoool00`000?ooooooo`15oooo101Voe3oool002koool506KoDOoo
o`030000oooooooo03ooool606Ko0oooo`03o`2Ioooooooo04koool003?oool506KoC?ooo`80000k
oooo1@1Vo`Woool00ol0VOooooooo`1>oooo000hoooo101VodSoool00`000?ooooooo`0eoooo1@1V
o`koool00ol0VOooooooo`1>oooo000loooo0P1VodKoool00`000?ooooooo`0coooo0P1Voa?oool0
0ol0VOooooooo`1>oooo000noooo0`1Vod?oool00`000?ooooooo`0`oooo0`1VoaGoool00ol0VOoo
ooooo`1>oooo0011oooo0P1Vod7oool20000;oooo`80I_lHoooo00?o09Woooooool0C_ooo`00@ooo
o`<0I_lnoooo00<0003oooooool0;?ooo`80I_lJoooo00?o09Woooooool0C_ooo`00A_ooo`80I_ll
oooo00<0003oooooool0:_ooo`80I_lLoooo00?o09Woooooool0C_ooo`00B?ooo`80I_ljoooo00<0
003oooooool0:?ooo`80I_lNoooo00?o09Woooooool0C_ooo`00B_ooo`80I_lhoooo00<0003ooooo
ool09_ooo`80I_lPoooo00?o09Woooooool0C_ooo`00C?ooo`80I_lfoooo0P0002Goool206Ko8_oo
o`03o`2Ioooooooo04koool004koool00`1Vooooooooo`0coooo00<0003oooooool08_ooo`80I_lT
oooo00?o09Woooooool0C_ooo`00Coooo`80I_lcoooo00<0003oooooool08Oooo`0306Kooooooooo
02Coool00ol0VOooooooo`1>oooo001Aoooo0P1Voc7oool00`000?ooooooo`0Ooooo0P1VobOoool0
0ol0VOooooooo`1>oooo001Coooo0P1Vobooool200007oooo`0306Kooooooooo02Ooool00ol0VOoo
ooooo`1>oooo001Eoooo00<0I_ooooooool0;?ooo`030000oooooooo01goool00`1Vooooooooo`0X
oooo00?o09Woooooool0C_ooo`00E_ooo`0306Kooooooooo02_oool00`000?ooooooo`0Loooo00<0
I_ooooooool0:Oooo`03o`2Ioooooooo04koool005Ooool00`1Vooooooooo`0Roooo1@0000?oool0
0`000?ooooooo`0Koooo00<0I_ooooooool0:_ooo`03o`2Ioooooooo04koool005Soool00`1Voooo
ooooo`0Soooo00<0003oooooool00oooo`030000oooooooo01[oool00`1Vooooooooo`0[oooo00?o
09Woooooool0C_ooo`00FOooo`0306Kooooooooo02;oool00`000?ooooooo`03oooo0`0001Woool0
0`1Vooooooooo`0/oooo00?o09Woooooool0C_ooo`00F_ooo`0306Kooooooooo027oool00`000?oo
ooooo`03oooo00<0003oooooool06?ooo`0306Kooooooooo02goool00ol0VOooooooo`1>oooo001K
oooo00<0I_ooooooool08?ooo`030000oooooooo00?oool00`000?ooooooo`0Hoooo00<0I_oooooo
ool0;Oooo`03o`2Ioooooooo04koool005coool00`1Vooooooooo`0Noooo0P0000Goool00`000?oo
ooooo`0Goooo00<0I_ooooooool0;_ooo`03o`2Ioooooooo04koool005goool00`1Vooooooooo`0T
oooo0P0001Ooool00`1Vooooooooo`0_oooo00?o09Woooooool0C_ooo`00G_ooo`0306Kooooooooo
02?oool00`000?ooooooo`0Eoooo00<0I_ooooooool0<?ooo`03o`2Ioooooooo04koool005ooool0
0`1Vooooooooo`0Roooo00<0003oooooool05?ooo`0306Kooooooooo037oool00ol0VOooooooo`1>
oooo001Ooooo00<0I_ooooooool08_ooo`030000oooooooo01?oool00`1Vooooooooo`0boooo00?o
09Woooooool0C_ooo`00H?ooo`0306Kooooooooo027oool00`000?ooooooo`0Boooo00<0I_oooooo
ool0<oooo`03o`2Ioooooooo04koool0067oool00`1Vooooooooo`0Poooo0P0001;oool00`1Voooo
ooooo`0doooo00?o09Woooooool0C_ooo`00H_ooo`0306Kooooooooo01ooool00`000?ooooooo`0@
oooo00<0I_ooooooool0=Oooo`03o`2Ioooooooo04koool006;oool00`1Vooooooooo`0Ooooo00<0
003oooooool03oooo`0306Kooooooooo03Koool00ol0VOooooooo`1>oooo001Soooo00<0I_oooooo
ool07_ooo`030000oooooooo00koool00`1Vooooooooo`0goooo00?o09Woooooool0C_ooo`00I?oo
o`0306Kooooooooo01goool200003oooo`0306Kooooooooo03Ooool00ol0VOooooooo`1>oooo001U
oooo00<0I_ooooooool07?ooo`030000oooooooo00goool00`1Vooooooooo`0hoooo00?o09Wooooo
ool0C_ooo`00IOooo`0306Kooooooooo01coool00`000?ooooooo`0<oooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo04koool006Koool00`1Vooooooooo`0Koooo00<0003oooooool02oooo`0306Ko
oooooooo03[oool00ol0VOooooooo`1>oooo001Woooo00<0I_ooooooool06_ooo`030000oooooooo
00[oool00`1Vooooooooo`0koooo00?o09Woooooool0C_ooo`00J?ooo`0306Kooooooooo01Woool2
00002_ooo`0306Kooooooooo03coool00ol0VOooooooo`1>oooo001Yoooo00<0I_ooooooool06?oo
o`030000oooooooo00Soool00`1Vooooooooo`0moooo00?o09Woooooool0C_ooo`00JOooo`0306Ko
oooooooo013oool400001?ooo`030000oooooooo00Soool00`1Vooooooooo`0moooo00?o09Wooooo
ool0C_ooo`00J_ooo`0306Kooooooooo00ooool00`000?ooooooo`05oooo00<0003oooooool01ooo
o`0306Kooooooooo03koool00ol0VOooooooo`1>oooo001[oooo00<0I_ooooooool03oooo`030000
oooooooo00Coool300001_ooo`0306Kooooooooo03ooool00ol0VOooooooo`1>oooo001/oooo00<0
I_ooooooool03oooo`030000oooooooo00?oool00`000?ooooooo`05oooo00<0I_ooooooool0@?oo
o`03o`2Ioooooooo04koool006coool00`1Vooooooooo`0=oooo00@0003oooooool00004oooo00<0
003oooooool01Oooo`0306Kooooooooo043oool00ol0VOooooooo`1>oooo001]oooo00<0I_oooooo
ool03Oooo`800005oooo00<0003oooooool01?ooo`0306Kooooooooo047oool00ol0VOooooooo`1>
oooo001^oooo00<0I_ooooooool04oooo`800004oooo00<0I_ooooooool0@_ooo`03o`2Ioooooooo
04koool006ooool00`1Vooooooooo`0Boooo00<0003oooooool00oooo`0306Kooooooooo04;oool0
0ol0VOooooooo`1>oooo001_oooo00<0I_ooooooool04_ooo`030000oooooooo00;oool00`1Voooo
ooooo`13oooo00?o09Woooooool0C_ooo`00L?ooo`0306Kooooooooo017oool01@000?oooooooooo
o`1Vo`16oooo00?o09Woooooool0C_ooo`00LOooo`0306Kooooooooo013oool010000?ooooooo`1V
odOoool00ol0VOooooooo`1>oooo001boooo00<0I_ooooooool03oooo`8000000oooo`1Vooooo`16
oooo00?o09Woooooool0C_ooo`00Loooo`0306Kooooooooo00koool00`000?ooo`1Vo`18oooo00?o
09Woooooool0C_ooo`00M?ooo`0306Kooooooooo00goool00`00001Vooooo`18oooo00?o09Wooooo
ool0C_ooo`00MOooo`0306Kooooooooo00_oool00`1Vo`000?ooo`19oooo00?o09Woooooool0C_oo
o`00M_ooo`80I_l:oooo00@0I_ooool000000019oooo00?o09Woooooool0C_ooo`00N?ooo`<0I_l4
oooo0`1Vo`;oool00`000?ooooooo`18oooo00?o09Woooooool0C_ooo`00N_ooo`D0I_l5oooo00<0
003oooooool0B?ooo`03o`2Ioooooooo04koool008Coool00`000?ooooooo`18oooo00?o09Wooooo
ool0C_ooo`00Q?ooo`030000oooooooo04Soool00ol0VOooooooo`1>oooo0024oooo0P0004Woool0
0ol0VOooooooo`1>oooo0024oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04koool007goool2
00001Oooo`030000oooooooo04Soool00ol0VOooooooo`1>oooo001loooo00@0003oooooool00004
oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04koool007koool00`000?ooooooo`03oooo0`00
04Soool00ol0VOooooooo`1>oooo001ooooo00<0003oooooool00_ooo`030000oooooooo04Soool0
0ol0VOooooooo`1>oooo001loooo00@0003oooooool00004oooo00<0003oooooool0B?ooo`03o`2I
oooooooo04koool007goool200001Oooo`030000oooooooo04Soool00ol0VOooooooo`1>oooo0024
oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04koool008Coool20000BOooo`03o`2Ioooooooo
04koool008Coool00`000?ooooooo`18oooo00?o09Woooooool0C_ooo`00Q?ooo`030000oooooooo
04Soool00ol0VOooooooo`1>oooo0024oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04koool0
08Coool20000BOooo`03o`2Ioooooooo04koool008Coool00`000?ooooooo`18oooo00?o09Wooooo
ool0C_ooo`00Q?ooo`030000oooooooo04Soool00ol0VOooooooo`1>oooo0024oooo00<0003ooooo
ool0B?ooo`03o`2Ioooooooo04koool008Coool00`000?ooooooo`18oooo00?o09Woooooool0C_oo
o`00Q?ooo`800019oooo00?o09Woooooool0C_ooo`00Q?ooo`030000oooooooo04Soool00ol0VOoo
ooooo`1>oooo0024oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04koool008Coool00`000?oo
ooooo`18oooo00?o09Woooooool0C_ooo`00Q?ooo`800019oooo00?o09Woooooool0C_ooo`00Q?oo
o`030000oooooooo04Soool00ol0VOooooooo`1>oooo0024oooo00<0003oooooool0B?ooo`03o`2I
oooooooo04koool007koool300000oooo`030000oooooooo04Soool00ol0VOooooooo`1>oooo001o
oooo00<0003oooooool00_ooo`030000oooooooo04Soool00ol0VOooooooo`1>oooo001loooo1@00
00?oool30000B?ooo`03o`2Ioooooooo04koool007coool010000?ooooooo`000:3oool007goool0
0`000?ooo`00002Poooo001noooo0P000:3oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000
oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo
01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01_ooo`@00003oooo0P0000Goool300000_ooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`0<
oooo00D0003oooooooooool00000OOooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0>
oooo00<0003oooooool02?ooo`D00003oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000>oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00009oooo00<0003oool000000ooo
o`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000_oool200000_ooo`030000
oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.69774 .26487 L
.71905 .26487 L
.73838 .26487 L
.74806 .26487 L
.75315 .26487 L
.75853 .26487 L
.76324 .26487 L
.76453 .26487 L
.76592 .26487 L
.76723 .26487 L
s
.76723 .26487 m
.7677 .61803 L
s
0 .4 1 r
.02381 .27036 m
.04262 .27169 L
.06244 .27345 L
.08255 .27569 L
.10458 .27882 L
.12415 .28235 L
.14509 .28712 L
.16639 .29329 L
.18653 .30069 L
.22495 .32038 L
.24479 .33429 L
.26581 .35257 L
.30365 .39628 L
.34394 .45782 L
.38271 .51933 L
.39281 .53216 L
.39815 .53792 L
.40384 .54314 L
.40931 .54718 L
.41426 .54995 L
.41665 .55097 L
.41924 .55183 L
.42043 .55214 L
.42169 .55241 L
.42276 .5526 L
.42393 .55275 L
.42524 .55286 L
.42644 .5529 L
.42707 .5529 L
.42777 .55288 L
.42849 .55284 L
.42917 .55278 L
.43042 .55263 L
.43156 .55244 L
.43282 .55218 L
.43414 .55184 L
.43858 .55021 L
.4411 .54896 L
.44344 .5476 L
.45356 .53958 L
.46436 .52765 L
.50586 .46381 L
.54584 .40165 L
.5843 .35579 L
.60418 .33783 L
.62522 .32245 L
.66311 .30226 L
.68256 .29479 L
.70345 .2884 L
.7232 .28361 L
Mistroke
.74473 .27949 L
.75472 .2779 L
.7602 .2771 L
.76289 .27673 L
.76536 .27639 L
.76657 .27623 L
.76771 .27609 L
.76889 .26487 L
.77018 .26487 L
.7754 .26487 L
.78449 .26487 L
.82345 .26487 L
.86486 .26487 L
.90476 .26487 L
.94314 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo0011
oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oool0I_l02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0E
oooo000Foooo3@1Vo`Woool00`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo
02Woool00`000?ooooooo`0Poooo00<0I_ooooooool01_ooo`030000oooooooo02Woool00`000?oo
ooooo`0Eoooo000Soooo1@1Voecoool00`000?ooooooo`1:oooo0`1Vodcoool002Soool606KoE_oo
o`030000oooooooo04Coool606Ko0_ooo`03o`2Ioooooooo04[oool002koool506KoDOooo`800010
oooo1@1Vo`Soool00ol0VOooooooo`1:oooo000coooo1@1Vodcoool00`000?ooooooo`0koooo101V
o`goool00ol0VOooooooo`1:oooo000hoooo101VodSoool00`000?ooooooo`0hoooo0`1Voa7oool0
0ol0VOooooooo`1:oooo000loooo0P1VodKoool00`000?ooooooo`0eoooo0`1VoaCoool00ol0VOoo
ooooo`1:oooo000noooo0P1VodCoool20000=?ooo`80I_lGoooo00?o09Woooooool0B_ooo`00@?oo
o`80I_m2oooo00<0003oooooool0<Oooo`80I_lIoooo00?o09Woooooool0B_ooo`00@_ooo`80I_m0
oooo00<0003oooooool0;oooo`80I_lKoooo00?o09Woooooool0B_ooo`00A?ooo`80I_lnoooo00<0
003oooooool0;Oooo`80I_lMoooo00?o09Woooooool0B_ooo`00A_ooo`80I_lloooo00<0003ooooo
ool0:oooo`80I_lOoooo00?o09Woooooool0B_ooo`00B?ooo`80I_ljoooo0P0002[oool206Ko8Ooo
o`03o`2Ioooooooo04[oool004[oool00`1Vooooooooo`0goooo00<0003oooooool0:?ooo`0306Ko
oooooooo027oool00ol0VOooooooo`1:oooo001;oooo0P1VocOoool00`000?ooooooo`0Voooo0P1V
obCoool00ol0VOooooooo`1:oooo001=oooo00<0I_ooooooool0=?ooo`030000oooooooo02Goool0
0`1Vooooooooo`0Toooo00?o09Woooooool0B_ooo`00C_ooo`0306Kooooooooo03?oool200009?oo
o`80I_lWoooo00?o09Woooooool0B_ooo`00Coooo`80I_lcoooo00<0003oooooool08_ooo`0306Ko
oooooooo02Ooool00ol0VOooooooo`1:oooo001Aoooo00<0I_ooooooool0<?ooo`030000oooooooo
027oool00`1Vooooooooo`0Xoooo00?o09Woooooool0B_ooo`00D_ooo`80I_lXoooo1@0000?oool0
0`000?ooooooo`0Ooooo0P1Vob_oool00ol0VOooooooo`1:oooo001Doooo00<0I_ooooooool09ooo
o`030000oooooooo00?oool00`000?ooooooo`0Noooo00<0I_ooooooool0:oooo`03o`2Ioooooooo
04[oool005Goool00`1Vooooooooo`0Voooo00<0003oooooool00oooo`<0000Moooo00<0I_oooooo
ool0;?ooo`03o`2Ioooooooo04[oool005Goool00`1Vooooooooo`0Voooo00<0003oooooool00ooo
o`030000oooooooo01coool00`1Vooooooooo`0]oooo00?o09Woooooool0B_ooo`00E_ooo`0306Ko
oooooooo02Goool00`000?ooooooo`03oooo00<0003oooooool06oooo`0306Kooooooooo02koool0
0ol0VOooooooo`1:oooo001Goooo00<0I_ooooooool08oooo`800005oooo00<0003oooooool06ooo
o`0306Kooooooooo02koool00ol0VOooooooo`1:oooo001Hoooo00<0I_ooooooool0:Oooo`80000K
oooo00<0I_ooooooool0;oooo`03o`2Ioooooooo04[oool005Soool00`1Vooooooooo`0Yoooo00<0
003oooooool06Oooo`0306Kooooooooo033oool00ol0VOooooooo`1:oooo001Ioooo00<0I_oooooo
ool0:?ooo`030000oooooooo01Soool00`1Vooooooooo`0aoooo00?o09Woooooool0B_ooo`00F_oo
o`0306Kooooooooo02Ooool00`000?ooooooo`0Hoooo00<0I_ooooooool0<Oooo`03o`2Ioooooooo
04[oool005_oool00`1Vooooooooo`0Voooo00<0003oooooool05oooo`0306Kooooooooo03;oool0
0ol0VOooooooo`1:oooo001Koooo00<0I_ooooooool09_ooo`80000Goooo00<0I_ooooooool0<ooo
o`03o`2Ioooooooo04[oool005coool00`1Vooooooooo`0Uoooo00<0003oooooool05Oooo`0306Ko
oooooooo03Coool00ol0VOooooooo`1:oooo001Moooo00<0I_ooooooool09?ooo`030000oooooooo
01Goool00`1Vooooooooo`0doooo00?o09Woooooool0B_ooo`00G_ooo`0306Kooooooooo02?oool0
0`000?ooooooo`0Doooo00<0I_ooooooool0=Oooo`03o`2Ioooooooo04[oool005koool00`1Voooo
ooooo`0Soooo0P0001Coool00`1Vooooooooo`0foooo00?o09Woooooool0B_ooo`00Goooo`0306Ko
oooooooo02;oool00`000?ooooooo`0Coooo00<0I_ooooooool0=_ooo`03o`2Ioooooooo04[oool0
063oool00`1Vooooooooo`0Qoooo00<0003oooooool04_ooo`0306Kooooooooo03Ooool00ol0VOoo
ooooo`1:oooo001Poooo00<0I_ooooooool08Oooo`030000oooooooo017oool00`1Vooooooooo`0h
oooo00?o09Woooooool0B_ooo`00HOooo`0306Kooooooooo023oool00`000?ooooooo`0Aoooo00<0
I_ooooooool0>?ooo`03o`2Ioooooooo04[oool006;oool00`1Vooooooooo`0Ooooo0P00017oool0
0`1Vooooooooo`0ioooo00?o09Woooooool0B_ooo`00H_ooo`0306Kooooooooo01ooool00`000?oo
ooooo`0?oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo04[oool006?oool00`1Vooooooooo`0F
oooo100000Coool00`000?ooooooo`0>oooo00<0I_ooooooool0>oooo`03o`2Ioooooooo04[oool0
06Coool00`1Vooooooooo`0Eoooo00<0003oooooool01Oooo`030000oooooooo00koool00`1Voooo
ooooo`0koooo00?o09Woooooool0B_ooo`00I?ooo`0306Kooooooooo01Koool00`000?ooooooo`04
oooo0`0000goool00`1Vooooooooo`0loooo00?o09Woooooool0B_ooo`00IOooo`0306Kooooooooo
01Koool00`000?ooooooo`03oooo00<0003oooooool03?ooo`0306Kooooooooo03goool00ol0VOoo
ooooo`1:oooo001Voooo00<0I_ooooooool04oooo`040000oooooooo00001?ooo`030000oooooooo
00coool00`1Vooooooooo`0moooo00?o09Woooooool0B_ooo`00I_ooo`0306Kooooooooo01Coool2
00001Oooo`030000oooooooo00_oool00`1Vooooooooo`0noooo00?o09Woooooool0B_ooo`00Iooo
o`0306Kooooooooo01[oool200002oooo`0306Kooooooooo03ooool00ol0VOooooooo`1:oooo001X
oooo00<0I_ooooooool06Oooo`030000oooooooo00[oool00`1Vooooooooo`0ooooo00?o09Wooooo
ool0B_ooo`00J?ooo`0306Kooooooooo01Woool00`000?ooooooo`09oooo00<0I_ooooooool0@?oo
o`03o`2Ioooooooo04[oool006Woool00`1Vooooooooo`0Hoooo00<0003oooooool02?ooo`0306Ko
oooooooo047oool00ol0VOooooooo`1:oooo001Yoooo00<0I_ooooooool06?ooo`030000oooooooo
00Soool00`1Vooooooooo`11oooo00?o09Woooooool0B_ooo`00J_ooo`0306Kooooooooo01Ooool2
00002?ooo`0306Kooooooooo04;oool00ol0VOooooooo`1:oooo001[oooo00<0I_ooooooool05_oo
o`030000oooooooo00Koool00`1Vooooooooo`13oooo00?o09Woooooool0B_ooo`00Joooo`0306Ko
oooooooo01Koool00`000?ooooooo`06oooo00<0I_ooooooool0@oooo`03o`2Ioooooooo04[oool0
06coool00`1Vooooooooo`0Eoooo00<0003oooooool01Oooo`0306Kooooooooo04Coool00ol0VOoo
ooooo`1:oooo001]oooo00<0I_ooooooool05?ooo`800006oooo00<0I_ooooooool0A?ooo`03o`2I
oooooooo04[oool006goool00`1Vooooooooo`0Doooo00<0003oooooool01?ooo`0306Kooooooooo
04Goool00ol0VOooooooo`1:oooo001^oooo00<0I_ooooooool04oooo`030000oooooooo00?oool0
0`1Vooooooooo`16oooo00?o09Woooooool0B_ooo`00K_ooo`0306Kooooooooo01?oool00`000?oo
ooooo`03oooo00<0I_ooooooool0A_ooo`03o`2Ioooooooo04[oool006ooool00`1Vooooooooo`0B
oooo00<0003oooooool00_ooo`0306Kooooooooo04Ooool00ol0VOooooooo`1:oooo001`oooo00<0
I_ooooooool04Oooo`800002oooo00<0I_ooooooool0B?ooo`03o`2Ioooooooo04[oool0073oool0
0`1Vooooooooo`0Aoooo00D0003oooooooooool0I_l0B_ooo`03o`2Ioooooooo04[oool0077oool0
0`1Vooooooooo`09oooo0P0000Goool010000?ooooooo`1Vod_oool00ol0VOooooooo`1:oooo001b
oooo00<0I_ooooooool01oooo`040000oooooooo00001?ooo`040000oooooooo06KoBoooo`03o`2I
oooooooo04[oool007?oool00`1Vooooooooo`08oooo00<0003oooooool00oooo`<0001<oooo00?o
09Woooooool0B_ooo`00M?ooo`0306Kooooooooo00Soool00`000?ooooooo`02oooo00<00000I_oo
ool0C?ooo`03o`2Ioooooooo04[oool007Goool00`1Vooooooooo`04oooo00@0003oooooool00004
oooo00<0003oooooool0C?ooo`03o`2Ioooooooo04[oool007Koool00`1Vooooooooo`04oooo0P00
00Coool00`1Vo`000?ooo`1=oooo00?o09Woooooool0B_ooo`00Moooo`0306Kooooooooo00Soool0
0`1Vooooo`00001>oooo00?o09Woooooool0B_ooo`00N?ooo`0306Kooooooooo00Goool206Ko0_oo
o`80001=oooo00?o09Woooooool0B_ooo`00NOooo`L0I_l4oooo00<0003oooooool0C?ooo`03o`2I
oooooooo04[oool008Coool00`000?ooooooo`1<oooo00?o09Woooooool0B_ooo`00Q?ooo`030000
oooooooo04coool00ol0VOooooooo`1:oooo0024oooo0P0004goool00ol0VOooooooo`1:oooo0024
oooo00<0003oooooool0C?ooo`03o`2Ioooooooo04[oool008Coool00`000?ooooooo`1<oooo00?o
09Woooooool0B_ooo`00Q?ooo`030000oooooooo04coool00ol0VOooooooo`1:oooo0024oooo00<0
003oooooool0C?ooo`03o`2Ioooooooo04[oool008Coool20000COooo`03o`2Ioooooooo04[oool0
08Coool00`000?ooooooo`1<oooo00?o09Woooooool0B_ooo`00Q?ooo`030000oooooooo04coool0
0ol0VOooooooo`1:oooo0024oooo00<0003oooooool0C?ooo`03o`2Ioooooooo04[oool008Coool2
0000COooo`03o`2Ioooooooo04[oool008Coool00`000?ooooooo`1<oooo00?o09Woooooool0B_oo
o`00Q?ooo`030000oooooooo04coool00ol0VOooooooo`1:oooo001noooo0`0000?oool00`000?oo
ooooo`1<oooo00?o09Woooooool0B_ooo`00Ooooo`030000oooooooo00;oool00`000?ooooooo`1<
oooo00?o09Woooooool0B_ooo`00O?ooo`D00003oooo0`0004coool00ol0VOooooooo`1:oooo001l
oooo00@0003oooooool0002Poooo001moooo00<0003oool00000X?ooo`00O_ooo`80002Poooo003o
oooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Nooo
o`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Koool400000oooo`800003oooo0`0000Coool0
0`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00<0003oooooool02Oooo`040000oooooooo00000oooo`030000oooooooo
07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooooooo00Soool0
10000?ooooooo`0000Coool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool0
0`000?ooooooo`07oooo0`0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool0
00003oooo`040000oooooooo00002Oooo`030000oooooooo00?oool00`000?ooooooo`1koooo001l
oooo00<0003oooooool04Oooo`80000:oooo0`0000;oool00`000?ooooooo`1loooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.69774 .26487 L
.73838 .26487 L
.75718 .26487 L
.76707 .26487 L
.77751 .26487 L
.78008 .26487 L
.78283 .26487 L
.78364 .26487 L
.78441 .26487 L
.7851 .26487 L
s
.7851 .26487 m
.7854 .61803 L
s
0 .4 1 r
.02381 .27159 m
.04262 .27322 L
.06244 .27536 L
.08255 .27811 L
.10458 .28193 L
.12415 .28626 L
.14509 .29209 L
.16639 .29965 L
.18653 .3087 L
.22495 .33279 L
.24479 .34982 L
.26581 .37218 L
.30365 .42566 L
.34394 .50097 L
.38271 .57624 L
.39281 .59193 L
.39815 .59898 L
.40384 .60537 L
.40931 .61031 L
.41426 .6137 L
.41665 .61495 L
.41924 .61601 L
.42043 .61639 L
.42169 .61672 L
.42276 .61695 L
.42393 .61713 L
.42524 .61726 L
.42644 .61731 L
.42707 .61731 L
.42777 .61728 L
.42849 .61724 L
.42917 .61717 L
.43042 .61699 L
.43156 .61676 L
.43282 .61643 L
.43414 .61602 L
.43858 .61402 L
.4411 .61249 L
.44344 .61082 L
.45356 .60102 L
.46436 .58642 L
.50586 .5083 L
.54584 .43224 L
.5843 .37613 L
.60418 .35415 L
.62522 .33533 L
.66311 .31063 L
.68256 .30148 L
.70345 .29366 L
.7232 .2878 L
Mistroke
.74473 .28276 L
.76559 .27893 L
.77468 .27753 L
.77945 .27686 L
.78206 .2765 L
.78449 .27618 L
.78571 .27602 L
.78701 .26487 L
.78776 .26487 L
.78846 .26487 L
.78978 .26487 L
.79464 .26487 L
.8042 .26487 L
.82518 .26487 L
.86357 .26487 L
.9044 .26487 L
.94372 .26487 L
.97619 .26487 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo0011
oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool00oooo`03o`2I06Kooooo00;oool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool05Oooo`005_ooo`P0I_l>oooo00<0003oooooool0:Oooo`030000oooooooo
02Woool00`000?ooooooo`0Yoooo00<0003oooooool09?ooo`0306Kooooooooo00;oool00`000?oo
ooooo`0Yoooo00<0003oooooool05Oooo`007_ooo`D0I_mQoooo00<0003oooooool0COooo`@0I_m8
oooo000Soooo1@1Voecoool00`000?ooooooo`19oooo101Vo`?oool00ol0VOooooooo`16oooo000X
oooo1P1VoeKoool20000AOooo`D0I_l7oooo00?o09Woooooool0A_ooo`00;_ooo`D0I_mAoooo00<0
003oooooool0@?ooo`@0I_l<oooo00?o09Woooooool0A_ooo`00<oooo`@0I_m=oooo00<0003ooooo
ool0?_ooo`80I_l@oooo00?o09Woooooool0A_ooo`00=oooo`80I_m;oooo00<0003oooooool0>ooo
o`<0I_lBoooo00?o09Woooooool0A_ooo`00>Oooo`<0I_m8oooo0P0003Woool306Ko5Oooo`03o`2I
oooooooo04Koool003coool206KoA_ooo`030000oooooooo03Goool306Ko6?ooo`03o`2Ioooooooo
04Koool003koool206KoA?ooo`030000oooooooo03?oool206Ko6oooo`03o`2Ioooooooo04Koool0
043oool206Ko@_ooo`030000oooooooo037oool206Ko7Oooo`03o`2Ioooooooo04Koool004;oool2
06Ko@?ooo`030000oooooooo02ooool206Ko7oooo`03o`2Ioooooooo04Koool004Coool00`1Voooo
ooooo`0moooo0P0002ooool00`1Vooooooooo`0Ooooo00?o09Woooooool0A_ooo`00AOooo`80I_lm
oooo00<0003oooooool0;?ooo`80I_lRoooo00?o09Woooooool0A_ooo`00Aoooo`80I_lkoooo00<0
003oooooool0:oooo`0306Kooooooooo02;oool00ol0VOooooooo`16oooo0019oooo00<0I_oooooo
ool0>?ooo`030000oooooooo02Woool206Ko9Oooo`03o`2Ioooooooo04Koool004[oool00`1Voooo
ooooo`0goooo0P0002Woool00`1Vooooooooo`0Uoooo00?o09Woooooool0A_ooo`00Boooo`0306Ko
oooooooo03Koool00`000?ooooooo`0Woooo00<0I_ooooooool09_ooo`03o`2Ioooooooo04Koool0
04coool00`1Vooooooooo`0eoooo00<0003oooooool09_ooo`0306Kooooooooo02Ooool00ol0VOoo
ooooo`16oooo001=oooo00<0I_ooooooool0;?ooo`D00003oooo00<0003oooooool09?ooo`80I_lZ
oooo00?o09Woooooool0A_ooo`00C_ooo`0306Kooooooooo02goool00`000?ooooooo`03oooo00<0
003oooooool08oooo`0306Kooooooooo02[oool00ol0VOooooooo`16oooo001?oooo00<0I_oooooo
ool0;?ooo`030000oooooooo00?oool300008_ooo`0306Kooooooooo02_oool00ol0VOooooooo`16
oooo001@oooo00<0I_ooooooool0:oooo`030000oooooooo00?oool00`000?ooooooo`0Qoooo00<0
I_ooooooool0;?ooo`03o`2Ioooooooo04Koool0057oool206Ko:oooo`030000oooooooo00?oool0
0`000?ooooooo`0Poooo00<0I_ooooooool0;Oooo`03o`2Ioooooooo04Koool005?oool00`1Voooo
ooooo`0Woooo0P0000Goool00`000?ooooooo`0Ooooo00<0I_ooooooool0;_ooo`03o`2Ioooooooo
04Koool005Coool00`1Vooooooooo`0]oooo0P0001ooool00`1Vooooooooo`0_oooo00?o09Wooooo
ool0A_ooo`00EOooo`0306Kooooooooo02coool00`000?ooooooo`0Moooo00<0I_ooooooool0<?oo
o`03o`2Ioooooooo04Koool005Goool00`1Vooooooooo`0/oooo00<0003oooooool07?ooo`0306Ko
oooooooo037oool00ol0VOooooooo`16oooo001Foooo00<0I_ooooooool0:oooo`030000oooooooo
01coool00`1Vooooooooo`0aoooo00?o09Woooooool0A_ooo`00Eoooo`0306Kooooooooo02[oool0
0`000?ooooooo`0Koooo00<0I_ooooooool0<_ooo`03o`2Ioooooooo04Koool005Ooool00`1Voooo
ooooo`0Zoooo0P0001coool00`1Vooooooooo`0boooo00?o09Woooooool0A_ooo`00F?ooo`0306Ko
oooooooo02Woool00`000?ooooooo`0Joooo00<0I_ooooooool0<oooo`03o`2Ioooooooo04Koool0
05Soool00`1Vooooooooo`0Yoooo00<0003oooooool06Oooo`0306Kooooooooo03Coool00ol0VOoo
ooooo`16oooo001Ioooo00<0I_ooooooool0:?ooo`030000oooooooo01Woool00`1Vooooooooo`0d
oooo00?o09Woooooool0A_ooo`00F_ooo`0306Kooooooooo02Ooool200006Oooo`0306Kooooooooo
03Goool00ol0VOooooooo`16oooo001Joooo00<0I_ooooooool09oooo`030000oooooooo01Soool0
0`1Vooooooooo`0eoooo00?o09Woooooool0A_ooo`00Foooo`0306Kooooooooo02Koool00`000?oo
ooooo`0Goooo00<0I_ooooooool0=_ooo`03o`2Ioooooooo04Koool005coool00`1Vooooooooo`0U
oooo00<0003oooooool05_ooo`0306Kooooooooo03Ooool00ol0VOooooooo`16oooo001Loooo00<0
I_ooooooool09Oooo`030000oooooooo01Koool00`1Vooooooooo`0goooo00?o09Woooooool0A_oo
o`00GOooo`0306Kooooooooo02Coool200005_ooo`0306Kooooooooo03Soool00ol0VOooooooo`16
oooo001Noooo00<0I_ooooooool08oooo`030000oooooooo01Goool00`1Vooooooooo`0hoooo00?o
09Woooooool0A_ooo`00G_ooo`0306Kooooooooo01_oool400001?ooo`030000oooooooo01Coool0
0`1Vooooooooo`0ioooo00?o09Woooooool0A_ooo`00Goooo`0306Kooooooooo01[oool00`000?oo
ooooo`05oooo00<0003oooooool04oooo`0306Kooooooooo03[oool00ol0VOooooooo`16oooo001O
oooo00<0I_ooooooool06oooo`030000oooooooo00Coool300004oooo`0306Kooooooooo03[oool0
0ol0VOooooooo`16oooo001Poooo00<0I_ooooooool06oooo`030000oooooooo00?oool00`000?oo
ooooo`0Boooo00<0I_ooooooool0>oooo`03o`2Ioooooooo04Koool0063oool00`1Vooooooooo`0I
oooo00@0003oooooool00004oooo00<0003oooooool04_ooo`0306Kooooooooo03_oool00ol0VOoo
ooooo`16oooo001Qoooo00<0I_ooooooool06Oooo`800005oooo00<0003oooooool04Oooo`0306Ko
oooooooo03coool00ol0VOooooooo`16oooo001Qoooo00<0I_ooooooool08?ooo`80000Boooo00<0
I_ooooooool0??ooo`03o`2Ioooooooo04Koool006;oool00`1Vooooooooo`0Ooooo00<0003ooooo
ool04?ooo`0306Kooooooooo03goool00ol0VOooooooo`16oooo001Roooo00<0I_ooooooool07ooo
o`030000oooooooo00ooool00`1Vooooooooo`0noooo00?o09Woooooool0A_ooo`00Hoooo`0306Ko
oooooooo01koool00`000?ooooooo`0?oooo00<0I_ooooooool0?_ooo`03o`2Ioooooooo04Koool0
06?oool00`1Vooooooooo`0Noooo00<0003oooooool03_ooo`0306Kooooooooo03ooool00ol0VOoo
ooooo`16oooo001Toooo00<0I_ooooooool07Oooo`80000?oooo00<0I_ooooooool0?oooo`03o`2I
oooooooo04Koool006Coool00`1Vooooooooo`0Moooo00<0003oooooool03Oooo`0306Kooooooooo
043oool00ol0VOooooooo`16oooo001Uoooo00<0I_ooooooool07?ooo`030000oooooooo00coool0
0`1Vooooooooo`11oooo00?o09Woooooool0A_ooo`00IOooo`0306Kooooooooo01coool00`000?oo
ooooo`0<oooo00<0I_ooooooool0@Oooo`03o`2Ioooooooo04Koool006Koool00`1Vooooooooo`0K
oooo0P0000coool00`1Vooooooooo`12oooo00?o09Woooooool0A_ooo`00I_ooo`0306Kooooooooo
01_oool00`000?ooooooo`0;oooo00<0I_ooooooool0@_ooo`03o`2Ioooooooo04Koool006Ooool0
0`1Vooooooooo`0Joooo00<0003oooooool02_ooo`0306Kooooooooo04?oool00ol0VOooooooo`16
oooo001Xoooo00<0I_ooooooool06Oooo`030000oooooooo00[oool00`1Vooooooooo`13oooo00?o
09Woooooool0A_ooo`00J?ooo`0306Kooooooooo01Woool00`000?ooooooo`09oooo00<0I_oooooo
ool0A?ooo`03o`2Ioooooooo04Koool006Woool00`1Vooooooooo`0Hoooo0P0000Woool00`1Voooo
ooooo`15oooo00?o09Woooooool0A_ooo`00JOooo`0306Kooooooooo01Soool00`000?ooooooo`08
oooo00<0I_ooooooool0AOooo`03o`2Ioooooooo04Koool006[oool00`1Vooooooooo`0@oooo0P00
00Goool00`000?ooooooo`07oooo00<0I_ooooooool0A_ooo`03o`2Ioooooooo04Koool006[oool0
0`1Vooooooooo`0?oooo00@0003oooooool00004oooo00<0003oooooool01oooo`0306Kooooooooo
04Koool00ol0VOooooooo`16oooo001[oooo00<0I_ooooooool04?ooo`030000oooooooo00?oool3
00001_ooo`0306Kooooooooo04Ooool00ol0VOooooooo`16oooo001[oooo00<0I_ooooooool04Ooo
o`030000oooooooo00;oool00`000?ooooooo`06oooo00<0I_ooooooool0Aoooo`03o`2Ioooooooo
04Koool006coool00`1Vooooooooo`0=oooo00@0003oooooool00004oooo00<0003oooooool01Ooo
o`0306Kooooooooo04Soool00ol0VOooooooo`16oooo001/oooo00<0I_ooooooool03_ooo`800005
oooo00<0003oooooool01Oooo`0306Kooooooooo04Soool00ol0VOooooooo`16oooo001]oooo00<0
I_ooooooool05?ooo`030000oooooooo00Coool00`1Vooooooooo`19oooo00?o09Woooooool0A_oo
o`00KOooo`0306Kooooooooo01Coool200001Oooo`0306Kooooooooo04Woool00ol0VOooooooo`16
oooo001^oooo00<0I_ooooooool04oooo`030000oooooooo00?oool00`1Vooooooooo`1:oooo00?o
09Woooooool0A_ooo`00K_ooo`0306Kooooooooo01?oool00`000?ooooooo`03oooo00<0I_oooooo
ool0B_ooo`03o`2Ioooooooo04Koool006ooool00`1Vooooooooo`0Boooo00<0003oooooool00_oo
o`0306Kooooooooo04_oool00ol0VOooooooo`16oooo001_oooo00<0I_ooooooool04_ooo`800003
oooo00<0I_ooooooool0Boooo`03o`2Ioooooooo04Koool0073oool00`1Vooooooooo`0Aoooo00D0
003oooooooooool0I_l0C_ooo`03o`2Ioooooooo04Koool0073oool00`1Vooooooooo`0Aoooo00D0
003oooooooooool0I_l0C_ooo`03o`2Ioooooooo04Koool0077oool00`1Vooooooooo`0@oooo00@0
003oooooool0I_m?oooo00?o09Woooooool0A_ooo`00L_ooo`0306Kooooooooo00ooool010000?oo
ooooo`1Vodooool00ol0VOooooooo`16oooo001boooo00<0I_ooooooool03oooo`8000000`1Voooo
ooooo`1>oooo00?o09Woooooool0A_ooo`00Loooo`0306Kooooooooo00koool00`000?ooo`1Vo`1@
oooo00?o09Woooooool0A_ooo`00M?ooo`0306Kooooooooo00goool00`00001Vooooo`1@oooo00?o
09Woooooool0A_ooo`00M?ooo`0306Kooooooooo00goool00`000?ooooooo`1@oooo00?o09Wooooo
ool0A_ooo`00MOooo`0306Kooooooooo00_oool00`1Vo`000000001Aoooo00?o09Woooooool0A_oo
o`00M_ooo`0306Kooooooooo00Woool00`1Vooooo`00001Boooo00?o09Woooooool0A_ooo`00Mooo
o`0306Kooooooooo00Soool00`1Vooooo`00001Boooo00?o09Woooooool0A_ooo`00N?ooo`0306Ko
oooooooo00?oool3000000@0I_ooooooool0001Boooo00?o09Woooooool0A_ooo`00NOooo`<0I_l2
oooo00<0I_l0003oool00oooo`030000oooooooo053oool00ol0VOooooooo`16oooo001loooo1@00
00?oool30000D?ooo`03o`2Ioooooooo04Koool007coool010000?ooooooo`000:3oool007goool0
0`000?ooo`00002Poooo001noooo0P000:3oool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000
oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo
01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01_ooo`@00003oooo0P0000Coool200001?ooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`09
oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool0
0`000?ooooooo`0>oooo00<0003oooooool02?ooo`040000oooooooo00001?ooo`030000oooooooo
07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo00Soool200001?ooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_oo
o`800003oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
.2 1 0 r
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
.97619 .26487 L
.02381 .26487 L
F
0 g
.02381 .26481 m
.03279 .26479 L
.04262 .26477 L
.06244 .26472 L
.07298 .26467 L
.08426 .26461 L
.0949 .26454 L
.10458 .26446 L
.12373 .26423 L
.13453 .26405 L
.14451 .26383 L
.16324 .26327 L
.17388 .26283 L
.18386 .2623 L
.19424 .26161 L
.20411 .26079 L
.22263 .25865 L
.23222 .25714 L
.24244 .25514 L
.26083 .25021 L
.27111 .24648 L
.28224 .24146 L
.29185 .23613 L
.30241 .22905 L
.32235 .21149 L
.34341 .18635 L
.36456 .1552 L
.38383 .12538 L
.39341 .11203 L
.39845 .10583 L
.40382 .10008 L
.40849 .09588 L
.41097 .094 L
.41365 .09225 L
.41609 .09092 L
.41834 .08993 L
.42048 .0892 L
.42156 .08891 L
.42274 .08866 L
.42406 .08845 L
.42528 .08834 L
.42592 .08831 L
.42661 .08829 L
.42735 .0883 L
.42803 .08833 L
.42929 .08845 L
.43043 .08862 L
.43176 .08889 L
.43302 .08923 L
.43534 .09003 L
Mistroke
.43748 .091 L
.44235 .09394 L
.44768 .09826 L
.4525 .10308 L
.4633 .11644 L
.50342 .17717 L
.52184 .20132 L
.54203 .22186 L
.562 .23641 L
.57291 .24233 L
.58308 .2468 L
.59356 .25052 L
.60347 .25336 L
.62204 .25729 L
.63172 .25878 L
.64199 .26005 L
.66042 .26171 L
.66982 .26232 L
.67993 .26285 L
.69823 .26354 L
.70782 .26381 L
.71831 .26404 L
.72925 .26422 L
.73942 .26436 L
.74997 .26447 L
.75992 .26455 L
.77852 .26466 L
.78826 .26471 L
.79857 .26474 L
.81703 .26479 L
.8265 .2648 L
.83665 .26482 L
.85497 .26484 L
.86513 .26484 L
.87619 .26485 L
.88663 .26485 L
.8963 .26486 L
.91494 .26486 L
.92556 .26486 L
.93554 .26487 L
.94535 .26487 L
.95569 .26487 L
.97419 .26487 L
.97619 .26487 L
Mfstroke
1 0 .6 r
.02381 .26487 m
.06244 .26487 L
.10458 .26487 L
.14415 .26487 L
.18221 .26487 L
.22272 .26487 L
.26171 .26487 L
.30316 .26487 L
.34309 .26487 L
.3815 .26487 L
.42237 .26487 L
.46172 .26487 L
.49955 .26487 L
.53984 .26487 L
.57861 .26487 L
.61984 .26487 L
.65954 .26487 L
.69774 .26487 L
.73838 .26487 L
.77751 .26487 L
.7878 .26487 L
.79321 .26487 L
.79616 .26487 L
.79892 .26487 L
.80134 .26487 L
.80204 .26487 L
.8027 .26487 L
s
.8027 .26487 m
.80319 .61803 L
s
0 .4 1 r
.02381 .27308 m
.04262 .27508 L
.06244 .2777 L
.08255 .28105 L
.10458 .28574 L
.12415 .29102 L
.14509 .29816 L
.16639 .3074 L
.18653 .31846 L
.22495 .34793 L
.24479 .36875 L
.26581 .3961 L
.30365 .4615 L
.34394 .55359 L
s
.34394 .55359 m
.37108 .61803 L
s
.48176 .61803 m
.50586 .56256 L
.54584 .46954 L
.5843 .40093 L
.60418 .37405 L
.62522 .35103 L
.66311 .32082 L
.68256 .30964 L
.70345 .30008 L
.7232 .29291 L
.74473 .28675 L
.76559 .28207 L
.78449 .2787 L
.78937 .27794 L
.79464 .27717 L
.79707 .27683 L
.79962 .27648 L
.80068 .27634 L
.80181 .27619 L
.80304 .26487 L
.8042 .26487 L
.82518 .26487 L
.8666 .26487 L
.9065 .26487 L
.94488 .26487 L
.97619 .26487 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.45671 0.0865801 0.264872 0.0882906 [
[.11039 .25237 -6 -9 ]
[.11039 .25237 6 0 ]
[.28355 .25237 -6 -9 ]
[.28355 .25237 6 0 ]
[.62987 .25237 -3 -9 ]
[.62987 .25237 3 0 ]
[.80303 .25237 -3 -9 ]
[.80303 .25237 3 0 ]
[.97619 .25237 -3 -9 ]
[.97619 .25237 3 0 ]
[.44421 0 -12 -4.5 ]
[.44421 0 0 4.5 ]
[.44421 .08829 -12 -4.5 ]
[.44421 .08829 0 4.5 ]
[.44421 .17658 -12 -4.5 ]
[.44421 .17658 0 4.5 ]
[.44421 .35316 -6 -4.5 ]
[.44421 .35316 0 4.5 ]
[.44421 .44145 -6 -4.5 ]
[.44421 .44145 0 4.5 ]
[.44421 .52974 -6 -4.5 ]
[.44421 .52974 0 4.5 ]
[.44421 .61803 -6 -4.5 ]
[.44421 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 .26487 m
.11039 .27112 L
s
[(-4)] .11039 .25237 0 1 Mshowa
.28355 .26487 m
.28355 .27112 L
s
[(-2)] .28355 .25237 0 1 Mshowa
.62987 .26487 m
.62987 .27112 L
s
[(2)] .62987 .25237 0 1 Mshowa
.80303 .26487 m
.80303 .27112 L
s
[(4)] .80303 .25237 0 1 Mshowa
.97619 .26487 m
.97619 .27112 L
s
[(6)] .97619 .25237 0 1 Mshowa
.125 Mabswid
.15368 .26487 m
.15368 .26862 L
s
.19697 .26487 m
.19697 .26862 L
s
.24026 .26487 m
.24026 .26862 L
s
.32684 .26487 m
.32684 .26862 L
s
.37013 .26487 m
.37013 .26862 L
s
.41342 .26487 m
.41342 .26862 L
s
.5 .26487 m
.5 .26862 L
s
.54329 .26487 m
.54329 .26862 L
s
.58658 .26487 m
.58658 .26862 L
s
.67316 .26487 m
.67316 .26862 L
s
.71645 .26487 m
.71645 .26862 L
s
.75974 .26487 m
.75974 .26862 L
s
.84632 .26487 m
.84632 .26862 L
s
.88961 .26487 m
.88961 .26862 L
s
.9329 .26487 m
.9329 .26862 L
s
.0671 .26487 m
.0671 .26862 L
s
.02381 .26487 m
.02381 .26862 L
s
.25 Mabswid
0 .26487 m
1 .26487 L
s
.45671 0 m
.46296 0 L
s
[(-3)] .44421 0 1 0 Mshowa
.45671 .08829 m
.46296 .08829 L
s
[(-2)] .44421 .08829 1 0 Mshowa
.45671 .17658 m
.46296 .17658 L
s
[(-1)] .44421 .17658 1 0 Mshowa
.45671 .35316 m
.46296 .35316 L
s
[(1)] .44421 .35316 1 0 Mshowa
.45671 .44145 m
.46296 .44145 L
s
[(2)] .44421 .44145 1 0 Mshowa
.45671 .52974 m
.46296 .52974 L
s
[(3)] .44421 .52974 1 0 Mshowa
.45671 .61803 m
.46296 .61803 L
s
[(4)] .44421 .61803 1 0 Mshowa
.125 Mabswid
.45671 .01766 m
.46046 .01766 L
s
.45671 .03532 m
.46046 .03532 L
s
.45671 .05297 m
.46046 .05297 L
s
.45671 .07063 m
.46046 .07063 L
s
.45671 .10595 m
.46046 .10595 L
s
.45671 .12361 m
.46046 .12361 L
s
.45671 .14126 m
.46046 .14126 L
s
.45671 .15892 m
.46046 .15892 L
s
.45671 .19424 m
.46046 .19424 L
s
.45671 .2119 m
.46046 .2119 L
s
.45671 .22956 m
.46046 .22956 L
s
.45671 .24721 m
.46046 .24721 L
s
.45671 .28253 m
.46046 .28253 L
s
.45671 .30019 m
.46046 .30019 L
s
.45671 .31785 m
.46046 .31785 L
s
.45671 .3355 m
.46046 .3355 L
s
.45671 .37082 m
.46046 .37082 L
s
.45671 .38848 m
.46046 .38848 L
s
.45671 .40614 m
.46046 .40614 L
s
.45671 .42379 m
.46046 .42379 L
s
.45671 .45911 m
.46046 .45911 L
s
.45671 .47677 m
.46046 .47677 L
s
.45671 .49443 m
.46046 .49443 L
s
.45671 .51209 m
.46046 .51209 L
s
.45671 .5474 m
.46046 .5474 L
s
.45671 .56506 m
.46046 .56506 L
s
.45671 .58272 m
.46046 .58272 L
s
.45671 .60038 m
.46046 .60038 L
s
.25 Mabswid
.45671 0 m
.45671 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo001moooo0P000:7oool007coool010000?ooooooo`000:3oool007koool00`000?oo
ooooo`03oooo0`0009Woool007Koool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2I
oooo001loooo00@0003oooooool00004oooo00<0003oooooool0VOooo`00OOooo`800005oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool20000V_ooo`00Q?ooo`030000
oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024oooo00<0003oooooool0VOooo`00Q?oo
o`80002Joooo0024oooo00<0003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool0
0`000?ooooooo`2Ioooo0024oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo0024oooo00<0
003oooooool0VOooo`00Q?ooo`030000oooooooo09Woool008Coool00`000?ooooooo`2Ioooo0024
oooo0P0009[oool008Coool00`000?ooooooo`2Ioooo001loooo100000Coool00`000?ooooooo`2I
oooo001loooo00<0003oooooool01Oooo`030000oooooooo09Woool007coool200001_ooo`<0002I
oooo001foooo1P000004<ol00000000000001?ooo`030000oooooooo09Woool007Soool01@0003?o
03?o03?o00000002<ol00P0000?oool00`000?ooooooo`2Ioooo001goooo00<0000co`0co`000c?o
00800002<ol00P000003oooo0000oooo09[oool007Koool00`0003?o03?o000:<ol00P0009_oool0
07Goool00`0003?o03?o000<<ol00P0009[oool007Coool00`0003?o03?o000=<ol000<0003ooooo
ool0VOooo`00Loooo`030000<ol0<ol000hco`020000V_ooo`00Loooo`030000<ol0<ol000hco`00
0`0003?o0000002Ioooo001boooo00<0000co`0co`003c?o008000000c?o00000?ooo`2Goooo001b
oooo00<0000co`0co`003c?o00040000<ol0<ol00000V?ooo`00LOooo`030000<ol0<ol0010co`00
1@0003?o03?o03?o0000002Goooo001aoooo00<0000co`0co`0043?o00030000<ol0<ol0008co`00
0`000?ooooooo`2Doooo001`oooo00<0000co`0co`004C?o00030000<ol0<ol0008co`000`000?oo
ooooo`2Doooo001_oooo00<0000co`0co`004S?o00800004<ol000<0003oooooool0Toooo`00K_oo
o`030000<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00K_ooo`030000
<ol0<ol001<co`000`0003?o03?o0004<ol000<0003oooooool0T_ooo`00KOooo`030000<ol0<ol0
01@co`000`0003?o03?o0005<ol000<0003oooooool0TOooo`00K?ooo`030000<ol0<ol001Dco`02
00001c?o00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001S?o
00030000oooooooo093oool006_oool00`0003?o03?o000F<ol000<0000co`0co`001c?o00030000
oooooooo08ooool006[oool00`0003?o03?o000?<ol01@0000<co`000`0003?o03?o0008<ol000<0
003oooooool0S_ooo`00JOooo`030000<ol0<ol0018co`000`0003?o03?o0003<ol000<0000co`0c
o`0023?o00030000oooooooo08koool006Soool00`0003?o03?o000C<ol000<0000co`0co`000c?o
00<00009<ol000<0003oooooool0SOooo`00J?ooo`030000<ol0<ol000/co`04000013?o00030000
<ol0<ol000<co`000`0003?o03?o000:<ol000<0003oooooool0S?ooo`00Ioooo`030000<ol0<ol0
01@co`000`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo08_oool006Koool0
0`0003?o03?o000D<ol00P0000Dco`000`0003?o03?o000;<ol000<0003oooooool0Roooo`00I_oo
o`030000<ol0<ol001/co`0200003C?o00030000oooooooo08[oool006Goool00`0003?o03?o000L
<ol000<0000co`0co`003C?o00030000oooooooo08Woool006Coool00`0003?o03?o000M<ol000<0
000co`0co`003S?o00030000oooooooo08Soool006?oool00`0003?o03?o000N<ol000<0000co`0c
o`003c?o00030000oooooooo08Ooool006?oool00`0003?o03?o000N<ol000<0000co`0co`0043?o
00030000oooooooo08Koool006;oool00`0003?o03?o000O<ol00P00018co`000`000?ooooooo`25
oooo001Qoooo00<0000co`0co`0083?o00030000<ol0<ol0018co`000`000?ooooooo`24oooo000_
oooo0`0002Ooool400000_ooo`80000S<ol000<0000co`0co`004c?o00030000oooooooo017oool4
0000:_ooo`<0000Woooo0`0001Ooool0033oool00`000?ooooooo`0Voooo00<0003oooooool00_oo
o`030000<ol0<ol002<co`000`0003?o03?o000D<ol000<0003oooooool04?ooo`030000oooooooo
02coool00`000?ooooooo`0Voooo00@0003oooooool0000Foooo000]oooo1@0002Soool010000?oo
ooooo`0002Hco`0200005S?o0080000Aoooo00<0003oooooool0:?ooo`D0000Woooo00@0003ooooo
ool0000Foooo000Woooo100000;oool010000?ooooooo`0002;oool400001?ooo`80000W<ol000<0
000co`0co`005c?o00030000oooooooo00ooool00`000?ooooooo`0Woooo00@0003oooooool0000X
oooo0`0001Ooool002koool00`000?ooo`00000Xoooo0P000003<ol00000<ol002Hco`000`0003?o
03?o000H<ol000<0003oooooool03?ooo`040000oooooooo0000:Oooo`030000oooo000002Woool0
0`000?ooooooo`0Foooo000_oooo0P0002Ooool40000:3?o00030000<ol0<ol001Tco`000`000?oo
ooooo`0<oooo0P0002_oool20000:Oooo`<0000Foooo001Foooo0P0002`co`000`0003?o03?o000J
<ol00P0007goool005Coool20000;S?o0080000M<ol00`0007[oool0057oool30000<3?o00030000
<ol0<ol001lco`060000M?ooo`00Boooo`H0000c<ol000<0000co`0co`009C?o00<0001aoooo0011
oooo2P0003Tco`000`0003?o03?o000X<ol02P0006Ooool0013ooooo00004Oooo`005_ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`0E
oooo000Foooo0`1Voa?oool00`000?ooooooo`0Yoooo00<0003oooooool0:Oooo`030000oooooooo
02Woool00`000?ooooooo`0Xoooo00<0I_l0003oool0:_ooo`030000oooooooo01Goool001Woool:
06KoHOooo`030000oooooooo05?oool206Ko00?o09Woooooool0@Oooo`008oooo`@0I_mMoooo00<0
003oooooool0C_ooo`D0I_l2oooo00?o09Woooooool0@Oooo`009oooo`<0I_mJoooo0P0004[oool5
06Ko1oooo`03o`2Ioooooooo047oool002[oool406KoE_ooo`030000oooooooo04Coool506Ko3?oo
o`03o`2Ioooooooo047oool002koool406KoD_ooo`030000oooooooo043oool406Ko4Oooo`03o`2I
oooooooo047oool003;oool206KoD?ooo`030000oooooooo03koool206Ko5Oooo`03o`2Ioooooooo
047oool003Coool306KoCOooo`80000moooo0P1VoaOoool00ol0VOooooooo`11oooo000goooo0P1V
od_oool00`000?ooooooo`0joooo0P1VoaWoool00ol0VOooooooo`11oooo000ioooo0P1VodWoool0
0`000?ooooooo`0hoooo0P1Voa_oool00ol0VOooooooo`11oooo000koooo0P1VodOoool00`000?oo
ooooo`0eoooo0`1Voagoool00ol0VOooooooo`11oooo000moooo0P1VodGoool00`000?ooooooo`0c
oooo0P1Vob3oool00ol0VOooooooo`11oooo000ooooo00<0I_ooooooool0@_ooo`80000boooo0P1V
ob;oool00ol0VOooooooo`11oooo0010oooo0P1Vod;oool00`000?ooooooo`0`oooo00<0I_oooooo
ool08_ooo`03o`2Ioooooooo047oool004;oool00`1Vooooooooo`0ooooo00<0003oooooool0;ooo
o`0306Kooooooooo02?oool00ol0VOooooooo`11oooo0013oooo00<0I_ooooooool0?_ooo`030000
oooooooo02koool00`1Vooooooooo`0Toooo00?o09Woooooool0@Oooo`00A?ooo`80I_lnoooo0P00
02goool206Ko9oooo`03o`2Ioooooooo047oool004Koool00`1Vooooooooo`0koooo00<0003ooooo
ool0:oooo`0306Kooooooooo02Ooool00ol0VOooooooo`11oooo0017oooo0P1Voc_oool00`000?oo
ooooo`0Zoooo00<0I_ooooooool0:?ooo`03o`2Ioooooooo047oool004Woool00`1Vooooooooo`0`
oooo1@0000?oool00`000?ooooooo`0Yoooo00<0I_ooooooool0:Oooo`03o`2Ioooooooo047oool0
04[oool00`1Vooooooooo`0aoooo00<0003oooooool00oooo`030000oooooooo02Soool00`1Voooo
ooooo`0Zoooo00?o09Woooooool0@Oooo`00Boooo`0306Kooooooooo033oool00`000?ooooooo`03
oooo0`0002Ooool00`1Vooooooooo`0[oooo00?o09Woooooool0@Oooo`00Boooo`0306Kooooooooo
033oool00`000?ooooooo`03oooo00<0003oooooool09_ooo`0306Kooooooooo02coool00ol0VOoo
ooooo`11oooo001<oooo00<0I_ooooooool0;oooo`030000oooooooo00?oool00`000?ooooooo`0U
oooo00<0I_ooooooool0;Oooo`03o`2Ioooooooo047oool004goool00`1Vooooooooo`0]oooo0P00
00Goool00`000?ooooooo`0Toooo00<0I_ooooooool0;_ooo`03o`2Ioooooooo047oool004koool0
0`1Vooooooooo`0coooo0P0002Coool00`1Vooooooooo`0_oooo00?o09Woooooool0@Oooo`00Cooo
o`0306Kooooooooo03;oool00`000?ooooooo`0Roooo00<0I_ooooooool0<?ooo`03o`2Ioooooooo
047oool0053oool00`1Vooooooooo`0aoooo00<0003oooooool08Oooo`0306Kooooooooo037oool0
0ol0VOooooooo`11oooo001Aoooo00<0I_ooooooool0<?ooo`030000oooooooo027oool00`1Voooo
ooooo`0aoooo00?o09Woooooool0@Oooo`00D_ooo`0306Kooooooooo02ooool00`000?ooooooo`0P
oooo00<0I_ooooooool0<_ooo`03o`2Ioooooooo047oool005?oool00`1Vooooooooo`0^oooo0P00
023oool00`1Vooooooooo`0coooo00?o09Woooooool0@Oooo`00E?ooo`0306Kooooooooo02goool0
0`000?ooooooo`0Noooo00<0I_ooooooool0=?ooo`03o`2Ioooooooo047oool005Goool00`1Voooo
ooooo`0/oooo00<0003oooooool07_ooo`0306Kooooooooo03Coool00ol0VOooooooo`11oooo001E
oooo00<0I_ooooooool0;?ooo`030000oooooooo01goool00`1Vooooooooo`0eoooo00?o09Wooooo
ool0@Oooo`00E_ooo`0306Kooooooooo02_oool200007Oooo`0306Kooooooooo03Koool00ol0VOoo
ooooo`11oooo001Foooo00<0I_ooooooool0:oooo`030000oooooooo01coool00`1Vooooooooo`0f
oooo00?o09Woooooool0@Oooo`00Eoooo`0306Kooooooooo02[oool00`000?ooooooo`0Koooo00<0
I_ooooooool0=oooo`03o`2Ioooooooo047oool005Ooool00`1Vooooooooo`0Zoooo00<0003ooooo
ool06oooo`0306Kooooooooo03Ooool00ol0VOooooooo`11oooo001Hoooo00<0I_ooooooool0:Ooo
o`030000oooooooo01[oool00`1Vooooooooo`0hoooo00?o09Woooooool0@Oooo`00F?ooo`0306Ko
oooooooo02Woool200006oooo`0306Kooooooooo03Soool00ol0VOooooooo`11oooo001Ioooo00<0
I_ooooooool0:?ooo`030000oooooooo01Woool00`1Vooooooooo`0ioooo00?o09Woooooool0@Ooo
o`00FOooo`0306Kooooooooo023oool400001?ooo`030000oooooooo01Woool00`1Vooooooooo`0i
oooo00?o09Woooooool0@Oooo`00F_ooo`0306Kooooooooo01ooool00`000?ooooooo`05oooo00<0
003oooooool06?ooo`0306Kooooooooo03[oool00ol0VOooooooo`11oooo001Joooo00<0I_oooooo
ool08?ooo`030000oooooooo00Coool300006?ooo`0306Kooooooooo03[oool00ol0VOooooooo`11
oooo001Koooo00<0I_ooooooool08?ooo`030000oooooooo00?oool00`000?ooooooo`0Goooo00<0
I_ooooooool0>oooo`03o`2Ioooooooo047oool005_oool00`1Vooooooooo`0Noooo00@0003ooooo
ool00004oooo00<0003oooooool05oooo`0306Kooooooooo03_oool00ol0VOooooooo`11oooo001L
oooo00<0I_ooooooool07_ooo`800005oooo00<0003oooooool05_ooo`0306Kooooooooo03coool0
0ol0VOooooooo`11oooo001Loooo00<0I_ooooooool09Oooo`80000Goooo00<0I_ooooooool0??oo
o`03o`2Ioooooooo047oool005goool00`1Vooooooooo`0Toooo00<0003oooooool05Oooo`0306Ko
oooooooo03goool00ol0VOooooooo`11oooo001Moooo00<0I_ooooooool09?ooo`030000oooooooo
01Goool00`1Vooooooooo`0moooo00?o09Woooooool0@Oooo`00G_ooo`0306Kooooooooo02?oool0
0`000?ooooooo`0Doooo00<0I_ooooooool0?_ooo`03o`2Ioooooooo047oool005koool00`1Voooo
ooooo`0Soooo00<0003oooooool05?ooo`0306Kooooooooo03koool00ol0VOooooooo`11oooo001O
oooo00<0I_ooooooool08_ooo`80000Doooo00<0I_ooooooool0?oooo`03o`2Ioooooooo047oool0
05ooool00`1Vooooooooo`0Roooo00<0003oooooool04oooo`0306Kooooooooo03ooool00ol0VOoo
ooooo`11oooo001Poooo00<0I_ooooooool08Oooo`030000oooooooo01;oool00`1Vooooooooo`10
oooo00?o09Woooooool0@Oooo`00H?ooo`0306Kooooooooo027oool00`000?ooooooo`0Boooo00<0
I_ooooooool0@?ooo`03o`2Ioooooooo047oool0063oool00`1Vooooooooo`0Qoooo0P0001;oool0
0`1Vooooooooo`11oooo00?o09Woooooool0@Oooo`00HOooo`0306Kooooooooo023oool00`000?oo
ooooo`0Aoooo00<0I_ooooooool0@Oooo`03o`2Ioooooooo047oool0067oool00`1Vooooooooo`0P
oooo00<0003oooooool04?ooo`0306Kooooooooo04;oool00ol0VOooooooo`11oooo001Roooo00<0
I_ooooooool07oooo`030000oooooooo013oool00`1Vooooooooo`12oooo00?o09Woooooool0@Ooo
o`00H_ooo`0306Kooooooooo01ooool00`000?ooooooo`0?oooo00<0I_ooooooool0@oooo`03o`2I
oooooooo047oool006?oool00`1Vooooooooo`0Noooo0P00013oool00`1Vooooooooo`13oooo00?o
09Woooooool0@Oooo`00Hoooo`0306Kooooooooo01koool00`000?ooooooo`0>oooo00<0I_oooooo
ool0A?ooo`03o`2Ioooooooo047oool006Coool00`1Vooooooooo`0Foooo0P0000Goool00`000?oo
ooooo`0>oooo00<0I_ooooooool0A?ooo`03o`2Ioooooooo047oool006Coool00`1Vooooooooo`0E
oooo00@0003oooooool00004oooo00<0003oooooool03_ooo`0306Kooooooooo04Coool00ol0VOoo
ooooo`11oooo001Toooo00<0I_ooooooool05oooo`030000oooooooo00?oool300003Oooo`0306Ko
oooooooo04Goool00ol0VOooooooo`11oooo001Uoooo00<0I_ooooooool05oooo`030000oooooooo
00;oool00`000?ooooooo`0=oooo00<0I_ooooooool0AOooo`03o`2Ioooooooo047oool006Goool0
0`1Vooooooooo`0Doooo00@0003oooooool00004oooo00<0003oooooool03?ooo`0306Kooooooooo
04Koool00ol0VOooooooo`11oooo001Voooo00<0I_ooooooool05?ooo`800005oooo00<0003ooooo
ool03?ooo`0306Kooooooooo04Koool00ol0VOooooooo`11oooo001Voooo00<0I_ooooooool06ooo
o`030000oooooooo00_oool00`1Vooooooooo`17oooo00?o09Woooooool0@Oooo`00Ioooo`0306Ko
oooooooo01[oool200003?ooo`0306Kooooooooo04Ooool00ol0VOooooooo`11oooo001Woooo00<0
I_ooooooool06_ooo`030000oooooooo00[oool00`1Vooooooooo`18oooo00?o09Woooooool0@Ooo
o`00Ioooo`0306Kooooooooo01[oool00`000?ooooooo`0:oooo00<0I_ooooooool0B?ooo`03o`2I
oooooooo047oool006Soool00`1Vooooooooo`0Ioooo00<0003oooooool02Oooo`0306Kooooooooo
04Woool00ol0VOooooooo`11oooo001Xoooo00<0I_ooooooool06Oooo`80000:oooo00<0I_oooooo
ool0BOooo`03o`2Ioooooooo047oool006Woool00`1Vooooooooo`0Hoooo00<0003oooooool02Ooo
o`0306Kooooooooo04Woool00ol0VOooooooo`11oooo001Yoooo00<0I_ooooooool06?ooo`030000
oooooooo00Soool00`1Vooooooooo`1:oooo00?o09Woooooool0@Oooo`00JOooo`0306Kooooooooo
01Soool00`000?ooooooo`08oooo00<0I_ooooooool0B_ooo`03o`2Ioooooooo047oool006[oool0
0`1Vooooooooo`0Goooo00<0003oooooool01oooo`0306Kooooooooo04_oool00ol0VOooooooo`11
oooo001Zoooo00<0I_ooooooool05oooo`800008oooo00<0I_ooooooool0Boooo`03o`2Ioooooooo
047oool006_oool00`1Vooooooooo`0Foooo00<0003oooooool01_ooo`0306Kooooooooo04coool0
0ol0VOooooooo`11oooo001[oooo00<0I_ooooooool05_ooo`030000oooooooo00Koool00`1Voooo
ooooo`1<oooo00?o09Woooooool0@Oooo`00K?ooo`0306Kooooooooo01Goool00`000?ooooooo`06
oooo00<0I_ooooooool0C?ooo`03o`2Ioooooooo047oool006coool00`1Vooooooooo`0Eoooo0P00
00Koool00`1Vooooooooo`1=oooo00?o09Woooooool0@Oooo`00K?ooo`0306Kooooooooo01Goool0
0`000?ooooooo`05oooo00<0I_ooooooool0COooo`03o`2Ioooooooo047oool006goool00`1Voooo
ooooo`0Doooo00<0003oooooool01?ooo`0306Kooooooooo04koool00ol0VOooooooo`11oooo001]
oooo00<0I_ooooooool03_ooo`<00003oooo00<0003oooooool01?ooo`0306Kooooooooo04koool0
0ol0VOooooooo`11oooo001^oooo00<0I_ooooooool03_ooo`030000oooooooo00;oool00`000?oo
ooooo`03oooo00<0I_ooooooool0Coooo`03o`2Ioooooooo047oool006koool00`1Vooooooooo`0;
oooo1@0000?oool300000oooo`0306Kooooooooo04ooool00ol0VOooooooo`11oooo001loooo00@0
003oooooool0002Poooo001moooo00<0003oool00000X?ooo`00O_ooo`80002Poooo003ooooo8Ooo
o`00ooooob7oool007ooool00`000?ooooooo`0Loooo00<0003oooooool0Ooooo`00O_ooo`030000
oooooooo00Soool00`000?ooooooo`0Coooo00<0003oooooool0O_ooo`00O_ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800004oooo00<0003oooooool0O_oo
o`00O_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`040000oooooooo00002Oooo`030000oooooooo07koool007goool00`000?ooooooo`02oooo00<0
003oooooool03oooo`030000oooooooo00Woool00`000?ooooooo`1moooo001noooo00<0003ooooo
ool01@0000ooool00`000?ooooooo`07oooo00<0003oooooool0O_ooo`00O_ooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Woool00`000?ooooooo`1noooo001ooooo00<0003ooooo
ool04Oooo`800009oooo00<0003oooooool0Ooooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-6.03535, \
-3.20105, 0.0455524, 0.0446699}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-6.03535, -3.20105, 0.0455524, 0.0446699}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Animate[{FilledPlot\[IndentingNewLine][{v[x]}, \ {x, \ \(-5\), \ 
              5}, \ PlotRange -> {\(-3\), 3}, \ 
            Fills \[Rule] {Hue[ .3]}], \[IndentingNewLine]Plot[{10\ UnitStep[
                  x - x0 - t]}, \ {x, \ \(-5\), \ 5}, \ 
            PlotStyle\  \[Rule] \ Hue[0.9], \ 
            PlotRange -> {\(-3\), 3}], \ \[IndentingNewLine]Plot[{g[x, 
                t]}, \ {x, \ \(-5\), \ 5}, 
            PlotStyle\  \[Rule] \ 
              Hue[ .6], \ \ PlotRange -> {\(-3\), 
                3}]}, \ \[IndentingNewLine]{t, \ \(-1.5\), \ 2.5, 0.1}, 
        PlotLabel \[Rule] {"\<t\>", t}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.40095 .30902 L
.42237 .30902 L
.43215 .30902 L
.43755 .30902 L
.44268 .30902 L
.44744 .30902 L
.44874 .30902 L
.45013 .30902 L
.45143 .30902 L
s
.45143 .30902 m
.45179 .61803 L
s
0 .4 1 r
.02381 .30698 m
.04262 .30654 L
.06244 .30596 L
.08426 .30518 L
.10458 .30426 L
.14264 .30193 L
.16305 .30024 L
.18163 .29836 L
.20239 .29579 L
.22156 .29287 L
.25997 .28501 L
.2787 .27998 L
.29932 .27332 L
.33961 .25652 L
.37838 .23606 L
.39809 .22508 L
.41961 .21413 L
.42957 .20989 L
.4402 .20624 L
.44536 .20484 L
.44789 .20425 L
.45023 .20378 L
.45132 .20357 L
.45235 .20339 L
.45342 .30902 L
.45459 .30902 L
.45932 .30902 L
.49822 .30902 L
.53959 .30902 L
.57943 .30902 L
.61776 .30902 L
.65854 .30902 L
.69781 .30902 L
.73556 .30902 L
.77576 .30902 L
.81445 .30902 L
.85559 .30902 L
.89521 .30902 L
.93332 .30902 L
.97388 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol000/co`05
06Ko1C?o00030000<ol0<ol000<co`0300002S?o00030000oooooooo087oool0077oool00`0003?o
03?o0009<ol00P1Vo`8co`04000013?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0
003oooooool0P?ooo`00L?ooo`030000<ol0<ol000Pco`0206Ko1S?o000306Ko<ol0<ol000<co`00
0`0003?o03?o0003<ol000<0000co`0co`002c?o00030000oooooooo083oool006ooool00`0003?o
03?o0007<ol00P1Vo`Pco`000`1Voc?o03?o0002<ol00P0000Dco`000`0003?o03?o000<<ol000<0
003oooooool0Ooooo`00K_ooo`030000<ol0<ol000Hco`0206Ko2S?o000306Ko<ol0<ol000Tco`00
0`0003?o03?o000=<ol000<0003oooooool0O_ooo`00K_ooo`030000<ol0<ol000@co`0206Ko33?o
000306Ko<ol0<ol000Tco`000`0003?o03?o000=<ol000<0003oooooool0O_ooo`00KOooo`030000
<ol0<ol000<co`0206Ko3S?o000306Ko<ol0<ol000Tco`0200003c?o00030000oooooooo07goool0
06coool00`0003?o03?o0002<ol00P1Voa0co`000`1Voc?o03?o0009<ol000<0000co`0co`003c?o
00030000oooooooo07coool006_oool00`0003?o03?o0002<ol000<0I_lco`0co`0043?o000306Ko
<ol0<ol000Tco`000`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`040000<ol0<ol0
<ol00P1Voa<co`000`1Voc?o03?o0009<ol000<0000co`0co`0043?o00030000oooooooo07_oool0
06[oool0100003?o001Vo`1VoaDco`000`1Voc?o03?o0009<ol000<0000co`0co`004C?o00030000
oooooooo07[oool006Woool00`00001Vo`1Vo`0G<ol000<0I_lco`0co`002C?o0080000C<ol000<0
003oooooool0NOooo`00J?ooo`80I_lI<ol000<0I_lco`0co`002C?o00030000<ol0<ol001<co`00
0`000?ooooooo`1hoooo001Uoooo0`1Voa/co`000`1Voc?o03?o0009<ol000<0000co`0co`0053?o
00030000oooooooo07Ooool006?oool206Ko00?oool0000co`006c?o000306Ko<ol0<ol000Tco`00
0`0003?o03?o000E<ol000<0003oooooool0M_ooo`00<Oooo`<0000/oooo10000003oooo0000<ol0
01`co`000`1Voc?o03?o0009<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:Oooo`80I_l01@000?ooooooooooo`00000N<ol000<0
I_lco`0co`002C?o0080000H<ol000<0003oooooool04Oooo`030000oooooooo037oool00`000?oo
ooooo`0/oooo000_oooo1@0002Ooool306Ko0oooo`030000oooo000001lco`000`1Voc?o03?o0009
<ol000<0000co`0co`0063?o00030000oooooooo017oool00`000?ooooooo`0]oooo1@0002goool0
02Woool400000_ooo`040000oooooooo00009_ooo`0306Ko0000000000800003oooo0P00020co`00
0`1Voc?o03?o0009<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000
oooooooo0000;_ooo`00<?ooo`030000oooo000002;oool406Ko1_ooo`800002<ol000<0000co`0c
o`007C?o000306Ko<ol0<ol000Tco`000`0003?o03?o000K<ol00P0000koool010000?ooooooo`00
02koool00`000?ooo`00000^oooo000aoooo0P0001goool506Ko2?ooo`800002<ol00P00020co`00
0`1Voc?o03?o0009<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Booo
o`D0I_l;oooo0P0002Hco`000`1Voc?o03?o0009<ol00P00020co`020000KOooo`00Aoooo`@0I_l=
oooo0`0002Pco`000`1Voc?o03?o0009<ol000<0000co`0co`008C?o00<0001Zoooo0012oooo1@1V
o`koool30000:c?o000306Ko<ol0<ol000Tco`000`0003?o03?o000T<ol01@0006Goool003Soool:
06Ko3?ooo`L0000^<ol000<0I_lco`0co`002C?o00030000<ol0<ol002Tco`060000Goooo`009?oo
oa@0I_l@oooo1P0003Dco`000`1Voc?o03?o0009<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo01Goool002koool0
0`000?ooooooo`0^oooo00<0003oooooool08Oooo`03o`2Ioooooooo00Woool00`000?ooooooo`0]
oooo00<0003oooooool0;_ooo`030000oooooooo02goool008?oool00ol0VOooooooo`09oooo00<0
003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o
09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo0P0008ooool0
08?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool0
0`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool0
0ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool20000Sooo
o`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Ooo
o`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Pooo
o`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`80002?
oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09
oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023
oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo0P00
08ooool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo
00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool0
08?oool01?l0VOooooooooooo`D00003oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo
00?oool00`000?ooooooo`03oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00?oool0
0`000?ooooooo`03oooo0`0008koool008?oool00ol0VOooooooo`03oooo00<0003oooooool00ooo
o`030000oooooooo08koool008?oool00ol0VOooooooo`03oooo00<0003oooooool00oooo`030000
oooooooo08koool008?oool00ol0VOooooooo`02oooo0P0000Goool00`000?ooooooo`2>oooo0023
oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo0P00
08ooool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo
00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool0
08?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool2
0000Soooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Wooooo
ool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_oo
o`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Ooo
o`80002?oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOoo
ooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>
oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09
oooo0P0008ooool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2I
oooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo
08koool008?oool01?l0VOooooooooooo`@00004oooo00<0003oooooool0S_ooo`00Poooo`05o`2I
oooooooooooo000000Ooool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool00_ooo`030000
oooooooo00Coool30000S_ooo`00Poooo`03o`2Ioooooooo00?oool00`000?ooooooo`03oooo00<0
003oooooool0S_ooo`00Poooo`05o`2Ioooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00;oool200001Oooo`030000oooooooo08koool0
08?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool2
0000Soooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Wooooo
ool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_oo
o`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Ooo
o`80002?oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOoo
ooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>
oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09
oooo0P0008ooool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2I
oooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo
08koool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo
00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`80002?oooo0023oooo00?o
09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003ooooo
ool0S_ooo`00Poooo`03o`2Ioooooooo00;oool200001Oooo`030000oooooooo08koool008?oool0
1Ol0VOooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo08koool008?oool0
0ol0VOooooooo`03oooo00<0003oooooool00oooo`<0002>oooo002:oooo00<0003oooooool0Tooo
o`00Qoooo`040000oooooooo0000UOooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool0
07Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool0
0`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00coool500000_ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo1000
00Goool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Mooo
o`030000oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool02_ooo`030000oooooooo
00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001Coool00`000?ooooooo`08
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005oooo`030000
oooooooo00Soool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo
01Ooool200002_ooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.45262 .30902 L
.45734 .30902 L
.45963 .30902 L
.46063 .30902 L
.46172 .30902 L
s
.46172 .30902 m
.46205 .61803 L
s
0 .4 1 r
.02381 .3072 m
.04262 .3068 L
.06244 .30628 L
.08426 .30558 L
.10458 .30477 L
.14264 .30268 L
.16305 .30117 L
.18163 .29949 L
.20239 .29718 L
.22156 .29457 L
.25997 .28755 L
.2787 .28304 L
.29932 .27709 L
.33961 .26207 L
.37838 .24377 L
.39809 .23395 L
.41961 .22416 L
.42957 .22036 L
.4402 .2171 L
.44536 .21585 L
.45023 .2149 L
.45459 .21424 L
.45705 .21395 L
.45932 .21374 L
.46058 .21365 L
.46177 .21358 L
.46285 .30902 L
.46401 .30902 L
.46905 .30902 L
.47814 .30902 L
.4988 .30902 L
.53959 .30902 L
.57885 .30902 L
.6166 .30902 L
.65681 .30902 L
.69549 .30902 L
.73663 .30902 L
.77626 .30902 L
.81437 .30902 L
.85493 .30902 L
.89397 .30902 L
.93547 .30902 L
.97545 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`0043?o00<0I_l3<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`00
0`000?ooooooo`20oooo001_oooo00<0000co`0co`003C?o00@0I_l2<ol000<0I_lco`0co`000P00
00Dco`000`0003?o03?o000<<ol000<0003oooooool0Ooooo`00K_ooo`030000<ol0<ol000`co`02
06Ko1S?o000306Ko<ol0<ol000Lco`000`0003?o03?o000=<ol000<0003oooooool0O_ooo`00K_oo
o`030000<ol0<ol000Tco`0306Ko23?o000306Ko<ol0<ol000Lco`000`0003?o03?o000=<ol000<0
003oooooool0O_ooo`00KOooo`030000<ol0<ol000Lco`0306Ko2c?o000306Ko<ol0<ol000Lco`02
00003c?o00030000oooooooo07goool006coool00`0003?o03?o0006<ol00P1Vo`hco`000`1Voc?o
03?o0007<ol000<0000co`0co`003c?o00030000oooooooo07coool006_oool00`0003?o03?o0005
<ol00P1Voa0co`000`1Voc?o03?o0007<ol000<0000co`0co`0043?o00030000oooooooo07_oool0
06[oool00`0003?o03?o0004<ol00P1Voa8co`000`1Voc?o03?o0007<ol000<0000co`0co`0043?o
00030000oooooooo07_oool006[oool00`0003?o03?o0003<ol000<0I_lco`0co`004S?o000306Ko
<ol0<ol000Lco`000`0003?o03?o000A<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol0
008co`0206Ko5C?o000306Ko<ol0<ol000Lco`0200004c?o00030000oooooooo07Woool006Soool0
100003?o03?o03?o0080I_lG<ol000<0I_lco`0co`001c?o00030000<ol0<ol001<co`000`000?oo
ooooo`1hoooo001Woooo00<0000co`0co`000P1VoaTco`000`1Voc?o03?o0007<ol000<0000co`0c
o`0053?o00030000oooooooo07Ooool006Koool0100003?o001Vo`1Voa/co`000`1Voc?o03?o0007
<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?ooo`@000001?ooo`1V
o`1Vo`1Voahco`000`1Voc?o03?o0006<ol000<0000co`0co`005S?o00030000oooooooo01;oool4
0000;oooo`<0000]oooo000boooo00<0003oooooool0:oooo`030000oooo06Ko0080I_lQ<ol000<0
I_lco`0co`001S?o0080000H<ol000<0003oooooool04Oooo`030000oooooooo037oool00`000?oo
ooooo`0/oooo000_oooo1@0002[oool306Ko00<0003oool000008S?o000306Ko<ol0<ol000Hco`00
0`0003?o03?o000H<ol000<0003oooooool04Oooo`030000oooooooo02goool50000;Oooo`00:Ooo
o`@00002oooo00@0003oooooool0000Woooo100000?oool200008c?o000306Ko<ol0<ol000Hco`00
0`0003?o03?o000I<ol00P0001;oool00`000?ooooooo`0/oooo00@0003oooooool0000^oooo000`
oooo00<0003oool000009_ooo`80I_l4oooo0P00008co`000`0003?o03?o000P<ol000<0I_lco`0c
o`001S?o00030000<ol0<ol001/co`0200003_ooo`040000oooooooo0000;_ooo`030000oooo0000
02koool0037oool200008_ooo`@0I_l4oooo0P00008co`0200008c?o000306Ko<ol0<ol000Hco`00
0`0003?o03?o000M<ol00P0000goool20000<?ooo`80000^oooo001@oooo1@1Vo`Koool20000:C?o
000306Ko<ol0<ol000Hco`02000083?o0080001]oooo001;oooo1@1Vo`Soool30000:c?o000306Ko
<ol0<ol000Hco`000`0003?o03?o000Q<ol00`0006[oool004;oool906Ko2_ooo`<0000^<ol000<0
I_lco`0co`001S?o00030000<ol0<ol002@co`050000IOooo`00>?ooo`X0I_l<oooo1`00034co`00
0`1Voc?o03?o0006<ol000<0000co`0co`00:C?o00H0001Ooooo000Yoooo3`1Voa3oool60000>3?o
000306Ko<ol0<ol000Hco`000`0003?o03?o000_<ol01P0005Woool0013ooooo00004Oooo`005_oo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000ooooo`2I00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool05Oooo`00;_ooo`030000oooooooo02koool0
0`000?ooooooo`0Soooo00?o09Woooooool01oooo`030000oooooooo02goool00`000?ooooooo`0^
oooo00<0003oooooool0;Oooo`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>oooo0025
oooo00?o09Woooooool01oooo`030000oooooooo08koool008Goool00ol0VOooooooo`07oooo00<0
003oooooool0S_ooo`00QOooo`03o`2Ioooooooo00Ooool20000Soooo`00QOooo`03o`2Ioooooooo
00Ooool00`000?ooooooo`2>oooo0025oooo00?o09Woooooool01oooo`030000oooooooo08koool0
08Goool00ol0VOooooooo`07oooo00<0003oooooool0S_ooo`00QOooo`03o`2Ioooooooo00Ooool0
0`000?ooooooo`2>oooo0025oooo00?o09Woooooool01oooo`80002?oooo0025oooo00?o09Wooooo
ool01oooo`030000oooooooo08koool008Goool00ol0VOooooooo`07oooo00<0003oooooool0S_oo
o`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>oooo0025oooo00?o09Woooooool01ooo
o`030000oooooooo08koool008Goool00ol0VOooooooo`07oooo0P0008ooool008Goool00ol0VOoo
ooooo`07oooo00<0003oooooool0S_ooo`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>
oooo0025oooo00?o09Woooooool01oooo`030000oooooooo08koool008Goool00ol0VOooooooo`07
oooo00<0003oooooool0S_ooo`00QOooo`03o`2Ioooooooo00Ooool20000Soooo`00QOooo`03o`2I
oooooooo00Ooool00`000?ooooooo`2>oooo0025oooo00?o09Woooooool01oooo`030000oooooooo
08koool008Goool00ol0VOooooooo`07oooo00<0003oooooool0S_ooo`00QOooo`03o`2Ioooo0000
00@00003oooo00<0003oooooool0S_ooo`00QOooo`05o`2Ioooooooooooo000000Goool00`000?oo
ooooo`2>oooo0025oooo00Go09Woooooooooool000001Oooo`<0002>oooo0025oooo00Go09Wooooo
ooooool000001Oooo`030000oooooooo08koool008Goool01Ol0VOooooooooooo`000005oooo00<0
003oooooool0S_ooo`00QOooo`03o`2Ioooooooo00800005oooo00<0003oooooool0S_ooo`00QOoo
o`03o`2Ioooooooo00Ooool00`000?ooooooo`2>oooo0025oooo00?o09Woooooool01oooo`80002?
oooo0025oooo00?o09Woooooool01oooo`030000oooooooo08koool008Goool00ol0VOooooooo`07
oooo00<0003oooooool0S_ooo`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>oooo0025
oooo00?o09Woooooool01oooo`030000oooooooo08koool008Goool00ol0VOooooooo`07oooo0P00
08ooool008Goool00ol0VOooooooo`07oooo00<0003oooooool0S_ooo`00QOooo`03o`2Ioooooooo
00Ooool00`000?ooooooo`2>oooo0025oooo00?o09Woooooool01oooo`030000oooooooo08koool0
08Goool00ol0VOooooooo`07oooo00<0003oooooool0S_ooo`00QOooo`03o`2Ioooooooo00Ooool2
0000Soooo`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>oooo0025oooo00?o09Wooooo
ool01oooo`030000oooooooo08koool008Goool00ol0VOooooooo`07oooo00<0003oooooool0S_oo
o`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>oooo0025oooo00?o09Woooooool01ooo
o`80002?oooo0025oooo00?o09Woooooool01oooo`030000oooooooo08koool008Goool00ol0VOoo
ooooo`07oooo00<0003oooooool0S_ooo`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>
oooo0025oooo00?o09Woool000000`0000Coool00`000?ooooooo`2>oooo0025oooo00?o09Woool0
00001oooo`030000oooooooo08koool008Goool01?l0VOooooooo`0000Koool30000S_ooo`00QOoo
o`05o`2Ioooooooooooo000000Goool00`000?ooooooo`2>oooo0025oooo00?o09Woool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`2>oooo0025oooo00?o09Woooooool00P0000Goool0
0`000?ooooooo`2>oooo0025oooo00?o09Woooooool01oooo`030000oooooooo08koool008Goool0
0ol0VOooooooo`07oooo0P0008ooool008Goool00ol0VOooooooo`07oooo00<0003oooooool0S_oo
o`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>oooo0025oooo00?o09Woooooool01ooo
o`030000oooooooo08koool008Goool00ol0VOooooooo`07oooo00<0003oooooool0S_ooo`00QOoo
o`03o`2Ioooooooo00Ooool20000Soooo`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>
oooo0025oooo00?o09Woooooool01oooo`030000oooooooo08koool008Goool00ol0VOooooooo`07
oooo00<0003oooooool0S_ooo`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>oooo0025
oooo00?o09Woooooool01oooo`80002?oooo0025oooo00?o09Woooooool01oooo`030000oooooooo
08koool008Goool00ol0VOooooooo`07oooo00<0003oooooool0S_ooo`00QOooo`03o`2Ioooooooo
00Ooool00`000?ooooooo`2>oooo0025oooo00?o09Woooooool01oooo`030000oooooooo08koool0
08Goool00ol0VOooooooo`07oooo00<0003oooooool0S_ooo`00QOooo`03o`2Ioooooooo00Ooool2
0000Soooo`00QOooo`03o`2Ioooooooo00Ooool00`000?ooooooo`2>oooo0025oooo00?o09Wooooo
ool01oooo`030000oooooooo08koool008Goool00ol0VOooooooo`0200001Oooo`030000oooooooo
08koool008Goool00ol0VOooo`000002oooo00<0003oooooool00_ooo`030000oooooooo08koool0
08Goool01Ol0VOooooooooooo`000005oooo0`0008koool008[oool00`000?ooooooo`2Coooo0027
oooo00@0003oooooool0002Eoooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00NOoo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03?ooo`D00002oooo0P0000Goool300000_ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400001Ooo
o`030000oooooooo00[oool01@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_oo
o`030000oooooooo01Goool00`000?ooooooo`07oooo1@0000?oool00`000?ooooooo`1goooo001h
oooo00<0003oooooool01@0001Coool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000001Ooool00`000?ooooooo`08oooo00<0
003oool000000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000_oool2
00000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.45262 .30902 L
.46172 .30902 L
.46618 .30902 L
.46854 .30902 L
.46984 .30902 L
.47106 .30902 L
s
.47106 .30902 m
.47141 .61803 L
s
0 .4 1 r
.02381 .30739 m
.04262 .30704 L
.06244 .30658 L
.08426 .30595 L
.10458 .30523 L
.14264 .30337 L
.16305 .30202 L
.18163 .30052 L
.20239 .29846 L
.22156 .29613 L
.25997 .28987 L
.2787 .28585 L
.29932 .28054 L
.33961 .26715 L
.37838 .25083 L
.39809 .24207 L
.41961 .23333 L
.42957 .22995 L
.4402 .22704 L
.44536 .22592 L
.45023 .22507 L
.45459 .22449 L
.45705 .22423 L
.45932 .22405 L
.46058 .22396 L
.46177 .2239 L
.46286 .22385 L
.46401 .22381 L
.46527 .22378 L
.46643 .22377 L
.46767 .22377 L
.46839 .22378 L
.46905 .22379 L
.47016 .22382 L
.47133 .22386 L
.47233 .30902 L
.47343 .30902 L
.47814 .30902 L
.4988 .30902 L
.53936 .30902 L
.57841 .30902 L
.61991 .30902 L
.65989 .30902 L
.69836 .30902 L
.73927 .30902 L
.77868 .30902 L
.81656 .30902 L
.8569 .30902 L
.89573 .30902 L
.93701 .30902 L
Mistroke
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`0043?o00P0I_l6<ol000<0000co`0co`003C?o00030000oooooooo
07koool006goool00`0003?o03?o000=<ol0101Vo`Lco`000`1Voc?o03?o0004<ol00P0000lco`00
0`000?ooooooo`1moooo001/oooo00<0000co`0co`002c?o00<0I_l;<ol000<0I_lco`0co`0013?o
00030000<ol0<ol000lco`000`000?ooooooo`1loooo001[oooo00<0000co`0co`002C?o00<0I_l>
<ol000<0I_lco`0co`0013?o00030000<ol0<ol0010co`000`000?ooooooo`1koooo001Zoooo00<0
000co`0co`0023?o0080I_lA<ol000<0I_lco`0co`0013?o00030000<ol0<ol0010co`000`000?oo
ooooo`1koooo001Zoooo00<0000co`0co`001S?o0080I_lC<ol000<0I_lco`0co`0013?o00030000
<ol0<ol0014co`000`000?ooooooo`1joooo001Yoooo00<0000co`0co`001C?o0080I_lE<ol000<0
I_lco`0co`0013?o0080000C<ol000<0003oooooool0NOooo`00J?ooo`030000<ol0<ol000@co`02
06Ko5c?o000306Ko<ol0<ol000@co`000`0003?o03?o000C<ol000<0003oooooool0N?ooo`00Iooo
o`030000<ol0<ol000<co`0206Ko6C?o000306Ko<ol0<ol000@co`000`0003?o03?o000D<ol000<0
003oooooool0Moooo`00I_ooo`040000<ol0<ol0<ol00`1Voa/co`000`1Voc?o03?o0004<ol000<0
000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?ooo`@000001?ooo`0003?o03?o
0080I_lN<ol000<0I_lco`0co`0013?o00030000<ol0<ol001Hco`000`000?ooooooo`0Boooo1000
02ooool30000;Oooo`00<_ooo`030000oooooooo02_oool01@000?ooooooooooo`00000306Ko83?o
000306Ko<ol0<ol000@co`02000063?o00030000oooooooo017oool00`000?ooooooo`0aoooo00<0
003oooooool0;?ooo`00;oooo`D0000]oooo00@00000I_l0I_l0I_lS<ol000<0I_lco`0co`0013?o
00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003oooooool0;Oooo`D0000]oooo000Y
oooo100000;oool010000?ooooooo`0002Ooool40000101Vo`030000<ol0<ol002<co`000`1Voc?o
03?o0004<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo
0000;_ooo`00<?ooo`030000oooo000002Soool306Ko00?oool0000000000S?o00030000<ol0<ol0
028co`000`1Voc?o03?o0004<ol000<0000co`0co`006c?o0080000>oooo00@0003oooooool0000^
oooo00<0003oool00000;_ooo`00<Oooo`80000Voooo0P1Vo`;oool200000S?o0080000U<ol000<0
I_lco`0co`0013?o00030000<ol0<ol001dco`0200003Oooo`80000`oooo0P0002koool005Goool4
06Ko0_ooo`80000[<ol000<0I_lco`0co`0013?o0080000P<ol00P0006goool004koool706Ko0ooo
o`<0000]<ol000<0I_lco`0co`0013?o00030000<ol0<ol0024co`030000J_ooo`00Aoooo`L0I_l7
oooo0`00030co`000`1Voc?o03?o0004<ol000<0000co`0co`0093?o00D0001Uoooo000moooo2P1V
o`Ooool70000<c?o000306Ko<ol0<ol000@co`000`0003?o03?o000Y<ol01P0005ooool002WooolD
06Ko2oooo`H0000j<ol000<0I_lco`0co`0013?o00030000<ol0<ol002lco`060000FOooo`004?oo
ool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool00_ooo`03o`2I
oooooooo00Coool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool05Oooo`00;_ooo`030000oooooooo02koool00`000?ooooooo`0Voooo00?o09Woooooool01?oo
o`030000oooooooo02goool00`000?ooooooo`0^oooo00<0003oooooool0;Oooo`00R?ooo`03o`2I
oooooooo00Coool00`000?ooooooo`2>oooo0028oooo00?o09Woooooool01?ooo`030000oooooooo
08koool008Soool00ol0VOooooooo`04oooo00<0003oooooool0S_ooo`00R?ooo`03o`2Ioooooooo
00Coool20000Soooo`00R?ooo`03o`2Ioooooooo00Coool00`000?ooooooo`2>oooo0028oooo00?o
09Woooooool01?ooo`030000oooooooo08koool008Soool00ol0VOooooooo`04oooo00<0003ooooo
ool0S_ooo`00R?ooo`03o`2Ioooooooo00Coool00`000?ooooooo`2>oooo0028oooo00?o09Wooooo
ool01?ooo`80002?oooo0028oooo00?o09Woooooool01?ooo`030000oooooooo08koool008Soool0
0ol0VOooooooo`04oooo00<0003oooooool0S_ooo`00R?ooo`03o`2Ioooooooo00Coool00`000?oo
ooooo`2>oooo0028oooo00?o09Woooooool01?ooo`030000oooooooo08koool008Soool00ol0VOoo
ooooo`04oooo0P0008ooool008Soool00ol0VOooooooo`04oooo00<0003oooooool0S_ooo`00R?oo
o`03o`2Ioooooooo00Coool00`000?ooooooo`2>oooo0028oooo00?o09Woooooool01?ooo`030000
oooooooo08koool008Soool00ol0VOooooooo`04oooo00<0003oooooool0S_ooo`00R?ooo`03o`2I
oooooooo00Coool20000Soooo`00R?ooo`03o`2Ioooooooo00Coool00`000?ooooooo`2>oooo0028
oooo00?o09Woooooool01?ooo`030000oooooooo08koool008Soool00ol0VOooooooo`04oooo00<0
003oooooool0S_ooo`00Qoooo`D00003oooo00<0003oooooool0S_ooo`00R?ooo`03o`2I0000oooo
00Coool00`000?ooooooo`2>oooo0028oooo00?o09T0003oool01?ooo`<0002>oooo0028oooo00?o
09T0003oool01?ooo`030000oooooooo08koool008Soool00ol0V@000?ooo`04oooo00<0003ooooo
ool0S_ooo`00R?ooo`800005oooo00<0003oooooool0S_ooo`00R?ooo`03o`2Ioooooooo00Coool0
0`000?ooooooo`2>oooo0028oooo00?o09Woooooool01?ooo`80002?oooo0028oooo00?o09Wooooo
ool01?ooo`030000oooooooo08koool008Soool00ol0VOooooooo`04oooo00<0003oooooool0S_oo
o`00R?ooo`03o`2Ioooooooo00Coool00`000?ooooooo`2>oooo0028oooo00?o09Woooooool01?oo
o`030000oooooooo08koool008Soool00ol0VOooooooo`04oooo0P0008ooool008Soool00ol0VOoo
ooooo`04oooo00<0003oooooool0S_ooo`00R?ooo`03o`2Ioooooooo00Coool00`000?ooooooo`2>
oooo0028oooo00?o09Woooooool01?ooo`030000oooooooo08koool008Soool00ol0VOooooooo`04
oooo00<0003oooooool0S_ooo`00R?ooo`03o`2Ioooooooo00Coool20000Soooo`00R?ooo`03o`2I
oooooooo00Coool00`000?ooooooo`2>oooo0028oooo00?o09Woooooool01?ooo`030000oooooooo
08koool008Soool00ol0VOooooooo`04oooo00<0003oooooool0S_ooo`00R?ooo`03o`2Ioooooooo
00Coool00`000?ooooooo`2>oooo0028oooo00?o09Woooooool01?ooo`80002?oooo0028oooo00?o
09Woooooool01?ooo`030000oooooooo08koool008Soool00ol0VOooooooo`04oooo00<0003ooooo
ool0S_ooo`00R?ooo`03o`2Ioooooooo00Coool00`000?ooooooo`2>oooo0027oooo100000Coool0
0`000?ooooooo`2>oooo0027oooo00<0003o09Woool01Oooo`030000oooooooo08koool008Soool0
0`000?ooooooo`04oooo0`0008koool008Soool00ol0V@000?ooo`04oooo00<0003oooooool0S_oo
o`00Qoooo`040000o`2Ioooo00001?ooo`030000oooooooo08koool008Soool200001Oooo`030000
oooooooo08koool008Soool00ol0VOooooooo`04oooo00<0003oooooool0S_ooo`00R?ooo`03o`2I
oooooooo00Coool20000Soooo`00R?ooo`03o`2Ioooooooo00Coool00`000?ooooooo`2>oooo0028
oooo00?o09Woooooool01?ooo`030000oooooooo08koool008Soool00ol0VOooooooo`04oooo00<0
003oooooool0S_ooo`00R?ooo`03o`2Ioooooooo00Coool00`000?ooooooo`2>oooo0028oooo00?o
09Woooooool01?ooo`80002?oooo0028oooo00?o09Woooooool01?ooo`030000oooooooo08koool0
08Soool00ol0VOooooooo`04oooo00<0003oooooool0S_ooo`00R?ooo`03o`2Ioooooooo00Coool0
0`000?ooooooo`2>oooo0028oooo00?o09Woooooool01?ooo`030000oooooooo08koool008Soool0
0ol0VOooooooo`04oooo0P0008ooool008Soool00ol0VOooooooo`04oooo00<0003oooooool0S_oo
o`00R?ooo`03o`2Ioooooooo00Coool00`000?ooooooo`2>oooo0028oooo00?o09Woooooool01?oo
o`030000oooooooo08koool008Soool00ol0VOooooooo`04oooo00<0003oooooool0S_ooo`00R?oo
o`03o`2Ioooooooo00Coool00`000?ooooooo`2>oooo0028oooo00?o09Woooooool01?ooo`80002?
oooo0028oooo00?o09Woooooool01?ooo`030000oooooooo08koool008Soool00ol0VOooooooo`04
oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0003oooooool0S_ooo`00Qoooo`040000
o`2Ioooo00001?ooo`030000oooooooo08koool008Soool00ol0V@000?ooo`04oooo0`0008koool0
08[oool00`000?ooooooo`2Coooo0027oooo00@0003oooooool0002Eoooo0028oooo0P0009Koool0
0?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`D00002oooo0P0000Coool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400001Oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01Goool00`000?oo
ooooo`09oooo00<0003oooooool00oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00005?ooo`030000oooooooo00[oool01@000?ooooooooooo`00001joooo001hoooo00D0003ooooo
ooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool05oooo`80000:oooo0P0000?oool00`000?ooooooo`1ioooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.46172 .30902 L
.47106 .30902 L
.47567 .30902 L
.47791 .30902 L
.47889 .30902 L
.47994 .30902 L
s
.47994 .30902 m
.48031 .61803 L
s
0 .4 1 r
.02381 .30757 m
.04262 .30726 L
.06244 .30685 L
.08426 .30629 L
.10458 .30565 L
.14264 .30399 L
.16305 .3028 L
.18163 .30146 L
.20239 .29964 L
.22156 .29757 L
.25997 .292 L
.2787 .28843 L
.29932 .28371 L
.33961 .2718 L
.37838 .2573 L
.39809 .24951 L
.41961 .24175 L
.42957 .23875 L
.4402 .23615 L
.44536 .23517 L
.45023 .23441 L
.45459 .23389 L
.45705 .23366 L
.45932 .2335 L
.46058 .23342 L
.46177 .23337 L
.46286 .23332 L
.46401 .23329 L
.46527 .23326 L
.46643 .23325 L
.46767 .23325 L
.46839 .23326 L
.46905 .23327 L
.47016 .23329 L
.47133 .23333 L
.47233 .23337 L
.47343 .23342 L
.47587 .23358 L
.47814 .23377 L
.47943 .23389 L
.48011 .23397 L
.48083 .23405 L
.48216 .30902 L
.48337 .30902 L
.48813 .30902 L
.4988 .30902 L
.53669 .30902 L
.57703 .30902 L
.61585 .30902 L
.65713 .30902 L
Mistroke
.69689 .30902 L
.73514 .30902 L
.77584 .30902 L
.81502 .30902 L
.85665 .30902 L
.89677 .30902 L
.93537 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
01<co`0906Ko13?o00030000<ol0<ol000lco`000`000?ooooooo`1loooo001[oooo00<0000co`0c
o`004C?o00<0I_l8<ol000<0I_lco`0co`000S?o00030000<ol0<ol0010co`000`000?ooooooo`1k
oooo001Zoooo00<0000co`0co`003C?o00D0I_l;<ol000<0I_lco`0co`000S?o00030000<ol0<ol0
010co`000`000?ooooooo`1koooo001Zoooo00<0000co`0co`002S?o00<0I_l@<ol000<0I_lco`0c
o`000S?o00030000<ol0<ol0014co`000`000?ooooooo`1joooo001Yoooo00<0000co`0co`0023?o
00<0I_lC<ol000<0I_lco`0co`000S?o0080000C<ol000<0003oooooool0NOooo`00J?ooo`030000
<ol0<ol000Lco`0206Ko5S?o000306Ko<ol0<ol0008co`000`0003?o03?o000C<ol000<0003ooooo
ool0N?ooo`00Ioooo`030000<ol0<ol000Dco`0306Ko63?o000306Ko<ol0<ol0008co`000`0003?o
03?o000D<ol000<0003oooooool0Moooo`00I_ooo`030000<ol0<ol000@co`0206Ko6c?o000306Ko
<ol0<ol0008co`000`0003?o03?o000E<ol000<0003oooooool0M_ooo`00<Oooo`<0000/oooo1000
0003oooo0000<ol000<co`0306Ko7C?o000306Ko<ol0<ol0008co`000`0003?o03?o000F<ol000<0
003oooooool04_ooo`@0000_oooo0`0002goool003;oool00`000?ooooooo`0[oooo00D0003ooooo
ooooool000000c?o0080I_lP<ol000<0I_lco`0co`000S?o0080000H<ol000<0003oooooool04Ooo
o`030000oooooooo037oool00`000?ooooooo`0/oooo000_oooo1@0002goool010000?ooo`0003?o
00<0I_lR<ol000<0I_lco`0co`000S?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0
003oooooool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000ooo
o`80000206Ko9C?o000306Ko<ol0<ol0008co`000`0003?o03?o000I<ol00P0001;oool00`000?oo
ooooo`0/oooo00@0003oooooool0000^oooo000`oooo00<0003oool00000:oooo`80I_l01000001V
oc?o000002Hco`000`1Voc?o03?o0002<ol000<0000co`0co`006c?o0080000>oooo00@0003ooooo
ool0000^oooo00<0003oool00000;_ooo`00<Oooo`80000Woooo101Vo`030000<ol0<ol00080000W
<ol000<0I_lco`0co`000S?o00030000<ol0<ol001dco`0200003Oooo`80000`oooo0P0002koool0
05Goool506Ko00?oool000000000;C?o000306Ko<ol0<ol0008co`02000083?o0080001]oooo001@
oooo1@1Vo`?oool30000;c?o000306Ko<ol0<ol0008co`000`0003?o03?o000Q<ol00`0006[oool0
04_oool506Ko1Oooo`<0000b<ol000<0I_lco`0co`000S?o00030000<ol0<ol002@co`050000IOoo
o`00?Oooo`h0I_l3oooo1`0003Dco`000`1Voc?o03?o0002<ol000<0000co`0co`00:C?o00H0001O
oooo000`oooo3@1Vo`_oool60000?3?o000306Ko<ol0<ol0008co`000`0003?o03?o000_<ol01P00
05Woool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Coool00ol0VOooooooo`02oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo01Goool002koool00`000?ooooooo`0^oooo00<0003oooooool0:?ooo`03o`2I
oooooooo00;oool00`000?ooooooo`0]oooo00<0003oooooool0;_ooo`030000oooooooo02goool0
08[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool0
0`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool0
0ol0VOooooooo`02oooo0P0008ooool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_oo
o`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_oo
o`030000oooooooo08koool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_oo
o`03o`2Ioooooooo00;oool20000Soooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>
oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOooooooo`02
oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:
oooo00?o09Woooooool00_ooo`80002?oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo
08koool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo
00;oool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo08koool0
08[oool00ol0VOooooooo`02oooo0P0008ooool008[oool00ol0VOooooooo`02oooo00<0003ooooo
ool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Wooooo
ool00_ooo`030000oooooooo08koool008Ooool500000oooo`030000oooooooo08koool008Woool0
0`000?l0VOooo`03oooo00<0003oooooool0S_ooo`00ROooo`030000o`2Ioooo00?oool30000S_oo
o`00ROooo`030000o`2Ioooo00?oool00`000?ooooooo`2>oooo0029oooo00<0003o09Woool00ooo
o`030000oooooooo08koool008Soool2000000?o09Woooooool00_ooo`030000oooooooo08koool0
08[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool2
0000Soooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Wooooo
ool00_ooo`030000oooooooo08koool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_oo
o`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_oo
o`80002?oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOoo
ooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>
oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOooooooo`02
oooo0P0008ooool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2I
oooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo
08koool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo
00;oool20000Soooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o
09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOooooooo`02oooo00<0003ooooo
ool0S_ooo`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`040000ooooooooo`2I1?oo
o`030000oooooooo08koool008Soool00`000?ooool0V@04oooo0`0008koool008Woool00`000?l0
VOooo`03oooo00<0003oooooool0S_ooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo
08koool008Soool2000000?o09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOoo
ooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool20000Soooo`00R_oo
o`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000
oooooooo08koool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2I
oooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_ooo`80002?oooo002:
oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOooooooo`02oooo00<0
003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o
09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOooooooo`02oooo0P0008ooool0
08[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool0
0`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool0
0ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool00`000?oo
ooooo`2>oooo002:oooo00?o09Woooooool00_ooo`80002?oooo002:oooo00?o09Woooooool00_oo
o`030000oooooooo08koool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R?oo
o`8000000ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00Qoooo`040000oooooooo00001?oo
o`030000oooooooo08koool008Woool00`000?l0VOooo`03oooo0`0008koool008[oool00`000?oo
ooooo`2Coooo0027oooo00@0003oooooool0002Eoooo0028oooo0P0009Koool00?oooolQoooo003o
oooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool03?ooo`D00002oooo0P0000?oool400000oooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Coool400001Oooo`030000oooooooo00Ooool00`000?ooooooo`04oooo00<0003oooooool0N?oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool02?ooo`030000
oooooooo00Coool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001Coool00`000?oo
ooooo`09oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`00000Goooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07Soool0
07Woool00`000?ooooooo`0Goooo0P0000[oool200000oooo`030000oooooooo07Woool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.44268 .30902 L
.46172 .30902 L
.47994 .30902 L
.48519 .30902 L
.48778 .30902 L
.48904 .30902 L
.49018 .30902 L
s
.49018 .30902 m
.49052 .61803 L
s
0 .4 1 r
.02381 .30774 m
.04262 .30746 L
.06244 .3071 L
.08426 .30661 L
.10458 .30603 L
.14264 .30457 L
.16305 .30351 L
.18163 .30233 L
.20239 .30072 L
.22156 .29889 L
.25997 .29396 L
.2787 .2908 L
.29932 .28662 L
.33961 .27609 L
.37838 .26325 L
.39809 .25637 L
.41961 .2495 L
.42957 .24684 L
.4402 .24454 L
.44536 .24367 L
.45023 .243 L
.45459 .24254 L
.45705 .24234 L
.45932 .24219 L
.46058 .24213 L
.46177 .24208 L
.46286 .24204 L
.46401 .24201 L
.46527 .24199 L
.46643 .24198 L
.46767 .24198 L
.46839 .24198 L
.46905 .24199 L
.47016 .24201 L
.47133 .24205 L
.47233 .24208 L
.47343 .24213 L
.47587 .24227 L
.47814 .24243 L
.48337 .24296 L
.48585 .24327 L
.48813 .24359 L
.48941 .24379 L
.49006 .2439 L
.49077 .30902 L
.49148 .30902 L
.49224 .30902 L
.49362 .30902 L
.4988 .30902 L
.54008 .30902 L
Mistroke
.57984 .30902 L
.61809 .30902 L
.65878 .30902 L
.69797 .30902 L
.7396 .30902 L
.77972 .30902 L
.81832 .30902 L
.85938 .30902 L
.89892 .30902 L
.93694 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol001Pco`0506Ko1C?o
00030000<ol0<ol0010co`000`000?ooooooo`1koooo001Zoooo00<0000co`0co`004S?o00H0I_l4
<ol0101Vo`8co`000`0003?o03?o000A<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol0
00hco`0506Ko3C?o000306Ko<ol0<ol00080000C<ol000<0003oooooool0NOooo`00J?ooo`030000
<ol0<ol000`co`0306Ko4S?o000406Ko<ol0<ol000005C?o00030000oooooooo07Soool006Ooool0
0`0003?o03?o000:<ol00`1VoaDco`00101Voc?o03?o000001Hco`000`000?ooooooo`1goooo001V
oooo00<0000co`0co`002C?o0080I_lH<ol000@0I_lco`0co`00000G<ol000<0003oooooool0M_oo
o`00<Oooo`<0000/oooo10000003oooo0000<ol000Pco`0306Ko6S?o000406Ko<ol0<ol0000063?o
00030000oooooooo01;oool40000;oooo`<0000]oooo000boooo00<0003oooooool0:oooo`050000
oooooooooooo000000Lco`0306Ko7C?o000306Ko<ol0<ol00080000H<ol000<0003oooooool04Ooo
o`030000oooooooo037oool00`000?ooooooo`0/oooo000_oooo1@0002goool00`000?ooo`000004
<ol0101Vob0co`00101Voc?o03?o000001Xco`000`000?ooooooo`0Aoooo00<0003oooooool0;Ooo
o`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`800002<ol00`1V
ob@co`00101Voc?o03?o000001/co`0200004_ooo`030000oooooooo02coool010000?ooooooo`00
02koool0033oool00`000?ooo`00000/oooo0P000004<ol006Ko000006Ko:3?o000306Ko<ol00000
01dco`0200003_ooo`040000oooooooo0000;_ooo`030000oooo000002koool0037oool20000:_oo
o`04000006Ko06Ko06Ko0P0002Xco`000`1Voc?o0000000O<ol00P0000goool20000<?ooo`80000^
oooo001Joooo101Voblco`00101Voc?o00000000020co`020000KOooo`00EOooo`D0I_l00`0003?o
03?o000`<ol000<0I_lco`0000008c?o00<0001Zoooo001>oooo1`1Vo`<0000e<ol000<0I_lco`00
00009S?o00D0001Uoooo0012oooo301Vo`L0000h<ol000<0I_lco`000000:c?o00H0001Ooooo000`
oooo4P1Vo`Koool60000?c?o000306Ko<ol00000034co`060000FOooo`004?ooool0000Aoooo000F
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool01_ooo`04o`2Ioooooooo00002ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo01Goool002koool00`000?ooooooo`0^
oooo00<0003oooooool0:_ooo`04o`2Ioooooooo0000;oooo`030000oooooooo02koool00`000?oo
ooooo`0]oooo002<oooo00Co09Woooooool0002@oooo002<oooo00Co09Woooooool0002@oooo002<
oooo00Co09Woooooool0002@oooo002<oooo00?o09Woooooool00P0008ooool008coool01?l0VOoo
ooooo`00093oool008coool01?l0VOooooooo`00093oool008coool01?l0VOooooooo`00093oool0
08coool01?l0VOooooooo`00093oool008coool00ol0VOooooooo`020000Soooo`00S?ooo`04o`2I
oooooooo0000T?ooo`00S?ooo`04o`2Ioooooooo0000T?ooo`00S?ooo`04o`2Ioooooooo0000T?oo
o`00S?ooo`04o`2Ioooooooo0000T?ooo`00S?ooo`03o`2Ioooooooo0080002?oooo002<oooo00Co
09Woooooool0002@oooo002<oooo00Co09Woooooool0002@oooo002<oooo00Co09Woooooool0002@
oooo002<oooo00Co09Woooooool0002@oooo002<oooo00?o09Woooooool00P0008ooool008coool0
1?l0VOooooooo`00093oool008coool01?l0VOooooooo`00093oool008coool01?l0VOooooooo`00
093oool008Ooool5000000Co09Woooooool0002@oooo0029oooo00@0003ooooooooo09T2oooo00<0
003oooooool0S_ooo`00ROooo`040000ooooooooo`2I0_ooo`<0002>oooo0029oooo00@0003ooooo
oooo09T2oooo00<0003oooooool0S_ooo`00ROooo`040000ooooooooo`2I0_ooo`030000oooooooo
08koool008Soool200000_ooo`04o`2Ioooooooo0000T?ooo`00S?ooo`04o`2Ioooooooo0000T?oo
o`00S?ooo`03o`2Ioooooooo0080002?oooo002<oooo00Co09Woooooool0002@oooo002<oooo00Co
09Woooooool0002@oooo002<oooo00Co09Woooooool0002@oooo002<oooo00Co09Woooooool0002@
oooo002<oooo00?o09Woooooool00P0008ooool008coool01?l0VOooooooo`00093oool008coool0
1?l0VOooooooo`00093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?oo
o`00SOooo`04o`2Ioooo00000000Soooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOoo
o`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool0
1?l0VOooo`00000008ooool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?oo
o`00SOooo`03o`2Ioooo0000093oool008Ooool400000_ooo`03o`2Ioooo0000093oool008Ooool0
0`000?ooooooo`03oooo00?o09Woool00000T?ooo`00R?ooo`030000oooooooo00;oool00ol0VOoo
o`0000020000S_ooo`00ROooo`070000ooooooooooooo`2Ioooo0000093oool008Ooool010000?oo
ooooo`0000;oool00ol0VOooo`00002@oooo0028oooo0P0000?oool00ol0VOooo`00002@oooo002=
oooo00?o09Woool00000T?ooo`00SOooo`04o`2Ioooo00000000Soooo`00SOooo`03o`2Ioooo0000
093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2I
oooo0000093oool008goool01?l0VOooo`00000008ooool008goool00ol0VOooo`00002@oooo002=
oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@
oooo002=oooo00Co09Woool00000002?oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2I
oooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOoo
o`03o`2Ioooo0000093oool008goool01?l0VOooo`00000008ooool008goool00ol0VOooo`00002@
oooo002=oooo00?o09Woool00000T?ooo`00R?ooo`800003oooo00?o09Woool00000T?ooo`00Qooo
o`040000oooooooo00000_ooo`03o`2Ioooo0000093oool008Woool01P000?ooooooooooool0VOoo
o`<0002>oooo002:oooo00<0003oooooool0Toooo`00Qoooo`040000oooooooo0000UOooo`00R?oo
o`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00coool500000_ooo`800003
oooo1@0000;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`09oooo00<0003ooooo
ool00_ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Ooo
o`030000oooooooo00Woool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000Doooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000005oooo`030000oooooooo00Woool00`000?ooooooo`02
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`800003oooo00<0
003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.48147 .30902 L
.49012 .30902 L
.49468 .30902 L
.49719 .30902 L
.49842 .30902 L
.49955 .30902 L
s
.49955 .30902 m
.49994 .61803 L
s
0 .4 1 r
.02381 .30789 m
.04262 .30765 L
.06244 .30733 L
.08426 .3069 L
.10458 .30639 L
.14264 .30511 L
.16305 .30417 L
.18163 .30314 L
.20239 .30171 L
.22156 .3001 L
.25997 .29577 L
.2787 .29299 L
.29932 .28931 L
.33961 .28005 L
.37838 .26875 L
.39809 .26269 L
.41961 .25665 L
.42957 .25431 L
.4402 .25229 L
.44536 .25152 L
.45023 .25093 L
.45459 .25053 L
.45705 .25035 L
.45932 .25022 L
.46058 .25016 L
.46177 .25012 L
.46286 .25009 L
.46401 .25006 L
.46527 .25004 L
.46643 .25003 L
.46767 .25003 L
.46839 .25004 L
.46905 .25004 L
.47016 .25006 L
.47133 .25009 L
.47233 .25012 L
.47343 .25016 L
.47587 .25029 L
.47814 .25043 L
.48337 .25089 L
.48813 .25145 L
.49332 .25221 L
.49615 .25269 L
.49754 .25294 L
.4988 .25317 L
.49998 .2534 L
.5011 .30902 L
.50227 .30902 L
.50356 .30902 L
.50879 .30902 L
Mistroke
.51799 .30902 L
.53879 .30902 L
.57948 .30902 L
.61867 .30902 L
.6603 .30902 L
.70042 .30902 L
.73902 .30902 L
.78008 .30902 L
.81962 .30902 L
.85764 .30902 L
.89812 .30902 L
.93708 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol001Tco`0406Ko1S?o0080000C<ol000<0
003oooooool0NOooo`00J?ooo`030000<ol0<ol001@co`0706Ko0c?o00H0I_l00`0003?o03?o000C
<ol000<0003oooooool0N?ooo`00Ioooo`030000<ol0<ol0010co`0506Ko43?o00030000<ol0<ol0
01@co`000`000?ooooooo`1goooo001Voooo00<0000co`0co`003S?o00<0I_lE<ol000<0000co`0c
o`005C?o00030000oooooooo07Koool0037oool30000;?ooo`@000000oooo`0003?o000<<ol0101V
oaPco`000`0003?o03?o000F<ol000<0003oooooool04_ooo`@0000_oooo0`0002goool003;oool0
0`000?ooooooo`0[oooo00D0003oooooooooool000002S?o00@0I_lL<ol00P0001Pco`000`000?oo
ooooo`0Aoooo00<0003oooooool0<Oooo`030000oooooooo02coool002ooool50000;Oooo`030000
oooo000000Pco`0306Ko83?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`800005
<ol0101Vob<co`000`0003?o03?o000I<ol00P0001;oool00`000?ooooooo`0/oooo00@0003ooooo
ool0000^oooo000`oooo00<0003oool00000;?ooo`800002<ol000<00000I_l0I_l00P1VobLco`00
0`0003?o03?o000K<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000a
oooo0P0002[oool200000P1Vo`8000000`1Voc?o03?o000Y<ol000<0000co`0co`007C?o0080000=
oooo0P00033oool20000;_ooo`00F_ooo`D0I_l`<ol00P00020co`020000KOooo`00EOooo`D0I_l0
0`0003?o03?o000b<ol000<0000co`0co`008C?o00<0001Zoooo001>oooo1`1Vo`<0000g<ol000<0
000co`0co`0093?o00D0001Uoooo0017oooo1`1Vo`L0000j<ol000<0000co`0co`00:C?o00H0001O
oooo000`oooo5`1Vo`03oooo0000000000@00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo01Goool002koool0
0`000?ooooooo`0^oooo00<0003oooooool0;Oooo`030000oooooooo02goool00`000?ooooooo`0^
oooo00<0003oooooool0;Oooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo0027oooo1@00
00?oool00`000?ooooooo`2>oooo0029oooo00<0003oooooool00oooo`030000oooooooo08koool0
08Woool00`000?ooooooo`03oooo0`0008koool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0S_ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo0027oooo100000Coool00`000?ooooooo`2>oooo0027oooo00<0003oooooool01Oooo`030000
oooooooo08koool008Soool00`000?ooooooo`04oooo0`0008koool008Woool00`000?ooooooo`03
oooo00<0003oooooool0S_ooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo08koool0
08Soool200001Oooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P00
08ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008Soool200001Oooo`030000oooooooo08koool008Ooool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo0029oooo00<0003oooooool00oooo`<0002>oooo002:
oooo00<0003oooooool0Toooo`00Qoooo`040000oooooooo0000UOooo`00R?ooo`80002Foooo003o
oooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Nooo
o`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00coool500000_ooo`800004oooo00<0003ooooo
ool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01?ooo`@00005oooo00<0003oooooool02?ooo`030000oooooooo07_oool007[oool00`000?oo
ooooo`02oooo00<0003oooooool05Oooo`030000oooooooo00Woool00`000?ooooooo`1joooo001k
oooo00<0003oooooool01@0001Coool00`000?ooooooo`08oooo00<0003oooooool0Noooo`00Nooo
o`050000oooooooooooo000001Ooool00`000?ooooooo`08oooo00<0003oooooool0Noooo`00O?oo
o`030000oooooooo01Ooool200002Oooo`030000oooooooo07coool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.48147 .30902 L
.49955 .30902 L
.50431 .30902 L
.50682 .30902 L
.5082 .30902 L
.5095 .30902 L
s
.5095 .30902 m
.50987 .61803 L
s
0 .4 1 r
.02381 .30804 m
.04262 .30782 L
.06244 .30754 L
.08426 .30717 L
.10458 .30673 L
.14264 .3056 L
.16305 .30479 L
.18163 .30388 L
.20239 .30264 L
.22156 .30123 L
.25997 .29744 L
.2787 .29502 L
.29932 .29181 L
.33961 .28371 L
.37838 .27385 L
.39809 .26855 L
.41961 .26327 L
.42957 .26123 L
.4402 .25947 L
.44536 .25879 L
.45023 .25828 L
.45459 .25793 L
.45705 .25777 L
.45932 .25766 L
.46058 .25761 L
.46177 .25757 L
.46286 .25754 L
.46401 .25752 L
.46527 .2575 L
.46643 .25749 L
.46767 .25749 L
.46839 .2575 L
.46905 .2575 L
.47016 .25752 L
.47133 .25755 L
.47233 .25757 L
.47343 .25761 L
.47587 .25772 L
.47814 .25784 L
.48337 .25825 L
.48813 .25874 L
.4988 .26024 L
.50365 .26109 L
.5063 .26159 L
.5076 .26185 L
.50879 .26208 L
.50987 .30902 L
.5109 .30902 L
.51317 .30902 L
.51799 .30902 L
Mistroke
.53879 .30902 L
.57703 .30902 L
.61773 .30902 L
.65691 .30902 L
.69854 .30902 L
.73866 .30902 L
.77727 .30902 L
.81832 .30902 L
.85786 .30902 L
.89589 .30902 L
.93636 .30902 L
.97532 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000I<ol01`1Vo`Dco`000`0003?o03?o000D<ol000<0003oooooool0Mooo
o`00I_ooo`030000<ol0<ol001@co`0606Ko1c?o00D0I_l00`00001Vo`1Vo`0E<ol000<0003ooooo
ool0M_ooo`00<Oooo`<0000/oooo10000003oooo0000<ol0018co`0406Ko4S?o00030000<ol006Ko
01Hco`000`000?ooooooo`0Boooo100002ooool30000;Oooo`00<_ooo`030000oooooooo02_oool0
1@000?ooooooooooo`00000><ol01P1VoaHco`02000000<0I_lco`0co`005C?o00030000oooooooo
017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]oooo00<0003oool0
00002c?o00@0I_lL<ol000<0000co`00I_l063?o00030000oooooooo017oool00`000?ooooooo`0]
oooo1@0002goool002Woool400000_ooo`040000oooooooo00009oooo`@00003oooo0P0000Tco`03
06Ko83?o00030000<ol006Ko01Tco`0200004_ooo`030000oooooooo02coool010000?ooooooo`00
02koool0033oool00`000?ooo`00000/oooo0P00008co`000`0003?o03?o0002<ol0101Vob<co`00
0`0003?o001Vo`0K<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000a
oooo0P0002[oool200000S?o008000000c?o001Vo`1Vo`0206Ko9c?o00030000<ol006Ko01dco`02
00003Oooo`80000`oooo0P0002koool005_oool200000S?o00D0I_l[<ol00P00000306Ko<ol0<ol0
01dco`020000KOooo`00F?ooo`80000506Ko<3?o00030000<ol006Ko024co`030000J_ooo`00C_oo
o``0I_le<ol000<0000co`00I_l093?o00D0001Uoooo0017oooo1`1Vo`L0000j<ol000<0000co`00
I_l0:C?o00H0001Ooooo000hoooo3`1Vo`03oooo0000000000@00011<ol000<0000co`00I_l0;c?o
00H0001Ioooo000@ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003ooooo09T02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
01Goool002koool00`000?ooooooo`0^oooo00<0003oooooool0;Oooo`030000ooooo`2I02goool0
0`000?ooooooo`0^oooo00<0003oooooool0;Oooo`00Soooo`030000ooooo`2I08koool008ooool0
0`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<
oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?oo
ool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<oooo002?
oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>
oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<oooo002?oooo00<0
003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?
oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<oooo002?oooo00<0003ooooo
09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo0027oooo1@00
00?oool00`000?ooool0V@2>oooo0029oooo00<0003oooooool00oooo`030000ooooo`2I08koool0
08Woool00`000?ooooooo`03oooo0`0008koool008Woool00`000?ooooooo`03oooo00<0003ooooo
09T0S_ooo`00ROooo`030000oooooooo00?oool00`000?ooool0V@2>oooo0028oooo0P0000Goool0
0`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<
oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?oo
ool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<oooo002?
oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>
oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<oooo002?oooo00<0
003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?
oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<oooo002?oooo00<0003ooooo
09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo0027oooo1000
00Coool00`000?ooool0V@2>oooo0027oooo00<0003oooooool01Oooo`030000ooooo`2I08koool0
08Soool00`000?ooooooo`04oooo0`0008koool008Woool00`000?ooooooo`03oooo00<0003ooooo
09T0S_ooo`00Qoooo`040000oooooooo00001?ooo`030000ooooo`2I08koool008Soool200001Ooo
o`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?oooo0P000003o`2Ioooooooo
08coool008ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000
ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?oooo0P000003o`2Ioooooooo08coool0
08ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I
08koool008ooool00`000?ooool0V@2>oooo002?oooo0P000003o`2Ioooooooo08coool008ooool0
0`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool0
08ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOoo
ooooo`2<oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008Soool2
00001Oooo`030000ooooo`2I08koool008Ooool010000?ooooooo`0000Coool00`000?ooool0V@2>
oooo0029oooo00<0003oooooool00oooo`<0002>oooo002:oooo00<0003oooooool0Toooo`00Qooo
o`040000oooooooo0000UOooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool0
0`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?oo
ooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00goool200001?ooo`800003oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool0
10000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Moooo`030000
oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool00009oooo0`0000Coool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0001;oool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005Oooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Woool00`000?oo
ooooo`0Goooo0P0000[oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.5095 .30902 L
.51441 .30902 L
.5168 .30902 L
.51784 .30902 L
.51896 .30902 L
s
.51896 .30902 m
.51935 .61803 L
s
0 .4 1 r
.02381 .30817 m
.04262 .30798 L
.06244 .30774 L
.08426 .30741 L
.10458 .30703 L
.14264 .30606 L
.16305 .30536 L
.18163 .30457 L
.20239 .3035 L
.22156 .30228 L
.25997 .299 L
.2787 .2969 L
.29932 .29413 L
.33961 .28712 L
.37838 .27859 L
.39809 .27401 L
.41961 .26944 L
.42957 .26767 L
.4402 .26615 L
.44536 .26557 L
.45023 .26512 L
.45459 .26482 L
.45705 .26468 L
.45932 .26458 L
.46058 .26454 L
.46177 .26451 L
.46286 .26448 L
.46401 .26446 L
.46527 .26445 L
.46643 .26444 L
.46767 .26444 L
.46839 .26444 L
.46905 .26445 L
.47016 .26446 L
.47133 .26449 L
.47233 .26451 L
.47343 .26454 L
.47587 .26463 L
.47814 .26474 L
.48337 .26509 L
.48813 .26552 L
.4988 .26682 L
.50879 .26841 L
.51354 .26928 L
.51586 .26973 L
.51688 .26993 L
.51799 .27015 L
.51918 .30902 L
.52031 .30902 L
.5228 .30902 L
Mistroke
.52809 .30902 L
.53879 .30902 L
.57948 .30902 L
.61867 .30902 L
.6603 .30902 L
.70042 .30902 L
.73902 .30902 L
.78008 .30902 L
.81962 .30902 L
.85764 .30902 L
.89812 .30902 L
.93708 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000J<ol03@1Vo`03<ol00000<ol001Lco`000`000?ooooooo`0Boooo1000
02ooool30000;Oooo`00<_ooo`030000oooooooo02_oool01@000?ooooooooooo`00000E<ol01`1V
o`dco`000`1Vo`000000000306Ko5C?o00030000oooooooo017oool00`000?ooooooo`0aoooo00<0
003oooooool0;?ooo`00;oooo`D0000]oooo00<0003oool000004c?o00<0I_lE<ol000@0000co`0c
o`0co`0206Ko5C?o00030000oooooooo017oool00`000?ooooooo`0]oooo1@0002goool002Woool4
00000_ooo`040000oooooooo00009oooo`@00003oooo0P00010co`0406Ko63?o00030000<ol0<ol0
008co`000`1Voc?o03?o000D<ol00P0001;oool00`000?ooooooo`0/oooo00@0003oooooool0000^
oooo000`oooo00<0003oool00000;?ooo`800002<ol000<0000co`0co`0023?o00D0I_lL<ol000<0
000co`0co`000S?o000306Ko<ol0<ol001Hco`0200003_ooo`040000oooooooo0000;_ooo`030000
oooo000002koool0037oool20000:_ooo`800002<ol00P0000Hco`0506Ko8C?o00030000<ol0<ol0
008co`000`1Voc?o03?o000H<ol00P0000goool20000<?ooo`80000^oooo001Koooo0P0000Lco`05
06Ko9S?o00800003<ol000<0I_lco`0co`006S?o0080001]oooo001Hoooo0`0000@co`0506Ko:c?o
00030000<ol0<ol0008co`000`1Voc?o03?o000L<ol00`0006[oool005Goool:06Ko<3?o00030000
<ol0<ol0008co`000`1Voc?o03?o000O<ol01@0006Goool004koool706Ko>S?o00030000<ol0<ol0
008co`000`1Voc?o03?o000T<ol01P0005ooool003SooolF06Ko@C?o00030000<ol0<ol0008co`00
0`1Voc?o03?o000Z<ol01P0005Woool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`02oooo00?o09Woooooool01?ooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo01Goool002koool00`000?ooooooo`0^oooo00<0
003oooooool0;Oooo`030000oooooooo00;oool00ol0VOooooooo`0Xoooo00<0003oooooool0;_oo
o`030000oooooooo02goool008ooool00`000?ooooooo`02oooo00?o09Woooooool0ROooo`00Sooo
o`030000oooooooo00;oool00ol0VOooooooo`29oooo002?oooo00<0003oooooool00_ooo`03o`2I
oooooooo08Woool008ooool200000oooo`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02
oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo00;oool00ol0VOooooooo`29oooo002?
oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02oooo00?o
09Woooooool0ROooo`00Soooo`800003oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo
00;oool00ol0VOooooooo`29oooo002?oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool0
08ooool00`000?ooooooo`02oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo00;oool0
0ol0VOooooooo`29oooo002?oooo0P0000?oool00ol0VOooooooo`29oooo002?oooo00<0003ooooo
ool00_ooo`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02oooo00?o09Woooooool0ROoo
o`00Soooo`030000oooooooo00;oool00ol0VOooooooo`29oooo002?oooo00<0003oooooool00_oo
o`03o`2Ioooooooo08Woool008ooool200000oooo`03o`2Ioooooooo08Woool008ooool00`000?oo
ooooo`02oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo00;oool00ol0VOooooooo`29
oooo002?oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool008Ooool500000oooo`030000
oooooooo00;oool00ol0VOooooooo`29oooo0029oooo00<0003oooooool00oooo`030000oooooooo
00;oool00ol0VOooooooo`29oooo0029oooo00<0003oooooool00oooo`<00002oooo00?o09Wooooo
ool0ROooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`02oooo00?o09Woooooool0ROoo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`02oooo00?o09Woooooool0ROooo`00R?oo
o`800005oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02
oooo00?o09Woooooool0ROooo`00Soooo`800003oooo00?o09Woooooool0ROooo`00Soooo`030000
oooooooo00;oool00ol0VOooooooo`29oooo002?oooo00<0003oooooool00_ooo`03o`2Ioooooooo
08Woool008ooool00`000?ooooooo`02oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo
00;oool00ol0VOooooooo`29oooo002?oooo0P0000?oool00ol0VOooooooo`29oooo002?oooo00<0
003oooooool00_ooo`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02oooo00?o09Wooooo
ool0ROooo`00Soooo`030000oooooooo00;oool00ol0VOooooooo`29oooo002?oooo00<0003ooooo
ool00_ooo`03o`2Ioooooooo08Woool008ooool200000oooo`03o`2Ioooooooo08Woool008ooool0
0`000?ooooooo`02oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo00;oool00ol0VOoo
ooooo`29oooo002?oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool008ooool00`000?oo
ooooo`02oooo00?o09Woooooool0ROooo`00Soooo`800003oooo00?o09Woooooool0ROooo`00Sooo
o`030000oooooooo00;oool00ol0VOooooooo`29oooo002?oooo00<0003oooooool00_ooo`03o`2I
oooooooo08Woool008ooool00`000?ooooooo`02oooo00?o09Woooooool0ROooo`00Qoooo`@00004
oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool008Ooool00`000?ooooooo`05oooo00<0
003oooooool00_ooo`03o`2Ioooooooo08Woool008Soool00`000?ooooooo`04oooo0`0000;oool0
0ol0VOooooooo`29oooo0029oooo00<0003oooooool00oooo`030000oooooooo00;oool00ol0VOoo
ooooo`29oooo0027oooo00@0003oooooool00004oooo00<0003oooooool00_ooo`03o`2Ioooooooo
08Woool008Soool200001Oooo`030000oooooooo00;oool00ol0VOooooooo`29oooo002?oooo00<0
003oooooool00_ooo`03o`2Ioooooooo08Woool008ooool200000oooo`03o`2Ioooooooo08Woool0
08ooool00`000?ooooooo`02oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo00;oool0
0ol0VOooooooo`29oooo002?oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool008ooool0
0`000?ooooooo`02oooo00?o09Woooooool0ROooo`00Soooo`800003oooo00?o09Woooooool0ROoo
o`00Soooo`030000oooooooo00;oool00ol0VOooooooo`29oooo002?oooo00<0003oooooool00_oo
o`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02oooo00?o09Woooooool0ROooo`00Sooo
o`030000oooooooo00;oool00ol0VOooooooo`29oooo002?oooo0P0000?oool00ol0VOooooooo`29
oooo002?oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02
oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo00;oool00ol0VOooooooo`29oooo002?
oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02oooo00?o
09Woooooool0ROooo`00Soooo`800003oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo
00;oool00ol0VOooooooo`29oooo002?oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool0
08Soool200001Oooo`030000oooooooo00;oool00ol0VOooooooo`29oooo0027oooo00@0003ooooo
ool00004oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool008Woool00`000?ooooooo`03
oooo0`0000;oool00ol0VOooooooo`29oooo002:oooo00<0003oooooool0Toooo`00Qoooo`040000
oooooooo0000UOooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00goool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003ooooo
ool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool0
0`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001;oool010000?ooooooo`0000Woool2
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Eoooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo
01Ooool200002_ooo`800003oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.5095 .30902 L
.51896 .30902 L
.52417 .30902 L
.5256 .30902 L
.52712 .30902 L
.52786 .30902 L
.52856 .30902 L
s
.52856 .30902 m
.52895 .61803 L
s
0 .4 1 r
.02381 .30829 m
.04262 .30813 L
.06244 .30793 L
.08426 .30765 L
.10458 .30732 L
.14264 .30649 L
.16305 .30589 L
.18163 .30522 L
.20239 .3043 L
.22156 .30326 L
.25997 .30047 L
.2787 .29867 L
.29932 .2963 L
.33961 .29032 L
.37838 .28303 L
.39809 .27911 L
.41961 .27521 L
.42957 .2737 L
.4402 .2724 L
.44536 .2719 L
.45023 .27152 L
.45459 .27126 L
.45705 .27115 L
.45932 .27106 L
.46058 .27103 L
.46177 .271 L
.46286 .27098 L
.46401 .27096 L
.46527 .27095 L
.46643 .27094 L
.46767 .27094 L
.46839 .27095 L
.46905 .27095 L
.47016 .27096 L
.47133 .27098 L
.47233 .271 L
.47343 .27103 L
.47587 .27111 L
.47814 .2712 L
.48337 .2715 L
.48813 .27186 L
.4988 .27297 L
.50879 .27433 L
.51799 .27582 L
.52321 .27673 L
.52576 .27719 L
.52687 .2774 L
.52809 .27763 L
.52935 .30902 L
.53055 .30902 L
Mistroke
.53318 .30902 L
.53879 .30902 L
.57948 .30902 L
.61867 .30902 L
.6603 .30902 L
.70042 .30902 L
.73902 .30902 L
.78008 .30902 L
.81962 .30902 L
.85764 .30902 L
.89812 .30902 L
.93708 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool000006C?o0180I_l00`0003?o03?o000H<ol000<0003oooooool04Oooo`030000
oooooooo02goool50000;Oooo`00:Oooo`@00002oooo00@0003oooooool0000Woooo100000?oool2
00005S?o00@0I_lB<ol000<00000I_l0I_l01@1Voa@co`0200004_ooo`030000oooooooo02coool0
10000?ooooooo`0002koool0033oool00`000?ooo`00000/oooo0P00008co`000`0003?o03?o000=
<ol01P1VoaHco`000`0003?o03?o0004<ol000<0I_lco`0co`0053?o0080000>oooo00@0003ooooo
ool0000^oooo00<0003oool00000;_ooo`00<Oooo`80000Zoooo0P00008co`0200002c?o00D0I_lL
<ol000<0000co`0co`0013?o000306Ko<ol0<ol001Hco`0200003Oooo`80000`oooo0P0002koool0
05_oool2000033?o00D0I_lQ<ol00P0000Dco`000`1Voc?o03?o000H<ol00P0006goool005Soool3
00001c?o00L0I_lV<ol000<0000co`0co`0013?o000306Ko<ol0<ol001Xco`030000J_ooo`00EOoo
o`<00002<ol0201Vobdco`000`0003?o03?o0004<ol000<0I_lco`0co`007C?o00D0001Uoooo001>
oooo301VocDco`000`0003?o03?o0004<ol000<0I_lco`0co`008S?o00H0001Ooooo000moooo4@1V
od4co`000`0003?o03?o0004<ol000<0I_lco`0co`00:3?o00H0001Ioooo000@ooooo`00017oool0
01Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool01?oo
o`03o`2Ioooooooo00;oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000^
oooo00<0003oooooool0;_ooo`030000oooooooo02goool00`000?ooooooo`04oooo00?o09Wooooo
ool09_ooo`030000oooooooo02koool00`000?ooooooo`0]oooo002?oooo00<0003oooooool01?oo
o`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Sooo
o`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo0P0000Goool00ol0VOooooooo`27
oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04
oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27oooo002?
oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool200001Oooo`03o`2Ioooooooo
08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo
00Coool00ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool0
08ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`800005oooo00?o09Wooooo
ool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo00<0003ooooo
ool01?ooo`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qooo
o`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo0P0000Goool00ol0VOoo
ooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool00`000?oo
ooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27
oooo0027oooo1@0000?oool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00ROooo`030000oooooooo
00?oool300001?ooo`03o`2Ioooooooo08Ooool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool01?ooo`03o`2Ioooooooo08Ooool008Woool00`000?ooooooo`03oooo00<0003oooooool01?oo
o`03o`2Ioooooooo08Ooool008Soool200001Oooo`030000oooooooo00Coool00ol0VOooooooo`27
oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool200001Oooo`03o`2I
oooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000
oooooooo00Coool00ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo
08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`800005oooo00?o
09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo00<0
003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Wooooo
ool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo0P0000Goool0
0ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool0
0`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOoo
ooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool200001Ooo
o`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Sooo
o`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2I
oooooooo08Ooool008Ooool400001?ooo`030000oooooooo00Coool00ol0VOooooooo`27oooo0027
oooo00<0003oooooool01Oooo`030000oooooooo00Coool00ol0VOooooooo`27oooo0028oooo00<0
003oooooool01?ooo`<00004oooo00?o09Woooooool0Qoooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Qoooo`040000oooooooo00001?ooo`030000
oooooooo00Coool00ol0VOooooooo`27oooo0028oooo0P0000Goool00`000?ooooooo`04oooo00?o
09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo0P00
00Goool00ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool0
08ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool0
0ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool2
00001Oooo`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qooo
o`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo00<0003oooooool01?oo
o`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Sooo
o`800005oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27
oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04
oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27oooo002?
oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool200001Oooo`03o`2Ioooooooo
08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo
00Coool00ol0VOooooooo`27oooo0028oooo0P0000Goool00`000?ooooooo`04oooo00?o09Wooooo
ool0Qoooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo00Coool00ol0VOooooooo`27
oooo0029oooo00<0003oooooool00oooo`<00004oooo00?o09Woooooool0Qoooo`00R_ooo`030000
oooooooo09?oool008Ooool010000?ooooooo`0009Goool008Soool20000U_ooo`00ooooob7oool0
0?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001Oooo`030000oooooooo00;oool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0
003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003ooooo
ool0000:oooo00<0003oooooool00oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00004_ooo`040000oooooooo00002oooo`050000oooooooooooo000007[oool007Soool01@000?oo
ooooooooo`00000Eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo01Ooool200002Oooo`@00002oooo00<0003oooooool0NOoo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.51896 .30902 L
.52455 .30902 L
.52986 .30902 L
.53463 .30902 L
.53594 .30902 L
.53666 .30902 L
.53733 .30902 L
s
.53733 .30902 m
.53773 .61803 L
s
0 .4 1 r
.02381 .30841 m
.04262 .30828 L
.06244 .3081 L
.08426 .30787 L
.10458 .3076 L
.14264 .3069 L
.16305 .30639 L
.18163 .30583 L
.20239 .30506 L
.22156 .30419 L
.25997 .30184 L
.2787 .30033 L
.29932 .29834 L
.33961 .29332 L
.37838 .2872 L
.39809 .28392 L
.41961 .28065 L
.42957 .27938 L
.4402 .27829 L
.44536 .27787 L
.45023 .27755 L
.45459 .27733 L
.45705 .27723 L
.45932 .27716 L
.46058 .27713 L
.46177 .27711 L
.46286 .27709 L
.46401 .27708 L
.46527 .27707 L
.46643 .27706 L
.46767 .27706 L
.46839 .27706 L
.46905 .27707 L
.47016 .27708 L
.47133 .27709 L
.47233 .27711 L
.47343 .27713 L
.47587 .2772 L
.47814 .27728 L
.48337 .27753 L
.48813 .27783 L
.4988 .27876 L
.50879 .27991 L
.51799 .28115 L
.52809 .28267 L
.53318 .28348 L
.53458 .28371 L
.53608 .28395 L
.5368 .28407 L
.53749 .28418 L
Mistroke
.53879 .30902 L
.54004 .30902 L
.54138 .30902 L
.54383 .30902 L
.5484 .30902 L
.55863 .30902 L
.57703 .30902 L
.61809 .30902 L
.65763 .30902 L
.69565 .30902 L
.73613 .30902 L
.77509 .30902 L
.8165 .30902 L
.8564 .30902 L
.89478 .30902 L
.93561 .30902 L
.97493 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000O
<ol02P1Vo`<co`000`0003?o03?o000I<ol00P0001;oool00`000?ooooooo`0/oooo00@0003ooooo
ool0000^oooo000`oooo00<0003oool00000;?ooo`800002<ol000<0000co`0co`004c?o00T0I_l:
<ol00`1Vo`03000006Ko06Ko00<0I_lH<ol00P0000koool010000?ooooooo`0002koool00`000?oo
o`00000^oooo000aoooo0P0002[oool200000S?o0080000@<ol01P1VoaHco`000`0003?o03?o0003
<ol0101VoaHco`0200003Oooo`80000`oooo0P0002koool005_oool200003c?o00L0I_lL<ol00P00
00Lco`000`1Voc?o03?o000F<ol00P0006goool005Soool300002C?o00P0I_lS<ol000<0000co`0c
o`001S?o000306Ko<ol0<ol001Pco`030000J_ooo`00EOooo`<00007<ol01@1Vob/co`000`0003?o
03?o0006<ol000<0I_lco`0co`006c?o00D0001Uoooo001>oooo1`0000X0I_l`<ol000<0000co`0c
o`001c?o000306Ko<ol0<ol001lco`060000Goooo`00@_oooa<0I_lj<ol000<0000co`0co`001c?o
000306Ko<ol0<ol002Dco`060000FOooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Koool01?l0VOooooooo`0000_oool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo01Goool002koool00`000?ooooooo`0^oooo00<0003oooooool0;Ooo
o`030000oooooooo00Koool00ol0VOooooooo`0Toooo00<0003oooooool0;_ooo`030000oooooooo
02goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo
00Koool00ol0VOooooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool0
08ooool200001oooo`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06oooo00?o09Wooooo
ool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25oooo002?oooo00<0003ooooo
ool01_ooo`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOoo
o`00Soooo`800007oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOoo
ooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool00`000?oo
ooooo`06oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25
oooo002?oooo0P0000Ooool00ol0VOooooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2I
oooooooo08Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Soooo`030000
oooooooo00Koool00ol0VOooooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo
08Goool008ooool200001oooo`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06oooo00?o
09Woooooool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25oooo002?oooo00<0
003oooooool01_ooo`03o`2Ioooooooo08Goool008Ooool500000oooo`030000oooooooo00Koool0
0ol0VOooooooo`25oooo0029oooo00<0003oooooool00oooo`030000oooooooo00Koool00ol0VOoo
ooooo`25oooo0029oooo00<0003oooooool00oooo`<00006oooo00?o09Woooooool0QOooo`00ROoo
o`030000oooooooo00?oool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00R?ooo`800005oooo00<0
003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06oooo00?o09Wooooo
ool0QOooo`00Soooo`800007oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo00Koool0
0ol0VOooooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool0
0`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOoo
ooooo`25oooo002?oooo0P0000Ooool00ol0VOooooooo`25oooo002?oooo00<0003oooooool01_oo
o`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Sooo
o`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2I
oooooooo08Coool008ooool200002?ooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07
oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?
oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00Soooo`800008oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo
00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool0
08ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Qoooo`@00004oooo00<0003ooooo
ool01oooo`03o`2Ioooooooo08Coool008Ooool00`000?ooooooo`05oooo00<0003oooooool01ooo
o`03o`2Ioooooooo08Coool008Soool00`000?ooooooo`04oooo0`0000Ooool00ol0VOooooooo`24
oooo0029oooo00<0003oooooool00oooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo0027
oooo00@0003oooooool00004oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008Soool2
00001Oooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01ooo
o`03o`2Ioooooooo08Coool008ooool200002?ooo`03o`2Ioooooooo08Coool008ooool00`000?oo
ooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24
oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07
oooo00?o09Woooooool0Q?ooo`00Soooo`800008oooo00?o09Woooooool0Q?ooo`00Soooo`030000
oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo
08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo
00Ooool00ol0VOooooooo`24oooo002?oooo0P0000Soool00ol0VOooooooo`24oooo002?oooo00<0
003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Wooooo
ool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003ooooo
ool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?oo
o`00Soooo`800008oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOoo
ooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008Soool200001Ooo
o`030000oooooooo00Ooool00ol0VOooooooo`24oooo0027oooo00@0003oooooool00004oooo00<0
003oooooool01oooo`03o`2Ioooooooo08Coool008Woool00`000?ooooooo`03oooo0`0000Ooool0
0ol0VOooooooo`24oooo002:oooo00<0003oooooool0Toooo`00Qoooo`040000oooooooo0000UOoo
o`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0
003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?oo
o`800003oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000
oooooooo01?oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1g
oooo001hoooo00<0003oooooool01@0001;oool010000?ooooooo`0000Soool300001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool00009oooo00<0
003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool3
00000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.52059 .30902 L
.53057 .30902 L
.53984 .30902 L
.54444 .30902 L
.54576 .30902 L
.54701 .30902 L
s
.54701 .30902 m
.54735 .61803 L
s
0 .4 1 r
.02381 .30852 m
.04262 .30841 L
.06244 .30827 L
.08426 .30808 L
.10458 .30785 L
.14264 .30728 L
.16305 .30687 L
.18163 .30641 L
.20239 .30578 L
.22156 .30506 L
.25997 .30314 L
.2787 .30191 L
.29932 .30028 L
.33961 .29617 L
.37838 .29116 L
.39809 .28848 L
.41961 .2858 L
.42957 .28476 L
.4402 .28386 L
.44536 .28352 L
.45023 .28326 L
.45459 .28308 L
.45705 .283 L
.45932 .28295 L
.46058 .28292 L
.46177 .2829 L
.46286 .28289 L
.46401 .28287 L
.46527 .28287 L
.46643 .28286 L
.46767 .28286 L
.46839 .28286 L
.46905 .28287 L
.47016 .28288 L
.47133 .28289 L
.47233 .2829 L
.47343 .28292 L
.47587 .28297 L
.47814 .28304 L
.48337 .28324 L
.48813 .28349 L
.4988 .28426 L
.50879 .28519 L
.51799 .28621 L
.52873 .28754 L
.53399 .28822 L
.53879 .28886 L
.54101 .28916 L
.54343 .28949 L
.54453 .28964 L
Mistroke
.54571 .28981 L
.54682 .28996 L
.54783 .30902 L
.54909 .30902 L
.55024 .30902 L
.55284 .30902 L
.55755 .30902 L
.57819 .30902 L
.61773 .30902 L
.65575 .30902 L
.69623 .30902 L
.73519 .30902 L
.7766 .30902 L
.8165 .30902 L
.85488 .30902 L
.89572 .30902 L
.93504 .30902 L
.97284 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000J<ol04P1Vo`04000006Ko06Ko06Ko73?o0080000=oooo0P00033oool20000;_oo
o`00Foooo`80000F<ol02P1Voa8co`0200000S?o00P0I_lF<ol00P0006goool005Soool300004C?o
00L0I_lL<ol000<0000co`0co`0023?o0080I_lG<ol00`0006[oool005Goool300002S?o00X0I_lS
<ol000<0000co`0co`002C?o000306Ko<ol0<ol001Pco`050000IOooo`00C_ooo`L00005<ol0201V
obdco`000`0003?o03?o0009<ol000<0I_lco`0co`007C?o00H0001Ooooo0017oooo4`1VocDco`00
0`0003?o03?o0009<ol000<0I_lco`0co`008c?o00H0001Ioooo000@ooooo`00017oool001Koool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool0
0`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09
oooo00<0003oooooool02Oooo`030000oooooooo01Goool002koool00`000?ooooooo`0^oooo00<0
003oooooool0;Oooo`030000oooooooo00Woool00ol0VOooooooo`0Qoooo00<0003oooooool0;_oo
o`030000oooooooo02goool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Sooo
o`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2I
oooooooo08;oool008ooool200002_ooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09
oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?
oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o
09Woooooool0P_ooo`00Soooo`80000:oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo
00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool0
08ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool0
0ol0VOooooooo`22oooo002?oooo0P0000[oool00ol0VOooooooo`22oooo002?oooo00<0003ooooo
ool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_oo
o`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Ooo
o`03o`2Ioooooooo08;oool008ooool200002_ooo`03o`2Ioooooooo08;oool008ooool00`000?oo
ooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22
oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008Ooool500000oooo`030000
oooooooo00Woool00ol0VOooooooo`22oooo0029oooo00<0003oooooool00oooo`030000oooooooo
00Woool00ol0VOooooooo`22oooo0029oooo00<0003oooooool00oooo`<00009oooo00?o09Wooooo
ool0P_ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`09oooo00?o09Woooooool0P_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00R?oo
o`800005oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09
oooo00?o09Woooooool0P_ooo`00Soooo`80000:oooo00?o09Woooooool0P_ooo`00Soooo`030000
oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo
08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo
00Woool00ol0VOooooooo`22oooo002?oooo0P0000[oool00ol0VOooooooo`22oooo002?oooo00<0
003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Wooooo
ool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003ooooo
ool02Oooo`03o`2Ioooooooo08;oool008ooool200002_ooo`03o`2Ioooooooo08;oool008ooool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOoo
ooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?oo
ooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`80000:oooo00?o09Woooooool0P_ooo`00Sooo
o`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2I
oooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Qoooo`@00004
oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008Ooool00`000?ooooooo`05oooo00<0
003oooooool02Oooo`03o`2Ioooooooo08;oool008Soool00`000?ooooooo`04oooo0`0000Woool0
0ol0VOooooooo`22oooo0029oooo00<0003oooooool00oooo`030000oooooooo00Woool00ol0VOoo
ooooo`22oooo0027oooo00@0003oooooool00004oooo00<0003oooooool02Oooo`03o`2Ioooooooo
08;oool008Soool200001Oooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0
003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool200002_ooo`03o`2Ioooooooo08;oool0
08ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool0
0ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`80000:oooo00?o09Woooooool0P_oo
o`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Ooo
o`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Sooo
o`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo0P0000[oool00ol0VOooooooo`22
oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09
oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?
oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o
09Woooooool0P_ooo`00Soooo`80000:oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo
00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool0
08Soool200001Oooo`030000oooooooo00Woool00ol0VOooooooo`22oooo0027oooo00@0003ooooo
ool00004oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008Woool00`000?ooooooo`03
oooo0`0000Woool00ol0VOooooooo`22oooo002:oooo00<0003oooooool0Toooo`00Qoooo`040000
oooooooo0000UOooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00goool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003ooooo
ool00_ooo`030000oooooooo01?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Boooo00@0003oooooool00009oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000005Oooo`040000oooooooo
00002Oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05ooo
o`80000:oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.52059 .30902 L
.53984 .30902 L
.54934 .30902 L
.55195 .30902 L
.55338 .30902 L
.55472 .30902 L
.55598 .30902 L
.55669 .30902 L
s
.55669 .30902 m
.55688 .61803 L
s
0 .4 1 r
.02381 .30862 m
.04262 .30854 L
.06244 .30843 L
.08426 .30828 L
.10458 .3081 L
.14264 .30765 L
.16305 .30732 L
.18163 .30696 L
.20239 .30646 L
.22156 .3059 L
.25997 .30439 L
.2787 .30341 L
.29932 .30213 L
.33961 .29889 L
.37838 .29494 L
.39809 .29283 L
.41961 .29071 L
.42957 .28989 L
.4402 .28919 L
.44536 .28892 L
.45023 .28872 L
.45459 .28857 L
.45705 .28851 L
.45932 .28847 L
.46058 .28845 L
.46177 .28843 L
.46286 .28842 L
.46401 .28841 L
.46527 .2884 L
.46643 .2884 L
.46767 .2884 L
.46839 .2884 L
.46905 .2884 L
.47016 .28841 L
.47133 .28842 L
.47233 .28843 L
.47343 .28845 L
.47587 .28849 L
.47814 .28854 L
.48337 .2887 L
.48813 .2889 L
.4988 .2895 L
.50879 .29024 L
.51799 .29104 L
.52873 .29208 L
.53879 .29313 L
.54783 .2941 L
.55044 .29438 L
.55291 .29465 L
.55513 .29489 L
Mistroke
.55638 .29503 L
.55755 .30902 L
.55885 .30902 L
.56025 .30902 L
.5628 .30902 L
.56755 .30902 L
.57819 .30902 L
.61924 .30902 L
.65878 .30902 L
.69681 .30902 L
.73728 .30902 L
.77625 .30902 L
.81766 .30902 L
.85756 .30902 L
.89594 .30902 L
.93677 .30902 L
.97609 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000R<ol0401Vo`80000P<ol00P0006goool005Soool3000063?o00`0I_l@<ol000<00000I_l0
I_l0201VoaTco`030000J_ooo`00EOooo`<0000D<ol01`1Voa`co`000`0003?o03?o0008<ol0101V
oaPco`050000IOooo`00C_ooo`L0000=<ol02P1Vob<co`000`0003?o03?o000;<ol000<0I_lco`0c
o`006c?o00H0001Ooooo0018oooo1P0001@0I_l]<ol000<0000co`0co`0033?o000306Ko<ol0<ol0
020co`060000FOooo`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooool0V@09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`0Eoooo000^oooo00<0003oooooool0;_ooo`030000oooooooo02goool00`000?ooooooo`0;
oooo00?o09Woooooool07oooo`030000oooooooo02koool00`000?ooooooo`0]oooo002?oooo00<0
003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Wooooo
ool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo0P0000coool0
0ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool0
0`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOoo
ooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool200003?oo
o`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Sooo
o`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2I
oooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`80000<
oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?
oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o
09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo0P00
00coool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0
08ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool0
0ol0VOooooooo`20oooo0027oooo1@0000?oool00`000?ooooooo`0;oooo00?o09Woooooool0P?oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00ROoo
o`030000oooooooo00?oool300002oooo`03o`2Ioooooooo083oool008Woool00`000?ooooooo`03
oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008Woool00`000?ooooooo`03oooo00<0
003oooooool02oooo`03o`2Ioooooooo083oool008Soool200001Oooo`030000oooooooo00_oool0
0ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool2
00003?ooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?oo
o`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02ooo
o`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Sooo
o`80000<oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20
oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;
oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?
oooo0P0000coool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo
083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo
00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0
08ooool200003?ooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Wooooo
ool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003ooooo
ool02oooo`03o`2Ioooooooo083oool008Ooool400001?ooo`030000oooooooo00_oool00ol0VOoo
ooooo`20oooo0027oooo00<0003oooooool01Oooo`030000oooooooo00_oool00ol0VOooooooo`20
oooo0028oooo00<0003oooooool01?ooo`<0000;oooo00?o09Woooooool0P?ooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Qoooo`040000oooooooo
00001?ooo`030000oooooooo00_oool00ol0VOooooooo`20oooo0028oooo0P0000Goool00`000?oo
ooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20
oooo002?oooo0P0000coool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2I
oooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000
oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo
083oool008ooool200003?ooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o
09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0
003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Wooooo
ool0P?ooo`00Soooo`80000<oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool0
0ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool0
0`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOoo
ooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool200003?oo
o`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Sooo
o`030000oooooooo00_oool00ol0VOooooooo`20oooo0028oooo0P0000Goool00`000?ooooooo`0;
oooo00?o09Woooooool0P?ooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo00_oool0
0ol0VOooooooo`20oooo0029oooo00<0003oooooool00oooo`<0000;oooo00?o09Woooooool0P?oo
o`00R_ooo`030000oooooooo09?oool008Ooool010000?ooooooo`0009Goool008Soool20000U_oo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001Oooo`<00002
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool0000;oooo00D0003oooooooooool0
0000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool00008
oooo1@0000?oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000005Oooo`040000oooooooo00002Oooo`030000oooo000000?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool05oooo`80000;oooo0P0000;oool00`000?ooooooo`1ioooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.52059 .30902 L
.53984 .30902 L
.54934 .30902 L
.55436 .30902 L
.55972 .30902 L
.56236 .30902 L
.56366 .30902 L
.56486 .30902 L
.56594 .30902 L
s
.56594 .30902 m
.56629 .61803 L
s
0 .4 1 r
.02381 .30873 m
.04262 .30866 L
.06244 .30858 L
.08426 .30847 L
.10458 .30834 L
.14264 .308 L
.16305 .30776 L
.18163 .30749 L
.20239 .30712 L
.22156 .30671 L
.25997 .30558 L
.2787 .30486 L
.29932 .30391 L
.33961 .30151 L
.37838 .29858 L
.39809 .29701 L
.41961 .29545 L
.42957 .29484 L
.4402 .29432 L
.44536 .29412 L
.45023 .29397 L
.45459 .29386 L
.45705 .29382 L
.45932 .29378 L
.46058 .29377 L
.46177 .29376 L
.46286 .29375 L
.46401 .29374 L
.46527 .29373 L
.46643 .29373 L
.46767 .29373 L
.46839 .29373 L
.46905 .29374 L
.47016 .29374 L
.47133 .29375 L
.47233 .29376 L
.47343 .29377 L
.47587 .2938 L
.47814 .29384 L
.48337 .29396 L
.48813 .2941 L
.4988 .29455 L
.50879 .29509 L
.51799 .29569 L
.53879 .29724 L
.54783 .29796 L
.55755 .29874 L
.56041 .29897 L
.56312 .29918 L
.5643 .29928 L
Mistroke
.56556 .29937 L
.56628 .29943 L
.56693 .30902 L
.56821 .30902 L
.57819 .30902 L
.61831 .30902 L
.65691 .30902 L
.69797 .30902 L
.73751 .30902 L
.77553 .30902 L
.81601 .30902 L
.85497 .30902 L
.89638 .30902 L
.93628 .30902 L
.97466 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0001/co`0L06Ko00<00000I_l0I_l0201Voa`co`050000IOooo`00C_ooo`L0000G
<ol01`1Voa`co`000`0003?o03?o0008<ol01`1VoaXco`060000Goooo`00B?ooo`H00007<ol05`1V
ob<co`000`0003?o03?o000><ol000<0I_lco`0co`007S?o00H0001Ioooo000@ooooo`00017oool0
01Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00;oool00ol0VOooooooo`04oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000^
oooo00<0003oooooool0;_ooo`030000oooooooo02goool00`000?ooooooo`0>oooo00?o09Wooooo
ool07?ooo`030000oooooooo02koool00`000?ooooooo`0]oooo002?oooo00<0003oooooool03_oo
o`03o`2Ioooooooo07goool008ooool00`000?ooooooo`0>oooo00?o09Woooooool0OOooo`00Sooo
o`030000oooooooo00koool00ol0VOooooooo`1moooo002?oooo0P0000ooool00ol0VOooooooo`1m
oooo002?oooo00<0003oooooool03_ooo`03o`2Ioooooooo07goool008ooool00`000?ooooooo`0>
oooo00?o09Woooooool0OOooo`00Soooo`030000oooooooo00koool00ol0VOooooooo`1moooo002?
oooo00<0003oooooool03_ooo`03o`2Ioooooooo07goool008ooool200003oooo`03o`2Ioooooooo
07goool008ooool00`000?ooooooo`0>oooo00?o09Woooooool0OOooo`00Soooo`030000oooooooo
00koool00ol0VOooooooo`1moooo002?oooo00<0003oooooool03_ooo`03o`2Ioooooooo07goool0
08ooool00`000?ooooooo`0>oooo00?o09Woooooool0OOooo`00Soooo`80000?oooo00?o09Wooooo
ool0OOooo`00Soooo`030000oooooooo00koool00ol0VOooooooo`1moooo002?oooo00<0003ooooo
ool03_ooo`03o`2Ioooooooo07goool008ooool00`000?ooooooo`0>oooo00?o09Woooooool0OOoo
o`00Soooo`030000oooooooo00koool00ol0VOooooooo`1moooo002?oooo0P0000ooool00ol0VOoo
ooooo`1moooo002?oooo00<0003oooooool03_ooo`03o`2Ioooooooo07goool008ooool00`000?oo
ooooo`0>oooo00?o09Woooooool0OOooo`00Soooo`030000oooooooo00koool00ol0VOooooooo`1m
oooo0027oooo1@0000?oool00`000?ooooooo`0>oooo00?o09Woooooool0OOooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`0>oooo00?o09Woooooool0OOooo`00ROooo`030000oooooooo
00?oool300003_ooo`03o`2Ioooooooo07goool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool03_ooo`03o`2Ioooooooo07goool008Woool00`000?ooooooo`03oooo00<0003oooooool03_oo
o`03o`2Ioooooooo07goool008Soool200001Oooo`030000oooooooo00koool00ol0VOooooooo`1m
oooo002?oooo00<0003oooooool03_ooo`03o`2Ioooooooo07goool008ooool200003oooo`03o`2I
oooooooo07goool008ooool00`000?ooooooo`0>oooo00?o09Woooooool0OOooo`00Soooo`030000
oooooooo00koool00ol0VOooooooo`1moooo002?oooo00<0003oooooool03_ooo`03o`2Ioooooooo
07goool008ooool00`000?ooooooo`0>oooo00?o09Woooooool0OOooo`00Soooo`80000?oooo00?o
09Woooooool0OOooo`00Soooo`030000oooooooo00koool00ol0VOooooooo`1moooo002?oooo00<0
003oooooool03_ooo`03o`2Ioooooooo07goool008ooool00`000?ooooooo`0>oooo00?o09Wooooo
ool0OOooo`00Soooo`030000oooooooo00koool00ol0VOooooooo`1moooo002?oooo0P0000ooool0
0ol0VOooooooo`1moooo002?oooo00<0003oooooool03_ooo`03o`2Ioooooooo07goool008ooool0
0`000?ooooooo`0>oooo00?o09Woooooool0OOooo`00Soooo`030000oooooooo00koool00ol0VOoo
ooooo`1moooo002?oooo00<0003oooooool03_ooo`03o`2Ioooooooo07goool008ooool200003ooo
o`03o`2Ioooooooo07goool008ooool00`000?ooooooo`0>oooo00?o09Woooooool0OOooo`00Sooo
o`030000oooooooo00koool00ol0VOooooooo`1moooo002?oooo00<0003oooooool03_ooo`03o`2I
oooooooo07goool008Ooool400001?ooo`030000oooooooo00koool00ol0VOooooooo`1moooo0027
oooo00<0003oooooool01Oooo`030000oooooooo00koool00ol0VOooooooo`1moooo0028oooo00<0
003oooooool01?ooo`<0000>oooo00?o09Woooooool0OOooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`0>oooo00?o09Woooooool0OOooo`00Qoooo`040000oooooooo00001?ooo`030000
oooooooo00koool00ol0VOooooooo`1moooo0028oooo0P0000Goool00`000?ooooooo`0>oooo00?o
09Woooooool0OOooo`00Soooo`030000oooooooo00koool00ol0VOooooooo`1moooo002?oooo0P00
00ooool00ol0VOooooooo`1moooo002?oooo00<0003oooooool03_ooo`03o`2Ioooooooo07goool0
08ooool00`000?ooooooo`0>oooo00?o09Woooooool0OOooo`00Soooo`030000oooooooo00koool0
0ol0VOooooooo`1moooo002?oooo00<0003oooooool03_ooo`03o`2Ioooooooo07goool008ooool2
00003oooo`03o`2Ioooooooo07goool008ooool00`000?ooooooo`0>oooo00?o09Woooooool0OOoo
o`00Soooo`030000oooooooo00koool00ol0VOooooooo`1moooo002?oooo00<0003oooooool03_oo
o`03o`2Ioooooooo07goool008ooool00`000?ooooooo`0>oooo00?o09Woooooool0OOooo`00Sooo
o`80000?oooo00?o09Woooooool0OOooo`00Soooo`030000oooooooo00koool00ol0VOooooooo`1m
oooo002?oooo00<0003oooooool03_ooo`03o`2Ioooooooo07goool008ooool00`000?ooooooo`0>
oooo00?o09Woooooool0OOooo`00Soooo`030000oooooooo00koool00ol0VOooooooo`1moooo002?
oooo00<0003oooooool03_ooo`03o`2Ioooooooo07goool008ooool200003oooo`03o`2Ioooooooo
07goool008ooool00`000?ooooooo`0>oooo00?o09Woooooool0OOooo`00Soooo`030000oooooooo
00koool00ol0VOooooooo`1moooo0028oooo0P0000Goool00`000?ooooooo`0>oooo00?o09Wooooo
ool0OOooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo00koool00ol0VOooooooo`1m
oooo0029oooo00<0003oooooool00oooo`<0000>oooo00?o09Woooooool0OOooo`00R_ooo`030000
oooooooo09?oool008Ooool010000?ooooooo`0009Goool008Soool20000U_ooo`00ooooob7oool0
0?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001?ooo`800004oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool0000:
oooo00<0003oooooool00oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500004_oo
o`040000oooooooo00002oooo`050000oooooooooooo000007[oool007Soool01@000?oooooooooo
o`00000Eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo01Ooool200002_ooo`800003oooo00<0003oooooool0NOooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.52059 .30902 L
.53984 .30902 L
.54934 .30902 L
.55972 .30902 L
.56446 .30902 L
.56951 .30902 L
.57197 .30902 L
.57318 .30902 L
.57429 .30902 L
.5753 .30902 L
s
.5753 .30902 m
.57562 .61803 L
s
0 .4 1 r
.02381 .30882 m
.04262 .30878 L
.06244 .30873 L
.08426 .30865 L
.10458 .30857 L
.14264 .30835 L
.16305 .30819 L
.18163 .30801 L
.20239 .30777 L
.22156 .30749 L
.25997 .30675 L
.2787 .30627 L
.29932 .30564 L
.33961 .30405 L
.37838 .30212 L
.39809 .30108 L
.41961 .30004 L
.42957 .29964 L
.4402 .2993 L
.44536 .29917 L
.45023 .29907 L
.45459 .299 L
.45705 .29897 L
.45932 .29894 L
.46058 .29893 L
.46177 .29893 L
.46286 .29892 L
.46401 .29892 L
.46527 .29891 L
.46643 .29891 L
.46767 .29891 L
.46839 .29891 L
.46905 .29891 L
.47016 .29892 L
.47133 .29892 L
.47233 .29893 L
.47343 .29893 L
.47587 .29896 L
.47814 .29898 L
.48337 .29906 L
.48813 .29916 L
.4988 .29945 L
.50879 .29981 L
.51799 .3002 L
.53879 .30123 L
.55755 .30222 L
.56269 .30249 L
.56821 .30278 L
.57089 .30292 L
.57343 .30305 L
Mistroke
.57453 .3031 L
.5757 .30316 L
.57699 .30902 L
.57819 .30902 L
.61982 .30902 L
.65994 .30902 L
.69854 .30902 L
.7396 .30902 L
.77914 .30902 L
.81716 .30902 L
.85764 .30902 L
.8966 .30902 L
.93801 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool700007S?o01`0I_l0
0`00001Vo`1Vo`0:06Ko7c?o00H0001Ooooo0018oooo1P0001@co`0A06Ko73?o00030000<ol0<ol0
00Xco`0706Ko7S?o00H0001Ioooo000@ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Coool00ol0VOoo
ooooo`02oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`0Eoooo000^oooo00<0003oooooool0;_ooo`030000
oooooooo02goool00`000?ooooooo`0@oooo00?o09Woooooool06_ooo`030000oooooooo02koool0
0`000?ooooooo`0]oooo002?oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool0
0`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo013oool00ol0VOoo
ooooo`1koooo002?oooo0P00017oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?oo
o`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Sooo
o`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2I
oooooooo07_oool008ooool200004Oooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@
oooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo013oool00ol0VOooooooo`1koooo002?
oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o
09Woooooool0Noooo`00Soooo`80000Aoooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo
013oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool0
08ooool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo013oool0
0ol0VOooooooo`1koooo002?oooo0P00017oool00ol0VOooooooo`1koooo002?oooo00<0003ooooo
ool04?ooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o09Woooooool0Nooo
o`00Soooo`030000oooooooo013oool00ol0VOooooooo`1koooo0027oooo1@0000?oool00`000?oo
ooooo`0@oooo00?o09Woooooool0Noooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0@
oooo00?o09Woooooool0Noooo`00ROooo`030000oooooooo00?oool300004?ooo`03o`2Ioooooooo
07_oool008Woool00`000?ooooooo`03oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool0
08Woool00`000?ooooooo`03oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008Soool2
00001Oooo`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?oo
o`03o`2Ioooooooo07_oool008ooool200004Oooo`03o`2Ioooooooo07_oool008ooool00`000?oo
ooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo013oool00ol0VOooooooo`1k
oooo002?oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@
oooo00?o09Woooooool0Noooo`00Soooo`80000Aoooo00?o09Woooooool0Noooo`00Soooo`030000
oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2Ioooooooo
07_oool008ooool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo
013oool00ol0VOooooooo`1koooo002?oooo0P00017oool00ol0VOooooooo`1koooo002?oooo00<0
003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o09Wooooo
ool0Noooo`00Soooo`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0003ooooo
ool04?ooo`03o`2Ioooooooo07_oool008ooool200004Oooo`03o`2Ioooooooo07_oool008ooool0
0`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo013oool00ol0VOoo
ooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008Ooool400001?oo
o`030000oooooooo013oool00ol0VOooooooo`1koooo0027oooo00<0003oooooool01Oooo`030000
oooooooo013oool00ol0VOooooooo`1koooo0028oooo00<0003oooooool01?ooo`<0000@oooo00?o
09Woooooool0Noooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0@oooo00?o09Wooooo
ool0Noooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo013oool00ol0VOooooooo`1k
oooo0028oooo0P0000Goool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`030000
oooooooo013oool00ol0VOooooooo`1koooo002?oooo0P00017oool00ol0VOooooooo`1koooo002?
oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o
09Woooooool0Noooo`00Soooo`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0
003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool200004Oooo`03o`2Ioooooooo07_oool0
08ooool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo013oool0
0ol0VOooooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool0
0`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`80000Aoooo00?o09Woooooool0Nooo
o`00Soooo`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?oo
o`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Sooo
o`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2I
oooooooo07_oool008ooool200004Oooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@
oooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo013oool00ol0VOooooooo`1koooo0028
oooo0P0000Goool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Qoooo`040000oooooooo
00001?ooo`030000oooooooo013oool00ol0VOooooooo`1koooo0029oooo00<0003oooooool00ooo
o`<0000@oooo00?o09Woooooool0Noooo`00R_ooo`030000oooooooo09?oool008Ooool010000?oo
ooooo`0009Goool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001ioooo00<0003ooooo
ool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=
oooo0P0000Coool200000oooo`@00003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003ooooo
ool00008oooo00<0003oooooool01?ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool04oooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0001;oool010000?ooooooo`0000[oool00`000?oo
ooooo`02oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000001Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003ooooo
ool05oooo`80000:oooo0P0000?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.55838 .30902 L
.56817 .30902 L
.57861 .30902 L
.58157 .30902 L
.58302 .30902 L
.58436 .30902 L
.58558 .30902 L
s
.58558 .30902 m
.58596 .61803 L
s
0 .4 1 r
.02381 .30892 m
.04262 .3089 L
.06244 .30887 L
.08426 .30884 L
.10458 .30879 L
.14264 .30868 L
.16305 .3086 L
.18163 .30852 L
.20239 .30839 L
.22156 .30826 L
.25997 .30789 L
.2787 .30765 L
.29932 .30734 L
.33961 .30655 L
.37838 .30559 L
.39809 .30507 L
.41961 .30455 L
.42957 .30435 L
.4402 .30418 L
.44536 .30412 L
.45023 .30407 L
.45459 .30403 L
.45705 .30402 L
.45932 .30401 L
.46058 .304 L
.46177 .304 L
.46286 .30399 L
.46401 .30399 L
.46527 .30399 L
.46643 .30399 L
.46767 .30399 L
.46839 .30399 L
.46905 .30399 L
.47016 .30399 L
.47133 .30399 L
.47233 .304 L
.47343 .304 L
.47587 .30401 L
.47814 .30402 L
.48337 .30406 L
.48813 .30411 L
.4988 .30426 L
.50879 .30444 L
.51799 .30463 L
.53879 .30514 L
.55914 .30568 L
.5691 .30594 L
.57819 .30616 L
.58267 .30627 L
.5839 .3063 L
Mistroke
.58521 .30633 L
.58644 .30902 L
.58756 .30902 L
.59645 .30902 L
.61608 .30902 L
.65619 .30902 L
.6948 .30902 L
.73585 .30902 L
.77539 .30902 L
.81342 .30902 L
.85389 .30902 L
.89285 .30902 L
.93427 .30902 L
.97416 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H0000U<ol0701Vo`03000006Ko06Ko00X0I_lU<ol01P00
05Woool0013ooooo00004Oooo`005_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool01oooo`03o`2Ioooo000000_oool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool05Ooo
o`00;_ooo`030000oooooooo02koool00`000?ooooooo`0]oooo00<0003oooooool04oooo`03o`2I
oooooooo01Ooool00`000?ooooooo`0^oooo00<0003oooooool0;Oooo`00Soooo`030000oooooooo
01?oool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool0
08ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`80000Doooo00?o09Wooooo
ool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0003ooooo
ool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?oo
o`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo0P0001Coool00ol0VOoo
ooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?oo
ooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1h
oooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool200005?ooo`03o`2I
oooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000
oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo
07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`80000Doooo00?o
09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0
003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Wooooo
ool0N?ooo`00Qoooo`D00003oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008Woool0
0`000?ooooooo`03oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008Woool00`000?oo
ooooo`03oooo0`0001?oool00ol0VOooooooo`1hoooo0029oooo00<0003oooooool00oooo`030000
oooooooo01?oool00ol0VOooooooo`1hoooo0029oooo00<0003oooooool00oooo`030000oooooooo
01?oool00ol0VOooooooo`1hoooo0028oooo0P0000Goool00`000?ooooooo`0Coooo00?o09Wooooo
ool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo0P0001Coool0
0ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool0
0`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOoo
ooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool200005?oo
o`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Sooo
o`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2I
oooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`80000D
oooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?
oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o
09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo0P00
01Coool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool0
08ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool0
0ol0VOooooooo`1hoooo0027oooo100000Coool00`000?ooooooo`0Coooo00?o09Woooooool0N?oo
o`00Qoooo`030000oooooooo00Goool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00R?oo
o`030000oooooooo00Coool300004oooo`03o`2Ioooooooo07Soool008Woool00`000?ooooooo`03
oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008Ooool010000?ooooooo`0000Coool0
0`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00R?ooo`800005oooo00<0003oooooool04ooo
o`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Sooo
o`80000Doooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1h
oooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0C
oooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?
oooo0P0001Coool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo
07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo
01?oool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool0
08ooool200005?ooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Wooooo
ool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0003ooooo
ool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?oo
o`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo0P0001Coool00ol0VOoo
ooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?oo
ooooo`0Coooo00?o09Woooooool0N?ooo`00R?ooo`800005oooo00<0003oooooool04oooo`03o`2I
oooooooo07Soool008Ooool010000?ooooooo`0000Coool00`000?ooooooo`0Coooo00?o09Wooooo
ool0N?ooo`00ROooo`030000oooooooo00?oool300004oooo`03o`2Ioooooooo07Soool008[oool0
0`000?ooooooo`2Coooo0027oooo00@0003oooooool0002Eoooo0028oooo0P0009Koool00?oooolQ
oooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0
003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000?oool500000_ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Coool400000oooo`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?oo
ooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`00
00[oool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000B
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000Eoooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool200000oooo`030000oooooooo
07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.55838 .30902 L
.57861 .30902 L
.58392 .30902 L
.58957 .30902 L
.59232 .30902 L
.59367 .30902 L
.59491 .30902 L
s
.59491 .30902 m
.59525 .61803 L
s
0 .4 1 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo01Goool002koool0
0`000?ooooooo`0^oooo00<0003oooooool0;Oooo`030000oooooooo01Goool00ol0VOooooooo`0E
oooo00<0003oooooool0;_ooo`030000oooooooo02goool008ooool00`000?ooooooo`0Eoooo00?o
09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0
003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool200005_ooo`03o`2Ioooooooo07Koool0
08ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool0
0ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool0
0`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`80000Foooo00?o09Woooooool0M_oo
o`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Ooo
o`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Sooo
o`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo0P0001Koool00ol0VOooooooo`1f
oooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0E
oooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?
oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool200005_ooo`03o`2Ioooooooo
07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo
01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool0
08Ooool500000oooo`030000oooooooo01Goool00ol0VOooooooo`1foooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo01Goool00ol0VOooooooo`1foooo0029oooo00<0003oooooool00ooo
o`<0000Eoooo00?o09Woooooool0M_ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0E
oooo00?o09Woooooool0M_ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Eoooo00?o
09Woooooool0M_ooo`00R?ooo`800005oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool0
08ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`80000Foooo00?o09Wooooo
ool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0003ooooo
ool05Oooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_oo
o`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo0P0001Koool00ol0VOoo
ooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool00`000?oo
ooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1f
oooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool200005_ooo`03o`2I
oooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000
oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo
07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`80000Foooo00?o
09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0
003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Wooooo
ool0M_ooo`00Qoooo`@00004oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008Ooool0
0`000?ooooooo`05oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008Soool00`000?oo
ooooo`04oooo0`0001Goool00ol0VOooooooo`1foooo0029oooo00<0003oooooool00oooo`030000
oooooooo01Goool00ol0VOooooooo`1foooo0027oooo00@0003oooooool00004oooo00<0003ooooo
ool05Oooo`03o`2Ioooooooo07Koool008Soool200001Oooo`030000oooooooo01Goool00ol0VOoo
ooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool200005_oo
o`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Sooo
o`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2I
oooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`80000F
oooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?
oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o
09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo0P00
01Koool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool0
08ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool0
0ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool0
0`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`80000Foooo00?o09Woooooool0M_oo
o`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Ooo
o`03o`2Ioooooooo07Koool008Soool200001Oooo`030000oooooooo01Goool00ol0VOooooooo`1f
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool0
08Woool00`000?ooooooo`03oooo0`0001Goool00ol0VOooooooo`1foooo002:oooo00<0003ooooo
ool0Toooo`00Qoooo`040000oooooooo0000UOooo`00R?ooo`80002Foooo003ooooo8Oooo`00oooo
ob7oool007ooool00`000?ooooooo`0Loooo00<0003oooooool0Ooooo`00O_ooo`030000oooooooo
00Soool00`000?ooooooo`0Coooo00<0003oooooool0O_ooo`00O_ooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Ooool200001?ooo`800004oooo00<0003oooooool0O_ooo`00O_oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000
oooooooo00002Oooo`030000oooooooo07koool007goool00`000?ooooooo`02oooo00<0003ooooo
ool03Oooo`040000oooooooo00002_ooo`030000oooooooo07goool007koool00`000?ooooooo`05
00003?ooo`040000oooooooo00002Oooo`030000oooooooo07koool007koool01@000?oooooooooo
o`00000?oooo00@0003oooooool00009oooo00<0003oooooool0O_ooo`00Ooooo`030000oooooooo
017oool200002Oooo`030000oooooooo07ooool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.58872 .30902 L
.59405 .30902 L
.59698 .30902 L
.59975 .30902 L
.60237 .30902 L
.60309 .30902 L
.60385 .30902 L
.6045 .30902 L
s
.6045 .30902 m
.60471 .61803 L
s
0 .4 1 r
.02381 .30911 m
.04262 .30913 L
.06244 .30916 L
.08426 .3092 L
.10458 .30924 L
.14264 .30935 L
.16305 .30943 L
.18163 .30952 L
.20239 .30964 L
.22156 .30978 L
.25997 .31015 L
.2787 .31038 L
.29932 .3107 L
.33961 .31149 L
.37838 .31245 L
.39809 .31297 L
.41961 .31348 L
.42957 .31368 L
.4402 .31385 L
.44536 .31392 L
.45023 .31397 L
.45459 .314 L
.45705 .31402 L
.45932 .31403 L
.46058 .31403 L
.46177 .31404 L
.46286 .31404 L
.46401 .31404 L
.46527 .31404 L
.46643 .31404 L
.46767 .31404 L
.46839 .31404 L
.46905 .31404 L
.47016 .31404 L
.47133 .31404 L
.47233 .31404 L
.47343 .31403 L
.47587 .31402 L
.47814 .31401 L
.48337 .31397 L
.48813 .31392 L
.4988 .31378 L
.50879 .3136 L
.51799 .3134 L
.53879 .31289 L
.55914 .31236 L
.57819 .31187 L
.58756 .31164 L
.59645 .31144 L
.60136 .31133 L
Mistroke
.6027 .3113 L
.60344 .31129 L
.60413 .31127 L
.60478 .30902 L
.60548 .30902 L
.60671 .30902 L
.61608 .30902 L
.65713 .30902 L
.69667 .30902 L
.7347 .30902 L
.77517 .30902 L
.81413 .30902 L
.85555 .30902 L
.89544 .30902 L
.93382 .30902 L
.97466 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Koool306Ko00<00000I_l0I_l02P1Vo`03000006Ko06Ko00T0I_l00`00001Vo`1Vo`0906Ko00<0
0000I_l0I_l02@1Vo`03000006Ko06Ko00T0I_l00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Goool406Ko00<00000I_l0I_l02@1Vo`03000006Ko06Ko00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool05Ooo
o`00;_ooo`030000oooooooo02koool00`000?ooooooo`0Foooo5`1Vo`03000006Ko06Ko00D0I_lB
oooo00?o09Woooooool04oooo`030000oooooooo02koool00`000?ooooooo`0]oooo002?oooo00<0
003oooooool05oooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Wooooo
ool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo0P0001Soool0
0ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool0
0`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOoo
ooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool200006?oo
o`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Sooo
o`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2I
oooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`80000H
oooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?
oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o
09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo0P00
01Soool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool0
08ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool0
0ol0VOooooooo`1doooo0027oooo1@0000?oool00`000?ooooooo`0Goooo00?o09Woooooool0M?oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00ROoo
o`030000oooooooo00?oool300005oooo`03o`2Ioooooooo07Coool008Woool00`000?ooooooo`03
oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008Woool00`000?ooooooo`03oooo00<0
003oooooool05oooo`03o`2Ioooooooo07Coool008Soool200001Oooo`030000oooooooo01Ooool0
0ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool2
00006?ooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?oo
o`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05ooo
o`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Sooo
o`80000Hoooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1d
oooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0H
oooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?
oooo0P0001Woool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo
07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo
01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool0
08ooool200006Oooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Wooooo
ool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0003ooooo
ool06?ooo`03o`2Ioooooooo07?oool008Ooool400001?ooo`030000oooooooo01Soool00ol0VOoo
ooooo`1coooo0027oooo00<0003oooooool01Oooo`030000oooooooo01Soool00ol0VOooooooo`1c
oooo0028oooo00<0003oooooool01?ooo`<0000Hoooo00?o09Woooooool0Loooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Qoooo`040000oooooooo
00001?ooo`030000oooooooo01Soool00ol0VOooooooo`1coooo0028oooo0P0000Goool00`000?oo
ooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1c
oooo002?oooo0P0001Woool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2I
oooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000
oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo
07?oool008ooool200006Oooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o
09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0
003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Wooooo
ool0Loooo`00Soooo`80000Ioooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool0
0ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool0
0`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOoo
ooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool200006Ooo
o`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Sooo
o`030000oooooooo01Soool00ol0VOooooooo`1coooo0028oooo0P0000Goool00`000?ooooooo`0H
oooo00?o09Woooooool0Loooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo01Soool0
0ol0VOooooooo`1coooo0029oooo00<0003oooooool00oooo`<0000Hoooo00?o09Woooooool0Looo
o`00R_ooo`030000oooooooo09?oool008Ooool010000?ooooooo`0009Goool008Soool20000U_oo
o`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool0
07_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`D00002
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?oo
ooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`00
00[oool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo07_oool007_oool0
1@000?ooooooooooo`00000?oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000
oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000oooooooo
07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.58872 .30902 L
.59975 .30902 L
.60479 .30902 L
.60756 .30902 L
.61016 .30902 L
.6126 .30902 L
.61327 .30902 L
.61397 .30902 L
s
.61397 .30902 m
.61435 .61803 L
s
0 .4 1 r
.02381 .30921 m
.04262 .30925 L
.06244 .30931 L
.08426 .30938 L
.10458 .30947 L
.14264 .30969 L
.16305 .30985 L
.18163 .31002 L
.20239 .31027 L
.22156 .31054 L
.25997 .31129 L
.2787 .31176 L
.29932 .31239 L
.33961 .31398 L
.37838 .31592 L
.39809 .31695 L
.41961 .31799 L
.42957 .31839 L
.4402 .31874 L
.44536 .31887 L
.45023 .31897 L
.45459 .31904 L
.45705 .31907 L
.45932 .31909 L
.46058 .3191 L
.46177 .31911 L
.46286 .31911 L
.46401 .31912 L
.46527 .31912 L
.46643 .31912 L
.46767 .31912 L
.46839 .31912 L
.46905 .31912 L
.47016 .31912 L
.47133 .31911 L
.47233 .31911 L
.47343 .3191 L
.47587 .31908 L
.47814 .31905 L
.48337 .31898 L
.48813 .31888 L
.4988 .31858 L
.50879 .31822 L
.51799 .31783 L
.53879 .3168 L
.55914 .31573 L
.57819 .31475 L
.59645 .31389 L
.60171 .31366 L
.60671 .31344 L
Mistroke
.61119 .31326 L
.61242 .31321 L
.61373 .31316 L
.61496 .30902 L
.61608 .30902 L
.65619 .30902 L
.6948 .30902 L
.73585 .30902 L
.77539 .30902 L
.81342 .30902 L
.85389 .30902 L
.89285 .30902 L
.93427 .30902 L
.97416 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`000?ooooooo`09oooo00<00000I_l0I_l02@1Vo`03000006Ko06Ko
00T0I_l00`00001Vo`1Vo`0:06Ko00<00000I_l0I_l02@1Vo`03000006Ko06Ko00T0I_l00`00001V
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool010000?ooooooooooo`80I_l6oooo00<0003ooooo
ool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo01Goool0
02koool00`000?ooooooo`0^oooo00<0003oool0I_l05P1VoaOoool00`000?ooooooo`05oooo501V
o`03ooooo`2Ioooo017oool00`000?ooooooo`0^oooo00<0003oooooool0;Oooo`00N?oooaL0I_l0
0`00001Vo`1Vo`0506Ko5Oooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o
09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo0P00
01_oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool0
08ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool0
0ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool2
00006oooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOoo
o`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_oo
o`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Sooo
o`80000Koooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1a
oooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0J
oooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?
oooo0P0001_oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo
077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo
01[oool00ol0VOooooooo`1aoooo0027oooo1@0000?oool00`000?ooooooo`0Joooo00?o09Wooooo
ool0LOooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Joooo00?o09Woooooool0LOoo
o`00ROooo`030000oooooooo00?oool300006_ooo`03o`2Ioooooooo077oool008Woool00`000?oo
ooooo`03oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008Woool00`000?ooooooo`03
oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008Soool200001Oooo`030000oooooooo
01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool0
08ooool200006oooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Wooooo
ool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003ooooo
ool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOoo
o`00Soooo`80000Koooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOoo
ooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool00`000?oo
ooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1a
oooo002?oooo0P0001_oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2I
oooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000
oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo
077oool008ooool200006oooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o
09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0
003oooooool06_ooo`03o`2Ioooooooo077oool008Ooool400001?ooo`030000oooooooo01[oool0
0ol0VOooooooo`1aoooo0027oooo00<0003oooooool01Oooo`030000oooooooo01[oool00ol0VOoo
ooooo`1aoooo0028oooo00<0003oooooool01?ooo`<0000Joooo00?o09Woooooool0LOooo`00ROoo
o`030000oooooooo00?oool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Qoooo`040000
oooooooo00001?ooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo0028oooo0P0000Goool0
0`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOoo
ooooo`1aoooo002?oooo0P0001_oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_oo
o`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Sooo
o`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2I
oooooooo077oool008ooool200006oooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0J
oooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?
oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o
09Woooooool0LOooo`00Soooo`80000Koooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo
01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool0
08ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool0
0ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool2
00006oooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOoo
o`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo0028oooo0P0000Goool00`000?oo
ooooo`0Joooo00?o09Woooooool0LOooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo
01[oool00ol0VOooooooo`1aoooo0029oooo00<0003oooooool00oooo`<0000Joooo00?o09Wooooo
ool0LOooo`00R_ooo`030000oooooooo09?oool008Ooool010000?ooooooo`0009Goool008Soool2
0000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo
07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool0
07_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000ooo
o`@00003oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`030000oooooooo00Coool0
0`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00goool010000?oo
ooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000<oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0
003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.59832 .30902 L
.60873 .30902 L
.61445 .30902 L
.61726 .30902 L
.61984 .30902 L
.62236 .30902 L
.62363 .30902 L
s
.62363 .30902 m
.62385 .61803 L
s
0 .4 1 r
.02381 .30931 m
.04262 .30937 L
.06244 .30945 L
.08426 .30957 L
.10458 .3097 L
.14264 .31003 L
.16305 .31027 L
.18163 .31054 L
.20239 .31091 L
.22156 .31133 L
.25997 .31245 L
.2787 .31317 L
.29932 .31412 L
.33961 .31652 L
.37838 .31945 L
.39809 .32102 L
.41961 .32259 L
.42957 .32319 L
.4402 .32372 L
.44536 .32392 L
.45023 .32407 L
.45459 .32417 L
.45705 .32422 L
.45932 .32425 L
.46058 .32427 L
.46177 .32428 L
.46286 .32429 L
.46401 .32429 L
.46527 .3243 L
.46643 .3243 L
.46767 .3243 L
.46839 .3243 L
.46905 .3243 L
.47016 .32429 L
.47133 .32429 L
.47233 .32428 L
.47343 .32427 L
.47587 .32424 L
.47814 .3242 L
.48337 .32408 L
.48813 .32393 L
.4988 .32349 L
.50879 .32294 L
.51799 .32235 L
.53879 .32079 L
.57819 .31769 L
.59799 .31628 L
.60664 .31572 L
.61608 .31514 L
.61858 .31499 L
Mistroke
.62125 .31484 L
.62255 .31477 L
.62377 .3147 L
.62487 .30902 L
.62605 .30902 L
.63552 .30902 L
.65642 .30902 L
.69747 .30902 L
.73701 .30902 L
.77503 .30902 L
.81551 .30902 L
.85447 .30902 L
.89589 .30902 L
.93578 .30902 L
.97416 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`000?ooooooo`0906Ko00<00000I_l0I_l02@1Vo`03000006Ko06Ko
00T0I_l00`00001Vo`1Vo`0:06Ko00<00000I_l0I_l02@1Vo`03000006Ko06Ko00@0I_l5oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool01?ooo`0306Kooooooooo
00;oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool05Oooo`00;_ooo`030000oooooooo02Woool506Ko00<00000I_l0I_l02@1VobCoool0
0`000?ooooooo`0Doooo2@1Voa3oool00`000?ooooooo`0^oooo00<0003oooooool0;Oooo`00Jooo
o`d0I_lGoooo00<0003oooooool01Oooo`l0I_l8oooo00?o09Woooooool0Koooo`00N?oooaL0I_l0
0`00001Vo`1Vo`0506Ko5oooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o
09Woooooool0Koooo`00Soooo`80000Moooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo
01coool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool0
08ooool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo01coool0
0ol0VOooooooo`1_oooo002?oooo0P0001goool00ol0VOooooooo`1_oooo002?oooo00<0003ooooo
ool07?ooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o09Woooooool0Kooo
o`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?oo
o`03o`2Ioooooooo06ooool008ooool200007Oooo`03o`2Ioooooooo06ooool008ooool00`000?oo
ooooo`0Loooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_
oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0L
oooo00?o09Woooooool0Koooo`00Soooo`80000Moooo00?o09Woooooool0Koooo`00Soooo`030000
oooooooo01coool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo
06ooool008ooool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Qoooo`D00003oooo00<0
003oooooool07?ooo`03o`2Ioooooooo06ooool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool07?ooo`03o`2Ioooooooo06ooool008Woool00`000?ooooooo`03oooo0`0001coool00ol0VOoo
ooooo`1_oooo0029oooo00<0003oooooool00oooo`030000oooooooo01coool00ol0VOooooooo`1_
oooo0029oooo00<0003oooooool00oooo`030000oooooooo01coool00ol0VOooooooo`1_oooo0028
oooo0P0000Goool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo
01coool00ol0VOooooooo`1_oooo002?oooo0P0001goool00ol0VOooooooo`1_oooo002?oooo00<0
003oooooool07?ooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o09Wooooo
ool0Koooo`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_oooo002?oooo00<0003ooooo
ool07?ooo`03o`2Ioooooooo06ooool008ooool200007Oooo`03o`2Ioooooooo06ooool008ooool0
0`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo01coool00ol0VOoo
ooooo`1_oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008ooool00`000?oo
ooooo`0Loooo00?o09Woooooool0Koooo`00Soooo`80000Moooo00?o09Woooooool0Koooo`00Sooo
o`030000oooooooo01coool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?ooo`03o`2I
oooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Soooo`030000
oooooooo01coool00ol0VOooooooo`1_oooo002?oooo0P0001goool00ol0VOooooooo`1_oooo002?
oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o
09Woooooool0Koooo`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_oooo0027oooo1000
00Coool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Qoooo`030000oooooooo00Goool0
0`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00R?ooo`030000oooooooo00Coool300007?oo
o`03o`2Ioooooooo06ooool008Woool00`000?ooooooo`03oooo00<0003oooooool07?ooo`03o`2I
oooooooo06ooool008Ooool010000?ooooooo`0000Coool00`000?ooooooo`0Loooo00?o09Wooooo
ool0Koooo`00R?ooo`800005oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008ooool0
0`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Soooo`80000Moooo00?o09Woooooool0Kooo
o`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?oo
o`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Sooo
o`030000oooooooo01coool00ol0VOooooooo`1_oooo002?oooo0P0001goool00ol0VOooooooo`1_
oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0L
oooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_oooo002?
oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008ooool200007Oooo`03o`2Ioooooooo
06ooool008ooool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo
01coool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool0
08ooool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo01coool0
0ol0VOooooooo`1_oooo002?oooo0P0001goool00ol0VOooooooo`1_oooo002?oooo00<0003ooooo
ool07?ooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o09Woooooool0Kooo
o`00R?ooo`800005oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008Ooool010000?oo
ooooo`0000Coool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00ROooo`030000oooooooo
00?oool300007?ooo`03o`2Ioooooooo06ooool008[oool00`000?ooooooo`2Coooo0027oooo00@0
003oooooool0002Eoooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000
oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo
01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01oooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_oo
o`030000oooooooo00goool010000?ooooooo`0000[oool00`000?ooooooo`03oooo00<0003ooooo
ool0N_ooo`00Noooo`030000oooooooo00D0000<oooo00@0003oooooool0000;oooo00D0003ooooo
ooooool00000OOooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:
oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.59832 .30902 L
.60873 .30902 L
.61984 .30902 L
.6254 .30902 L
.62812 .30902 L
.63064 .30902 L
.63182 .30902 L
.63292 .30902 L
s
.63292 .30902 m
.63327 .61803 L
s
0 .4 1 r
.02381 .30941 m
.04262 .3095 L
.06244 .30961 L
.08426 .30976 L
.10458 .30993 L
.14264 .31038 L
.16305 .31071 L
.18163 .31107 L
.20239 .31157 L
.22156 .31213 L
.25997 .31365 L
.2787 .31462 L
.29932 .3159 L
.33961 .31914 L
.37838 .32309 L
.39809 .32521 L
.41961 .32732 L
.42957 .32814 L
.4402 .32884 L
.44536 .32911 L
.45023 .32932 L
.45459 .32946 L
.45705 .32952 L
.45932 .32957 L
.46058 .32959 L
.46177 .3296 L
.46286 .32961 L
.46401 .32962 L
.46527 .32963 L
.46643 .32963 L
.46767 .32963 L
.46839 .32963 L
.46905 .32963 L
.47016 .32962 L
.47133 .32961 L
.47233 .3296 L
.47343 .32959 L
.47587 .32954 L
.47814 .32949 L
.48337 .32933 L
.48813 .32914 L
.4988 .32854 L
.50879 .3278 L
.51799 .32699 L
.53879 .3249 L
.57819 .32071 L
.59799 .31881 L
.61608 .31727 L
.62085 .3169 L
.62605 .31651 L
Mistroke
.62843 .31634 L
.62974 .31625 L
.63097 .31616 L
.63212 .31608 L
.63336 .30902 L
.63449 .30902 L
.63552 .30902 L
.65642 .30902 L
.69596 .30902 L
.73398 .30902 L
.77446 .30902 L
.81342 .30902 L
.85483 .30902 L
.89473 .30902 L
.93311 .30902 L
.97394 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`0906Ko00<00000I_l0I_l02@1Vo`03000006Ko06Ko
00T0I_l00`00001Vo`1Vo`0:06Ko00<00000I_l0I_l00`1Vo`Koool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool01_ooo`0406Koo`2Ioooo
00002oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000
oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo01Goool0
02koool00`000?ooooooo`0Loooo4P1Vo`03000006Kooooo02goool00`000?ooooooo`0Loooo0`1V
o`03o`2Ioooooooo00_oool00`000?ooooooo`0^oooo00<0003oooooool0;Oooo`00HOooo`X0I_lT
oooo00<0003oooooool03Oooo`l0I_l3oooo00?o09Woooooool0K?ooo`00Joooo`P0I_lLoooo00<0
003oooooool01Oooo`P0I_lBoooo00?o09Woooooool0K?ooo`00Loooo`h0I_l=oooo00<0I_l00000
I_l01P1Voa[oool00ol0VOooooooo`1/oooo0021oooo3@1Vo`03oooo00000000023oool00ol0VOoo
ooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool008ooool00`000?oo
ooooo`0Ooooo00?o09Woooooool0K?ooo`00Soooo`030000oooooooo01ooool00ol0VOooooooo`1/
oooo002?oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool008ooool200008?ooo`03o`2I
oooooooo06coool008ooool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00Soooo`030000
oooooooo01ooool00ol0VOooooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2Ioooooooo
06coool008ooool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00Soooo`80000Poooo00?o
09Woooooool0K?ooo`00Soooo`030000oooooooo01ooool00ol0VOooooooo`1/oooo002?oooo00<0
003oooooool07oooo`03o`2Ioooooooo06coool008ooool00`000?ooooooo`0Ooooo00?o09Wooooo
ool0K?ooo`00Soooo`030000oooooooo01ooool00ol0VOooooooo`1/oooo002?oooo0P00023oool0
0ol0VOooooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool008ooool0
0`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00Soooo`030000oooooooo01ooool00ol0VOoo
ooooo`1/oooo0027oooo1@0000?oool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00ROoo
o`030000oooooooo00?oool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00ROooo`030000
oooooooo00?oool300007oooo`03o`2Ioooooooo06coool008Woool00`000?ooooooo`03oooo00<0
003oooooool07oooo`03o`2Ioooooooo06coool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool07oooo`03o`2Ioooooooo06coool008Soool200001Oooo`030000oooooooo01ooool00ol0VOoo
ooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool008ooool200008?oo
o`03o`2Ioooooooo06coool008ooool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00Sooo
o`030000oooooooo01ooool00ol0VOooooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2I
oooooooo06coool008ooool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00Soooo`80000P
oooo00?o09Woooooool0K?ooo`00Soooo`030000oooooooo01ooool00ol0VOooooooo`1/oooo002?
oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool008ooool00`000?ooooooo`0Ooooo00?o
09Woooooool0K?ooo`00Soooo`030000oooooooo01ooool00ol0VOooooooo`1/oooo002?oooo0P00
023oool00ol0VOooooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool0
08ooool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00Soooo`030000oooooooo01ooool0
0ol0VOooooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool008ooool2
00008?ooo`03o`2Ioooooooo06coool008ooool00`000?ooooooo`0Ooooo00?o09Woooooool0K?oo
o`00Soooo`030000oooooooo01ooool00ol0VOooooooo`1/oooo002?oooo00<0003oooooool07ooo
o`03o`2Ioooooooo06coool008Ooool400001?ooo`030000oooooooo01ooool00ol0VOooooooo`1/
oooo0027oooo00<0003oooooool01Oooo`030000oooooooo01ooool00ol0VOooooooo`1/oooo0028
oooo00<0003oooooool01?ooo`<0000Ooooo00?o09Woooooool0K?ooo`00ROooo`030000oooooooo
00?oool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00Qoooo`040000oooooooo00001?oo
o`030000oooooooo01ooool00ol0VOooooooo`1/oooo0028oooo0P0000Goool00`000?ooooooo`0O
oooo00?o09Woooooool0K?ooo`00Soooo`030000oooooooo01ooool00ol0VOooooooo`1/oooo002?
oooo0P00023oool00ol0VOooooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2Ioooooooo
06coool008ooool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00Soooo`030000oooooooo
01ooool00ol0VOooooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool0
08ooool200008?ooo`03o`2Ioooooooo06coool008ooool00`000?ooooooo`0Ooooo00?o09Wooooo
ool0K?ooo`00Soooo`030000oooooooo01ooool00ol0VOooooooo`1/oooo002?oooo00<0003ooooo
ool07oooo`03o`2Ioooooooo06coool008ooool00`000?ooooooo`0Ooooo00?o09Woooooool0K?oo
o`00Soooo`80000Poooo00?o09Woooooool0K?ooo`00Soooo`030000oooooooo01ooool00ol0VOoo
ooooo`1/oooo002?oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool008ooool00`000?oo
ooooo`0Ooooo00?o09Woooooool0K?ooo`00Soooo`030000oooooooo01ooool00ol0VOooooooo`1/
oooo002?oooo00<0003oooooool07oooo`03o`2Ioooooooo06coool008ooool200008?ooo`03o`2I
oooooooo06coool008ooool00`000?ooooooo`0Ooooo00?o09Woooooool0K?ooo`00Soooo`030000
oooooooo01ooool00ol0VOooooooo`1/oooo0028oooo0P0000Goool00`000?ooooooo`0Ooooo00?o
09Woooooool0K?ooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo01ooool00ol0VOoo
ooooo`1/oooo0029oooo00<0003oooooool00oooo`<0000Ooooo00?o09Woooooool0K?ooo`00R_oo
o`030000oooooooo09?oool008Ooool010000?ooooooo`0009Goool008Soool20000U_ooo`00oooo
ob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool0
0`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001Oooo`<00002oooo00<0
003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`040000oooooooo00002oooo`050000oooooooooooo000007goool007[oool0
0`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002?ooo`D00003oooo00<0
003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool0
10000?ooooooo`0000Woool00`000?ooo`000003oooo00<0003oooooool0Noooo`00O?ooo`030000
oooooooo017oool200002oooo`800002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.59832 .30902 L
.61984 .30902 L
.6298 .30902 L
.63527 .30902 L
.63796 .30902 L
.64043 .30902 L
.64164 .30902 L
.64277 .30902 L
s
.64277 .30902 m
.64312 .61803 L
s
0 .4 1 r
.02381 .30952 m
.04262 .30962 L
.06244 .30976 L
.08426 .30996 L
.10458 .31018 L
.14264 .31075 L
.16305 .31116 L
.18163 .31162 L
.20239 .31226 L
.22156 .31297 L
.25997 .31489 L
.2787 .31612 L
.29932 .31775 L
.33961 .32186 L
.37838 .32687 L
.39809 .32956 L
.41961 .33224 L
.42957 .33328 L
.4402 .33417 L
.44536 .33451 L
.45023 .33477 L
.45459 .33495 L
.45705 .33503 L
.45932 .33509 L
.46058 .33511 L
.46177 .33513 L
.46286 .33515 L
.46401 .33516 L
.46527 .33517 L
.46643 .33517 L
.46767 .33517 L
.46839 .33517 L
.46905 .33517 L
.47016 .33516 L
.47133 .33515 L
.47233 .33513 L
.47343 .33511 L
.47587 .33506 L
.47814 .33499 L
.48337 .33479 L
.48813 .33454 L
.4988 .33378 L
.50879 .33284 L
.51799 .33182 L
.53879 .32917 L
.57819 .32386 L
.61608 .31949 L
.62605 .31853 L
.63552 .31768 L
.63805 .31746 L
Mistroke
.64075 .31724 L
.64155 .31718 L
.6423 .31712 L
.64297 .30902 L
.6437 .30902 L
.64644 .30902 L
.65642 .30902 L
.69747 .30902 L
.73701 .30902 L
.77503 .30902 L
.81551 .30902 L
.85447 .30902 L
.89589 .30902 L
.93578 .30902 L
.97416 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`0906Ko00<00000I_l0I_l02@1Vo`03000006Ko06Ko
00T0I_l00`00001Vo`1Vo`0:06Ko00<00000I_l0I_l00`1Vo`Koool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000^
oooo00<0003oooooool07?ooo`d0I_l5oooo00<0003oooooool0;Oooo`030000oooooooo027oool0
0`1Vooooooooo`09oooo00<0003oooooool0;_ooo`030000oooooooo02goool005[oool706Ko;_oo
o`030000oooooooo01Koool;06Ko00?o09Woooooool0J_ooo`00HOooo`X0I_lToooo00<0003ooooo
ool03oooo`L0I_l;oooo00?o09Woooooool0J_ooo`00Joooo`P0I_lLoooo00<0003oooooool02_oo
o`D0I_lBoooo00?o09Woooooool0J_ooo`00Loooo`T0I_lCoooo0P0000/0I_lGoooo00?o09Wooooo
ool0J_ooo`00O?oooa<0I_l00`00001Vooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000
oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo
06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`80000Roooo00?o
09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0
003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Wooooo
ool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo0P0002;oool0
0ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool0
0`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOoo
ooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool200008_oo
o`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Sooo
o`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2I
oooooooo06[oool008Ooool500000oooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo0029
oooo00<0003oooooool00oooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo0029oooo00<0
003oooooool00oooo`<0000Qoooo00?o09Woooooool0J_ooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`0Qoooo00?o09Woooooool0J_ooo`00R?ooo`800005oooo00<0003oooooool08Oooo`03o`2I
oooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`80000R
oooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?
oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o
09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo0P00
02;oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool0
08ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool0
0ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool2
00008_ooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_oo
o`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Ooo
o`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Sooo
o`80000Roooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Z
oooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Q
oooo00?o09Woooooool0J_ooo`00Qoooo`@00004oooo00<0003oooooool08Oooo`03o`2Ioooooooo
06[oool008Ooool00`000?ooooooo`05oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool0
08Soool00`000?ooooooo`04oooo0`00027oool00ol0VOooooooo`1Zoooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo0027oooo00@0003oooooool00004
oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008Soool200001Oooo`030000oooooooo
027oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool0
08ooool200008_ooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Wooooo
ool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0003ooooo
ool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_oo
o`00Soooo`80000Roooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOoo
ooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?oo
ooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Z
oooo002?oooo0P0002;oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2I
oooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000
oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo
06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`80000Roooo00?o
09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0
003oooooool08Oooo`03o`2Ioooooooo06[oool008Soool200001Oooo`030000oooooooo027oool0
0ol0VOooooooo`1Zoooo0027oooo00@0003oooooool00004oooo00<0003oooooool08Oooo`03o`2I
oooooooo06[oool008Woool00`000?ooooooo`03oooo0`00027oool00ol0VOooooooo`1Zoooo002:
oooo00<0003oooooool0Toooo`00Qoooo`040000oooooooo0000UOooo`00R?ooo`80002Foooo003o
oooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Nooo
o`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800004oooo0P0000Coool0
0`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003?oo
o`040000oooooooo00002Oooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Woool00`000?ooooooo`03oooo00<0003oooooool0Nooo
o`00O?ooo`030000oooooooo017oool200002_ooo`<00002oooo00<0003oooooool0O?ooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.59832 .30902 L
.61984 .30902 L
.6298 .30902 L
.64043 .30902 L
.64559 .30902 L
.64812 .30902 L
.64923 .30902 L
.65045 .30902 L
.65155 .30902 L
s
.65155 .30902 m
.65186 .61803 L
s
0 .4 1 r
.02381 .30963 m
.04262 .30976 L
.06244 .30993 L
.08426 .31017 L
.10458 .31044 L
.14264 .31114 L
.16305 .31164 L
.18163 .3122 L
.20239 .31297 L
.22156 .31385 L
.25997 .31619 L
.2787 .3177 L
.29932 .31969 L
.33961 .32471 L
.37838 .33083 L
.39809 .33411 L
.41961 .33739 L
.42957 .33866 L
.4402 .33975 L
.44536 .34017 L
.45023 .34048 L
.45459 .3407 L
.45705 .3408 L
.45932 .34087 L
.46058 .3409 L
.46177 .34092 L
.46286 .34094 L
.46401 .34096 L
.46527 .34097 L
.46643 .34097 L
.46767 .34097 L
.46839 .34097 L
.46905 .34097 L
.47016 .34096 L
.47133 .34094 L
.47233 .34092 L
.47343 .3409 L
.47587 .34083 L
.47814 .34076 L
.48337 .34051 L
.48813 .3402 L
.4988 .33927 L
.50879 .33812 L
.51799 .33688 L
.53879 .33364 L
.57819 .32715 L
.61608 .32182 L
.63552 .3196 L
.64112 .31903 L
.64644 .31851 L
Mistroke
.64875 .31829 L
.65002 .31817 L
.65121 .31806 L
.65189 .318 L
.65263 .30902 L
.65391 .30902 L
.65642 .30902 L
.69747 .30902 L
.73701 .30902 L
.77503 .30902 L
.81551 .30902 L
.85447 .30902 L
.89589 .30902 L
.93578 .30902 L
.97416 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`0906Ko00<00000I_l0I_l02@1Vo`03000006Ko06Ko
00T0I_l00`00001Vo`1Vo`0906Ko00?oool0003oool02_ooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00@0003ooooo09T0I_l8
oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool05Oooo`00;_oo
o`030000oooooooo01Goool?06Ko2_ooo`030000oooooooo02goool00`000?ooooooo`0Soooo00<0
I_ooooooool01oooo`030000oooooooo02koool00`000?ooooooo`0]oooo001Eoooo301Vobkoool0
0`000?ooooooo`0Moooo1`1Vof[oool0067oool806Ko9_ooo`030000oooooooo01Koool706Ko1_oo
o`03o`2Ioooooooo06Soool006Woool506Ko8Oooo`030000oooooooo00ooool706Ko3Oooo`03o`2I
oooooooo06Soool006koool506Ko7?ooo`80000;oooo1@1VoaCoool00ol0VOooooooo`1Xoooo001c
oooo1@1VoaOoool010000?ooooooooooo`T0I_lIoooo00?o09Woooooool0J?ooo`00N?ooo`h0I_l2
oooo1`1Vo`04000006Ko06Ko06Ko8_ooo`03o`2Ioooooooo06Soool008Goool406Ko1_ooo`030000
oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo
06Soool008ooool200009?ooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o
09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo00<0
003oooooool08oooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o09Wooooo
ool0J?ooo`00Soooo`80000Toooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool0
0ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008ooool0
0`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOoo
ooooo`1Xoooo002?oooo0P0002Coool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08ooo
o`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Sooo
o`030000oooooooo02?oool00ol0VOooooooo`1Xoooo0027oooo1@0000?oool00`000?ooooooo`0S
oooo00?o09Woooooool0J?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Soooo00?o
09Woooooool0J?ooo`00ROooo`030000oooooooo00?oool300008oooo`03o`2Ioooooooo06Soool0
08Woool00`000?ooooooo`03oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008Woool0
0`000?ooooooo`03oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008Soool200001Ooo
o`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2I
oooooooo06Soool008ooool200009?ooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0S
oooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?
oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o
09Woooooool0J?ooo`00Soooo`80000Toooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo
02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool0
08ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool0
0ol0VOooooooo`1Xoooo002?oooo0P0002Coool00ol0VOooooooo`1Xoooo002?oooo00<0003ooooo
ool08oooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?oo
o`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08ooo
o`03o`2Ioooooooo06Soool008ooool200009?ooo`03o`2Ioooooooo06Soool008ooool00`000?oo
ooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1X
oooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008Ooool400001?ooo`030000
oooooooo02?oool00ol0VOooooooo`1Xoooo0027oooo00<0003oooooool01Oooo`030000oooooooo
02?oool00ol0VOooooooo`1Xoooo0028oooo00<0003oooooool01?ooo`<0000Soooo00?o09Wooooo
ool0J?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Soooo00?o09Woooooool0J?oo
o`00Qoooo`040000oooooooo00001?ooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo0028
oooo0P0000Goool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo
02?oool00ol0VOooooooo`1Xoooo002?oooo0P0002Coool00ol0VOooooooo`1Xoooo002?oooo00<0
003oooooool08oooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o09Wooooo
ool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003ooooo
ool08oooo`03o`2Ioooooooo06Soool008ooool200009?ooo`03o`2Ioooooooo06Soool008ooool0
0`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOoo
ooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008ooool00`000?oo
ooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`80000Toooo00?o09Woooooool0J?ooo`00Sooo
o`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2I
oooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`030000
oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo
06Soool008ooool200009?ooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o
09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo0028oooo0P00
00Goool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Qoooo`040000oooooooo00001?oo
o`030000oooooooo02?oool00ol0VOooooooo`1Xoooo0029oooo00<0003oooooool00oooo`<0000S
oooo00?o09Woooooool0J?ooo`00R_ooo`030000oooooooo09?oool008Ooool010000?ooooooo`00
09Goool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_oo
o`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000
oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P00
00Coool200000oooo`<00004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003ooooo
ool03Oooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo07[oool0
07_oool00`000?ooooooo`0500003?ooo`040000oooooooo00002?ooo`<00004oooo00<0003ooooo
ool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`0000Woool00`000?oo
ooooo`03oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`<00002
oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.64043 .30902 L
.65045 .30902 L
.65519 .30902 L
.65954 .30902 L
.66069 .30902 L
.66177 .30902 L
s
.66177 .30902 m
.6621 .61803 L
s
0 .4 1 r
.02381 .30974 m
.04262 .3099 L
.06244 .31011 L
.08426 .31039 L
.10458 .31071 L
.14264 .31154 L
.16305 .31214 L
.18163 .31281 L
.20239 .31373 L
.22156 .31477 L
.25997 .31757 L
.2787 .31936 L
.29932 .32174 L
.33961 .32772 L
.37838 .33501 L
.39809 .33892 L
.41961 .34282 L
.42957 .34433 L
.4402 .34563 L
.44536 .34613 L
.45023 .34651 L
.45459 .34677 L
.45705 .34689 L
.45932 .34697 L
.46058 .34701 L
.46177 .34704 L
.46286 .34706 L
.46401 .34707 L
.46527 .34709 L
.46643 .34709 L
.46767 .34709 L
.46839 .34709 L
.46905 .34708 L
.47016 .34707 L
.47133 .34705 L
.47233 .34703 L
.47343 .34701 L
.47587 .34693 L
.47814 .34683 L
.48337 .34654 L
.48813 .34617 L
.4988 .34506 L
.50879 .3437 L
.51799 .34222 L
.53879 .33835 L
.57819 .33062 L
.61608 .32427 L
.63716 .32143 L
.64715 .32025 L
.65642 .31925 L
Mistroke
.65879 .319 L
.65996 .31889 L
.66103 .31878 L
.66227 .30902 L
.66292 .30902 L
.66361 .30902 L
.66594 .30902 L
.67633 .30902 L
.69524 .30902 L
.73326 .30902 L
.77374 .30902 L
.8127 .30902 L
.85411 .30902 L
.89401 .30902 L
.93239 .30902 L
.97323 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`0906Ko00<00000I_l0I_l02@1Vo`03000006Ko06Ko
00T0I_l00`00001Vo`1Vo`0406Ko1_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00;oool00`1Vooooooooo`04oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool05Oooo`00;_ooo`030000oooooooo013oool<06Ko4_ooo`030000oooooooo02goool0
0`000?ooooooo`0Voooo00<0I_ooooooool01?ooo`030000oooooooo02koool00`000?ooooooo`0]
oooo001=oooo3@1VocGoool00`000?ooooooo`0Roooo1@1VofOoool005[oool706Ko;_ooo`030000
oooooooo01Soool:06Ko1?ooo`03o`2Ioooooooo06Goool0067oool806Ko9_ooo`030000oooooooo
01Coool406Ko3_ooo`03o`2Ioooooooo06Goool006Woool506Ko8Oooo`80000@oooo1@1Voa;oool0
0ol0VOooooooo`1Uoooo001^oooo1@1Voacoool00`000?ooooooo`0:oooo1@1VoaOoool00ol0VOoo
ooooo`1Uoooo001coooo1@1VoaOoool00`000?ooooooo`05oooo1@1Voacoool00ol0VOooooooo`1U
oooo001hoooo1`1Voa3oool00`000?ooo`1Vo`0506Ko8Oooo`03o`2Ioooooooo06Goool007ooool@
06Ko00<00000I_ooool09_ooo`03o`2Ioooooooo06Goool008ooool200009oooo`03o`2Ioooooooo
06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo
02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool0
08ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`80000Woooo00?o09Wooooo
ool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003ooooo
ool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOoo
o`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo0P0002Ooool00ol0VOoo
ooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?oo
ooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1U
oooo0027oooo1@0000?oool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00ROooo`030000oooooooo
00?oool300009_ooo`03o`2Ioooooooo06Goool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool09_ooo`03o`2Ioooooooo06Goool008Woool00`000?ooooooo`03oooo00<0003oooooool09_oo
o`03o`2Ioooooooo06Goool008Soool200001Oooo`030000oooooooo02Koool00ol0VOooooooo`1U
oooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool200009oooo`03o`2I
oooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000
oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo
06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`80000Woooo00?o
09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0
003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Wooooo
ool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo0P0002Ooool0
0ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool0
0`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOoo
ooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool200009ooo
o`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Sooo
o`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2I
oooooooo06Goool008Ooool400001?ooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo0027
oooo00<0003oooooool01Oooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo0028oooo00<0
003oooooool01?ooo`<0000Voooo00?o09Woooooool0IOooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Qoooo`040000oooooooo00001?ooo`030000
oooooooo02Koool00ol0VOooooooo`1Uoooo0028oooo0P0000Goool00`000?ooooooo`0Voooo00?o
09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo0P00
02Ooool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool0
08ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool0
0ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool2
00009oooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOoo
o`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_oo
o`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Sooo
o`80000Woooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1U
oooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0V
oooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?
oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool200009oooo`03o`2Ioooooooo
06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo
02Koool00ol0VOooooooo`1Uoooo0028oooo0P0000Goool00`000?ooooooo`0Voooo00?o09Wooooo
ool0IOooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo02Koool00ol0VOooooooo`1U
oooo0029oooo00<0003oooooool00oooo`<0000Voooo00?o09Woooooool0IOooo`00R_ooo`030000
oooooooo09?oool008Ooool010000?ooooooo`0009Goool008Soool20000U_ooo`00ooooob7oool0
0?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?oo
ooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001Oooo`030000oooooooo00;oool0
0`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo
07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002_oo
o`030000oooooooo00?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000coool0
10000?ooooooo`0000_oool01@000?ooooooooooo`00001moooo001koooo00D0003oooooooooool0
00003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool0
07coool00`000?ooooooo`0Aoooo0P0000Woool400000_ooo`030000oooooooo07coool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.64043 .30902 L
.65045 .30902 L
.65954 .30902 L
.66412 .30902 L
.66652 .30902 L
.66906 .30902 L
.67014 .30902 L
.67129 .30902 L
s
.67129 .30902 m
.67167 .61803 L
s
0 .4 1 r
.02381 .30987 m
.04262 .31005 L
.06244 .31029 L
.08426 .31062 L
.10458 .311 L
.14264 .31197 L
.16305 .31268 L
.18163 .31346 L
.20239 .31454 L
.22156 .31575 L
.25997 .31903 L
.2787 .32113 L
.29932 .32391 L
.33961 .33091 L
.37838 .33945 L
.39809 .34403 L
.41961 .34859 L
.42957 .35036 L
.4402 .35189 L
.44536 .35247 L
.45023 .35291 L
.45459 .35322 L
.45705 .35335 L
.45932 .35345 L
.46058 .35349 L
.46177 .35353 L
.46286 .35355 L
.46401 .35357 L
.46527 .35359 L
.46643 .35359 L
.46767 .35359 L
.46839 .35359 L
.46905 .35358 L
.47016 .35357 L
.47133 .35355 L
.47233 .35352 L
.47343 .35349 L
.47587 .3534 L
.47814 .35329 L
.48337 .35294 L
.48813 .35252 L
.4988 .35122 L
.50879 .34962 L
.51799 .34789 L
.53879 .34336 L
.57819 .33431 L
.61608 .32687 L
.63716 .32354 L
.65642 .32099 L
.66594 .31989 L
Mistroke
.66856 .3196 L
.66999 .31945 L
.67069 .31938 L
.67133 .31931 L
.6726 .30902 L
.67326 .30902 L
.67396 .30902 L
.67633 .30902 L
.69524 .30902 L
.73326 .30902 L
.77374 .30902 L
.8127 .30902 L
.85411 .30902 L
.89401 .30902 L
.93239 .30902 L
.97323 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`0906Ko00<00000I_l0I_l02@1Vo`03000006Ko06Ko
00T0I_l00`00001Vooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool01?oo
o`03o`2I06Kooooo00;oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`0Eoooo000^oooo00<0003oooooool02ooooa40I_lBoooo00<0003oooooool0;Oooo`030000
oooooooo02Soool00`1Vooooooooo`02oooo00<0003oooooool0;_ooo`030000oooooooo02goool0
04goool=06Ko=Oooo`030000oooooooo02?oool606KoIOooo`00F_ooo`D0I_l`oooo00<0003ooooo
ool07_ooo`D0I_l5oooo00?o09Woooooool0Hoooo`00Goooo`D0I_l[oooo00<0003oooooool06?oo
o`H0I_l:oooo00?o09Woooooool0Hoooo`00I?ooo`D0I_lVoooo0P0001Goool406Ko4?ooo`03o`2I
oooooooo06?oool006Woool506Ko8Oooo`030000oooooooo00ooool506Ko5?ooo`03o`2Ioooooooo
06?oool006koool506Ko7?ooo`030000oooooooo00[oool506Ko6Oooo`03o`2Ioooooooo06?oool0
07?oool506Ko5oooo`030000oooooooo00Goool506Ko7_ooo`03o`2Ioooooooo06?oool007Soool4
06Ko4oooo`040000oooooooooooo101Vob?oool00ol0VOooooooo`1Soooo001loooo1P1Vo`[oool3
06Ko0P000080I_lWoooo00?o09Woooooool0Hoooo`00P_ooo`X0I_l3oooo00<0003oooooool0:?oo
o`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00Sooo
o`030000oooooooo02Soool00ol0VOooooooo`1Soooo002?oooo00<0003oooooool0:?ooo`03o`2I
oooooooo06?oool008ooool20000:Oooo`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0X
oooo00?o09Woooooool0Hoooo`00Soooo`030000oooooooo02Soool00ol0VOooooooo`1Soooo002?
oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0Xoooo00?o
09Woooooool0Hoooo`00Soooo`80000Yoooo00?o09Woooooool0Hoooo`00Soooo`030000oooooooo
02Soool00ol0VOooooooo`1Soooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool0
08ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00Qoooo`D00003oooo00<0003ooooo
ool0:?ooo`03o`2Ioooooooo06?oool008Woool00`000?ooooooo`03oooo00<0003oooooool0:?oo
o`03o`2Ioooooooo06?oool008Woool00`000?ooooooo`03oooo0`0002Soool00ol0VOooooooo`1S
oooo0029oooo00<0003oooooool00oooo`030000oooooooo02Soool00ol0VOooooooo`1Soooo0029
oooo00<0003oooooool00oooo`030000oooooooo02Soool00ol0VOooooooo`1Soooo0028oooo0P00
00Goool00`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00Soooo`030000oooooooo02Soool0
0ol0VOooooooo`1Soooo002?oooo0P0002Woool00ol0VOooooooo`1Soooo002?oooo00<0003ooooo
ool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hooo
o`00Soooo`030000oooooooo02Soool00ol0VOooooooo`1Soooo002?oooo00<0003oooooool0:?oo
o`03o`2Ioooooooo06?oool008ooool20000:Oooo`03o`2Ioooooooo06?oool008ooool00`000?oo
ooooo`0Xoooo00?o09Woooooool0Hoooo`00Soooo`030000oooooooo02Soool00ol0VOooooooo`1S
oooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0X
oooo00?o09Woooooool0Hoooo`00Soooo`80000Yoooo00?o09Woooooool0Hoooo`00Soooo`030000
oooooooo02Soool00ol0VOooooooo`1Soooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo
06?oool008ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00Soooo`030000oooooooo
02Soool00ol0VOooooooo`1Soooo002?oooo0P0002Woool00ol0VOooooooo`1Soooo002?oooo00<0
003oooooool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0Xoooo00?o09Wooooo
ool0Hoooo`00Soooo`030000oooooooo02Soool00ol0VOooooooo`1Soooo0027oooo100000Coool0
0`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`0Xoooo00?o09Woooooool0Hoooo`00R?ooo`030000oooooooo00Coool30000:?ooo`03o`2I
oooooooo06?oool008Woool00`000?ooooooo`03oooo00<0003oooooool0:?ooo`03o`2Ioooooooo
06?oool008Ooool010000?ooooooo`0000Coool00`000?ooooooo`0Xoooo00?o09Woooooool0Hooo
o`00R?ooo`800005oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?oo
ooooo`0Xoooo00?o09Woooooool0Hoooo`00Soooo`80000Yoooo00?o09Woooooool0Hoooo`00Sooo
o`030000oooooooo02Soool00ol0VOooooooo`1Soooo002?oooo00<0003oooooool0:?ooo`03o`2I
oooooooo06?oool008ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00Soooo`030000
oooooooo02Soool00ol0VOooooooo`1Soooo002?oooo0P0002Woool00ol0VOooooooo`1Soooo002?
oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0Xoooo00?o
09Woooooool0Hoooo`00Soooo`030000oooooooo02Soool00ol0VOooooooo`1Soooo002?oooo00<0
003oooooool0:?ooo`03o`2Ioooooooo06?oool008ooool20000:Oooo`03o`2Ioooooooo06?oool0
08ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00Soooo`030000oooooooo02Soool0
0ol0VOooooooo`1Soooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool008ooool0
0`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00Soooo`030000oooooooo02Soool00ol0VOoo
ooooo`1Soooo002?oooo0P0002Woool00ol0VOooooooo`1Soooo002?oooo00<0003oooooool0:?oo
o`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00R?oo
o`800005oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool008Ooool010000?ooooooo`00
00Coool00`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00ROooo`030000oooooooo00?oool3
0000:?ooo`03o`2Ioooooooo06?oool008[oool00`000?ooooooo`2Coooo0027oooo00@0003ooooo
ool0002Eoooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo
02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool0
0`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004oooo0P0000Coool200001?ooo`030000oooooooo07_oool007_oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000
oooooooo00goool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1j
oooo001koooo00<0003oooooool01@0000coool010000?ooooooo`0000Woool200001?ooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_oo
o`800003oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.64043 .30902 L
.65954 .30902 L
.66906 .30902 L
.67373 .30902 L
.67803 .30902 L
.67928 .30902 L
.68044 .30902 L
s
.68044 .30902 m
.68081 .61803 L
s
0 .4 1 r
.02381 .31 m
.04262 .31021 L
.06244 .31049 L
.08426 .31087 L
.10458 .31131 L
.14264 .31243 L
.16305 .31325 L
.18163 .31415 L
.20239 .3154 L
.22156 .3168 L
.25997 .32059 L
.2787 .32302 L
.29932 .32623 L
.33961 .33432 L
.37838 .34419 L
.39809 .34948 L
.41961 .35476 L
.42957 .35681 L
.4402 .35857 L
.44536 .35924 L
.45023 .35975 L
.45459 .36011 L
.45705 .36026 L
.45932 .36037 L
.46058 .36042 L
.46177 .36046 L
.46286 .36049 L
.46401 .36052 L
.46527 .36053 L
.46643 .36054 L
.46767 .36054 L
.46839 .36054 L
.46905 .36053 L
.47016 .36051 L
.47133 .36049 L
.47233 .36046 L
.47343 .36042 L
.47587 .36032 L
.47814 .36019 L
.48337 .35979 L
.48813 .3593 L
.4988 .35779 L
.50879 .35595 L
.51799 .35395 L
.53879 .34872 L
.57819 .33825 L
.61608 .32965 L
.63716 .32581 L
.65642 .32286 L
.66594 .32158 L
Mistroke
.67098 .32095 L
.67374 .32062 L
.67633 .32032 L
.67881 .32003 L
.67949 .31996 L
.6802 .31988 L
.68148 .30902 L
.68263 .30902 L
.68371 .30902 L
.68614 .30902 L
.69524 .30902 L
.7342 .30902 L
.77561 .30902 L
.81551 .30902 L
.85389 .30902 L
.89473 .30902 L
.93405 .30902 L
.97185 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`0906Ko00<00000I_l0I_l02@1Vo`03000006Ko06Ko
00T0I_l00`00001Vooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool01ooo
o`0306Kooooo000000_oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo01Goool002koool0
0`000?ooooooo`0;oooo4@1Voa;oool00`000?ooooooo`0]oooo00<0003oooooool0:oooo`0306Ko
oooo0000033oool00`000?ooooooo`0]oooo001=oooo201Voc[oool00`000?ooooooo`0Xoooo101V
of;oool005Goool506Ko=Oooo`030000oooooooo02?oool506Ko0oooo`03o`2Ioooooooo063oool0
05[oool506Ko<?ooo`030000oooooooo01koool506Ko2?ooo`03o`2Ioooooooo063oool005ooool5
06Ko:oooo`80000Ioooo1P1Vo`goool00ol0VOooooooo`1Poooo001Toooo1@1VobKoool00`000?oo
ooooo`0Doooo101Voa?oool00ol0VOooooooo`1Poooo001Yoooo1@1Vob7oool00`000?ooooooo`0?
oooo1@1VoaOoool00ol0VOooooooo`1Poooo001^oooo101Voagoool00`000?ooooooo`0:oooo1@1V
oacoool00ol0VOooooooo`1Poooo001boooo0P1Voa_oool00`000?ooooooo`06oooo101Vob7oool0
0ol0VOooooooo`1Poooo001doooo101VoaOoool200001Oooo`80I_lUoooo00?o09Woooooool0H?oo
o`00N?ooo`@0I_lCoooo00<0003oool0I_l0101VobOoool00ol0VOooooooo`1Poooo001loooo4`1V
o`03000006Kooooo02_oool00ol0VOooooooo`1Poooo002?oooo00<0003oooooool0:oooo`03o`2I
oooooooo063oool008ooool00`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00Soooo`80000/
oooo00?o09Woooooool0H?ooo`00Soooo`030000oooooooo02_oool00ol0VOooooooo`1Poooo002?
oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool008ooool00`000?ooooooo`0[oooo00?o
09Woooooool0H?ooo`00Soooo`030000oooooooo02_oool00ol0VOooooooo`1Poooo002?oooo0P00
02coool00ol0VOooooooo`1Poooo002?oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool0
08ooool00`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00Soooo`030000oooooooo02_oool0
0ol0VOooooooo`1Poooo0027oooo1@0000?oool00`000?ooooooo`0[oooo00?o09Woooooool0H?oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00ROoo
o`030000oooooooo00?oool30000:oooo`03o`2Ioooooooo063oool008Woool00`000?ooooooo`03
oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool008Woool00`000?ooooooo`03oooo00<0
003oooooool0:oooo`03o`2Ioooooooo063oool008Soool200001Oooo`030000oooooooo02_oool0
0ol0VOooooooo`1Poooo002?oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool008ooool2
0000;?ooo`03o`2Ioooooooo063oool008ooool00`000?ooooooo`0[oooo00?o09Woooooool0H?oo
o`00Soooo`030000oooooooo02_oool00ol0VOooooooo`1Poooo002?oooo00<0003oooooool0:ooo
o`03o`2Ioooooooo063oool008ooool00`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00Sooo
o`80000/oooo00?o09Woooooool0H?ooo`00Soooo`030000oooooooo02_oool00ol0VOooooooo`1P
oooo002?oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool008ooool00`000?ooooooo`0[
oooo00?o09Woooooool0H?ooo`00Soooo`030000oooooooo02_oool00ol0VOooooooo`1Poooo002?
oooo0P0002coool00ol0VOooooooo`1Poooo002?oooo00<0003oooooool0:oooo`03o`2Ioooooooo
063oool008ooool00`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00Soooo`030000oooooooo
02_oool00ol0VOooooooo`1Poooo002?oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool0
08ooool20000;?ooo`03o`2Ioooooooo063oool008ooool00`000?ooooooo`0[oooo00?o09Wooooo
ool0H?ooo`00Soooo`030000oooooooo02_oool00ol0VOooooooo`1Poooo002?oooo00<0003ooooo
ool0:oooo`03o`2Ioooooooo063oool008Ooool400001?ooo`030000oooooooo02_oool00ol0VOoo
ooooo`1Poooo0027oooo00<0003oooooool01Oooo`030000oooooooo02_oool00ol0VOooooooo`1P
oooo0028oooo00<0003oooooool01?ooo`<0000[oooo00?o09Woooooool0H?ooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00Qoooo`040000oooooooo
00001?ooo`030000oooooooo02_oool00ol0VOooooooo`1Poooo0028oooo0P0000Goool00`000?oo
ooooo`0[oooo00?o09Woooooool0H?ooo`00Soooo`030000oooooooo02_oool00ol0VOooooooo`1P
oooo002?oooo0P0002coool00ol0VOooooooo`1Poooo002?oooo00<0003oooooool0:oooo`03o`2I
oooooooo063oool008ooool00`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00Soooo`030000
oooooooo02_oool00ol0VOooooooo`1Poooo002?oooo00<0003oooooool0:oooo`03o`2Ioooooooo
063oool008ooool20000;?ooo`03o`2Ioooooooo063oool008ooool00`000?ooooooo`0[oooo00?o
09Woooooool0H?ooo`00Soooo`030000oooooooo02_oool00ol0VOooooooo`1Poooo002?oooo00<0
003oooooool0:oooo`03o`2Ioooooooo063oool008ooool00`000?ooooooo`0[oooo00?o09Wooooo
ool0H?ooo`00Soooo`80000/oooo00?o09Woooooool0H?ooo`00Soooo`030000oooooooo02_oool0
0ol0VOooooooo`1Poooo002?oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool008ooool0
0`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00Soooo`030000oooooooo02_oool00ol0VOoo
ooooo`1Poooo002?oooo00<0003oooooool0:oooo`03o`2Ioooooooo063oool008ooool20000;?oo
o`03o`2Ioooooooo063oool008ooool00`000?ooooooo`0[oooo00?o09Woooooool0H?ooo`00Sooo
o`030000oooooooo02_oool00ol0VOooooooo`1Poooo0028oooo0P0000Goool00`000?ooooooo`0[
oooo00?o09Woooooool0H?ooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo02_oool0
0ol0VOooooooo`1Poooo0029oooo00<0003oooooool00oooo`<0000[oooo00?o09Woooooool0H?oo
o`00R_ooo`030000oooooooo09?oool008Ooool010000?ooooooo`0009Goool008Soool20000U_oo
o`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool0
07_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`<00004
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?oo
ooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`00
00Woool300001?ooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003?ooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`<00002oooo00<0003oooooool0O?oo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.64043 .30902 L
.65954 .30902 L
.67803 .30902 L
.68335 .30902 L
.68596 .30902 L
.68711 .30902 L
.68837 .30902 L
.6895 .30902 L
s
.6895 .30902 m
.68981 .61803 L
s
0 .4 1 r
.02381 .31014 m
.04262 .31039 L
.06244 .3107 L
.08426 .31114 L
.10458 .31164 L
.14264 .31293 L
.16305 .31386 L
.18163 .3149 L
.20239 .31632 L
.22156 .31793 L
.25997 .32227 L
.2787 .32505 L
.29932 .32872 L
.33961 .33799 L
.37838 .34928 L
.39809 .35534 L
.41961 .36139 L
.42957 .36373 L
.4402 .36574 L
.44536 .36651 L
.45023 .3671 L
.45459 .36751 L
.45705 .36768 L
.45932 .36781 L
.46058 .36787 L
.46177 .36792 L
.46286 .36795 L
.46401 .36798 L
.46527 .36799 L
.46643 .368 L
.46767 .368 L
.46839 .368 L
.46905 .36799 L
.47016 .36797 L
.47133 .36794 L
.47233 .36791 L
.47343 .36787 L
.47587 .36775 L
.47814 .3676 L
.48337 .36714 L
.48813 .36658 L
.4988 .36486 L
.50879 .36275 L
.51799 .36045 L
.53879 .35447 L
.57819 .34248 L
.61608 .33264 L
.63716 .32824 L
.65642 .32486 L
.66594 .3234 L
Mistroke
.67633 .32195 L
.68108 .32134 L
.68369 .32101 L
.68614 .32071 L
.68844 .32044 L
.68973 .32029 L
.69092 .30902 L
.69192 .30902 L
.69302 .30902 L
.69524 .30902 L
.73572 .30902 L
.77468 .30902 L
.81609 .30902 L
.85599 .30902 L
.89437 .30902 L
.9352 .30902 L
.97452 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`0906Ko00<00000I_l0I_l02@1Vo`03000006Ko06Ko
00H0I_l3oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000^
oooo00<0003oooooool01_ooo`l0I_lIoooo00<0003oooooool0;Oooo`030000oooooooo02goool0
0`000?ooooooo`0^oooo00<0003oooooool0;Oooo`00A_ooo`L0I_m2oooo00<0003oooooool0;?oo
o`80I_mPoooo001=oooo3@1VocGoool00`000?ooooooo`0Soooo2@1Vo`03ooooo`2Ioooo05ooool0
05[oool406Ko<Oooo`030000oooooooo01koool506Ko2_ooo`03o`2Ioooooooo05koool005koool3
06Ko;_ooo`80000Joooo1@1Vo`ooool00ol0VOooooooo`1Noooo001Qoooo101Vob[oool00`000?oo
ooooo`0Foooo0`1VoaCoool00ol0VOooooooo`1Noooo001Uoooo0`1VobOoool00`000?ooooooo`0C
oooo0`1VoaOoool00ol0VOooooooo`1Noooo001Xoooo0`1VobCoool00`000?ooooooo`0@oooo0`1V
oa[oool00ol0VOooooooo`1Noooo001[oooo101Vob3oool00`000?ooooooo`0=oooo0`1Voagoool0
0ol0VOooooooo`1Noooo001_oooo101Voacoool200002_ooo`@0I_lPoooo00?o09Woooooool0G_oo
o`00Loooo`@0I_lHoooo00<0003oooooool01Oooo`@0I_lToooo00?o09Woooooool0G_ooo`00Mooo
o`<0I_lEoooo00@0003oooooooooool406Ko:?ooo`03o`2Ioooooooo05koool007[oool506Ko4?oo
o`040000oooo06Ko06Ko;?ooo`03o`2Ioooooooo05koool007ooool@06Ko00<00000I_ooool0;Ooo
o`03o`2Ioooooooo05koool008ooool20000;_ooo`03o`2Ioooooooo05koool008ooool00`000?oo
ooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1N
oooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]
oooo00?o09Woooooool0G_ooo`00Soooo`80000^oooo00?o09Woooooool0G_ooo`00Soooo`030000
oooooooo02goool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo
05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Qoooo`D00003oooo00<0
003oooooool0;Oooo`03o`2Ioooooooo05koool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0;Oooo`03o`2Ioooooooo05koool008Woool00`000?ooooooo`03oooo0`0002goool00ol0VOoo
ooooo`1Noooo0029oooo00<0003oooooool00oooo`030000oooooooo02goool00ol0VOooooooo`1N
oooo0029oooo00<0003oooooool00oooo`030000oooooooo02goool00ol0VOooooooo`1Noooo0028
oooo0P0000Goool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo
02goool00ol0VOooooooo`1Noooo002?oooo0P0002koool00ol0VOooooooo`1Noooo002?oooo00<0
003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Wooooo
ool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo00<0003ooooo
ool0;Oooo`03o`2Ioooooooo05koool008ooool20000;_ooo`03o`2Ioooooooo05koool008ooool0
0`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOoo
ooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?oo
ooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`80000^oooo00?o09Woooooool0G_ooo`00Sooo
o`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2I
oooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000
oooooooo02goool00ol0VOooooooo`1Noooo002?oooo0P0002koool00ol0VOooooooo`1Noooo002?
oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o
09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo0027oooo1000
00Coool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Qoooo`030000oooooooo00Goool0
0`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00R?ooo`030000oooooooo00Coool30000;Ooo
o`03o`2Ioooooooo05koool008Woool00`000?ooooooo`03oooo00<0003oooooool0;Oooo`03o`2I
oooooooo05koool008Ooool010000?ooooooo`0000Coool00`000?ooooooo`0]oooo00?o09Wooooo
ool0G_ooo`00R?ooo`800005oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool0
0`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`80000^oooo00?o09Woooooool0G_oo
o`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Ooo
o`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Sooo
o`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo0P0002koool00ol0VOooooooo`1N
oooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]
oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?
oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool20000;_ooo`03o`2Ioooooooo
05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo
02goool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool0
08ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool0
0ol0VOooooooo`1Noooo002?oooo0P0002koool00ol0VOooooooo`1Noooo002?oooo00<0003ooooo
ool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_oo
o`00R?ooo`800005oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008Ooool010000?oo
ooooo`0000Coool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00ROooo`030000oooooooo
00?oool30000;Oooo`03o`2Ioooooooo05koool008[oool00`000?ooooooo`2Coooo0027oooo00@0
003oooooool0002Eoooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Oooo`00Ooooo`030000
oooooooo01coool00`000?ooooooo`1ooooo001noooo00<0003oooooool02?ooo`030000oooooooo
01?oool00`000?ooooooo`1noooo001noooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01_ooo`D00002oooo0P0000Coool00`000?ooooooo`1noooo001noooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool02?ooo`030000
oooooooo07koool007goool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo
00Woool00`000?ooooooo`1moooo001noooo00<0003oooooool01@0000koool00`000?ooooooo`08
oooo00<0003oooooool0O_ooo`00O_ooo`050000oooooooooooo0000017oool00`000?ooooooo`08
oooo00<0003oooooool0O_ooo`00Ooooo`030000oooooooo017oool200002Oooo`030000oooooooo
07ooool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.67958 .30902 L
.6883 .30902 L
.69289 .30902 L
.6954 .30902 L
.69774 .30902 L
.69895 .30902 L
s
.69895 .30902 m
.69934 .61803 L
s
0 .4 1 r
.02381 .31029 m
.04262 .31057 L
.06244 .31093 L
.08426 .31143 L
.10458 .312 L
.14264 .31346 L
.16305 .31452 L
.18163 .3157 L
.20239 .31732 L
.22156 .31915 L
.25997 .32407 L
.2787 .32723 L
.29932 .33141 L
.33961 .34194 L
.37838 .35478 L
.39809 .36167 L
.41961 .36854 L
.42957 .3712 L
.4402 .37349 L
.44536 .37436 L
.45023 .37503 L
.45459 .37549 L
.45705 .37569 L
.45932 .37584 L
.46058 .37591 L
.46177 .37596 L
.46286 .37599 L
.46401 .37602 L
.46527 .37605 L
.46643 .37606 L
.46767 .37606 L
.46839 .37605 L
.46905 .37604 L
.47016 .37602 L
.47133 .37599 L
.47233 .37595 L
.47343 .3759 L
.47587 .37577 L
.47814 .3756 L
.48337 .37508 L
.48813 .37444 L
.4988 .37248 L
.50879 .37008 L
.51799 .36748 L
.53879 .36067 L
.57819 .34705 L
.61608 .33587 L
.63716 .33086 L
.65642 .32703 L
.67656 .32369 L
Mistroke
.68636 .32228 L
.69524 .32112 L
.69752 .32084 L
.69872 .32069 L
.69999 .32054 L
.7011 .30902 L
.70232 .30902 L
.70445 .30902 L
.71426 .30902 L
.735 .30902 L
.77548 .30902 L
.81444 .30902 L
.85585 .30902 L
.89575 .30902 L
.93413 .30902 L
.97496 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`0906Ko00<00000I_l0I_l02@1Vo`03000006Kooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`040000ooooo`2I06Ko2?ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003ooooo
ool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool05Oooo`00;_oo
o`030000oooo06Ko0100I_lNoooo00<0003oooooool0;Oooo`030000oooooooo02goool010000?oo
ool0V@1Vobgoool00`000?ooooooo`0]oooo0011oooo301Vod;oool00`000?ooooooo`0^oooo0`1V
oegoool004goool806Ko>_ooo`030000oooooooo02Soool606Ko00?ooooo09Woool0GOooo`00EOoo
o`D0I_leoooo00<0003oooooool08oooo`D0I_l7oooo00?o09Woooooool0G?ooo`00F_ooo`@0I_la
oooo0P0001ooool506Ko3?ooo`03o`2Ioooooooo05coool005koool306Ko;_ooo`030000oooooooo
01Woool506Ko4Oooo`03o`2Ioooooooo05coool0067oool406Ko:_ooo`030000oooooooo01Koool3
06Ko5_ooo`03o`2Ioooooooo05coool006Goool306Ko9oooo`030000oooooooo01?oool306Ko6Ooo
o`03o`2Ioooooooo05coool006Soool306Ko9?ooo`030000oooooooo013oool306Ko7?ooo`03o`2I
oooooooo05coool006_oool406Ko8?ooo`80000?oooo0P1Voaooool00ol0VOooooooo`1Loooo001_
oooo0`1Voagoool00`000?ooooooo`0;oooo0`1Vob7oool00ol0VOooooooo`1Loooo001boooo0P1V
oa_oool00`000?ooooooo`09oooo0P1VobCoool00ol0VOooooooo`1Loooo001doooo0`1VoaSoool0
0`000?ooooooo`05oooo101VobKoool00ol0VOooooooo`1Loooo001goooo0`1VoaGoool010000?oo
ooooooooo`@0I_lZoooo00?o09Woooooool0G?ooo`00N_ooo`D0I_l@oooo0P000080I_l^oooo00?o
09Woooooool0G?ooo`00Oooooa00I_l00`00001Vooooo`0_oooo00?o09Woooooool0G?ooo`00Sooo
o`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2I
oooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Soooo`80000`
oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?
oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o
09Woooooool0G?ooo`00Qoooo`D00003oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool0
08Woool00`000?ooooooo`03oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008Woool0
0`000?ooooooo`03oooo0`0002ooool00ol0VOooooooo`1Loooo0029oooo00<0003oooooool00ooo
o`030000oooooooo02ooool00ol0VOooooooo`1Loooo0029oooo00<0003oooooool00oooo`030000
oooooooo02ooool00ol0VOooooooo`1Loooo0028oooo0P0000Goool00`000?ooooooo`0_oooo00?o
09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo0P00
033oool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool0
08ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool0
0ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool2
0000<?ooo`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?oo
o`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0<?oo
o`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Sooo
o`80000aoooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1K
oooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`
oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?
oooo0P00037oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo
05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo
033oool00ol0VOooooooo`1Koooo0027oooo100000Coool00`000?ooooooo`0`oooo00?o09Wooooo
ool0Foooo`00Qoooo`030000oooooooo00Goool00`000?ooooooo`0`oooo00?o09Woooooool0Fooo
o`00R?ooo`030000oooooooo00Coool30000<?ooo`03o`2Ioooooooo05_oool008Woool00`000?oo
ooooo`03oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008Ooool010000?ooooooo`00
00Coool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00R?ooo`800005oooo00<0003ooooo
ool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Fooo
o`00Soooo`80000aoooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOoo
ooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?oo
ooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1K
oooo002?oooo0P00037oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2I
oooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`030000
oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo
05_oool008ooool20000<Oooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o
09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0
003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Wooooo
ool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo0P00037oool0
0ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool0
0`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00R?ooo`800005oooo00<0003oooooool0<?oo
o`03o`2Ioooooooo05_oool008Ooool010000?ooooooo`0000Coool00`000?ooooooo`0`oooo00?o
09Woooooool0Foooo`00ROooo`030000oooooooo00?oool30000<?ooo`03o`2Ioooooooo05_oool0
08[oool00`000?ooooooo`2Coooo0027oooo00@0003oooooool0002Eoooo0028oooo0P0009Koool0
0?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001k
oooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000?oool500000_oo
o`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Ooool00`000?ooooooo`09oooo00<0003oooooool00_ooo`030000oooooooo
07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Woool0
0`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0
003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001koooo00D0003ooooo
ooooool000004Oooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0Nooo
o`00O?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0003oooooool0O?ooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.67958 .30902 L
.69774 .30902 L
.7026 .30902 L
.70516 .30902 L
.70656 .30902 L
.70787 .30902 L
.70901 .30902 L
s
.70901 .30902 m
.70938 .61803 L
s
0 .4 1 r
.02381 .31046 m
.04262 .31078 L
.06244 .31118 L
.08426 .31174 L
.10458 .31239 L
.14264 .31404 L
.16305 .31524 L
.18163 .31657 L
.20239 .3184 L
.22156 .32047 L
.25997 .32603 L
.2787 .3296 L
.29932 .33432 L
.33961 .34623 L
.37838 .36073 L
.39809 .36852 L
.41961 .37628 L
.42957 .37929 L
.4402 .38188 L
.44536 .38287 L
.45023 .38362 L
.45459 .38414 L
.45705 .38437 L
.45932 .38454 L
.46058 .38461 L
.46177 .38467 L
.46286 .38471 L
.46401 .38474 L
.46527 .38477 L
.46643 .38478 L
.46767 .38478 L
.46839 .38477 L
.46905 .38476 L
.47016 .38474 L
.47133 .3847 L
.47233 .38466 L
.47343 .38461 L
.47587 .38445 L
.47814 .38427 L
.48337 .38367 L
.48813 .38295 L
.4988 .38074 L
.50879 .37803 L
.51799 .37508 L
.53879 .36739 L
.57819 .352 L
.61608 .33936 L
.63716 .33371 L
.65642 .32937 L
.67656 .3256 L
Mistroke
.69524 .3227 L
.69999 .32204 L
.70445 .32145 L
.70693 .32114 L
.70761 .32105 L
.70832 .32096 L
.7096 .30902 L
.71075 .30902 L
.71183 .30902 L
.71426 .30902 L
.735 .30902 L
.77396 .30902 L
.81537 .30902 L
.85527 .30902 L
.89365 .30902 L
.93449 .30902 L
.97381 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`0906Ko00<00000I_l0I_l02@1Vo`03000006Kooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00;oool00`1Vooooooooo`04oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`0Eoooo000^oooo00<0003oool0I_l0401Voakoool00`000?ooooooo`0]oooo00<0003ooooo
ool0;Oooo`030000oooooooo00;oool00`1Vooooooooo`0Yoooo00<0003oooooool0;Oooo`00@Ooo
o`X0I_m4oooo00<0003oooooool0<Oooo`80I_mKoooo001;oooo1@1Vocooool00`000?ooooooo`0]
oooo1@1Vo`03o`2Ioooooooo05Woool0053oool506Ko>_ooo`030000oooooooo02Soool506Ko1Ooo
o`03o`2Ioooooooo05Woool005Goool506Ko=Oooo`80000Toooo1@1Vo`[oool00ol0VOooooooo`1I
oooo001Joooo101Voc7oool00`000?ooooooo`0Noooo1@1Vo`ooool00ol0VOooooooo`1Ioooo001N
oooo0`1Vobkoool00`000?ooooooo`0Ioooo1@1VoaCoool00ol0VOooooooo`1Ioooo001Qoooo101V
ob[oool00`000?ooooooo`0Foooo0`1VoaWoool00ol0VOooooooo`1Ioooo001Uoooo0`1VobOoool0
0`000?ooooooo`0Coooo0`1Voacoool00ol0VOooooooo`1Ioooo001Xoooo0P1VobGoool200004Ooo
o`<0I_lOoooo00?o09Woooooool0FOooo`00J_ooo`<0I_lRoooo00<0003oooooool03_ooo`80I_lR
oooo00?o09Woooooool0FOooo`00KOooo`80I_lPoooo00<0003oooooool02oooo`<0I_lToooo00?o
09Woooooool0FOooo`00Koooo`<0I_lMoooo00<0003oooooool02Oooo`80I_lWoooo00?o09Wooooo
ool0FOooo`00L_ooo`80I_lKoooo00<0003oooooool01_ooo`<0I_lYoooo00?o09Woooooool0FOoo
o`00M?ooo`@0I_lGoooo0P0000Goool206Ko;?ooo`03o`2Ioooooooo05Woool007Soool406Ko4ooo
o`040000oooooooooooo0`1Vobkoool00ol0VOooooooo`1Ioooo001loooo0`1Voa3oool010000?oo
o`1Vo`1Voc7oool00ol0VOooooooo`1Ioooo001ooooo1@1Vo`Goool606Ko00<00000I_ooool0<_oo
o`03o`2Ioooooooo05Woool008Coool606Ko1Oooo`030000oooooooo03;oool00ol0VOooooooo`1I
oooo002?oooo0P0003?oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2I
oooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000
oooooooo03;oool00ol0VOooooooo`1Ioooo0027oooo1@0000?oool00`000?ooooooo`0boooo00?o
09Woooooool0FOooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0boooo00?o09Wooooo
ool0FOooo`00ROooo`030000oooooooo00?oool30000<_ooo`03o`2Ioooooooo05Woool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008Woool00`000?oo
ooooo`03oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008Soool200001Oooo`030000
oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo
05Woool008ooool20000<oooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o
09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0
003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Wooooo
ool0FOooo`00Soooo`80000coooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool0
0ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool0
0`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOoo
ooooo`1Ioooo002?oooo0P0003?oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_oo
o`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Sooo
o`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2I
oooooooo05Woool008ooool20000<oooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0b
oooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?
oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008Ooool400001?ooo`030000oooooooo
03;oool00ol0VOooooooo`1Ioooo0027oooo00<0003oooooool01Oooo`030000oooooooo03;oool0
0ol0VOooooooo`1Ioooo0028oooo00<0003oooooool01?ooo`<0000boooo00?o09Woooooool0FOoo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Qooo
o`040000oooooooo00001?ooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo0028oooo0P00
00Goool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool0
0ol0VOooooooo`1Ioooo002?oooo0P0003?oool00ol0VOooooooo`1Ioooo002?oooo00<0003ooooo
ool0<_ooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOoo
o`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_oo
o`03o`2Ioooooooo05Woool008ooool20000<oooo`03o`2Ioooooooo05Woool008ooool00`000?oo
ooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1I
oooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0b
oooo00?o09Woooooool0FOooo`00Soooo`80000coooo00?o09Woooooool0FOooo`00Soooo`030000
oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo
05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo
03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool0
08ooool20000<oooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Wooooo
ool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo0028oooo0P0000Goool0
0`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Qoooo`040000oooooooo00001?ooo`030000
oooooooo03;oool00ol0VOooooooo`1Ioooo0029oooo00<0003oooooool00oooo`<0000boooo00?o
09Woooooool0FOooo`00R_ooo`030000oooooooo09?oool008Ooool010000?ooooooo`0009Goool0
08Soool20000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000
oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo
07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool2
00000oooo`@00003oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Ooool00`000?ooooooo`04
oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0
003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`1joooo001koooo00<0003ooooo
ool01@0000koool00`000?ooooooo`09oooo00<0003oooooool00_ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`00000Aoooo00<0003oooooool01oooo`040000oooooooo00000ooo
o`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000
oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.70787 .30902 L
.71284 .30902 L
.71502 .30902 L
.71741 .30902 L
.71805 .30902 L
.71874 .30902 L
s
.71874 .30902 m
.71911 .61803 L
s
0 .4 1 r
.02381 .31064 m
.04262 .311 L
.06244 .31145 L
.08426 .31208 L
.10458 .31281 L
.14264 .31467 L
.16305 .31602 L
.18163 .31752 L
.20239 .31957 L
.22156 .3219 L
.25997 .32816 L
.2787 .33218 L
.29932 .33749 L
.33961 .35089 L
.37838 .36721 L
.39809 .37597 L
.41961 .3847 L
.42957 .38808 L
.4402 .391 L
.44536 .39211 L
.45023 .39296 L
.45459 .39355 L
.45705 .3938 L
.45932 .39399 L
.46058 .39407 L
.46177 .39414 L
.46286 .39418 L
.46401 .39422 L
.46527 .39425 L
.46643 .39426 L
.46767 .39426 L
.46839 .39426 L
.46905 .39424 L
.47016 .39422 L
.47133 .39418 L
.47233 .39413 L
.47343 .39407 L
.47587 .3939 L
.47814 .39368 L
.48337 .39302 L
.48813 .39221 L
.4988 .38972 L
.50879 .38667 L
.51799 .38335 L
.53879 .3747 L
.57819 .35738 L
.61608 .34316 L
.63716 .3368 L
.65642 .33192 L
.69524 .32441 L
Mistroke
.70445 .32301 L
.70951 .3223 L
.71426 .32166 L
.71698 .32131 L
.71772 .32121 L
.71851 .32111 L
.71918 .30902 L
.71991 .30902 L
.72502 .30902 L
.735 .30902 L
.77548 .30902 L
.81444 .30902 L
.85585 .30902 L
.89575 .30902 L
.93413 .30902 L
.97496 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`0906Ko00<00000I_l0I_l02@1Vo`03000006Kooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Coool00ol0V@1Vooooo`02oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`0Eoooo000^oooo00<0003oool0I_l02`1Vob?oool00`000?ooooooo`0]oooo00<0003ooooo
ool0;Oooo`030000oooooooo00Coool00`1Vooooooooo`0Woooo00<0003oooooool0;Oooo`00??oo
o`X0I_m9oooo00<0003oooooool0=?ooo`0306Kooooooooo05Ooool004Koool706Ko@_ooo`030000
oooooooo02coool906KoFOooo`00COooo`P0I_ljoooo00<0003oooooool0:?ooo`@0I_l8oooo00?o
09Woooooool0Eoooo`00EOooo`@0I_lfoooo0P0002Coool506Ko3?ooo`03o`2Ioooooooo05Ooool0
05Woool206Ko=?ooo`030000oooooooo01ooool406Ko4Oooo`03o`2Ioooooooo05Ooool005_oool3
06Ko<Oooo`030000oooooooo01coool306Ko5Oooo`03o`2Ioooooooo05Ooool005koool306Ko;_oo
o`030000oooooooo01Woool306Ko6?ooo`03o`2Ioooooooo05Ooool0067oool406Ko:_ooo`030000
oooooooo01Ooool206Ko6oooo`03o`2Ioooooooo05Ooool006Goool306Ko9oooo`80000Foooo0P1V
oagoool00ol0VOooooooo`1Goooo001Xoooo0P1VobGoool00`000?ooooooo`0Coooo0P1Voaooool0
0ol0VOooooooo`1Goooo001Zoooo0`1Vob;oool00`000?ooooooo`0@oooo0`1Vob7oool00ol0VOoo
ooooo`1Goooo001]oooo0P1Vob3oool00`000?ooooooo`0>oooo0P1VobCoool00ol0VOooooooo`1G
oooo001_oooo0`1Voagoool00`000?ooooooo`0;oooo0`1VobKoool00ol0VOooooooo`1Goooo001b
oooo0P1Voa_oool200002_ooo`80I_lYoooo00?o09Woooooool0Eoooo`00M?ooo`80I_lIoooo00<0
003oooooool01_ooo`<0I_l[oooo00?o09Woooooool0Eoooo`00M_ooo`80I_lGoooo00<0003ooooo
ool01?ooo`80I_l^oooo00?o09Woooooool0Eoooo`00N?ooo`80I_lEoooo00@0003oooooooooool3
06Ko<?ooo`03o`2Ioooooooo05Ooool007[oool506Ko4?ooo`040000oooo06Ko06Ko<oooo`03o`2I
oooooooo05Ooool007ooool306Ko3?ooo`0306Ko0000000003Goool00ol0VOooooooo`1Goooo0022
oooo301Vo`03oooo0000oooo03Goool00ol0VOooooooo`1Goooo002?oooo00<0003oooooool0=?oo
o`03o`2Ioooooooo05Ooool008ooool00`000?ooooooo`0doooo00?o09Woooooool0Eoooo`00Qooo
o`D00003oooo00<0003oooooool0=?ooo`03o`2Ioooooooo05Ooool008Woool00`000?ooooooo`03
oooo00<0003oooooool0=?ooo`03o`2Ioooooooo05Ooool008Woool00`000?ooooooo`03oooo0`00
03Coool00ol0VOooooooo`1Goooo0029oooo00<0003oooooool00oooo`030000oooooooo03Coool0
0ol0VOooooooo`1Goooo0029oooo00<0003oooooool00oooo`030000oooooooo03Coool00ol0VOoo
ooooo`1Goooo0028oooo0P0000Goool00`000?ooooooo`0doooo00?o09Woooooool0Eoooo`00Sooo
o`030000oooooooo03Coool00ol0VOooooooo`1Goooo002?oooo0P0003Goool00ol0VOooooooo`1G
oooo002?oooo00<0003oooooool0=?ooo`03o`2Ioooooooo05Ooool008ooool00`000?ooooooo`0d
oooo00?o09Woooooool0Eoooo`00Soooo`030000oooooooo03Coool00ol0VOooooooo`1Goooo002?
oooo00<0003oooooool0=?ooo`03o`2Ioooooooo05Ooool008ooool20000=Oooo`03o`2Ioooooooo
05Ooool008ooool00`000?ooooooo`0doooo00?o09Woooooool0Eoooo`00Soooo`030000oooooooo
03Coool00ol0VOooooooo`1Goooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool0
08ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000foooo00?o09Wooooo
ool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003ooooo
ool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_oo
o`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo0P0003Koool00ol0VOoo
ooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?oo
ooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1F
oooo0027oooo100000Coool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Qoooo`030000
oooooooo00Goool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00R?ooo`030000oooooooo
00Coool30000=Oooo`03o`2Ioooooooo05Koool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0=Oooo`03o`2Ioooooooo05Koool008Ooool010000?ooooooo`0000Coool00`000?ooooooo`0e
oooo00?o09Woooooool0E_ooo`00R?ooo`800005oooo00<0003oooooool0=Oooo`03o`2Ioooooooo
05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000foooo00?o
09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0
003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Wooooo
ool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo0P0003Koool0
0ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool0
0`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOoo
ooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool20000=_oo
o`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Sooo
o`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2I
oooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`030000
oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo0P0003Koool00ol0VOooooooo`1Foooo002?
oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o
09Woooooool0E_ooo`00R?ooo`800005oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool0
08Ooool010000?ooooooo`0000Coool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00ROoo
o`030000oooooooo00?oool30000=Oooo`03o`2Ioooooooo05Koool008[oool00`000?ooooooo`2C
oooo0027oooo00@0003oooooool0002Eoooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Ooo
o`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?oo
o`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool01_ooo`D00002oooo0P0000Coool200001?ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000
oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool02Oooo`030000oooooooo00?oool0
0`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool00`000?ooooooo`0:oooo00D0
003oooooooooool00000OOooo`00Noooo`050000oooooooooooo0000017oool00`000?ooooooo`07
oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool2
00002_ooo`800003oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71741 .30902 L
.72307 .30902 L
.72585 .30902 L
.72707 .30902 L
.72772 .30902 L
.72841 .30902 L
s
.72841 .30902 m
.72877 .61803 L
s
0 .4 1 r
.02381 .31084 m
.04262 .31124 L
.06244 .31175 L
.08426 .31245 L
.10458 .31327 L
.14264 .31535 L
.16305 .31686 L
.18163 .31855 L
.20239 .32085 L
.22156 .32346 L
.25997 .33049 L
.2787 .33499 L
.29932 .34094 L
.33961 .35596 L
.37838 .37426 L
.39809 .38408 L
.41961 .39388 L
.42957 .39767 L
.4402 .40094 L
.44536 .40219 L
.45023 .40314 L
.45459 .4038 L
.45705 .40408 L
.45932 .40429 L
.46058 .40438 L
.46177 .40446 L
.46286 .40451 L
.46401 .40455 L
.46527 .40458 L
.46643 .4046 L
.46767 .4046 L
.46839 .40459 L
.46905 .40458 L
.47016 .40455 L
.47133 .4045 L
.47233 .40445 L
.47343 .40438 L
.47587 .40419 L
.47814 .40395 L
.48337 .4032 L
.48813 .40229 L
.4988 .39951 L
.50879 .39608 L
.51799 .39236 L
.53879 .38267 L
.57819 .36324 L
.61608 .3473 L
.63716 .34017 L
.65642 .3347 L
.69524 .32628 L
Mistroke
.71426 .32319 L
.71948 .32244 L
.72233 .32205 L
.72502 .32169 L
.72625 .32153 L
.72754 .32136 L
.72822 .32127 L
.72896 .30902 L
.73026 .30902 L
.735 .30902 L
.77548 .30902 L
.81444 .30902 L
.85585 .30902 L
.89575 .30902 L
.93413 .30902 L
.97496 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`0906Ko00<00000I_l0I_l02@1Vo`03000006Kooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Ooool00`1Vooooo`00000;oooo00<0003oooooool02Oooo`030000oooooooo
00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo01Goool002koool0
0`000?ooo`1Vo`0;06Ko8oooo`030000oooooooo02goool00`000?ooooooo`0]oooo00<0003ooooo
ool01oooo`0306Kooooooooo02Coool00`000?ooooooo`0]oooo000loooo2P1VodWoool00`000?oo
ooooo`0goooo00<0I_ooooooool0E?ooo`00A_ooo`D0I_m4oooo00<0003oooooool0<Oooo`L0I_mF
oooo001;oooo1@1Vocooool00`000?ooooooo`0/oooo1@1Vo`Koool00ol0VOooooooo`1Doooo001@
oooo1@1Voc[oool20000:Oooo`@0I_l;oooo00?o09Woooooool0E?ooo`00EOooo`@0I_lfoooo00<0
003oooooool08oooo`D0I_l?oooo00?o09Woooooool0E?ooo`00FOooo`80I_ldoooo00<0003ooooo
ool07oooo`@0I_lDoooo00?o09Woooooool0E?ooo`00Foooo`<0I_laoooo00<0003oooooool07?oo
o`<0I_lHoooo00?o09Woooooool0E?ooo`00G_ooo`<0I_l^oooo00<0003oooooool06Oooo`<0I_lK
oooo00?o09Woooooool0E?ooo`00HOooo`@0I_lZoooo0P0001Soool206Ko7_ooo`03o`2Ioooooooo
05Coool006Goool206Ko:?ooo`030000oooooooo01Goool206Ko8?ooo`03o`2Ioooooooo05Coool0
06Ooool206Ko9_ooo`030000oooooooo01?oool206Ko8_ooo`03o`2Ioooooooo05Coool006Woool2
06Ko9?ooo`030000oooooooo017oool206Ko9?ooo`03o`2Ioooooooo05Coool006_oool206Ko8_oo
o`030000oooooooo00ooool206Ko9_ooo`03o`2Ioooooooo05Coool006goool206Ko8?ooo`80000>
oooo0P1VobSoool00ol0VOooooooo`1Doooo001_oooo0`1Voagoool00`000?ooooooo`0;oooo0P1V
ob[oool00ol0VOooooooo`1Doooo001boooo0P1Voa_oool00`000?ooooooo`09oooo0P1Vobcoool0
0ol0VOooooooo`1Doooo001doooo0P1VoaWoool00`000?ooooooo`07oooo0P1Vobkoool00ol0VOoo
ooooo`1Doooo001foooo0P1VoaOoool00`000?ooooooo`05oooo0P1Voc3oool00ol0VOooooooo`1D
oooo001hoooo0P1VoaGoool200001?ooo`80I_lboooo00?o09Woooooool0E?ooo`00N_ooo`80I_lC
oooo00<0003oool0I_l00`1VocCoool00ol0VOooooooo`1Doooo001loooo0`1Vo`ooool00`1Vo`00
001Vo`0hoooo00?o09Woooooool0E?ooo`00Ooooo`D0I_l5oooo1@1Vo`03oooo0000oooo03Soool0
0ol0VOooooooo`1Doooo0024oooo0`1Vo`D00003oooo00<0003oooooool0=oooo`03o`2Ioooooooo
05Coool008Woool00`000?ooooooo`03oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool0
08Woool00`000?ooooooo`03oooo0`0003Ooool00ol0VOooooooo`1Doooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo0029oooo00<0003oooooool00ooo
o`030000oooooooo03Ooool00ol0VOooooooo`1Doooo0028oooo0P0000Goool00`000?ooooooo`0g
oooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?
oooo0P0003Soool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo
05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo
03Ooool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool0
08ooool20000>?ooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Wooooo
ool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo00<0003ooooo
ool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?oo
o`00Soooo`80000hoooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOoo
ooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?oo
ooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1D
oooo002?oooo0P0003Soool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2I
oooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`030000
oooooooo03Ooool00ol0VOooooooo`1Doooo0027oooo100000Coool00`000?ooooooo`0goooo00?o
09Woooooool0E?ooo`00Qoooo`030000oooooooo00Goool00`000?ooooooo`0goooo00?o09Wooooo
ool0E?ooo`00R?ooo`030000oooooooo00Coool30000=oooo`03o`2Ioooooooo05Coool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008Ooool010000?oo
ooooo`0000Coool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00R?ooo`800005oooo00<0
003oooooool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Wooooo
ool0E?ooo`00Soooo`80000hoooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool0
0ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008ooool0
0`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOoo
ooooo`1Doooo002?oooo0P0003Soool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=ooo
o`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Sooo
o`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2I
oooooooo05Coool008ooool20000>?ooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0g
oooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?
oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o
09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo0P00
03Soool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool0
08ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00R?ooo`800005oooo00<0003ooooo
ool0=oooo`03o`2Ioooooooo05Coool008Ooool010000?ooooooo`0000Coool00`000?ooooooo`0g
oooo00?o09Woooooool0E?ooo`00ROooo`030000oooooooo00?oool30000=oooo`03o`2Ioooooooo
05Coool008[oool00`000?ooooooo`2Coooo0027oooo00@0003oooooool0002Eoooo0028oooo0P00
09Koool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1l
oooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001k
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000Goool3
00000_ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Ooool00`000?ooooooo`0:oooo00D0003oooooooooool00000OOoo
o`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`D00003
oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0003oooooool01ooo
o`040000oooooooo00000oooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000A
oooo00<0003oooooool02?ooo`030000oooo000000?oool00`000?ooooooo`1koooo001loooo00<0
003oooooool04Oooo`80000;oooo0P0000;oool00`000?ooooooo`1loooo003ooooo8Oooo`00oooo
ob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71741 .30902 L
.72307 .30902 L
.72841 .30902 L
.7332 .30902 L
.73451 .30902 L
.7359 .30902 L
.73708 .30902 L
s
.73708 .30902 m
.73747 .61803 L
s
0 .4 1 r
.02381 .31105 m
.04262 .3115 L
.06244 .31207 L
.08426 .31286 L
.10458 .31377 L
.14264 .3161 L
.16305 .31779 L
.18163 .31967 L
.20239 .32225 L
.22156 .32517 L
.25997 .33302 L
.2787 .33806 L
.29932 .34472 L
.33961 .36151 L
.37838 .38197 L
.39809 .39295 L
.41961 .4039 L
.42957 .40814 L
.4402 .4118 L
.44536 .41319 L
.45023 .41426 L
.45459 .41499 L
.45705 .41531 L
.45932 .41555 L
.46058 .41565 L
.46177 .41573 L
.46286 .41579 L
.46401 .41584 L
.46527 .41587 L
.46643 .41589 L
.46767 .41589 L
.46839 .41588 L
.46905 .41587 L
.47016 .41583 L
.47133 .41578 L
.47233 .41572 L
.47343 .41565 L
.47587 .41543 L
.47814 .41516 L
.48337 .41433 L
.48813 .41331 L
.4988 .4102 L
.50879 .40637 L
.51799 .40221 L
.53879 .39137 L
.57819 .36965 L
.61608 .35182 L
.63716 .34385 L
.65642 .33773 L
.69524 .32831 L
Mistroke
.71426 .32486 L
.72515 .32317 L
.73028 .32243 L
.735 .32179 L
.73623 .32162 L
.73738 .32148 L
.73857 .30902 L
.73988 .30902 L
.74516 .30902 L
.75471 .30902 L
.7757 .30902 L
.81466 .30902 L
.85607 .30902 L
.89597 .30902 L
.93435 .30902 L
.97519 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`0906Ko00<00000I_l0I_l0101Vo`Goool00`000?oo
ooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000Y
oooo1@1Vo`03000006Ko06Ko00H0I_lXoooo00<0003oooooool0;Oooo`030000oooooooo02goool0
0`000?ooooooo`09oooo00<0I_ooooooool08_ooo`030000oooooooo02goool003Ooool:06KoC_oo
o`030000oooooooo03Woool00`1Vooooooooo`1Boooo0011oooo1@1VodWoool00`000?ooooooo`0a
oooo2@1VoeCoool004Koool706Ko@_ooo`030000oooooooo02goool406Ko2?ooo`03o`2Ioooooooo
05;oool004goool706Ko>oooo`80000[oooo0`1Vo`coool00ol0VOooooooo`1Boooo001Doooo0P1V
ocWoool00`000?ooooooo`0Woooo0`1Vo`ooool00ol0VOooooooo`1Boooo001Foooo101VocGoool0
0`000?ooooooo`0Soooo101Voa;oool00ol0VOooooooo`1Boooo001Joooo0`1Voc;oool00`000?oo
ooooo`0Ooooo101VoaKoool00ol0VOooooooo`1Boooo001Moooo0P1Voc3oool00`000?ooooooo`0L
oooo0`1Voa[oool00ol0VOooooooo`1Boooo001Ooooo0P1Vobkoool200006oooo`80I_lMoooo00?o
09Woooooool0D_ooo`00HOooo`80I_l/oooo00<0003oooooool06?ooo`80I_lOoooo00?o09Wooooo
ool0D_ooo`00Hoooo`80I_lZoooo00<0003oooooool05_ooo`80I_lQoooo00?o09Woooooool0D_oo
o`00IOooo`80I_lXoooo00<0003oooooool05?ooo`80I_lSoooo00?o09Woooooool0D_ooo`00Iooo
o`80I_lVoooo00<0003oooooool04_ooo`80I_lUoooo00?o09Woooooool0D_ooo`00JOooo`80I_lT
oooo0P0001;oool00`1Vooooooooo`0Uoooo00?o09Woooooool0D_ooo`00Joooo`80I_lRoooo00<0
003oooooool03oooo`80I_lXoooo00?o09Woooooool0D_ooo`00KOooo`80I_lPoooo00<0003ooooo
ool03Oooo`80I_lZoooo00?o09Woooooool0D_ooo`00Koooo`80I_lNoooo00<0003oooooool02ooo
o`80I_l/oooo00?o09Woooooool0D_ooo`00LOooo`80I_lLoooo00<0003oooooool02Oooo`80I_l^
oooo00?o09Woooooool0D_ooo`00Loooo`80I_lJoooo0P0000Soool206Ko<?ooo`03o`2Ioooooooo
05;oool007Goool206Ko6?ooo`030000oooooooo00Goool206Ko<_ooo`03o`2Ioooooooo05;oool0
07Ooool306Ko5Oooo`030000oooooooo00?oool206Ko=?ooo`03o`2Ioooooooo05;oool007[oool2
06Ko4oooo`040000oooooooooooo0P1VocKoool00ol0VOooooooo`1Boooo001loooo00<0I_oooooo
ool02?ooo`D00003oooo00@0003oool0I_l0I_lhoooo00?o09Woooooool0D_ooo`00OOooo`@0I_l8
oooo00<0003oooooool00_ooo`0306Ko000006Ko03[oool00ol0VOooooooo`1Boooo0021oooo201V
o`03000006Ko06Ko0080I_l01?ooo`000000000003Woool00ol0VOooooooo`1Boooo0026oooo0P1V
o`03oooo0000oooo00Coool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00R?ooo`800005oooo00<0
003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Wooooo
ool0D_ooo`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool0
0ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool0
0`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOoo
ooooo`1Boooo002?oooo0P0003[oool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Ooo
o`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Sooo
o`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2I
oooooooo05;oool008ooool20000>_ooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0i
oooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?
oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o
09Woooooool0D_ooo`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo
03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool0
08ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Qoooo`@00004oooo00<0003ooooo
ool0>Oooo`03o`2Ioooooooo05;oool008Ooool00`000?ooooooo`05oooo00<0003oooooool0>Ooo
o`03o`2Ioooooooo05;oool008Soool00`000?ooooooo`04oooo0`0003Woool00ol0VOooooooo`1B
oooo0029oooo00<0003oooooool00oooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo0027
oooo00@0003oooooool00004oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008Soool2
00001Oooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Ooo
o`03o`2Ioooooooo05;oool008ooool20000>_ooo`03o`2Ioooooooo05;oool008ooool00`000?oo
ooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1B
oooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0i
oooo00?o09Woooooool0D_ooo`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000
oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo
05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo
03Woool00ol0VOooooooo`1Boooo002?oooo0P0003[oool00ol0VOooooooo`1Boooo002?oooo00<0
003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Wooooo
ool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003ooooo
ool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_oo
o`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOoo
ooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008Soool200001Ooo
o`030000oooooooo03Woool00ol0VOooooooo`1Boooo0027oooo00@0003oooooool00004oooo00<0
003oooooool0>Oooo`03o`2Ioooooooo05;oool008Woool00`000?ooooooo`03oooo0`0003Woool0
0ol0VOooooooo`1Boooo002:oooo00<0003oooooool0Toooo`00Qoooo`040000oooooooo0000UOoo
o`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0
003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003ooooo
ool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_oo
o`800004oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`040000oooooooo
00000oooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03ooo
o`030000oooooooo00[oool00`000?ooooooo`02oooo00<0003oooooool0N_ooo`00Noooo`030000
oooooooo00D0000>oooo00<0003oooooool02?ooo`800004oooo00<0003oooooool0Noooo`00Nooo
o`050000oooooooooooo0000017oool00`000?ooooooo`08oooo00<0003oooooool00oooo`030000
oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool300000_ooo`030000oooooooo
07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71905 .30902 L
.72912 .30902 L
.73838 .30902 L
.74309 .30902 L
.74546 .30902 L
.74611 .30902 L
.7468 .30902 L
s
.7468 .30902 m
.74718 .61803 L
s
0 .4 1 r
.02381 .31129 m
.04262 .31179 L
.06244 .31243 L
.08426 .3133 L
.10458 .31432 L
.14264 .31692 L
.16305 .31881 L
.18163 .3209 L
.20239 .32378 L
.22156 .32704 L
.25997 .3358 L
.2787 .34142 L
.29932 .34885 L
.33961 .36758 L
.37838 .39041 L
.39809 .40266 L
.41961 .41488 L
.42957 .41961 L
.4402 .42369 L
.44536 .42524 L
.45023 .42643 L
.45459 .42725 L
.45705 .42761 L
.45932 .42787 L
.46058 .42798 L
.46177 .42808 L
.46286 .42814 L
.46401 .4282 L
.46527 .42823 L
.46643 .42825 L
.46767 .42825 L
.46839 .42824 L
.46905 .42823 L
.47016 .42819 L
.47133 .42813 L
.47233 .42807 L
.47343 .42798 L
.47587 .42774 L
.47814 .42744 L
.48337 .42651 L
.48813 .42538 L
.4988 .4219 L
.50879 .41763 L
.51799 .41299 L
.53879 .40089 L
.57819 .37666 L
.61608 .35677 L
.63716 .34787 L
.65642 .34105 L
.69524 .33055 L
Mistroke
.71426 .3267 L
.72515 .3248 L
.735 .32326 L
.73988 .32256 L
.74245 .3222 L
.74516 .32183 L
.7463 .32168 L
.74753 .32152 L
.74824 .30902 L
.74888 .30902 L
.75014 .30902 L
.75471 .30902 L
.7757 .30902 L
.8156 .30902 L
.85398 .30902 L
.89481 .30902 L
.93413 .30902 L
.97193 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`0906Ko00<00000I_l0I_l0101Vo`Goool00`000?oo
ooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00@0003oooooool0I_l8oooo00<0003oooooool02Oooo`030000
oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo01Goool0
02Woool506Ko00<00000I_l0I_l01P1VobSoool00`000?ooooooo`0]oooo00<0003oooooool0;Ooo
o`030000oooooooo00coool00`1Vooooooooo`0Ooooo00<0003oooooool0;Oooo`00=oooo`X0I_m>
oooo00<0003oooooool0??ooo`0306Kooooooooo04ooool0047oool506KoBOooo`030000oooooooo
03Goool806KoDOooo`00A_ooo`D0I_m4oooo00<0003oooooool0<Oooo`@0I_l7oooo00?o09Wooooo
ool0Coooo`00Boooo`D0I_looooo0P0002koool406Ko2oooo`03o`2Ioooooooo04ooool0053oool4
06Ko>oooo`030000oooooooo02[oool306Ko3oooo`03o`2Ioooooooo04ooool005Coool206Ko>Ooo
o`030000oooooooo02Ooool306Ko4_ooo`03o`2Ioooooooo04ooool005Koool306Ko=_ooo`030000
oooooooo02?oool406Ko5Oooo`03o`2Ioooooooo04ooool005Woool206Ko=?ooo`030000oooooooo
023oool306Ko6Oooo`03o`2Ioooooooo04ooool005_oool306Ko<Oooo`80000Ooooo0P1Voacoool0
0ol0VOooooooo`1?oooo001Noooo0P1Vobooool00`000?ooooooo`0Loooo0P1Voakoool00ol0VOoo
ooooo`1?oooo001Poooo0`1Vobcoool00`000?ooooooo`0Joooo0P1Vob3oool00ol0VOooooooo`1?
oooo001Soooo0P1Vob[oool00`000?ooooooo`0Hoooo0P1Vob;oool00ol0VOooooooo`1?oooo001U
oooo0P1VobSoool00`000?ooooooo`0Foooo0P1VobCoool00ol0VOooooooo`1?oooo001Woooo0P1V
obKoool200005Oooo`80I_lVoooo00?o09Woooooool0Coooo`00JOooo`80I_lToooo00<0003ooooo
ool04_ooo`80I_lXoooo00?o09Woooooool0Coooo`00Joooo`0306Kooooooooo027oool00`000?oo
ooooo`0Aoooo00<0I_ooooooool0:?ooo`03o`2Ioooooooo04ooool006coool206Ko8Oooo`030000
oooooooo00ooool206Ko:oooo`03o`2Ioooooooo04ooool006koool206Ko7oooo`030000oooooooo
00goool206Ko;Oooo`03o`2Ioooooooo04ooool0073oool00`1Vooooooooo`0Loooo0P0000goool0
0`1Vooooooooo`0]oooo00?o09Woooooool0Coooo`00LOooo`80I_lLoooo00<0003oooooool02_oo
o`80I_l`oooo00?o09Woooooool0Coooo`00Loooo`80I_lJoooo00<0003oooooool02?ooo`80I_lb
oooo00?o09Woooooool0Coooo`00MOooo`0306Kooooooooo01Ooool00`000?ooooooo`07oooo00<0
I_ooooooool0<_ooo`03o`2Ioooooooo04ooool007Koool206Ko3oooo`D00003oooo00<0003ooooo
ool01Oooo`80I_leoooo00?o09Woooooool0Coooo`00N?ooo`80I_l?oooo00<0003oooooool00ooo
o`030000oooooooo00?oool206Ko=oooo`03o`2Ioooooooo04ooool007[oool206Ko3Oooo`030000
oooooooo00?oool3000000?oool0I_l0I_l0>Oooo`03o`2Ioooooooo04ooool007coool306Ko2_oo
o`030000oooooooo00?oool010000?ooo`1Vo`1Voc_oool00ol0VOooooooo`1?oooo001ooooo0P1V
o`Soool00`000?ooooooo`02oooo00<0I_l00000I_l0?Oooo`03o`2Ioooooooo04ooool0087oool4
06Ko0oooo`80000406Ko00?oool0003oool0?Oooo`03o`2Ioooooooo04ooool008Goool506Ko1Ooo
o`030000oooooooo03coool00ol0VOooooooo`1?oooo002?oooo0P0003goool00ol0VOooooooo`1?
oooo002?oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?ooooooo`0l
oooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?oooo002?
oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool20000?Oooo`03o`2Ioooooooo
04ooool008ooool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo
03coool00ol0VOooooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool0
08ooool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Soooo`80000moooo00?o09Wooooo
ool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?oooo002?oooo00<0003ooooo
ool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?ooooooo`0loooo00?o09Woooooool0Cooo
o`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?oooo002?oooo0P0003goool00ol0VOoo
ooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?oo
ooooo`0loooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?
oooo0027oooo100000Coool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Qoooo`030000
oooooooo00Goool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00R?ooo`030000oooooooo
00Coool30000??ooo`03o`2Ioooooooo04ooool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0??ooo`03o`2Ioooooooo04ooool008Ooool010000?ooooooo`0000Coool00`000?ooooooo`0l
oooo00?o09Woooooool0Coooo`00R?ooo`800005oooo00<0003oooooool0??ooo`03o`2Ioooooooo
04ooool008ooool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Soooo`80000moooo00?o
09Woooooool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?oooo002?oooo00<0
003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?ooooooo`0loooo00?o09Wooooo
ool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?oooo002?oooo0P0003goool0
0ol0VOooooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool0
0`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo03coool00ol0VOoo
ooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool20000?Ooo
o`03o`2Ioooooooo04ooool008ooool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Sooo
o`030000oooooooo03coool00ol0VOooooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2I
oooooooo04ooool008ooool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Soooo`030000
oooooooo03coool00ol0VOooooooo`1?oooo002?oooo0P0003goool00ol0VOooooooo`1?oooo002?
oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?ooooooo`0loooo00?o
09Woooooool0Coooo`00R?ooo`800005oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool0
08Ooool010000?ooooooo`0000Coool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00ROoo
o`030000oooooooo00?oool30000??ooo`03o`2Ioooooooo04ooool008[oool00`000?ooooooo`2C
oooo0027oooo00@0003oooooool0002Eoooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Ooo
o`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?oo
o`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool01_ooo`D00002oooo0P0000?oool300001?ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool0
0`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000
oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`040000oooooooo00001?oo
o`030000oooooooo07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo00Ooool3
00001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000Aoooo00<0003ooooo
ool02?ooo`030000oooooooo00?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Ooo
o`80000:oooo0`0000;oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71905 .30902 L
.73838 .30902 L
.74806 .30902 L
.75071 .30902 L
.75351 .30902 L
.75467 .30902 L
.75591 .30902 L
.75662 .30902 L
s
.75662 .30902 m
.75681 .61803 L
s
0 .4 1 r
.02381 .31155 m
.04262 .3121 L
.06244 .31281 L
.08426 .31379 L
.10458 .31492 L
.14264 .31782 L
.16305 .31992 L
.18163 .32226 L
.20239 .32546 L
.22156 .32908 L
.25997 .33884 L
.2787 .3451 L
.29932 .35337 L
.33961 .37424 L
.37838 .39966 L
.39809 .41331 L
.41961 .42691 L
.42957 .43218 L
.4402 .43672 L
.44536 .43846 L
.45023 .43978 L
.45459 .44069 L
.45705 .44109 L
.45932 .44138 L
.46058 .44151 L
.46177 .44161 L
.46286 .44169 L
.46401 .44175 L
.46527 .44179 L
.46643 .44181 L
.46767 .44181 L
.46839 .4418 L
.46905 .44178 L
.47016 .44174 L
.47133 .44167 L
.47233 .4416 L
.47343 .44151 L
.47587 .44124 L
.47814 .44091 L
.48337 .43987 L
.48813 .4386 L
.4988 .43473 L
.50879 .42998 L
.51799 .42481 L
.53879 .41134 L
.57819 .38436 L
.61608 .3622 L
.63716 .35229 L
.65642 .34469 L
.69524 .33299 L
Mistroke
.71426 .32871 L
.735 .32488 L
.74516 .32329 L
.75014 .32257 L
.75232 .32226 L
.75471 .32193 L
.75536 .32185 L
.75605 .32175 L
.75729 .30902 L
.75802 .30902 L
.75871 .30902 L
.76001 .30902 L
.76573 .30902 L
.7757 .30902 L
.81408 .30902 L
.85491 .30902 L
.89423 .30902 L
.93204 .30902 L
.97229 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`0906Ko00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`02oooo00<0I_ooooooool01?ooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`0Eoooo000Soooo2`1Vo`03000006Kooooo02koool00`000?ooooooo`0]oooo00<0003ooooo
ool0;Oooo`030000oooooooo00koool00`1Vooooooooo`0Moooo00<0003oooooool0;Oooo`00<?oo
o``0I_mCoooo00<0003oooooool0?_ooo`0306Kooooooooo04goool003coool506KoC_ooo`030000
oooooooo03Ooool806KoCoooo`00@Oooo`D0I_m9oooo00<0003oooooool0<Oooo`H0I_l7oooo00?o
09Woooooool0COooo`00A_ooo`D0I_m4oooo0P0002koool406Ko3Oooo`03o`2Ioooooooo04goool0
04_oool506Ko?oooo`030000oooooooo02[oool306Ko4Oooo`03o`2Ioooooooo04goool0053oool4
06Ko>oooo`030000oooooooo02Ooool306Ko5?ooo`03o`2Ioooooooo04goool005Coool206Ko>Ooo
o`030000oooooooo02Coool306Ko5oooo`03o`2Ioooooooo04goool005Koool306Ko=_ooo`030000
oooooooo02;oool206Ko6_ooo`03o`2Ioooooooo04goool005Woool206Ko=?ooo`80000Qoooo0P1V
oacoool00ol0VOooooooo`1=oooo001Koooo0P1Voc;oool00`000?ooooooo`0Noooo0P1Voakoool0
0ol0VOooooooo`1=oooo001Moooo0P1Voc3oool00`000?ooooooo`0Loooo0P1Vob3oool00ol0VOoo
ooooo`1=oooo001Ooooo0P1Vobkoool00`000?ooooooo`0Joooo0P1Vob;oool00ol0VOooooooo`1=
oooo001Qoooo0P1Vobcoool00`000?ooooooo`0Hoooo0P1VobCoool00ol0VOooooooo`1=oooo001S
oooo0P1Vob[oool200006?ooo`0306Kooooooooo02Coool00ol0VOooooooo`1=oooo001Uoooo0P1V
obSoool00`000?ooooooo`0Eoooo0P1VobOoool00ol0VOooooooo`1=oooo001Woooo0P1VobKoool0
0`000?ooooooo`0Doooo00<0I_ooooooool09oooo`03o`2Ioooooooo04goool006Woool206Ko9?oo
o`030000oooooooo01;oool206Ko:_ooo`03o`2Ioooooooo04goool006_oool00`1Vooooooooo`0Q
oooo00<0003oooooool04Oooo`0306Kooooooooo02[oool00ol0VOooooooo`1=oooo001/oooo0P1V
ob7oool200004?ooo`80I_l]oooo00?o09Woooooool0COooo`00K_ooo`80I_lOoooo00<0003ooooo
ool03Oooo`80I_l_oooo00?o09Woooooool0COooo`00L?ooo`0306Kooooooooo01coool00`000?oo
ooooo`0<oooo00<0I_ooooooool0;oooo`03o`2Ioooooooo04goool0077oool00`1Vooooooooo`0K
oooo00<0003oooooool02_ooo`80I_lboooo00?o09Woooooool0COooo`00L_ooo`80I_lCoooo1@00
00?oool00`000?ooooooo`08oooo0P1VocCoool00ol0VOooooooo`1=oooo001doooo00<0I_oooooo
ool04_ooo`030000oooooooo00?oool00`000?ooooooo`07oooo00<0I_ooooooool0=?ooo`03o`2I
oooooooo04goool007Goool00`1Vooooooooo`0Aoooo00<0003oooooool00oooo`<00006oooo00<0
I_ooooooool0=Oooo`03o`2Ioooooooo04goool007Koool206Ko4Oooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo0P1VocSoool00ol0VOooooooo`1=oooo001hoooo0P1Vo`ooool00`000?oo
ooooo`03oooo00<0003oooooool00oooo`0306Kooooooooo03Soool00ol0VOooooooo`1=oooo001j
oooo0P1Vo`coool200001Oooo`040000oooooooooooo0P1Voc_oool00ol0VOooooooo`1=oooo001l
oooo00<0I_ooooooool04?ooo`040000oooo06Ko06Ko?Oooo`03o`2Ioooooooo04goool007goool2
06Ko3oooo`0306Ko0000000003ooool00ol0VOooooooo`1=oooo001ooooo0`1Vo`[oool206Ko00?o
ool0003oool0?oooo`03o`2Ioooooooo04goool008;oool:06Ko0oooo`030000oooooooo03koool0
0ol0VOooooooo`1=oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool0
0`000?ooooooo`0noooo00?o09Woooooool0COooo`00Soooo`80000ooooo00?o09Woooooool0COoo
o`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=oooo002?oooo00<0003oooooool0?_oo
o`03o`2Ioooooooo04goool008ooool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00Sooo
o`030000oooooooo03koool00ol0VOooooooo`1=oooo002?oooo0P0003ooool00ol0VOooooooo`1=
oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool00`000?ooooooo`0n
oooo00?o09Woooooool0COooo`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=oooo002?
oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool20000?oooo`03o`2Ioooooooo
04goool008ooool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00Soooo`030000oooooooo
03koool00ol0VOooooooo`1=oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool0
08Ooool400001?ooo`030000oooooooo03koool00ol0VOooooooo`1=oooo0027oooo00<0003ooooo
ool01Oooo`030000oooooooo03koool00ol0VOooooooo`1=oooo0028oooo00<0003oooooool01?oo
o`<0000noooo00?o09Woooooool0COooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0n
oooo00?o09Woooooool0COooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo03koool0
0ol0VOooooooo`1=oooo0028oooo0P0000Goool00`000?ooooooo`0noooo00?o09Woooooool0COoo
o`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=oooo002?oooo0P0003ooool00ol0VOoo
ooooo`1=oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool00`000?oo
ooooo`0noooo00?o09Woooooool0COooo`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=
oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool20000?oooo`03o`2I
oooooooo04goool008ooool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00Soooo`030000
oooooooo03koool00ol0VOooooooo`1=oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo
04goool008ooool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00Soooo`80000ooooo00?o
09Woooooool0COooo`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=oooo002?oooo00<0
003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool00`000?ooooooo`0noooo00?o09Wooooo
ool0COooo`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=oooo002?oooo00<0003ooooo
ool0?_ooo`03o`2Ioooooooo04goool008ooool20000?oooo`03o`2Ioooooooo04goool008ooool0
0`000?ooooooo`0noooo00?o09Woooooool0COooo`00Soooo`030000oooooooo03koool00ol0VOoo
ooooo`1=oooo0028oooo0P0000Goool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00Qooo
o`040000oooooooo00001?ooo`030000oooooooo03koool00ol0VOooooooo`1=oooo0029oooo00<0
003oooooool00oooo`<0000noooo00?o09Woooooool0COooo`00R_ooo`030000oooooooo09?oool0
08Ooool010000?ooooooo`0009Goool008Soool20000U_ooo`00ooooob7oool00?oooolQoooo001l
oooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0
003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`06oooo1@0000;oool200001Oooo`030000oooooooo00;oool00`000?ooooooo`1k
oooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07
oooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001joooo00<0
003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`09oooo00<0003oooooool00ooo
o`030000oooooooo07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo00[oool0
1@000?ooooooooooo`00001moooo001koooo00D0003oooooooooool000004Oooo`030000oooooooo
00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Ooo
o`800009oooo100000;oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71905 .30902 L
.73838 .30902 L
.74806 .30902 L
.75315 .30902 L
.75853 .30902 L
.76324 .30902 L
.76453 .30902 L
.76525 .30902 L
.76592 .30902 L
s
.76592 .30902 m
.76631 .61803 L
s
0 .4 1 r
.02381 .31183 m
.04262 .31245 L
.06244 .31324 L
.08426 .31432 L
.10458 .31559 L
.14264 .31881 L
.16305 .32114 L
.18163 .32374 L
.20239 .3273 L
.22156 .33133 L
.25997 .34219 L
.2787 .34915 L
.29932 .35835 L
.33961 .38155 L
.37838 .40982 L
.39809 .425 L
.41961 .44013 L
.42957 .44599 L
.4402 .45104 L
.44536 .45297 L
.45023 .45443 L
.45459 .45545 L
.45705 .45589 L
.45932 .45622 L
.46058 .45636 L
.46177 .45647 L
.46286 .45656 L
.46401 .45662 L
.46527 .45667 L
.46643 .45669 L
.46767 .45669 L
.46839 .45668 L
.46905 .45666 L
.47016 .45661 L
.47133 .45654 L
.47233 .45646 L
.47343 .45636 L
.47587 .45606 L
.47814 .45569 L
.48337 .45454 L
.48813 .45313 L
.4988 .44882 L
.50879 .44353 L
.51799 .43779 L
.53879 .4228 L
.57819 .3928 L
.61608 .36817 L
.63716 .35714 L
.65642 .34869 L
.69524 .33568 L
Mistroke
.71426 .33091 L
.735 .32666 L
.75471 .32338 L
.76039 .32255 L
.76317 .32217 L
.76439 .322 L
.76503 .32191 L
.76573 .32182 L
.76693 .30902 L
.76806 .30902 L
.77052 .30902 L
.7757 .30902 L
.81711 .30902 L
.85701 .30902 L
.89539 .30902 L
.93623 .30902 L
.97554 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`0906Ko00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`04oooo00?o09T0I_ooool00_ooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`0Eoooo000Soooo2`1Vo`03000006Kooooo02koool00`000?ooooooo`0]oooo00<0003ooooo
ool0;Oooo`030000oooooooo013oool00`1Vooooooooo`0Koooo00<0003oooooool0;Oooo`00<?oo
o``0I_mCoooo00<0003oooooool0@?ooo`0306Kooooooooo04_oool003coool506KoC_ooo`030000
oooooooo03coool506KoCOooo`00@Oooo`D0I_m9oooo00<0003oooooool0=oooo`D0I_l4oooo00?o
09Woooooool0Boooo`00A_ooo`@0I_m5oooo0P0003;oool606Ko2Oooo`03o`2Ioooooooo04_oool0
04[oool306Ko@_ooo`030000oooooooo02goool406Ko3oooo`03o`2Ioooooooo04_oool004goool4
06Ko?_ooo`030000oooooooo02[oool306Ko4oooo`03o`2Ioooooooo04_oool0057oool306Ko>ooo
o`030000oooooooo02Ooool306Ko5_ooo`03o`2Ioooooooo04_oool005Coool206Ko>Oooo`030000
oooooooo02Goool206Ko6Oooo`03o`2Ioooooooo04_oool005Koool306Ko=_ooo`80000Toooo0P1V
oa_oool00ol0VOooooooo`1;oooo001Ioooo0P1VocCoool00`000?ooooooo`0Qoooo0P1Voagoool0
0ol0VOooooooo`1;oooo001Koooo0P1Voc;oool00`000?ooooooo`0Ooooo0P1Voaooool00ol0VOoo
ooooo`1;oooo001Moooo0P1Voc3oool00`000?ooooooo`0Loooo0`1Vob7oool00ol0VOooooooo`1;
oooo001Ooooo0P1Vobkoool00`000?ooooooo`0Joooo0P1VobCoool00ol0VOooooooo`1;oooo001Q
oooo00<0I_ooooooool0:oooo`80000Joooo00<0I_ooooooool09?ooo`03o`2Ioooooooo04_oool0
06;oool206Ko:oooo`030000oooooooo01Ooool206Ko9oooo`03o`2Ioooooooo04_oool006Coool2
06Ko:Oooo`030000oooooooo01Koool00`1Vooooooooo`0Woooo00?o09Woooooool0Boooo`00I_oo
o`0306Kooooooooo02Koool00`000?ooooooo`0Eoooo00<0I_ooooooool0:?ooo`03o`2Ioooooooo
04_oool006Ooool206Ko9_ooo`030000oooooooo01?oool206Ko:oooo`03o`2Ioooooooo04_oool0
06Woool00`1Vooooooooo`0Soooo0P0001?oool00`1Vooooooooo`0[oooo00?o09Woooooool0Booo
o`00J_ooo`0306Kooooooooo02;oool00`000?ooooooo`0Aoooo00<0I_ooooooool0;?ooo`03o`2I
oooooooo04_oool006_oool206Ko8_ooo`030000oooooooo00ooool206Ko;oooo`03o`2Ioooooooo
04_oool006goool00`1Vooooooooo`0Ooooo00<0003oooooool03_ooo`0306Kooooooooo02ooool0
0ol0VOooooooo`1;oooo001^oooo0P1VoaOoool500000oooo`030000oooooooo00goool00`1Voooo
ooooo`0`oooo00?o09Woooooool0Boooo`00L?ooo`0306Kooooooooo01Koool00`000?ooooooo`03
oooo00<0003oooooool02oooo`80I_lcoooo00?o09Woooooool0Boooo`00LOooo`0306Kooooooooo
01Goool00`000?ooooooo`03oooo0`0000[oool00`1Vooooooooo`0coooo00?o09Woooooool0Booo
o`00L_ooo`80I_lEoooo00<0003oooooool00oooo`030000oooooooo00Soool206Ko=_ooo`03o`2I
oooooooo04_oool007Coool00`1Vooooooooo`0Boooo00<0003oooooool00oooo`030000oooooooo
00Ooool00`1Vooooooooo`0foooo00?o09Woooooool0Boooo`00MOooo`0306Kooooooooo013oool2
00001Oooo`030000oooooooo00Koool00`1Vooooooooo`0goooo00?o09Woooooool0Boooo`00M_oo
o`80I_lGoooo00<0003oooooool01?ooo`80I_ljoooo00?o09Woooooool0Boooo`00N?ooo`0306Ko
oooooooo01Coool200001?ooo`0306Kooooooooo03[oool00ol0VOooooooo`1;oooo001ioooo0P1V
oaCoool00`000?ooooooo`02oooo00<0I_ooooooool0>oooo`03o`2Ioooooooo04_oool007_oool0
0`1Vooooooooo`0Aoooo00<0003oooooool00P1Vockoool00ol0VOooooooo`1;oooo001loooo0`1V
oa3oool00`000?ooo`1Vo`10oooo00?o09Woooooool0Boooo`00Ooooo`80I_l=oooo00<0I_l00000
I_l0@Oooo`03o`2Ioooooooo04_oool0087oool206Ko2?ooo`<0I_l00oooo`0000000011oooo00?o
09Woooooool0Boooo`00Poooo`P0I_l4oooo00<0003oooooool0@?ooo`03o`2Ioooooooo04_oool0
08ooool00`000?ooooooo`10oooo00?o09Woooooool0Boooo`00Soooo`030000oooooooo043oool0
0ol0VOooooooo`1;oooo002?oooo00<0003oooooool0@?ooo`03o`2Ioooooooo04_oool008ooool2
0000@Oooo`03o`2Ioooooooo04_oool008ooool00`000?ooooooo`10oooo00?o09Woooooool0Booo
o`00Soooo`030000oooooooo043oool00ol0VOooooooo`1;oooo002?oooo00<0003oooooool0@?oo
o`03o`2Ioooooooo04_oool008ooool00`000?ooooooo`10oooo00?o09Woooooool0Boooo`00Sooo
o`800011oooo00?o09Woooooool0Boooo`00Soooo`030000oooooooo043oool00ol0VOooooooo`1;
oooo002?oooo00<0003oooooool0@?ooo`03o`2Ioooooooo04_oool008ooool00`000?ooooooo`10
oooo00?o09Woooooool0Boooo`00Qoooo`@00004oooo00<0003oooooool0@?ooo`03o`2Ioooooooo
04_oool008Ooool00`000?ooooooo`05oooo00<0003oooooool0@?ooo`03o`2Ioooooooo04_oool0
08Soool00`000?ooooooo`04oooo0`00043oool00ol0VOooooooo`1;oooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo043oool00ol0VOooooooo`1;oooo0027oooo00@0003oooooool00004
oooo00<0003oooooool0@?ooo`03o`2Ioooooooo04_oool008Soool200001Oooo`030000oooooooo
043oool00ol0VOooooooo`1;oooo002?oooo00<0003oooooool0@?ooo`03o`2Ioooooooo04_oool0
08ooool20000@Oooo`03o`2Ioooooooo04_oool008ooool00`000?ooooooo`10oooo00?o09Wooooo
ool0Boooo`00Soooo`030000oooooooo043oool00ol0VOooooooo`1;oooo002?oooo00<0003ooooo
ool0@?ooo`03o`2Ioooooooo04_oool008ooool00`000?ooooooo`10oooo00?o09Woooooool0Booo
o`00Soooo`800011oooo00?o09Woooooool0Boooo`00Soooo`030000oooooooo043oool00ol0VOoo
ooooo`1;oooo002?oooo00<0003oooooool0@?ooo`03o`2Ioooooooo04_oool008ooool00`000?oo
ooooo`10oooo00?o09Woooooool0Boooo`00Soooo`030000oooooooo043oool00ol0VOooooooo`1;
oooo002?oooo0P00047oool00ol0VOooooooo`1;oooo002?oooo00<0003oooooool0@?ooo`03o`2I
oooooooo04_oool008ooool00`000?ooooooo`10oooo00?o09Woooooool0Boooo`00Soooo`030000
oooooooo043oool00ol0VOooooooo`1;oooo002?oooo00<0003oooooool0@?ooo`03o`2Ioooooooo
04_oool008ooool00`000?ooooooo`10oooo00?o09Woooooool0Boooo`00Soooo`800011oooo00?o
09Woooooool0Boooo`00Soooo`030000oooooooo043oool00ol0VOooooooo`1;oooo002?oooo00<0
003oooooool0@?ooo`03o`2Ioooooooo04_oool008Soool200001Oooo`030000oooooooo043oool0
0ol0VOooooooo`1;oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0@?ooo`03o`2I
oooooooo04_oool008Woool00`000?ooooooo`03oooo0`00043oool00ol0VOooooooo`1;oooo002:
oooo00<0003oooooool0Toooo`00Qoooo`040000oooooooo0000UOooo`00R?ooo`80002Foooo003o
oooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Nooo
o`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800004oooo0P0000Coool0
0`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo
07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Ooool0
10000?ooooooo`0000Coool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool0
0`000?ooooooo`08oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool0
00004Oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001l
oooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.71905 .30902 L
.73838 .30902 L
.74806 .30902 L
.75853 .30902 L
.76334 .30902 L
.76842 .30902 L
.77275 .30902 L
.77394 .30902 L
.77521 .30902 L
s
.77521 .30902 m
.77557 .61803 L
s
0 .4 1 r
.02381 .31214 m
.04262 .31283 L
.06244 .31371 L
.08426 .31491 L
.10458 .31631 L
.14264 .31989 L
.16305 .32248 L
.18163 .32537 L
.20239 .32933 L
.22156 .33381 L
.25997 .34586 L
.2787 .35359 L
.29932 .36381 L
.33961 .38959 L
.37838 .42099 L
.39809 .43785 L
.41961 .45466 L
.42957 .46116 L
.4402 .46677 L
.44536 .46891 L
.45023 .47055 L
.45459 .47168 L
.45705 .47217 L
.45932 .47253 L
.46058 .47269 L
.46177 .47281 L
.46286 .4729 L
.46401 .47298 L
.46527 .47303 L
.46643 .47305 L
.46767 .47305 L
.46839 .47304 L
.46905 .47302 L
.47016 .47297 L
.47133 .47289 L
.47233 .4728 L
.47343 .47268 L
.47587 .47235 L
.47814 .47194 L
.48337 .47066 L
.48813 .4691 L
.4988 .46431 L
.50879 .45844 L
.51799 .45206 L
.53879 .43541 L
.57819 .40208 L
.61608 .37472 L
.63716 .36247 L
.65642 .35309 L
.69524 .33864 L
Mistroke
.71426 .33334 L
.735 .32862 L
.75636 .3247 L
.76644 .32313 L
.77086 .32249 L
.77336 .32215 L
.77458 .32198 L
.7757 .32183 L
.77687 .30902 L
.77798 .30902 L
.78042 .30902 L
.7854 .30902 L
.79589 .30902 L
.81488 .30902 L
.85326 .30902 L
.8941 .30902 L
.93341 .30902 L
.97122 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`0506Ko1?ooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool01oooo`0306Kooooo000000_oool00`000?oo
ooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000N
oooo401Vo`03000006Kooooo02koool00`000?ooooooo`0]oooo00<0003oooooool0;Oooo`030000
oooooooo01?oool00`1Vooooooooo`0Hoooo00<0003oooooool0;Oooo`00<?ooo`L0I_mHoooo00<0
003oooooool0@oooo`0306Kooooooooo04Soool003Ooool506KoDoooo`030000oooooooo03coool8
06KoB_ooo`00??ooo`D0I_m>oooo00<0003oooooool0>?ooo`@0I_l7oooo00?o09Woooooool0B?oo
o`00@Oooo`D0I_m9oooo0P0003Koool306Ko2oooo`03o`2Ioooooooo04Soool004Koool406KoAOoo
o`030000oooooooo037oool406Ko3_ooo`03o`2Ioooooooo04Soool004[oool306Ko@_ooo`030000
oooooooo02goool406Ko4_ooo`03o`2Ioooooooo04Soool004goool406Ko?_ooo`030000oooooooo
02_oool206Ko5_ooo`03o`2Ioooooooo04Soool0057oool306Ko>oooo`030000oooooooo02Woool2
06Ko6?ooo`03o`2Ioooooooo04Soool005Coool206Ko>Oooo`80000Xoooo0P1Voa[oool00ol0VOoo
ooooo`18oooo001Foooo0`1VocKoool00`000?ooooooo`0Toooo0`1Voacoool00ol0VOooooooo`18
oooo001Ioooo0P1VocCoool00`000?ooooooo`0Roooo0P1Voaooool00ol0VOooooooo`18oooo001K
oooo0P1Voc;oool00`000?ooooooo`0Poooo0P1Vob7oool00ol0VOooooooo`18oooo001Moooo0P1V
oc3oool00`000?ooooooo`0Noooo0P1Vob?oool00ol0VOooooooo`18oooo001Ooooo00<0I_oooooo
ool0;Oooo`80000Moooo0P1VobGoool00ol0VOooooooo`18oooo001Poooo00<0I_ooooooool0;?oo
o`030000oooooooo01[oool206Ko9oooo`03o`2Ioooooooo04Soool0067oool206Ko;?ooo`030000
oooooooo01Woool00`1Vooooooooo`0Woooo00?o09Woooooool0B?ooo`00Hoooo`0306Kooooooooo
02Woool00`000?ooooooo`0Goooo0P1Vob[oool00ol0VOooooooo`18oooo001Toooo0P1VobWoool0
0`000?ooooooo`0Foooo00<0I_ooooooool0:_ooo`03o`2Ioooooooo04Soool006Koool00`1Voooo
ooooo`0Voooo0P0001Koool00`1Vooooooooo`0[oooo00?o09Woooooool0B?ooo`00Ioooo`0306Ko
oooooooo02Goool00`000?ooooooo`0Coooo0P1Vobkoool00ol0VOooooooo`18oooo001Xoooo0P1V
obGoool00`000?ooooooo`0Boooo00<0I_ooooooool0;_ooo`03o`2Ioooooooo04Soool006[oool0
0`1Vooooooooo`0Roooo00<0003oooooool04Oooo`0306Kooooooooo02ooool00ol0VOooooooo`18
oooo001[oooo00<0I_ooooooool06Oooo`D00003oooo00<0003oooooool04?ooo`0306Kooooooooo
033oool00ol0VOooooooo`18oooo001/oooo00<0I_ooooooool06_ooo`030000oooooooo00?oool0
0`000?ooooooo`0>oooo0P1Voc?oool00ol0VOooooooo`18oooo001]oooo0P1Voa[oool00`000?oo
ooooo`03oooo0`0000goool00`1Vooooooooo`0coooo00?o09Woooooool0B?ooo`00Koooo`0306Ko
oooooooo01Ooool00`000?ooooooo`03oooo00<0003oooooool03?ooo`0306Kooooooooo03Coool0
0ol0VOooooooo`18oooo001`oooo00<0I_ooooooool05_ooo`030000oooooooo00?oool00`000?oo
ooooo`0;oooo00<0I_ooooooool0=Oooo`03o`2Ioooooooo04Soool0077oool00`1Vooooooooo`0D
oooo0P0000Goool00`000?ooooooo`09oooo0P1VocSoool00ol0VOooooooo`18oooo001boooo0P1V
oa_oool00`000?ooooooo`08oooo00<0I_ooooooool0>?ooo`03o`2Ioooooooo04Soool007Coool0
0`1Vooooooooo`0Hoooo0P0000Soool00`1Vooooooooo`0ioooo00?o09Woooooool0B?ooo`00MOoo
o`0306Kooooooooo01Ooool00`000?ooooooo`06oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo
04Soool007Koool206Ko5oooo`030000oooooooo00Goool00`1Vooooooooo`0koooo00?o09Wooooo
ool0B?ooo`00N?ooo`0306Kooooooooo01Coool00`000?ooooooo`04oooo00<0I_ooooooool0??oo
o`03o`2Ioooooooo04Soool007Woool206Ko5?ooo`030000oooooooo00?oool00`1Vooooooooo`0m
oooo00?o09Woooooool0B?ooo`00Noooo`0306Kooooooooo017oool200000_ooo`80I_m0oooo00?o
09Woooooool0B?ooo`00O?ooo`0306Kooooooooo013oool010000?ooo`1Vo`1Vod;oool00ol0VOoo
ooooo`18oooo001moooo0P1Voa3oool00`00001Vooooo`13oooo00?o09Woooooool0B?ooo`00Oooo
o`80I_l=oooo00<0I_l0003oool0A?ooo`03o`2Ioooooooo04Soool0087oool206Ko2?ooo`<0I_l0
0oooo`000?ooo`14oooo00?o09Woooooool0B?ooo`00Poooo`P0I_l4oooo0P0004Coool00ol0VOoo
ooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool00`000?oo
ooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18
oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool20000A?ooo`03o`2I
oooooooo04Soool008ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`030000
oooooooo04?oool00ol0VOooooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo
04Soool008Ooool400001?ooo`030000oooooooo04?oool00ol0VOooooooo`18oooo0027oooo00<0
003oooooool01Oooo`030000oooooooo04?oool00ol0VOooooooo`18oooo0028oooo00<0003ooooo
ool01?ooo`<00013oooo00?o09Woooooool0B?ooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`13oooo00?o09Woooooool0B?ooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo
04?oool00ol0VOooooooo`18oooo0028oooo0P0000Goool00`000?ooooooo`13oooo00?o09Wooooo
ool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18oooo002?oooo0P0004Coool0
0ol0VOooooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool0
0`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOoo
ooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool20000A?oo
o`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Sooo
o`030000oooooooo04?oool00ol0VOooooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2I
oooooooo04Soool008ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`800014
oooo00?o09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18oooo002?
oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13oooo00?o
09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18oooo002?oooo00<0
003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool20000A?ooo`03o`2Ioooooooo04Soool0
08ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool0
0ol0VOooooooo`18oooo0028oooo0P0000Goool00`000?ooooooo`13oooo00?o09Woooooool0B?oo
o`00Qoooo`040000oooooooo00001?ooo`030000oooooooo04?oool00ol0VOooooooo`18oooo0029
oooo00<0003oooooool00oooo`<00013oooo00?o09Woooooool0B?ooo`00R_ooo`030000oooooooo
09?oool008Ooool010000?ooooooo`0009Goool008Soool20000U_ooo`00ooooob7oool00?oooolQ
oooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08
oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo1@0000;oool200000oooo`<00004oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01ooo
o`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00N_ooo`030000
oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool02?ooo`<00004oooo00<0003ooooo
ool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0003oooooool01oooo`040000oooooooo
00000oooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000Aoooo00<0003ooooo
ool01oooo`040000oooooooo00000oooo`030000oooooooo07_oool007coool00`000?ooooooo`0A
oooo0P0000[oool300000_ooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.75718 .30902 L
.76707 .30902 L
.77751 .30902 L
.78008 .30902 L
.78283 .30902 L
.78364 .30902 L
.78441 .30902 L
.7851 .30902 L
s
.7851 .30902 m
.78532 .61803 L
s
0 .4 1 r
.02381 .31249 m
.04262 .31324 L
.06244 .31422 L
.08426 .31556 L
.10458 .31711 L
.14264 .32108 L
.16305 .32396 L
.18163 .32717 L
.20239 .33156 L
.22156 .33653 L
.25997 .3499 L
.2787 .35848 L
.29932 .36983 L
.33961 .39843 L
.37838 .43328 L
.39809 .45199 L
.41961 .47064 L
.42957 .47786 L
.4402 .48409 L
.44536 .48646 L
.45023 .48828 L
.45459 .48953 L
.45705 .49007 L
.45932 .49047 L
.46058 .49065 L
.46177 .49079 L
.46286 .49089 L
.46401 .49097 L
.46527 .49103 L
.46643 .49106 L
.46767 .49106 L
.46839 .49104 L
.46905 .49102 L
.47016 .49096 L
.47133 .49087 L
.47233 .49078 L
.47343 .49065 L
.47587 .49027 L
.47814 .48982 L
.48337 .4884 L
.48813 .48667 L
.4988 .48136 L
.50879 .47484 L
.51799 .46776 L
.53879 .44928 L
.57819 .4123 L
.61608 .38193 L
.63716 .36834 L
.65642 .35792 L
.69524 .34189 L
Mistroke
.71426 .33601 L
.735 .33077 L
.75636 .32642 L
.7757 .32323 L
.78042 .32255 L
.783 .32219 L
.78426 .32202 L
.7854 .32186 L
.78666 .30902 L
.78735 .30902 L
.78801 .30902 L
.79087 .30902 L
.79589 .30902 L
.81488 .30902 L
.85326 .30902 L
.8941 .30902 L
.93341 .30902 L
.97122 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`0506Ko1?ooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`03000006Kooooo00Woool00`000?oo
ooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`0Eoooo000N
oooo401Vo`03000006Kooooo02koool00`000?ooooooo`0]oooo00<0003oooooool0;Oooo`030000
oooooooo01Goool00`1Vooooooooo`0Foooo00<0003oooooool0;Oooo`00<?ooo`L0I_mHoooo00<0
003oooooool0AOooo`0306Kooooooooo04Koool003Ooool506KoDoooo`030000oooooooo047oool5
06KoB?ooo`00??ooo`D0I_m>oooo00<0003oooooool0??ooo`D0I_l4oooo00?o09Woooooool0A_oo
o`00@Oooo`D0I_m9oooo0P0003Soool506Ko2Oooo`03o`2Ioooooooo04Koool004Koool406KoAOoo
o`030000oooooooo03;oool506Ko3_ooo`03o`2Ioooooooo04Koool004[oool206Ko@oooo`030000
oooooooo033oool206Ko4oooo`03o`2Ioooooooo04Koool004coool306Ko@?ooo`030000oooooooo
02goool306Ko5Oooo`03o`2Ioooooooo04Koool004ooool206Ko?_ooo`030000oooooooo02_oool2
06Ko6?ooo`03o`2Ioooooooo04Koool0057oool306Ko>oooo`80000Zoooo0P1Voa[oool00ol0VOoo
ooooo`16oooo001Doooo0P1VocWoool00`000?ooooooo`0Woooo0P1Voacoool00ol0VOooooooo`16
oooo001Foooo0P1VocOoool00`000?ooooooo`0Toooo0`1Voakoool00ol0VOooooooo`16oooo001H
oooo0P1VocGoool00`000?ooooooo`0Roooo0P1Vob7oool00ol0VOooooooo`16oooo001Joooo0P1V
oc?oool00`000?ooooooo`0Poooo0P1Vob?oool00ol0VOooooooo`16oooo001Loooo00<0I_oooooo
ool0<?ooo`80000Ooooo0P1VobGoool00ol0VOooooooo`16oooo001Moooo0P1Voc3oool00`000?oo
ooooo`0Moooo00<0I_ooooooool09Oooo`03o`2Ioooooooo04Koool005ooool00`1Vooooooooo`0]
oooo00<0003oooooool06oooo`80I_lXoooo00?o09Woooooool0A_ooo`00H?ooo`0306Kooooooooo
02coool00`000?ooooooo`0Joooo00<0I_ooooooool0:?ooo`03o`2Ioooooooo04Koool0067oool2
06Ko;?ooo`030000oooooooo01Woool00`1Vooooooooo`0Yoooo00?o09Woooooool0A_ooo`00Hooo
o`0306Kooooooooo02Woool200006Oooo`0306Kooooooooo02[oool00ol0VOooooooo`16oooo001T
oooo0P1VobWoool00`000?ooooooo`0Goooo00<0I_ooooooool0:oooo`03o`2Ioooooooo04Koool0
06Koool00`1Vooooooooo`0Voooo00<0003oooooool05Oooo`80I_l^oooo00?o09Woooooool0A_oo
o`00Ioooo`0306Kooooooooo02Goool00`000?ooooooo`0Doooo00<0I_ooooooool0;_ooo`03o`2I
oooooooo04Koool006Soool00`1Vooooooooo`0Loooo1@0000?oool00`000?ooooooo`0Coooo00<0
I_ooooooool0;oooo`03o`2Ioooooooo04Koool006Woool00`1Vooooooooo`0Moooo00<0003ooooo
ool00oooo`030000oooooooo01;oool00`1Vooooooooo`0`oooo00?o09Woooooool0A_ooo`00J_oo
o`0306Kooooooooo01coool00`000?ooooooo`03oooo0`00017oool00`1Vooooooooo`0aoooo00?o
09Woooooool0A_ooo`00Joooo`80I_lLoooo00<0003oooooool00oooo`030000oooooooo013oool0
0`1Vooooooooo`0boooo00?o09Woooooool0A_ooo`00KOooo`0306Kooooooooo01Woool00`000?oo
ooooo`03oooo00<0003oooooool03oooo`0306Kooooooooo03?oool00ol0VOooooooo`16oooo001^
oooo00<0I_ooooooool05oooo`800005oooo00<0003oooooool03_ooo`0306Kooooooooo03Coool0
0ol0VOooooooo`16oooo001_oooo00<0I_ooooooool07Oooo`030000oooooooo00goool00`1Voooo
ooooo`0eoooo00?o09Woooooool0A_ooo`00L?ooo`0306Kooooooooo01coool200003?ooo`80I_lh
oooo00?o09Woooooool0A_ooo`00LOooo`0306Kooooooooo01_oool00`000?ooooooo`0:oooo00<0
I_ooooooool0>?ooo`03o`2Ioooooooo04Koool007;oool00`1Vooooooooo`0Joooo00<0003ooooo
ool02Oooo`0306Kooooooooo03Woool00ol0VOooooooo`16oooo001coooo00<0I_ooooooool06Ooo
o`030000oooooooo00Soool00`1Vooooooooo`0joooo00?o09Woooooool0A_ooo`00M?ooo`0306Ko
oooooooo01Soool00`000?ooooooo`07oooo00<0I_ooooooool0>oooo`03o`2Ioooooooo04Koool0
07Goool00`1Vooooooooo`0Goooo0P0000Ooool00`1Vooooooooo`0loooo00?o09Woooooool0A_oo
o`00M_ooo`80I_lGoooo00<0003oooooool01Oooo`0306Kooooooooo03goool00ol0VOooooooo`16
oooo001hoooo00<0I_ooooooool05?ooo`030000oooooooo00Coool00`1Vooooooooo`0noooo00?o
09Woooooool0A_ooo`00NOooo`80I_lDoooo00<0003oooooool00oooo`0306Kooooooooo03ooool0
0ol0VOooooooo`16oooo001koooo00<0I_ooooooool04Oooo`040000oooooooooooo0P1Vod;oool0
0ol0VOooooooo`16oooo001loooo00<0I_ooooooool04?ooo`80000206KoA?ooo`03o`2Ioooooooo
04Koool007goool00`1Vooooooooo`0?oooo00<00000I_ooool0AOooo`03o`2Ioooooooo04Koool0
07koool206Ko3_ooo`0306Ko0000oooo04Koool00ol0VOooooooo`16oooo0020oooo0P1Vo`[oool2
06Ko00?oool0003oool0A_ooo`03o`2Ioooooooo04Koool008;oool406Ko0_ooo`@0I_l3oooo00<0
003oooooool0AOooo`03o`2Ioooooooo04Koool008Goool406Ko1_ooo`800016oooo00?o09Wooooo
ool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003ooooo
ool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_oo
o`00Qoooo`@00004oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008Ooool00`000?oo
ooooo`05oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008Soool00`000?ooooooo`04
oooo0`0004Goool00ol0VOooooooo`16oooo0029oooo00<0003oooooool00oooo`030000oooooooo
04Goool00ol0VOooooooo`16oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0AOoo
o`03o`2Ioooooooo04Koool008Soool200001Oooo`030000oooooooo04Goool00ol0VOooooooo`16
oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool20000A_ooo`03o`2I
oooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000
oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo
04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`800016oooo00?o
09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0
003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Wooooo
ool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo0P0004Koool0
0ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool0
0`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOoo
ooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?oo
ooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`800016oooo00?o09Woooooool0A_ooo`00Sooo
o`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2I
oooooooo04Koool008Soool200001Oooo`030000oooooooo04Goool00ol0VOooooooo`16oooo0027
oooo00@0003oooooool00004oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008Woool0
0`000?ooooooo`03oooo0`0004Goool00ol0VOooooooo`16oooo002:oooo00<0003oooooool0Tooo
o`00Qoooo`040000oooooooo0000UOooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool0
07ooool00`000?ooooooo`0Loooo00<0003oooooool0Ooooo`00O_ooo`030000oooooooo00Soool0
0`000?ooooooo`0Coooo00<0003oooooool0O_ooo`00O_ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool400000oooo`800004oooo00<0003oooooool0O_ooo`00O_ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo
00[oool00`000?ooooooo`1noooo001moooo00<0003oooooool00_ooo`030000oooooooo00koool0
0`000?ooooooo`0:oooo00<0003oooooool0OOooo`00O_ooo`030000oooooooo00D0000>oooo00<0
003oooooool02?ooo`030000oooooooo07koool007koool01@000?ooooooooooo`00000?oooo00@0
003oooooool00009oooo00<0003oooooool0O_ooo`00Ooooo`030000oooooooo017oool200002Ooo
o`030000oooooooo07ooool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.75718 .30902 L
.77751 .30902 L
.78293 .30902 L
.78866 .30902 L
.79102 .30902 L
.79355 .30902 L
.7943 .30902 L
.79501 .30902 L
s
.79501 .30902 m
.7952 .61803 L
s
0 .4 1 r
.02381 .31286 m
.04262 .3137 L
.06244 .31479 L
.08426 .31627 L
.10458 .318 L
.14264 .3224 L
.16305 .32559 L
.18163 .32914 L
.20239 .33401 L
.22156 .33952 L
.25997 .35436 L
.2787 .36387 L
.29932 .37645 L
.33961 .40817 L
.37838 .44682 L
.39809 .46756 L
.41961 .48824 L
.42957 .49625 L
.4402 .50315 L
.44536 .50579 L
.45023 .5078 L
.45459 .50919 L
.45705 .50979 L
.45932 .51023 L
.46058 .51043 L
.46177 .51058 L
.46286 .5107 L
.46401 .51079 L
.46527 .51085 L
.46643 .51088 L
.46767 .51088 L
.46839 .51087 L
.46905 .51084 L
.47016 .51078 L
.47133 .51068 L
.47233 .51057 L
.47343 .51043 L
.47587 .51001 L
.47814 .50951 L
.48337 .50794 L
.48813 .50602 L
.4988 .50013 L
.50879 .4929 L
.51799 .48504 L
.53879 .46456 L
.57819 .42355 L
.61608 .38987 L
.63716 .3748 L
.65642 .36325 L
.69524 .34547 L
Mistroke
.71426 .33895 L
.735 .33314 L
.75636 .32832 L
.7757 .32478 L
.7854 .32326 L
.78806 .32287 L
.79087 .32247 L
.79326 .32213 L
.79392 .32204 L
.79462 .32195 L
.79589 .30902 L
.79716 .30902 L
.79834 .30902 L
.801 .30902 L
.80583 .30902 L
.81488 .30902 L
.8542 .30902 L
.892 .30902 L
.93226 .30902 L
.971 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00@0003oooooool0I_l8oooo00<0003ooooo
ool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool05Oooo`006Ooo
oa00I_l5oooo00<0003oooooool0;_ooo`030000oooooooo02goool00`000?ooooooo`0]oooo00<0
003oooooool06?ooo`0306Kooooooooo01?oool00`000?ooooooo`0]oooo000Yoooo1`1Voeooool0
0`000?ooooooo`18oooo00<0I_ooooooool0@oooo`00<?ooo`L0I_mHoooo00<0003oooooool0@Ooo
o`P0I_m5oooo000goooo1@1Voe?oool00`000?ooooooo`0moooo101Vo`Ooool00ol0VOooooooo`13
oooo000loooo1@1Vodkoool20000??ooo`80I_l;oooo00?o09Woooooool0@oooo`00@Oooo`D0I_m9
oooo00<0003oooooool0=oooo`@0I_l=oooo00?o09Woooooool0@oooo`00A_ooo`@0I_m5oooo00<0
003oooooool0<_ooo`D0I_lAoooo00?o09Woooooool0@oooo`00B_ooo`80I_m3oooo00<0003ooooo
ool0<?ooo`80I_lFoooo00?o09Woooooool0@oooo`00C?ooo`<0I_m0oooo00<0003oooooool0;Ooo
o`<0I_lHoooo00?o09Woooooool0@oooo`00Coooo`80I_lnoooo0P0002coool206Ko6oooo`03o`2I
oooooooo04?oool0057oool306Ko>oooo`030000oooooooo02Woool206Ko7Oooo`03o`2Ioooooooo
04?oool005Coool206Ko>Oooo`030000oooooooo02Ooool206Ko7oooo`03o`2Ioooooooo04?oool0
05Koool206Ko=oooo`030000oooooooo02Goool206Ko8Oooo`03o`2Ioooooooo04?oool005Soool0
0`1Vooooooooo`0doooo00<0003oooooool08oooo`80I_lSoooo00?o09Woooooool0@oooo`00FOoo
o`80I_ldoooo0P0002;oool206Ko9Oooo`03o`2Ioooooooo04?oool005_oool00`1Vooooooooo`0a
oooo00<0003oooooool08?ooo`0306Kooooooooo02Goool00ol0VOooooooo`13oooo001Loooo00<0
I_ooooooool0<?ooo`030000oooooooo01koool206Ko:?ooo`03o`2Ioooooooo04?oool005goool0
0`1Vooooooooo`0_oooo00<0003oooooool07Oooo`0306Kooooooooo02Soool00ol0VOooooooo`13
oooo001Noooo0P1Vobooool00`000?ooooooo`0Koooo0P1Vob_oool00ol0VOooooooo`13oooo001P
oooo00<0I_ooooooool0;?ooo`80000Koooo00<0I_ooooooool0:oooo`03o`2Ioooooooo04?oool0
067oool00`1Vooooooooo`0[oooo00<0003oooooool06Oooo`0306Kooooooooo02coool00ol0VOoo
ooooo`13oooo001Roooo00<0I_ooooooool0:_ooo`030000oooooooo01Soool00`1Vooooooooo`0]
oooo00?o09Woooooool0@oooo`00Hoooo`80I_lZoooo00<0003oooooool05oooo`0306Kooooooooo
02koool00ol0VOooooooo`13oooo001Uoooo00<0I_ooooooool07oooo`D00003oooo00<0003ooooo
ool05Oooo`80I_laoooo00?o09Woooooool0@oooo`00I_ooo`0306Kooooooooo023oool00`000?oo
ooooo`03oooo00<0003oooooool05?ooo`0306Kooooooooo037oool00ol0VOooooooo`13oooo001W
oooo00<0I_ooooooool07oooo`030000oooooooo00?oool300004oooo`0306Kooooooooo03;oool0
0ol0VOooooooo`13oooo001Xoooo00<0I_ooooooool07_ooo`030000oooooooo00?oool00`000?oo
ooooo`0Boooo00<0I_ooooooool0<oooo`03o`2Ioooooooo04?oool006Woool00`1Vooooooooo`0M
oooo00<0003oooooool00oooo`030000oooooooo017oool00`1Vooooooooo`0doooo00?o09Wooooo
ool0@oooo`00J_ooo`0306Kooooooooo01_oool200001Oooo`030000oooooooo013oool00`1Voooo
ooooo`0eoooo00?o09Woooooool0@oooo`00Joooo`80I_lRoooo00<0003oooooool03oooo`0306Ko
oooooooo03Koool00ol0VOooooooo`13oooo001]oooo00<0I_ooooooool07oooo`80000?oooo00<0
I_ooooooool0=oooo`03o`2Ioooooooo04?oool006koool00`1Vooooooooo`0Noooo00<0003ooooo
ool03Oooo`0306Kooooooooo03Soool00ol0VOooooooo`13oooo001_oooo00<0I_ooooooool07Ooo
o`030000oooooooo00coool00`1Vooooooooo`0ioooo00?o09Woooooool0@oooo`00L?ooo`0306Ko
oooooooo01coool00`000?ooooooo`0<oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04?oool0
077oool00`1Vooooooooo`0Koooo00<0003oooooool02oooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`13oooo001boooo00<0I_ooooooool06_ooo`80000;oooo00<0I_ooooooool0>oooo`03o`2I
oooooooo04?oool007;oool00`1Vooooooooo`0Joooo00<0003oooooool02Oooo`0306Kooooooooo
03coool00ol0VOooooooo`13oooo001coooo00<0I_ooooooool06Oooo`030000oooooooo00Soool0
0`1Vooooooooo`0moooo00?o09Woooooool0@oooo`00M?ooo`0306Kooooooooo01Soool00`000?oo
ooooo`07oooo00<0I_ooooooool0?_ooo`03o`2Ioooooooo04?oool007Goool00`1Vooooooooo`0G
oooo00<0003oooooool01_ooo`0306Kooooooooo03ooool00ol0VOooooooo`13oooo001foooo00<0
I_ooooooool05_ooo`800006oooo00<0I_ooooooool0@?ooo`03o`2Ioooooooo04?oool007Ooool0
0`1Vooooooooo`0Eoooo00<0003oooooool01?ooo`0306Kooooooooo047oool00ol0VOooooooo`13
oooo001hoooo0P1VoaGoool00`000?ooooooo`03oooo00<0I_ooooooool0@_ooo`03o`2Ioooooooo
04?oool007[oool00`1Vooooooooo`0Boooo00<0003oooooool00_ooo`0306Kooooooooo04?oool0
0ol0VOooooooo`13oooo001koooo00<0I_ooooooool04Oooo`030000oooooooo0080I_m6oooo00?o
09Woooooool0@oooo`00O?ooo`0306Kooooooooo013oool2000000<0I_ooooooool0A_ooo`03o`2I
oooooooo04?oool007goool00`1Vooooooooo`0?oooo00<00000I_ooool0B?ooo`03o`2Ioooooooo
04?oool007koool206Ko3_ooo`0306Ko0000oooo04Woool00ol0VOooooooo`13oooo0020oooo0P1V
o`[oool206Ko00?oool0003oool0BOooo`03o`2Ioooooooo04?oool008;oool406Ko00?oool00000
00000P00000506Kooooooooooooo000004[oool00ol0VOooooooo`13oooo0025oooo0P1Vo`030000
06Kooooo00Goool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00R?ooo`030000oooooooo
00Coool30000B?ooo`03o`2Ioooooooo04?oool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0B?ooo`03o`2Ioooooooo04?oool008Ooool010000?ooooooo`0000Coool00`000?ooooooo`18
oooo00?o09Woooooool0@oooo`00R?ooo`800005oooo00<0003oooooool0B?ooo`03o`2Ioooooooo
04?oool008ooool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Soooo`800019oooo00?o
09Woooooool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOooooooo`13oooo002?oooo00<0
003oooooool0B?ooo`03o`2Ioooooooo04?oool008ooool00`000?ooooooo`18oooo00?o09Wooooo
ool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOooooooo`13oooo002?oooo0P0004Woool0
0ol0VOooooooo`13oooo002?oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool008ooool0
0`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOoo
ooooo`13oooo002?oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool008ooool20000BOoo
o`03o`2Ioooooooo04?oool008ooool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Sooo
o`030000oooooooo04Soool00ol0VOooooooo`13oooo002?oooo00<0003oooooool0B?ooo`03o`2I
oooooooo04?oool008ooool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Soooo`030000
oooooooo04Soool00ol0VOooooooo`13oooo002?oooo0P0004Woool00ol0VOooooooo`13oooo002?
oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool008ooool00`000?ooooooo`18oooo00?o
09Woooooool0@oooo`00R?ooo`800005oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool0
08Ooool010000?ooooooo`0000Coool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00ROoo
o`030000oooooooo00?oool30000B?ooo`03o`2Ioooooooo04?oool008[oool00`000?ooooooo`2C
oooo0027oooo00@0003oooooool0002Eoooo0028oooo0P0009Koool00?oooolQoooo003ooooo8Ooo
o`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?oo
o`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool01_ooo`@00003oooo0P0000?oool500000_ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
0`000?ooooooo`0;oooo00<0003oooooool00_ooo`030000oooooooo07_oool007[oool00`000?oo
ooooo`02oooo00<0003oooooool03_ooo`030000oooooooo00[oool00`000?ooooooo`03oooo00<0
003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0003oooooool02Oooo`030000
oooooooo00;oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000003oooo`040000
oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`1koooo001loooo00<0003ooooo
ool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.7878 .30902 L
.79321 .30902 L
.79892 .30902 L
.80134 .30902 L
.80267 .30902 L
.80393 .30902 L
.80464 .30902 L
s
.80464 .30902 m
.80488 .61803 L
s
0 .4 1 r
.02381 .31328 m
.04262 .31421 L
.06244 .31541 L
.08426 .31706 L
.10458 .31897 L
.14264 .32385 L
.16305 .32738 L
.18163 .33132 L
.20239 .33671 L
.22156 .34283 L
.25997 .35926 L
.2787 .36981 L
.29932 .38375 L
.33961 .4189 L
.37838 .46173 L
.39809 .48471 L
.41961 .50764 L
.42957 .51651 L
.4402 .52416 L
.44536 .52708 L
.45023 .52931 L
.45459 .53085 L
.45705 .53152 L
.45932 .53201 L
.46058 .53223 L
.46177 .5324 L
.46286 .53252 L
.46401 .53262 L
.46527 .5327 L
.46643 .53273 L
.46767 .53273 L
.46839 .53271 L
.46905 .53268 L
.47016 .53261 L
.47133 .5325 L
.47233 .53238 L
.47343 .53222 L
.47587 .53177 L
.47814 .53121 L
.48337 .52946 L
.48813 .52733 L
.4988 .52081 L
.50879 .5128 L
.51799 .50409 L
.53879 .48139 L
.57819 .43594 L
.61608 .39862 L
.63716 .38192 L
.65642 .36912 L
.69524 .34941 L
Mistroke
.71426 .34219 L
.735 .33575 L
.75636 .33041 L
.7757 .32649 L
.7854 .3248 L
.7905 .32398 L
.79589 .32316 L
.80061 .32248 L
.8019 .32229 L
.80329 .3221 L
.80459 .32193 L
.80579 .30902 L
.80695 .30902 L
.80803 .30902 L
.81046 .30902 L
.81488 .30902 L
.8542 .30902 L
.892 .30902 L
.93226 .30902 L
.971 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`00001Vo`1Vo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool00_ooo`03o`2I06Kooooo
00Coool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`0Eoooo000Ioooo401Vo`Goool00`000?ooooooo`0^oooo00<0003oooooool0;Oooo`030000
oooooooo02goool00`000?ooooooo`0Joooo00<0I_ooooooool04Oooo`030000oooooooo02goool0
02Woool706KoGoooo`030000oooooooo04[oool00`1Vooooooooo`11oooo000`oooo1`1VoeSoool0
0`000?ooooooo`15oooo1P1Vod?oool003Ooool506KoDoooo`030000oooooooo047oool406Ko1Ooo
o`03o`2Ioooooooo047oool003coool506KoC_ooo`80000moooo1@1Vo`Woool00ol0VOooooooo`11
oooo0011oooo101Vod[oool00`000?ooooooo`0hoooo101Vo`koool00ol0VOooooooo`11oooo0015
oooo0P1VodSoool00`000?ooooooo`0eoooo0`1Voa;oool00ol0VOooooooo`11oooo0017oooo0`1V
odGoool00`000?ooooooo`0boooo0`1VoaGoool00ol0VOooooooo`11oooo001:oooo0P1Vod?oool0
0`000?ooooooo`0`oooo0P1VoaSoool00ol0VOooooooo`11oooo001<oooo0`1Vod3oool20000;ooo
o`80I_lJoooo00?o09Woooooool0@Oooo`00Coooo`80I_lnoooo00<0003oooooool0;?ooo`80I_lL
oooo00?o09Woooooool0@Oooo`00DOooo`80I_lloooo00<0003oooooool0:_ooo`80I_lNoooo00?o
09Woooooool0@Oooo`00Doooo`80I_ljoooo00<0003oooooool0:?ooo`80I_lPoooo00?o09Wooooo
ool0@Oooo`00EOooo`80I_lhoooo00<0003oooooool09_ooo`80I_lRoooo00?o09Woooooool0@Ooo
o`00Eoooo`0306Kooooooooo03Goool200009_ooo`0306Kooooooooo02;oool00ol0VOooooooo`11
oooo001Hoooo0P1VocGoool00`000?ooooooo`0Soooo0P1VobGoool00ol0VOooooooo`11oooo001J
oooo0P1Voc?oool00`000?ooooooo`0Qoooo0P1VobOoool00ol0VOooooooo`11oooo001Loooo00<0
I_ooooooool0<?ooo`030000oooooooo023oool00`1Vooooooooo`0Woooo00?o09Woooooool0@Ooo
o`00GOooo`0306Kooooooooo02ooool00`000?ooooooo`0Noooo0P1Vob[oool00ol0VOooooooo`11
oooo001Noooo00<0I_ooooooool0;_ooo`80000Noooo00<0I_ooooooool0:_ooo`03o`2Ioooooooo
047oool005ooool00`1Vooooooooo`0]oooo00<0003oooooool06oooo`80I_l]oooo00?o09Wooooo
ool0@Oooo`00H?ooo`0306Kooooooooo02coool00`000?ooooooo`0Joooo00<0I_ooooooool0;Ooo
o`03o`2Ioooooooo047oool0067oool206Ko;?ooo`030000oooooooo01Woool00`1Vooooooooo`0^
oooo00?o09Woooooool0@Oooo`00Hoooo`0306Kooooooooo027oool500000oooo`030000oooooooo
01Soool00`1Vooooooooo`0_oooo00?o09Woooooool0@Oooo`00I?ooo`0306Kooooooooo02;oool0
0`000?ooooooo`03oooo00<0003oooooool05oooo`0306Kooooooooo033oool00ol0VOooooooo`11
oooo001Uoooo00<0I_ooooooool08Oooo`030000oooooooo00?oool300005_ooo`0306Kooooooooo
037oool00ol0VOooooooo`11oooo001Voooo00<0I_ooooooool08?ooo`030000oooooooo00?oool0
0`000?ooooooo`0Eoooo00<0I_ooooooool0<_ooo`03o`2Ioooooooo047oool006Ooool00`1Voooo
ooooo`0Ooooo00<0003oooooool00oooo`030000oooooooo01Goool00`1Vooooooooo`0boooo00?o
09Woooooool0@Oooo`00J?ooo`0306Kooooooooo01goool200001Oooo`030000oooooooo01Coool0
0`1Vooooooooo`0coooo00?o09Woooooool0@Oooo`00JOooo`0306Kooooooooo02?oool00`000?oo
ooooo`0Coooo00<0I_ooooooool0=?ooo`03o`2Ioooooooo047oool006[oool00`1Vooooooooo`0R
oooo0P0001?oool00`1Vooooooooo`0eoooo00?o09Woooooool0@Oooo`00Joooo`0306Kooooooooo
027oool00`000?ooooooo`0Aoooo00<0I_ooooooool0=_ooo`03o`2Ioooooooo047oool006_oool0
0`1Vooooooooo`0Qoooo00<0003oooooool04?ooo`0306Kooooooooo03Ooool00ol0VOooooooo`11
oooo001/oooo00<0I_ooooooool08?ooo`030000oooooooo00ooool00`1Vooooooooo`0hoooo00?o
09Woooooool0@Oooo`00KOooo`0306Kooooooooo01ooool00`000?ooooooo`0>oooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo047oool006koool00`1Vooooooooo`0Noooo0P0000koool00`1Voooo
ooooo`0joooo00?o09Woooooool0@Oooo`00Koooo`0306Kooooooooo01goool00`000?ooooooo`0<
oooo00<0I_ooooooool0>oooo`03o`2Ioooooooo047oool0073oool00`1Vooooooooo`0Loooo00<0
003oooooool03?ooo`0306Kooooooooo03_oool00ol0VOooooooo`11oooo001aoooo00<0I_oooooo
ool06oooo`030000oooooooo00_oool00`1Vooooooooo`0loooo00?o09Woooooool0@Oooo`00L_oo
o`0306Kooooooooo01[oool00`000?ooooooo`0:oooo00<0I_ooooooool0?Oooo`03o`2Ioooooooo
047oool007;oool00`1Vooooooooo`0Joooo0P0000[oool00`1Vooooooooo`0noooo00?o09Wooooo
ool0@Oooo`00Loooo`0306Kooooooooo01Woool00`000?ooooooo`08oooo00<0I_ooooooool0?ooo
o`03o`2Ioooooooo047oool007Coool00`1Vooooooooo`0Hoooo00<0003oooooool01oooo`0306Ko
oooooooo043oool00ol0VOooooooo`11oooo001eoooo00<0I_ooooooool05oooo`030000oooooooo
00Koool00`1Vooooooooo`11oooo00?o09Woooooool0@Oooo`00M_ooo`0306Kooooooooo01Koool0
0`000?ooooooo`05oooo00<0I_ooooooool0@_ooo`03o`2Ioooooooo047oool007Ooool00`1Voooo
ooooo`0Eoooo0P0000Goool00`1Vooooooooo`13oooo00?o09Woooooool0@Oooo`00N?ooo`0306Ko
oooooooo01Coool00`000?ooooooo`04oooo00<0I_ooooooool0@oooo`03o`2Ioooooooo047oool0
07Woool00`1Vooooooooo`0Coooo00<0003oooooool00oooo`0306Kooooooooo04Coool00ol0VOoo
ooooo`11oooo001joooo00<0I_ooooooool04_ooo`030000oooooooo00;oool00`1Vooooooooo`15
oooo00?o09Woooooool0@Oooo`00Noooo`0306Kooooooooo00Woool400001?ooo`030000oooooooo
0080I_m8oooo00?o09Woooooool0@Oooo`00O?ooo`0306Kooooooooo00Soool00`000?ooooooo`05
oooo00<0003oool0I_l0B_ooo`03o`2Ioooooooo047oool007goool00`1Vooooooooo`08oooo00<0
003oooooool01?ooo`<0001:oooo00?o09Woooooool0@Oooo`00O_ooo`80I_l9oooo00<0003ooooo
ool00oooo`030000oooooooo04[oool00ol0VOooooooo`11oooo0020oooo00<0I_ooooooool01?oo
o`040000oooooooo00000_ooo`80I_l00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00POoo
o`80I_l5oooo0P000003oooo06Ko06Ko00;oool00`000?ooooooo`1:oooo00?o09Woooooool0@Ooo
o`00Poooo`P0I_l4oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool008ooool20000Booo
o`03o`2Ioooooooo047oool008ooool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Sooo
o`030000oooooooo04[oool00ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_ooo`03o`2I
oooooooo047oool008ooool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Soooo`80001;
oooo00?o09Woooooool0@Oooo`00Soooo`030000oooooooo04[oool00ol0VOooooooo`11oooo002?
oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool008ooool00`000?ooooooo`1:oooo00?o
09Woooooool0@Oooo`00Soooo`030000oooooooo04[oool00ol0VOooooooo`11oooo002?oooo0P00
04_oool00ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool0
08ooool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Soooo`030000oooooooo04[oool0
0ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool008ooool0
0`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Soooo`80001;oooo00?o09Woooooool0@Ooo
o`00Soooo`030000oooooooo04[oool00ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_oo
o`03o`2Ioooooooo047oool008Soool200001Oooo`030000oooooooo04[oool00ol0VOooooooo`11
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool0
08Woool00`000?ooooooo`03oooo0`0004[oool00ol0VOooooooo`11oooo002:oooo00<0003ooooo
ool0Toooo`00Qoooo`040000oooooooo0000UOooo`00R?ooo`80002Foooo003ooooo8Oooo`00oooo
ob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo
00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Koool400000oooo`800003oooo100000?oool00`000?ooooooo`1k
oooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05
oooo00<0003oooooool02Oooo`030000oooooooo00Coool00`000?ooooooo`1koooo001joooo00<0
003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`09oooo00<0003oooooool01?oo
o`030000oooooooo07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo00Woool0
0`000?ooooooo`02oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool0
10000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0
003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00oooo
ob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.7878 .30902 L
.79892 .30902 L
.80403 .30902 L
.80943 .30902 L
.81165 .30902 L
.81288 .30902 L
.81404 .30902 L
s
.81404 .30902 m
.81423 .61803 L
s
0 .4 1 r
.02381 .31374 m
.04262 .31477 L
.06244 .3161 L
.08426 .31792 L
.10458 .32004 L
.14264 .32544 L
.16305 .32936 L
.18163 .33372 L
.20239 .3397 L
.22156 .34647 L
.25997 .36467 L
.2787 .37635 L
.29932 .39179 L
.33961 .43073 L
.37838 .47817 L
.39809 .50363 L
.41961 .52902 L
.42957 .53885 L
.4402 .54733 L
.44536 .55056 L
.45023 .55303 L
.45459 .55473 L
.45705 .55548 L
.45932 .55602 L
.46058 .55626 L
.46177 .55645 L
.46286 .55659 L
.46401 .5567 L
.46527 .55678 L
.46643 .55681 L
.46767 .55681 L
.46839 .55679 L
.46905 .55676 L
.47016 .55668 L
.47133 .55656 L
.47233 .55643 L
.47343 .55626 L
.47587 .55575 L
.47814 .55513 L
.48337 .5532 L
.48813 .55084 L
.4988 .54361 L
.50879 .53474 L
.51799 .5251 L
.53879 .49995 L
.57819 .4496 L
.61608 .40827 L
.63716 .38977 L
.65642 .37559 L
.69524 .35376 L
Mistroke
.71426 .34576 L
.735 .33863 L
.75636 .33271 L
.7757 .32837 L
.7854 .3265 L
.79589 .32468 L
.8007 .32391 L
.80579 .32314 L
.81012 .32251 L
.81131 .32234 L
.81259 .32217 L
.81379 .322 L
.81488 .30902 L
.81606 .30902 L
.81717 .30902 L
.8197 .30902 L
.82482 .30902 L
.834 .30902 L
.85478 .30902 L
.89352 .30902 L
.93471 .30902 L
.97439 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool01Oooo`0506Kooooooooo
oooo000000coool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo01Goool0
01Koool=06Ko2oooo`030000oooooooo02koool00`000?ooooooo`0]oooo00<0003oooooool0;Ooo
o`030000oooooooo01goool00`1Vooooooooo`0>oooo00<0003oooooool0;Oooo`008oooo`/0I_mQ
oooo00<0003oooooool0COooo`0306Kooooooooo03koool002koool406KoGOooo`030000oooooooo
04Ooool706Ko@?ooo`00<_ooo`D0I_mHoooo00<0003oooooool0@Oooo`H0I_l6oooo00?o09Wooooo
ool0?_ooo`00=oooo`D0I_mCoooo0P0003koool406Ko3?ooo`03o`2Ioooooooo03koool003coool5
06KoC_ooo`030000oooooooo03_oool206Ko4?ooo`03o`2Ioooooooo03koool0047oool406KoB_oo
o`030000oooooooo03Soool306Ko4_ooo`03o`2Ioooooooo03koool004Goool206KoB?ooo`030000
oooooooo03Goool306Ko5Oooo`03o`2Ioooooooo03koool004Ooool206KoA_ooo`030000oooooooo
03;oool306Ko6?ooo`03o`2Ioooooooo03koool004Woool206KoA?ooo`80000aoooo0P1Voa_oool0
0ol0VOooooooo`0noooo001;oooo0P1Vod;oool00`000?ooooooo`0^oooo0P1Voagoool00ol0VOoo
ooooo`0noooo001=oooo0P1Vod3oool00`000?ooooooo`0/oooo0P1Voaooool00ol0VOooooooo`0n
oooo001?oooo0P1Vockoool00`000?ooooooo`0Zoooo0P1Vob7oool00ol0VOooooooo`0noooo001A
oooo0`1Voc_oool00`000?ooooooo`0Xoooo0P1Vob?oool00ol0VOooooooo`0noooo001Doooo0P1V
ocWoool200009oooo`80I_lUoooo00?o09Woooooool0?_ooo`00E_ooo`80I_lgoooo00<0003ooooo
ool09Oooo`0306Kooooooooo02Goool00ol0VOooooooo`0noooo001Hoooo00<0I_ooooooool0=?oo
o`030000oooooooo02Coool00`1Vooooooooo`0Voooo00?o09Woooooool0?_ooo`00FOooo`80I_ld
oooo00<0003oooooool08_ooo`80I_lYoooo00?o09Woooooool0?_ooo`00Foooo`0306Kooooooooo
037oool00`000?ooooooo`0Qoooo00<0I_ooooooool0:Oooo`03o`2Ioooooooo03koool005coool0
0`1Vooooooooo`0`oooo0P00027oool00`1Vooooooooo`0Zoooo00?o09Woooooool0?_ooo`00GOoo
o`0306Kooooooooo02ooool00`000?ooooooo`0Ooooo00<0I_ooooooool0:oooo`03o`2Ioooooooo
03koool005koool00`1Vooooooooo`0^oooo00<0003oooooool07_ooo`0306Kooooooooo02coool0
0ol0VOooooooo`0noooo001Ooooo00<0I_ooooooool0;Oooo`030000oooooooo01coool206Ko;ooo
o`03o`2Ioooooooo03koool0063oool00`1Vooooooooo`0Toooo1@0000?oool00`000?ooooooo`0K
oooo00<0I_ooooooool0;oooo`03o`2Ioooooooo03koool0067oool00`1Vooooooooo`0Uoooo00<0
003oooooool00oooo`030000oooooooo01[oool00`1Vooooooooo`0`oooo00?o09Woooooool0?_oo
o`00H_ooo`0306Kooooooooo02Coool00`000?ooooooo`03oooo0`0001Woool00`1Vooooooooo`0a
oooo00?o09Woooooool0?_ooo`00Hoooo`0306Kooooooooo02?oool00`000?ooooooo`03oooo00<0
003oooooool06?ooo`0306Kooooooooo03;oool00ol0VOooooooo`0noooo001Toooo00<0I_oooooo
ool08_ooo`030000oooooooo00?oool00`000?ooooooo`0Goooo00<0I_ooooooool0<oooo`03o`2I
oooooooo03koool006Goool00`1Vooooooooo`0Poooo0P0000Goool00`000?ooooooo`0Foooo00<0
I_ooooooool0=?ooo`03o`2Ioooooooo03koool006Koool00`1Vooooooooo`0Voooo00<0003ooooo
ool05Oooo`0306Kooooooooo03Goool00ol0VOooooooo`0noooo001Woooo00<0I_ooooooool09Ooo
o`80000Foooo00<0I_ooooooool0=Oooo`03o`2Ioooooooo03koool006Soool00`1Vooooooooo`0T
oooo00<0003oooooool05?ooo`0306Kooooooooo03Koool00ol0VOooooooo`0noooo001Xoooo00<0
I_ooooooool09?ooo`030000oooooooo01?oool00`1Vooooooooo`0goooo00?o09Woooooool0?_oo
o`00JOooo`0306Kooooooooo02?oool00`000?ooooooo`0Boooo00<0I_ooooooool0>?ooo`03o`2I
oooooooo03koool006[oool00`1Vooooooooo`0Roooo00<0003oooooool04Oooo`0306Kooooooooo
03Woool00ol0VOooooooo`0noooo001[oooo00<0I_ooooooool08Oooo`80000Aoooo00<0I_oooooo
ool0>_ooo`03o`2Ioooooooo03koool006coool00`1Vooooooooo`0Poooo00<0003oooooool03ooo
o`0306Kooooooooo03_oool00ol0VOooooooo`0noooo001]oooo00<0I_ooooooool07oooo`030000
oooooooo00ooool00`1Vooooooooo`0koooo00?o09Woooooool0?_ooo`00KOooo`0306Kooooooooo
01ooool00`000?ooooooo`0>oooo00<0I_ooooooool0??ooo`03o`2Ioooooooo03koool006koool0
0`1Vooooooooo`0Noooo00<0003oooooool03Oooo`0306Kooooooooo03goool00ol0VOooooooo`0n
oooo001_oooo00<0I_ooooooool07Oooo`80000=oooo00<0I_ooooooool0?_ooo`03o`2Ioooooooo
03koool0073oool00`1Vooooooooo`0Loooo00<0003oooooool03?ooo`0306Kooooooooo03koool0
0ol0VOooooooo`0noooo001aoooo00<0I_ooooooool06oooo`030000oooooooo00_oool00`1Voooo
ooooo`0ooooo00?o09Woooooool0?_ooo`00LOooo`0306Kooooooooo01_oool00`000?ooooooo`0:
oooo00<0I_ooooooool0@?ooo`03o`2Ioooooooo03koool007;oool00`1Vooooooooo`0Joooo00<0
003oooooool02Oooo`0306Kooooooooo047oool00ol0VOooooooo`0noooo001coooo00<0I_oooooo
ool06Oooo`80000:oooo00<0I_ooooooool0@Oooo`03o`2Ioooooooo03koool007Coool00`1Voooo
ooooo`0Hoooo00<0003oooooool02?ooo`0306Kooooooooo04;oool00ol0VOooooooo`0noooo001d
oooo00<0I_ooooooool06?ooo`030000oooooooo00Ooool00`1Vooooooooo`13oooo00?o09Wooooo
ool0?_ooo`00MOooo`0306Kooooooooo01Ooool00`000?ooooooo`06oooo00<0I_ooooooool0A?oo
o`03o`2Ioooooooo03koool007Koool00`1Vooooooooo`0>oooo100000Coool00`000?ooooooo`05
oooo00<0I_ooooooool0AOooo`03o`2Ioooooooo03koool007Ooool00`1Vooooooooo`0=oooo00<0
003oooooool01Oooo`030000oooooooo00Coool00`1Vooooooooo`16oooo00?o09Woooooool0?_oo
o`00N?ooo`0306Kooooooooo00goool00`000?ooooooo`04oooo0`0000Coool00`1Vooooooooo`16
oooo00?o09Woooooool0?_ooo`00NOooo`0306Kooooooooo00goool00`000?ooooooo`03oooo00<0
003oooooool00oooo`0306Kooooooooo04Ooool00ol0VOooooooo`0noooo001joooo00<0I_oooooo
ool02_ooo`040000oooooooo00001?ooo`030000oooooooo00;oool00`1Vooooooooo`18oooo00?o
09Woooooool0?_ooo`00Noooo`0306Kooooooooo00[oool200001Oooo`050000oooooooooooo06Ko
04_oool00ol0VOooooooo`0noooo001loooo00<0I_ooooooool04?ooo`040000oooooooo06KoC?oo
o`03o`2Ioooooooo03koool007coool00`1Vooooooooo`0@oooo0P00000306Kooooooooo04_oool0
0ol0VOooooooo`0noooo001moooo00<0I_ooooooool03oooo`03000006Kooooo04goool00ol0VOoo
ooooo`0noooo001noooo0P1Vo`ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00P?oo
o`0306Kooooooooo00[oool206Ko00<0003oooooool0COooo`03o`2Ioooooooo03koool0087oool2
06Ko2?ooo`80I_l2oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool008?oool806Ko1?oo
o`80001>oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0n
oooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool008ooool00`000?ooooooo`1=
oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0noooo002?
oooo0P0004koool00ol0VOooooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo
03koool008ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo
04goool00ol0VOooooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool0
08ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`80001>oooo00?o09Wooooo
ool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0noooo002?oooo00<0003ooooo
ool0COooo`03o`2Ioooooooo03koool008Soool200001Oooo`030000oooooooo04goool00ol0VOoo
ooooo`0noooo0027oooo00@0003oooooool00004oooo00<0003oooooool0COooo`03o`2Ioooooooo
03koool008Woool00`000?ooooooo`03oooo0`0004goool00ol0VOooooooo`0noooo002:oooo00<0
003oooooool0Toooo`00Qoooo`040000oooooooo0000UOooo`00R?ooo`80002Foooo003ooooo8Ooo
o`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000
oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool400000oooo`800004oooo0P0000Coool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00<0003oooooool02Oooo`040000oooooooo00000oooo`030000oooooooo07_oool0
07[oool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooooooo00[oool00`000?oo
ooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0003ooooo
ool02_ooo`050000oooooooooooo000007goool007_oool01@000?ooooooooooo`00000?oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000
oooooooo017oool200002_ooo`800003oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.79749 .30902 L
.80799 .30902 L
.81373 .30902 L
.81654 .30902 L
.81909 .30902 L
.82028 .30902 L
.82156 .30902 L
.82277 .30902 L
s
.82277 .30902 m
.82311 .61803 L
s
0 .4 1 r
.02381 .31425 m
.04262 .31539 L
.06244 .31686 L
.08426 .31888 L
.10458 .32122 L
.14264 .32721 L
.16305 .33154 L
.18163 .33637 L
.20239 .34299 L
.22156 .35048 L
.25997 .37064 L
.2787 .38357 L
.29932 .40066 L
.33961 .44377 L
.37838 .4963 L
.39809 .52449 L
.41961 .55261 L
.42957 .56349 L
.4402 .57287 L
.44536 .57646 L
.45023 .57919 L
.45459 .58108 L
.45705 .5819 L
.45932 .5825 L
.46058 .58276 L
.46177 .58297 L
.46286 .58313 L
.46401 .58325 L
.46527 .58334 L
.46643 .58338 L
.46767 .58338 L
.46839 .58336 L
.46905 .58332 L
.47016 .58323 L
.47133 .5831 L
.47233 .58295 L
.47343 .58276 L
.47587 .5822 L
.47814 .58152 L
.48337 .57938 L
.48813 .57676 L
.4988 .56876 L
.50879 .55893 L
.51799 .54826 L
.53879 .52042 L
.57819 .46468 L
.61608 .41891 L
.63716 .39843 L
.65642 .38273 L
.69524 .35856 L
Mistroke
.71426 .3497 L
.735 .3418 L
.75636 .33525 L
.7757 .33044 L
.79612 .32632 L
.80507 .32477 L
.81015 .32395 L
.81488 .32323 L
.81941 .32257 L
.82072 .32239 L
.82195 .32221 L
.82306 .32206 L
.82426 .30902 L
.82545 .30902 L
.82676 .30902 L
.82941 .30902 L
.83417 .30902 L
.855 .30902 L
.89525 .30902 L
.93399 .30902 L
.97519 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool01oooo`0306Kooooo0000
00coool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo01Goool001Koool=
06Ko2oooo`030000oooooooo02koool00`000?ooooooo`0]oooo00<0003oooooool0;Oooo`030000
oooooooo01ooool00`1Vooooooooo`0<oooo00<0003oooooool0;Oooo`008oooo`H0I_mVoooo00<0
003oooooool0Coooo`0306Kooooooooo03coool002Woool706KoGoooo`030000oooooooo04[oool6
06Ko?_ooo`00<?ooo`L0I_mHoooo00<0003oooooool0A_ooo`@0I_l5oooo00?o09Woooooool0??oo
o`00=oooo`D0I_mCoooo0P0004;oool506Ko2Oooo`03o`2Ioooooooo03coool003coool406KoCooo
o`030000oooooooo03goool406Ko3_ooo`03o`2Ioooooooo03coool0043oool306KoC?ooo`030000
oooooooo03_oool206Ko4_ooo`03o`2Ioooooooo03coool004?oool206KoB_ooo`030000oooooooo
03Soool306Ko5?ooo`03o`2Ioooooooo03coool004Goool206KoB?ooo`030000oooooooo03Goool3
06Ko5oooo`03o`2Ioooooooo03coool004Ooool206KoA_ooo`80000coooo0`1Voa[oool00ol0VOoo
ooooo`0loooo0019oooo0P1VodCoool00`000?ooooooo`0`oooo0P1Voagoool00ol0VOooooooo`0l
oooo001;oooo0P1Vod;oool00`000?ooooooo`0^oooo0P1Voaooool00ol0VOooooooo`0loooo001=
oooo0P1Vod3oool00`000?ooooooo`0/oooo0P1Vob7oool00ol0VOooooooo`0loooo001?oooo0P1V
ockoool00`000?ooooooo`0[oooo00<0I_ooooooool08Oooo`03o`2Ioooooooo03coool0057oool2
06Ko??ooo`80000Zoooo0P1VobCoool00ol0VOooooooo`0loooo001Coooo0P1Voc[oool00`000?oo
ooooo`0Xoooo00<0I_ooooooool09?ooo`03o`2Ioooooooo03coool005Goool206Ko>?ooo`030000
oooooooo02Koool206Ko9oooo`03o`2Ioooooooo03coool005Ooool00`1Vooooooooo`0eoooo00<0
003oooooool09Oooo`0306Kooooooooo02Ooool00ol0VOooooooo`0loooo001Hoooo00<0I_oooooo
ool0=?ooo`030000oooooooo02Coool00`1Vooooooooo`0Xoooo00?o09Woooooool0??ooo`00FOoo
o`0306Kooooooooo03?oool200008oooo`80I_l[oooo00?o09Woooooool0??ooo`00F_ooo`0306Ko
oooooooo03;oool00`000?ooooooo`0Qoooo00<0I_ooooooool0:oooo`03o`2Ioooooooo03coool0
05_oool00`1Vooooooooo`0aoooo00<0003oooooool08?ooo`0306Kooooooooo02coool00ol0VOoo
ooooo`0loooo001Loooo00<0I_ooooooool0<?ooo`030000oooooooo01ooool00`1Vooooooooo`0]
oooo00?o09Woooooool0??ooo`00GOooo`0306Kooooooooo02Ooool500000oooo`030000oooooooo
01koool00`1Vooooooooo`0^oooo00?o09Woooooool0??ooo`00G_ooo`0306Kooooooooo02Soool0
0`000?ooooooo`03oooo00<0003oooooool07?ooo`80I_laoooo00?o09Woooooool0??ooo`00Gooo
o`0306Kooooooooo02Ooool00`000?ooooooo`03oooo0`0001_oool00`1Vooooooooo`0aoooo00?o
09Woooooool0??ooo`00H?ooo`0306Kooooooooo02Koool00`000?ooooooo`03oooo00<0003ooooo
ool06_ooo`0306Kooooooooo03;oool00ol0VOooooooo`0loooo001Qoooo00<0I_ooooooool09Ooo
o`030000oooooooo00?oool00`000?ooooooo`0Ioooo00<0I_ooooooool0<oooo`03o`2Ioooooooo
03coool0067oool00`1Vooooooooo`0Toooo0P0000Goool00`000?ooooooo`0Hoooo00<0I_oooooo
ool0=?ooo`03o`2Ioooooooo03coool006;oool00`1Vooooooooo`0Zoooo00<0003oooooool06?oo
o`0306Kooooooooo03Coool00ol0VOooooooo`0loooo001Soooo00<0I_ooooooool0:Oooo`80000H
oooo00<0I_ooooooool0=Oooo`03o`2Ioooooooo03coool006Coool00`1Vooooooooo`0Xoooo00<0
003oooooool05_ooo`0306Kooooooooo03Koool00ol0VOooooooo`0loooo001Uoooo00<0I_oooooo
ool09oooo`030000oooooooo01Goool00`1Vooooooooo`0goooo00?o09Woooooool0??ooo`00I_oo
o`0306Kooooooooo02Koool00`000?ooooooo`0Eoooo00<0I_ooooooool0=oooo`03o`2Ioooooooo
03coool006Ooool00`1Vooooooooo`0Uoooo00<0003oooooool05?ooo`0306Kooooooooo03Soool0
0ol0VOooooooo`0loooo001Xoooo00<0I_ooooooool09?ooo`80000Doooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo03coool006Soool00`1Vooooooooo`0Toooo00<0003oooooool04_ooo`0306Ko
oooooooo03[oool00ol0VOooooooo`0loooo001Yoooo00<0I_ooooooool08oooo`030000oooooooo
01;oool00`1Vooooooooo`0joooo00?o09Woooooool0??ooo`00J_ooo`0306Kooooooooo02;oool0
0`000?ooooooo`0Aoooo00<0I_ooooooool0>oooo`03o`2Ioooooooo03coool006_oool00`1Voooo
ooooo`0Qoooo00<0003oooooool04?ooo`0306Kooooooooo03coool00ol0VOooooooo`0loooo001[
oooo00<0I_ooooooool08Oooo`80000Aoooo00<0I_ooooooool0??ooo`03o`2Ioooooooo03coool0
06coool00`1Vooooooooo`0Poooo00<0003oooooool03oooo`0306Kooooooooo03goool00ol0VOoo
ooooo`0loooo001]oooo00<0I_ooooooool07oooo`030000oooooooo00koool00`1Vooooooooo`0n
oooo00?o09Woooooool0??ooo`00K_ooo`0306Kooooooooo01koool00`000?ooooooo`0=oooo00<0
I_ooooooool0?oooo`03o`2Ioooooooo03coool006koool00`1Vooooooooo`0Noooo00<0003ooooo
ool03Oooo`0306Kooooooooo03ooool00ol0VOooooooo`0loooo001_oooo00<0I_ooooooool07Ooo
o`80000=oooo00<0I_ooooooool0@?ooo`03o`2Ioooooooo03coool0073oool00`1Vooooooooo`0L
oooo00<0003oooooool02oooo`0306Kooooooooo047oool00ol0VOooooooo`0loooo001aoooo00<0
I_ooooooool06oooo`030000oooooooo00_oool00`1Vooooooooo`11oooo00?o09Woooooool0??oo
o`00LOooo`0306Kooooooooo01_oool00`000?ooooooo`0:oooo00<0I_ooooooool0@_ooo`03o`2I
oooooooo03coool007;oool00`1Vooooooooo`0Boooo100000Coool00`000?ooooooo`09oooo00<0
I_ooooooool0@oooo`03o`2Ioooooooo03coool007?oool00`1Vooooooooo`0Aoooo00<0003ooooo
ool01Oooo`030000oooooooo00Soool00`1Vooooooooo`14oooo00?o09Woooooool0??ooo`00M?oo
o`0306Kooooooooo017oool00`000?ooooooo`04oooo0`0000Soool00`1Vooooooooo`14oooo00?o
09Woooooool0??ooo`00M?ooo`0306Kooooooooo01;oool00`000?ooooooo`03oooo00<0003ooooo
ool01oooo`0306Kooooooooo04Goool00ol0VOooooooo`0loooo001eoooo00<0I_ooooooool03ooo
o`040000oooooooo00001?ooo`030000oooooooo00Koool00`1Vooooooooo`16oooo00?o09Wooooo
ool0??ooo`00M_ooo`0306Kooooooooo00ooool200001Oooo`030000oooooooo00Koool00`1Voooo
ooooo`16oooo00?o09Woooooool0??ooo`00Moooo`0306Kooooooooo01Goool00`000?ooooooo`05
oooo00<0I_ooooooool0Aoooo`03o`2Ioooooooo03coool007Soool00`1Vooooooooo`0Doooo0P00
00Goool00`1Vooooooooo`18oooo00?o09Woooooool0??ooo`00N?ooo`0306Kooooooooo01Coool0
0`000?ooooooo`03oooo00<0I_ooooooool0BOooo`03o`2Ioooooooo03coool007Woool00`1Voooo
ooooo`0Coooo00<0003oooooool00oooo`0306Kooooooooo04Woool00ol0VOooooooo`0loooo001j
oooo00<0I_ooooooool04_ooo`030000oooooooo00;oool00`1Vooooooooo`1:oooo00?o09Wooooo
ool0??ooo`00Noooo`0306Kooooooooo017oool01@000?ooooooooooo`1Vo`1=oooo00?o09Wooooo
ool0??ooo`00O?ooo`0306Kooooooooo013oool2000000?oool0I_ooool0COooo`03o`2Ioooooooo
03coool007coool00`1Vooooooooo`0@oooo00<0003oool0I_l0Coooo`03o`2Ioooooooo03coool0
07goool00`1Vooooooooo`0?oooo00<00000I_ooool0Coooo`03o`2Ioooooooo03coool007koool2
06Ko3oooo`030000oooooooo04ooool00ol0VOooooooo`0loooo0020oooo00<0I_ooooooool02_oo
o`80I_l00`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00POooo`0306Kooooooooo00Soool0
0`1Vooooooooo`020000D?ooo`03o`2Ioooooooo03coool008;oool206Ko1oooo`0506Kooooooooo
oooo0000057oool00ol0VOooooooo`0loooo0024oooo1`1Vo`Coool00`000?ooooooo`1?oooo00?o
09Woooooool0??ooo`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0loooo002?oooo00<0
003oooooool0Coooo`03o`2Ioooooooo03coool008ooool00`000?ooooooo`1?oooo00?o09Wooooo
ool0??ooo`00Soooo`80001@oooo00?o09Woooooool0??ooo`00Soooo`030000oooooooo04ooool0
0ol0VOooooooo`0loooo002?oooo00<0003oooooool0Coooo`03o`2Ioooooooo03coool008Soool2
00001Oooo`030000oooooooo04ooool00ol0VOooooooo`0loooo0027oooo00@0003oooooool00004
oooo00<0003oooooool0Coooo`03o`2Ioooooooo03coool008Woool00`000?ooooooo`03oooo0`00
04ooool00ol0VOooooooo`0loooo002:oooo00<0003oooooool0Toooo`00Qoooo`040000oooooooo
0000UOooo`00R?ooo`80002Foooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0R
oooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0
003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool4
00000oooo`800005oooo0`0000;oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool03?ooo`050000
oooooooooooo000007goool007[oool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000
oooooooo00Soool500000oooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003_oo
o`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001koooo00D0
003oooooooooool000003oooo`040000oooooooo00002Oooo`030000oooo000000?oool00`000?oo
ooooo`1koooo001loooo00<0003oooooool04Oooo`80000;oooo0P0000;oool00`000?ooooooo`1l
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
.2 1 0 r
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
.97619 .30902 L
.02381 .30902 L
F
0 g
.02381 .30894 m
.03279 .30893 L
.04262 .30891 L
.06244 .30885 L
.07298 .30881 L
.08426 .30875 L
.10458 .30861 L
.1148 .30851 L
.12589 .30838 L
.13547 .30824 L
.14603 .30805 L
.16586 .30754 L
.17672 .30717 L
.18689 .30673 L
.19727 .30618 L
.20714 .30553 L
.22566 .30389 L
.23525 .30277 L
.24547 .3013 L
.26386 .29777 L
.27414 .29515 L
.28527 .29165 L
.29488 .28797 L
.30544 .28309 L
.32538 .2709 L
.34644 .25278 L
.36595 .23029 L
.38687 .2001 L
.40668 .16769 L
.42823 .13369 L
.43826 .12067 L
.44376 .11479 L
.44892 .11025 L
.4533 .1072 L
.45556 .10595 L
.45803 .10482 L
.46058 .10394 L
.46197 .10358 L
.46327 .10332 L
.46448 .10315 L
.46559 .10305 L
.46687 .10301 L
.46807 .10303 L
.46923 .10312 L
.47046 .10328 L
.47163 .10349 L
.4727 .10374 L
.47531 .10457 L
.47779 .10563 L
.48272 .10852 L
Mistroke
.48809 .11279 L
.49766 .12297 L
.50654 .13481 L
.54572 .19789 L
.56573 .22726 L
.58736 .25259 L
.60826 .27065 L
.62747 .28253 L
.64634 .2908 L
.65704 .29433 L
.66701 .29703 L
.67749 .29934 L
.68741 .30112 L
.70597 .30364 L
.71565 .30462 L
.72592 .30546 L
.74436 .3066 L
.75375 .30703 L
.76387 .30741 L
.78216 .30792 L
.79176 .30812 L
.80224 .3083 L
.81331 .30845 L
.82335 .30855 L
.843 .30871 L
.85379 .30877 L
.86396 .30882 L
.87371 .30886 L
.88402 .30889 L
.90248 .30893 L
.91194 .30894 L
.9221 .30896 L
.94042 .30898 L
.94921 .30898 L
.95878 .30899 L
.97619 .309 L
Mfstroke
1 0 .6 r
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.79749 .30902 L
.80799 .30902 L
.81909 .30902 L
.8239 .30902 L
.82904 .30902 L
.83056 .30902 L
.832 .30902 L
.83329 .30902 L
s
.83329 .30902 m
.8335 .61803 L
s
0 .4 1 r
.02381 .3148 m
.04262 .31607 L
.06244 .3177 L
.08426 .31993 L
.10458 .32253 L
.14264 .32915 L
.16305 .33395 L
.18163 .33929 L
.20239 .34661 L
.22156 .35491 L
.25997 .37722 L
.2787 .39154 L
.29932 .41046 L
.33961 .45817 L
.37838 .51631 L
.39809 .54751 L
.41961 .57863 L
.42957 .59068 L
.4402 .60106 L
.44536 .60503 L
.45023 .60805 L
.45459 .61014 L
.45705 .61105 L
.45932 .61171 L
.46058 .61201 L
.46177 .61224 L
.46286 .61241 L
.46401 .61255 L
.46527 .61265 L
.46643 .61269 L
.46767 .61269 L
.46839 .61266 L
.46905 .61263 L
.47016 .61253 L
.47133 .61238 L
.47233 .61222 L
.47343 .61201 L
.47587 .61138 L
.47814 .61063 L
.48337 .60826 L
.48813 .60537 L
.4988 .59651 L
.50879 .58563 L
.51799 .57382 L
.53879 .54301 L
.57819 .48131 L
.61608 .43065 L
.63716 .40798 L
.65642 .3906 L
.69524 .36385 L
Mistroke
.71426 .35404 L
.735 .3453 L
.75636 .33805 L
.7757 .33273 L
.79612 .32817 L
.81488 .32475 L
.82426 .32327 L
.82899 .32258 L
.83028 .3224 L
.83167 .32221 L
.83297 .32203 L
.83417 .30902 L
.83546 .30902 L
.83683 .30902 L
.8393 .30902 L
.84487 .30902 L
.855 .30902 L
.8928 .30902 L
.93306 .30902 L
.9718 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.103006 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -12 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -6 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-3)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(2)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(3)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0028oooo0P0009Koool008Ooool010000?ooooooo`0009Goool008Woool00`000?oo
ooooo`03oooo0`0008koool0087oool400001Oooo`030000oooooooo00;oool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00R?ooo`800005oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Qoooo`@00004oooo00<0003oooooool0S_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`2>oooo0025oooo100000Koool30000S_ooo`00POooo`@00004<ol000<0003oooooool00ooo
o`030000oooooooo08koool008;oool00`0003?o03?o0002<ol000<0000co`0co`000P0000?oool0
0`000?ooooooo`2>oooo0021oooo00<0000co`0co`0013?o00800002<ol000@0003oooooool0002@
oooo0020oooo00<0000co`0co`002S?o00030000oooo0000093oool007ooool00`0003?o03?o000<
<ol00`0008ooool007koool00`0003?o03?o000><ol000<0003oooooool0S_ooo`00O_ooo`030000
<ol0<ol000hco`020000Soooo`00OOooo`030000<ol0<ol000lco`000`0003?o0000002>oooo001l
oooo00<0000co`0co`0043?o00040000<ol0<ol00000SOooo`00O?ooo`030000<ol0<ol0010co`00
100003?o03?o000008goool007_oool00`0003?o03?o000A<ol00P00008co`000`000?ooooooo`2:
oooo001joooo00<0000co`0co`004S?o00050000<ol0<ol0<ol0000008coool007[oool00`0003?o
03?o000B<ol000<0000co`0co`000S?o00030000oooooooo08Woool007Woool00`0003?o03?o000C
<ol000<0000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol000<0
000co`0co`000c?o00030000oooooooo08Soool007Soool00`0003?o03?o000D<ol00P0000Dco`00
0`000?ooooooo`27oooo001goooo00<0000co`0co`005C?o00030000<ol0<ol000Dco`000`000?oo
ooooo`26oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Dco`000`000?ooooooo`26
oooo001foooo00<0000co`0co`005S?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001e
oooo00<0000co`0co`005c?o00030000<ol0<ol000Hco`000`000?ooooooo`25oooo001doooo00<0
000co`0co`0063?o00800008<ol000<0003oooooool0Q?ooo`00M?ooo`030000<ol0<ol001Pco`00
0`0003?o03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol001Tco`000`0003?o
03?o0008<ol000<0003oooooool0Poooo`00Loooo`030000<ol0<ol0014co`0500000c?o00030000
<ol0<ol000Tco`000`000?ooooooo`22oooo001boooo00<0000co`0co`0053?o00030000<ol0<ol0
00<co`000`0003?o03?o000:<ol000<0003oooooool0POooo`00LOooo`030000<ol0<ol001Dco`00
0`0003?o03?o0003<ol00`0000Xco`000`000?ooooooo`21oooo001aoooo00<0000co`0co`003C?o
00@00004<ol000<0000co`0co`000c?o00030000<ol0<ol000/co`000`000?ooooooo`20oooo001`
oooo00<0000co`0co`005S?o00030000<ol0<ol000<co`000`0003?o03?o000;<ol000<0003ooooo
ool0P?ooo`00Koooo`030000<ol0<ol001Hco`0200001C?o00030000<ol0<ol000`co`000`000?oo
ooooo`1ooooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1n
oooo001^oooo00<0000co`0co`007S?o00030000<ol0<ol000dco`000`000?ooooooo`1noooo001]
oooo00<0000co`0co`007c?o0080000?<ol000<0003oooooool0OOooo`00K?ooo`030000<ol0<ol0
020co`000`0003?o03?o000?<ol000<0003oooooool0O?ooo`00Joooo`030000<ol0<ol0024co`00
0`0003?o03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o
03?o000@<ol000<0003oooooool0Noooo`00J_ooo`030000<ol0<ol0028co`000`0003?o03?o000A
<ol000<0003oooooool0N_ooo`00JOooo`030000<ol0<ol002<co`0200004c?o00030000oooooooo
07Woool006Soool00`0003?o03?o000T<ol000<0000co`0co`004c?o00030000oooooooo07Soool0
06Ooool00`0003?o03?o000U<ol000<0000co`0co`0053?o00030000oooooooo07Ooool006Koool0
0`0003?o03?o000V<ol000<0000co`0co`005C?o00030000oooooooo07Koool0037oool30000;?oo
o`@000000oooo`0003?o000X<ol000<0000co`0co`005S?o00030000oooooooo01;oool40000;ooo
o`<0000]oooo000boooo00<0003oooooool0:oooo`050000oooooooooooo000002Xco`02000063?o
00030000oooooooo017oool00`000?ooooooo`0aoooo00<0003oooooool0;?ooo`00;oooo`D0000]
oooo00<0003oool00000:c?o00030000<ol0<ol001Pco`000`000?ooooooo`0Aoooo00<0003ooooo
ool0;Oooo`D0000]oooo000Yoooo100000;oool010000?ooooooo`0002Ooool400000oooo`80000/
<ol000<0000co`0co`006C?o0080000Boooo00<0003oooooool0;?ooo`040000oooooooo0000;_oo
o`00<?ooo`030000oooo000002coool200000S?o00030000<ol0<ol002Tco`000`0003?o03?o000K
<ol00P0000koool010000?ooooooo`0002koool00`000?ooo`00000^oooo000aoooo0P0002[oool2
00000S?o0080000/<ol000<0000co`0co`007C?o0080000=oooo0P00033oool20000;_ooo`00Fooo
o`80000b<ol00P00020co`020000KOooo`00F?ooo`<0000d<ol000<0000co`0co`008C?o00<0001Z
oooo001Eoooo0`0003Lco`000`0003?o03?o000T<ol01@0006Goool004koool70000>S?o00030000
<ol0<ol002Tco`060000Goooo`00B?ooo`H00011<ol000<0000co`0co`00;c?o00H0001Ioooo000@
ooooo`00017oool001Koool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02Oooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Ooo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02Oooo`03000006Kooooo
00[oool00`000?ooooooo`09oooo00<0003oooooool02Oooo`030000oooooooo01Goool001Koool8
06Ko4?ooo`030000oooooooo02koool00`000?ooooooo`0]oooo00<0003oooooool0;Oooo`030000
oooooooo027oool00`1Vooooooooo`0:oooo00<0003oooooool0;Oooo`007_ooo`/0I_mVoooo00<0
003oooooool0DOooo`0306Kooooooooo03[oool002Woool506KoHOooo`030000oooooooo04_oool7
06Ko??ooo`00;_ooo`@0I_mMoooo00<0003oooooool0A_ooo`D0I_l6oooo00?o09Woooooool0>_oo
o`00<_ooo`D0I_mHoooo0P0004?oool406Ko2oooo`03o`2Ioooooooo03[oool003Ooool506KoDooo
o`030000oooooooo043oool206Ko3oooo`03o`2Ioooooooo03[oool003coool406KoCoooo`030000
oooooooo03goool306Ko4Oooo`03o`2Ioooooooo03[oool0043oool306KoC?ooo`030000oooooooo
03_oool206Ko5?ooo`03o`2Ioooooooo03[oool004?oool206KoB_ooo`030000oooooooo03Soool3
06Ko5_ooo`03o`2Ioooooooo03[oool004Goool206KoB?ooo`80000foooo0`1VoaWoool00ol0VOoo
ooooo`0joooo0017oooo0P1VodKoool00`000?ooooooo`0boooo0`1Voacoool00ol0VOooooooo`0j
oooo0019oooo0P1VodCoool00`000?ooooooo`0`oooo0P1Voaooool00ol0VOooooooo`0joooo001;
oooo0P1Vod;oool00`000?ooooooo`0^oooo0P1Vob7oool00ol0VOooooooo`0joooo001=oooo00<0
I_ooooooool0?oooo`030000oooooooo02goool00`1Vooooooooo`0Qoooo00?o09Woooooool0>_oo
o`00C_ooo`80I_looooo0P0002coool206Ko9?ooo`03o`2Ioooooooo03[oool0053oool206Ko?Ooo
o`030000oooooooo02[oool00`1Vooooooooo`0Toooo00?o09Woooooool0>_ooo`00D_ooo`0306Ko
oooooooo03[oool00`000?ooooooo`0Yoooo00<0I_ooooooool09Oooo`03o`2Ioooooooo03[oool0
05?oool206Ko>_ooo`030000oooooooo02Ooool206Ko:?ooo`03o`2Ioooooooo03[oool005Goool2
06Ko>?ooo`030000oooooooo02Koool00`1Vooooooooo`0Xoooo00?o09Woooooool0>_ooo`00Eooo
o`0306Kooooooooo03Goool200009_ooo`0306Kooooooooo02Woool00ol0VOooooooo`0joooo001H
oooo00<0I_ooooooool0=?ooo`030000oooooooo02Coool00`1Vooooooooo`0Zoooo00?o09Wooooo
ool0>_ooo`00FOooo`0306Kooooooooo03?oool00`000?ooooooo`0Soooo00<0I_ooooooool0:ooo
o`03o`2Ioooooooo03[oool005[oool00`1Vooooooooo`0boooo00<0003oooooool08_ooo`0306Ko
oooooooo02coool00ol0VOooooooo`0joooo001Koooo00<0I_ooooooool0:Oooo`D00003oooo00<0
003oooooool08Oooo`0306Kooooooooo02goool00ol0VOooooooo`0joooo001Loooo00<0I_oooooo
ool0:_ooo`030000oooooooo00?oool00`000?ooooooo`0Poooo00<0I_ooooooool0;_ooo`03o`2I
oooooooo03[oool005goool00`1Vooooooooo`0Yoooo00<0003oooooool00oooo`<0000Ooooo00<0
I_ooooooool0;oooo`03o`2Ioooooooo03[oool005koool00`1Vooooooooo`0Xoooo00<0003ooooo
ool00oooo`030000oooooooo01koool00`1Vooooooooo`0`oooo00?o09Woooooool0>_ooo`00G_oo
o`0306Kooooooooo02Soool00`000?ooooooo`03oooo00<0003oooooool07?ooo`80I_lcoooo00?o
09Woooooool0>_ooo`00Goooo`0306Kooooooooo02Koool200001Oooo`030000oooooooo01_oool0
0`1Vooooooooo`0coooo00?o09Woooooool0>_ooo`00H?ooo`0306Kooooooooo02coool00`000?oo
ooooo`0Joooo00<0I_ooooooool0=?ooo`03o`2Ioooooooo03[oool0067oool00`1Vooooooooo`0[
oooo0P0001[oool00`1Vooooooooo`0eoooo00?o09Woooooool0>_ooo`00H_ooo`0306Kooooooooo
02[oool00`000?ooooooo`0Ioooo00<0I_ooooooool0=Oooo`03o`2Ioooooooo03[oool006?oool0
0`1Vooooooooo`0Yoooo00<0003oooooool06?ooo`0306Kooooooooo03Koool00ol0VOooooooo`0j
oooo001Soooo00<0I_ooooooool0:Oooo`030000oooooooo01Ooool00`1Vooooooooo`0goooo00?o
09Woooooool0>_ooo`00I?ooo`0306Kooooooooo02Soool00`000?ooooooo`0Goooo00<0I_oooooo
ool0=oooo`03o`2Ioooooooo03[oool006Goool00`1Vooooooooo`0Woooo0P0001Ooool00`1Voooo
ooooo`0hoooo00?o09Woooooool0>_ooo`00I_ooo`0306Kooooooooo02Koool00`000?ooooooo`0E
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03[oool006Ooool00`1Vooooooooo`0Uoooo00<0
003oooooool05?ooo`0306Kooooooooo03[oool00ol0VOooooooo`0joooo001Woooo00<0I_oooooo
ool09Oooo`030000oooooooo01Coool00`1Vooooooooo`0koooo00?o09Woooooool0>Oooo`00J?oo
o`0306Kooooooooo02Coool00`000?ooooooo`0Coooo00<0I_ooooooool0??ooo`03o`2Ioooooooo
03Woool006Woool00`1Vooooooooo`0Soooo0P0001?oool00`1Vooooooooo`0moooo00?o09Wooooo
ool0>Oooo`00JOooo`0306Kooooooooo02?oool00`000?ooooooo`0Boooo00<0I_ooooooool0?Ooo
o`03o`2Ioooooooo03Woool006[oool00`1Vooooooooo`0Roooo00<0003oooooool04Oooo`0306Ko
oooooooo03koool00ol0VOooooooo`0ioooo001[oooo00<0I_ooooooool08Oooo`030000oooooooo
013oool00`1Vooooooooo`0ooooo00?o09Woooooool0>Oooo`00Joooo`0306Kooooooooo027oool0
0`000?ooooooo`0@oooo00<0I_ooooooool0?oooo`03o`2Ioooooooo03Woool006coool00`1Voooo
ooooo`0Poooo0P00013oool00`1Vooooooooo`10oooo00?o09Woooooool0>Oooo`00KOooo`0306Ko
oooooooo01ooool00`000?ooooooo`0>oooo00<0I_ooooooool0@Oooo`03o`2Ioooooooo03Woool0
06goool00`1Vooooooooo`0Ooooo00<0003oooooool03_ooo`0306Kooooooooo047oool00ol0VOoo
ooooo`0ioooo001^oooo00<0I_ooooooool07_ooo`030000oooooooo00goool00`1Vooooooooo`12
oooo00?o09Woooooool0>Oooo`00Koooo`0306Kooooooooo01Goool400001?ooo`030000oooooooo
00goool00`1Vooooooooo`12oooo00?o09Woooooool0>Oooo`00Koooo`0306Kooooooooo01Goool0
0`000?ooooooo`05oooo00<0003oooooool03?ooo`0306Kooooooooo04?oool00ol0VOooooooo`0i
oooo001`oooo00<0I_ooooooool05Oooo`030000oooooooo00Coool300002oooo`0306Kooooooooo
04Coool00ol0VOooooooo`0ioooo001aoooo00<0I_ooooooool05Oooo`030000oooooooo00?oool0
0`000?ooooooo`0;oooo00<0I_ooooooool0A?ooo`03o`2Ioooooooo03Woool0077oool00`1Voooo
ooooo`0Coooo00@0003oooooool00004oooo00<0003oooooool02_ooo`0306Kooooooooo04Goool0
0ol0VOooooooo`0ioooo001boooo00<0I_ooooooool04oooo`800005oooo00<0003oooooool02Ooo
o`0306Kooooooooo04Koool00ol0VOooooooo`0ioooo001boooo00<0I_ooooooool06_ooo`030000
oooooooo00Woool00`1Vooooooooo`16oooo00?o09Woooooool0>Oooo`00Loooo`0306Kooooooooo
01Woool200002Oooo`0306Kooooooooo04Ooool00ol0VOooooooo`0ioooo001doooo00<0I_oooooo
ool06?ooo`030000oooooooo00Soool00`1Vooooooooo`17oooo00?o09Woooooool0>Oooo`00M?oo
o`0306Kooooooooo01Soool00`000?ooooooo`07oooo00<0I_ooooooool0B?ooo`03o`2Ioooooooo
03Woool007Goool00`1Vooooooooo`0Goooo00<0003oooooool01_ooo`0306Kooooooooo04Woool0
0ol0VOooooooo`0ioooo001foooo00<0I_ooooooool05_ooo`030000oooooooo00Koool00`1Voooo
ooooo`19oooo00?o09Woooooool0>Oooo`00M_ooo`0306Kooooooooo01Koool200001_ooo`0306Ko
oooooooo04[oool00ol0VOooooooo`0ioooo001goooo00<0I_ooooooool05Oooo`030000oooooooo
00Coool00`1Vooooooooo`1;oooo00?o09Woooooool0>Oooo`00N?ooo`0306Kooooooooo01Coool0
0`000?ooooooo`04oooo00<0I_ooooooool0Boooo`03o`2Ioooooooo03Woool007Woool00`1Voooo
ooooo`0Coooo00<0003oooooool00oooo`0306Kooooooooo04coool00ol0VOooooooo`0ioooo001i
oooo00<0I_ooooooool04oooo`030000oooooooo00?oool00`1Vooooooooo`1<oooo00?o09Wooooo
ool0>Oooo`00N_ooo`0306Kooooooooo01;oool200000oooo`0306Kooooooooo04goool00ol0VOoo
ooooo`0ioooo001koooo00<0I_ooooooool04Oooo`050000oooooooooooo06Ko053oool00ol0VOoo
ooooo`0ioooo001loooo00<0I_ooooooool04?ooo`040000oooooooo06KoDOooo`03o`2Ioooooooo
03Woool007coool00`1Vooooooooo`0@oooo00<0003oool0I_l0D_ooo`03o`2Ioooooooo03Woool0
07goool00`1Vooooooooo`0?oooo00<00000I_ooool0D_ooo`03o`2Ioooooooo03Woool007koool2
06Ko3oooo`030000oooooooo05;oool00ol0VOooooooo`0ioooo0020oooo00<0I_ooooooool02ooo
o`0306Ko0000000005?oool00ol0VOooooooo`0ioooo0021oooo00<0I_ooooooool02Oooo`0306Ko
oooo000005Coool00ol0VOooooooo`0ioooo0022oooo00<0I_ooooooool01_ooo`80I_l2oooo00<0
003oooooool0D_ooo`03o`2Ioooooooo03Woool008?oool506Ko0P00000306Kooooooooo00;oool0
0`000?ooooooo`1Boooo00?o09Woooooool0>Oooo`00Qoooo`040000oooooooo00001?ooo`030000
oooooooo05;oool00ol0VOooooooo`0ioooo0029oooo00<0003oooooool00oooo`<0001Boooo00?o
09Woooooool0>Oooo`00R_ooo`030000oooooooo09?oool008Ooool010000?ooooooo`0009Goool0
08Soool20000U_ooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000
oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo
07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000?oool2
00001?ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00Woool010000?ooooooo`00
00?oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00koool0
0`000?ooooooo`0;oooo00<0003oooooool00_ooo`030000oooooooo07[oool007_oool00`000?oo
ooooo`0500003_ooo`030000oooooooo00Soool200001?ooo`030000oooooooo07_oool007_oool0
1@000?ooooooooooo`00000?oooo00@0003oooooool00009oooo00<0003oooooool00oooo`030000
oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool300000_ooo`030000oooooooo
07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-5.94123, \
-3.17232, 0.0414113, 0.0382884}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-5.94123, -3.17232, 0.0414113, 0.0382884}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 819}},
ScreenStyleEnvironment->"Working",
WindowSize->{578, 751},
WindowMargins->{{Automatic, 174}, {Automatic, -10}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 162, 4, 96, "Title"],
Cell[1892, 58, 1262, 33, 315, "Text"],
Cell[3157, 93, 120, 4, 49, "Text"],
Cell[3280, 99, 353, 9, 19, "Input",
  CellOpen->False],
Cell[3636, 110, 163, 4, 49, "Text"],
Cell[3802, 116, 88, 1, 30, "Input"],
Cell[3893, 119, 108, 1, 49, "Text"],
Cell[4004, 122, 281, 6, 19, "Input",
  CellOpen->False],
Cell[4288, 130, 74, 2, 19, "Input",
  CellOpen->False],
Cell[4365, 134, 75, 2, 19, "Input",
  CellOpen->False],
Cell[4443, 138, 373, 12, 68, "Text"],

Cell[CellGroupData[{
Cell[4841, 154, 645, 11, 150, "Input"],

Cell[CellGroupData[{
Cell[5511, 169, 24289, 1082, 186, 15375, 968, "GraphicsData", "PostScript", \
"Graphics"],
Cell[29803, 1253, 27462, 1136, 186, 15619, 985, "GraphicsData", "PostScript", \
"Graphics"],
Cell[57268, 2391, 27682, 1142, 186, 15702, 990, "GraphicsData", "PostScript", \
"Graphics"],
Cell[84953, 3535, 27764, 1143, 186, 15703, 990, "GraphicsData", "PostScript", \
"Graphics"],
Cell[112720, 4680, 27891, 1146, 186, 15733, 992, "GraphicsData", \
"PostScript", "Graphics"],
Cell[140614, 5828, 27804, 1146, 186, 15747, 993, "GraphicsData", \
"PostScript", "Graphics"],
Cell[168421, 6976, 27926, 1148, 186, 15751, 993, "GraphicsData", \
"PostScript", "Graphics"],
Cell[196350, 8126, 28096, 1151, 186, 15780, 995, "GraphicsData", \
"PostScript", "Graphics"],
Cell[224449, 9279, 28088, 1152, 186, 15792, 996, "GraphicsData", \
"PostScript", "Graphics"],
Cell[252540, 10433, 28143, 1153, 186, 15794, 996, "GraphicsData", \
"PostScript", "Graphics"],
Cell[280686, 11588, 28106, 1155, 186, 15842, 999, "GraphicsData", \
"PostScript", "Graphics"],
Cell[308795, 12745, 28206, 1155, 186, 15829, 998, "GraphicsData", \
"PostScript", "Graphics"],
Cell[337004, 13902, 28213, 1156, 186, 15844, 999, "GraphicsData", \
"PostScript", "Graphics"],
Cell[365220, 15060, 28181, 1156, 186, 15861, 1000, "GraphicsData", \
"PostScript", "Graphics"],
Cell[393404, 16218, 28176, 1156, 186, 15856, 1000, "GraphicsData", \
"PostScript", "Graphics"],
Cell[421583, 17376, 27966, 1151, 186, 15808, 997, "GraphicsData", \
"PostScript", "Graphics"],
Cell[449552, 18529, 28065, 1157, 186, 15886, 1002, "GraphicsData", \
"PostScript", "Graphics"],
Cell[477620, 19688, 28090, 1159, 186, 15940, 1005, "GraphicsData", \
"PostScript", "Graphics"],
Cell[505713, 20849, 27906, 1155, 186, 15893, 1002, "GraphicsData", \
"PostScript", "Graphics"],
Cell[533622, 22006, 27876, 1155, 186, 15912, 1003, "GraphicsData", \
"PostScript", "Graphics"],
Cell[561501, 23163, 27724, 1154, 186, 15922, 1004, "GraphicsData", \
"PostScript", "Graphics"],
Cell[589228, 24319, 27657, 1152, 186, 15904, 1003, "GraphicsData", \
"PostScript", "Graphics"],
Cell[616888, 25473, 27542, 1151, 186, 15910, 1003, "GraphicsData", \
"PostScript", "Graphics"],
Cell[644433, 26626, 27162, 1148, 186, 15939, 1005, "GraphicsData", \
"PostScript", "Graphics"],
Cell[671598, 27776, 26492, 1154, 186, 16221, 1023, "GraphicsData", \
"PostScript", "Graphics"],
Cell[698093, 28932, 25337, 1144, 186, 16289, 1028, "GraphicsData", \
"PostScript", "Graphics"],
Cell[723433, 30078, 26621, 1164, 186, 16382, 1033, "GraphicsData", \
"PostScript", "Graphics"],
Cell[750057, 31244, 27503, 1173, 186, 16353, 1031, "GraphicsData", \
"PostScript", "Graphics"],
Cell[777563, 32419, 27408, 1173, 186, 16367, 1032, "GraphicsData", \
"PostScript", "Graphics"],
Cell[804974, 33594, 27429, 1175, 186, 16400, 1034, "GraphicsData", \
"PostScript", "Graphics"],
Cell[832406, 34771, 26192, 1115, 186, 15338, 977, "GraphicsData", \
"PostScript", "Graphics"],
Cell[858601, 35888, 26973, 1158, 186, 15989, 1018, "GraphicsData", \
"PostScript", "Graphics"],
Cell[885577, 37048, 27060, 1161, 186, 16040, 1021, "GraphicsData", \
"PostScript", "Graphics"],
Cell[912640, 38211, 27058, 1160, 186, 16005, 1019, "GraphicsData", \
"PostScript", "Graphics"],
Cell[939701, 39373, 27113, 1159, 186, 15975, 1017, "GraphicsData", \
"PostScript", "Graphics"],
Cell[966817, 40534, 27109, 1165, 186, 16080, 1024, "GraphicsData", \
"PostScript", "Graphics"],
Cell[993929, 41701, 27277, 1164, 186, 16038, 1021, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1021209, 42867, 27337, 1165, 186, 16037, 1021, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1048549, 44034, 27538, 1171, 186, 16100, 1025, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1076090, 45207, 27777, 1170, 186, 16032, 1021, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1103870, 46379, 28063, 1177, 186, 16099, 1025, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1131936, 47558, 28567, 1182, 186, 16085, 1024, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1160506, 48742, 29070, 1191, 186, 16134, 1027, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1189579, 49935, 29609, 1198, 186, 16130, 1027, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1219191, 51135, 30333, 1208, 186, 16162, 1029, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1249527, 52345, 30071, 1185, 186, 15730, 1004, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1279647, 53536, 649, 11, 150, "Input"],

Cell[CellGroupData[{
Cell[1280321, 53551, 26038, 1076, 186, 14523, 929, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1306362, 54629, 25865, 1074, 186, 14533, 930, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1332230, 55705, 25818, 1081, 186, 14680, 939, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1358051, 56788, 25918, 1088, 186, 14788, 946, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1383972, 57878, 24454, 1072, 186, 14835, 949, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1408429, 58952, 24037, 1069, 186, 14867, 951, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1432469, 60023, 24358, 1073, 186, 14864, 951, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1456830, 61098, 25976, 1093, 186, 14866, 951, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1482809, 62193, 25952, 1094, 186, 14891, 953, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1508764, 63289, 25985, 1098, 186, 14977, 958, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1534752, 64389, 25922, 1097, 186, 14979, 958, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1560677, 65488, 25885, 1098, 186, 14990, 959, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1586565, 66588, 25872, 1097, 186, 14981, 958, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1612440, 67687, 25831, 1096, 186, 14960, 957, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1638274, 68785, 25762, 1094, 186, 14940, 956, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1664039, 69881, 24610, 1037, 186, 13918, 901, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1688652, 70920, 25451, 1084, 186, 14629, 946, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1714106, 72006, 25437, 1082, 186, 14603, 944, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1739546, 73090, 25454, 1082, 186, 14600, 944, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1765003, 74174, 25507, 1085, 186, 14632, 946, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1790513, 75261, 25512, 1084, 186, 14621, 945, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1816028, 76347, 25552, 1085, 186, 14629, 946, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1841583, 77434, 25586, 1085, 186, 14618, 945, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1867172, 78521, 25662, 1087, 186, 14650, 947, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1892837, 79610, 25644, 1088, 186, 14664, 948, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1918484, 80700, 25557, 1087, 186, 14654, 948, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1944044, 81789, 25682, 1087, 186, 14629, 946, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1969729, 82878, 25815, 1090, 186, 14661, 948, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1995547, 83970, 25825, 1089, 186, 14643, 947, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2021375, 85061, 25850, 1090, 186, 14647, 947, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2047228, 86153, 25970, 1092, 186, 14662, 948, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2073201, 87247, 26118, 1095, 186, 14689, 950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2099322, 88344, 26318, 1099, 186, 14727, 952, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2125643, 89445, 26488, 1101, 186, 14710, 951, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2152134, 90548, 26642, 1103, 186, 14727, 952, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2178779, 91653, 26773, 1105, 186, 14720, 952, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2205555, 92760, 27157, 1112, 186, 14747, 954, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2232715, 93874, 27410, 1115, 186, 14749, 954, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2260128, 94991, 27682, 1120, 186, 14782, 956, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2287813, 96113, 27959, 1123, 186, 14788, 956, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2315775, 97238, 28262, 1126, 186, 14767, 955, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

